'''
Created on 16 feb. 2022

@author: tleduc

Copyright 2020-2022 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from io import StringIO
from geopandas import clip
from t4gpd.commons.GeoDataFrameLib import GeoDataFrameLib
from t4gpd.demos.AbstractGeoDataFrameDemos import AbstractGeoDataFrameDemos
from t4gpd.demos.NantesBDT import NantesBDT

import matplotlib.pyplot as plt


class GeoDataFrameDemos2(AbstractGeoDataFrameDemos):
    '''
    classdocs
    '''

    @staticmethod
    def irisMadeleineInNantes():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/contoursiris

        iris = read_file("/home/tleduc/data/iris/CONTOURS-IRIS_2-1__SHP__FRA_2021-01-01/CONTOURS-IRIS/\
1_DONNEES_LIVRAISON_2021-06-00217/CONTOURS-IRIS_2-1_SHP_LAMB93_FXX-2021/CONTOURS-IRIS.shp")

        madeleine = iris[(iris.NOM_COM == "Nantes") & (iris.NOM_IRIS == "Madeleine")]

        madeleine.to_csv("/tmp/madeleine.csv", sep=";", index=False)
        '''
        _sio = StringIO("""INSEE_COM;NOM_COM;IRIS;CODE_IRIS;NOM_IRIS;TYP_IRIS;geometry
44109;Nantes;0108;441090108;Madeleine;H;POLYGON ((355966.7 6688574.6, 355890.4 6688546.7, 355833.1 6688539.5, 355749.6 6688529, 355385.6 6688603.8, 355385.4 6688606.3, 355551.7 6688685.3, 355666.6 6688667.5, 355751.2 6688713.9, 355759.8 6688723.3, 355662 6688931.3, 355516.4 6689067.2, 355516.1 6689067.5, 355555.7 6689086, 355701.9 6689160.9, 355836.8 6689230.8, 355866 6689247, 355905.8 6689274.7, 355974.8 6689317.7, 356036.1 6689353.1, 356066.8 6689368.8, 356090.5 6689379.8, 356090.6 6689379.5, 356094.4 6689372.2, 356097 6689366.4, 356092.5 6689364, 356086.1 6689127.2, 356039.7 6688918.8, 356011.4 6688787.9, 355967.6 6688577.6, 355966.7 6688574.6))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def irisMadeleineInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos2.irisMadeleineInNantesINSEEGrid()
        return NantesBDT.buildings(roi)

    @staticmethod
    def irisMadeleineInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos2.irisMadeleineInNantesINSEEGrid()
        return NantesBDT.roads(roi)

    @staticmethod
    def irisMadeleineInNantesINSEEGrid():
        '''
        # SOURCE:
        # https://www.insee.fr/fr/statistiques/4176290

        grid = read_file("/home/tleduc/data/insee/Filosofi2015_carreaux_200m_metropole.shp",
            mask=madeleine)

        grid.to_csv("/tmp/madeleine-grid.csv", sep=";", index=False)
        '''
        _sio = StringIO("""IdINSPIRE;Id_carr1km;I_est_cr;Id_carr_n;Groupe;Depcom;I_pauv;Id_car2010;Ind;Men;Men_pauv;Men_1ind;Men_5ind;Men_prop;Men_fmp;Ind_snv;Men_surf;Men_coll;Men_mais;Log_av45;Log_45_70;Log_70_90;Log_ap90;Log_inc;Log_soc;Ind_0_3;Ind_4_5;Ind_6_10;Ind_11_17;Ind_18_24;Ind_25_39;Ind_40_54;Ind_55_64;Ind_65_79;Ind_80p;Ind_inc;I_est_1km;geometry
CRS3035RES200mN2745200E3448800;CRS3035RES1000mN2745000E3448000;0;CRS3035RES200mN2745200E3448800;719472;44109;0;CRS3035RES200mN2745200E3448800;243.0;134.0;12.0;69.0;6.0;36.0;13.0;5760690.0;7550.0;131.0;3.0;42.0;1.0;5.0;86.0;0.0;17.0;19.5;4.0;13.0;13.0;20.5;120.0;29.0;13.0;7.0;2.0;2.0;0;POLYGON ((355254.74781201413 6688392.447911897, 355236.1007251136 6688591.051108183, 355435.309513901 6688610.6988489395, 355453.9564422081 6688412.095411543, 355254.74781201413 6688392.447911897))
CRS3035RES200mN2745200E3449000;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745200E3449000;719484;44109;0;CRS3035RES200mN2745200E3449000;94.0;74.0;24.0;63.0;1.0;18.0;2.0;1683520.3;2862.0;72.0;2.0;21.0;1.0;7.0;45.0;0.0;0.0;4.0;1.0;1.0;2.0;20.0;39.0;15.0;7.0;3.0;2.0;0.0;0;POLYGON ((355453.9564422081 6688412.095411543, 355435.309513901 6688610.6988489395, 355634.51813928277 6688630.3461738955, 355653.1649089593 6688431.742495428, 355453.9564422081 6688412.095411543))
CRS3035RES200mN2745800E3449400;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745800E3449400;719499;44109;0;CRS3035RES200mN2745800E3449400;681.5;382.0;67.0;209.0;7.0;75.0;59.0;13408228.7;23218.0;374.0;8.0;55.0;34.0;38.0;255.0;0.0;167.0;39.0;20.5;36.0;42.5;42.5;217.0;162.0;49.0;39.0;16.0;18.0;0;POLYGON ((355796.4314401406 6689047.200638423, 355777.78288987477 6689245.8042748105, 355976.9916655613 6689265.451491305, 355995.64005670114 6689066.847613798, 355796.4314401406 6689047.200638423))
CRS3035RES200mN2745600E3449200;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745600E3449200;719493;44109;0;CRS3035RES200mN2745600E3449200;322.5;223.0;42.0;153.0;2.0;46.0;9.0;7357402.8;11309.0;218.0;5.0;107.0;27.0;25.0;64.0;0.0;0.0;9.0;1.0;7.0;10.5;42.0;170.0;48.0;18.0;7.0;6.0;4.0;0;POLYGON ((355615.87072309875 6688828.949757712, 355597.22266035486 6689027.553247112, 355796.4314401406 6689047.200638423, 355815.0793439357 6688848.596907908, 355615.87072309875 6688828.949757712))
CRS3035RES200mN2745600E3449400;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745600E3449400;719495;44109;0;CRS3035RES200mN2745600E3449400;376.5;254.0;64.0;172.0;4.0;63.0;11.0;8291802.9;11624.0;249.0;5.0;88.0;55.0;19.0;91.0;1.0;0.0;18.0;8.5;9.0;12.0;55.0;169.0;64.0;25.0;11.0;3.0;2.0;0;POLYGON ((355815.0793439357 6688848.596907908, 355796.4314401406 6689047.200638423, 355995.64005670114 6689066.847613798, 356014.2878015113 6688868.24364221, 355815.0793439357 6688848.596907908))
CRS3035RES200mN2745600E3449600;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745600E3449600;719491;44109;0;CRS3035RES200mN2745600E3449600;287.0;188.0;39.0;116.0;1.0;34.0;14.0;6573766.0;9732.0;181.0;7.0;80.0;9.0;0.0;99.0;0.0;20.0;10.0;2.0;4.5;11.5;31.0;153.0;38.0;22.0;9.0;4.0;2.0;0;POLYGON ((356014.2878015113 6688868.24364221, 355995.64005670114 6689066.847613798, 356194.84851009026 6689086.494173208, 356213.4960958796 6688887.889960593, 356014.2878015113 6688868.24364221))
CRS3035RES200mN2745800E3449200;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745800E3449200;719487;44109;0;CRS3035RES200mN2745800E3449200;192.5;112.0;24.0;65.0;2.0;34.0;5.0;4856368.3;6349.0;110.0;2.0;61.0;6.0;0.0;45.0;0.0;1.0;8.0;5.0;8.5;5.0;27.0;77.0;18.0;26.0;11.0;2.0;5.0;0;POLYGON ((355597.22266035486 6689027.553247112, 355578.5739509989 6689226.156642333, 355777.78288987477 6689245.8042748105, 355796.4314401406 6689047.200638423, 355597.22266035486 6689027.553247112))
CRS3035RES200mN2745800E3449600;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745800E3449600;719500;44109;0;CRS3035RES200mN2745800E3449600;657.5;388.0;67.0;227.0;10.0;63.0;34.0;14025486.2;20182.0;386.0;2.0;33.0;27.0;17.0;311.0;0.0;113.0;37.5;8.0;25.5;37.5;61.5;270.0;117.0;43.0;31.5;19.0;7.0;0;POLYGON ((355995.64005670114 6689066.847613798, 355976.9916655613 6689265.451491305, 356176.2002781128 6689285.098291784, 356194.84851009026 6689086.494173208, 355995.64005670114 6689066.847613798))
CRS3035RES200mN2746000E3449400;CRS3035RES1000mN2746000E3449000;0;CRS3035RES200mN2746000E3449400;721600;44109;0;CRS3035RES200mN2746000E3449400;84.5;43.0;10.0;24.0;2.0;12.0;3.0;2281324.4;3490.0;42.0;1.0;43.0;0.0;0.0;0.0;0.0;0.0;4.0;3.0;4.0;7.5;10.0;25.0;13.0;5.0;9.0;0.0;4.0;0;POLYGON ((355777.78288987477 6689245.8042748105, 355759.1336930858 6689444.407817299, 355958.34262803965 6689464.055274954, 355976.9916655613 6689265.451491305, 355777.78288987477 6689245.8042748105))
CRS3035RES200mN2746000E3449600;CRS3035RES1000mN2746000E3449000;0;CRS3035RES200mN2746000E3449600;721599;44109;0;CRS3035RES200mN2746000E3449600;34.0;27.0;3.0;20.0;0.0;12.0;0.0;791844.5;1468.0;27.0;0.0;0.0;0.0;20.0;7.0;0.0;0.0;0.0;0.0;0.0;0.0;5.0;13.0;6.0;3.0;6.0;1.0;0.0;0;POLYGON ((355976.9916655613 6689265.451491305, 355958.34262803965 6689464.055274954, 356157.5513998944 6689483.702316556, 356176.2002781128 6689285.098291784, 355976.9916655613 6689265.451491305))
CRS3035RES200mN2745400E3449600;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745400E3449600;719497;44109;0;CRS3035RES200mN2745400E3449600;483.5;313.0;77.0;207.0;7.0;36.0;40.0;8898581.8;16044.0;313.0;0.0;9.0;1.0;81.0;222.0;0.0;125.0;19.0;9.0;20.0;28.5;63.0;161.0;95.0;35.0;38.0;12.0;3.0;0;POLYGON ((356032.9349000443 6688669.639576297, 356014.2878015113 6688868.24364221, 356213.4960958796 6688887.889960593, 356232.1430355322 6688689.285653696, 356032.9349000443 6688669.639576297))
CRS3035RES200mN2745800E3449000;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745800E3449000;719492;44109;0;CRS3035RES200mN2745800E3449000;328.0;201.0;33.0;122.0;2.0;70.0;18.0;8340779.9;13119.0;201.0;0.0;167.0;28.0;0.0;5.0;1.0;9.0;11.0;6.0;10.5;12.5;38.0;113.0;60.0;30.0;21.0;15.0;11.0;0;POLYGON ((355398.0137172896 6689007.905439882, 355379.3648488804 6689206.508593897, 355578.5739509989 6689226.156642333, 355597.22266035486 6689027.553247112, 355398.0137172896 6689007.905439882))
CRS3035RES200mN2745400E3449400;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745400E3449400;719498;44109;0;CRS3035RES200mN2745400E3449400;541.0;331.0;68.0;199.0;4.0;88.0;25.0;12476433.5;18770.0;310.0;21.0;98.0;25.0;9.0;199.0;0.0;44.0;29.0;5.0;22.0;25.0;53.0;226.0;80.0;49.0;29.0;16.0;7.0;0;POLYGON ((355833.7266013124 6688649.993083023, 355815.0793439357 6688848.596907908, 356014.2878015113 6688868.24364221, 356032.9349000443 6688669.639576297, 355833.7266013124 6688649.993083023))
CRS3035RES200mN2745400E3449200;CRS3035RES1000mN2745000E3449000;0;CRS3035RES200mN2745400E3449200;719486;44109;0;CRS3035RES200mN2745400E3449200;137.5;98.0;43.0;76.0;2.0;24.0;4.0;2410422.5;4457.0;92.0;6.0;86.0;0.0;0.0;10.0;2.0;4.0;7.0;2.0;4.0;4.5;22.0;59.0;24.0;6.0;7.0;2.0;0.0;0;POLYGON ((355634.51813928277 6688630.3461738955, 355615.87072309875 6688828.949757712, 355815.0793439357 6688848.596907908, 355833.7266013124 6688649.993083023, 355634.51813928277 6688630.3461738955))
CRS3035RES200mN2745400E3448800;CRS3035RES1000mN2745000E3448000;0;CRS3035RES200mN2745400E3448800;719464;44109;0;CRS3035RES200mN2745400E3448800;53.0;29.0;2.0;12.0;0.0;14.0;2.0;1741265.4;2166.0;29.0;0.0;0.0;29.0;0.0;0.0;0.0;0.0;2.0;0.0;2.0;1.0;3.0;11.0;9.0;11.0;5.0;8.0;1.0;0;POLYGON ((355236.1007251136 6688591.051108183, 355217.452991423 6688789.654209725, 355416.66193894553 6688809.302191641, 355435.309513901 6688610.6988489395, 355236.1007251136 6688591.051108183))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def plot(oFile=None):
        # LOAD DATASETS
        iris = GeoDataFrameDemos2.irisMadeleineInNantes()
        buildings = GeoDataFrameDemos2.irisMadeleineInNantesBuildings()
        roads = GeoDataFrameDemos2.irisMadeleineInNantesRoads()
        grid = GeoDataFrameDemos2.irisMadeleineInNantesINSEEGrid()

        # MAPPING
        fig, ax = plt.subplots(figsize=(0.7 * 8.26, 1 * 8.26))
        ax.set_title(NantesBDT.version(), size=24)
        # grid.plot(ax=basemap, column='Ind', alpha=0.95, legend=True)
        iris.boundary.plot(ax=ax, color='red')
        buildings.plot(ax=ax, color='grey', edgecolor='white')
        roads.plot(ax=ax, color='black', linewidth=1)
        grid.boundary.plot(ax=ax, color='green', linewidth=1)
        ax.axis("off")
        if oFile is None:
            fig.tight_layout()
            plt.show()
        else:
            plt.savefig(oFile, bbox_inches="tight")
        plt.close(fig)
