'''
Created on 2 juin 2022

@author: tleduc

Copyright 2020-2022 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from io import StringIO
from geopandas import clip, GeoDataFrame
from shapely import box, LineString
from t4gpd.commons.GeoDataFrameLib import GeoDataFrameLib
from t4gpd.demos.AbstractGeoDataFrameDemos import AbstractGeoDataFrameDemos
from t4gpd.demos.NantesBDT import NantesBDT


class GeoDataFrameDemos4(AbstractGeoDataFrameDemos):
    '''
    classdocs
    '''

    @staticmethod
    def bretagneDistrictInNantesRoi():
        _sio = StringIO("""geometry
POLYGON ((355621.6652469886 6689254.702599095, 355621.6652469886 6690054.702599095, 354821.6652469886 6690054.702599095, 354821.6652469886 6689254.702599095, 355621.6652469886 6689254.702599095))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def bretagneDistrictInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.bretagneDistrictInNantesRoi()
        return NantesBDT.buildings(roi)

    @staticmethod
    def bretagneDistrictInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.bretagneDistrictInNantesRoi()
        return NantesBDT.roads(roi)

    @staticmethod
    def cathedraleDistrictInNantesRoi():
        _sio = StringIO("""geometry
POLYGON ((356206.6120044511 6689310.160406497, 356206.6120044511 6690187.153400643, 355435.7798654291 6690187.153400643, 355435.7798654291 6689310.160406497, 356206.6120044511 6689310.160406497))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def cathedraleDistrictInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.cathedraleDistrictInNantesRoi()
        return NantesBDT.buildings(roi)

    @staticmethod
    def cathedraleDistrictInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.cathedraleDistrictInNantesRoi()
        return NantesBDT.roads(roi)

    @staticmethod
    def comfortPathInNantesRoi():
        _sio = StringIO("""geometry
POLYGON ((355743.641404 6689058.227064, 355743.641404 6689590.284898, 355037.981116 6689590.284898, 355037.981116 6689058.227064, 355743.641404 6689058.227064))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def comfortPathInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.comfortPathInNantesRoi()
        return NantesBDT.buildings(roi)

    @staticmethod
    def comfortPathInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.comfortPathInNantesRoi()
        return NantesBDT.roads(roi)

    @staticmethod
    def comfortPathInNantesTrack():
        _sio = StringIO("""gid;geometry
1;LINESTRING (355392.96470584260532632 6689221.3744371235370636, 355412.67132887372281402 6689244.53988672606647015, 355433.09852666116785258 6689255.78011080622673035, 355509.10439810110256076 6689275.44374090060591698, 355490.81650339963380247 6689324.15750889200717211, 355510.3057868488249369 6689336.78874534461647272, 355516.12081579066580161 6689339.13943534158170223, 355555.12937142804730684 6689331.42594018206000328, 355598.87898308114381507 6689341.36065902188420296, 355596.82560778578044847 6689346.87340179178863764, 355591.97690130537375808 6689352.70877896528691053, 355554.56406825740123168 6689396.68252452369779348, 355568.79533843748504296 6689401.76234283577650785, 355643.64140382345067337 6689426.23192811757326126, 355626.02107379987137392 6689471.04311584495007992, 355619.1835743592819199 6689490.28489797003567219, 355596.51908082998124883 6689468.18660745956003666, 355548.96530386694939807 6689445.19262360781431198, 355503.62613612611312419 6689424.17906180489808321, 355505.82558483036700636 6689399.87895506713539362, 355491.82603878510417417 6689398.69437266979366541, 355473.7311866115196608 6689409.93415133375674486, 355458.20811651338590309 6689417.95525676943361759, 355455.99495649326127023 6689428.3657007273286581, 355357.93626119446707889 6689449.15271293930709362, 355371.13083457422908396 6689388.58934582583606243, 355375.57350494508864358 6689369.76685459911823273, 355377.92664316802984104 6689364.25166197493672371, 355367.39326221233932301 6689359.24153527617454529, 355348.53702137572690845 6689350.70210501085966825, 355334.19520349189406261 6689344.32414614781737328, 355279.33167604188201949 6689319.49132502358406782, 355249.94372197875054553 6689306.14160723146051168, 355226.57632894982816651 6689295.84038443118333817, 355188.96458710660226643 6689278.86062657460570335, 355173.42680212174309418 6689285.08317295648157597, 355162.29672422946896404 6689255.99566111341118813, 355158.48683999408967793 6689242.23696675337851048, 355148.74747931980527937 6689212.13882182631641626, 355137.98111592716304585 6689178.65157704427838326, 355143.68804865196580067 6689180.00388703681528568, 355173.19613626052159816 6689159.17779209557920694, 355180.553304047731217 6689166.81197269260883331, 355249.86330052919220179 6689188.67875776905566454, 355259.09168292104732245 6689178.46078986767679453, 355275.34549884573789313 6689158.22706367075443268, 355323.42062583763618022 6689183.11225642077624798, 355353.7870587797369808 6689200.02321627270430326, 355387.35315817449009046 6689218.70356828160583973)
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def royaleDistrictInNantesRoi():
        _sio = StringIO("""geometry
POLYGON ((355434.58636375755 6689050.073765778, 355434.58636375755 6689576.426100205, 354776.9722446392 6689576.426100205, 354776.9722446392 6689050.073765778, 355434.58636375755 6689050.073765778))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def royaleDistrictInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.royaleDistrictInNantesRoi()
        return NantesBDT.buildings(roi)

    @staticmethod
    def royaleDistrictInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.royaleDistrictInNantesRoi()
        return NantesBDT.roads(roi)

    @staticmethod
    def commerceFeydeauInNantesRoi():
        bbox = box(355074.5, 6688983.5, 355440.5, 6689259.5)
        return GeoDataFrame([{"geometry": bbox}], crs="epsg:2154")

    @staticmethod
    def commerceFeydeauInNantesBuildings(postpcs=False):
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.commerceFeydeauInNantesRoi()
        buildings = NantesBDT.buildings(roi)
        if postpcs:
            IDS = ["029192554"] + list(range(302931787, 302931804))
            IDS = [f"BATIMENT0000000{id}" for id in IDS]
            buildings.drop(
                index=buildings[buildings.ID.isin(IDS)].index, inplace=True)
            buildings.reset_index(drop=True, inplace=True)
        return buildings

    @staticmethod
    def commerceFeydeauInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        '''
        roi = GeoDataFrameDemos4.commerceFeydeauInNantesRoi()
        return NantesBDT.roads(roi)

    @staticmethod
    def commerceFeydeauInNantesTrees(postpcs=False):
        """
        read_file("/home/tleduc/data/nantes_metropole/arbre_20200908_rgf93.shp",
            bbox=GeoDataFrameDemos4.commerceFeydeauInNantesRoi()).to_csv(
                "/tmp/1.csv", sep=";", index=False)
        """
        _sio = StringIO("""genre;espece;hauteurFut;hauteur;DIAMETRE;MI_PRINX;geometry
Prunus;cerasifera;< 5,5 m;6-10 m;16.0;183560;POINT (355233.72032061714 6689039.273333661)
Acer;platanoïdes;< 5,5 m;6-10 m;31.0;183561;POINT (355205.70985354995 6689041.345041888)
Acer;platanoïdes;< 5,5 m;6-10 m;25.0;183562;POINT (355202.53926669765 6689038.976961793)
Acer;platanoïdes;< 5,5 m;6-10 m;27.0;183563;POINT (355199.97007639334 6689035.864544464)
Acer;platanoïdes;< 5,5 m;6-10 m;30.0;183564;POINT (355197.9058922605 6689032.375033606)
Acer;platanoïdes;< 5,5 m;6-10 m;33.0;183565;POINT (355196.61624205083 6689028.522497988)
Acer;platanoïdes;< 5,5 m;6-10 m;37.0;183566;POINT (355196.43683025794 6689020.2608142495)
Acer;platanoïdes;< 5,5 m;6-10 m;36.0;183567;POINT (355197.520296312 6689016.176032237)
Acer;platanoïdes;< 5,5 m;6-10 m;38.0;183568;POINT (355199.6627758145 6689011.971288081)
Acer;platanoïdes;< 5,5 m;6-10 m;35.0;183569;POINT (355202.37299418455 6689008.822865842)
Acer;platanoïdes;< 5,5 m;6-10 m;26.0;183570;POINT (355205.64552751224 6689006.227665672)
Acer;platanoïdes;< 5,5 m;6-10 m;34.0;183571;POINT (355209.203854687 6689004.355880122)
Acer;platanoïdes;< 5,5 m;6-10 m;24.0;183572;POINT (355213.15756925324 6689003.095309576)
Acer;platanoïdes;< 5,5 m;6-10 m;33.0;183573;POINT (355217.28552783834 6689002.671020152)
Acer;platanoïdes;< 5,5 m;6-10 m;27.0;183574;POINT (355221.1969065144 6689003.029579143)
Acer;platanoïdes;< 5,5 m;6-10 m;35.0;183575;POINT (355224.94755161565 6689004.283135311)
Magnolia;soulangeana (x);< 5,5 m;6-10 m;30.0;183576;POINT (355232.9006580125 6689007.345024062)
Magnolia;soulangeana (x);< 5,5 m;0-5 m;11.0;183577;POINT (355236.1931585864 6689017.580813777)
Pinus;nigra;> 5,5 m;16-20 m;45.0;183578;POINT (355241.848255679 6689015.988043314)
Liquidambar;styraciflua;< 5,5 m;16-20 m;43.0;183579;POINT (355243.3962203236 6689020.881856534)
Prunus;cerasifera;< 5,5 m;6-10 m;16.0;183580;POINT (355239.3813926068 6689028.340127233)
Liquidambar;styraciflua;< 5,5 m;16-20 m;45.0;183581;POINT (355229.96566627186 6689046.881136391)
Magnolia;soulangeana (x);< 5,5 m;6-10 m;15.0;183582;POINT (355223.14200989075 6689042.8772759605)
Pinus;nigra;< 5,5 m;11-15 m;25.0;183583;POINT (355224.9740612692 6689048.445700529)
Liriodendron;tulipifera;< 5,5 m;21-30 m;34.0;183584;POINT (355220.31631359534 6689050.054399657)
Magnolia;soulangeana (x);< 5,5 m;6-10 m;18.0;183585;POINT (355212.786881811 6689046.105777902)
Tilia;tomentosa;< 5,5 m;6-10 m;51.0;183685;POINT (355132.4786774405 6689067.48372)
Tilia;tomentosa;< 5,5 m;6-10 m;48.0;183686;POINT (355136.40862912516 6689072.030656398)
Tilia;tomentosa;< 5,5 m;6-10 m;47.0;183687;POINT (355139.8802229453 6689076.581991253)
Tilia;tomentosa;< 5,5 m;6-10 m;48.0;183688;POINT (355143.6957473187 6689081.1298632575)
Tilia;tomentosa;< 5,5 m;6-10 m;48.0;183689;POINT (355147.36624667543 6689085.775253925)
Tilia;tomentosa;< 5,5 m;6-10 m;47.0;183690;POINT (355151.086430495 6689090.099345662)
Tilia;tomentosa;< 5,5 m;6-10 m;47.0;183691;POINT (355138.4723931321 6689100.405955821)
Tilia;tomentosa;< 5,5 m;6-10 m;52.0;183692;POINT (355134.94410111604 6689096.0379867535)
Tilia;tomentosa;< 5,5 m;6-10 m;40.0;183693;POINT (355131.08158749214 6689091.421503655)
Tilia;tomentosa;< 5,5 m;6-10 m;43.0;183694;POINT (355127.6369481728 6689086.647992108)
Tilia;tomentosa;< 5,5 m;6-10 m;44.0;183695;POINT (355123.7834460777 6689082.093921601)
Tilia;tomentosa;< 5,5 m;6-10 m;49.0;183696;POINT (355120.1357736503 6689077.441184447)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494968;POINT (355211.14683336054 6689071.082218322)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494969;POINT (355205.3920403113 6689066.322810142)
Platanus;acerifolia (x);< 5,5 m;6-10 m;25.0;6494970;POINT (355199.6380647654 6689061.663321696)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494971;POINT (355193.841423194 6689056.674425015)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494972;POINT (355188.22651936556 6689051.913873165)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494973;POINT (355182.47164463333 6689047.144473113)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494974;POINT (355176.81693600037 6689042.404232047)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494975;POINT (355171.0620613009 6689037.63483205)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494976;POINT (355166.2455740143 6689025.423236253)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494977;POINT (355173.5609612063 6689023.065118248)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494978;POINT (355179.5647387388 6689027.722564068)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494979;POINT (355184.5054314861 6689031.909055073)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6494980;POINT (355209.96486032224 6689052.4156387085)
Platanus;acerifolia (x);< 5,5 m;6-10 m;35.0;6494981;POINT (355216.29708747455 6689055.691414983)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6494982;POINT (355222.9808360427 6689059.184155272)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6494983;POINT (355219.47703619127 6689065.737996311)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6494984;POINT (355206.7099633082 6689058.857525567)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494985;POINT (355200.95517028676 6689054.098117462)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494986;POINT (355195.1813740986 6689049.458776429)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494987;POINT (355189.28571095405 6689044.580608467)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494988;POINT (355183.6607333212 6689039.810146424)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6494989;POINT (355177.77604327793 6689035.051800465)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6494990;POINT (355172.1221521589 6689030.4114791835)
Platanus;acerifolia (x);< 5,5 m;11-15 m;55.0;6495382;POINT (355415.4671902414 6689196.707927431)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495383;POINT (355407.0997843616 6689192.61940139)
Platanus;acerifolia (x);< 5,5 m;16-20 m;70.0;6495384;POINT (355310.496924888 6689191.040978901)
Platanus;acerifolia (x);< 5,5 m;16-20 m;60.0;6495385;POINT (355302.0842371191 6689186.303301097)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495386;POINT (355293.10733297205 6689181.000655835)
Platanus;acerifolia (x);< 5,5 m;16-20 m;60.0;6495387;POINT (355284.48759095283 6689176.604420738)
Platanus;acerifolia (x);< 5,5 m;16-20 m;60.0;6495388;POINT (355275.9830125247 6689171.6276709)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495389;POINT (355267.10701028485 6689166.4441124005)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495390;POINT (355398.1424927912 6689184.828428272)
Amelanchier;canadensis;> 5,5 m;0-5 m;10.0;6495025;POINT (355434.6349918043 6689253.099570936)
Amelanchier;canadensis;> 5,5 m;0-5 m;10.0;6495026;POINT (355437.26419930975 6689254.457058902)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495391;POINT (355389.3631856151 6689181.692570968)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495392;POINT (355380.42647626076 6689177.63867757)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495393;POINT (355372.14237753703 6689172.740066479)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495394;POINT (355363.217458794 6689168.905914802)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495395;POINT (355352.45828493417 6689163.168173053)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495396;POINT (355344.9271078007 6689158.693089609)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495397;POINT (355337.00023434724 6689155.929983056)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495398;POINT (355326.9129826731 6689150.486526869)
Platanus;acerifolia (x);< 5,5 m;11-15 m;50.0;6495399;POINT (355318.0623156657 6689143.514078861)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495400;POINT (355310.6955081633 6689139.587246822)
Platanus;acerifolia (x);< 5,5 m;11-15 m;45.0;6495401;POINT (355301.2283636703 6689137.87596828)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495402;POINT (355290.48255251284 6689131.328713461)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495403;POINT (355283.0124094812 6689125.763933263)
Platanus;acerifolia (x);< 5,5 m;11-15 m;45.0;6495404;POINT (355272.7945064402 6689121.4507137565)
Platanus;acerifolia (x);< 5,5 m;11-15 m;65.0;6495405;POINT (355263.75805875746 6689116.198519024)
Platanus;acerifolia (x);< 5,5 m;11-15 m;50.0;6495406;POINT (355255.05002316943 6689112.002859071)
Platanus;acerifolia (x);< 5,5 m;16-20 m;80.0;6495407;POINT (355268.4997768047 6689111.942856184)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495408;POINT (355282.87024313025 6689119.379798334)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495409;POINT (355289.21793974703 6689123.324955279)
Platanus;acerifolia (x);< 5,5 m;16-20 m;50.0;6495410;POINT (355298.75628065557 6689128.852840403)
Platanus;acerifolia (x);< 5,5 m;6-10 m;5.0;6495411;POINT (355315.5495728789 6689136.849546545)
Platanus;acerifolia (x);< 5,5 m;16-20 m;50.0;6495412;POINT (355321.07530271163 6689140.481659501)
Platanus;acerifolia (x);< 5,5 m;16-20 m;50.0;6495413;POINT (355327.62253278744 6689143.166112342)
Platanus;acerifolia (x);< 5,5 m;16-20 m;45.0;6495414;POINT (355333.01362410246 6689146.219752952)
Platanus;acerifolia (x);< 5,5 m;16-20 m;40.0;6495415;POINT (355340.83160997037 6689151.551858488)
Platanus;acerifolia (x);< 5,5 m;16-20 m;50.0;6495416;POINT (355349.36248597625 6689156.078724092)
Platanus;acerifolia (x);< 5,5 m;16-20 m;35.0;6495417;POINT (355359.5271401492 6689161.211775517)
Platanus;acerifolia (x);< 5,5 m;16-20 m;55.0;6495418;POINT (355367.60297697363 6689165.082847262)
Platanus;acerifolia (x);< 5,5 m;16-20 m;60.0;6495419;POINT (355376.39863393933 6689170.217099138)
Platanus;acerifolia (x);< 5,5 m;16-20 m;60.0;6495420;POINT (355385.5867803557 6689174.46878954)
Platanus;acerifolia (x);< 5,5 m;16-20 m;45.0;6495421;POINT (355394.56074164883 6689179.411723415)
Platanus;acerifolia (x);< 5,5 m;6-10 m;5.0;6495422;POINT (355404.49704951455 6689184.726509424)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495423;POINT (355412.0021745017 6689189.681452718)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495424;POINT (355420.9860275519 6689195.833415431)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495425;POINT (355247.59591174044 6689129.161211861)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495426;POINT (355256.22940612165 6689134.016995712)
Platanus;acerifolia (x);< 5,5 m;6-10 m;25.0;6495427;POINT (355265.05996274285 6689138.531418601)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495428;POINT (355274.0303268144 6689143.034705786)
Platanus;acerifolia (x);< 5,5 m;6-10 m;25.0;6495429;POINT (355282.8826661285 6689147.768788695)
Platanus;acerifolia (x);< 5,5 m;6-10 m;25.0;6495430;POINT (355291.6332044002 6689152.2738732025)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495431;POINT (355300.4846445233 6689156.89804443)
Platanus;acerifolia (x);< 5,5 m;6-10 m;35.0;6495432;POINT (355309.31511951407 6689161.402475387)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495433;POINT (355318.0684373251 6689166.247286991)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495434;POINT (355327.04068176966 6689170.980389596)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495435;POINT (355335.8813124146 6689175.504722828)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495436;POINT (355344.7225970767 6689180.108991854)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495437;POINT (355353.3542932445 6689184.7449524235)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495438;POINT (355362.44554355496 6689189.36716301)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495439;POINT (355371.1960820396 6689193.872247595)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495440;POINT (355379.81860368745 6689198.608209625)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495441;POINT (355389.56467191305 6689202.65548579)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495442;POINT (355397.8511414679 6689207.843864314)
Platanus;acerifolia (x);< 5,5 m;11-15 m;45.0;6495443;POINT (355401.1419777159 6689213.12305091)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495444;POINT (355391.3505269869 6689209.635733689)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495445;POINT (355381.2137233879 6689204.24264553)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495446;POINT (355372.6899594001 6689200.585081298)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495447;POINT (355364.71667797636 6689195.813833058)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495448;POINT (355353.13521015795 6689189.7230790835)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495449;POINT (355346.11671703414 6689186.842626307)
Platanus;acerifolia (x);< 5,5 m;11-15 m;40.0;6495450;POINT (355336.6863898868 6689182.303129137)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495451;POINT (355328.5348860257 6689177.733190926)
EMPLACEMENT CONSERVE;VIDE;Z.N.R.;Z.N.R;0.0;6495452;POINT (355319.9297326993 6689172.677322391)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495453;POINT (355311.1660140392 6689167.782632572)
Platanus;acerifolia (x);< 5,5 m;6-10 m;10.0;6495454;POINT (355302.2225009398 6689164.118507611)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495455;POINT (355293.4974613836 6689157.844517131)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495456;POINT (355284.61022212903 6689153.730263242)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495457;POINT (355275.7673843869 6689148.936146764)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495458;POINT (355266.50880309136 6689144.62507618)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495459;POINT (355257.9576160581 6689140.058405903)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495460;POINT (355248.8105827102 6689135.946276116)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495461;POINT (355261.49712339696 6689154.968464358)
Platanus;acerifolia (x);< 5,5 m;6-10 m;15.0;6495462;POINT (355271.2773998445 6689160.7541804705)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495463;POINT (355297.11232763104 6689172.194372017)
Platanus;acerifolia (x);< 5,5 m;6-10 m;5.0;6495464;POINT (355305.57176886377 6689177.76105666)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495465;POINT (355313.37536692887 6689181.334575323)
Platanus;acerifolia (x);< 5,5 m;6-10 m;10.0;6495466;POINT (355323.7839372948 6689185.7461627)
Platanus;acerifolia (x);< 5,5 m;6-10 m;10.0;6495467;POINT (355331.54434146464 6689191.368525983)
Platanus;acerifolia (x);< 5,5 m;11-15 m;35.0;6495468;POINT (355342.05878172896 6689197.727812844)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495469;POINT (355350.73185469594 6689201.314207918)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495470;POINT (355359.7572292417 6689207.655691615)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495471;POINT (355368.78035219497 6689211.279195225)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495472;POINT (355377.0814291309 6689214.588837803)
Platanus;acerifolia (x);< 5,5 m;11-15 m;20.0;6495473;POINT (355384.9116776254 6689221.419739829)
Platanus;acerifolia (x);< 5,5 m;11-15 m;30.0;6495474;POINT (355395.06196283863 6689223.575101941)
Platanus;acerifolia (x);< 5,5 m;16-20 m;75.0;6495475;POINT (355382.78739514604 6689225.594047159)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495476;POINT (355373.6999869228 6689221.441459075)
Platanus;acerifolia (x);< 5,5 m;16-20 m;65.0;6495477;POINT (355364.17570649215 6689217.632192715)
Platanus;acerifolia (x);< 5,5 m;16-20 m;70.0;6495478;POINT (355355.309840898 6689213.687638756)
Platanus;acerifolia (x);< 5,5 m;16-20 m;70.0;6495479;POINT (355345.9797614994 6689209.187292314)
Platanus;acerifolia (x);< 5,5 m;16-20 m;84.0;6495480;POINT (355337.0511639721 6689204.903501446)
Platanus;acerifolia (x);< 5,5 m;16-20 m;90.0;6495481;POINT (355328.4214297509 6689200.507347998)
Platanus;acerifolia (x);< 5,5 m;16-20 m;70.0;6495482;POINT (355319.55999738834 6689195.883258187)
Tilia;tomentosa;< 5,5 m;11-15 m;40.0;6494843;POINT (355154.1058707717 6689087.896545336)
Tilia;tomentosa;< 5,5 m;11-15 m;40.0;6494844;POINT (355150.7023051511 6689084.716735635)
Tilia;tomentosa;< 5,5 m;11-15 m;45.0;6494845;POINT (355146.5703989113 6689080.453683167)
Tilia;tomentosa;< 5,5 m;11-15 m;30.0;6494846;POINT (355142.68762202695 6689077.327754721)
Tilia;tomentosa;< 5,5 m;11-15 m;40.0;6494847;POINT (355139.24909351644 6689073.538679919)
Tilia;tomentosa;< 5,5 m;11-15 m;35.0;6494848;POINT (355134.1211041373 6689068.444389793)
Tilia;tomentosa;< 5,5 m;11-15 m;50.0;6494849;POINT (355115.0198435865 6689073.9266382605)
Tilia;tomentosa;< 5,5 m;11-15 m;35.0;6494850;POINT (355117.58182937483 6689079.281731385)
Tilia;tomentosa;< 5,5 m;11-15 m;50.0;6494851;POINT (355120.6035327755 6689084.643058535)
Tilia;tomentosa;< 5,5 m;6-10 m;10.0;6494852;POINT (355124.0801306293 6689089.421093429)
Tilia;tomentosa;< 5,5 m;11-15 m;30.0;6494853;POINT (355127.5595896908 6689094.548847336)
Tilia;tomentosa;< 5,5 m;11-15 m;40.0;6494854;POINT (355131.03512483486 6689099.196986668)
Tilia;tomentosa;< 5,5 m;11-15 m;45.0;6494855;POINT (355134.1711743826 6689103.877879568)
Magnolia;grandiflora;< 5,5 m;11-15 m;30.0;6496815;POINT (355260.4811306466 6689250.63632296)
Magnolia;grandiflora;< 5,5 m;11-15 m;30.0;6496816;POINT (355258.2310570549 6689254.092188126)
Magnolia;grandiflora;< 5,5 m;11-15 m;20.0;6496817;POINT (355261.46829144005 6689256.48393976)
Magnolia;grandiflora;< 5,5 m;11-15 m;20.0;6496818;POINT (355265.3953066437 6689258.910022337)
Magnolia;grandiflora;< 5,5 m;11-15 m;25.0;6496820;POINT (355272.7932282004 6689258.090096298)
Magnolia;grandiflora;< 5,5 m;6-10 m;25.0;6496128;POINT (355146.1158354437 6689054.2067362545)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496129;POINT (355151.8715276239 6689059.076056104)
Magnolia;grandiflora;< 5,5 m;6-10 m;25.0;6496130;POINT (355157.0630852106 6689063.390400558)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496131;POINT (355162.3763462852 6689067.923588048)
Magnolia;grandiflora;< 5,5 m;6-10 m;25.0;6496132;POINT (355167.5688031343 6689072.347844228)
Magnolia;grandiflora;< 5,5 m;6-10 m;30.0;6496133;POINT (355173.89631436503 6689078.711384902)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496134;POINT (355180.0357744983 6689085.296301209)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496135;POINT (355184.6262351635 6689090.6448022695)
Magnolia;grandiflora;< 5,5 m;6-10 m;15.0;6496136;POINT (355159.24415910296 6689078.371519786)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496137;POINT (355152.8014843124 6689072.588493767)
Magnolia;grandiflora;< 5,5 m;6-10 m;20.0;6496138;POINT (355146.0990153668 6689066.807591864)
Magnolia;grandiflora;< 5,5 m;6-10 m;15.0;6496139;POINT (355139.6500272217 6689061.474286303)
Celtis;australis;< 5,5 m;16-20 m;60.0;6496142;POINT (355076.8484114511 6688986.093661615)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495858;POINT (355244.25514499506 6688999.304193114)
Platanus;acerifolia (x);< 5,5 m;6-10 m;35.0;6495859;POINT (355250.67664683645 6689002.499297938)
Platanus;acerifolia (x);< 5,5 m;6-10 m;50.0;6495860;POINT (355256.91812768846 6689005.67588936)
Platanus;acerifolia (x);< 5,5 m;6-10 m;15.0;6495861;POINT (355261.04795968794 6689017.013747178)
Platanus;acerifolia (x);< 5,5 m;6-10 m;50.0;6495862;POINT (355258.10150941805 6689023.29323013)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6495863;POINT (355253.5491318566 6689028.706491035)
Platanus;acerifolia (x);< 5,5 m;6-10 m;50.0;6495864;POINT (355250.4297727104 6689035.836762071)
Platanus;acerifolia (x);< 5,5 m;6-10 m;25.0;6495865;POINT (355245.19941176433 6689046.321834539)
Platanus;acerifolia (x);< 5,5 m;6-10 m;50.0;6495866;POINT (355243.266884601 6689054.3917027125)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495867;POINT (355235.0431681505 6689064.201764307)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6495868;POINT (355230.8507763192 6689073.309358571)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6495869;POINT (355225.5854574019 6689072.193261952)
Platanus;acerifolia (x);< 5,5 m;6-10 m;30.0;6495870;POINT (355227.42574816826 6689065.063456079)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495871;POINT (355231.73124112346 6689056.344650099)
Platanus;acerifolia (x);< 5,5 m;6-10 m;35.0;6495872;POINT (355234.16513351916 6689050.928724945)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495873;POINT (355235.3731435247 6689043.464338939)
Platanus;acerifolia (x);< 5,5 m;6-10 m;15.0;6495874;POINT (355243.79821052484 6689031.394294563)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495875;POINT (355248.0549130414 6689026.483083173)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495876;POINT (355249.39772502624 6689019.617153424)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6495877;POINT (355253.59046932287 6689014.216825602)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495878;POINT (355248.5026747269 6689010.37128724)
Platanus;acerifolia (x);< 5,5 m;6-10 m;40.0;6495879;POINT (355241.9371962599 6689006.677727558)
Platanus;acerifolia (x);< 5,5 m;6-10 m;45.0;6495880;POINT (355235.36967408704 6689002.734368613)
Magnolia;sp;< 5,5 m;6-10 m;10.0;6495901;POINT (355254.73116460314 6689176.847710286)
Magnolia;sp;< 5,5 m;6-10 m;10.0;6495902;POINT (355248.8389533149 6689171.170102022)
Magnolia;sp;< 5,5 m;6-10 m;10.0;6495903;POINT (355243.86977422616 6689165.944608534)
Magnolia;sp;< 5,5 m;6-10 m;5.0;6495904;POINT (355238.46192444244 6689160.842613346)
Magnolia;sp;< 5,5 m;6-10 m;5.0;6495905;POINT (355233.11829684506 6689155.040608273)
Magnolia;sp;< 5,5 m;6-10 m;10.0;6495906;POINT (355227.16276269854 6689150.172921758)
Magnolia;sp;< 5,5 m;6-10 m;10.0;6495907;POINT (355222.3025156138 6689144.8266260885)
Magnolia;sp;< 5,5 m;6-10 m;5.0;6495908;POINT (355216.86182843836 6689139.3751571)
Cercis;siliquastrum;< 5,5 m;0-5 m;5.0;6495909;POINT (355247.92178333877 6689183.648416407)
Cercis;siliquastrum;< 5,5 m;0-5 m;10.0;6495910;POINT (355243.02885719726 6689188.964535336)
Cercis;siliquastrum;< 5,5 m;0-5 m;5.0;6495911;POINT (355237.3621073996 6689194.966480591)
Cercis;siliquastrum;< 5,5 m;0-5 m;5.0;6495912;POINT (355232.4653390286 6689199.81297675)
Platanus;acerifolia (x);< 5,5 m;16-20 m;58.0;6495913;POINT (355217.6308800734 6689204.061223714)
Celtis;australis;< 5,5 m;11-15 m;55.0;6496706;POINT (355120.083391427 6689008.853144463)
Celtis;australis;< 5,5 m;11-15 m;40.0;6496707;POINT (355112.3920963655 6689004.349392818)
Celtis;australis;< 5,5 m;11-15 m;70.0;6496708;POINT (355103.54253711656 6688999.955037564)
Celtis;australis;< 5,5 m;11-15 m;60.0;6496709;POINT (355094.23056260246 6688995.224713324)
Celtis;australis;< 5,5 m;11-15 m;30.0;6496710;POINT (355109.2744645907 6688989.705689227)
Celtis;australis;< 5,5 m;11-15 m;30.0;6496711;POINT (355118.827003621 6688993.3048783345)
Celtis;australis;< 5,5 m;11-15 m;40.0;6496712;POINT (355126.76532130456 6688997.466860494)
""")
        trees = GeoDataFrameLib.read_csv(_sio)

        if postpcs:
            IDS = list(range(6495901, 6495913))
            IDS += [6495388, 6495390, 6495392, 6495393, 6495396, 6495397, 6495398,
                    6495401, 6495402, 6495403, 6495404, 6495405, 6495406, 6495408,
                    6495410, 6495412, 6495414, 6495415, 6495417, 6495419, 6495425,
                    6495426, 6495427, 6495428, 6495429, 6495430, 6495431, 6495432,
                    6495433, 6495434, 6495435, 6495436, 6495437, 6495438, 6495439,
                    6495440, 6495441, 6495442, 6495443, 6495444, 6495445, 6495446,
                    6495447, 6495448, 6495449, 6495450, 6495451, 6495452, 6495453,
                    6495454, 6495455, 6495456, 6495457, 6495458, 6495459, 6495460,
                    6495461, 6495462, 6495464, 6495465, 6495466, 6495467, 6495470,
                    6495471, 6495477, 6495478, 6495481]
            trees.drop(
                index=trees[trees.MI_PRINX.isin(IDS)].index, inplace=True)
            trees.reset_index(drop=True, inplace=True)
            trees.at[trees[trees.MI_PRINX == 6495407].index[0],
                     "hauteur"] = "6-10 m"
            CROWNS = {
                "0-5 m": {"trunk_height": 2.0, "crown_radius": 1.5},
                "6-10 m": {"trunk_height": 4.0, "crown_radius": 3.0},
                "11-15 m": {"trunk_height": 5.0, "crown_radius": 5.0},
                "16-20 m": {"trunk_height": 6.0, "crown_radius": 7.0},
                "21-30 m": {"trunk_height": 8.0, "crown_radius": 11.0},
                "Z.N.R": {"trunk_height": 2.0, "crown_radius": 1.0},
            }
            trees["trunk_height"] = trees.hauteur.apply(
                lambda h: CROWNS[h]["trunk_height"])
            trees["crown_radius"] = trees.hauteur.apply(
                lambda h: CROWNS[h]["crown_radius"])

        return trees

    @staticmethod
    def commerceFeydeauInNantesWater(postpcs=False):
        """
        read_file("/home/tleduc/data/osm/pays-de-la-loire/gis_osm_water_a_free_1.shp",
            bbox=GeoDataFrameDemos4.commerceFeydeauInNantesRoi()).to_csv(
                "/tmp/1.csv", sep=";", index=False)
        """
        _sio = StringIO("""osm_id;code;fclass;name;geometry
361093275;8200;water;;POLYGON ((-1.5579218 47.2119217, -1.5579213 47.2119357, -1.5579165 47.2119492, -1.5579077 47.2119618, -1.5578952 47.2119729, -1.5578796 47.2119819, -1.5578615 47.2119886, -1.5578419 47.2119925, -1.5578214 47.2119936, -1.5578011 47.2119918, -1.5577817 47.2119871, -1.5577642 47.2119799, -1.5577494 47.2119703, -1.5577378 47.2119588, -1.5577299 47.2119459, -1.5577262 47.2119322, -1.5577267 47.2119183, -1.5577315 47.2119047, -1.5577403 47.2118921, -1.5577528 47.2118811, -1.5577684 47.211872, -1.5577864 47.2118654, -1.5578061 47.2118614, -1.5578266 47.2118603, -1.5578469 47.2118622, -1.5578662 47.2118668, -1.5578837 47.2118741, -1.5578986 47.2118837, -1.5579102 47.2118952, -1.5579181 47.211908, -1.5579218 47.2119217))
1172832933;8200;water;;POLYGON ((-1.5577121 47.2131132, -1.55764 47.213148, -1.5575246 47.2131874, -1.5575045 47.2131776, -1.5575904 47.2131318, -1.5576822 47.2130984, -1.5577121 47.2131132))
1172832934;8200;water;;POLYGON ((-1.5578834 47.2130394, -1.557816 47.2130822, -1.5577121 47.2131132, -1.5576822 47.2130984, -1.557769 47.2130597, -1.5578621 47.2130285, -1.5578834 47.2130394))
1172832935;8200;water;;POLYGON ((-1.5578146 47.2130044, -1.5577386 47.2130451, -1.5576393 47.2130771, -1.5576152 47.2130651, -1.5576941 47.2130238, -1.557795 47.2129944, -1.5578146 47.2130044))
1172832936;8200;water;;POLYGON ((-1.5580011 47.2129291, -1.5579183 47.2129699, -1.5578146 47.2130044, -1.557795 47.2129944, -1.5578749 47.2129488, -1.5579773 47.2129171, -1.5580011 47.2129291))
1172832937;8200;water;;POLYGON ((-1.5578497 47.2129365, -1.5577703 47.2129818, -1.5576749 47.2130146, -1.5576487 47.213002, -1.5577271 47.2129599, -1.5578281 47.212926, -1.5578497 47.2129365))
1172832938;8200;water;;POLYGON ((-1.557574 47.2128025, -1.5574989 47.2128431, -1.5573983 47.2128731, -1.5573779 47.2128628, -1.557457 47.2128213, -1.5575548 47.212792, -1.557574 47.2128025))
1172832939;8200;water;;POLYGON ((-1.5576049 47.2127358, -1.5575259 47.2127797, -1.5574288 47.2128083, -1.557403 47.2127967, -1.5574857 47.212758, -1.5575829 47.2127243, -1.5576049 47.2127358))
1172832940;8200;water;;POLYGON ((-1.5573913 47.2127855, -1.5573105 47.2128271, -1.5572108 47.2128596, -1.5571873 47.2128469, -1.5572657 47.2128045, -1.5573683 47.2127735, -1.5573913 47.2127855))
""")
        water = GeoDataFrameLib.read_csv(_sio, crs="epsg:4326")
        water = water.to_crs("epsg:2154")
        return water

    @staticmethod
    def commerceFeydeauInNantesPath1():
        waypoints = GeoDataFrameDemos4.commerceFeydeauInNantesWaypoints1()
        return GeoDataFrame([{"geometry": LineString(waypoints.geometry)}], crs=waypoints.crs)

    @staticmethod
    def commerceFeydeauInNantesPath2():
        _sio = StringIO("""geometry
MultiLineString ((355266.67524864181177691 6689003.58286331128329039, 355234.14613407291471958 6689064.94797699898481369, 355205.90719539282144979 6689054.80148575082421303, 355187.23159433016553521 6689035.78776307869702578, 355150.67401724768569693 6689010.67006647773087025, 355145.7277559112990275 6689027.04012018069624901, 355133.58221824065549299 6689032.65771413780748844, 355126.84174604166764766 6689037.16293329000473022, 355095.48340827133506536 6689057.54779675975441933, 355123.03376798465615138 6689125.90247301943600178, 355138.22369604284176603 6689179.36506295017898083, 355173.81578237522626296 6689160.89887589868158102, 355194.0275680071208626 6689153.34598872344940901, 355237.98850580648286268 6689188.69954809173941612, 355258.27412374701816589 6689164.49820563290268183, 355237.50232082110596821 6689152.69402636494487524, 355207.516313421074301 6689135.26286439783871174, 355211.57864669983973727 6689132.08854337781667709, 355227.0549910104018636 6689140.77594424411654472, 355238.44743705401197076 6689146.2860161866992712, 355267.01842045941157266 6689167.87381617445498705, 355300.41544670541770756 6689186.53792100492864847, 355297.20078628370538354 6689193.01667188946157694, 355350.91680657933466136 6689219.23908032011240721, 355407.22157399728894234 6689239.46000812388956547, 355420.43334522668737918 6689210.22927357628941536, 355390.1792964770575054 6689189.38471272587776184, 355339.0695841092383489 6689157.69191605318337679, 355334.99523301905719563 6689167.12760189455002546, 355282.68299837573431432 6689137.40732358675450087, 355257.65822842170018703 6689123.20328237302601337, 355239.93664568715030327 6689115.45939748082309961, 355225.44812281843042001 6689106.60784605424851179, 355233.03741745906881988 6689100.40810982137918472, 355257.8998220291105099 6689111.86688942369073629, 355274.06207587441895157 6689122.16282459907233715, 355281.07954023615457118 6689109.2959394222125411, 355343.26501153316348791 6689141.63355298340320587, 355364.31132520810933784 6689100.23083283845335245, 355338.32683041045675054 6689085.97475996147841215))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def commerceFeydeauInNantesWaypoints1():
        _sio = StringIO("""id;geometry
1;POINT (355266.6752486418 6689003.582863311)
2;POINT (355234.1461340729 6689064.947976999)
4;POINT (355205.9071953928 6689054.801485751)
7;POINT (355187.23159433017 6689035.787763079)
9;POINT (355150.6740172477 6689010.670066478)
12;POINT (355145.7277559113 6689027.040120181)
13;POINT (355133.58221824066 6689032.657714138)
14;POINT (355126.84174604167 6689037.16293329)
15;POINT (355094.507061138 6689057.15896728)
17;POINT (355117.1240950218 6689114.235760006)
19;POINT (355137.1069045223 6689179.9464677125)
23;POINT (355194.0275680071 6689153.345988723)
24;POINT (355237.9885058065 6689188.699548092)
26;POINT (355258.274123747 6689164.498205633)
28;POINT (355237.5023208211 6689152.694026365)
31;POINT (355207.5163134211 6689135.262864398)
32;POINT (355211.57864669984 6689132.088543378)
35;POINT (355239.0217225409 6689145.677887823)
36;POINT (355267.0184204594 6689167.873816174)
37;POINT (355300.4154467054 6689186.537921005)
38;POINT (355297.2007862837 6689193.016671889)
40;POINT (355350.91680657933 6689219.23908032)
41;POINT (355407.2215739973 6689239.460008124)
42;POINT (355420.4333452267 6689210.229273576)
43;POINT (355390.17929647706 6689189.384712726)
46;POINT (355339.06958410924 6689157.691916053)
47;POINT (355334.99523301906 6689167.127601895)
49;POINT (355282.68299837573 6689137.407323587)
51;POINT (355236.86425548047 6689114.2762046885)
52;POINT (355225.44812281843 6689106.607846054)
53;POINT (355233.03741745907 6689100.408109821)
55;POINT (355257.8998220291 6689111.866889424)
56;POINT (355274.0620758744 6689122.162824599)
57;POINT (355281.07954023615 6689109.295939422)
58;POINT (355343.26501153316 6689141.633552983)
59;POINT (355364.3113252081 6689100.230832838)
60;POINT (355338.32683041046 6689085.9747599615)
""")
        return GeoDataFrameLib.read_csv(_sio)

    def commerceFeydeauInNantesRailways(postpcs=False):
        """
        read_file("/home/tleduc/data/osm/pays-de-la-loire/gis_osm_railways_free_1.shp",
            mask=GeoDataFrameDemos4.commerceFeydeauInNantesRoi()).to_csv(
                "/tmp/1.csv", sep=";", index=False)
        """
        _sio = StringIO("""osm_id;code;fclass;name;layer;bridge;tunnel;geometry
51193296;6101;rail;Galerie de la Bourse;-1;F;T;LINESTRING (-1.5570432 47.2114196, -1.5567824 47.2114805, -1.5563525 47.2116, -1.5556895 47.211816, -1.5552498 47.2119639, -1.5547744 47.2121318, -1.5543339 47.2123, -1.5535332 47.2126378, -1.5534085 47.2126936)
51194255;6104;tram;;0;F;F;LINESTRING (-1.5550797 47.2136518, -1.5551049 47.2136934, -1.5551235 47.2137433, -1.5551223 47.2137884, -1.5551152 47.21381, -1.5551084 47.2138327, -1.5550933 47.2138555, -1.5550715 47.213885, -1.5550467 47.2139092, -1.5550321 47.2139184, -1.5550104 47.2139313, -1.5549644 47.2139588)
140332262;6101;rail;Galerie de la Bourse;-1;F;T;LINESTRING (-1.5533708 47.2126646, -1.554314 47.2122767, -1.5546061 47.2121652, -1.5547555 47.2121081, -1.5552318 47.2119399, -1.5556718 47.2117919, -1.556325 47.211571, -1.5567648 47.2114514, -1.5570252 47.2113864)
156559282;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5629014 47.2103233, -1.5627834 47.2103714, -1.5626685 47.2104147, -1.5623863 47.2105187, -1.5618621 47.2107281, -1.5612735 47.2109606, -1.5608619 47.2111213, -1.5604415 47.2112844, -1.5600924 47.2114218, -1.5599766 47.2114682, -1.559862 47.2115163, -1.559736 47.2115695, -1.5596075 47.2116269, -1.5595561 47.2116519, -1.5594318 47.2117124, -1.5593661 47.2117455, -1.5593008 47.2117791, -1.5592234 47.2118203, -1.559147 47.2118624, -1.5590642 47.2119095, -1.5590266 47.2119311, -1.5589892 47.2119527, -1.5589293 47.2119895, -1.5588809 47.2120194, -1.5588569 47.2120345, -1.5588329 47.2120494, -1.5587539 47.2120994, -1.5587147 47.2121248, -1.5586759 47.2121512, -1.5585192 47.2122619, -1.5584437 47.212316, -1.5584251 47.2123303, -1.5584064 47.2123445, -1.5583695 47.212373, -1.5582313 47.2124828, -1.5580921 47.212594, -1.5580541 47.2126234, -1.5580147 47.2126522, -1.5579497 47.2126981, -1.5579107 47.2127251, -1.5578731 47.212751, -1.5578359 47.2127752, -1.5577931 47.2128028, -1.5577288 47.2128391, -1.5576945 47.2128596, -1.5576506 47.2128831, -1.5575879 47.212915)
156559354;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5549902 47.2139836, -1.5550738 47.2139563, -1.5551326 47.2139381, -1.5552851 47.2138869, -1.5553239 47.2138731, -1.5553649 47.2138587, -1.5555287 47.2137995)
156559369;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5572304 47.2131074, -1.5572059 47.2131171, -1.5571811 47.2131266, -1.5571539 47.2131358, -1.5571297 47.2131435, -1.5570661 47.21316, -1.5569841 47.2131809, -1.5569212 47.2132008)
156559478;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5555463 47.213759, -1.5553428 47.2138334, -1.5553017 47.2138478, -1.5552632 47.2138617, -1.5551054 47.2139141, -1.5550493 47.213933, -1.5549644 47.2139588, -1.5547718 47.214018)
156560719;6104;tram;;0;F;F;LINESTRING (-1.5549902 47.2139836, -1.5550477 47.2139736, -1.555089 47.2139696, -1.5551283 47.2139654, -1.5551741 47.2139646, -1.5552402 47.2139725, -1.5552959 47.2139875, -1.5553507 47.214009, -1.555404 47.2140393, -1.5554585 47.2140848)
158055106;6104;tram;Ligne 2 - Ligne 3;0;F;F;LINESTRING (-1.5552851 47.2138869, -1.5553654 47.2139763, -1.5554585 47.2140848, -1.555505 47.2141367, -1.5556993 47.2143586, -1.5559482 47.2146437, -1.5561336 47.2148565, -1.5561633 47.2148885, -1.5561937 47.2149264, -1.5562104 47.2149498, -1.5562268 47.2149751, -1.5562396 47.214997, -1.5562498 47.2150161, -1.556267 47.21505, -1.5562817 47.2150884, -1.5562979 47.2151336, -1.5563682 47.2153053, -1.5564386 47.215477, -1.5565556 47.2157631, -1.5566037 47.2158819, -1.5566391 47.2159694, -1.5566407 47.2159733)
158055108;6104;tram;Ligne 2 - Ligne 3;0;F;F;LINESTRING (-1.5553239 47.2138731, -1.5553017 47.2138478, -1.5551833 47.2137124, -1.5550712 47.2135846, -1.5550368 47.2135453, -1.5550179 47.2135259, -1.5549994 47.2135023, -1.5549666 47.2134648, -1.5548509 47.2133326, -1.5547222 47.2131855, -1.5545372 47.2129739, -1.5544478 47.2128716, -1.5543803 47.2127942, -1.5543048 47.2127095, -1.5542826 47.2126856, -1.554224 47.2126281, -1.5542085 47.2126119, -1.5541719 47.2125748, -1.5541383 47.2125458, -1.5541119 47.2125204, -1.5540742 47.2124857, -1.5539631 47.212396, -1.553706 47.2121986, -1.5536074 47.2121134, -1.5535924 47.2121004, -1.5535506 47.2120643, -1.553317 47.2118608, -1.5528462 47.211438, -1.5526064 47.2112226, -1.5523043 47.2109527, -1.5521348 47.2108012, -1.551939 47.2106262, -1.5517504 47.2104542, -1.5511257 47.2098939, -1.5509203 47.209703, -1.5507048 47.2095237, -1.5505958 47.209433, -1.5505609 47.2094008, -1.5502759 47.2091247, -1.5500188 47.2088835)
158055119;6104;tram;Ligne 2 - Ligne 3;0;F;F;LINESTRING (-1.549841 47.2087187, -1.5498734 47.2087647, -1.549919 47.2088247, -1.5499395 47.2088518, -1.5499568 47.2088725, -1.5502372 47.2091452, -1.5504716 47.2093679, -1.5505244 47.2094181, -1.550561 47.2094553, -1.5506916 47.2095996, -1.550827 47.2097286, -1.5511941 47.2100556, -1.551676 47.2104867, -1.5520629 47.2108387, -1.5523674 47.2111096, -1.5524434 47.2111769, -1.5525273 47.2112505, -1.5525702 47.211288, -1.552617 47.2113229, -1.5526599 47.2113516, -1.5527119 47.2113883, -1.5527723 47.2114311, -1.5528075 47.2114575, -1.5528152 47.2114633, -1.5528523 47.2114951, -1.5532795 47.2118736, -1.5535137 47.2120795, -1.5535575 47.2121168, -1.5535738 47.2121307, -1.5536738 47.2122159, -1.5539262 47.2124162, -1.5540362 47.2125042, -1.5540743 47.2125393, -1.5541011 47.2125656, -1.5541368 47.2125952, -1.5541741 47.2126289, -1.554195 47.21265, -1.5542219 47.2126781, -1.5542665 47.2127259, -1.5543148 47.2127773, -1.5544117 47.2128844, -1.5544986 47.2129873, -1.5546852 47.2132005, -1.5547199 47.2132402, -1.5549566 47.2135107, -1.5549796 47.2135391, -1.5550341 47.2135993, -1.5550797 47.2136518, -1.5551341 47.2137134, -1.5552632 47.2138617, -1.5552851 47.2138869)
288191719;6104;tram;Ligne 2 - Ligne 3;0;F;F;LINESTRING (-1.5563 47.2150245, -1.5562917 47.215007, -1.556281 47.2149863, -1.556266 47.214961, -1.5562498 47.2149364, -1.5562331 47.2149132, -1.5562 47.214873, -1.5561711 47.2148414, -1.5559977 47.2146447, -1.5557642 47.2143743, -1.5555415 47.2141222, -1.5554841 47.214056, -1.555402 47.2139609, -1.5553239 47.2138731)
318023906;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5575879 47.212915, -1.5575081 47.2129553, -1.5574167 47.2129974, -1.5573085 47.2130435, -1.5572294 47.2130747, -1.5569212 47.2132008, -1.5568985 47.2132101, -1.5557594 47.2136749, -1.5556333 47.2137254, -1.5555463 47.213759)
318023907;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5576092 47.2129418, -1.5577363 47.2128725, -1.5578148 47.2128275, -1.5579516 47.2127401)
332468597;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5555287 47.2137995, -1.5556569 47.2137484, -1.5557792 47.2137013, -1.556562 47.2133822)
509494116;6104;tram;;0;F;F;LINESTRING (-1.5551833 47.2137124, -1.5552083 47.2137294, -1.5552386 47.2137446, -1.5552802 47.213758, -1.5553431 47.2137698, -1.5553944 47.2137753, -1.5554602 47.2137743, -1.5555463 47.213759)
722299673;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.556562 47.2133822, -1.5568836 47.2132509, -1.5569229 47.2132346, -1.5572304 47.2131074, -1.5572533 47.213098, -1.5574305 47.213027, -1.5575213 47.2129858, -1.5576092 47.2129418)
722299674;6104;tram;Ligne 1;0;F;F;LINESTRING (-1.5579516 47.2127401, -1.5579992 47.2127071, -1.5580467 47.212673, -1.5580883 47.2126422, -1.5581271 47.2126114, -1.5581929 47.2125584, -1.5582589 47.2125052, -1.5583999 47.2123943, -1.5584382 47.2123645, -1.5584764 47.2123358, -1.5585557 47.2122786, -1.5587031 47.2121742, -1.5587423 47.2121477, -1.5587807 47.2121226, -1.5588602 47.2120724, -1.5589139 47.2120389, -1.5589632 47.2120082, -1.5589989 47.2119864, -1.5590295 47.2119677, -1.5590624 47.2119486, -1.5591026 47.2119257, -1.5591759 47.2118843, -1.5592485 47.2118445, -1.5593227 47.2118047, -1.5593885 47.2117708, -1.5594227 47.2117534, -1.5594401 47.2117448, -1.5594575 47.2117362, -1.5595154 47.2117078, -1.5595734 47.2116799, -1.5596518 47.2116422, -1.5597592 47.2115948, -1.5598816 47.2115423, -1.5599951 47.2114948, -1.5601105 47.2114479, -1.5604644 47.211309, -1.5608806 47.2111448, -1.5612977 47.2109834, -1.5618012 47.210787, -1.5621086 47.2106656, -1.5624094 47.2105468, -1.5626872 47.2104388, -1.5627759 47.210405, -1.5629278 47.2103434)
""")
        railways = GeoDataFrameLib.read_csv(_sio, crs="epsg:4326")
        railways = railways.to_crs("epsg:2154")
        railways = clip(
            railways, GeoDataFrameDemos4.commerceFeydeauInNantesRoi())
        return railways

    @staticmethod
    def plot(labels=None):
        import matplotlib.pyplot as plt

        if labels is None:
            labels = ["Tour Bretagne", "Cathedrale", "Comfort path",
                      "Royale", "Commerce Feydeau"]
        elif isinstance(labels, str):
            labels = [labels]

        for label in labels:
            # LOAD DATASETS
            if ("Tour Bretagne" == label):
                roi = GeoDataFrameDemos4.bretagneDistrictInNantesRoi()
                buildings = GeoDataFrameDemos4.bretagneDistrictInNantesBuildings()
                roads = GeoDataFrameDemos4.bretagneDistrictInNantesRoads()
            elif ("Cathedrale" == label):
                roi = GeoDataFrameDemos4.cathedraleDistrictInNantesRoi()
                buildings = GeoDataFrameDemos4.cathedraleDistrictInNantesBuildings()
                roads = GeoDataFrameDemos4.cathedraleDistrictInNantesRoads()
            elif ("Comfort path" == label):
                roi = GeoDataFrameDemos4.comfortPathInNantesRoi()
                buildings = GeoDataFrameDemos4.comfortPathInNantesBuildings()
                roads = GeoDataFrameDemos4.comfortPathInNantesRoads()
                path = GeoDataFrameDemos4.comfortPathInNantesTrack()
            elif ("Royale" == label):
                roi = GeoDataFrameDemos4.royaleDistrictInNantesRoi()
                buildings = GeoDataFrameDemos4.royaleDistrictInNantesBuildings()
                roads = GeoDataFrameDemos4.royaleDistrictInNantesRoads()
            elif ("Commerce Feydeau" == label):
                roi = GeoDataFrameDemos4.commerceFeydeauInNantesRoi()
                buildings = GeoDataFrameDemos4.commerceFeydeauInNantesBuildings(
                    postpcs=True)
                roads = GeoDataFrameDemos4.commerceFeydeauInNantesRoads()
                trees = GeoDataFrameDemos4.commerceFeydeauInNantesTrees(
                    postpcs=True)
                water = GeoDataFrameDemos4.commerceFeydeauInNantesWater()
                path1 = GeoDataFrameDemos4.commerceFeydeauInNantesPath1()
                railways = GeoDataFrameDemos4.commerceFeydeauInNantesRailways()

            # MAPPING
            fig, ax = plt.subplots(figsize=(1.25 * 8.26, 1.25 * 8.26))
            ax.set_title(f"{label} - {NantesBDT.version()}", size=20)
            roi.boundary.plot(ax=ax, color="red")
            buildings.plot(ax=ax, color="lightgrey")
            if ("Comfort path" == label):
                path.plot(ax=ax, color="blue")
                roads.plot(ax=ax, color="black", linewidth=0.3)
            elif ("Commerce Feydeau" == label):
                trees.plot(ax=ax, color="green", marker="+")
                water.plot(ax=ax, color="blue", alpha=0.33)
                path1.plot(ax=ax, color="brown", linestyle="dotted")
                railways.plot(ax=ax, color="black", linewidth=0.3)
            else:
                roads.plot(ax=ax, color="black", linewidth=0.3)

            ax.axis("off")
            fig.tight_layout()
            plt.show()
            plt.close(fig)


# GeoDataFrameDemos4.plot()
# GeoDataFrameDemos4.plot("Commerce Feydeau")
