'''
Created on 22 mars 2023

@author: tleduc

Copyright 2020-2023 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from io import StringIO

from t4gpd.commons.GeoDataFrameLib import GeoDataFrameLib
from t4gpd.demos.AbstractGeoDataFrameDemos import AbstractGeoDataFrameDemos

import matplotlib.pyplot as plt


class GeoDataFrameDemos9(AbstractGeoDataFrameDemos):
    '''
    classdocs
    '''

    @staticmethod
    def prairieAuDucInNantesRoi():
        '''
        from t4gpd.demos.GeoDataFrameDemos9 import GeoDataFrameDemos9
        from t4gpd.morph.STBBox import STBBox

        roi = STBBox(GeoDataFrameDemos9.prairieAuDucInNantesPath1(), buffDist=100).run()
        roi.geometry.squeeze().wkt
        '''
        _sio = StringIO("""geometry
POLYGON ((354896 6688015, 354156 6688015, 354156 6688409, 354896 6688409, 354896 6688015))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def prairieAuDucInNantesBuildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        from geopandas import clip, read_file

        roi = GeoDataFrameDemos9.prairieAuDucInNantesRoi()
        buildings = read_file('/home/tleduc/data/bdtopo/\
BDTOPO_3-3_TOUSTHEMES_SHP_LAMB93_D044_2022-12-15/BDTOPO/1_DONNEES_LIVRAISON_2022-12-00159/\
BDT_3-3_SHP_LAMB93_D044-ED2022-12-15/BATI/BATIMENT.shp', bbox=roi)

        buildings = clip(buildings, roi)
        buildings = buildings[ buildings.area > 0 ]
        buildings.to_csv('/tmp/prairie-buildings.csv', sep=';', index=False)
        '''
        _sio = StringIO("""ID;NATURE;USAGE1;USAGE2;LEGER;ETAT;DATE_CREAT;DATE_MAJ;DATE_APP;DATE_CONF;SOURCE;ID_SOURCE;ACQU_PLANI;PREC_PLANI;ACQU_ALTI;PREC_ALTI;NB_LOGTS;NB_ETAGES;MAT_MURS;MAT_TOITS;HAUTEUR;Z_MIN_SOL;Z_MIN_TOIT;Z_MAX_TOIT;Z_MAX_SOL;ORIGIN_BAT;APP_FF;geometry
BATIMENT0000002011295646;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2010-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;4.1;6.4;;;;Imagerie aérienne;C 0.2;POLYGON Z ((354220 6688015.4 9.3, 354223.8222222242 6688015 9.3, 354219.95229357795 6688015 9.344036697287034, 354220 6688015.4 9.3))
BATIMENT0000000029199009;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;4.6;6.0;;11.8;8.8;Imagerie aérienne;C 0.2;POLYGON Z ((354372.7 6688049.3 10.2, 354372.6 6688045.5 10.2, 354364.6 6688046.2 10.3, 354364.6 6688043.8 10.3, 354341.1 6688046.1 10.5, 354341.4 6688052.5 10.6, 354372.7 6688049.3 10.2))
BATIMENT0000000029198234;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2012-06-19 18:43:00;;;;;BDTopo;2.5;BDTopo;1.5;;;;;7.1;6.0;;;;Imagerie aérienne;;POLYGON Z ((354323.9 6688055.7 12.3, 354321.5 6688055.8 12.3, 354321.5 6688053.7 12.3, 354314 6688053.9 12.4, 354313.9 6688057.1 12.7, 354317 6688057 12.8, 354317 6688058.9 13, 354317 6688060.3 13.1, 354323.7 6688060.7 12.9, 354323.8 6688058.8 12.7, 354323.9 6688055.7 12.3))
BATIMENT0000002275362620;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;38.2;6.8;;;;Imagerie aérienne;;POLYGON Z ((354354.3 6688152.2 26.9, 354334.7 6688150.2 27, 354337.2 6688134.9 44.4, 354338.7 6688115.9 45, 354348.6 6688116.7 24.4, 354350.1 6688101.7 24.3, 354302.7 6688097.8 24.8, 354301.3 6688112.7 25.3, 354319.8 6688115.7 44.1, 354318 6688133.6 44.1, 354322.1 6688134.1 44.7, 354318.9 6688149.1 28, 354303.7 6688147.5 28, 354302.6 6688159.2 28, 354353.1 6688164 28, 354354.3 6688152.2 26.9))
BATIMENT0000000291501161;Industriel, agricole ou commercial;Industriel;Commercial et services;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.8;6.4;;14.2;7.2;Imagerie aérienne;C 0.2;POLYGON Z ((354190.4 6688176.9 10.6, 354205.8 6688176.5 10.6, 354210.3 6688169.4 10.6, 354156 6688139.285615251 10.976429809359434, 354156 6688157.7736 10.6, 354190.4 6688176.9 10.6))
BATIMENT0000002011294752;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;20.0;6.2;;;;Imagerie aérienne;;POLYGON Z ((354284.7 6688181.3 26.2, 354271.1 6688180 26.2, 354269.7 6688195 26.2, 354268.8 6688205.4 26.2, 354281.2 6688206.4 26.2, 354281.9 6688200.2 26.2, 354283.4 6688200.5 26.2, 354284.7 6688181.3 26.2))
BATIMENT0000002011294934;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;25.0;5.7;;;;Imagerie aérienne;;POLYGON Z ((354414.1 6688194.1 30.7, 354399.8 6688192.5 30.7, 354397.2 6688220.6 30.7, 354411.6 6688222.1 30.7, 354414.1 6688194.1 30.7))
BATIMENT0000002275362740;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.6;6.3;;;;Imagerie aérienne;;POLYGON Z ((354434.6 6688216.2 12.9, 354436.1 6688197 12.9, 354436.2 6688196.1 12.9, 354414.1 6688194.1 12.9, 354411.6 6688222.1 12.9, 354434 6688224.1 12.5, 354434.6 6688216.2 12.9))
BATIMENT0000002011295805;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.6;5.3;;;;Imagerie aérienne;;POLYGON Z ((354291.3 6688207.2 17.7, 354288.3 6688239.1 12.3, 354295.6 6688240.7 12.3, 354298.6 6688208.1 17.7, 354300.1 6688196.6 17.7, 354300.6 6688183 12.3, 354284.7 6688181.3 12.3, 354283.7 6688195.1 17.8, 354283.4 6688200.5 17.9, 354281.9 6688200.2 17.7, 354281.2 6688206.4 17.7, 354291.3 6688207.2 17.7))
BATIMENT0000002011295322;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.9;5.8;;;;Imagerie aérienne;;POLYGON Z ((354269.7 6688195 14.7, 354255.2 6688193.5 14.7, 354251.8 6688230.6 14.7, 354259.3 6688232.4 14.7, 354262.2 6688204.4 14.7, 354268.8 6688205.4 14.7, 354269.7 6688195 14.7))
BATIMENT0000000029198637;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:27;;;;;BDTopo;2.5;BDTopo;1.5;;;;;5.5;6.0;;11.9;7.1;Imagerie aérienne;;POLYGON Z ((354467.2 6688025.4 11.5, 354466.8 6688021 11.5, 354457.1 6688022.4 11.5, 354457.3 6688027 11.3, 354467.2 6688025.4 11.5))
BATIMENT0000002275362612;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;25.2;7.0;;;;Imagerie aérienne;;POLYGON Z ((354455.5 6688111.3 31.2, 354425.6 6688108.7 31.4, 354422.4 6688140 31.2, 354419.6 6688170.5 29, 354455.9 6688173.6 29, 354457.2 6688160.6 29, 354432.8 6688158.3 29.1, 354434.4 6688141 32.1, 354435.9 6688124.5 32.1, 354454.4 6688126.5 32.2, 354460.4 6688126.8 25.2, 354461.7 6688112.3 25.2, 354455.5 6688111.3 31.2))
BATIMENT0000002275362624;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;31.3;6.5;;;;Imagerie aérienne;;POLYGON Z ((354496.2 6688115.8 31.7, 354469.5 6688113.1 24.9, 354467.9 6688127.6 24.9, 354494.4 6688130.6 31.5, 354492.7 6688147.3 31.8, 354466.9 6688144 13.8, 354465.5 6688155.6 37.2, 354463.6 6688174.6 37.8, 354490.5 6688176.9 37.8, 354492.3 6688158.6 36.1, 354493.3 6688152 30.9, 354505.3 6688153 31, 354508.6 6688116.6 31, 354496.2 6688115.8 31.7))
BATIMENT0000002275363041;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;35.1;8.3;;;;Imagerie aérienne;;POLYGON Z ((354536.3 6688119.4 30.1, 354534.7 6688135 30.1, 354534.7 6688144.8 42.3, 354520.4 6688143.6 42.5, 354518 6688170.1 43.2, 354520.2 6688170.4 43.4, 354518.6 6688179.2 20.5, 354541.8 6688181.7 33.7, 354571.5 6688184.6 34.3, 354572.9 6688170.7 34.3, 354539 6688167.9 39.3, 354540.7 6688148.1 39.3, 354562.9 6688149.3 14.5, 354563.9 6688137.4 25.5, 354564.1 6688135.2 27.5, 354565.6 6688122.4 27.5, 354536.3 6688119.4 30.1))
BATIMENT0000002275362604;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;39.7;5.6;;;;Imagerie aérienne;;POLYGON Z ((354617.2 6688126.5 20.9, 354608.1 6688126 24.1, 354573.6 6688122.4 24.5, 354571.9 6688137.4 24.5, 354578.7 6688138.2 24.5, 354579.1 6688136.7 24.5, 354584 6688139 42.8, 354581.8 6688158.7 42.8, 354582.7 6688158.7 42.8, 354579.7 6688182.2 24.1, 354592.4 6688183.3 30.1, 354611.3 6688185.2 30.1, 354612.8 6688172.3 30.2, 354594 6688170.4 31, 354595.3 6688159.7 45.3, 354597 6688138.5 45.3, 354606.1 6688139.2 25.8, 354605.8 6688140.6 25.8, 354616 6688141.6 25.8, 354617.1 6688129.3 26.1, 354617.2 6688126.5 20.9))
BATIMENT0000002011294521;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;36.0;10.0;00;00;29.9;5.9;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354436.2 6688196.1 35.8, 354434.6 6688216.2 35.8, 354444.1 6688217.2 35.8, 354450.3 6688217.9 35.8, 354452.4 6688197.5 35.8, 354436.2 6688196.1 35.8))
BATIMENT0000002011295173;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;30.0;10.0;00;00;14.5;6.0;;;;Imagerie aérienne;C 0.1;POLYGON Z ((354497.1 6688200.6 20.5, 354495.7 6688215.2 20.5, 354529 6688218 20.5, 354529.9 6688205.5 20.5, 354529.6 6688203.1 20.5, 354497.1 6688200.6 20.5))
BATIMENT0000002011295249;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;4.0;;;31.2;6.4;;;;Imagerie aérienne;C 0.1;POLYGON Z ((354529.9 6688205.5 37.6, 354528.9 6688220.2 37.6, 354528 6688223.7 37.6, 354527.8 6688227.6 37.6, 354526.7 6688237.4 32, 354539.6 6688239.1 32, 354541.9 6688229.4 34.7, 354547 6688204.8 34.7, 354529.6 6688203.1 34.7, 354529.9 6688205.5 37.6))
BATIMENT0000002011294234;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.7;5.9;;;;Imagerie aérienne;;POLYGON Z ((354519.6 6688229 14.6, 354498 6688227.4 14.6, 354494.7 6688227.2 12.2, 354494 6688234.8 12.2, 354497.2 6688235 14.6, 354518.8 6688236.9 14.6, 354519.6 6688229 14.6))
BATIMENT0000002011296150;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;7.0;5.4;;;;Imagerie aérienne;;POLYGON Z ((354450.3 6688247.6 12.3, 354463.6 6688248.5 12.3, 354464.3 6688240.3 12.3, 354466.1 6688219.4 11.6, 354468 6688199.5 11.6, 354452.4 6688197.5 11.6, 354450.3 6688217.9 11.6, 354447.6 6688217.6 9.5, 354446 6688238.5 12.3, 354445.1 6688247.7 12.3, 354432.4 6688246.4 12.3, 354428.7 6688285.2 12.3, 354446.6 6688289.6 12.3, 354449.9 6688256.9 12.4, 354450.3 6688247.6 12.3), (354453.1 6688223.8 9.5, 354460.2 6688224.5 9.5, 354459.3 6688234.3 9.5, 354452.2 6688233.7 9.5, 354453.1 6688223.8 9.5))
BATIMENT0000002275362637;Indifférenciée;Commercial et services;;Non;En service;2021-12-05 17:02:40;2022-10-25 15:32:08;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.1;6.8;;;;Imagerie aérienne;;POLYGON Z ((354876.2 6688155 10.9, 354875.2 6688163.4 10.9, 354872.9 6688163.1 10.9, 354872.1 6688169.7 10.9, 354877.2 6688170.2 10.9, 354896 6688172.225862069 10.818965517241514, 354896 6688157.172568578 10.9, 354876.2 6688155 10.9))
BATIMENT0000002275363026;Indifférenciée;Commercial et services;;Non;En service;2021-12-05 17:02:40;2022-10-25 15:32:08;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.8;7.1;;;;Imagerie aérienne;;POLYGON Z ((354872.1 6688169.7 10.9, 354871.6 6688174.6 10.9, 354860.4 6688173.4 10.7, 354858.3 6688195.3 10.7, 354861.3 6688195.6 10.7, 354862 6688189.1 10.7, 354866.8 6688189.5 10.7, 354866 6688196 10.7, 354874.5 6688196.8 10.7, 354877.2 6688170.2 10.9, 354872.1 6688169.7 10.9))
BATIMENT0000000327814936;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;30.7;6.5;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354791.9 6688248.4 37.2, 354793.8 6688226.8 37.2, 354774.6 6688224.6 37.2, 354772.4 6688246.6 37, 354791.9 6688248.4 37.2))
BATIMENT0000002011295603;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.8;5.8;;;;Imagerie aérienne;;POLYGON Z ((354871.4 6688254.1 9.6, 354873.7 6688234.1 9.6, 354839.3 6688232.4 9.3, 354853.4 6688240.4 9.6, 354853.7 6688238.9 9.6, 354861.1 6688239.3 9.6, 354860.5 6688245.7 9.6, 354856.1 6688245.6 9.6, 354855.6 6688250 9.6, 354853.8 6688250 9.6, 354853.9 6688249 9.6, 354851 6688248.7 9.6, 354850.4 6688252.1 9.6, 354871.4 6688254.1 9.6))
BATIMENT0000002011294768;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;33.4;5.6;;;;Imagerie aérienne;;POLYGON Z ((354836.4 6688230.8 39, 354826.7 6688248.2 39, 354844.1 6688257.8 39, 354853.4 6688240.4 39, 354836.4 6688230.8 39))
BATIMENT0000000302923052;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-06-04 12:14:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;11.8;7.0;;;;Imagerie aérienne;;POLYGON Z ((354883.4 6688279.9 18.7, 354884.9 6688280.1 18.7, 354885.5 6688273.4 18.7, 354889.7 6688273.8 18.7, 354896 6688274.279347826 18.7, 354896 6688261.396240602 18.7, 354885.4 6688260.4 18.7, 354883.4 6688279.9 18.7))
BATIMENT0000000327814935;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:27;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.0;6.6;;17.7;6.8;Imagerie aérienne;;POLYGON Z ((354817 6688278.8 12.6, 354816.6 6688283.4 12.6, 354827.9 6688284.4 12.6, 354827 6688294.4 12.6, 354831.3 6688294.9 12.6, 354831.7 6688287.4 12.6, 354845.7 6688289.1 12.6, 354846.4 6688281.5 12.5, 354817 6688278.8 12.6))
BATIMENT0000000327814873;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:27;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;18.0;7.0;;25.6;7.1;Imagerie aérienne;;POLYGON Z ((354869.7 6688282.5 25, 354846.5 6688280.3 25, 354846.4 6688281.5 25, 354845.7 6688289.1 25, 354848.9 6688289.5 25, 354846.6 6688310.1 25, 354867.1 6688312 25, 354869.7 6688282.5 25))
BATIMENT0000000327814875;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2007-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;19.9;6.0;;27.1;6.5;Imagerie aérienne;C 0.2;POLYGON Z ((354751 6688308.9 25.8, 354762.2 6688311 15.2, 354768.5 6688300.8 15.2, 354775.7 6688269.7 12.5, 354773.9 6688263.4 25.4, 354752.4 6688258.3 25.4, 354747.2 6688260.6 19.2, 354738.8 6688292 25.9, 354729.6 6688330.5 25.9, 354744.7 6688334.4 25.9, 354751 6688308.9 25.8))
BATIMENT0000002275362896;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;35.3;7.1;;;;Imagerie aérienne;;POLYGON Z ((354357.7 6688186.6 26.3, 354319.2 6688183.1 23.8, 354317.6 6688200.3 23.8, 354316.4 6688210 20.8, 354331 6688211.4 20.8, 354332 6688201.4 24.3, 354332.2 6688198.7 24.1, 354355.8 6688202 38.4, 354355.1 6688213.2 42.4, 354353.6 6688228.8 42.1, 354342.3 6688227.9 28.5, 354339.5 6688255.1 28, 354337.3 6688254.5 28, 354337.6 6688252.8 28, 354324 6688249.8 27.8, 354323.4 6688251.5 27.8, 354320.7 6688250.9 27.8, 354321.4 6688248.1 27.8, 354305.9 6688244.9 27.8, 354304.1 6688244.5 27.8, 354302.7 6688257.3 27.8, 354352.2 6688268.4 26.5, 354356.8 6688229.6 40.6, 354371.1 6688230.8 40.8, 354372.5 6688214.5 40.8, 354374.1 6688199.3 39.2, 354375 6688188.3 26.3, 354357.7 6688186.6 26.3))
BATIMENT0000002275363100;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;5.3;6.8;;;;Imagerie aérienne;;POLYGON Z ((354426.5 6688236.9 11.7, 354428.2 6688229.7 11.9, 354421.6 6688230.2 11.1, 354410 6688228 12.1, 354410.7 6688235 11.4, 354408.6 6688242.4 11.5, 354420.4 6688242.5 10.8, 354426.9 6688244.1 11.4, 354426.5 6688236.9 11.7))
BATIMENT0000002011295712;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;25.9;6.6;;;;Imagerie aérienne;;POLYGON Z ((354286.6 6688238.7 24.2, 354269.7 6688234.9 24.2, 354262.5 6688233.1 32.5, 354259.3 6688232.4 32.5, 354251.8 6688230.6 32.5, 354242.7 6688228.4 32.5, 354241.2 6688243.3 32.5, 354261.2 6688247.9 32.5, 354266.5 6688249.2 24.2, 354294.3 6688255.4 24.2, 354295.6 6688240.7 24.2, 354286.6 6688238.7 24.2))
BATIMENT0000002011295988;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;18.8;5.7;;;;Imagerie aérienne;;POLYGON Z ((354392.6 6688262.6 24.5, 354395.6 6688227.1 24.5, 354381.5 6688225.9 24.5, 354376.9 6688274.1 24.5, 354421.6 6688284.1 24.5, 354422.9 6688269.8 24.5, 354392.6 6688262.6 24.5))
BATIMENT0000000302923343;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.9;6.3;10.3;12.5;6.6;Cadastre;;POLYGON Z ((354346.6 6688322.4 10.3, 354346.9 6688321 10.3, 354356.5 6688323.1 10.3, 354357.5 6688319.2 10.3, 354347.9 6688316.7 10.3, 354348.5 6688314.3 10.3, 354301.4 6688304.2 10.3, 354299.6 6688311.9 10.3, 354346.6 6688322.4 10.3))
BATIMENT0000000291501091;Industriel, agricole ou commercial;Industriel;Commercial et services;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.9;6.5;;13.0;6.7;Imagerie aérienne;C 0.3;POLYGON Z ((354444 6688341.8 10.3, 354448.7 6688323.6 10.3, 354389.9 6688310.3 10.3, 354384 6688308.7 9.4, 354382.3 6688314.4 9.4, 354388.1 6688316.8 12.4, 354385.7 6688328.5 10.3, 354444 6688341.8 10.3))
BATIMENT0000000291499603;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2018-09-18 13:36:27;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.4;5.4;;14.0;6.8;Imagerie aérienne;;POLYGON Z ((354361.5 6688325.1 9.5, 354360.5 6688329.6 13.8, 354360.1 6688332.1 13.8, 354366.1 6688333.3 13.8, 354366.6 6688330.6 13.8, 354367.3 6688326.5 9.5, 354361.5 6688325.1 9.5))
BATIMENT0000000291500249;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;6.0;;;;Imagerie aérienne;;POLYGON Z ((354376.5 6688335.8 9.3, 354377.9 6688329.9 9.3, 354370.8 6688328.5 9.3, 354369.4 6688334.3 9.3, 354376.5 6688335.8 9.3))
BATIMENT0000000291501759;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;6.1;;;;Imagerie aérienne;;POLYGON Z ((354395.4 6688340.3 9.4, 354396.9 6688335.5 9.4, 354384.7 6688332.8 9.4, 354383.7 6688337.7 9.4, 354395.4 6688340.3 9.4))
BATIMENT0000000291500522;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.6;6.0;;;;Imagerie aérienne;;POLYGON Z ((354413.3 6688344.2 9.6, 354414.8 6688339.2 9.6, 354403.2 6688336.8 9.6, 354401.8 6688341.7 9.5, 354413.3 6688344.2 9.6))
BATIMENT0000000327814967;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;8.3;6.5;;15.1;6.9;Imagerie aérienne;A 1.0;POLYGON Z ((354560.3 6688314.9 10.8, 354584 6688320.8 9.1, 354589.2 6688297.5 10.4, 354595.5 6688268.5 11.3, 354599.9 6688248.3 14.8, 354606 6688216.3 14.8, 354558.1 6688212 14.8, 354553.6 6688233.7 14.8, 354559.4 6688236.5 14.8, 354547.9 6688257.7 14.8, 354544.7 6688271.8 14.1, 354536.1 6688309.8 11.5, 354560.3 6688314.9 10.8), (354562.5 6688296.2 10.7, 354561.4 6688288.5 10.7, 354562.2 6688274.2 10.3, 354568.7 6688258.2 11.4, 354574.9 6688252.3 11.4, 354581.5 6688253.7 11.4, 354584 6688262.2 11.4, 354582.7 6688278.3 11.4, 354581.4 6688282.8 11.4, 354578.7 6688290 10.8, 354578.1 6688293.3 10.7, 354578 6688298 10, 354578 6688299.7 9.6, 354581.7 6688301.7 9.6, 354580.7 6688305 9.2, 354577.7 6688308.7 9.2, 354574 6688310.5 9, 354570.6 6688310.6 9, 354568 6688310.2 9, 354568.7 6688307.1 9, 354567.9 6688304.1 9.6, 354566.9 6688301.7 10.7, 354562.5 6688296.2 10.7), (354574.2 6688223.9 11.3, 354577.8 6688223.1 11.3, 354582.9 6688226.5 11.3, 354582.9 6688230.4 11.3, 354572.6 6688231.1 11.3, 354574.2 6688223.9 11.3), (354550.9 6688298.8 11.4, 354554.1 6688302.6 11.4, 354553 6688305.5 11.4, 354547.2 6688303.8 11.4, 354550.9 6688298.8 11.4))
BATIMENT0000002011295114;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2013-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;11.0;;;30.9;6.2;;;;Imagerie aérienne;C 0.6;POLYGON Z ((354449.9 6688256.9 37.1, 354446.6 6688289.6 37.1, 354459.2 6688292.1 37.1, 354463 6688258.3 37, 354449.9 6688256.9 37.1))
BATIMENT0000002011294770;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;24.0;9.0;00;00;33.9;5.7;;;;Imagerie aérienne;C 0.6;POLYGON Z ((354488.4 6688263 30.7, 354483.2 6688285.5 35.3, 354489.8 6688287 37.1, 354499.3 6688289 39.6, 354504.6 6688266.7 30.7, 354488.4 6688263 30.7))
BATIMENT0000002011296045;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;4.0;2.0;;;8.0;6.0;;;;Imagerie aérienne;C 0.3;POLYGON Z ((354525 6688293.8 13.4, 354527.2 6688284.4 11.9, 354530.6 6688267.1 14, 354532.4 6688260.8 12.7, 354526.3 6688259.1 12.7, 354514.3 6688256.7 13.3, 354508.6 6688255.4 13.3, 354503 6688254.2 12.4, 354492.4 6688251.9 12.7, 354490.8 6688258.5 12.7, 354488.4 6688263 10.1, 354504.6 6688266.7 10.1, 354499.3 6688289 10.1, 354489.8 6688287 10.1, 354483.2 6688285.5 10.1, 354481.8 6688297.8 10.1, 354522.8 6688306.3 10.1, 354525 6688293.8 13.4))
BATIMENT0000000302923326;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;5.6;8.5;9.0;6.5;Cadastre;;POLYGON Z ((354456.3 6688311.2 8.5, 354449.2 6688309.7 8.5, 354448 6688315.6 8.5, 354455.1 6688317.1 8.5, 354456.3 6688311.2 8.5))
BATIMENT0000000302923324;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;6.0;12.2;12.9;6.6;Cadastre;;POLYGON Z ((354496.8 6688325.1 12.2, 354498.9 6688326.4 12.2, 354501.3 6688326.5 12.2, 354503.6 6688325.4 12.2, 354505.2 6688323.3 12.2, 354505.5 6688320.9 12.2, 354504.6 6688318.6 12.2, 354502.8 6688317 12.2, 354500.5 6688316.3 12.2, 354498.1 6688316.8 12.2, 354496.2 6688318.4 12.2, 354495.3 6688320.6 12.2, 354495.5 6688323.1 12.2, 354496.8 6688325.1 12.2))
BATIMENT0000000302923345;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;6.4;8.7;9.2;6.6;Cadastre;;POLYGON Z ((354455.1 6688323.1 8.7, 354452.7 6688322.6 8.7, 354452 6688326.2 8.7, 354454.4 6688326.7 8.7, 354455.1 6688323.1 8.7))
BATIMENT0000000302923132;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.4;6.0;19.5;24.2;6.5;Cadastre;C 0.4;POLYGON Z ((354678.8 6688271.8 19.5, 354646.9061898212 6688409 19.5, 354704.5424242424 6688409 19.5, 354705.9 6688403.4 19.5, 354707.6 6688403.8 19.5, 354710 6688393.9 19.5, 354713.3 6688394.7 19.5, 354714.8 6688388.6 19.5, 354716.3 6688388.9 19.5, 354717.8 6688382.7 19.5, 354719.3 6688383 19.5, 354720.8 6688376.8 19.5, 354722.2 6688377.1 19.5, 354723.8 6688370.6 19.5, 354725.3 6688370.9 19.5, 354727 6688364.2 19.5, 354717.8 6688361.9 19.5, 354742.7 6688255.8 19.5, 354685.5 6688242.4 19.5, 354678.8 6688271.8 19.5))
BATIMENT0000000291499680;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2012-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;2.6;6.2;;9.0;6.8;Imagerie aérienne;C 0.4;POLYGON Z ((354419.7 6688345.6 8.8, 354437.3 6688349.5 8.8, 354437.2 6688349.4 8.8, 354438.5 6688344.2 8.8, 354420.8 6688341.2 8.8, 354419.7 6688345.6 8.8))
BATIMENT0000000302923159;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.7;6.0;17.7;24.3;6.6;Cadastre;;POLYGON Z ((354534.3 6688360.8 17.7, 354617.6 6688407.1 17.7, 354626.8 6688390.2 17.7, 354543.4 6688344.2 17.7, 354534.3 6688360.8 17.7))
BATIMENT0000002011291485;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2006-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;17.8;7.1;;;;Imagerie aérienne;C 0.2;POLYGON Z ((354881.5 6688317.8 22, 354896 6688319.157142857 22, 354896 6688305.7 22.4, 354896 6688274.279347826 24.468478260869162, 354889.7 6688273.8 24.4, 354885.5 6688273.4 21.9, 354884.9 6688280.1 22, 354881.5 6688317.8 22))
BATIMENT0000000327814956;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;21.6;6.9;;;;Imagerie aérienne;;POLYGON Z ((354863.6 6688353.8 28.5, 354864.5 6688342.4 28.5, 354857.6 6688341.7 28.5, 354858.2 6688335.8 28.5, 354828 6688332.2 24.6, 354830.1 6688308.5 24.6, 354831.3 6688294.9 24.6, 354827 6688294.4 24.6, 354827.9 6688284.4 24.6, 354816.6 6688283.4 24.6, 354810.1 6688348.5 24.4, 354863.6 6688353.8 28.5))
BATIMENT0000000327814969;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2000-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;15.4;6.3;;22.7;6.8;Imagerie aérienne;A 1.0;POLYGON Z ((354792.4 6688339.2 21.7, 354793.6 6688338.4 21.7, 354795.4 6688336.7 21.7, 354796.8 6688333.9 21.7, 354797.8 6688331 21.7, 354798.3 6688328.9 21.7, 354798.5 6688324.7 21.7, 354798.4 6688321.3 21.7, 354797.9 6688317.2 21.7, 354796.6 6688312.5 21.7, 354794.6 6688307.7 21.7, 354788.9 6688311.8 21.7, 354784.7 6688315.5 21.7, 354781.6 6688319.1 21.7, 354778.3 6688323.8 21.7, 354776.7 6688327.4 21.7, 354776.7 6688330.2 21.7, 354777.2 6688332.8 21.7, 354778.6 6688335.6 21.7, 354780.2 6688337.5 21.7, 354782.6 6688339 21.7, 354785 6688339.9 21.7, 354786.8 6688340.2 21.7, 354788.3 6688340.3 21.7, 354790.7 6688340 21.7, 354792.4 6688339.2 21.7))
BATIMENT0000000327814958;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;9.7;8.3;;;;Imagerie aérienne;;POLYGON Z ((354867.1 6688312 18, 354846.6 6688310.1 18, 354830.1 6688308.5 18, 354828 6688332.2 18, 354858.2 6688335.8 18, 354857.6 6688341.7 18, 354864.5 6688342.4 18, 354867.1 6688312 18))
BATIMENT0000002011291483;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;31.1;7.1;;;;Imagerie aérienne;;POLYGON Z ((354878 6688338.9 37.5, 354896 6688340.626027397 37.5, 354896 6688319.157142857 35.1, 354881.5 6688317.8 35.1, 354880.2 6688317.7 35.1, 354879.4 6688324.4 38.2, 354878.4 6688324.3 38.2, 354876.8 6688338.8 37.5, 354878 6688338.9 37.5))
BATIMENT0000002011291484;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;14.4;7.6;;;;Imagerie aérienne;;POLYGON Z ((354878 6688338.9 22, 354876.6 6688352.4 22, 354896 6688354.185774059 22, 354896 6688340.626027397 22, 354878 6688338.9 22))
BATIMENT0000000302923337;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.5;6.7;27.2;28.0;6.9;Cadastre;;POLYGON Z ((354860.3 6688367.2 27.2, 354857.4 6688397.1 27.2, 354858.5 6688397.2 27.2, 354861.3 6688367.3 27.2, 354860.3 6688367.2 27.2))
BATIMENT0000002011295819;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.3;7.1;;;;Imagerie aérienne;;POLYGON Z ((354871.9 6688393.2 19.4, 354896 6688395.299621212 19.4, 354896 6688371.850943396 19.4, 354874 6688369.9 19.4, 354871.9 6688393.2 19.4))
BATIMENT0000000302923558;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2022-10-20 15:45:51;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.2;6.6;22.8;27.5;6.9;Cadastre;B 0.3;POLYGON Z ((354841.3 6688396.2 22.8, 354857.4 6688397.1 22.8, 354860.3 6688367.2 22.8, 354758.9 6688358 22.8, 354743.2 6688386.6 22.8, 354740.5423728813 6688409 22.8, 354840.1307692308 6688409 22.8, 354841.3 6688396.2 22.8))
BATIMENT0000000302923339;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2000-01-01;;;;Image satellite;10.0;Z corrigé;2.5;0.0;1.0;;;12.6;5.6;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354871.1 6688403.6 18.2, 354870.47594339616 6688409 18.2, 354896 6688409 18.2, 354896 6688405.862218045 18.2, 354871.1 6688403.6 18.2))
BATIMENT0000000302923344;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2021-06-15 12:25:42;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.3;6.3;10.6;12.9;6.6;Cadastre;;POLYGON Z ((354318.9 6688355.7 10.6, 354369.8 6688366.8 10.6, 354372.1 6688354.2 10.6, 354322 6688343.4 10.6, 354318.9 6688355.7 10.6))
BATIMENT0000000327814957;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.4;6.5;;;;Imagerie aérienne;;POLYGON Z ((354385.05864661693 6688409 10.690977443628434, 354412.73826086934 6688409 12.510434782585465, 354409.9 6688403.9 12.2, 354408.2 6688389.3 12.7, 354378.5 6688394.3 10.5, 354379.3 6688399.6 10.5, 354377.2 6688403.8 10.3, 354385.05864661693 6688409 10.690977443628434))
BATIMENT0000000327814970;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:27;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.8;6.2;;24.9;6.8;Imagerie aérienne;;POLYGON Z ((354432.5 6688407.6 22, 354434.4 6688405.1 22, 354435.6 6688403.1 22, 354436 6688400.3 22, 354435.9 6688397.5 22, 354435.1 6688394.7 22, 354434 6688392.5 22, 354431.8 6688390.3 22, 354429.8 6688389.2 22, 354426.8 6688388.8 22, 354423.9 6688389.1 22, 354421.3 6688390 22, 354418.6 6688392 22, 354416.6 6688394.7 22, 354415.8 6688397.1 22, 354415.7 6688399.9 22, 354416.1 6688402.1 22, 354416.8 6688404.4 22, 354418.1 6688406.3 22, 354420 6688408 22, 354421.8 6688408.9 22, 354422.1624999987 6688409 22, 354430.16666666704 6688409 22, 354432.5 6688407.6 22))
BATIMENT0000000302923557;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.8;6.6;12.4;16.0;6.8;Cadastre;B 0.2;POLYGON Z ((354743.2 6688386.6 12.4, 354741.5 6688386.5 12.4, 354729.1312154697 6688409 12.4, 354740.5423728813 6688409 12.4, 354743.2 6688386.6 12.4))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def prairieAuDucInNantesRoads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        from geopandas import clip, read_file

        roi = GeoDataFrameDemos9.prairieAuDucInNantesRoi()
        roads = read_file('/home/tleduc/data/bdtopo/\
BDTOPO_3-3_TOUSTHEMES_SHP_LAMB93_D044_2022-12-15/BDTOPO/1_DONNEES_LIVRAISON_2022-12-00159/\
BDT_3-3_SHP_LAMB93_D044-ED2022-12-15/TRANSPORT/TRONCON_DE_ROUTE.shp', bbox=roi)

        roads = clip(roads, roi)
        roads = roads[ roads.length > 0 ]
        roads.to_csv('/tmp/prairie-roads.csv', sep=';', index=False)
        '''
        _sio = StringIO("""DELESTAGE;SRC_BAN_G;SRC_BAN_D;NOM_BAN_G;NOM_BAN_D;LD_BAN_G;LD_BAN_D;ID_BAN_G;ID_BAN_D;NOM_ITI;NATURE_ITI;VOIE_VERTE;ITI_CYCL;TOPONYME;GESTION;CL_ADMIN;NUM_EUROP;NUMERO;ID_ITI;ID_RN;ID_VOIE_D;ID_VOIE_G;DATE_SERV;ALIAS_D;ALIAS_G;INSEECOM_D;INSEECOM_G;BORNEFIN_D;BORNEFIN_G;BORNEDEB_D;BORNEDEB_G;RESTR_MAT;RESTR_LON;RESTR_LAR;RESTR_PPE;RESTR_P;RESTR_H;NAT_RESTR;SENS_CYC_G;SENS_CYC_D;CYCLABLE_G;CYCLABLE_D;FERMETURE;ACCES_PED;ACCES_VL;VIT_MOY_VL;URBAIN;BUS;SENS;PRIVE;IT_VERT;LARGEUR;NB_VOIES;PREC_ALTI;ACQU_ALTI;PREC_PLANI;ACQU_PLANI;ID_SOURCE;SOURCE;DATE_CONF;DATE_APP;DATE_MAJ;DATE_CREAT;ETAT;POS_SOL;FICTIF;IMPORTANCE;NOM_COLL_D;NOM_COLL_G;NATURE;ID;geometry
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2020-06-22;;2022-12-10 14:57:12;2021-12-29 14:46:14;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002275575139;LINESTRING Z (354156 6688076.712765957 7.3, 354165 6688077 7.3, 354218.3 6688082.1 7.6)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2021-11-29 16:59:37;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002275175078;LINESTRING Z (354218.3 6688082.1 7.6, 354222.4 6688082.1 7.6, 354237.2 6688082.6 7.6, 354282.2 6688087.4 7.6, 354289.8 6688088 7.5, 354296.4 6688088.7 7.5)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;Libre;Physiquement impossible;0;Non;;Sans objet;;Non;;;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2020-06-22;;;2021-12-29 14:46:14;En service;0;Non;6;;;Sentier;TRONROUT0000002275575134;LINESTRING Z (354156 6688087.5 7.3, 354157.2 6688091.5 7.3, 354164.1 6688103 6)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;32;;44;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2018-10-16 13:44:57;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002101116220;LINESTRING Z (354296.4 6688088.7 7.5, 354303.8 6688089.3 7.6, 354310.7 6688090 7.7, 354317.7 6688090.7 7.8, 354324.9 6688091.4 7.6, 354332.3 6688092 7.6, 354340 6688092.6 7.6, 354347.8 6688093.3 7.5, 354356 6688094 7.5, 354364.8 6688094.9 7.6, 354374 6688095.8 7.6, 354383.7 6688096.8 7.6, 354394.1 6688097.7 7.7, 354400.4 6688098.2 7.6)
;commune;commune;Quai des Antilles;Quai des Antilles;;;44109_0316;44109_0316;;;;;;;;;;;;441090341;441090341;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2009-10-15 13:29:33;En service;0;Non;5;QU DES ANTILLES;QU DES ANTILLES;Route à 1 chaussée;TRONROUT0000000224965231;LINESTRING Z (354228.2 6688162.8 7.5, 354224.9 6688170.8 5.3, 354220.4 6688175.3 5.3, 354211.3 6688179.6 5.3, 354193.4 6688180.7 5.3, 354185.2 6688179.1 5.3, 354156 6688162.506984127 5.3)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;;2021-12-29 14:46:14;En service;0;Non;5;;;Route à 1 chaussée;TRONROUT0000002275575140;LINESTRING Z (354164.1 6688103 6, 354165.3 6688103.1 6.1, 354168.7 6688101.4 6.2, 354172 6688101.2 6.3, 354175.9 6688101 6.4, 354179.9 6688102.4 6.5, 354184 6688106 6.6, 354193.3 6688120.7 6.6)
;;;;;;;;;;;;;;;;;;;;44109#0IB;44109#0IB;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2021-12-29 14:46:14;2018-06-04 12:14:25;En service;0;Non;4;BD DES ANTILLES;BD DES ANTILLES;Route à 1 chaussée;TRONROUT0000002011296240;LINESTRING Z (354209.6 6688156.7 7.2, 354170.8 6688134.7 6.1, 354169 6688132.7 6.1, 354156 6688108.640298508 6.002985074627771)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2020-06-22;;2021-12-29 14:46:14;2018-06-04 12:14:25;En service;0;Non;5;;;Route à 1 chaussée;TRONROUT0000002011296236;LINESTRING Z (354193.3 6688120.7 6.6, 354223.9 6688104.7 6.6, 354226.2 6688104.1 6.6, 354228.3 6688104.5 6.6, 354230.8 6688105.6 6.6, 354240.4 6688123.2 6.6, 354240.7 6688125.9 6.6, 354239.5 6688128.1 6.6, 354236.4 6688130.3 6.6, 354208.7 6688144.2 6.8)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;Libre;Physiquement impossible;0;Non;;Sans objet;;Non;;;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2020-06-22;;;2021-12-29 14:46:14;En service;0;Non;6;;;Sentier;TRONROUT0000002275575135;LINESTRING Z (354164.1 6688103 6, 354164.1 6688106.6 7.2, 354163.3 6688111.8 7.2, 354170.1 6688123.9 7.1, 354172.6 6688128.8 7.1, 354177 6688133.2 7.2, 354182.5 6688135.6 7.5, 354191 6688141.1 7.4, 354203.4 6688147.7 6.9, 354210.1 6688152.6 7.1)
;commune;commune;Allée Miriam Makeba;Allée Miriam Makeba;;;44109_5670;44109_5670;;;;;;;;;;;;44109#0T7;44109#0T7;;;;44109;44109;5;;1;;Non;;;;;;;;;;;;Libre;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;1.0;9999.0;Pas de Z;5.0;Fichier numérique non métrique;;;;;2022-12-10 14:57:12;2021-11-29 16:59:41;En service;0;Non;5;ALL MIRIAM MAKEBA;ALL MIRIAM MAKEBA;Route à 1 chaussée;TRONROUT0000002275175081;LINESTRING Z (354291.4 6688168.9 -1000, 354296.4 6688088.7 -1000)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;32;;44;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2017-12-04 15:37:14;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002007432841;LINESTRING Z (354400.4 6688098.2 7.6, 354404.9 6688098.6 7.6, 354416 6688099.6 7.7, 354426.4 6688100.6 7.6, 354436.3 6688101.5 7.6, 354445.8 6688102.3 7.6, 354455.1 6688103.1 7.7, 354464.5 6688104.1 7.6, 354473.9 6688104.9 7.7, 354483.3 6688105.7 7.7, 354492.7 6688106.6 7.7, 354502.1 6688107.4 7.7, 354514.6 6688109.2 7.7)
;commune;commune;Rue Ruth First;Rue Ruth First;;;44109_7517;44109_7517;;;;;;;;;;;;44109#0S7;44109#0S7;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;5.0;Fichier numérique non métrique;;;;;2022-12-10 14:57:12;2018-10-16 13:44:57;En service;0;Non;5;R RUTH FIRST;R RUTH FIRST;Route à 1 chaussée;TRONROUT0000002101116218;LINESTRING Z (354400.4 6688098.2 -1000, 354400.7 6688165.8 -1000, 354400.2 6688178.7 -1000)
;commune;commune;Allée Susan Brownell Anthony;Allée Susan Brownell Anthony;;;44109_8007;44109_8007;;;;;;;;;;;;44109#0RL;44109#0RL;;;;44109;44109;10;7;2;1;Non;;;;;;;;;;;;Libre;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2017-12-04 15:37:14;En service;0;Non;5;ALL SUSAN BROWNELL ANTHONY;ALL SUSAN BROWNELL ANTHONY;Route à 1 chaussée;TRONROUT0000002007432833;LINESTRING Z (354508.4 6688188.9 6.3, 354514.6 6688109.2 7.7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;88;97;80;87;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000357587266;LINESTRING Z (354400.2 6688178.7 6.5, 354392.4 6688178.1 6.5, 354389.3 6688178.6 6.6)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;88;97;80;87;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2022-03-01 17:19:58;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002276434772;LINESTRING Z (354476.4 6688185.9 6.5, 354400.2 6688178.7 6.5)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2015-05-07 18:59:26;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000350024877;LINESTRING Z (354483.4 6688186.6 6.4, 354476.4 6688185.9 6.5)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;85;;85;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2017-12-04 15:37:14;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002007432834;LINESTRING Z (354508.4 6688188.9 6.3, 354483.4 6688186.6 6.4)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;78;83;72;79;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2013-03-12 15:44:43;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000320084032;LINESTRING Z (354555.5 6688193.3 6.1, 354508.4 6688188.9 6.3)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Sens direct;Non;Non;4.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2015-05-07 18:59:26;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000000350024875;LINESTRING Z (354483.4 6688186.6 6.4, 354478.9 6688246.2 5.4)
;commune;commune;Esplanade Edouard Glissant;Esplanade Edouard Glissant;;;44109_2734;44109_2734;;;;;;;;;;;;44109#0PL;44109#0PL;;;;44109;44109;;9;;9;Non;;;;;;Plot amovible;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;5.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-03-12 15:44:43;En service;0;Non;5;ESP EDOUARD GLISSANT;ESP EDOUARD GLISSANT;Route à 1 chaussée;TRONROUT0000000320084028;LINESTRING Z (354542.2 6688258.8 -1000, 354555.5 6688193.3 -1000)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;;2021-12-29 14:46:14;En service;0;Non;5;;;Route à 1 chaussée;TRONROUT0000002275575141;LINESTRING Z (354193.3 6688120.7 6.6, 354207 6688142.5 6.7, 354208.7 6688144.2 6.8)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;;2021-12-29 14:46:14;En service;0;Non;5;;;Route à 1 chaussée;TRONROUT0000002275575136;LINESTRING Z (354208.7 6688144.2 6.8, 354209.8 6688146.6 6.9, 354210.6 6688148.5 7, 354210.1 6688152.6 7.1)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2021-12-29 14:46:14;2018-06-04 12:14:25;En service;0;Non;5;;;Route à 1 chaussée;TRONROUT0000002011296238;LINESTRING Z (354210.1 6688152.6 7.1, 354209.6 6688156.7 7.2)
;;;;;;;;;;;;;;;;;;;;44109#0IB;44109#0IB;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2021-12-29 14:46:14;2012-02-08 10:00:49;En service;0;Non;4;BD DES ANTILLES;BD DES ANTILLES;Route à 1 chaussée;TRONROUT0000000295263991;LINESTRING Z (354228.2 6688162.8 7.5, 354225.6 6688162.6 7.5, 354216.3 6688160.6 7.5, 354209.6 6688156.7 7.2)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2012-02-08 10:00:49;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000295263997;LINESTRING Z (354248.9 6688164.8 6.8, 354244.3 6688164.4 6.9, 354238.8 6688163.9 6.9, 354228.2 6688162.8 7.5)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;96;;94;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2017-06-01 17:22:06;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002003976218;LINESTRING Z (354291.4 6688168.9 6.7, 354248.9 6688164.8 6.8)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;96;;94;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2021-11-17 14:20:28;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002274981780;LINESTRING Z (354313.6 6688171.2 6.7, 354291.4 6688168.9 6.7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;92;;90;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000357587265;LINESTRING Z (354389.3 6688178.6 6.6, 354313.6 6688171.2 6.7)
;commune;commune;Allée Lucy Stone;Allée Lucy Stone;;;44109_5162;44109_5162;;;;;;;;;;;;44109#0QH;44109#0QH;;;;44109;44109;1;;7;;Non;;;;;;Plot amovible;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;5.0;Fichier numérique non métrique;;;;;2022-12-10 14:57:12;2017-06-01 17:22:06;En service;0;Non;5;ALL LUCY STONE;ALL LUCY STONE;Route à 1 chaussée;TRONROUT0000002003976216;LINESTRING Z (354248.9 6688164.8 -1000, 354241.9 6688225.5 -1000, 354236.9 6688249.2 -1000)
;commune;commune;Rue Nadine Gordimer;Rue Nadine Gordimer;;;44109_3767;44109_3767;;;;;;;;;;;;44109#0PX;44109#0PX;;;;44109;44109;6;5;2;5;Non;;;;;;Plot amovible;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;5;R NADINE GORDIMER;R NADINE GORDIMER;Route à 1 chaussée;TRONROUT0000000357587263;LINESTRING Z (354297.4 6688262.1 -1000, 354299.3 6688255 -1000, 354304 6688233.4 -1000, 354306.7 6688209 -1000, 354313.6 6688171.2 -1000)
;commune;commune;Rue Magdeleine;Rue Magdeleine;;;44109_5202;44109_5202;;;;;;;;;;;;44109#0PY;44109#0PY;;;;44109;44109;10;9;2;1;Non;;;;;;Plot amovible;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;5.0;Plan non métrique papier;;;;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;5;R MAGDELEINE;R MAGDELEINE;Route à 1 chaussée;TRONROUT0000000357587264;LINESTRING Z (354364.7 6688278.4 -1000, 354367.1 6688262.8 -1000, 354368.8 6688260.9 -1000, 354371.8 6688241.9 -1000, 354379.6 6688224.9 -1000, 354383.8 6688219.4 -1000, 354386.3 6688211.7 -1000, 354389.3 6688178.6 -1000)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;10;;4;;Non;;;;;;;;;;;;;Libre;35;Non;;Sens direct;Non;Non;4.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2015-05-07 18:59:26;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000000350024874;LINESTRING Z (354468.8 6688278.5 5.9, 354469.4 6688272.6 5.9, 354469.7 6688265.3 5.8, 354470.4 6688256.3 5.4, 354471.5 6688245.9 5.3, 354472.6 6688234.8 5.4, 354473.7 6688223.7 5.6, 354474.6 6688214 5.6, 354475.9 6688201.2 5.6, 354476.4 6688185.9 6.5)
;commune;commune;Esplanade Edouard Glissant;Esplanade Edouard Glissant;;;44109_2734;44109_2734;;;;;;;;;;;;44109#0PL;44109#0PL;;;;44109;44109;7;;23;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-03-12 15:44:43;En service;0;Non;6;ESP EDOUARD GLISSANT;ESP EDOUARD GLISSANT;Sentier;TRONROUT0000000320084029;LINESTRING Z (354478.9 6688246.2 -1000, 354542.2 6688258.8 -1000)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;7;;7;;Non;;;;;;;;;;;;;Libre;35;Non;;Sens direct;Non;Non;4.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000002011476003;LINESTRING Z (354478.9 6688246.2 5.4, 354475.8 6688280.1 3.4)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Sens direct;Non;Non;4.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2015-05-07 18:59:26;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000000350024876;LINESTRING Z (354475.8 6688280.1 3.4, 354472.5 6688279.3 5.9, 354468.8 6688278.5 5.9)
;commune;commune;Esplanade Edouard Glissant;Esplanade Edouard Glissant;;;44109_2734;44109_2734;;;;;;;;;;;;44109#0PL;44109#0PL;;;;44109;44109;5;;3;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;5.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-03-12 15:44:43;En service;0;Non;5;ESP EDOUARD GLISSANT;ESP EDOUARD GLISSANT;Route à 1 chaussée;TRONROUT0000000320084030;LINESTRING Z (354530.5 6688318.1 -1000, 354542.2 6688258.8 -1000)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;24;;16;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000000357587267;LINESTRING Z (354467.3 6688303.2 -1000, 354364.7 6688278.4 -1000)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;5.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2012-02-08 10:00:49;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000000295263927;LINESTRING Z (354468.8 6688278.5 5.9, 354468.1 6688294.6 6.1, 354467.3 6688303.2 6.1)
;commune;commune;Rue René Siegfried;Rue René Siegfried;;;44109_7223;44109_7223;;;;;;;;;;;;441097223;441097223;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;5.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;5;R RENE SIEGFRIED;R RENE SIEGFRIED;Route à 1 chaussée;TRONROUT0000002011476002;LINESTRING Z (354475.8 6688280.1 3.4, 354473.7 6688292.8 6.2, 354472.3 6688295.2 6.2, 354467.3 6688303.2 6.1)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2009-10-15 13:29:33;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000000224965230;LINESTRING Z (354530.5 6688318.1 -1000, 354481.9 6688306.7 -1000, 354467.3 6688303.2 -1000)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2009-10-15 13:29:33;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000000224965223;LINESTRING Z (354236.9 6688249.2 -1000, 354171.7 6688234 -1000, 354156 6688239.046428571 -1000)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;42;;36;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2017-06-01 17:22:06;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000002003976217;LINESTRING Z (354297.4 6688262.1 -1000, 354236.9 6688249.2 -1000)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;34;;26;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2016-06-01 16:58:00;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000000357587262;LINESTRING Z (354364.7 6688278.4 -1000, 354297.4 6688262.1 -1000)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;la Loire à Vélo/la Vélodyssée;;;;;;ITI_AUT_0000002285710202;ROUTNOMM0000000325617764/ROUTNOMM0000000325297519;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2013-11-15 09:02:56;En service;0;Non;6;;;Sentier;TRONROUT0000000329622517;LINESTRING Z (354156 6688252.383505154 -1000, 354156.2 6688252.6 -1000, 354213.7 6688267.3 -1000, 354362.5 6688299.6 -1000, 354463.3 6688321 -1000)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2012-02-13 08:57:14;2012-02-08 10:00:49;En service;0;Non;6;;;Sentier;TRONROUT0000000295264838;LINESTRING Z (354454.6 6688360.7 6.4, 354182.3 6688298.1 -1000)
;;;;;;;;;;;;;;;;;;;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2012-02-13 08:57:14;2009-10-15 13:29:33;En service;0;Non;6;;;Sentier;TRONROUT0000000224965227;LINESTRING Z (354454.6 6688360.7 -1000, 354447.1 6688379.5 -1000, 354258.7538461562 6688409 -1000)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-05-13 20:06:25;2013-11-15 09:02:56;En service;0;Non;6;;;Sentier;TRONROUT0000000329622519;LINESTRING Z (354467.3 6688303.2 6.4, 354463.3 6688321 6.4)
;;;;;;;;;;;;;;;;;;;;44109#0RO;44109#0RO;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2019-09-27 21:08:43;2014-02-25 17:13:51;En service;0;Non;5;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;Route à 1 chaussée;TRONROUT0000000332255658;LINESTRING Z (354472.1 6688345.3 -1000, 354467.3 6688303.2 -1000)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;la Loire à Vélo/la Vélodyssée;;;;;;ITI_AUT_0000002285710202;ROUTNOMM0000000325617764/ROUTNOMM0000000325297519;;;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-05-13 20:06:25;2012-02-08 10:00:49;En service;0;Non;6;;;Sentier;TRONROUT0000000295264930;LINESTRING Z (354463.3 6688321 6.4, 354454.6 6688360.7 6.4)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;la Loire à Vélo/la Vélodyssée;;;;;;ITI_AUT_0000002285710202;ROUTNOMM0000000325297519/ROUTNOMM0000000325617764;44109#0RO;44109#0RO;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2014-02-25 17:13:51;En service;0;Non;5;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;Route à 1 chaussée;TRONROUT0000000332255659;LINESTRING Z (354488.2 6688354.8 -1000, 354472.1 6688345.3 -1000)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;la Loire à Vélo/la Vélodyssée;;;;;;ITI_AUT_0000002285710202;ROUTNOMM0000000325617764/ROUTNOMM0000000325297519;44109#0RO;44109#0RO;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2009-10-15 13:29:33;En service;0;Non;5;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;Route à 1 chaussée;TRONROUT0000000224965228;LINESTRING Z (354472.1 6688345.3 -1000, 354454.6 6688360.7 6.4)
;;;;;;;;;;;;;;;;;;;;44109#0RO;44109#0RO;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2018-02-28 15:51:21;2014-02-25 17:13:51;En service;0;Non;5;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;Route à 1 chaussée;TRONROUT0000000332255656;LINESTRING Z (354457.4378378377 6688409 -1000, 354488.2 6688354.8 -1000)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;30;;30;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2022-06-07 09:25:57;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002287724025;LINESTRING Z (354514.6 6688109.2 7.7, 354519.8 6688109.2 7.8, 354545.3 6688111.7 8, 354554.2 6688112.5 7.8, 354563 6688113.3 7.9, 354571.9 6688114.1 7.8, 354581.1 6688115.1 7.7, 354590.6 6688116 7.8, 354600.4 6688116.9 7.8, 354610.3 6688117.8 7.8, 354620.5 6688118.8 7.7, 354630.8 6688119.8 7.8, 354641.3 6688120.7 7.6, 354651.9 6688121.7 7.6, 354662.6 6688122.7 7.6, 354673.4 6688123.7 7.5, 354684.2 6688124.6 7.6, 354694.7 6688125.6 7.5, 354699.3 6688126 7.5)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;30;;30;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2022-10-25 15:32:08;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002322235082;LINESTRING Z (354699.3 6688126 7.5, 354705 6688126.4 7.6, 354715.2 6688127.4 7.6, 354725.3 6688128.3 7.7, 354735.4 6688129.4 7.7, 354745.4 6688130.2 7.7, 354755.4 6688131.1 7.7, 354765.2 6688132 7.6, 354774.8 6688132.8 7.7, 354784.1 6688133.7 7.6, 354793.3 6688134.5 7.6, 354802.3 6688135.4 7.4, 354808.5 6688136.2 7.4)
;;;;;;;;;;;;;;;;;;;;44109#0TV;44109#0TV;2023-03-01;;;44109;44109;;;;;Non;;;;;;;;;;;;Libre;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;1.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-10-25 15:32:08;2019-10-03 17:17:05;En construction;0;Non;5;R LUCRETIA MOTT;R LUCRETIA MOTT;Route à 1 chaussée;TRONROUT0000002204966811;LINESTRING Z (354614.6 6688194.1 -1000, 354623.2 6688120.4 -1000)
;commune;commune;Rue Maya Angelou;Rue Maya Angelou;;;44109_5557;44109_5557;;;;;;;;;;;;44109#0UT;44109#0UT;2023-03-01;;;44109;44109;;;;;Non;;;;;;;;;;;;Libre;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;1.0;9999.0;Pas de Z;5.0;Fichier numérique non métrique;;;;;2022-12-10 14:57:12;2022-06-07 09:25:57;En construction;0;Non;5;R MAYA ANGELOU;R MAYA ANGELOU;Route à 1 chaussée;TRONROUT0000002287724024;LINESTRING Z (354689.5 6688206.3 -1000, 354699.3 6688126 -1000)
;;;;;;;;;;;;;;;;;;;;44109#0VZ;44109#0VZ;;;;44109;44109;;;;;Non;;;;;;;;;;;;Libre;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;3.0;1.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-10-25 15:32:08;2021-11-17 14:20:28;En service;0;Non;5;ALL BOUBACAR JOSEPH NDIAYE;ALL BOUBACAR JOSEPH NDIAYE;Route à 1 chaussée;TRONROUT0000002274981781;LINESTRING Z (354808.5 6688136.2 7.4, 354808.1 6688145.1 7.2, 354802.2 6688198.9 6.5, 354801.8 6688209.4 6.4)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;70;;70;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2012-02-08 10:00:49;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000295263912;LINESTRING Z (354651 6688202.3 5.7, 354555.5 6688193.3 6.1)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;62;53;62;53;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002011476004;LINESTRING Z (354689.5 6688206.3 5.9, 354651 6688202.3 5.7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-09-09 09:57:41;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000326790008;LINESTRING Z (354811.7 6688206.4 7, 354816.9 6688205.8 7, 354820.9 6688206.3 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002011476011;LINESTRING Z (354801.8 6688209.4 6.4, 354811.7 6688206.4 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;62;53;62;53;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;7.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2022-06-08 15:50:46;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002287832895;LINESTRING Z (354774.6 6688215.1 6.4, 354689.5 6688206.3 5.9)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;30;;30;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2013-09-05 19:16:07;En service;0;Non;4;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000000326049882;LINESTRING Z (354808.5 6688136.2 7.4, 354819.6 6688137 7.6, 354827.9 6688137.7 7.6, 354835.5 6688138.3 7.5, 354842.2 6688138.9 7.6, 354855.4 6688141.9 7.8)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2013-09-09 09:57:41;En service;0;Non;3;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000000326790010;LINESTRING Z (354855.4 6688141.9 7, 354864.2 6688143.2 7, 354869.6 6688148 7)
;commune;commune;Boulevard de l'Estuaire;Boulevard de l'Estuaire;;;44109_1073;44109_1073;;;;;;;;;;;;44109#0HU;44109#0HU;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;Sens direct;Sens inverse;Non;Non;4.0;2.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2017-06-01 17:22:06;En service;0;Non;3;BD DE L'ESTUAIRE;BD DE L'ESTUAIRE;Route à 1 chaussée;TRONROUT0000002003976209;LINESTRING Z (354896 6688146.893333334 6.6, 354895.2 6688146.8 6.6, 354889.6 6688146.3 6.7, 354877.9 6688144.7 6.8, 354869.6 6688148 6.9)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2013-09-05 19:16:07;En service;0;Non;3;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000326049890;LINESTRING Z (354820.9 6688206.3 7, 354846.9 6688157.7 6.9, 354849.2 6688152.9 7, 354852.1 6688148.5 6.9, 354855.4 6688141.9 7)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;Sens inverse;Sens inverse;Non;Non;4.0;1.0;2.5;Z corrigé;5.0;Levé non GPS;;;;;2022-12-10 14:57:12;2013-09-09 09:57:41;En service;0;Non;5;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000326790009;LINESTRING Z (354825.1 6688209.4 7, 354834.5 6688193.9 7, 354845.2 6688175 7, 354855.7 6688158.8 7, 354867 6688151.2 7, 354869.6 6688148 7)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Sens inverse;Non;Non;4.0;1.0;1.5;Levé GPS;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2013-09-05 19:16:07;En service;0;Non;5;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000326049880;LINESTRING Z (354828.6 6688212.4 7, 354840.3 6688195.7 6.7, 354843 6688190.9 6.8, 354846.1 6688185.8 6.7, 354849.5 6688180.5 6.8, 354853.3 6688175.4 6.8, 354857.1 6688170.8 6.9, 354861.1 6688166.7 6.8, 354864.9 6688163.3 6.5, 354868 6688160.3 6.5, 354870.3 6688157.4 6.5, 354872 6688154 6.5, 354869.6 6688148 6.9)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-09-09 09:57:41;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000326790011;LINESTRING Z (354820.9 6688206.3 7, 354825.1 6688209.4 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2013-09-09 09:57:41;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000326790012;LINESTRING Z (354825.1 6688209.4 7, 354828.6 6688212.4 7)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;Double sens;Double sens;Non;Non;7.0;2.0;2.5;Z corrigé;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2019-12-06 11:25:52;En service;0;Non;5;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000002206016815;LINESTRING Z (354825.1 6688209.4 7, 354822.7 6688213 6.9, 354820 6688216.3 6.9)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000002011476005;LINESTRING Z (354828.6 6688212.4 7, 354828.4 6688217.1 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000002011476006;LINESTRING Z (354805.2 6688215.8 7, 354806.4 6688211.7 7, 354808.3 6688209.6 7, 354811.7 6688206.4 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2022-10-25 15:32:08;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002322235081;LINESTRING Z (354774.6 6688215.1 6.4, 354777.1 6688213.8 6.4, 354786.2 6688210.7 6.4, 354792.4 6688209.7 6.4, 354801.8 6688209.4 6.4)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;Sens direct;Sens direct;Non;Non;3.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2009-07-01;;2022-12-10 14:57:12;2012-02-08 10:00:49;En service;0;Non;5;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000295263913;LINESTRING Z (354774.6 6688215.1 6.4, 354787.6 6688214.3 6.5, 354800.2 6688213.8 6.6, 354805.2 6688215.8 7)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;Double sens;Double sens;Non;Non;7.0;2.0;2.5;Z corrigé;2.5;Levé GPS;;;;;2022-12-10 14:57:12;2013-11-29 11:47:57;En service;0;Non;5;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000329965122;LINESTRING Z (354820 6688216.3 6.9, 354817.4 6688217.6 6.9, 354812.8 6688217.6 6.9, 354805.2 6688215.8 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;58;Non;;Sens direct;Non;Non;3.0;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;4;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002011476010;LINESTRING Z (354806.4 6688223.9 7.1, 354799.5 6688219.8 6.4, 354788.8 6688218 6.4, 354774.6 6688215.1 6.4)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2006-10-04 09:41:10;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000029477821;LINESTRING Z (354806.4 6688223.9 7.1, 354805.2 6688215.8 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000002011476007;LINESTRING Z (354813.6 6688229.1 7.1, 354809.4 6688227.1 7.1, 354806.4 6688223.9 7.1)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;;Double sens;Non;Non;7.0;2.0;1.5;BDTopo;2.5;BDTopo;;;;;2022-12-10 14:57:12;2006-10-04 09:41:10;En service;0;Non;3;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000029477698;LINESTRING Z (354800.1 6688263.8 7, 354809.6 6688248 7.1, 354812 6688242.2 7.1, 354812.8 6688236.2 7.1, 354813.6 6688229.1 7.1)
;;;;;;;;;;;;;;;;;;;;44109#0RP;44109#0RP;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2019-01-15 14:19:07;2013-03-12 15:44:43;En service;0;Non;6;ESP DES RIVEURS;ESP DES RIVEURS;Sentier;TRONROUT0000000320084033;LINESTRING Z (354704.3 6688240.9 -1000, 354800.1 6688263.8 7)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;44109#0RP;44109#0RP;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2019-01-15 14:19:07;En service;0;Non;6;ESP DES RIVEURS;ESP DES RIVEURS;Sentier;TRONROUT0000002200361542;LINESTRING Z (354605.7 6688335.8 -1000, 354631.8 6688234 -1000, 354647.2 6688226.7 -1000, 354683.9 6688236 -1000, 354704.3 6688240.9 -1000)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;Libre;Libre;35;Non;Sens direct;Sens direct;Non;Non;3.5;1.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2019-12-06 11:25:52;En service;0;Non;5;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002206016814;LINESTRING Z (354820 6688216.3 6.9, 354828.4 6688217.1 7)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;Sens direct;Sens direct;Non;Non;3.5;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002011476009;LINESTRING Z (354828.4 6688217.1 7, 354843.2 6688218.6 6.7, 354862.3 6688222.7 6.8)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2006-10-04 09:41:10;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000029477853;LINESTRING Z (354828.4 6688217.1 7, 354828.1 6688221.7 7.1, 354827.1 6688223.5 7.1)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;;Sens direct;Non;Non;3.5;1.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2018-06-11 11:56:08;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002011476008;LINESTRING Z (354862.3 6688222.7 6.8, 354841.4 6688224.1 6.7, 354827.1 6688223.5 7.1)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;63;Non;Sens direct;Sens inverse;Non;Non;7.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2007-07-12 11:22:41;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000000084093560;LINESTRING Z (354862.3 6688222.7 6.8, 354882 6688224.7 6.8)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;25;Non;;Sens direct;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2006-10-04 09:41:10;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Rond-point;TRONROUT0000000029477772;LINESTRING Z (354827.1 6688223.5 7.1, 354826 6688225.3 7.1, 354822.3 6688228.9 7.1, 354818.6 6688229.8 7.1, 354813.6 6688229.1 7.1)
;commune;commune;Boulevard de la Prairie au Duc;Boulevard de la Prairie au Duc;;;44109_6896;44109_6896;;;;;;;;;;;;441096896;441096896;;;;44109;44109;;50;;52;Non;;;;;;;;;;;;;Libre;63;Non;Sens direct;Sens inverse;Non;Non;7.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2017-06-01 17:22:06;En service;0;Non;3;BD DE LA PRAIRIE AU DUC;BD DE LA PRAIRIE AU DUC;Route à 1 chaussée;TRONROUT0000002003976208;LINESTRING Z (354882 6688224.7 6.8, 354896 6688226.036225596 6.891106290672433)
;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;;;;;;;;44109#0EA;44109#0EA;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2014-02-11 16:21:21;En service;0;Non;5;R ARTHUR III;R ARTHUR III;Route à 1 chaussée;TRONROUT0000000331917263;LINESTRING Z (354882 6688224.7 6.8, 354874.8 6688278.7 6.8)
;commune;commune;Place Albert Camus;Place Albert Camus;;;44109_9nsczb;44109_9nsczb;;;;;;;;;;;;44109#0O2;44109#0O2;;;;44109;44109;;1;;2;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;2.5;Z corrigé;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2014-02-11 16:20:55;En service;0;Non;6;PL ALBERT CAMUS;PL ALBERT CAMUS;Sentier;TRONROUT0000000331917258;LINESTRING Z (354800.1 6688263.8 7, 354820.7 6688274.2 9.1, 354874.8 6688278.7 11.3)
;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;;;;;;;;44109#0EA;44109#0EA;;;;44109;44109;11;10;11;10;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2009-09-09 16:24:10;En service;0;Non;5;R ARTHUR III;R ARTHUR III;Route à 1 chaussée;TRONROUT0000000224176717;LINESTRING Z (354874.8 6688278.7 6.8, 354874.7 6688294.1 6.9, 354868.6 6688361.8 6.6)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;6;15;6;15;Non;;;;;;;;;;;;;Libre;63;Non;;Double sens;Non;Non;7.0;2.0;1.5;BDTopo;2.5;BDTopo;;;;;2022-12-10 14:57:12;2014-02-11 16:20:55;En service;0;Non;3;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000331917259;LINESTRING Z (354751.1 6688346.9 6.7, 354800.1 6688263.8 7)
;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;441091631;441091631;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-12-10 14:57:12;2014-02-25 17:13:18;En service;0;Non;6;MAIL DES CHANTIERS;MAIL DES CHANTIERS;Sentier;TRONROUT0000000332255639;LINESTRING Z (354530.5 6688318.1 -1000, 354605.7 6688335.8 -1000)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;;;;;;;ITI_AUT_0000002285710202;;;;;;;44109;44109;;;;;;;;;;;;;;;;;Libre;Physiquement impossible;0;Non;;Sans objet;Non;Non;;;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2019-01-15 14:19:07;En service;0;Non;6;;;Sentier;TRONROUT0000002200361541;LINESTRING Z (354704.3 6688240.9 -1000, 354651.3 6688403.6 -1000, 354648.11036269413 6688409 -1000)
;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;;;;;;;;441094812;441094812;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2009-09-09 16:24:10;En service;0;Non;5;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;Route à 1 chaussée;TRONROUT0000000224176715;LINESTRING Z (354868.6 6688361.8 6.6, 354805.5 6688356 6.6, 354762 6688352 6.4, 354759.7 6688351.6 6.4, 354751.1 6688346.9 6.7)
;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;;;;;;;;441094904;441094904;;;;44109;44109;4B;;4;;Non;;;;;;;;;;;;;Libre;63;Non;;Double sens;Non;Non;7.0;2.0;1.5;BDTopo;2.5;BDTopo;;;;;2022-12-10 14:57:12;2009-09-09 16:24:10;En service;0;Non;3;BD LEON BUREAU;BD LEON BUREAU;Route à 1 chaussée;TRONROUT0000000224176716;LINESTRING Z (354720.6586206897 6688409 6.4689655172417115, 354727.3 6688398.2 6.5, 354751.1 6688346.9 6.7)
;;;;;;;;;Voyage à Nantes;Sentier de découverte;;la Loire à Vélo/la Vélodyssée;;;;;;ITI_AUT_0000002285710202;ROUTNOMM0000000325297519/ROUTNOMM0000000325617764;44109#0RO;44109#0RO;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;4.0;2.0;9999.0;Pas de Z;3.0;Orthophotographie;;;;;2022-05-13 20:06:25;2014-02-25 17:13:51;En service;0;Non;5;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;Route à 1 chaussée;TRONROUT0000000332255657;LINESTRING Z (354579.1723472669 6688409 -1000, 354488.2 6688354.8 -1000)
;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;;;;;;;;441094812;441094812;;;;44109;44109;47;42;47;42;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2007-07-12 11:22:41;En service;0;Non;5;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;Route à 1 chaussée;TRONROUT0000000084093559;LINESTRING Z (354868.6 6688361.8 6.6, 354872.8 6688362.2 6.6, 354896 6688364.087884268 6.977576853526454)
;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;;;;;;;;44109#0EA;44109#0EA;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2016-12-19 12:06:24;En service;0;Non;5;R ARTHUR III;R ARTHUR III;Route à 1 chaussée;TRONROUT0000002000615688;LINESTRING Z (354868.6 6688361.8 6.6, 354864.8 6688397.3 6.8)
;;;;;;;;;;;;;;;;;;;;44109#0QW;44109#0QW;;;;44109;44109;;;;;Non;;;;;;;;;;;;;Restreint aux ayants droit;0;Non;;Double sens;Non;Non;5.0;2.0;2.5;Z corrigé;3.0;Orthophotographie;;;;;2017-11-30 19:26:50;2017-06-01 17:22:06;En service;0;Non;5;ALL NIKI DE SAINT-PHALLE;ALL NIKI DE SAINT-PHALLE;Route à 1 chaussée;TRONROUT0000002003976220;LINESTRING Z (354864.8 6688397.3 9.5, 354896 6688400.301749271 9.090670553935745)
;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;;;;;;;;44109#0EA;44109#0EA;;;;44109;44109;5;;9;;Non;;;;;;;;;;;;;Libre;35;Non;;Double sens;Non;Non;4.0;2.0;1.5;Photogrammétrie;2.5;Photogrammétrie;;;2017-07-01;;2022-12-10 14:57:12;2009-09-09 16:24:10;En service;0;Non;5;R ARTHUR III;R ARTHUR III;Route à 1 chaussée;TRONROUT0000000224176726;LINESTRING Z (354864.8 6688397.3 6.8, 354863.79649122804 6688409 6.959649122810142)
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def prairieAuDucInNantesPath1():
        _sio = StringIO("""geometry
LINESTRING (354648.14260727953 6688211.714330149, 354647.98951279157 6688211.700557634, 354637.0486024345 6688210.774508305, 354608.84270565317 6688208.035683066, 354607.23398820555 6688207.891409829, 354603.7878139746 6688215.314824239, 354596.12449331133 6688214.60645006, 354582.21460034273 6688213.12530405, 354561.6951105398 6688211.187280567, 354557.2851932434 6688210.806176603, 354535.6419351096 6688309.2769515505, 354535.2429963443 6688309.182155434, 354556.5590431452 6688210.639357932, 354548.6296467959 6688203.631769472, 354531.07009532617 6688201.426221944, 354529.5855921826 6688202.528995708, 354498.11401195574 6688199.51979617, 354469.57980941766 6688198.36201807, 354437.6913605514 6688195.395514355, 354421.1730309755 6688193.736811619, 354415.3960465532 6688193.18902414, 354400.47970195283 6688191.887598102, 354391.73722885555 6688190.755842207, 354384.02804173384 6688188.514798805, 354319.8235337814 6688181.57152045, 354301.9931839867 6688182.598759329, 354272.3427244896 6688180.052884458, 354256.62933774316 6688177.917788565, 354257.7399293631 6688160.703618456, 354274.0732028209 6688162.185869786, 354302.6872480606 6688160.435389245, 354353.66166452534 6688165.808973411, 354361.91342331434 6688168.14458231, 354422.1271878291 6688173.645538298, 354431.51965424535 6688173.712997138, 354490.2935181291 6688179.267759969, 354491.81261139293 6688179.365765986, 354494.1825415612 6688153.873190666, 354505.8896226801 6688154.891197719, 354510.1935504898 6688117.591178974, 354510.5008961229 6688115.365209089, 354536.31791394326 6688117.691902807, 354533.75295199157 6688144.012572044, 354520.33814017085 6688142.567301788, 354516.5292664833 6688180.769991856, 354518.724669209 6688181.053308609, 354573.889699626 6688186.344854437, 354580.85283508507 6688183.947709443, 354612.44760676724 6688186.7815402225, 354622.50627731724 6688195.284220334, 354625.85076048446 6688197.246368688, 354649.16882604925 6688199.280476171, 354668.7956855427 6688201.109139725, 354771.0482473519 6688210.732207292, 354776.2318187611 6688211.299160414, 354779.3095642853 6688210.813200595, 354789.0099146984 6688208.157929713, 354791.71021843486 6688207.897659474, 354796.08260541165 6688208.036073784)
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def prairieAuDucInNantesWaypoints1():
        _sio = StringIO("""id;geometry
201;POINT (354648.1468654478 6688211.714330152)
202;POINT (354608.84270565317 6688208.035683066)
203;POINT (354557.2851932434 6688210.806176603)
204;POINT (354535.4171597668 6688309.242533148)
205;POINT (354556.5590431452 6688210.639357932)
206;POINT (354548.6296467959 6688203.631769472)
208;POINT (354272.3427244896 6688180.052884458)
209;POINT (354274.0732028209 6688162.185869786)
210;POINT (354353.66166452534 6688165.808973411)
211;POINT (354490.2935181291 6688179.267759969)
212;POINT (354510.1935504898 6688117.591178974)
213;POINT (354518.724669209 6688181.053308609)
214;POINT (354612.44760676724 6688186.7815402225)
215;POINT (354649.1688260489 6688199.280476169)
216;POINT (354796.08260541165 6688208.036073784)
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def plot(oFile=None):
        roi = GeoDataFrameDemos9.prairieAuDucInNantesRoi()
        buildings = GeoDataFrameDemos9.prairieAuDucInNantesBuildings()
        roads = GeoDataFrameDemos9.prairieAuDucInNantesRoads()
        path1 = GeoDataFrameDemos9.prairieAuDucInNantesPath1()
        waypoints1 = GeoDataFrameDemos9.prairieAuDucInNantesWaypoints1()

        # MAPPING
        minx, miny, maxx, maxy = roi.total_bounds

        fig, basemap = plt.subplots(figsize=(0.7 * 8.26, 1 * 8.26))
        roi.boundary.plot(ax=basemap, color='blue')
        buildings.plot(ax=basemap, color='lightgrey')
        roads.plot(ax=basemap, color='black', linewidth=0.3)
        path1.plot(ax=basemap, color='green', linewidth=0.3)
        waypoints1.plot(ax=basemap, color='green', marker='^', markersize=2)
        basemap.axis('off')
        basemap.axis([minx, maxx, miny, maxy])
        if oFile is None:
            plt.show()
        else:
            plt.savefig(oFile, bbox_inches='tight')
        plt.close(fig)


# GeoDataFrameDemos9.plot()
