'''
Created on 6 sep. 2023

@author: tleduc

Copyright 2020-2023 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from io import StringIO
from geopandas import clip
from t4gpd.commons.GeoDataFrameLib import GeoDataFrameLib
from t4gpd.demos.AbstractGeoDataFrameDemos import AbstractGeoDataFrameDemos


class NantesBDT(AbstractGeoDataFrameDemos):
    '''
    classdocs
    '''

    @staticmethod
    def version():
        return "2023-06-15"

    @staticmethod
    def buildings(roi=None):
        buildings = NantesBDT.__buildings()
        if roi is not None:
            buildings = clip(buildings, roi, keep_geom_type=True)
        return buildings

    @staticmethod
    def __buildings():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        from geopandas import clip, read_file
        from t4gpd.demos.GeoDataFrameDemosA import GeoDataFrameDemosA
        from t4gpd.morph.STBBox import STBBox

        roi = STBBox(GeoDataFrameDemosA.psmv(), buffDist=350.0).run()
        # roi = GeoDataFrameDemosA.intraPeripheriqueNantes()

        buildings = read_file("/home/tleduc/data/bdtopo/\
BDTOPO_3-3_TOUSTHEMES_SHP_LAMB93_D044_2023-06-15/\
BDTOPO/1_DONNEES_LIVRAISON_2023-06-00117/\
BDT_3-3_SHP_LAMB93_D044-ED2023-06-15\
/BATI/BATIMENT.shp", bbox=roi)
        buildings.geometry = buildings.geometry.buffer(0)
        buildings = clip(buildings, roi, keep_geom_type=True)
        buildings.to_csv('/tmp/buildings.csv', sep=';', index=False)
        '''
        _sio = StringIO("""ID;NATURE;USAGE1;USAGE2;LEGER;ETAT;DATE_CREAT;DATE_MAJ;DATE_APP;DATE_CONF;SOURCE;ID_SOURCE;ACQU_PLANI;PREC_PLANI;ACQU_ALTI;PREC_ALTI;NB_LOGTS;NB_ETAGES;MAT_MURS;MAT_TOITS;HAUTEUR;Z_MIN_SOL;Z_MIN_TOIT;Z_MAX_TOIT;Z_MAX_SOL;ORIGIN_BAT;APP_FF;geometry
BATIMENT0000000302929784;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;20.2;7.0;27.3;29.6;7.5;Cadastre;B 0.8;POLYGON Z ((355368.8 6688312.2 27.3, 355369.040916009 6688312.003221275 27.3, 355368.63864144555 6688312.003221275 27.3, 355368.8 6688312.2 27.3))
BATIMENT0000000302929765;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.9;6.4;15.3;16.2;7.7;Cadastre;A 0.3;POLYGON Z ((355311.4 6688320.2 15.3, 355338 6688322.8 15.3, 355338.2 6688319.6 15.3, 355338.9 6688313 15.3, 355339.03748672066 6688312.003221275 15.3, 355312.29900153755 6688312.003221275 15.3, 355311.4 6688320.2 15.3))
BATIMENT0000000302929777;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;6.5;12.7;14.1;7.6;Cadastre;;POLYGON Z ((355338.9 6688313 12.7, 355344.4 6688313.6 12.7, 355352.5 6688314.2 12.7, 355352.6961409576 6688312.003221275 12.7, 355339.03748672066 6688312.003221275 12.7, 355338.9 6688313 12.7))
BATIMENT0000000302929790;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;19.7;7.0;26.7;29.8;7.7;Cadastre;C 0.8;POLYGON Z ((355368.8 6688312.2 26.7, 355381.3 6688327 26.7, 355383.1 6688327.2 26.7, 355394.9 6688317.3 26.7, 355390.5418909228 6688312.003221275 26.7, 355369.040916009 6688312.003221275 26.7, 355368.8 6688312.2 26.7))
BATIMENT0000000302929794;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;10;10;5.7;6.1;11.8;12.4;7.5;Cadastre;C 0.6;POLYGON Z ((355343.5 6688323.4 11.8, 355367.3 6688325.7 11.8, 355370.1 6688325.9 11.8, 355370.8 6688321.2 11.8, 355359.8 6688320 11.8, 355359.7 6688321.5 11.8, 355354.9 6688321.2 11.8, 355355.2 6688319.5 11.8, 355344 6688318.4 11.8, 355343.5 6688323.4 11.8))
BATIMENT0000000302929795;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.3;7.5;17.8;22.2;7.7;Cadastre;A 1.0;POLYGON Z ((355383.1 6688327.2 17.8, 355389.9 6688327.9 17.8, 355392.7 6688328.2 17.8, 355402 6688329.1 17.8, 355402.2 6688326.3 17.8, 355394.9 6688317.3 17.8, 355383.1 6688327.2 17.8))
BATIMENT0000002011295166;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.7;5.0;;14.7;7.8;Imagerie aérienne;;POLYGON Z ((355370.1 6688325.9 11.8, 355367.3 6688325.7 11.8, 355343.5 6688323.4 11.8, 355342.7 6688333 10.1, 355345.8 6688333.4 10.1, 355346 6688331.1 10.1, 355348.3 6688331.4 10.1, 355348.4 6688330.7 10.1, 355352 6688330.9 10.1, 355352.2 6688329.9 10.1, 355362.5 6688330.9 10.1, 355362.2 6688335.8 10.1, 355369.4 6688336.6 13.7, 355375.6 6688337.2 13.7, 355376.5 6688329.6 13.7, 355376.7 6688326.8 10.6, 355370.1 6688325.9 11.8))
BATIMENT0000000302929792;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;30;90;4.4;7.0;11.4;13.9;7.6;Cadastre;A 1.0;POLYGON Z ((355383.1 6688327.2 11.4, 355381.3 6688327 11.4, 355380 6688337 11.4, 355388.8 6688338.1 11.4, 355389.9 6688327.9 11.4, 355383.1 6688327.2 11.4))
BATIMENT0000000302929796;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;20;10.1;7.0;17.1;18.0;7.7;Cadastre;A 1.0;POLYGON Z ((355392 6688335.4 17.1, 355390.8 6688335.1 17.1, 355390.5 6688338.1 17.1, 355401 6688339.3 17.1, 355402 6688329.1 17.1, 355392.7 6688328.2 17.1, 355392 6688335.4 17.1))
BATIMENT0000000302930042;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;2.0;50;30;5.8;5.4;11.2;12.5;6.5;Cadastre;C 0.1;POLYGON Z ((355335.3 6688340.8 11.2, 355336.3 6688330.1 11.2, 355307.9 6688327.4 11.2, 355306.9 6688338.2 11.2, 355335.3 6688340.8 11.2))
BATIMENT0000000302929847;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;86.0;4.0;00;00;10.7;6.8;17.5;20.5;7.7;Cadastre;A 1.0;POLYGON Z ((355547.3 6688317.3 17.5, 355548.8 6688317.4 17.5, 355548.7 6688319.2 17.5, 355548.5 6688320.9 17.5, 355547 6688320.8 17.5, 355546.9 6688321.6 17.5, 355545.7 6688334.4 17.5, 355556.1 6688335.3 17.5, 355559.2 6688335.5 17.5, 355559.6 6688329.6 17.5, 355561.00399830245 6688312.003221275 17.5, 355547.78152533865 6688312.003221275 17.5, 355547.3 6688317.3 17.5))
BATIMENT0000000302929851;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;7.3;15.7;18.2;7.5;Cadastre;;POLYGON Z ((355548.7 6688319.2 15.7, 355547.1 6688319 15.7, 355547 6688320.5 15.7, 355547 6688320.8 15.7, 355548.5 6688320.9 15.7, 355548.7 6688319.2 15.7))
BATIMENT0000000302929908;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;6.0;11.2;11.9;7.4;Cadastre;;POLYGON Z ((355519.5 6688336.6 11.2, 355516.1 6688336.2 11.2, 355515.5 6688343.6 11.2, 355537.6 6688345.7 11.2, 355538.3 6688338.1 11.2, 355534.9 6688337.9 11.2, 355535.8 6688328 11.2, 355537 6688328 11.2, 355537.5 6688322.2 11.2, 355529.7 6688321.3 11.2, 355529.4 6688324.6 11.2, 355520.8 6688323.9 11.2, 355519.5 6688336.6 11.2))
BATIMENT0000000302929849;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;10;10.6;6.9;17.5;19.9;7.2;Cadastre;A 1.0;POLYGON Z ((355545.2 6688340.5 17.5, 355555.4 6688341.3 17.5, 355556.1 6688335.3 17.5, 355545.7 6688334.4 17.5, 355545.2 6688340.5 17.5))
BATIMENT0000000302929852;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;5.0;00;00;13.7;7.0;20.7;21.6;7.5;Cadastre;C 0.1;POLYGON Z ((355543.3 6688361.2 20.7, 355543.4 6688361.2 20.7, 355556.5 6688362.4 20.7, 355556.7 6688359.6 20.7, 355561 6688360 20.7, 355567.4 6688360.5 20.7, 355568.3 6688349.8 20.7, 355555.8 6688348.8 20.7, 355556.4 6688341.4 20.7, 355555.4 6688341.3 20.7, 355545.2 6688340.5 20.7, 355543.3 6688361.2 20.7))
BATIMENT0000000302929856;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.4;7.0;18.4;21.1;7.3;Cadastre;;POLYGON Z ((355560.9 6688362.8 18.4, 355561 6688360 18.4, 355556.7 6688359.6 18.4, 355556.5 6688362.4 18.4, 355560.9 6688362.8 18.4))
BATIMENT0000000302929932;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;6.7;9.0;10.2;7.3;Cadastre;;POLYGON Z ((355487.2 6688371.7 9, 355487.6 6688368 9, 355476.5 6688367 9, 355476.2 6688370.7 9, 355487.2 6688371.7 9))
BATIMENT0000000302929936;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;6.2;8.5;11.2;7.3;Cadastre;;POLYGON Z ((355495.5 6688368.6 8.5, 355487.6 6688368 8.5, 355487.2 6688371.7 8.5, 355486.2 6688381.6 8.5, 355488 6688381.9 8.5, 355488.3 6688379.8 8.5, 355489.1 6688379.8 8.5, 355490.2 6688370.7 8.5, 355492.7 6688370.9 8.5, 355491.9 6688380.9 8.5, 355494.3 6688381.1 8.5, 355495.5 6688368.6 8.5))
BATIMENT0000000302929797;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;7.0;12.7;14.7;7.4;Cadastre;;POLYGON Z ((355555.1 6688377.8 12.7, 355556.9 6688377.9 12.7, 355557.4 6688372.8 12.7, 355555.6 6688372.6 12.7, 355555.1 6688377.8 12.7))
BATIMENT0000000302929935;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;6.0;11.0;12.9;7.3;Cadastre;;POLYGON Z ((355486.2 6688381.6 11, 355487.2 6688371.7 11, 355476.2 6688370.7 11, 355475.1 6688382.4 11, 355475 6688383.3 11, 355482.1 6688384.1 11, 355486 6688384.5 11, 355486.2 6688381.6 11))
BATIMENT0000000302929949;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;6.8;17.7;19.6;7.8;Cadastre;;POLYGON Z ((355477.6 6688313.6 17.7, 355469.4 6688313 17.7, 355470.9 6688334.1 17.7, 355471 6688334.5 17.7, 355471.1 6688335 17.7, 355471.1 6688335.1 17.7, 355471.1 6688335.6 17.7, 355471.1 6688335.7 17.7, 355471 6688336 17.7, 355471 6688336.3 17.7, 355470.8 6688336.7 17.7, 355470.7 6688337 17.7, 355470.7 6688337.2 17.7, 355470.5 6688337.4 17.7, 355470.4 6688337.7 17.7, 355470.2 6688337.9 17.7, 355470 6688338.2 17.7, 355469.6 6688338.6 17.7, 355469.3 6688338.9 17.7, 355469.1 6688339 17.7, 355469 6688339 17.7, 355468.8 6688339.2 17.7, 355468.2 6688339.3 17.7, 355467.8 6688339.4 17.7, 355467.2 6688339.5 17.7, 355466.4 6688339.6 17.7, 355466.2 6688339.7 17.7, 355465.4 6688339.8 17.7, 355465.1 6688339.9 17.7, 355464 6688340 17.7, 355463.8 6688340.1 17.7, 355463 6688340.2 17.7, 355462.7 6688340.6 17.7, 355462.4 6688340.8 17.7, 355462.2 6688341 17.7, 355461.9 6688341.2 17.7, 355461.7 6688341.3 17.7, 355461.6 6688341.4 17.7, 355461.5 6688341.4 17.7, 355461.2 6688341.6 17.7, 355460.9 6688341.7 17.7, 355460.4 6688341.8 17.7, 355459.9 6688341.9 17.7, 355459.7 6688341.9 17.7, 355459.3 6688342 17.7, 355459.1 6688342 17.7, 355458.8 6688342 17.7, 355458.4 6688341.9 17.7, 355458.1 6688341.9 17.7, 355457.8 6688341.8 17.7, 355457.6 6688341.7 17.7, 355457.3 6688341.6 17.7, 355457 6688341.5 17.7, 355422.4 6688336.4 17.7, 355423.4 6688340.4 17.7, 355423.4 6688340.5 17.7, 355423.5 6688340.6 17.7, 355423.5 6688340.7 17.7, 355423.6 6688341 17.7, 355423.8 6688341.2 17.7, 355424 6688341.5 17.7, 355424.2 6688341.8 17.7, 355424.4 6688342 17.7, 355424.5 6688342 17.7, 355424.9 6688342.3 17.7, 355425.3 6688342.4 17.7, 355425.6 6688342.5 17.7, 355425.8 6688342.6 17.7, 355426.2 6688342.6 17.7, 355426.3 6688342.6 17.7, 355426.1 6688346.8 17.7, 355425.8 6688350.6 17.7, 355418.3 6688349.8 17.7, 355418.2 6688349.8 17.7, 355416.4 6688368.9 17.7, 355440.8 6688371.4 17.7, 355442.4 6688355.6 17.7, 355455 6688356.7 17.7, 355455.9 6688360.6 17.7, 355473.5 6688362.1 17.7, 355473.6 6688358.9 17.7, 355503.9 6688361.4 17.7, 355504.4 6688356.4 17.7, 355508.4948485231 6688312.003221275 17.7, 355477.7277422979 6688312.003221275 17.7, 355477.6 6688313.6 17.7), (355492.5 6688313.5 17.7, 355505.3 6688314.7 17.7, 355505.1 6688317.2 17.7, 355500.7 6688316.8 17.7, 355500 6688322.2 17.7, 355502.8 6688322.6 17.7, 355501.7 6688335.9 17.7, 355498.9 6688335.6 17.7, 355498.5 6688340.1 17.7, 355502.8 6688340.5 17.7, 355502.4 6688343.3 17.7, 355489.7 6688342 17.7, 355490.1 6688338.2 17.7, 355489.3 6688338.2 17.7, 355491.6 6688316.2 17.7, 355492.2 6688316.3 17.7, 355492.5 6688313.5 17.7))
BATIMENT0000000302929947;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.4;7.0;17.5;19.6;7.5;Cadastre;;POLYGON Z ((355418.3 6688349.8 17.5, 355425.8 6688350.6 17.5, 355426.1 6688346.8 17.5, 355418.6 6688346 17.5, 355418.2 6688349.8 17.5, 355418.3 6688349.8 17.5))
BATIMENT0000000302929946;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;6.8;15.0;19.6;7.3;Cadastre;;POLYGON Z ((355416.4 6688368.9 15, 355416.1 6688372.4 15, 355440.5 6688374.9 15, 355440.8 6688371.4 15, 355416.4 6688368.9 15))
BATIMENT0000000302929929;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;2.7;6.4;9.2;11.0;7.3;Cadastre;C 0.2;POLYGON Z ((355455.9 6688392.3 9.2, 355456.9 6688380.9 9.2, 355454.3 6688380.7 9.2, 355454.4 6688379.5 9.2, 355458.4 6688379.8 9.2, 355459.1 6688373.7 9.2, 355458.6 6688373.7 9.2, 355458.9 6688370.9 9.2, 355470.4 6688371.9 9.2, 355470.1 6688374.6 9.2, 355469.7 6688374.5 9.2, 355469.1 6688381.8 9.2, 355475.1 6688382.4 9.2, 355476.2 6688370.7 9.2, 355476.5 6688367 9.2, 355454.2 6688365 9.2, 355452.9 6688378.3 9.2, 355451.6 6688391.9 9.2, 355455 6688392.2 9.2, 355455.9 6688392.3 9.2))
BATIMENT0000000302929927;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;12;20;14.7;6.5;21.2;27.0;7.1;Cadastre;A 1.0;POLYGON Z ((355422.8 6688391 21.2, 355429 6688391.6 21.2, 355430.3 6688391.7 21.2, 355431.4 6688391.8 21.2, 355432.2 6688391.9 21.2, 355432.5 6688388.8 21.2, 355429.1 6688388.5 21.2, 355430.1 6688378.8 21.2, 355432.2 6688379.1 21.2, 355432.1 6688381.2 21.2, 355432.7 6688382.5 21.2, 355434.9 6688382.7 21.2, 355437.2 6688382.9 21.2, 355437.8 6688376.9 21.2, 355437.8 6688376.8 21.2, 355430.4 6688376.1 21.2, 355415.9 6688374.6 21.2, 355414.4 6688390.2 21.2, 355422.8 6688391 21.2))
BATIMENT0000000302929930;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;6.2;8.7;17.5;6.8;Cadastre;;POLYGON Z ((355437.2 6688382.9 8.7, 355434.9 6688382.7 8.7, 355434.2 6688390 8.7, 355436.5 6688390.2 8.7, 355436.6 6688388.7 8.7, 355437.2 6688382.9 8.7))
BATIMENT0000000302929925;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;5.0;6.0;11.0;26.2;7.3;Cadastre;A 1.0;POLYGON Z ((355434.9 6688406.9 11, 355450.1 6688408.3 11, 355451 6688398.4 11, 355451.4 6688394.3 11, 355451.6 6688391.9 11, 355452.9 6688378.3 11, 355437.8 6688376.8 11, 355437.8 6688376.9 11, 355437.2 6688382.9 11, 355436.6 6688388.7 11, 355442.1 6688389.3 11, 355442.3 6688388.2 11, 355447.8 6688388.7 11, 355447.7 6688389.8 11, 355448.2 6688389.9 11, 355447.6 6688393.8 11, 355446.8 6688393.8 11, 355446.5 6688392.8 11, 355442.1 6688392.4 11, 355442 6688393.3 11, 355436.3 6688392.6 11, 355434.9 6688406.9 11))
BATIMENT0000000302929931;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.8;6.4;8.2;10.5;6.6;Cadastre;;POLYGON Z ((355458.3 6688394.2 8.2, 355458.5 6688392.6 8.2, 355455.9 6688392.3 8.2, 355455 6688392.2 8.2, 355454.9 6688393.9 8.2, 355458.3 6688394.2 8.2))
BATIMENT0000000302929926;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;6.5;11.0;12.7;6.7;Cadastre;;POLYGON Z ((355451.4 6688394.3 11, 355454.8 6688394.6 11, 355454.9 6688393.9 11, 355455 6688392.2 11, 355451.6 6688391.9 11, 355451.4 6688394.3 11))
BATIMENT0000000302929923;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;6.7;9.2;10.3;7.1;Cadastre;;POLYGON Z ((355477.1 6688392 9.2, 355474.2 6688391.7 9.2, 355473.8 6688395.4 9.2, 355476.8 6688395.7 9.2, 355477.1 6688392 9.2))
BATIMENT0000000327821795;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;12;23;7.9;7.3;;16.6;7.5;Imagerie aérienne;A 1.0;POLYGON Z ((355385.3 6688348.8 15.2, 355391.7 6688349.6 15.2, 355399.9 6688350.3 15.2, 355400.1 6688345.1 15.2, 355378.9 6688342.5 15.2, 355378.1 6688348.1 15.2, 355385.3 6688348.8 15.2))
BATIMENT0000002011295638;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;78.0;7.0;00;00;18.4;5.3;;24.0;7.7;Imagerie aérienne;C 0.5;POLYGON Z ((355358 6688364.2 18.3, 355356.2 6688363.9 23.1, 355356.6 6688361 23.1, 355358.3 6688361.2 18.5, 355359.2 6688351.9 18.2, 355360.1 6688352 18.2, 355360.8 6688344.4 23.7, 355361.5 6688336.8 23.7, 355361.8 6688334.5 19.7, 355360.1 6688334.4 19.7, 355360.4 6688331.6 19.7, 355352.8 6688330.9 19.7, 355352.7 6688331.8 19.7, 355349.3 6688331.5 19.7, 355348.8 6688338.4 19.7, 355349.9 6688338.6 23.1, 355349.6 6688343.4 23.1, 355348.4 6688343.2 19.3, 355347.6 6688351.3 19.5, 355346.7 6688351.2 19.5, 355346.1 6688360 19.5, 355347.6 6688360.2 23, 355347.3 6688363.4 23, 355345.8 6688363.2 19.5, 355345.2 6688370.1 19.5, 355344.9 6688373.9 19.5, 355344.7 6688376.8 19.5, 355346.5 6688377 23.2, 355355.1 6688377.6 23.2, 355356.9 6688377.8 19, 355358 6688364.2 18.3))
BATIMENT0000000302930039;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;6.4;11.6;12.7;6.6;Cadastre;;POLYGON Z ((355333.4 6688361.3 11.6, 355334.4 6688350.7 11.6, 355308.2 6688348.2 11.6, 355307.2 6688358.8 11.6, 355333.4 6688361.3 11.6))
BATIMENT0000000302929786;Indifférenciée;Annexe;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;7.0;00;00;4.4;6.1;10.5;12.5;7.4;Cadastre;A 1.0;POLYGON Z ((355364.6 6688381.1 10.5, 355381.9 6688382.5 10.5, 355382.5 6688376.5 10.5, 355382.6 6688374.4 10.5, 355376.9 6688374.1 10.5, 355376.9 6688376.5 10.5, 355370.6 6688375.8 10.5, 355372.2 6688355.4 10.5, 355373.6 6688353 10.5, 355384.6 6688353.9 10.5, 355385.3 6688348.8 10.5, 355378.1 6688348.1 10.5, 355368.1 6688347 10.5, 355364.6 6688381.1 10.5))
BATIMENT0000000302929762;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;6.3;9.5;15.1;6.7;Cadastre;;POLYGON Z ((355306.1 6688371.3 9.5, 355306.3 6688369.9 9.5, 355306.8 6688365.7 9.5, 355300 6688364.8 9.5, 355299.4 6688370.7 9.5, 355306.1 6688371.3 9.5))
BATIMENT0000000302929766;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.3;7.0;13.3;;;Cadastre;C 0.3;POLYGON Z ((355306.3 6688369.9 13.3, 355317.1 6688370.9 13.3, 355317.6 6688366.8 13.3, 355306.8 6688365.7 13.3, 355306.3 6688369.9 13.3))
BATIMENT0000000302929780;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.2;6.3;10.5;15.2;6.6;Cadastre;C 0.3;POLYGON Z ((355327.8 6688367.8 10.5, 355317.6 6688366.8 10.5, 355317.1 6688370.9 10.5, 355327.4 6688371.9 10.5, 355327.8 6688367.8 10.5))
BATIMENT0000002011291600;Indifférenciée;Annexe;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;0.0;00;00;13.7;5.8;;25.8;6.6;Imagerie aérienne;C 0.2;POLYGON Z ((355339.2 6688373.3 13.7, 355344.9 6688373.9 19.5, 355345.2 6688370.1 19.5, 355339.6 6688369.4 13.7, 355339.2 6688373.3 13.7))
BATIMENT0000002011296022;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;1950-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;41.0;7.0;39;49;22.1;6.2;;30.5;7.5;Imagerie aérienne;A 1.0;POLYGON Z ((355390.6 6688349.5 27.3, 355387.8 6688376.2 27.3, 355387.4 6688376.6 27.3, 355385.9 6688392.7 27.3, 355362.1 6688390.8 27.2, 355362.9 6688382.1 26.8, 355356 6688381.3 26.8, 355354.3 6688399.1 26.8, 355389.6 6688402.6 28.3, 355394.4 6688398.6 28.3, 355398.9 6688350.4 28.2, 355390.6 6688349.5 27.3))
BATIMENT0000000302929769;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;6.4;11.2;13.7;6.8;Cadastre;;POLYGON Z ((355315.6 6688375.5 11.2, 355314.4 6688375.4 11.2, 355314.3 6688377.5 11.2, 355312.2 6688377.3 11.2, 355312 6688380.1 11.2, 355316.2 6688380.2 11.2, 355317 6688373.3 11.2, 355315.6 6688373.2 11.2, 355315.6 6688375.5 11.2))
BATIMENT0000000302929799;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;11.6;6.8;18.4;20.9;7.4;Cadastre;A 1.0;POLYGON Z ((355539.9 6688386.1 18.4, 355549.8 6688387 18.4, 355549.8 6688386.6 18.4, 355550.7 6688377.4 18.4, 355551.1 6688372.2 18.4, 355542.5 6688371.3 18.4, 355529.2 6688370.1 18.4, 355527.9 6688384.9 18.4, 355539.9 6688386.1 18.4), (355539.9 6688376.4 18.4, 355545.5 6688376.8 18.4, 355545.3 6688379.5 18.4, 355544.9 6688384.4 18.4, 355542.4 6688384.2 18.4, 355542.8 6688380 18.4, 355539.5 6688379.7 18.4, 355539.9 6688376.4 18.4))
BATIMENT0000000302929941;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;4.0;10;20;8.9;6.3;15.2;21.0;7.4;Cadastre;A 1.0;POLYGON Z ((355494.3 6688381.1 15.2, 355494.2 6688382.5 15.2, 355493.5 6688390.5 15.2, 355493.4 6688391 15.2, 355498.9 6688391.5 15.2, 355500.7 6688391.7 15.2, 355501 6688388.9 15.2, 355499.4 6688388.8 15.2, 355500.8 6688374.9 15.2, 355506.5 6688375.3 15.2, 355506.1 6688379.3 15.2, 355505.6 6688379.2 15.2, 355505.4 6688380.7 15.2, 355505.9 6688380.8 15.2, 355505.3 6688387.1 15.2, 355502.3 6688386.9 15.2, 355502 6688389 15.2, 355505.8 6688389.3 15.2, 355514.8 6688390.2 15.2, 355516.4 6688370.4 15.2, 355503.2 6688369.2 15.2, 355495.5 6688368.6 15.2, 355494.3 6688381.1 15.2))
BATIMENT0000000302929798;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;2.0;00;00;8.1;6.9;15.0;15.4;7.6;Cadastre;C 0.1;POLYGON Z ((355549.8 6688386.6 15, 355554.8 6688387 15, 355555 6688384.9 15, 355559.4 6688385.3 15, 355559.4 6688385.8 15, 355570.3 6688386.8 15, 355570.4 6688386.3 15, 355575.9 6688386.8 15, 355575.7 6688389 15, 355581.6 6688389.5 15, 355582.5 6688380.3 15, 355578 6688379.9 15, 355576.2 6688379.8 15, 355576.7 6688374.6 15, 355557.4 6688372.8 15, 355556.9 6688377.9 15, 355555.1 6688377.8 15, 355550.7 6688377.4 15, 355549.8 6688386.6 15))
BATIMENT0000000302929937;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1856-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;15;20;7.4;6.3;13.7;15.9;6.8;Cadastre;C 0.3;POLYGON Z ((355486 6688384.5 13.7, 355485.4 6688389.7 13.7, 355487 6688389.9 13.7, 355491.8 6688390.4 13.7, 355493.5 6688390.5 13.7, 355494.2 6688382.5 13.7, 355488 6688381.9 13.7, 355486.2 6688381.6 13.7, 355486 6688384.5 13.7))
BATIMENT0000000302929940;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;6.0;11.0;13.0;6.9;Cadastre;;POLYGON Z ((355481.3 6688392.7 11, 355485.1 6688393.1 11, 355485.4 6688389.7 11, 355486 6688384.5 11, 355482.1 6688384.1 11, 355481.3 6688392.7 11))
BATIMENT0000000302929801;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;20;10;7.8;6.5;14.3;19.7;7.3;Cadastre;A 1.0;POLYGON Z ((355527.9 6688384.9 14.3, 355527.4 6688390.7 14.3, 355549.2 6688392.8 14.3, 355549.6 6688389 14.3, 355541.2 6688388.3 14.3, 355541 6688389.8 14.3, 355539.7 6688389.7 14.3, 355539.9 6688386.1 14.3, 355527.9 6688384.9 14.3))
BATIMENT0000000302929942;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;6.2;9.7;10.8;7.1;Cadastre;;POLYGON Z ((355493.4 6688391 9.7, 355493.2 6688393.6 9.7, 355498.6 6688394.1 9.7, 355498.9 6688391.5 9.7, 355493.4 6688391 9.7))
BATIMENT0000000302929938;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;6.3;9.0;12.0;6.8;Cadastre;;POLYGON Z ((355485.1 6688393.1 9, 355485.1 6688393.5 9, 355484.8 6688396.5 9, 355484.7 6688397.8 9, 355486.3 6688398 9, 355486.5 6688395.8 9, 355488.1 6688396 9, 355488.6 6688391.8 9, 355486.8 6688391.6 9, 355487 6688389.9 9, 355485.4 6688389.7 9, 355485.1 6688393.1 9))
BATIMENT0000000302929939;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;6.2;8.9;13.5;6.9;Cadastre;;POLYGON Z ((355493.2 6688393.6 8.9, 355493.4 6688391 8.9, 355493.5 6688390.5 8.9, 355491.8 6688390.4 8.9, 355491.7 6688391.6 8.9, 355490.9 6688391.5 8.9, 355490.2 6688397.1 8.9, 355491.2 6688397.2 8.9, 355491.1 6688398.4 8.9, 355492.7 6688398.6 8.9, 355493.2 6688393.6 8.9))
BATIMENT0000000302929945;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;6.5;9.0;10.0;6.8;Cadastre;;POLYGON Z ((355484 6688393.4 9, 355483.7 6688396.4 9, 355484.8 6688396.5 9, 355485.1 6688393.5 9, 355484 6688393.4 9))
BATIMENT0000000302929772;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;6.4;13.5;22.2;6.8;Cadastre;;POLYGON Z ((355325.4 6688373.4 13.5, 355324.5 6688384.9 13.5, 355326.4 6688385 13.5, 355327.3 6688373.6 13.5, 355325.4 6688373.4 13.5))
BATIMENT0000000302929773;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;6.4;11.5;15.2;6.7;Cadastre;;POLYGON Z ((355323 6688384 11.5, 355323.2 6688380.9 11.5, 355321 6688380.8 11.5, 355321 6688383.7 11.5, 355323 6688384 11.5))
BATIMENT0000000302929781;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;00;00;9.5;6.4;16.0;22.6;6.8;Cadastre;A 1.0;POLYGON Z ((355327.3 6688373.6 16, 355326.4 6688385 16, 355326.2 6688386.1 16, 355325.6 6688396.6 16, 355337.3 6688397.6 16, 355338.3 6688383.8 16, 355339.6 6688369.4 16, 355327.8 6688367.8 16, 355327.4 6688371.9 16, 355327.3 6688373.6 16), (355329.9 6688378.8 16, 355335.1 6688379.5 16, 355334.6 6688385.7 16, 355335.5 6688386 16, 355335.4 6688387.1 16, 355328.7 6688386.5 16, 355329.5 6688384.7 16, 355329.9 6688378.8 16))
BATIMENT0000000302929767;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;20;20;13.5;6.4;20.0;23.4;6.8;Cadastre;C 1.0;POLYGON Z ((355304.3 6688394.6 20, 355315 6688395.6 20, 355315.9 6688384.8 20, 355316.1 6688381.8 20, 355309.3 6688380.9 20, 355309 6688382.2 20, 355305 6688381.7 20, 355304.3 6688394.6 20))
BATIMENT0000000302929768;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.3;6.4;19.7;23.3;6.8;Cadastre;C 0.9;POLYGON Z ((355321 6688385.7 19.7, 355321 6688383.7 19.7, 355321 6688380.8 19.7, 355318.6 6688380.5 19.7, 355318.1 6688385.3 19.7, 355315.9 6688384.8 19.7, 355315 6688395.6 19.7, 355325.6 6688396.6 19.7, 355326.2 6688386.1 19.7, 355321 6688385.7 19.7))
BATIMENT0000000302929782;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;7.5;6.0;13.5;16.5;6.8;Cadastre;A 1.0;POLYGON Z ((355337.3 6688397.6 13.5, 355347.8 6688398.6 13.5, 355348.8 6688384.9 13.5, 355338.3 6688383.8 13.5, 355337.3 6688397.6 13.5))
BATIMENT0000000302929709;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;6.6;6.0;12.6;13.4;6.7;Cadastre;A 1.0;POLYGON Z ((355326 6688424.8 12.6, 355330.2 6688425.3 12.6, 355330.5 6688421.1 12.6, 355333.9 6688421.3 12.6, 355334.4 6688416.9 12.6, 355337.4 6688417.1 12.6, 355337.9 6688412.5 12.6, 355327.2 6688411.4 12.6, 355326 6688424.8 12.6))
BATIMENT0000000302929708;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;3.0;10;20;9.5;6.4;16.0;19.2;6.9;Cadastre;A 0.7;POLYGON Z ((355358.9 6688428 16, 355360.4 6688414.6 16, 355342.8 6688412.9 16, 355341.2 6688426.3 16, 355347.2 6688427 16, 355358.9 6688428 16))
BATIMENT0000000302930049;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;8.8;6.3;15.2;19.9;6.8;Cadastre;A 1.0;POLYGON Z ((355386.9 6688430.5 15.2, 355388 6688425.5 15.2, 355389.5 6688416.4 15.2, 355378.6 6688415.4 15.2, 355377.8 6688424.8 15.2, 355377.4 6688429.5 15.2, 355378.7 6688429.6 15.2, 355379.3 6688424.4 15.2, 355383.5 6688424.8 15.2, 355383.4 6688427.3 15.2, 355380.3 6688426.9 15.2, 355380 6688429.8 15.2, 355386.9 6688430.5 15.2))
BATIMENT0000000302930046;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;12;12;10.9;6.8;17.7;19.8;7.0;Cadastre;A 1.0;POLYGON Z ((355388 6688425.5 17.7, 355386.9 6688430.5 17.7, 355380 6688429.8 17.7, 355378.7 6688429.6 17.7, 355377.4 6688429.5 17.7, 355376.9 6688435.4 17.7, 355391 6688436.5 17.7, 355392.5 6688420.3 17.7, 355389.5 6688416.4 17.7, 355388 6688425.5 17.7))
BATIMENT0000000302929807;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;7.8;6.8;14.7;17.3;7.4;Cadastre;C 0.5;POLYGON Z ((355564.7 6688394.1 14.7, 355564.3 6688398.2 14.7, 355575 6688399 14.7, 355575.2 6688395 14.7, 355564.7 6688394.1 14.7))
BATIMENT0000000302929802;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;10;20;4.7;6.7;11.5;18.0;7.3;Cadastre;A 1.0;POLYGON Z ((355538.2 6688405 11.5, 355540.2 6688405.2 11.5, 355548 6688405.9 11.5, 355549.2 6688392.8 11.5, 355527.4 6688390.7 11.5, 355526.3 6688404 11.5, 355538.2 6688405 11.5), (355537.8 6688397.2 11.5, 355539.4 6688397.3 11.5, 355539.3 6688398.7 11.5, 355537.7 6688398.6 11.5, 355537.8 6688397.2 11.5))
BATIMENT0000000302929943;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;36.0;4.0;10;20;11.2;6.7;17.9;20.6;7.1;Cadastre;A 0.7;POLYGON Z ((355491.5 6688412 17.9, 355512.8 6688413.9 17.9, 355514.8 6688390.2 17.9, 355505.8 6688389.3 17.9, 355504.8 6688399.7 17.9, 355492.7 6688398.6 17.9, 355491.5 6688412 17.9))
BATIMENT0000000302929924;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;7.0;6.7;13.8;16.4;7.1;Cadastre;A 0.2;POLYGON Z ((355472.4 6688410.3 13.8, 355480 6688410.9 13.8, 355480.6 6688403.5 13.8, 355479.8 6688403.4 13.8, 355480 6688400.6 13.8, 355477 6688400.3 13.8, 355477.5 6688395.8 13.8, 355476.8 6688395.7 13.8, 355473.8 6688395.4 13.8, 355472.4 6688410.3 13.8))
BATIMENT0000000302929944;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;15;20;8.1;6.6;14.7;17.7;7.1;Cadastre;C 0.9;POLYGON Z ((355483.4 6688411.2 14.7, 355491.5 6688412 14.7, 355492.7 6688398.6 14.7, 355491.1 6688398.4 14.7, 355486.3 6688398 14.7, 355484.7 6688397.8 14.7, 355483.4 6688411.2 14.7))
BATIMENT0000000302929805;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;12;20;8.8;6.6;15.5;18.5;7.3;Cadastre;A 1.0;POLYGON Z ((355547.1 6688416.4 15.5, 355556.6 6688417.3 15.5, 355558.9 6688393.6 15.5, 355549.2 6688392.8 15.5, 355548 6688405.9 15.5, 355547.1 6688416.4 15.5), (355553.4 6688394.3 15.5, 355555 6688394.5 15.5, 355554.2 6688404.9 15.5, 355555.7 6688405.1 15.5, 355555.8 6688404 15.5, 355556.5 6688404.1 15.5, 355556.4 6688407 15.5, 355552.3 6688406.6 15.5, 355553.4 6688394.3 15.5))
BATIMENT0000000302929806;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;4.0;25;29;9.0;6.6;15.7;22.8;7.7;Cadastre;C 0.7;POLYGON Z ((355558.9 6688393.6 15.7, 355556.6 6688417.3 15.7, 355578.6 6688419.3 15.7, 355579.8 6688404.6 15.7, 355580.5 6688395.4 15.7, 355576.3 6688395.1 15.7, 355575.5 6688404.4 15.7, 355576.3 6688405.2 15.7, 355577.7 6688405.4 15.7, 355577.4 6688407.3 15.7, 355560.1 6688405.6 15.7, 355560.5 6688403.8 15.7, 355561.7 6688403.9 15.7, 355562.8 6688402.8 15.7, 355563.5 6688394 15.7, 355558.9 6688393.6 15.7))
BATIMENT0000000302929804;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;;;7.8;6.2;14.0;17.6;7.0;Cadastre;A 1.0;POLYGON Z ((355525.4 6688414.5 14, 355537.2 6688415.6 14, 355537.9 6688408.5 14, 355538.2 6688405 14, 355526.3 6688404 14, 355525.4 6688414.5 14))
BATIMENT0000000302929803;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;3.8;6.7;10.5;13.2;7.0;Cadastre;A 1.0;POLYGON Z ((355539.9 6688408.7 10.5, 355537.9 6688408.5 10.5, 355537.2 6688415.6 10.5, 355547.1 6688416.4 10.5, 355548 6688405.9 10.5, 355540.2 6688405.2 10.5, 355539.9 6688408.7 10.5))
BATIMENT0000000302930193;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;6.8;15.9;18.6;7.2;Cadastre;;POLYGON Z ((355479.9 6688430.1 15.9, 355480.4 6688425.1 15.9, 355475.5 6688424.7 15.9, 355473.6 6688424.6 15.9, 355473.1 6688429.5 15.9, 355479.9 6688430.1 15.9))
BATIMENT0000000302929934;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;6.9;15.2;18.0;7.1;Cadastre;;POLYGON Z ((355422.5 6688394.8 15.2, 355422.1 6688398.7 15.2, 355423.2 6688398.8 15.2, 355423.5 6688395 15.2, 355422.5 6688394.8 15.2))
BATIMENT0000000302929933;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;20;20;7.6;6.6;14.2;20.5;7.1;Cadastre;A 1.0;POLYGON Z ((355414.4 6688390.2 14.2, 355413.3 6688401.3 14.2, 355416.8 6688405.4 14.2, 355427.6 6688406.3 14.2, 355428.1 6688401.9 14.2, 355425.8 6688401.6 14.2, 355425.9 6688400.8 14.2, 355422 6688400.5 14.2, 355422.1 6688398.7 14.2, 355422.5 6688394.8 14.2, 355422.8 6688391 14.2, 355414.4 6688390.2 14.2))
BATIMENT0000000302929928;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;11.8;6.6;18.4;20.6;7.0;Cadastre;A 1.0;POLYGON Z ((355428.1 6688401.9 18.4, 355427.6 6688406.3 18.4, 355434.9 6688406.9 18.4, 355436.3 6688392.6 18.4, 355436.3 6688392.3 18.4, 355432.2 6688391.9 18.4, 355431.4 6688391.8 18.4, 355430.3 6688391.7 18.4, 355429 6688391.6 18.4, 355428.1 6688401.9 18.4))
BATIMENT0000000302929922;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;20;20;9.3;6.6;15.9;18.2;7.2;Cadastre;C 1.0;POLYGON Z ((355450.1 6688408.3 15.9, 355472.4 6688410.3 15.9, 355473.8 6688395.4 15.9, 355474.2 6688391.7 15.9, 355471.6 6688391.5 15.9, 355470.6 6688400.6 15.9, 355451 6688398.4 15.9, 355450.1 6688408.3 15.9))
BATIMENT0000000302929630;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.9;6.0;12.9;15.2;7.0;Cadastre;A 1.0;POLYGON Z ((355426.1 6688430.5 12.9, 355430.2 6688430.9 12.9, 355430.8 6688420.6 12.9, 355427 6688420.3 12.9, 355426.1 6688430.5 12.9))
BATIMENT0000000302929631;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;7.8;6.0;13.8;18.2;6.9;Cadastre;A 1.0;POLYGON Z ((355430.2 6688430.9 13.8, 355430.5 6688431.3 13.8, 355440.6 6688432.2 13.8, 355441.6 6688421.6 13.8, 355430.8 6688420.6 13.8, 355430.2 6688430.9 13.8))
BATIMENT0000000302929625;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;5.3;11.4;13.7;6.9;Cadastre;;POLYGON Z ((355458.3 6688423.9 11.4, 355458.8 6688424 11.4, 355458.1 6688430.5 11.4, 355459 6688430.5 11.4, 355459.1 6688429.7 11.4, 355462 6688430 11.4, 355461.8 6688430.8 11.4, 355462.5 6688430.8 11.4, 355463.2 6688423.5 11.4, 355458.4 6688423.1 11.4, 355458.3 6688423.9 11.4))
BATIMENT0000000302929626;Industriel, agricole ou commercial;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;5.9;5.3;11.2;13.6;7.0;Cadastre;A 1.0;POLYGON Z ((355446.3 6688428.8 11.2, 355447.1 6688428.9 11.2, 355446.2 6688440.9 11.2, 355461.4 6688442.4 11.2, 355462.5 6688430.8 11.2, 355461.8 6688430.8 11.2, 355462 6688430 11.2, 355459.1 6688429.7 11.2, 355459 6688430.5 11.2, 355458.1 6688430.5 11.2, 355458.8 6688424 11.2, 355458.3 6688423.9 11.2, 355458.4 6688423.1 11.2, 355446.6 6688422 11.2, 355446.3 6688428.8 11.2))
BATIMENT0000000302929629;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;00;00;5.7;5.5;11.2;21.0;7.0;Cadastre;A 1.0;POLYGON Z ((355410.1 6688445.9 11.2, 355424.6 6688447 11.2, 355425.7 6688435 11.2, 355426.1 6688430.5 11.2, 355427 6688420.3 11.2, 355419.1 6688419.5 11.2, 355416.8 6688419.3 11.2, 355412.2 6688423 11.2, 355410.1 6688445.9 11.2), (355418.9 6688426.7 11.2, 355421.6 6688427 11.2, 355421.4 6688428.1 11.2, 355424.3 6688428.5 11.2, 355424 6688432.6 11.2, 355418.9 6688426.7 11.2))
BATIMENT0000000302929617;Industriel, agricole ou commercial;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;;;8.5;6.6;15.1;16.9;7.4;Cadastre;A 1.0;POLYGON Z ((355462.5 6688430.8 15.1, 355461.4 6688442.4 15.1, 355461.3 6688444.2 15.1, 355471.6 6688444.9 15.1, 355473.1 6688429.5 15.1, 355473.6 6688424.6 15.1, 355463.2 6688423.5 15.1, 355462.5 6688430.8 15.1))
BATIMENT0000000302929863;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;12;20;7.7;6.2;13.9;18.5;6.9;Cadastre;A 1.0;POLYGON Z ((355558 6688442 13.9, 355564.1 6688442.5 13.9, 355565.1 6688432.8 13.9, 355559.1 6688432.2 13.9, 355558 6688442 13.9))
BATIMENT0000000302929861;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;20;12.7;6.2;19.0;22.1;6.9;Cadastre;A 1.0;POLYGON Z ((355540.6 6688444.9 19, 355543.7 6688445.2 19, 355544.1 6688440.7 19, 355549.6 6688441.4 19, 355558 6688442 19, 355559.1 6688432.2 19, 355542.1 6688430.6 19, 355540.6 6688444.9 19))
BATIMENT0000000302929858;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;10;10.5;6.0;16.5;22.1;7.0;Cadastre;A 1.0;POLYGON Z ((355537 6688452 16.5, 355538.2 6688452.1 16.5, 355539.8 6688452.3 16.5, 355540.6 6688444.9 16.5, 355542.1 6688430.6 16.5, 355526.1 6688429.1 16.5, 355524.7 6688444.2 16.5, 355530.8 6688444.9 16.5, 355531.1 6688443.1 16.5, 355531.8 6688443.1 16.5, 355534.4 6688443.2 16.5, 355534.5 6688442.5 16.5, 355536.1 6688442.7 16.5, 355535.3 6688450.4 16.5, 355535.2 6688451.8 16.5, 355537 6688452 16.5))
BATIMENT0000000302929616;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;6.9;13.0;18.0;7.3;Cadastre;;POLYGON Z ((355480.6 6688438.6 13, 355480.3 6688441.8 13, 355495.1 6688443 13, 355495.3 6688439.9 13, 355480.6 6688438.6 13))
BATIMENT0000000302929857;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.9;6.1;16.0;17.7;6.7;Cadastre;;POLYGON Z ((355530.3 6688451.3 16, 355535.2 6688451.8 16, 355535.3 6688450.4 16, 355534.2 6688449.4 16, 355532.8 6688449.3 16, 355533.2 6688445.3 16, 355531.8 6688443.1 16, 355531.1 6688443.1 16, 355530.8 6688444.9 16, 355530.3 6688451.3 16))
BATIMENT0000000302930194;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;60.0;6.0;34;10;13.0;6.0;19.0;24.1;7.3;Cadastre;C 0.6;POLYGON Z ((355497.5 6688472.5 19, 355506.5 6688470.4 19, 355506 6688468.4 19, 355508.6 6688467.9 19, 355507.9 6688465.5 19, 355508.8 6688465.3 19, 355509.8 6688453.4 19, 355510.5 6688446.1 19, 355511.4 6688434.7 19, 355511.7 6688431.5 19, 355510.3 6688431.6 19, 355510.4 6688431.4 19, 355510.4 6688431.2 19, 355510.4 6688431.1 19, 355510.4 6688431 19, 355510.4 6688430.7 19, 355510.3 6688430.6 19, 355510.2 6688430.3 19, 355510.1 6688430 19, 355510 6688429.8 19, 355509.9 6688429.7 19, 355509.8 6688429.6 19, 355509.6 6688429.4 19, 355509.5 6688429.3 19, 355509.3 6688429.2 19, 355509.2 6688429.2 19, 355509 6688429.1 19, 355508.8 6688429 19, 355508.5 6688428.9 19, 355508.2 6688428.9 19, 355508 6688429 19, 355508.2 6688427.6 19, 355482.6 6688425.3 19, 355480.4 6688425.1 19, 355479.9 6688430.1 19, 355479.7 6688431.6 19, 355481.1 6688433.1 19, 355480.6 6688438.6 19, 355495.3 6688439.9 19, 355499.1 6688440.2 19, 355498.8 6688445 19, 355497.7 6688459.2 19, 355485.1 6688462.1 19, 355485.3 6688463.4 19, 355478.6 6688464.8 19, 355477.6 6688477 19, 355497.5 6688472.5 19))
BATIMENT0000000302929867;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;45;20;9.0;5.9;15.0;21.8;6.8;Cadastre;A 0.7;POLYGON Z ((355557.7 6688444.6 15, 355557.2 6688449.9 15, 355556.5 6688455.8 15, 355557.3 6688459 15, 355583.3 6688453 15, 355582.3 6688444.2 15, 355579 6688443.9 15, 355578.9 6688445 15, 355563.8 6688448.3 15, 355564 6688445 15, 355557.7 6688444.6 15))
BATIMENT0000000302929860;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.9;6.1;15.0;16.0;6.7;Cadastre;;POLYGON Z ((355536.9 6688452.9 15, 355538.1 6688453 15, 355538.2 6688452.1 15, 355537 6688452 15, 355536.9 6688452.9 15))
BATIMENT0000000302929859;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.3;6.1;20.5;25.0;6.7;Cadastre;A 0.3;POLYGON Z ((355530.8 6688444.9 20.5, 355524.7 6688444.2 20.5, 355522.7 6688465.3 20.5, 355524.3 6688466.6 20.5, 355538.6 6688463.3 20.5, 355539.6 6688453.9 20.5, 355529.8 6688456.2 20.5, 355530.3 6688451.3 20.5, 355530.8 6688444.9 20.5))
BATIMENT0000000302929862;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;35;40;11.2;6.0;17.2;19.6;6.6;Cadastre;A 1.0;POLYGON Z ((355539.6 6688453.9 17.2, 355538.6 6688463.3 17.2, 355557.3 6688459 17.2, 355556.5 6688455.8 17.2, 355557.2 6688449.9 17.2, 355539.6 6688453.9 17.2))
BATIMENT0000000302930047;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;00;00;11.5;6.8;18.3;18.5;7.2;Cadastre;C 0.6;POLYGON Z ((355369.5 6688414.5 18.3, 355366.6 6688448.6 18.3, 355375.8 6688449.2 18.3, 355375.9 6688448.3 18.3, 355376.3 6688443.4 18.3, 355376.3 6688443 18.3, 355372.6 6688442.7 18.3, 355373.2 6688435.1 18.3, 355375.4 6688435.3 18.3, 355375.9 6688429.1 18.3, 355373.8 6688428.9 18.3, 355374.1 6688424.5 18.3, 355377.8 6688424.8 18.3, 355378.6 6688415.4 18.3, 355369.5 6688414.5 18.3))
BATIMENT0000000302929701;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;5.3;12.9;13.5;7.0;Cadastre;;POLYGON Z ((355336.6 6688425.8 12.9, 355330.2 6688425.3 12.9, 355326 6688424.8 12.9, 355325.8 6688427.7 12.9, 355324.9 6688436.9 12.9, 355345.8 6688439.6 12.9, 355347.2 6688427 12.9, 355341.2 6688426.3 12.9, 355336.6 6688425.8 12.9))
BATIMENT0000000302929699;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;19.8;6.3;26.2;28.5;6.9;Cadastre;A 1.0;POLYGON Z ((355300.6 6688426.1 26.2, 355299.8 6688434.5 26.2, 355299.1 6688441.5 26.2, 355298.9 6688443.9 26.2, 355324.1 6688446.3 26.2, 355324.9 6688436.9 26.2, 355325.8 6688427.7 26.2, 355300.6 6688426.1 26.2))
BATIMENT0000000302930045;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;00;00;11.0;6.7;17.7;20.6;6.8;Cadastre;A 1.0;POLYGON Z ((355376.5 6688440.4 17.7, 355390.5 6688442 17.7, 355391 6688436.5 17.7, 355376.9 6688435.4 17.7, 355376.5 6688440.4 17.7))
BATIMENT0000000302930048;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;15;20;15.6;6.6;22.2;23.2;7.2;Cadastre;A 1.0;POLYGON Z ((355375.8 6688449.2 22.2, 355375.7 6688450.9 22.2, 355389.6 6688452.2 22.2, 355390.5 6688442 22.2, 355376.5 6688440.4 22.2, 355376.3 6688443 22.2, 355376.3 6688443.4 22.2, 355380.9 6688443.9 22.2, 355381.5 6688442.6 22.2, 355382.1 6688442.6 22.2, 355381.7 6688450.1 22.2, 355380.9 6688450 22.2, 355380.7 6688448.8 22.2, 355375.9 6688448.3 22.2, 355375.8 6688449.2 22.2))
BATIMENT0000000302930050;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;30;40;15.7;6.7;22.5;22.7;7.3;Cadastre;A 1.0;POLYGON Z ((355374.8 6688461.2 22.5, 355388.7 6688462.2 22.5, 355389.6 6688452.2 22.5, 355375.7 6688450.9 22.5, 355375.5 6688453.1 22.5, 355379.9 6688453.9 22.5, 355380.2 6688452.7 22.5, 355381.1 6688452.8 22.5, 355380.6 6688460 22.5, 355379.3 6688459.9 22.5, 355378.8 6688458.8 22.5, 355376.9 6688458.8 22.5, 355377.2 6688455.8 22.5, 355375.3 6688455.7 22.5, 355374.8 6688461.2 22.5))
BATIMENT0000000302930055;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;13.1;6.8;20.0;22.2;7.4;Cadastre;A 1.0;POLYGON Z ((355373.9 6688472.3 20, 355379.1 6688473 20, 355387.6 6688473.9 20, 355388.7 6688462.2 20, 355374.8 6688461.2 20, 355374.3 6688467.7 20, 355375.8 6688467.8 20, 355377.8 6688468.1 20, 355377.8 6688469.1 20, 355377.7 6688471 20, 355375.8 6688471 20, 355375.9 6688469.8 20, 355374.1 6688469.7 20, 355373.9 6688472.3 20))
BATIMENT0000000302930056;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;6.8;12.7;14.5;7.3;Cadastre;;POLYGON Z ((355377.8 6688469.1 12.7, 355377.8 6688468.1 12.7, 355375.8 6688467.8 12.7, 355375.5 6688469.1 12.7, 355377.8 6688469.1 12.7))
BATIMENT0000000302930051;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.2;6.6;21.9;26.9;7.4;Cadastre;;POLYGON Z ((355362 6688483.3 21.9, 355364.9 6688448.5 21.9, 355363.2 6688448.4 21.9, 355363 6688449.9 21.9, 355353.8 6688449.1 21.9, 355353.1 6688456.9 21.9, 355354.1 6688457 21.9, 355353.8 6688461.2 21.9, 355352.8 6688461.1 21.9, 355349.7 6688498.4 21.9, 355364.9 6688499.7 21.9, 355365.1 6688496.7 21.9, 355371.9 6688497.3 21.9, 355372.5 6688489.7 21.9, 355372.6 6688487.9 21.9, 355372.8 6688485.6 21.9, 355372.9 6688484.2 21.9, 355362 6688483.3 21.9))
BATIMENT0000000302930054;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.4;6.5;16.9;20.9;7.1;Cadastre;;POLYGON Z ((355364.8 6688500.7 16.9, 355364.9 6688499.7 16.9, 355349.7 6688498.4 16.9, 355352.8 6688461.1 16.9, 355353.8 6688461.2 16.9, 355354.1 6688457 16.9, 355353.1 6688456.9 16.9, 355353.8 6688449.1 16.9, 355363 6688449.9 16.9, 355363.2 6688448.4 16.9, 355352.9 6688447.6 16.9, 355348.6 6688499.4 16.9, 355364.8 6688500.7 16.9))
BATIMENT0000000327814875;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2007-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;19.9;6.0;;27.1;6.5;Imagerie aérienne;C 0.2;POLYGON Z ((354750.2333218027 6688312.003221275 25.812169495195718, 354734.0200094615 6688312.003221275 25.9, 354729.6 6688330.5 25.9, 354744.7 6688334.4 25.9, 354750.2333218027 6688312.003221275 25.812169495195718))
BATIMENT0000000327814969;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2000-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;15.4;6.3;;22.7;6.8;Imagerie aérienne;A 1.0;POLYGON Z ((354792.4 6688339.2 21.7, 354793.6 6688338.4 21.7, 354795.4 6688336.7 21.7, 354796.8 6688333.9 21.7, 354797.8 6688331 21.7, 354798.3 6688328.9 21.7, 354798.5 6688324.7 21.7, 354798.4 6688321.3 21.7, 354797.9 6688317.2 21.7, 354796.6 6688312.5 21.7, 354796.39300886466 6688312.003221275 21.7, 354788.66931639006 6688312.003221275 21.7, 354784.7 6688315.5 21.7, 354781.6 6688319.1 21.7, 354778.3 6688323.8 21.7, 354776.7 6688327.4 21.7, 354776.7 6688330.2 21.7, 354777.2 6688332.8 21.7, 354778.6 6688335.6 21.7, 354780.2 6688337.5 21.7, 354782.6 6688339 21.7, 354785 6688339.9 21.7, 354786.8 6688340.2 21.7, 354788.3 6688340.3 21.7, 354790.7 6688340 21.7, 354792.4 6688339.2 21.7))
BATIMENT0000000302923557;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.8;6.6;12.4;16.0;6.8;Cadastre;B 0.2;POLYGON Z ((354726.9 6688419.6 12.4, 354735.9 6688420.2 12.4, 354736.6 6688415.8 12.4, 354739.7 6688416.1 12.4, 354743.2 6688386.6 12.4, 354741.5 6688386.5 12.4, 354721.6 6688422.7 12.4, 354724.4 6688424.1 12.4, 354726.9 6688419.6 12.4))
BATIMENT0000000327814877;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;8.0;;;28.5;5.1;;35.7;6.6;Imagerie aérienne;C 0.5;POLYGON Z ((354736 6688447.1 33.6, 354710.7 6688444.8 33.6, 354704.3 6688455.3 33.6, 354706 6688459.4 33.6, 354715.2 6688461.8 33.6, 354734.7 6688462.9 33.5, 354736 6688447.1 33.6))
BATIMENT0000000327814874;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:27;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;20.4;5.7;;28.0;6.5;Imagerie aérienne;;POLYGON Z ((354760.9 6688449.1 26.1, 354736 6688447.1 26.1, 354734.7 6688462.9 26.1, 354734.7 6688463.2 26.1, 354759.8 6688465.5 26, 354760.9 6688449.1 26.1))
BATIMENT0000000302923153;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;14.2;6.0;20.2;24.2;6.4;Cadastre;A 1.0;POLYGON Z ((354721.9 6688486.6 20.2, 354720.5 6688489.2 20.2, 354725.8 6688492.3 20.2, 354726.8 6688493 20.2, 354728 6688490.8 20.2, 354729.5 6688488.6 20.2, 354730 6688488.8 20.2, 354731.8 6688489.3 20.2, 354730.2 6688492.1 20.2, 354730 6688492.5 20.2, 354729.5 6688494.5 20.2, 354736.3 6688498.6 20.2, 354744.3 6688484.3 20.2, 354742.4 6688480.8 20.2, 354727.2 6688476.7 20.2, 354721.9 6688486.6 20.2))
BATIMENT0000000302923154;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;6.1;15.7;18.2;6.4;Cadastre;;POLYGON Z ((354726.8 6688493 15.7, 354727.4 6688493.4 15.7, 354728.3 6688493.8 15.7, 354729.5 6688494.5 15.7, 354730 6688492.5 15.7, 354730.2 6688492.1 15.7, 354728 6688490.8 15.7, 354726.8 6688493 15.7))
BATIMENT0000002244337835;Indifférenciée;Indifférencié;;Non;En service;2021-06-09 10:33:21;2023-01-31 17:40:48;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;13.9;6.2;20.2;29.8;6.6;Cadastre;;POLYGON Z ((354789.6 6688488.7 20.2, 354759.3 6688486.5 20.2, 354751.3 6688500.8 20.2, 354788.5 6688503.5 20.2, 354789.6 6688488.7 20.2))
BATIMENT0000000302923155;Industriel, agricole ou commercial;Industriel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.0;6.0;17.0;19.9;6.6;Cadastre;A 1.0;POLYGON Z ((354701.5 6688513.9 17, 354721.6 6688524.7 17, 354736.3 6688498.6 17, 354729.5 6688494.5 17, 354728.3 6688493.8 17, 354727.4 6688493.4 17, 354726.8 6688493 17, 354725.8 6688492.3 17, 354720.5 6688489.2 17, 354719.6 6688490.6 17, 354717.3 6688489.2 17, 354716.1 6688488.4 17, 354701.5 6688513.9 17))
BATIMENT0000002244337836;Indifférenciée;Indifférencié;;Oui;En service;2021-06-09 10:33:21;2023-01-31 17:40:48;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;13.2;6.2;19.5;22.0;6.4;Cadastre;;POLYGON Z ((354775.5 6688521 19.5, 354776.7 6688505 19.5, 354788.3 6688505.9 19.5, 354788.5 6688503.5 19.5, 354774.8 6688502.5 19.5, 354773.4 6688520.8 19.5, 354775.5 6688521 19.5))
BATIMENT0000000302923132;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.4;6.0;19.5;24.2;6.5;Cadastre;C 0.4;POLYGON Z ((354645 6688417.2 19.5, 354691.9 6688429.2 19.5, 354695.3 6688414.5 19.5, 354701.4 6688415.9 19.5, 354702.9 6688409.7 19.5, 354704.3 6688410 19.5, 354705.9 6688403.4 19.5, 354707.6 6688403.8 19.5, 354710 6688393.9 19.5, 354713.3 6688394.7 19.5, 354714.8 6688388.6 19.5, 354716.3 6688388.9 19.5, 354717.8 6688382.7 19.5, 354719.3 6688383 19.5, 354720.8 6688376.8 19.5, 354722.2 6688377.1 19.5, 354723.8 6688370.6 19.5, 354725.3 6688370.9 19.5, 354727 6688364.2 19.5, 354717.8 6688361.9 19.5, 354729.509988598 6688312.003221275 19.5, 354669.45427180803 6688312.003221275 19.5, 354645 6688417.2 19.5))
BATIMENT0000000302923133;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.0;12.2;16.0;6.2;Cadastre;;POLYGON Z ((354664.3 6688441.8 12.2, 354668.8 6688424 12.2, 354661.7 6688422.2 12.2, 354657.1 6688439.9 12.2, 354664.3 6688441.8 12.2))
BATIMENT0000000302923157;Industriel, agricole ou commercial;Industriel;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.6;6.0;12.6;13.8;6.8;Cadastre;;POLYGON Z ((354679.9 6688499.1 12.6, 354699.5 6688510.2 12.6, 354712.5 6688486.8 12.6, 354716.3 6688479.6 12.6, 354717.1 6688478.4 12.6, 354712.7 6688475.8 12.6, 354708.8 6688473.3 12.6, 354707.9 6688474.7 12.6, 354697.2 6688468.6 12.6, 354679.9 6688499.1 12.6))
BATIMENT0000000302923139;Industriel, agricole ou commercial;Commercial et services;;Oui;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.9;6.3;14.2;16.6;6.6;Cadastre;B 1.0;POLYGON Z ((354669.8 6688519.7 14.2, 354677.9 6688524.4 14.2, 354683.4 6688527.7 14.2, 354685.2 6688528.7 14.2, 354689.3 6688531 14.2, 354712.5 6688543.7 14.2, 354719.9 6688530.4 14.2, 354689.1 6688514 14.2, 354676.8 6688507.4 14.2, 354669.8 6688519.7 14.2))
BATIMENT0000000302923135;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;10.5;6.2;16.7;20.0;6.5;Cadastre;A 1.0;POLYGON Z ((354669.8 6688519.7 16.7, 354664.6 6688529 16.7, 354676.4 6688535.4 16.7, 354680.2 6688528.6 16.7, 354676.5 6688526.6 16.7, 354677.9 6688524.4 16.7, 354669.8 6688519.7 16.7))
BATIMENT0000000302923137;Industriel, agricole ou commercial;Industriel;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;6.0;10.9;15.4;6.6;Cadastre;;POLYGON Z ((354684.6 6688539.7 10.9, 354686.6 6688535.9 10.9, 354689.3 6688531 10.9, 354685.2 6688528.7 10.9, 354683.4 6688527.7 10.9, 354678.8 6688536.8 10.9, 354680.5 6688537.6 10.9, 354684.6 6688539.7 10.9))
BATIMENT0000000302923136;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;;;7.3;6.2;13.5;18.3;6.6;Cadastre;A 1.0;POLYGON Z ((354659.1 6688538.6 13.5, 354660.4 6688542 13.5, 354671.5 6688548 13.5, 354678 6688536.3 13.5, 354676.4 6688535.4 13.5, 354664.6 6688529 13.5, 354659.1 6688538.6 13.5))
BATIMENT0000000302923570;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.0;6.4;15.5;18.5;6.6;Cadastre;C 0.4;POLYGON Z ((354692.5 6688539.2 15.5, 354690.5 6688542.8 15.5, 354707.6 6688552.4 15.5, 354712.5 6688543.7 15.5, 354689.3 6688531 15.5, 354686.6 6688535.9 15.5, 354692.5 6688539.2 15.5))
BATIMENT0000000302923134;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;20;20;12.2;6.3;18.5;22.0;6.5;Cadastre;A 1.0;POLYGON Z ((354680.5 6688537.6 18.5, 354678.8 6688536.8 18.5, 354678 6688536.3 18.5, 354671.5 6688548 18.5, 354683.8 6688554.7 18.5, 354689.5 6688545.1 18.5, 354683.3 6688542.2 18.5, 354684.6 6688539.7 18.5, 354680.5 6688537.6 18.5))
BATIMENT0000000302923571;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;9.4;6.3;15.8;21.1;6.6;Cadastre;C 0.5;POLYGON Z ((354692.6 6688559.5 15.8, 354698.9 6688562.9 15.8, 354701.9 6688562.4 15.8, 354707.6 6688552.4 15.8, 354690.5 6688542.8 15.8, 354689.5 6688545.1 15.8, 354683.8 6688554.7 15.8, 354692.6 6688559.5 15.8))
BATIMENT0000000327814967;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;8.3;6.5;;15.1;6.9;Imagerie aérienne;A 1.0;POLYGON Z ((354560.3 6688314.9 10.8, 354584 6688320.8 9.1, 354585.9632295866 6688312.003221275 9.590807396651371, 354546.55450095306 6688312.003221275 11.19759707986963, 354560.3 6688314.9 10.8))
BATIMENT0000000302923159;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.7;6.0;17.7;24.3;6.6;Cadastre;;POLYGON Z ((354534.3 6688360.8 17.7, 354617.6 6688407.1 17.7, 354626.8 6688390.2 17.7, 354543.4 6688344.2 17.7, 354534.3 6688360.8 17.7))
BATIMENT0000000302923061;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;12;20;19.8;6.8;26.6;28.2;9.2;Cadastre;A 1.0;POLYGON Z ((354567 6688802.3 26.6, 354569 6688795.1 26.6, 354571.9 6688787.6 26.6, 354563.3 6688784.3 26.6, 354559.4 6688800.3 26.6, 354567 6688802.3 26.6))
BATIMENT0000000302923060;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;18.8;8.0;26.8;28.0;9.3;Cadastre;A 1.0;POLYGON Z ((354546.1 6688797.2 26.8, 354545.4 6688800.5 26.8, 354550.6 6688802.5 26.8, 354549.6 6688807.5 26.8, 354557.4 6688808.8 26.8, 354559.4 6688800.3 26.8, 354563.3 6688784.3 26.8, 354551.1 6688779.9 26.8, 354547.2 6688793.5 26.8, 354546.1 6688797.2 26.8), (354552.2 6688791.9 26.8, 354555.5 6688792.8 26.8, 354554.4 6688797.8 26.8, 354550.9 6688796.9 26.8, 354551.7 6688793.7 26.8, 354552.2 6688791.9 26.8))
BATIMENT0000000302923526;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;21.9;6.7;28.6;32.5;7.2;Cadastre;B 0.4;POLYGON Z ((354601.4 6688805.3 28.6, 354600.3 6688808.1 28.6, 354602.4 6688808.9 28.6, 354605.6 6688800.4 28.6, 354605.6 6688800.3 28.6, 354600.1 6688798.3 28.6, 354598.1 6688804 28.6, 354598.5 6688804.3 28.6, 354601.4 6688805.3 28.6))
BATIMENT0000000302923065;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;20.6;6.5;27.1;31.5;7.9;Cadastre;A 1.0;POLYGON Z ((354581.4 6688821.1 27.1, 354582 6688819.7 27.1, 354583.6 6688815.7 27.1, 354581.4 6688814.8 27.1, 354583.3 6688810.2 27.1, 354585.4 6688811.1 27.1, 354591.8 6688795.2 27.1, 354584.5 6688792.5 27.1, 354575.9 6688819.6 27.1, 354581.4 6688821.1 27.1))
BATIMENT0000000302923527;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;10;20;21.8;6.7;28.5;32.6;7.0;Cadastre;B 0.5;POLYGON Z ((354606.1 6688810.3 28.5, 354605.6 6688811.5 28.5, 354617.1 6688815.7 28.5, 354617.5 6688814.5 28.5, 354623.2 6688816.7 28.5, 354624.3 6688813.6 28.5, 354626.9 6688814.6 28.5, 354629.1 6688809.2 28.5, 354605.6 6688800.3 28.5, 354605.6 6688800.4 28.5, 354602.4 6688808.9 28.5, 354606.1 6688810.3 28.5))
BATIMENT0000000302923525;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;10;20;20.4;7.8;28.2;32.4;7.9;Cadastre;A 1.0;POLYGON Z ((354587.4 6688821.1 28.2, 354587.3 6688821.8 28.2, 354590.7 6688823.3 28.2, 354598.5 6688804.3 28.2, 354598.1 6688804 28.2, 354600.1 6688798.3 28.2, 354591.8 6688795.2 28.2, 354585.4 6688811.1 28.2, 354583.6 6688815.7 28.2, 354582 6688819.7 28.2, 354587.4 6688821.1 28.2))
BATIMENT0000000302923063;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;10;20;20.5;6.5;27.0;30.1;10.1;Cadastre;A 1.0;POLYGON Z ((354573.5 6688788.3 27, 354570.2 6688796.3 27, 354568.8 6688803.1 27, 354574.2 6688805.3 27, 354572.8 6688807.8 27, 354570.9 6688814.3 27, 354566.6 6688813 27, 354563.4 6688827 27, 354562.5 6688830.3 27, 354571.7 6688832.6 27, 354575.4 6688819.3 27, 354575.9 6688819.6 27, 354584.5 6688792.5 27, 354573.5 6688788.3 27))
BATIMENT0000000302923072;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;2.0;00;00;5.8;7.9;13.7;;;Cadastre;A 1.0;POLYGON Z ((354597 6688827.1 13.7, 354605.2 6688830.1 13.7, 354604.6 6688831.8 13.7, 354613.8 6688835.4 13.7, 354617.9 6688824.7 13.7, 354606 6688820.1 13.7, 354607.1 6688817 13.7, 354601.5 6688814.9 13.7, 354597 6688827.1 13.7))
BATIMENT0000002244337837;Indifférenciée;Indifférencié;;Non;En service;2021-06-09 10:33:21;2023-01-31 17:40:48;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;15.5;6.2;21.7;22.2;6.4;Cadastre;;POLYGON Z ((354787.1 6688521.8 21.7, 354788.3 6688505.9 21.7, 354776.7 6688505 21.7, 354775.5 6688521 21.7, 354787.1 6688521.8 21.7))
BATIMENT0000000327814966;Industriel, agricole ou commercial;Industriel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;3.3;6.0;;11.1;6.7;Imagerie aérienne;C 0.3;POLYGON Z ((354764 6688526.1 9.3, 354742.3 6688524.2 9.3, 354741.1 6688539.8 9.3, 354733.9 6688539.4 9.3, 354732.7 6688554.6 9.3, 354741.4 6688555.7 9.3, 354741.2 6688562.5 9.3, 354726.3 6688554.5 9.3, 354722.3 6688552.4 9.3, 354719.2 6688557.9 9.3, 354727.1 6688562.3 9.3, 354732 6688564.9 9.3, 354744.1 6688572.4 9.3, 354764.9 6688566.5 9.3, 354765.6 6688559.1 9.3, 354783.4 6688560.6 9.3, 354788.8 6688559 9.3, 354839.5 6688566.1 9.3, 354842.7 6688532.9 9.3, 354833.3 6688532 9.3, 354828.5 6688531.5 9.3, 354794.8 6688528.3 9.3, 354792.9 6688528.1 9.3, 354764 6688526.1 9.3))
BATIMENT0000000302923349;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;2.9;6.3;9.3;9.6;6.6;Cadastre;C 0.2;POLYGON Z ((354721.9 6688552.1 9.3, 354722.3 6688552.4 9.3, 354726.3 6688554.5 9.3, 354729.1 6688549.3 9.3, 354723.5 6688549.2 9.3, 354721.9 6688552.1 9.3))
BATIMENT0000000302923090;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;20;20;10.7;6.0;16.7;19.6;6.9;Cadastre;A 0.6;POLYGON Z ((354719.2 6688557.9 16.7, 354717.6 6688557.1 16.7, 354710.8 6688569.8 16.7, 354725.4 6688577.6 16.7, 354726.9 6688570.1 16.7, 354724 6688568.5 16.7, 354727.1 6688562.3 16.7, 354719.2 6688557.9 16.7))
BATIMENT0000000302923089;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;6.4;10.9;14.5;6.6;Cadastre;;POLYGON Z ((354734.1 6688575 10.9, 354732 6688564.9 10.9, 354727.1 6688562.3 10.9, 354724 6688568.5 10.9, 354726.9 6688570.1 10.9, 354725.4 6688577.6 10.9, 354734.1 6688575 10.9))
BATIMENT0000000291500046;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;28.0;8.0;00;00;26.1;6.0;;32.1;6.4;Imagerie aérienne;C 0.1;POLYGON Z ((354785.9 6688583.8 31.8, 354789.7 6688582.8 31.8, 354786.7 6688573.6 31.8, 354786.4 6688570.5 27.7, 354770.2 6688575.3 27.7, 354770.6 6688577.7 32.1, 354772.1 6688582.4 32, 354773.5 6688587 32, 354785.9 6688583.8 31.8))
BATIMENT0000000327814963;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2010-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;30;30;8.8;6.4;;31.5;6.4;Imagerie aérienne;C 0.5;POLYGON Z ((354773.5 6688587 15.2, 354772.1 6688582.4 15.2, 354769.7 6688591.5 15.2, 354774.3 6688593.2 15.2, 354782 6688595.4 15.2, 354785.9 6688583.8 15.2, 354773.5 6688587 15.2))
BATIMENT0000000291500043;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;20.0;8.0;00;00;25.7;6.6;;;;Imagerie aérienne;C 0.1;POLYGON Z ((354784.2 6688596 32.3, 354782 6688595.4 32.3, 354774.3 6688593.2 32.3, 354769.7 6688591.5 29.2, 354767.1 6688590.6 27.5, 354763.2 6688603.7 27.5, 354765.2 6688604.3 28.6, 354770.4 6688605.8 31.7, 354778.7 6688608.1 31.6, 354779.8 6688608.4 31.6, 354784.2 6688596 32.3))
BATIMENT0000000302923151;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;18.4;5.8;24.2;24.9;6.7;Cadastre;A 1.0;POLYGON Z ((354684.8 6688582.5 24.2, 354675 6688600.7 24.2, 354735.2 6688618.6 24.2, 354748.8 6688581 24.2, 354716.1 6688590.5 24.2, 354714.3 6688591 24.2, 354689.2 6688583.6 24.2, 354684.8 6688582.5 24.2))
BATIMENT0000000291500259;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2010-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;9.0;4.0;00;00;9.0;6.6;;16.1;6.8;Imagerie aérienne;C 0.5;POLYGON Z ((354748.7 6688623 15.6, 354763.5 6688582.7 15.6, 354754.7 6688580 15.6, 354739.6 6688620.5 15.5, 354748.7 6688623 15.6))
BATIMENT0000000302923152;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;18.9;5.3;24.2;25.2;6.9;Cadastre;A 1.0;POLYGON Z ((354643 6688583.9 24.2, 354675 6688600.7 24.2, 354684.8 6688582.5 24.2, 354689.2 6688583.6 24.2, 354691.1 6688576.3 24.2, 354657.7 6688557.4 24.2, 354643 6688583.9 24.2))
BATIMENT0000000302923067;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;00;00;17.1;8.2;25.3;;;Cadastre;A 1.0;POLYGON Z ((354623.2 6688824.1 25.3, 354633.2 6688827.9 25.3, 354635.6 6688823.8 25.3, 354639.3 6688813.1 25.3, 354629.1 6688809.2 25.3, 354626.9 6688814.6 25.3, 354623.2 6688824.1 25.3))
BATIMENT0000000302923084;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;30;20;18.1;6.6;24.7;28.4;7.9;Cadastre;C 0.7;POLYGON Z ((354667.3 6688836.1 24.7, 354668.6 6688832.8 24.7, 354672.7 6688834.2 24.7, 354673.4 6688834.4 24.7, 354675.3 6688828.2 24.7, 354646 6688817.3 24.7, 354642.5 6688827 24.7, 354646.1 6688828.5 24.7, 354649.3 6688829.7 24.7, 354650.2 6688830.1 24.7, 354650.3 6688829.6 24.7, 354667.3 6688836.1 24.7))
BATIMENT0000000302923068;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;11.3;7.2;18.5;24.5;8.5;Cadastre;A 1.0;POLYGON Z ((354620.2 6688831 18.5, 354626.4 6688833.6 18.5, 354627.1 6688833.8 18.5, 354630.5 6688834.9 18.5, 354633.2 6688827.9 18.5, 354623.2 6688824.1 18.5, 354620.2 6688831 18.5))
BATIMENT0000000302923083;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;11.7;7.0;18.7;27.1;8.8;Cadastre;A 1.0;POLYGON Z ((354637.6 6688840 18.7, 354642.1 6688841.8 18.7, 354642.4 6688840.7 18.7, 354644.5 6688836.3 18.7, 354645.4 6688833.7 18.7, 354646.1 6688830.5 18.7, 354646.1 6688829.7 18.7, 354642.1 6688828.1 18.7, 354637.6 6688840 18.7))
BATIMENT0000000302923069;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;35;23;16.2;7.4;23.7;26.3;8.7;Cadastre;B 0.2;POLYGON Z ((354617.8 6688836.8 23.7, 354623.9 6688839.2 23.7, 354626.4 6688833.6 23.7, 354620.2 6688831 23.7, 354617.8 6688836.8 23.7))
BATIMENT0000000302923071;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;7.9;20.0;23.9;8.8;Cadastre;;POLYGON Z ((354625.7 6688837.6 20, 354626 6688837.9 20, 354626.1 6688838.6 20, 354627.7 6688839.2 20, 354628.7 6688839.5 20, 354630.5 6688834.9 20, 354627.1 6688833.8 20, 354625.7 6688837.6 20))
BATIMENT0000000302923528;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;50;20;19.6;6.8;26.4;28.0;7.3;Cadastre;C 0.5;POLYGON Z ((354693.3 6688844.7 26.4, 354698.7 6688836.9 26.4, 354684.5 6688831.6 26.4, 354681.4 6688838.9 26.4, 354680.7 6688839.8 26.4, 354693.3 6688844.7 26.4))
BATIMENT0000000302923086;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;10;20;20.3;6.8;27.1;30.2;8.4;Cadastre;A 1.0;POLYGON Z ((354666.4 6688844.2 27.1, 354661.3 6688849.1 27.1, 354667.4 6688854.2 27.1, 354669.3 6688852.5 27.1, 354672.7 6688848.3 27.1, 354674.1 6688846.2 27.1, 354675.6 6688847.1 27.1, 354680.7 6688839.8 27.1, 354681.4 6688838.9 27.1, 354684.5 6688831.6 27.1, 354675.3 6688828.2 27.1, 354673.4 6688834.4 27.1, 354672.7 6688834.2 27.1, 354666.4 6688844.2 27.1))
BATIMENT0000000302923085;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;4.2;6.9;11.1;12.0;8.6;Cadastre;C 0.4;POLYGON Z ((354646.4 6688836.9 11.1, 354644.4 6688841.5 11.1, 354659.4 6688848 11.1, 354661.5 6688843.4 11.1, 354646.4 6688836.9 11.1))
BATIMENT0000000327814964;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2010-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;30;30;9.0;6.5;;31.5;6.5;Imagerie aérienne;C 0.1;POLYGON Z ((354770.4 6688605.8 15.5, 354765.2 6688604.3 15.5, 354762.2 6688613.1 15.5, 354770.2 6688615.1 15.5, 354775.8 6688616.8 15.5, 354778.7 6688608.1 15.5, 354770.4 6688605.8 15.5))
BATIMENT0000000291499381;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;25.4;6.6;;;;Imagerie aérienne;C 0.3;POLYGON Z ((354758.2 6688625.7 32, 354767.1 6688628.2 32, 354771.8 6688629.7 26.9, 354775.8 6688616.8 26.9, 354770.2 6688615.1 31.6, 354762.2 6688613.1 32, 354758.2 6688625.7 32))
BATIMENT0000000302923150;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;6.3;14.1;16.3;7.1;Cadastre;;POLYGON Z ((354749.4 6688818.8 14.1, 354752.6 6688810.8 14.1, 354728.4 6688801.4 14.1, 354725.3 6688809.3 14.1, 354749.4 6688818.8 14.1))
BATIMENT0000000302923092;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;18.2;7.8;26.0;29.4;8.8;Cadastre;A 1.0;POLYGON Z ((354727.6 6688847 26, 354716.7 6688842.3 26, 354706.2 6688854.1 26, 354708.5 6688855.3 26, 354705.3 6688861.7 26, 354710.9 6688864.5 26, 354712.1 6688862.9 26, 354718.1 6688866.7 26, 354727.6 6688847 26))
BATIMENT0000000302923094;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;5.0;10;20;16.7;6.9;23.7;28.0;12.5;Cadastre;A 1.0;POLYGON Z ((354731.6 6688871 23.7, 354728 6688868.7 23.7, 354726.6 6688867.9 23.7, 354722.2 6688864.8 23.7, 354721.2 6688864.1 23.7, 354717.2 6688871 23.7, 354719.3 6688872.3 23.7, 354720.3 6688870.4 23.7, 354724.4 6688872.9 23.7, 354722.2 6688876.5 23.7, 354721 6688878.7 23.7, 354714.8 6688875 23.7, 354711.1 6688881.2 23.7, 354716.8 6688883.2 23.7, 354717.9 6688884.2 23.7, 354718.2 6688883.7 23.7, 354721.8 6688885.5 23.7, 354728.5 6688880.3 23.7, 354736.6 6688874.5 23.7, 354748.1 6688855.5 23.7, 354729 6688847.6 23.7, 354723.4 6688859.6 23.7, 354730 6688863.8 23.7, 354730.4 6688863.5 23.7, 354732.3 6688864.7 23.7, 354734.5 6688865.9 23.7, 354732.8 6688868.9 23.7, 354731.6 6688871 23.7))
BATIMENT0000000302923049;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;10;20;21.8;6.9;28.7;32.4;8.4;Cadastre;A 1.0;POLYGON Z ((354758.8 6688860.1 28.7, 354756.6 6688860.6 28.7, 354747.9 6688875.1 28.7, 354755.9 6688879.7 28.7, 354758.3 6688875.4 28.7, 354759.2 6688875.8 28.7, 354760 6688874.8 28.7, 354759.1 6688874.3 28.7, 354760.6 6688871.9 28.7, 354762.2 6688871.7 28.7, 354764.7 6688872.8 28.7, 354768.4 6688864.7 28.7, 354758.8 6688860.1 28.7))
BATIMENT0000000302923048;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;7.0;30;20;21.9;6.8;28.7;32.5;10.5;Cadastre;A 1.0;POLYGON Z ((354769.1 6688874.6 28.7, 354768.7 6688876 28.7, 354781.8 6688881.8 28.7, 354784.8 6688874.4 28.7, 354784.7 6688874.4 28.7, 354785.6 6688872.2 28.7, 354768.4 6688864.7 28.7, 354764.7 6688872.8 28.7, 354769.1 6688874.6 28.7))
BATIMENT0000002209617002;Indifférenciée;Indifférencié;;Non;En service;2020-10-01 09:32:48;2023-01-31 17:40:48;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.4;7.1;10.5;12.8;13.3;Cadastre;;POLYGON Z ((354759.5 6688897 10.5, 354760.1 6688896.8 10.5, 354776.2 6688884.6 10.5, 354774.7 6688883.2 10.5, 354771.1 6688881.5 10.5, 354761.6 6688888.7 10.5, 354758.7 6688889.2 10.5, 354748.9 6688882.1 10.5, 354745.5 6688886.6 10.5, 354759.5 6688897 10.5))
BATIMENT0000000302923035;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;4.0;30;20;15.3;11.5;26.8;31.7;18.1;Cadastre;A 1.0;POLYGON Z ((354777.3 6688890.3 26.8, 354773.5 6688892.8 26.8, 354774 6688895.1 26.8, 354773.6 6688895.1 26.8, 354772.3 6688895.4 26.8, 354772 6688894.9 26.8, 354771.3 6688895 26.8, 354771.5 6688895.8 26.8, 354770.2 6688896 26.8, 354769.9 6688895.1 26.8, 354762 6688900.5 26.8, 354762.1 6688900.8 26.8, 354762.3 6688903.4 26.8, 354760.7 6688905.3 26.8, 354758.6 6688905.4 26.8, 354756.6 6688903.9 26.8, 354756.1 6688901.4 26.8, 354757.8 6688899.5 26.8, 354735.5 6688882.7 26.8, 354735.4 6688882.8 26.8, 354732.5 6688886.5 26.8, 354730.9 6688885.4 26.8, 354727.5 6688887.9 26.8, 354727.6 6688889.9 26.8, 354754.8 6688910.6 26.8, 354756.9 6688910.8 26.8, 354759.3 6688907.9 26.8, 354761.1 6688907.3 26.8, 354762.8 6688908.5 26.8, 354762.8 6688909.5 26.8, 354764.1 6688910.7 26.8, 354765.3 6688910.5 26.8, 354766 6688913.9 26.8, 354765 6688914.3 26.8, 354765.4 6688918.6 26.8, 354765.7 6688918.9 26.8, 354769.1 6688921.6 26.8, 354775.5 6688913.5 26.8, 354776.3 6688912.6 26.8, 354776.2 6688912.3 26.8, 354777.7 6688910.4 26.8, 354777.5 6688910.1 26.8, 354779 6688908 26.8, 354787 6688914.4 26.8, 354788.1 6688912.6 26.8, 354789.3 6688913.4 26.8, 354791.4 6688914.9 26.8, 354797.1 6688906.6 26.8, 354799.2 6688903.5 26.8, 354794 6688900.1 26.8, 354795.7 6688897.1 26.8, 354794 6688896 26.8, 354792.2 6688894.9 26.8, 354790.4 6688893.8 26.8, 354790.3 6688892.2 26.8, 354788.9 6688891.3 26.8, 354789.6 6688889.5 26.8, 354787 6688888.4 26.8, 354782.3 6688889.3 26.8, 354777.3 6688890.3 26.8))
BATIMENT0000000302923124;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;26.3;15.5;41.8;44.9;18.3;Cadastre;A 1.0;POLYGON Z ((354698.2 6688939.7 41.8, 354708.2 6688927.7 41.8, 354708.4 6688927.8 41.8, 354710.9 6688924.8 41.8, 354713.3 6688927.1 41.8, 354713.9 6688927.6 41.8, 354714.5 6688928 41.8, 354715.2 6688928.3 41.8, 354715.7 6688928.4 41.8, 354716.3 6688928.3 41.8, 354717 6688928 41.8, 354717.5 6688927.5 41.8, 354726 6688917.4 41.8, 354739.3 6688928.2 41.8, 354732.6 6688936.1 41.8, 354734.5 6688937.6 41.8, 354739.2 6688941.1 41.8, 354744.4 6688933.6 41.8, 354752.6 6688922.9 41.8, 354728.5 6688902.5 41.8, 354697.7 6688939.3 41.8, 354698.2 6688939.7 41.8))
BATIMENT0000000302923082;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.9;8.8;25.7;27.7;9.2;Cadastre;;POLYGON Z ((354636.6 6688842.6 25.7, 354636.3 6688843.5 25.7, 354635.3 6688846.1 25.7, 354639.5 6688848.1 25.7, 354640.8 6688845.1 25.7, 354641.1 6688844.3 25.7, 354642.1 6688841.8 25.7, 354637.6 6688840 25.7, 354636.6 6688842.6 25.7))
BATIMENT0000000302923080;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.3;9.3;25.6;27.9;9.7;Cadastre;;POLYGON Z ((354639.5 6688848.1 25.6, 354635.3 6688846.1 25.6, 354633.7 6688849.7 25.6, 354638.1 6688851.4 25.6, 354639.5 6688848.1 25.6))
BATIMENT0000000302923529;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;4.4;6.8;11.2;26.0;8.3;Cadastre;C 0.4;POLYGON Z ((354683.1 6688858.7 11.2, 354683.4 6688858 11.2, 354683.7 6688858.2 11.2, 354686.5 6688854.6 11.2, 354688.7 6688851.5 11.2, 354693.3 6688844.7 11.2, 354680.7 6688839.8 11.2, 354675.6 6688847.1 11.2, 354674.7 6688848.6 11.2, 354671.3 6688853.3 11.2, 354683.1 6688858.7 11.2), (354678.1 6688850.1 11.2, 354683.9 6688842.4 11.2, 354686.9 6688843.2 11.2, 354686.6 6688843.4 11.2, 354689.2 6688844.7 11.2, 354689.5 6688844.4 11.2, 354690.6 6688844.8 11.2, 354688.8 6688847.7 11.2, 354687.7 6688847.2 11.2, 354686.9 6688847.5 11.2, 354683.3 6688852.5 11.2, 354678.1 6688850.1 11.2))
BATIMENT0000000302923087;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1740-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;;;16.2;8.7;24.9;;;Cadastre;A 1.0;POLYGON Z ((354688.3 6688861.6 24.9, 354694.1 6688855.3 24.9, 354701 6688846.8 24.9, 354706.5 6688839.9 24.9, 354698.7 6688836.9 24.9, 354693.3 6688844.7 24.9, 354688.7 6688851.5 24.9, 354686.5 6688854.6 24.9, 354683.7 6688858.2 24.9, 354688.3 6688861.6 24.9))
BATIMENT0000000302923078;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;16.4;9.3;25.7;27.8;10.9;Cadastre;A 1.0;POLYGON Z ((354632.7 6688849.3 25.7, 354625 6688870.2 25.7, 354633.6 6688872.1 25.7, 354633.7 6688871.7 25.7, 354634.3 6688870.1 25.7, 354636.5 6688864.5 25.7, 354634.1 6688863.8 25.7, 354635 6688861.5 25.7, 354636.5 6688860.5 25.7, 354637.9 6688861.1 25.7, 354640.4 6688854.1 25.7, 354638.9 6688853.4 25.7, 354638.3 6688854.9 25.7, 354637.3 6688854.5 25.7, 354638.6 6688851.6 25.7, 354638.1 6688851.4 25.7, 354633.7 6688849.7 25.7, 354632.7 6688849.3 25.7))
BATIMENT0000000302923081;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;9.0;21.5;26.2;9.9;Cadastre;;POLYGON Z ((354637.9 6688861.1 21.5, 354636.5 6688860.5 21.5, 354635 6688861.5 21.5, 354634.1 6688863.8 21.5, 354636.5 6688864.5 21.5, 354637.9 6688861.1 21.5))
BATIMENT0000000302923093;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;30;20;18.3;7.6;25.9;29.9;11.0;Cadastre;A 1.0;POLYGON Z ((354696.8 6688864.3 25.9, 354704.4 6688868.8 25.9, 354713.3 6688873.7 25.9, 354718.1 6688866.7 25.9, 354712.1 6688862.9 25.9, 354710.9 6688864.5 25.9, 354705.3 6688861.7 25.9, 354708.5 6688855.3 25.9, 354706.2 6688854.1 25.9, 354696.8 6688864.3 25.9))
BATIMENT0000000302923073;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;15.1;9.3;24.4;25.6;10.3;Cadastre;A 1.0;POLYGON Z ((354641.1 6688872.2 24.4, 354640.8 6688872.8 24.4, 354649.3 6688875.3 24.4, 354655.6 6688859.4 24.4, 354655.8 6688858.6 24.4, 354649.1 6688854.6 24.4, 354639.7 6688871.8 24.4, 354641.1 6688872.2 24.4), (354648.1 6688865.4 24.4, 354649 6688865.7 24.4, 354650.9 6688866.3 24.4, 354649.7 6688869.6 24.4, 354648 6688868.8 24.4, 354647 6688868.7 24.4, 354648.1 6688865.4 24.4))
BATIMENT0000000302923074;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;8.8;25.2;25.3;9.4;Cadastre;;POLYGON Z ((354648.1 6688865.4 25.2, 354647 6688868.7 25.2, 354648 6688868.8 25.2, 354649 6688865.7 25.2, 354648.1 6688865.4 25.2))
BATIMENT0000000302923075;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;7.4;8.5;16.0;21.7;9.8;Cadastre;A 1.0;POLYGON Z ((354653.2 6688876.4 16, 354660.9 6688863.9 16, 354659 6688861.2 16, 354655.6 6688859.4 16, 354649.3 6688875.3 16, 354649.7 6688875.4 16, 354653.2 6688876.4 16))
BATIMENT0000000302923064;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;8.0;40;23;23.3;7.9;31.2;36.3;10.6;Cadastre;A 1.0;POLYGON Z ((354587.4 6688834.3 31.2, 354587.9 6688833.2 31.2, 354581.5 6688828 31.2, 354580.7 6688829.1 31.2, 354577.4 6688826.2 31.2, 354572.1 6688832.8 31.2, 354571.5 6688833.5 31.2, 354583.6 6688843.8 31.2, 354589.7 6688836.4 31.2, 354587.4 6688834.3 31.2))
BATIMENT0000000302923523;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;7.3;13.7;28.5;9.5;Cadastre;;POLYGON Z ((354607.7 6688850.8 13.7, 354608.5 6688850 13.7, 354611.6 6688845.9 13.7, 354594.6 6688831.8 13.7, 354591.4 6688835.7 13.7, 354590.9 6688836.4 13.7, 354607.7 6688850.8 13.7))
BATIMENT0000000302923070;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;16.0;7.5;23.5;26.9;9.8;Cadastre;A 1.0;POLYGON Z ((354617.6 6688837.6 23.5, 354618.5 6688837.9 23.5, 354614.4 6688849.9 23.5, 354622.7 6688852.9 23.5, 354627.3 6688840.4 23.5, 354623.9 6688839.2 23.5, 354617.8 6688836.8 23.5, 354617.6 6688837.6 23.5))
BATIMENT0000000302923524;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;7.0;10;20;23.4;8.0;31.4;36.6;11.2;Cadastre;C 0.5;POLYGON Z ((354601.1 6688858.4 31.4, 354607.7 6688850.8 31.4, 354590.9 6688836.4 31.4, 354591.4 6688835.7 31.4, 354590.7 6688835.1 31.4, 354589.7 6688836.4 31.4, 354583.6 6688843.8 31.4, 354601.1 6688858.4 31.4))
BATIMENT0000000302923066;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;7.0;30;20;24.1;7.9;32.0;36.8;11.4;Cadastre;A 1.0;POLYGON Z ((354613.4 6688852.2 32, 354610.9 6688850.4 32, 354610 6688851.3 32, 354608.5 6688850 32, 354607.7 6688850.8 32, 354601.1 6688858.4 32, 354609.1 6688865.1 32, 354609.4 6688865.5 32, 354609.7 6688865.8 32, 354610.1 6688866.1 32, 354610.5 6688866.4 32, 354610.9 6688866.7 32, 354611.3 6688866.9 32, 354611.7 6688867.1 32, 354612.2 6688867.2 32, 354612.6 6688867.4 32, 354613.1 6688867.4 32, 354613.6 6688867.5 32, 354614.1 6688867.5 32, 354614.5 6688867.4 32, 354614.9 6688867.3 32, 354615.3 6688867.2 32, 354615.7 6688867.1 32, 354616 6688866.9 32, 354616.4 6688866.7 32, 354616.7 6688866.4 32, 354617 6688866.2 32, 354617.3 6688865.9 32, 354617.5 6688865.6 32, 354617.8 6688865.3 32, 354618 6688864.9 32, 354622.7 6688852.9 32, 354614.4 6688849.9 32, 354613.4 6688852.2 32))
BATIMENT0000000302923097;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.3;11.3;29.7;32.1;12.2;Cadastre;;POLYGON Z ((354557 6688862.1 29.7, 354558.9 6688863.5 29.7, 354561.8 6688860.1 29.7, 354559.7 6688858.5 29.7, 354557 6688862.1 29.7))
BATIMENT0000000302923095;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;30;20;21.7;10.9;32.6;36.6;12.2;Cadastre;A 1.0;POLYGON Z ((354558.9 6688863.5 32.6, 354558.6 6688864 32.6, 354570.9 6688874.3 32.6, 354578.6 6688865.2 32.6, 354566 6688854.9 32.6, 354561.8 6688860.1 32.6, 354558.9 6688863.5 32.6))
BATIMENT0000000302923098;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;00;00;22.1;11.1;33.2;37.1;12.0;Cadastre;A 1.0;POLYGON Z ((354573.8 6688876.6 33.2, 354583.3 6688884.8 33.2, 354590.9 6688875.7 33.2, 354578.6 6688865.2 33.2, 354570.9 6688874.3 33.2, 354573.8 6688876.6 33.2))
BATIMENT0000000302923353;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;1.0;1.0;20;20;5.1;11.9;17.1;20.9;14.5;Cadastre;C 0.6;POLYGON Z ((354564.5 6688876.6 17.1, 354560.7 6688874.6 17.1, 354557.1 6688873.7 17.1, 354556.3 6688879.3 17.1, 354559.3 6688879.7 17.1, 354561.9 6688881.1 17.1, 354564.5 6688883.1 17.1, 354567.3 6688884.8 17.1, 354570.8 6688880.7 17.1, 354568 6688878.7 17.1, 354564.5 6688876.6 17.1))
BATIMENT0000000302923105;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;6.3;12.7;19.0;23.0;15.5;Cadastre;C 0.2;POLYGON Z ((354547 6688890.1 19, 354546.8 6688891.7 19, 354551.1 6688892.5 19, 354555 6688893.2 19, 354561.3 6688894.3 19, 354566.4 6688895.1 19, 354567.1 6688889.6 19, 354554.3 6688887.4 19, 354553.7 6688884.1 19, 354548 6688883.2 19, 354547 6688890.1 19))
BATIMENT0000000302923535;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;7.7;8.4;16.2;23.5;13.2;Cadastre;C 0.5;POLYGON Z ((354663.4 6688877.7 16.2, 354670.6 6688882.4 16.2, 354668 6688886.8 16.2, 354672.3 6688889.7 16.2, 354673.7 6688887.4 16.2, 354677.2 6688881.3 16.2, 354678.4 6688879.3 16.2, 354683 6688871.3 16.2, 354683.6 6688870.4 16.2, 354666.7 6688863 16.2, 354655.7 6688880.3 16.2, 354660 6688883.5 16.2, 354663.4 6688877.7 16.2))
BATIMENT0000000302923127;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;6.5;8.2;14.7;16.6;11.9;Cadastre;A 1.0;POLYGON Z ((354678.4 6688879.3 14.7, 354684.2 6688882.5 14.7, 354688.8 6688874.6 14.7, 354689.4 6688873.6 14.7, 354683.6 6688870.4 14.7, 354683 6688871.3 14.7, 354678.4 6688879.3 14.7))
BATIMENT0000000302923076;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;10.0;9.4;19.5;25.1;11.5;Cadastre;A 1.0;POLYGON Z ((354646.4 6688877.9 19.5, 354648.6 6688878.5 19.5, 354649.7 6688875.4 19.5, 354649.3 6688875.3 19.5, 354640.8 6688872.8 19.5, 354637.9 6688879 19.5, 354644.7 6688881.7 19.5, 354646.4 6688877.9 19.5))
BATIMENT0000000302923077;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;17.5;9.3;26.8;30.5;12.8;Cadastre;A 1.0;POLYGON Z ((354624.9 6688870.5 26.8, 354626 6688870.9 26.8, 354623.1 6688878.5 26.8, 354634.1 6688887.8 26.8, 354637.9 6688879 26.8, 354640.8 6688872.8 26.8, 354641.1 6688872.2 26.8, 354639.7 6688871.8 26.8, 354638.2 6688871.3 26.8, 354634.3 6688870.1 26.8, 354633.7 6688871.7 26.8, 354636.8 6688872.8 26.8, 354636 6688875.4 26.8, 354635.3 6688875.9 26.8, 354633.1 6688874.1 26.8, 354633.6 6688872.1 26.8, 354625 6688870.2 26.8, 354624.9 6688870.5 26.8))
BATIMENT0000000302923122;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.8;8.7;18.5;26.2;13.2;Cadastre;;POLYGON Z ((354698.2 6688879 18.5, 354696.4 6688881.6 18.5, 354701.7 6688885.5 18.5, 354704.2 6688882.3 18.5, 354698.2 6688879 18.5))
BATIMENT0000000302923120;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;8.5;8.6;17.2;35.5;13.5;Cadastre;A 1.0;POLYGON Z ((354694.4 6688884.1 17.2, 354699.6 6688888 17.2, 354701.7 6688885.5 17.2, 354696.4 6688881.6 17.2, 354694.4 6688884.1 17.2))
BATIMENT0000000302923126;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.1;10.3;14.4;15.7;12.6;Cadastre;A 1.0;POLYGON Z ((354677.2 6688881.3 14.4, 354673.7 6688887.4 14.4, 354679.5 6688890.8 14.4, 354684.2 6688882.5 14.4, 354678.4 6688879.3 14.4, 354677.2 6688881.3 14.4))
BATIMENT0000000302923079;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;8.7;9.7;18.5;22.2;13.5;Cadastre;A 1.0;POLYGON Z ((354640 6688892.6 18.5, 354644.7 6688881.7 18.5, 354637.9 6688879 18.5, 354634.1 6688887.8 18.5, 354640 6688892.6 18.5))
BATIMENT0000000302923128;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;9.6;12.5;15.5;13.7;Cadastre;A 1.0;POLYGON Z ((354673.7 6688887.4 12.5, 354672.3 6688889.7 12.5, 354672.1 6688890.1 12.5, 354677.5 6688894.2 12.5, 354679.5 6688890.8 12.5, 354673.7 6688887.4 12.5))
BATIMENT0000000302923121;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.2;8.7;21.0;38.2;14.3;Cadastre;;POLYGON Z ((354683.2 6688898.8 21, 354683.6 6688899.2 21, 354687.9 6688902.7 21, 354688.3 6688902.3 21, 354699.6 6688888 21, 354694.4 6688884.1 21, 354683.2 6688898.8 21))
BATIMENT0000000302923099;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;7.0;00;00;18.8;11.6;30.5;36.5;15.3;Cadastre;A 1.0;POLYGON Z ((354583.3 6688884.8 30.5, 354582.1 6688886.2 30.5, 354579.1 6688898.3 30.5, 354579.8 6688898.5 30.5, 354603.4 6688904.4 30.5, 354607.6 6688893.1 30.5, 354607.6 6688892.6 30.5, 354604.2 6688886.5 30.5, 354590.9 6688875.7 30.5, 354583.3 6688884.8 30.5))
BATIMENT0000000302923110;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;4.2;14.7;19.0;20.2;16.0;Cadastre;A 1.0;POLYGON Z ((354566.4 6688895.1 19, 354565.6 6688900.2 19, 354568.6 6688901 19, 354570.3 6688896.1 19, 354566.4 6688895.1 19))
BATIMENT0000000302923111;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;4.7;14.2;18.9;19.0;16.0;Cadastre;A 1.0;POLYGON Z ((354570.3 6688896.1 18.9, 354568.6 6688901 18.9, 354571.1 6688901.7 18.9, 354573.8 6688896.9 18.9, 354570.3 6688896.1 18.9))
BATIMENT0000000302923107;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;6.2;13.6;19.8;23.2;16.1;Cadastre;A 1.0;POLYGON Z ((354573.8 6688896.9 19.8, 354571.1 6688901.7 19.8, 354573.8 6688902.5 19.8, 354579.1 6688903.3 19.8, 354579.8 6688898.5 19.8, 354579.1 6688898.3 19.8, 354573.8 6688896.9 19.8))
BATIMENT0000000302923108;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;14.2;19.4;26.8;16.1;Cadastre;;POLYGON Z ((354563.1 6688914.3 19.4, 354565.6 6688900.2 19.4, 354566.4 6688895.1 19.4, 354561.3 6688894.3 19.4, 354558 6688913.5 19.4, 354563.1 6688914.3 19.4))
BATIMENT0000000302923103;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;4.0;15.1;19.1;24.7;16.1;Cadastre;A 1.0;POLYGON Z ((354579.1 6688903.3 19.1, 354573.8 6688902.5 19.1, 354573.4 6688905.6 19.1, 354578.7 6688906.3 19.1, 354578.9 6688904.7 19.1, 354579.1 6688903.3 19.1))
BATIMENT0000000302923102;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;3.0;15.8;18.8;21.0;16.1;Cadastre;A 1.0;POLYGON Z ((354578.7 6688906.3 18.8, 354573.4 6688905.6 18.8, 354572.9 6688908.8 18.8, 354578.4 6688909.5 18.8, 354578.7 6688906.3 18.8))
BATIMENT0000000302923112;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;20;20;18.9;12.8;31.7;34.3;14.3;Cadastre;A 1.0;POLYGON Z ((354627.6 6688906.6 31.7, 354619.1 6688899.4 31.7, 354616.3 6688900 31.7, 354611.2 6688913.3 31.7, 354619.7 6688916.2 31.7, 354620.8 6688916.6 31.7, 354627.6 6688906.6 31.7))
BATIMENT0000000302923100;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.6;14.7;24.3;29.4;16.2;Cadastre;A 0.2;POLYGON Z ((354560.6 6688928.2 24.3, 354562.5 6688917.8 24.3, 354563.1 6688914.3 24.3, 354558 6688913.5 24.3, 354552.1 6688912.6 24.3, 354555 6688893.2 24.3, 354551.1 6688892.5 24.3, 354550 6688899.5 24.3, 354547.9 6688899.2 24.3, 354547.3 6688903.5 24.3, 354549.3 6688903.9 24.3, 354548.1 6688911.9 24.3, 354546 6688911.6 24.3, 354545.1 6688917 24.3, 354541.4 6688916.2 24.3, 354540.5 6688921.4 24.3, 354560.6 6688928.2 24.3))
BATIMENT0000000302923106;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;2.5;16.0;18.6;20.4;16.1;Cadastre;A 1.0;POLYGON Z ((354578.4 6688909.5 18.6, 354572.9 6688908.8 18.6, 354572.5 6688912 18.6, 354578 6688912.7 18.6, 354578.4 6688909.5 18.6))
BATIMENT0000002011291485;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2006-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;17.8;7.1;;;;Imagerie aérienne;C 0.2;POLYGON Z ((354881.5 6688317.8 22, 354901.8 6688319.7 22, 354919.4 6688321.4 22, 354927.7 6688322 22, 354928.5458812767 6688312.003221275 22, 354882.0227864102 6688312.003221275 22, 354881.5 6688317.8 22))
BATIMENT0000002011291483;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;31.1;7.1;;;;Imagerie aérienne;;POLYGON Z ((354878 6688338.9 37.5, 354899.9 6688341 37.5, 354901.4 6688326.6 38, 354901.8 6688319.7 35.1, 354881.5 6688317.8 35.1, 354880.2 6688317.7 35.1, 354879.4 6688324.4 38.2, 354878.4 6688324.3 38.2, 354876.8 6688338.8 37.5, 354878 6688338.9 37.5))
BATIMENT0000002011291482;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;23.8;7.4;;;;Imagerie aérienne;;POLYGON Z ((354925.8 6688343.7 31.2, 354930 6688344.1 31.2, 354930.6 6688337.7 31.2, 354931.7 6688337.9 28.6, 354933.3 6688322.5 28.5, 354927.7 6688322 28.5, 354919.4 6688321.4 28.4, 354917.8 6688336.3 31.2, 354911.5 6688335.9 31.2, 354911 6688342.2 31.2, 354925.8 6688343.7 31.2))
BATIMENT0000002011291484;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;14.4;7.6;;;;Imagerie aérienne;;POLYGON Z ((354899.9 6688341 22, 354878 6688338.9 22, 354876.6 6688352.4 22, 354924.4 6688356.8 22, 354925.8 6688343.7 22, 354911 6688342.2 22, 354899.9 6688341 22))
BATIMENT0000002011295819;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:49;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.3;7.1;;20.0;7.5;Imagerie aérienne;;POLYGON Z ((354871.9 6688393.2 19.4, 354924.7 6688397.8 19.4, 354927 6688374.6 19.4, 354874 6688369.9 19.4, 354871.9 6688393.2 19.4))
BATIMENT0000002275362755;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.5;6.9;;;;Imagerie aérienne;;POLYGON Z ((354927 6688374.6 19.4, 354924.7 6688397.8 19.4, 354941.5 6688399.3 19.4, 354943.6 6688376.1 19.4, 354927 6688374.6 19.4))
BATIMENT0000000302923339;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:48:51;2000-01-01;;;;Image satellite;10.0;Corrélation;1.0;0.0;1.0;;;15.9;6.7;22.6;24.7;8.5;Imagerie aérienne;A 1.0;POLYGON Z ((354871.1 6688403.6 22.6, 354866.2 6688446 22.6, 355027.6 6688460.6 22.6, 355027.9 6688459.6 22.6, 355030.7 6688418.1 22.6, 354871.1 6688403.6 22.6))
BATIMENT0000000302923055;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.5;5.5;16.0;20.6;6.9;Cadastre;A 0.5;POLYGON Z ((354876.2 6688458.3 16, 354871.2 6688457.9 16, 354864.4 6688457.3 16, 354862.4 6688477.8 16, 354864.7 6688480.4 16, 354924.5 6688485.3 16, 354926.4 6688462.4 16, 354876.2 6688458.3 16))
BATIMENT0000000302923056;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.5;5.5;16.0;19.7;6.8;Cadastre;;POLYGON Z ((354924.5 6688485.3 16, 354927.7 6688485.6 16, 354929.6 6688462.7 16, 354926.4 6688462.4 16, 354924.5 6688485.3 16))
BATIMENT0000000302923058;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;23.2;6.3;29.5;30.6;8.2;Cadastre;A 0.1;POLYGON Z ((354967.4 6688591.7 29.5, 354972.7 6688535.2 29.5, 354858.8 6688524.3 29.5, 354853.4 6688581.1 29.5, 354967.4 6688591.7 29.5))
BATIMENT0000000327814956;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;21.6;6.9;;;;Imagerie aérienne;;POLYGON Z ((354863.6 6688353.8 28.5, 354864.5 6688342.4 28.5, 354857.6 6688341.7 28.5, 354858.2 6688335.8 28.5, 354828 6688332.2 24.6, 354829.7895879882 6688312.003221275 24.6, 354813.74407160847 6688312.003221275 24.512125280260907, 354810.1 6688348.5 24.4, 354863.6 6688353.8 28.5))
BATIMENT0000000327814958;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;9.7;8.3;;;;Imagerie aérienne;;POLYGON Z ((354867.0997244962 6688312.003221275 18, 354829.7895879882 6688312.003221275 18, 354828 6688332.2 18, 354858.2 6688335.8 18, 354857.6 6688341.7 18, 354864.5 6688342.4 18, 354867.0997244962 6688312.003221275 18))
BATIMENT0000000302923337;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.5;6.7;27.2;28.0;6.9;Cadastre;;POLYGON Z ((354860.3 6688367.2 27.2, 354857.4 6688397.1 27.2, 354858.5 6688397.2 27.2, 354861.3 6688367.3 27.2, 354860.3 6688367.2 27.2))
BATIMENT0000000302923558;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2022-10-20 15:45:51;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.2;6.6;22.8;27.5;6.9;Cadastre;B 0.3;POLYGON Z ((354744.5 6688426.8 22.8, 354744.4 6688429 22.8, 354765.2 6688430.4 22.8, 354767.3 6688409.9 22.8, 354839.4 6688417 22.8, 354841.3 6688396.2 22.8, 354857.4 6688397.1 22.8, 354860.3 6688367.2 22.8, 354758.9 6688358 22.8, 354743.2 6688386.6 22.8, 354739.7 6688416.1 22.8, 354738.8 6688426.2 22.8, 354744.5 6688426.8 22.8))
BATIMENT0000000302923054;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;6.5;13.7;15.2;6.7;Cadastre;;POLYGON Z ((354876.2 6688458.3 13.7, 354876.3 6688457.3 13.7, 354871.3 6688456.9 13.7, 354871.2 6688457.9 13.7, 354876.2 6688458.3 13.7))
BATIMENT0000000327814968;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;8.0;;;29.5;6.2;;35.7;6.7;Imagerie aérienne;A 1.0;POLYGON Z ((354792.7 6688474.7 31.9, 354794.1 6688474.8 28.2, 354804.9 6688475.9 28.2, 354807 6688475.9 35.7, 354820 6688476.9 35.7, 354821.5 6688454 35.7, 354808.8 6688452.9 35.7, 354807.9 6688462.1 35.7, 354794.2 6688461.2 32, 354794.7 6688451.8 32, 354778.6 6688450.3 32, 354776.8 6688473.3 32, 354792.7 6688474.7 31.9))
BATIMENT0000000302923320;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;22.0;6.3;28.3;31.0;6.7;Cadastre;A 0.3;POLYGON Z ((354834 6688455.7 28.3, 354832.1 6688478.6 28.3, 354852.1 6688480.3 28.3, 354854 6688457.4 28.3, 354834 6688455.7 28.3))
BATIMENT0000000327814965;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2013-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;26.0;6.0;00;00;10.7;6.2;;22.4;6.8;Imagerie aérienne;C 0.5;POLYGON Z ((354828.5 6688531.5 16.9, 354830.4 6688508.9 16.9, 354812.2 6688507 16.9, 354814 6688489.6 16.9, 354798.3 6688488.1 16.9, 354796.8 6688505.4 16.9, 354794.8 6688528.3 16.9, 354828.5 6688531.5 16.9))
BATIMENT0000000327814872;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;3.0;;;20.6;6.0;;28.8;6.7;Imagerie aérienne;C 0.1;POLYGON Z ((354852.8 6688491.6 26.6, 354837.1 6688490.2 26.6, 354833.3 6688532 26.6, 354842.7 6688532.9 26.6, 354848.3 6688533.6 26.5, 354852.8 6688491.6 26.6))
BATIMENT0000000291499676;Indifférenciée;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;16.2;6.2;;;;Imagerie aérienne;;POLYGON Z ((354840 6688620 15, 354843.8 6688582.5 15, 354840.3 6688577.8 16.9, 354830.1 6688576.2 22.4, 354817.9 6688574.1 14.9, 354815.7 6688587.5 14.9, 354816.4 6688587.4 14.9, 354816.1 6688591 14.9, 354815.2 6688591.1 14.9, 354813.2 6688612.1 14.9, 354813.3 6688618.2 14.9, 354840 6688620 15))
BATIMENT0000000302923316;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:48:52;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;10.4;7.1;;28.0;7.8;Imagerie aérienne;A 1.0;POLYGON Z ((355005.2 6688366.7 17.5, 355009.8 6688314.7 17.5, 354979.2195469109 6688312.003221275 17.5, 354949.4578398814 6688312.003221275 17.5, 354944.9 6688361 17.5, 355005.2 6688366.7 17.5))
BATIMENT0000000302930038;Industriel, agricole ou commercial;Industriel;Résidentiel;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;6.0;00;00;10.2;6.5;16.7;25.1;7.5;Cadastre;A 1.0;POLYGON Z ((355010.1 6688323.2 16.7, 355009 6688337.4 16.7, 355007.8 6688352.6 16.7, 355006.2 6688366.7 16.7, 355027.6 6688368.7 16.7, 355030.6 6688332.7 16.7, 355031.8 6688316.4 16.7, 355011.1 6688314.5 16.7, 355010.1 6688323.2 16.7))
BATIMENT0000002011296093;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;11.9;7.5;;20.2;9.2;Imagerie aérienne;;POLYGON Z ((355034 6688407.5 19.4, 355036.3 6688384.4 19.4, 354943.6 6688376.1 19.4, 354941.5 6688399.3 19.4, 355034 6688407.5 19.4))
BATIMENT0000000302923325;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;7.0;;;23.8;5.1;28.9;30.6;6.8;Cadastre;A 1.0;POLYGON Z ((354943.3 6688486.8 28.9, 354943.4 6688486.9 28.9, 354943.5 6688487 28.9, 354943.6 6688487.1 28.9, 354943.8 6688487.1 28.9, 354975.1 6688489.7 28.9, 354975.2 6688489.7 28.9, 354975.3 6688489.7 28.9, 354975.4 6688489.6 28.9, 354975.6 6688489.4 28.9, 354975.6 6688489.3 28.9, 354975.6 6688489.2 28.9, 354977.3 6688468.4 28.9, 354977.3 6688468.3 28.9, 354977.3 6688468.2 28.9, 354977.2 6688468.1 28.9, 354977.1 6688468 28.9, 354977 6688467.9 28.9, 354976.8 6688467.9 28.9, 354945.5 6688465.3 28.9, 354945.4 6688465.3 28.9, 354945.3 6688465.4 28.9, 354945.2 6688465.5 28.9, 354945.1 6688465.5 28.9, 354945.1 6688465.6 28.9, 354945 6688465.7 28.9, 354945 6688465.8 28.9, 354943.3 6688486.6 28.9, 354943.3 6688486.8 28.9))
BATIMENT0000002011294891;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2011-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;6.0;;;22.9;7.6;;;;Imagerie aérienne;A 1.0;POLYGON Z ((355015.8 6688471.1 30.5, 354995.3 6688469.4 30.5, 354993.2 6688490.3 30.5, 355014.1 6688491.9 30.5, 355015.8 6688471.1 30.5))
BATIMENT0000000302923554;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;00;00;17.1;4.5;21.6;25.1;6.8;Cadastre;C 0.3;POLYGON Z ((355032.1 6688516.1 21.6, 355035.9 6688516.3 21.6, 355036.9 6688506 21.6, 355032.9 6688505.7 21.6, 354997.7 6688502.6 21.6, 354997 6688510 21.6, 354996.7 6688513.2 21.6, 355032.1 6688516.1 21.6))
BATIMENT0000000302929299;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;23.4;6.4;29.9;31.6;6.6;Cadastre;;POLYGON Z ((355029 6688534.9 29.9, 355028.3 6688531.5 29.9, 355026.1 6688532 29.9, 355026.8 6688535.4 29.9, 355029 6688534.9 29.9))
BATIMENT0000000302930164;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;7.0;00;00;25.9;4.5;30.4;31.7;6.8;Cadastre;C 0.1;POLYGON Z ((355030.1 6688540.7 30.4, 355029 6688534.9 30.4, 355026.8 6688535.4 30.4, 355026.1 6688532 30.4, 355028.3 6688531.5 30.4, 355027.4 6688529 30.4, 355009.1 6688532.7 30.4, 355011.7 6688545.2 30.4, 355030.1 6688540.7 30.4))
BATIMENT0000000302923556;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;6.3;13.4;26.2;6.8;Cadastre;;POLYGON Z ((354988.2 6688607.8 13.4, 354988 6688608 13.4, 354988 6688608.3 13.4, 354988 6688608.4 13.4, 354988 6688608.5 13.4, 354988 6688608.6 13.4, 354988.1 6688608.8 13.4, 354988.1 6688608.9 13.4, 354988.2 6688609.2 13.4, 354988.4 6688609.3 13.4, 354988.5 6688609.4 13.4, 354988.6 6688609.5 13.4, 354988.7 6688609.5 13.4, 354988.7 6688609.6 13.4, 354988.8 6688609.6 13.4, 354988.9 6688609.6 13.4, 354989 6688609.6 13.4, 354989.2 6688609.7 13.4, 354989.3 6688609.7 13.4, 354989.3 6688609.6 13.4, 354989.5 6688609.6 13.4, 354989.6 6688609.6 13.4, 354990 6688609.4 13.4, 354990.1 6688609.3 13.4, 354990.2 6688609.2 13.4, 354990.6 6688609.4 13.4, 355003.2 6688605 13.4, 355022.9 6688598.1 13.4, 355004.7 6688593.7 13.4, 355008.2 6688581.2 13.4, 355026 6688585.9 13.4, 355026.4 6688582 13.4, 355029.8 6688582.3 13.4, 355033.1 6688546.7 13.4, 355029.7 6688546.3 13.4, 355030.1 6688540.7 13.4, 355011.7 6688545.2 13.4, 355009.1 6688532.7 13.4, 355027.4 6688529 13.4, 355028.3 6688531.5 13.4, 355030.7 6688531 13.4, 355032.1 6688516.1 13.4, 354996.7 6688513.2 13.4, 354992.8 6688555.6 13.4, 355011.2 6688556.6 13.4, 355010.3 6688569.5 13.4, 354991.6 6688567.9 13.4, 354988.3 6688604.1 13.4, 354987.9 6688607.4 13.4, 354988.2 6688607.6 13.4, 354988.2 6688607.8 13.4))
BATIMENT0000000302923555;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;7.0;10;40;25.3;4.5;29.8;31.7;6.6;Cadastre;C 0.2;POLYGON Z ((355010.3 6688569.5 29.8, 355011.2 6688556.6 29.8, 354992.8 6688555.6 29.8, 354991.6 6688567.9 29.8, 355010.3 6688569.5 29.8))
BATIMENT0000000291501069;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;21.0;9.0;00;00;28.5;7.2;;;;Imagerie aérienne;C 0.4;POLYGON Z ((354787.8 6688624.2 32.2, 354790.3 6688625 32.2, 354787.1 6688634.7 32.2, 354795.8 6688636.9 32.2, 354798.2 6688629.9 32.2, 354800.4 6688630.3 32.2, 354800.9 6688636.3 32.2, 354804 6688636.4 35.7, 354804.1 6688638.2 35.7, 354809.5 6688637.8 35.7, 354808.2 6688620.2 35.7, 354802.9 6688620.6 35.7, 354803.1 6688622.4 35.7, 354800.4 6688621.8 32.1, 354790.4 6688617.5 32.1, 354787.8 6688624.2 32.2))
BATIMENT0000000302923338;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.2;6.3;15.5;19.7;6.6;Cadastre;;POLYGON Z ((354823.3 6688637.6 15.5, 354837.7 6688637.1 15.5, 354839.2 6688624.6 15.5, 354822.8 6688625.1 15.5, 354823.3 6688637.6 15.5))
BATIMENT0000000302923032;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;17.8;6.9;24.7;26.9;11.8;Cadastre;A 1.0;POLYGON Z ((354788.8 6688873.6 24.7, 354783.8 6688884.4 24.7, 354791.3 6688888.3 24.7, 354797.2 6688877.8 24.7, 354788.8 6688873.6 24.7))
BATIMENT0000000302923030;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;19.0;6.9;26.0;27.9;12.1;Cadastre;A 1.0;POLYGON Z ((354800.8 6688879.7 26, 354797.2 6688877.8 26, 354791.3 6688888.3 26, 354791.7 6688888.5 26, 354792.5 6688887.1 26, 354794.4 6688888.1 26, 354793.5 6688889.6 26, 354794.1 6688889.9 26, 354800.8 6688879.7 26))
BATIMENT0000000302923031;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;17.1;6.8;24.0;28.0;12.4;Cadastre;A 1.0;POLYGON Z ((354793.6 6688890.5 24, 354794.7 6688891.1 24, 354799.1 6688894.1 24, 354806 6688882.3 24, 354800.8 6688879.7 24, 354794.1 6688889.9 24, 354793.6 6688890.5 24))
BATIMENT0000000302923033;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;7.0;10;20;20.8;7.1;28.0;29.2;14.5;Cadastre;A 1.0;POLYGON Z ((354799.1 6688894.1 28, 354797.4 6688896.9 28, 354795.7 6688897.1 28, 354794 6688900.1 28, 354799.2 6688903.5 28, 354804.1 6688896.4 28, 354805.4 6688894.5 28, 354810.3 6688884.5 28, 354806 6688882.3 28, 354799.1 6688894.1 28))
BATIMENT0000000302923034;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;19.7;7.1;26.9;29.4;14.7;Cadastre;A 1.0;POLYGON Z ((354804.1 6688896.4 26.9, 354799.2 6688903.5 26.9, 354806.6 6688908.4 26.9, 354809.5 6688906 26.9, 354809.9 6688906.2 26.9, 354810.9 6688904.4 26.9, 354819.4 6688889.1 26.9, 354810.3 6688884.5 26.9, 354805.4 6688894.5 26.9, 354804.1 6688896.4 26.9), (354810.3 6688897.4 26.9, 354812.4 6688898.5 26.9, 354811.3 6688900.5 26.9, 354809.2 6688899.5 26.9, 354809.7 6688898.5 26.9, 354810.3 6688897.4 26.9))
BATIMENT0000000302923039;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;20;20;19.0;7.0;26.0;27.9;10.5;Cadastre;A 1.0;POLYGON Z ((354814.7 6688906.6 26, 354817 6688907.9 26, 354820.5 6688901.2 26, 354825.2 6688892.2 26, 354819.4 6688889.1 26, 354810.9 6688904.4 26, 354814.7 6688906.6 26))
BATIMENT0000000302923036;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;11.4;18.2;26.7;15.3;Cadastre;;POLYGON Z ((354803.5 6688911.1 18.2, 354806.6 6688908.4 18.2, 354799.2 6688903.5 18.2, 354797.1 6688906.6 18.2, 354803.5 6688911.1 18.2))
BATIMENT0000000302923040;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;20;20;18.3;7.0;25.3;27.8;15.7;Cadastre;A 1.0;POLYGON Z ((354824.2 6688903.3 25.3, 354821 6688908.8 25.3, 354819.8 6688908.2 25.3, 354818.5 6688910.5 25.3, 354813.9 6688908 25.3, 354807.8 6688918.4 25.3, 354808 6688918.8 25.3, 354804.5 6688924.7 25.3, 354810.3 6688928 25.3, 354811.2 6688928.5 25.3, 354814.4 6688922.8 25.3, 354811.6 6688921.2 25.3, 354813.6 6688917.9 25.3, 354816.3 6688919.5 25.3, 354816.6 6688919 25.3, 354817.2 6688917.9 25.3, 354818.4 6688915.8 25.3, 354824.8 6688919.7 25.3, 354827.6 6688915.2 25.3, 354825.4 6688913.9 25.3, 354827.9 6688909.5 25.3, 354830.4 6688910.9 25.3, 354831.4 6688909.2 25.3, 354838.1 6688898.9 25.3, 354825.2 6688892.2 25.3, 354820.5 6688901.2 25.3, 354824.2 6688903.3 25.3))
BATIMENT0000000302930165;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;03;04;25.6;4.5;30.1;32.0;6.5;Cadastre;C 0.6;POLYGON Z ((355022.9 6688598.1 30.1, 355024.4 6688592.2 30.1, 355023 6688591.8 30.1, 355023.9 6688588.4 30.1, 355025.3 6688588.8 30.1, 355026 6688585.9 30.1, 355008.2 6688581.2 30.1, 355004.7 6688593.7 30.1, 355022.9 6688598.1 30.1))
BATIMENT0000000302929300;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;6.2;15.0;32.1;6.4;Cadastre;;POLYGON Z ((355024.4 6688592.2 15, 355025.3 6688588.8 15, 355023.9 6688588.4 15, 355023 6688591.8 15, 355024.4 6688592.2 15))
BATIMENT0000000302923321;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;6.3;10.5;11.2;6.5;Cadastre;;POLYGON Z ((354987.7 6688610.4 10.5, 354990.6 6688609.4 10.5, 354990.2 6688609.2 10.5, 354990.1 6688609.3 10.5, 354990 6688609.4 10.5, 354989.6 6688609.6 10.5, 354989.5 6688609.6 10.5, 354989.3 6688609.6 10.5, 354989.3 6688609.7 10.5, 354989.2 6688609.7 10.5, 354989 6688609.6 10.5, 354988.9 6688609.6 10.5, 354988.8 6688609.6 10.5, 354988.7 6688609.6 10.5, 354988.7 6688609.5 10.5, 354988.6 6688609.5 10.5, 354988.5 6688609.4 10.5, 354988.4 6688609.3 10.5, 354988.2 6688609.2 10.5, 354988.1 6688608.9 10.5, 354988.1 6688608.8 10.5, 354988 6688608.6 10.5, 354988 6688608.5 10.5, 354988 6688608.4 10.5, 354988 6688608.3 10.5, 354988 6688608 10.5, 354988.2 6688607.8 10.5, 354988.2 6688607.6 10.5, 354987.9 6688607.4 10.5, 354987.7 6688610.4 10.5))
BATIMENT0000000302923441;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;6.8;21.7;25.4;7.3;Cadastre;;POLYGON Z ((354975.4 6688967.4 21.7, 354972.1 6688965.7 21.7, 354969.2 6688971.2 21.7, 354972.7 6688972.9 21.7, 354975.4 6688967.4 21.7))
BATIMENT0000000302923443;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;18.0;6.8;24.9;27.6;9.5;Cadastre;A 1.0;POLYGON Z ((354957.7 6688971.6 24.9, 354950.4 6688984.6 24.9, 354954.1 6688986.5 24.9, 354967.5 6688963.4 24.9, 354963.5 6688961.4 24.9, 354958.7 6688969.8 24.9, 354957.7 6688971.6 24.9))
BATIMENT0000000302923438;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;5.0;;;16.9;6.8;23.7;28.7;7.3;Cadastre;A 1.0;POLYGON Z ((354972.7 6688972.9 23.7, 354970.9 6688976.4 23.7, 354972.8 6688977.3 23.7, 354973.8 6688976.4 23.7, 354976.4 6688977.6 23.7, 354975.3 6688979.9 23.7, 354978.5 6688981.6 23.7, 354982.9 6688971.1 23.7, 354975.4 6688967.4 23.7, 354972.7 6688972.9 23.7))
BATIMENT0000000302923442;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;12;20;15.1;6.8;22.0;26.2;9.4;Cadastre;A 1.0;POLYGON Z ((354952.6 6688999.5 22, 354961.6 6688984.7 22, 354968 6688973.5 22, 354969.2 6688971.2 22, 354972.1 6688965.7 22, 354967.5 6688963.4 22, 354954.1 6688986.5 22, 354953.3 6688988 22, 354948.1 6688997.1 22, 354952.6 6688999.5 22))
BATIMENT0000000302923434;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.4;6.8;26.3;28.0;6.9;Cadastre;;POLYGON Z ((354985.1 6688984.5 26.3, 354984.3 6688986.8 26.3, 354987 6688987.8 26.3, 354987.2 6688987.3 26.3, 354987.9 6688985.7 26.3, 354985.1 6688984.5 26.3))
BATIMENT0000000302923435;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;20.1;6.8;26.9;29.1;8.2;Cadastre;A 1.0;POLYGON Z ((354978.5 6688981.6 26.9, 354972.1 6688997.4 26.9, 354981.3 6689001.6 26.9, 354984.5 6688993.7 26.9, 354981.8 6688992.5 26.9, 354981.1 6688992.4 26.9, 354982.1 6688989.2 26.9, 354983 6688988.8 26.9, 354983.6 6688987.5 26.9, 354983.2 6688987.1 26.9, 354984.3 6688984.2 26.9, 354985.1 6688984.5 26.9, 354987.9 6688985.7 26.9, 354990.7 6688978.8 26.9, 354992 6688975.6 26.9, 354982.9 6688971.1 26.9, 354978.5 6688981.6 26.9))
BATIMENT0000000302923437;Industriel, agricole ou commercial;Annexe;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.2;7.0;15.2;28.3;7.9;Cadastre;A 1.0;POLYGON Z ((354974 6688979.3 15.2, 354972.7 6688980.7 15.2, 354964.8 6688993.9 15.2, 354972.1 6688997.4 15.2, 354978.5 6688981.6 15.2, 354975.3 6688979.9 15.2, 354974 6688979.3 15.2))
BATIMENT0000000302923057;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.4;6.8;28.2;29.9;9.1;Cadastre;;POLYGON Z ((354853.4 6688581.1 28.2, 354851.1 6688605.2 28.2, 354965.1 6688616 28.2, 354967.4 6688591.7 28.2, 354853.4 6688581.1 28.2))
BATIMENT0000000302923047;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;23.8;8.1;32.0;35.2;17.1;Cadastre;;POLYGON Z ((354859.5 6688929.4 32, 354857.6 6688933.7 32, 354857 6688933.7 32, 354853.4 6688940.8 32, 354857.2 6688942.7 32, 354855 6688946.4 32, 354865.5 6688951.8 32, 354871.2 6688954.7 32, 354875.9 6688957.1 32, 354873.5 6688957.7 32, 354875.6 6688967.1 32, 354878.1 6688966.5 32, 354875.9 6688970.9 32, 354865.6 6688990.9 32, 354857 6688987.1 32, 354856.5 6688986.8 32, 354852.3 6688992.5 32, 354853 6688993.1 32, 354871.2 6689008.6 32, 354873.5 6689005 32, 354873.1 6689004.8 32, 354873.6 6689003.7 32, 354873.4 6689002.9 32, 354877.5 6689002 32, 354877.7 6689002.6 32, 354878.8 6689003.3 32, 354878.6 6689003.8 32, 354883.7 6689007 32, 354900.2 6688979.4 32, 354902.9 6688974.8 32, 354896.5 6688970.9 32, 354891.2 6688947.2 32, 354899.1 6688931.5 32, 354898.4 6688929.2 32, 354867.3 6688913.8 32, 354859.5 6688929.4 32))
BATIMENT0000000302923447;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;8.0;20;20;24.6;6.8;31.5;35.7;9.9;Cadastre;C 0.8;POLYGON Z ((354922.8 6688977.3 31.5, 354934.7 6688957.7 31.5, 354958.7 6688969.8 31.5, 354963.5 6688961.4 31.5, 354937 6688948.5 31.5, 354927.6 6688951.2 31.5, 354915 6688972.7 31.5, 354922.7 6688977.5 31.5, 354922.8 6688977.3 31.5))
BATIMENT0000000302923448;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;16.7;7.7;24.5;31.5;10.3;Cadastre;A 1.0;POLYGON Z ((354911.2 6688978.8 24.5, 354919 6688983.5 24.5, 354922.7 6688977.5 24.5, 354915 6688972.7 24.5, 354911.2 6688978.8 24.5))
BATIMENT0000000302923446;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;20;20;3.1;6.9;10.0;25.5;9.6;Cadastre;C 0.1;POLYGON Z ((354954 6688969.5 10, 354953.7 6688970.2 10, 354951.5 6688969.2 10, 354951.2 6688969.5 10, 354947.8 6688967.8 10, 354943 6688976.5 10, 354932.4 6688971 10, 354932.1 6688971.3 10, 354929.9 6688970.1 10, 354925.4 6688978.5 10, 354947 6688990.2 10, 354949.6 6688986.2 10, 354950.4 6688984.6 10, 354957.7 6688971.6 10, 354954 6688969.5 10))
BATIMENT0000000302923449;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;19.1;8.6;27.7;29.7;11.6;Cadastre;A 1.0;POLYGON Z ((354905.9 6688988 27.7, 354913.5 6688992.4 27.7, 354919 6688983.5 27.7, 354911.2 6688978.8 27.7, 354905.9 6688988 27.7))
BATIMENT0000000302923445;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;8.4;12.4;12.7;9.6;Cadastre;;POLYGON Z ((354924 6688977.9 12.4, 354921.6 6688982.6 12.4, 354944.3 6688994.8 12.4, 354947 6688990.2 12.4, 354925.4 6688978.5 12.4, 354924 6688977.9 12.4))
BATIMENT0000000302923450;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;16.8;10.6;27.4;29.2;12.6;Cadastre;A 1.0;POLYGON Z ((354900.1 6688997.5 27.4, 354907.6 6689002.3 27.4, 354909.6 6688999.1 27.4, 354913.5 6688992.4 27.4, 354905.9 6688988 27.4, 354900.1 6688997.5 27.4))
BATIMENT0000000302923454;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;00;00;2.9;8.6;11.5;13.1;12.5;Cadastre;A 1.0;POLYGON Z ((354930.8 6689006.1 11.5, 354931.3 6689005.5 11.5, 354935.2 6688998.9 11.5, 354918.8 6688989.9 11.5, 354916.1 6688994.9 11.5, 354921.4 6688998.1 11.5, 354922.2 6688997.4 11.5, 354926.9 6689001.3 11.5, 354926.5 6689001.9 11.5, 354930.8 6689006.1 11.5))
BATIMENT0000000302923579;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;8.5;12.8;21.9;12.5;Cadastre;;POLYGON Z ((354938.2 6689009.8 12.8, 354944.6 6688999.3 12.8, 354937.7 6688995 12.8, 354935.2 6688998.9 12.8, 354931.3 6689005.5 12.8, 354938.2 6689009.8 12.8))
BATIMENT0000000302923041;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;17.9;7.0;24.9;27.0;10.3;Cadastre;A 1.0;POLYGON Z ((354844.8 6688902.4 24.9, 354838.1 6688898.9 24.9, 354831.4 6688909.2 24.9, 354833 6688910.1 24.9, 354829.4 6688916.2 24.9, 354827.6 6688915.2 24.9, 354824.8 6688919.7 24.9, 354831.8 6688923.6 24.9, 354844.8 6688902.4 24.9))
BATIMENT0000000302923042;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.1;9.8;26.0;26.7;11.8;Cadastre;;POLYGON Z ((354816.6 6688919 26, 354818.1 6688919.9 26, 354818.5 6688918.8 26, 354817.2 6688917.9 26, 354816.6 6688919 26))
BATIMENT0000000302923044;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;10.0;22.2;25.7;12.8;Cadastre;;POLYGON Z ((354816.3 6688919.5 22.2, 354815.7 6688920.6 22.2, 354818.7 6688922.9 22.2, 354819.6 6688921 22.2, 354818.1 6688919.9 22.2, 354816.6 6688919 22.2, 354816.3 6688919.5 22.2))
BATIMENT0000000302923045;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;20;20;17.6;7.1;24.7;30.2;15.1;Cadastre;A 1.0;POLYGON Z ((354851.9 6688928.4 24.7, 354845.4 6688937.2 24.7, 354847.7 6688938.5 24.7, 354853.6 6688931.2 24.7, 354855.6 6688924.8 24.7, 354858.8 6688915.6 24.7, 354861.2 6688910.8 24.7, 354846.5 6688903.4 24.7, 354837.7 6688920.1 24.7, 354836 6688921.4 24.7, 354832.4 6688927.6 24.7, 354835.7 6688930 24.7, 354840.7 6688922.1 24.7, 354851.9 6688928.4 24.7))
BATIMENT0000000302923043;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;14.9;9.0;24.0;27.6;12.8;Cadastre;A 1.0;POLYGON Z ((354831.8 6688923.6 24, 354824.8 6688919.7 24, 354818.4 6688915.8 24, 354817.2 6688917.9 24, 354818.5 6688918.8 24, 354820.3 6688919.9 24, 354819.6 6688921 24, 354818.7 6688922.9 24, 354827.2 6688928.6 24, 354831.8 6688923.6 24))
BATIMENT0000000302923046;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;7.0;10;20;23.1;7.0;30.2;35.2;16.4;Cadastre;A 1.0;POLYGON Z ((354861.2 6688910.8 30.2, 354858.8 6688915.6 30.2, 354855.6 6688924.8 30.2, 354857.8 6688926 30.2, 354858.4 6688926.3 30.2, 354855.4 6688932.3 30.2, 354854.6 6688931.9 30.2, 354853.6 6688931.2 30.2, 354847.7 6688938.5 30.2, 354853.3 6688941.1 30.2, 354853.4 6688940.8 30.2, 354857 6688933.7 30.2, 354857.6 6688933.7 30.2, 354859.5 6688929.4 30.2, 354867.3 6688913.8 30.2, 354861.2 6688910.8 30.2))
BATIMENT0000000302923363;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;12.3;10.7;23.0;25.1;15.9;Cadastre;A 1.0;POLYGON Z ((354827.2 6688928.6 23, 354818.7 6688922.9 23, 354815.7 6688920.6 23, 354814.4 6688922.8 23, 354811.2 6688928.5 23, 354821.6 6688934.4 23, 354827.2 6688928.6 23))
BATIMENT0000000302923366;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;23.0;7.9;31.0;32.2;11.3;Cadastre;;POLYGON Z ((354855.6 6688924.8 31, 354853.6 6688931.2 31, 354854.6 6688931.9 31, 354857.8 6688926 31, 354855.6 6688924.8 31))
BATIMENT0000000302923362;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;12;20;9.5;14.5;24.0;25.3;16.2;Cadastre;A 1.0;POLYGON Z ((354806.4 6688934.9 24, 354817 6688940.8 24, 354821.6 6688934.4 24, 354811.2 6688928.5 24, 354810.3 6688928 24, 354806.4 6688934.9 24))
BATIMENT0000000302923365;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;5.0;30;30;19.0;14.7;33.7;34.2;18.5;Cadastre;A 1.0;POLYGON Z ((354807.3 6688953.9 33.7, 354813.3 6688945.6 33.7, 354798.7 6688933 33.7, 354796.6 6688936.3 33.7, 354796.4 6688936.1 33.7, 354792.6 6688941.3 33.7, 354807.3 6688953.9 33.7))
BATIMENT0000000302923436;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;7.0;00;00;18.9;6.8;25.7;29.3;9.0;Cadastre;A 1.0;POLYGON Z ((354987.9 6688985.7 25.7, 354987.2 6688987.3 25.7, 354988.4 6688987.9 25.7, 354986.5 6688992.6 25.7, 354985.3 6688992.1 25.7, 354984.5 6688993.7 25.7, 354981.3 6689001.6 25.7, 354991.3 6689006.2 25.7, 354991.8 6689005.3 25.7, 354997.1 6688994.5 25.7, 354993.8 6688993.2 25.7, 354994.2 6688991.9 25.7, 354995 6688989.9 25.7, 354998.7 6688991.4 25.7, 355003.2 6688981 25.7, 354992 6688975.6 25.7, 354990.7 6688978.8 25.7, 354987.9 6688985.7 25.7), (354990.5 6688996.2 25.7, 354992.5 6688997.1 25.7, 354991.5 6688999.5 25.7, 354989.4 6688998.6 25.7, 354990.5 6688996.2 25.7))
BATIMENT0000000302923444;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;8.4;13.3;17.5;9.6;Cadastre;;POLYGON Z ((354948.1 6688997.1 13.3, 354953.3 6688988 13.3, 354949.6 6688986.2 13.3, 354947 6688990.2 13.3, 354944.3 6688994.8 13.3, 354948.1 6688997.1 13.3))
BATIMENT0000000302923440;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.9;6.8;24.8;28.2;7.2;Cadastre;;POLYGON Z ((354994.2 6688991.9 24.8, 354993.8 6688993.2 24.8, 354997.1 6688994.5 24.8, 354997.8 6688993.2 24.8, 354994.2 6688991.9 24.8))
BATIMENT0000000302923439;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;10;20;18.5;6.7;25.3;28.4;8.5;Cadastre;A 1.0;POLYGON Z ((354994.6 6689006.5 25.3, 354997.6 6689002.2 25.3, 355002.4 6688997.1 25.3, 355010 6688984.4 25.3, 355003.2 6688981 25.3, 354998.7 6688991.4 25.3, 354997.8 6688993.2 25.3, 354997.1 6688994.5 25.3, 354991.8 6689005.3 25.3, 354994.6 6689006.5 25.3))
BATIMENT0000000302927293;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;10;20;16.4;6.7;23.2;27.3;9.1;Cadastre;A 1.0;POLYGON Z ((355012.2 6688985.6 23.2, 355009.6 6688990.1 23.2, 354997.2 6689007.3 23.2, 355001.2 6689009.5 23.2, 355005.9 6689008.2 23.2, 355006.9 6689005.7 23.2, 355002.5 6689003.2 23.2, 355002.9 6689002.7 23.2, 355003.8 6689001.9 23.2, 355005.4 6689002.7 23.2, 355005.8 6689002 23.2, 355007.9 6689003 23.2, 355007.3 6689004.6 23.2, 355011.4 6689006.7 23.2, 355015 6689000.3 23.2, 355020.8 6688989.9 23.2, 355012.2 6688985.6 23.2))
BATIMENT0000000302930088;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;17.6;7.0;24.7;28.6;8.8;Cadastre;A 1.0;POLYGON Z ((355041.5 6689008.7 24.7, 355042.2 6689000.4 24.7, 355029.7 6688994.3 24.7, 355025.9 6689000.4 24.7, 355028.9 6689001.9 24.7, 355029 6689004.5 24.7, 355031.1 6689011.8 24.7, 355041.5 6689008.7 24.7))
BATIMENT0000000302930087;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;00;00;18.3;6.9;25.2;28.6;10.3;Cadastre;A 1.0;POLYGON Z ((355031.1 6689011.8 25.2, 355029 6689004.5 25.2, 355025.8 6689005.3 25.2, 355023.6 6689004.2 25.2, 355025.9 6689000.4 25.2, 355029.7 6688994.3 25.2, 355020.8 6688989.9 25.2, 355015 6689000.3 25.2, 355021.9 6689004 25.2, 355019.1 6689007.3 25.2, 355013.5 6689008.9 25.2, 355011.4 6689006.7 25.2, 355011 6689006.7 25.2, 355007.8 6689007.6 25.2, 355011.1 6689017.5 25.2, 355031.1 6689011.8 25.2))
BATIMENT0000000302923455;Industriel, agricole ou commercial;Annexe;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;8.1;10.9;13.2;10.7;Cadastre;A 1.0;POLYGON Z ((354962 6688998.8 10.9, 354948.6 6689021.8 10.9, 354953.4 6689024.6 10.9, 354964.1 6689006.4 10.9, 354976.7 6689012.5 10.9, 354978.4 6689008.8 10.9, 354979.1 6689007.4 10.9, 354962 6688998.8 10.9))
BATIMENT0000000302927376;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;30;20;19.2;7.9;27.2;30.9;10.9;Cadastre;A 1.0;POLYGON Z ((354998.2 6689010.4 27.2, 355001.5 6689020.2 27.2, 355011.1 6689017.5 27.2, 355007.8 6689007.6 27.2, 355005.9 6689008.2 27.2, 355001.2 6689009.5 27.2, 354998.2 6689010.4 27.2))
BATIMENT0000000302927377;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;30;20;18.9;8.7;27.6;30.9;11.7;Cadastre;C 0.6;POLYGON Z ((354985.5 6689014.2 27.6, 354988.9 6689023.8 27.6, 355001.5 6689020.2 27.6, 354998.2 6689010.4 27.6, 354985.5 6689014.2 27.6))
BATIMENT0000000302923452;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;16.7;10.7;27.4;31.0;13.5;Cadastre;A 1.0;POLYGON Z ((354895.2 6689005.8 27.4, 354902.7 6689010.6 27.4, 354906.2 6689004.9 27.4, 354907.6 6689002.3 27.4, 354900.1 6688997.5 27.4, 354895.2 6689005.8 27.4))
BATIMENT0000000302923451;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;9.1;20.0;28.5;12.9;Cadastre;;POLYGON Z ((354909.6 6688999.1 20, 354907.6 6689002.3 20, 354906.2 6689004.9 20, 354910.9 6689007.9 20, 354913.1 6689009.6 20, 354913.5 6689009.8 20, 354917.2 6689004.2 20, 354909.6 6688999.1 20))
BATIMENT0000000302923580;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;50;20;8.6;8.6;17.2;25.3;12.4;Cadastre;C 0.5;POLYGON Z ((354950.3 6689002.8 17.2, 354944.6 6688999.3 17.2, 354938.2 6689009.8 17.2, 354943.9 6689013.6 17.2, 354950.3 6689002.8 17.2))
BATIMENT0000000302927383;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.5;12.1;21.7;24.2;13.6;Cadastre;;POLYGON Z ((354902.7 6689010.6 21.7, 354906.9 6689013.5 21.7, 354910.9 6689007.9 21.7, 354906.2 6689004.9 21.7, 354902.7 6689010.6 21.7))
BATIMENT0000000302927390;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;11.8;12.9;24.7;29.0;14.3;Cadastre;A 1.0;POLYGON Z ((354892.2 6689010.4 24.7, 354898.5 6689017.1 24.7, 354902.7 6689010.6 24.7, 354895.2 6689005.8 24.7, 354892.2 6689010.4 24.7))
BATIMENT0000000302923453;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;6.0;00;00;14.6;10.1;24.7;31.6;14.2;Cadastre;A 1.0;POLYGON Z ((354918.5 6689013.4 24.7, 354926.5 6689001.9 24.7, 354926.9 6689001.3 24.7, 354922.2 6688997.4 24.7, 354921.4 6688998.1 24.7, 354917.2 6689004.2 24.7, 354913.5 6689009.8 24.7, 354913.1 6689009.6 24.7, 354909.1 6689014.9 24.7, 354911.8 6689016.8 24.7, 354917.1 6689020.6 24.7, 354922.6 6689024.6 24.7, 354927.9 6689028.3 24.7, 354929.4 6689026.2 24.7, 354928.7 6689025.6 24.7, 354929 6689024.8 24.7, 354930.6 6689022.3 24.7, 354918.5 6689013.4 24.7))
BATIMENT0000000302927388;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.4;11.4;29.8;30.7;13.9;Cadastre;;POLYGON Z ((354907.8 6689016.4 29.8, 354909.1 6689014.9 29.8, 354908.9 6689014.9 29.8, 354907.5 6689014.2 29.8, 354906.6 6689015.6 29.8, 354907.8 6689016.4 29.8))
BATIMENT0000000302927391;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;10.9;10.6;21.5;24.4;12.4;Cadastre;A 1.0;POLYGON Z ((354932.2 6689019.8 21.5, 354938.2 6689023.1 21.5, 354943.9 6689013.6 21.5, 354938.2 6689009.8 21.5, 354932.2 6689019.8 21.5))
BATIMENT0000000302927389;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;16.4;11.5;27.9;32.8;15.5;Cadastre;A 1.0;POLYGON Z ((354885.8 6689021.2 27.9, 354886.3 6689023.7 27.9, 354896.7 6689032.4 27.9, 354902.4 6689027.2 27.9, 354903.7 6689026 27.9, 354905.7 6689024.3 27.9, 354910.7 6689018.4 27.9, 354907.8 6689016.4 27.9, 354906.6 6689015.6 27.9, 354907.5 6689014.2 27.9, 354906.9 6689013.5 27.9, 354902.7 6689010.6 27.9, 354898.5 6689017.1 27.9, 354892.2 6689010.4 27.9, 354885.8 6689021.2 27.9))
BATIMENT0000000302927386;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.7;13.4;28.2;32.6;15.2;Cadastre;C 0.1;POLYGON Z ((354903.7 6689026 28.2, 354906.1 6689027.8 28.2, 354908.9 6689030.2 28.2, 354917.1 6689020.6 28.2, 354911.8 6689016.8 28.2, 354910.7 6689018.4 28.2, 354905.7 6689024.3 28.2, 354903.7 6689026 28.2))
BATIMENT0000000029192601;Indifférenciée;Commercial et services;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;;;;;BDTopo;2.5;BDTopo;1.5;0.0;7.0;;;7.8;14.0;;22.5;17.4;Imagerie aérienne;C 0.3;POLYGON Z ((354851.8 6688948.8 21.8, 354846.8 6688946.2 21.8, 354842 6688954.1 21.8, 354829.1 6688975.5 21.8, 354834.5 6688978.5 21.5, 354836.1 6688976.1 21.5, 354840.6 6688978 20.8, 354845.1 6688970.5 20.2, 354840.4 6688967.5 21.6, 354849.6 6688952.3 21.8, 354851.8 6688948.8 21.8))
BATIMENT0000000302923488;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;10.0;17.9;27.9;29.8;18.8;Cadastre;A 1.0;POLYGON Z ((354795.6 6688969.2 27.9, 354807.2 6688978.6 27.9, 354811.6 6688973.4 27.9, 354795.6 6688960 27.9, 354791 6688965.4 27.9, 354795.6 6688969.2 27.9))
BATIMENT0000000302923563;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;18.4;17.9;36.3;39.7;19.8;Cadastre;C 0.7;POLYGON Z ((354810.8 6689011.6 36.3, 354819 6689001.9 36.3, 354813.7 6688997.6 36.3, 354806.9 6688992 36.3, 354817.8 6688978.7 36.3, 354811.6 6688973.4 36.3, 354807.2 6688978.6 36.3, 354803.3 6688983.2 36.3, 354799.3 6688988 36.3, 354792.5 6688996.2 36.3, 354810.8 6689011.6 36.3))
BATIMENT0000000302923562;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;17.9;23.6;30.5;18.1;Cadastre;;POLYGON Z ((354822.1 6688998.3 23.6, 354829.9 6688988.9 23.6, 354824.7 6688984.5 23.6, 354813.7 6688997.6 23.6, 354819 6689001.9 23.6, 354822.1 6688998.3 23.6))
BATIMENT0000000302923484;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;19;20;17.2;17.9;35.1;;;Cadastre;A 1.0;POLYGON Z ((354829.9 6688988.9 35.1, 354822.1 6688998.3 35.1, 354825.2 6689000.9 35.1, 354826.7 6688999.3 35.1, 354831.1 6689003 35.1, 354837.6 6688995.4 35.1, 354829.9 6688988.9 35.1))
BATIMENT0000000302923367;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;15.6;28.2;31.0;16.8;Cadastre;;POLYGON Z ((354851.3 6688994 28.2, 354870.4 6689010.2 28.2, 354871.2 6689008.6 28.2, 354853 6688993.1 28.2, 354852.3 6688992.5 28.2, 354851.3 6688994 28.2))
BATIMENT0000000302923483;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;12;20;21.1;16.8;38.0;41.2;19.9;Cadastre;A 1.0;POLYGON Z ((354822.1 6689021.1 38, 354828.4 6689013.7 38, 354826.6 6689012.3 38, 354828.1 6689010.7 38, 354829.8 6689012 38, 354831.3 6689010.2 38, 354841.3 6688998.5 38, 354837.6 6688995.4 38, 354831.1 6689003 38, 354829.7 6689004.8 38, 354829.4 6689004.5 38, 354826.4 6689008.2 38, 354822.1 6689004.6 38, 354825.2 6689000.9 38, 354822.1 6688998.3 38, 354819 6689001.9 38, 354810.8 6689011.6 38, 354822.1 6689021.1 38))
BATIMENT0000000302923482;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;6.0;10;20;23.1;15.9;39.0;42.6;19.9;Cadastre;A 1.0;POLYGON Z ((354845 6689040.4 39, 354851.6 6689032.7 39, 354848.8 6689030.3 39, 354851.7 6689026.8 39, 354854.5 6689029.1 39, 354855 6689028.5 39, 354864.1 6689017.8 39, 354856.4 6689011.3 39, 354850.6 6689018.3 39, 354842.9 6689011.8 39, 354848.8 6689004.8 39, 354841.3 6688998.5 39, 354831.3 6689010.2 39, 354834.6 6689013 39, 354831.6 6689016.3 39, 354828.4 6689013.7 39, 354822.1 6689021.1 39, 354845 6689040.4 39))
BATIMENT0000000302927418;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;7.0;10;20;22.1;15.3;37.4;41.5;19.5;Cadastre;A 1.0;POLYGON Z ((354870.3 6689061.7 37.4, 354876.9 6689053.8 37.4, 354877.2 6689053.4 37.4, 354874.1 6689050.9 37.4, 354877.2 6689047.2 37.4, 354880.2 6689049.7 37.4, 354889.1 6689039 37.4, 354881.6 6689032.6 37.4, 354873.2 6689042.7 37.4, 354863.1 6689034.5 37.4, 354871.6 6689024.1 37.4, 354864.1 6689017.8 37.4, 354855 6689028.5 37.4, 354857.7 6689030.7 37.4, 354855.1 6689033.8 37.4, 354852.4 6689031.6 37.4, 354851.6 6689032.7 37.4, 354845 6689040.4 37.4, 354870.3 6689061.7 37.4))
BATIMENT0000000302928331;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;00;00;18.4;20.0;38.5;41.4;22.0;Cadastre;A 1.0;POLYGON Z ((354799.2 6689098.1 38.5, 354801.7 6689095 38.5, 354811.4 6689083.2 38.5, 354800.5 6689074.1 38.5, 354790.8 6689065.9 38.5, 354785.7 6689072 38.5, 354788.4 6689074.2 38.5, 354785.9 6689077.2 38.5, 354783.2 6689075 38.5, 354780.9 6689077.8 38.5, 354779.2 6689079.9 38.5, 354771.9 6689088.6 38.5, 354778.5 6689094.1 38.5, 354781.4 6689096.5 38.5, 354785.2 6689092.1 38.5, 354782.2 6689089.6 38.5, 354788.6 6689081.8 38.5, 354796.6 6689088.4 38.5, 354786.6 6689100.9 38.5, 354792.8 6689105.9 38.5, 354799.2 6689098.1 38.5))
BATIMENT0000000302929287;Industriel, agricole ou commercial;Industriel;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;4.6;12.8;17.4;7.4;Cadastre;;POLYGON Z ((355226.4796095824 6688312.003221275 12.8, 355202.1516133389 6688312.003221275 12.8, 355201.7 6688316.7 12.8, 355225.8 6688318.9 12.8, 355226.4796095824 6688312.003221275 12.8))
BATIMENT0000000302929284;Industriel, agricole ou commercial;Industriel;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;7.7;5.9;13.6;18.4;7.3;Cadastre;A 1.0;POLYGON Z ((355191 6688315.7 13.6, 355201.7 6688316.7 13.6, 355202.1516133389 6688312.003221275 13.6, 355191.4133044537 6688312.003221275 13.6, 355191 6688315.7 13.6))
BATIMENT0000000302929295;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;00;00;10.4;6.7;17.2;21.9;7.1;Cadastre;A 1.0;POLYGON Z ((355254.2 6688321.4 17.2, 355260.3 6688322 17.2, 355267.8 6688316.5 17.2, 355268.2371868204 6688312.003221275 17.2, 355254.71138931834 6688312.003221275 17.2, 355254.2 6688321.4 17.2))
BATIMENT0000000302929754;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;8.9;6.5;15.4;18.4;7.4;Cadastre;A 1.0;POLYGON Z ((355279.6 6688317.1 15.4, 355295.9 6688318.7 15.4, 355296.5 6688318.7 15.4, 355297.1 6688318.8 15.4, 355311.4 6688320.2 15.4, 355312.29900153755 6688312.003221275 15.4, 355279.9920599019 6688312.003221275 15.4, 355279.6 6688317.1 15.4))
BATIMENT0000000302929296;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;5.0;00;00;12.0;6.9;18.9;24.1;7.0;Cadastre;A 1.0;POLYGON Z ((355232.1 6688319.4 18.9, 355254.2 6688321.4 18.9, 355254.71138931834 6688312.003221275 18.9, 355232.79036601435 6688312.003221275 18.9, 355232.1 6688319.4 18.9))
BATIMENT0000000302929755;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.4;6.3;15.7;18.4;6.8;Cadastre;;POLYGON Z ((355295.9 6688330.7 15.7, 355297.1 6688318.8 15.7, 355296.5 6688318.7 15.7, 355295.9 6688318.7 15.7, 355294.7 6688330.6 15.7, 355295.9 6688330.7 15.7))
BATIMENT0000000302929752;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;00;00;12.4;6.7;19.1;23.5;6.9;Cadastre;C 0.5;POLYGON Z ((355291.7 6688341.6 19.1, 355292.6 6688341.7 19.1, 355293.3 6688333.7 19.1, 355294.5 6688333.8 19.1, 355294.7 6688330.6 19.1, 355295.9 6688318.7 19.1, 355279.6 6688317.1 19.1, 355277.8 6688340.5 19.1, 355291.7 6688341.6 19.1))
BATIMENT0000000302930066;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.3;6.7;17.0;;;Cadastre;C 0.1;POLYGON Z ((355213.8 6688333.2 17, 355213.5 6688339.5 17, 355217 6688339.8 17, 355217.4 6688333.5 17, 355213.8 6688333.2 17))
BATIMENT0000000302929753;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.3;6.4;14.8;21.0;6.7;Cadastre;A 1.0;POLYGON Z ((355291.7 6688341.6 14.8, 355277.8 6688340.5 14.8, 355277 6688350 14.8, 355290.6 6688351.1 14.8, 355290.8 6688348 14.8, 355286.4 6688348.4 14.8, 355286.8 6688345.3 14.8, 355291.1 6688345.3 14.8, 355291.7 6688341.6 14.8))
BATIMENT0000000302930070;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;5.8;11.7;26.2;6.5;Cadastre;;POLYGON Z ((355227.7 6688352.8 11.7, 355227.4 6688355.1 11.7, 355242.6 6688356.5 11.7, 355242.9 6688354.1 11.7, 355227.7 6688352.8 11.7))
BATIMENT0000000302929273;Industriel, agricole ou commercial;Industriel;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;90;10;7.3;4.9;12.2;14.4;6.8;Cadastre;A 1.0;POLYGON Z ((355157.5 6688312.6 12.2, 355162.6 6688313.1 12.2, 355162.68658779404 6688312.003221275 12.2, 355157.5628188131 6688312.003221275 12.2, 355157.5 6688312.6 12.2))
BATIMENT0000000302929282;Industriel, agricole ou commercial;Industriel;Commercial et services;Oui;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.5;4.6;12.1;15.8;6.7;Cadastre;A 0.2;POLYGON Z ((355167.2 6688313.5 12.1, 355191 6688315.7 12.1, 355191.4133044537 6688312.003221275 12.1, 355167.3535157666 6688312.003221275 12.1, 355167.2 6688313.5 12.1))
BATIMENT0000000302930035;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.4;6.7;18.1;19.1;7.0;Cadastre;;POLYGON Z ((355136.2 6688335 18.1, 355137 6688335.1 18.1, 355137.5 6688329.2 18.1, 355136.7 6688329.1 18.1, 355136.2 6688335 18.1))
BATIMENT0000000302930032;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.9;6.1;13.0;14.2;6.7;Cadastre;;POLYGON Z ((355149.2 6688335.2 13, 355149.6 6688335.2 13, 355150 6688335.3 13, 355150.6 6688329.4 13, 355150.1 6688329.3 13, 355149.8 6688329.3 13, 355149.2 6688335.2 13))
BATIMENT0000000302930034;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;00;00;11.7;6.5;18.2;22.7;7.8;Cadastre;C 0.5;POLYGON Z ((355120.5 6688367.9 18.2, 355120.3 6688367.8 18.2, 355119.7 6688374 18.2, 355133 6688375.3 18.2, 355134.8 6688356.8 18.2, 355133.2 6688356.7 18.2, 355134.1 6688347.5 18.2, 355135.7 6688347.7 18.2, 355137 6688335.1 18.2, 355136.2 6688335 18.2, 355136.7 6688329.1 18.2, 355124.4 6688327.9 18.2, 355122.2 6688351.1 18.2, 355124 6688351.3 18.2, 355123.4 6688356.8 18.2, 355121.6 6688356.6 18.2, 355120.5 6688367.9 18.2))
BATIMENT0000002011295617;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:52;2012-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;15.0;3.0;01;02;10.6;6.6;;18.9;7.5;Imagerie aérienne;A 1.0;POLYGON Z ((355186.7 6688370.9 14.8, 355190.2 6688331 14.8, 355181.6 6688330.4 17.2, 355170.5 6688329.3 17.2, 355169.9 6688337.4 17.2, 355169 6688346.3 13, 355177.2 6688347 15.3, 355175.4 6688365.9 14.6, 355180.4 6688366.3 14.6, 355179.7 6688374 14.6, 355185.4 6688374.5 14.6, 355186.7 6688370.9 14.8))
BATIMENT0000000302930036;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.6;6.5;18.1;19.7;7.6;Cadastre;;POLYGON Z ((355133.2 6688356.7 18.1, 355134.8 6688356.8 18.1, 355135.7 6688347.7 18.1, 355134.1 6688347.5 18.1, 355133.2 6688356.7 18.1))
BATIMENT0000000302930030;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.4;6.0;13.4;16.9;7.5;Cadastre;;POLYGON Z ((355146.7 6688360.7 13.4, 355147.4 6688360.8 13.4, 355148.3 6688360.9 13.4, 355149.9 6688344.2 13.4, 355148.9 6688344.1 13.4, 355148.3 6688344.1 13.4, 355146.7 6688360.7 13.4))
BATIMENT0000000302930031;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;3.0;00;00;7.7;5.8;13.5;18.2;7.7;Cadastre;A 1.0;POLYGON Z ((355150 6688335.3 13.5, 355149.6 6688335.2 13.5, 355149.2 6688335.2 13.5, 355148.3 6688344.1 13.5, 355148.9 6688344.1 13.5, 355149.9 6688344.2 13.5, 355148.3 6688360.9 13.5, 355147.4 6688360.8 13.5, 355146.7 6688360.7 13.5, 355145.3 6688375.4 13.5, 355146.2 6688375.5 13.5, 355158.5 6688376.7 13.5, 355160.6 6688355.3 13.5, 355163.9 6688355.7 13.5, 355164.2 6688352.3 13.5, 355160.9 6688352 13.5, 355163 6688330.6 13.5, 355150.6 6688329.4 13.5, 355150 6688335.3 13.5))
BATIMENT0000000302930033;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;7.3;15.7;21.0;7.7;Cadastre;;POLYGON Z ((355121.6 6688356.6 15.7, 355123.4 6688356.8 15.7, 355124 6688351.3 15.7, 355122.2 6688351.1 15.7, 355121.6 6688356.6 15.7))
BATIMENT0000000302930069;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;6.0;14.0;26.9;6.5;Cadastre;;POLYGON Z ((355247.9 6688354.5 14, 355247.6 6688356.8 14, 355255.6 6688357.4 14, 355255.8 6688355.2 14, 355247.9 6688354.5 14))
BATIMENT0000000302929759;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;16.0;6.4;22.5;25.1;6.7;Cadastre;A 1.0;POLYGON Z ((355290.6 6688351.1 22.5, 355277 6688350 22.5, 355276.1 6688362 22.5, 355289.6 6688363.2 22.5, 355289.8 6688360 22.5, 355286.7 6688359.9 22.5, 355287.1 6688357.5 22.5, 355287.4 6688354.3 22.5, 355290.3 6688354.7 22.5, 355290.6 6688351.1 22.5))
BATIMENT0000000302930067;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;7.0;00;00;12.3;6.0;18.4;26.7;7.5;Cadastre;A 1.0;POLYGON Z ((355195.5 6688331.5 18.4, 355191.6 6688384 18.4, 355209.8 6688385.7 18.4, 355211.1 6688369.8 18.4, 355211.4 6688367.8 18.4, 355213 6688346.4 18.4, 355213.5 6688339.5 18.4, 355213.8 6688333.2 18.4, 355195.5 6688331.5 18.4))
BATIMENT0000000302929760;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;6.5;16.7;20.0;6.7;Cadastre;;POLYGON Z ((355290 6688357.8 16.7, 355287.1 6688357.5 16.7, 355286.7 6688359.9 16.7, 355289.8 6688360 16.7, 355290 6688357.8 16.7))
BATIMENT0000000302930068;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;159.0;7.0;00;00;11.8;5.8;17.6;26.3;7.3;Cadastre;C 0.6;POLYGON Z ((355213.5 6688339.5 17.6, 355213 6688346.4 17.6, 355211.4 6688367.8 17.6, 355211.1 6688369.8 17.6, 355209.8 6688385.7 17.6, 355231.6 6688387.7 17.6, 355262.8 6688362.9 17.6, 355264.8 6688341.8 17.6, 355261.2 6688337.6 17.6, 355217.4 6688333.5 17.6, 355217 6688339.8 17.6, 355213.5 6688339.5 17.6), (355227.7 6688352.8 17.6, 355242.9 6688354.1 17.6, 355246.1 6688354.4 17.6, 355247.9 6688354.5 17.6, 355255.8 6688355.2 17.6, 355257.5 6688355.4 17.6, 355257 6688360.1 17.6, 355243.3 6688371.3 17.6, 355226.3 6688369.3 17.6, 355227.4 6688355.1 17.6, 355227.7 6688352.8 17.6))
BATIMENT0000000302929779;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;10;10;11.3;6.2;17.5;23.0;6.7;Cadastre;A 1.0;POLYGON Z ((355275.9 6688364.3 17.5, 355287 6688377 17.5, 355288.7 6688374.2 17.5, 355289.6 6688363.2 17.5, 355276.1 6688362 17.5, 355275.9 6688364.3 17.5))
BATIMENT0000000302929761;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;2001-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;;;14.6;6.3;21.0;22.0;6.7;Cadastre;C 0.4;POLYGON Z ((355299.4 6688370.7 21, 355300 6688364.8 21, 355299.5 6688364.8 21, 355299.7 6688363.4 21, 355296.6 6688363.1 21, 355296.5 6688363.8 21, 355289.6 6688363.2 21, 355288.7 6688374.2 21, 355287 6688377 21, 355297.7 6688389.3 21, 355302.2 6688394.4 21, 355304.3 6688394.6 21, 355305 6688381.7 21, 355305.1 6688380.9 21, 355302 6688380.7 21, 355302.5 6688378.4 21, 355298.8 6688378.4 21, 355299.4 6688370.7 21))
BATIMENT0000000302929698;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;12.1;6.5;18.6;24.5;6.8;Cadastre;A 1.0;POLYGON Z ((355297.4 6688434.6 18.6, 355291.4 6688426.2 18.6, 355301.2 6688419.6 18.6, 355302.2 6688409 18.6, 355300.5 6688408.9 18.6, 355284.3 6688421.1 18.6, 355299.1 6688441.5 18.6, 355299.8 6688434.5 18.6, 355297.4 6688434.6 18.6))
BATIMENT0000000302929976;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.6;6.7;27.4;29.8;7.4;Cadastre;;POLYGON Z ((355243.7 6688509 27.4, 355246.4 6688504 27.4, 355248.8 6688498.8 27.4, 355250.4 6688494.7 27.4, 355255.8 6688431.1 27.4, 355248.6 6688422.3 27.4, 355224 6688435.2 27.4, 355192.2 6688451.9 27.4, 355187.3 6688505.8 27.4, 355217.6 6688508.5 27.4, 355242.5 6688510.8 27.4, 355243.7 6688509 27.4))
BATIMENT0000002011296123;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;75.0;8.0;00;00;24.6;6.5;;;;Imagerie aérienne;C 0.2;POLYGON Z ((355293.3 6688497.8 25.3, 355281.6 6688497 25.3, 355280.8 6688497.4 30.5, 355278.9 6688497.1 30.5, 355280.5 6688482.5 30.5, 355284.3 6688443 30.5, 355293.9 6688435.4 27.7, 355285.5 6688423.4 27.7, 355275.3 6688431.6 31.1, 355273.3 6688429.6 31.1, 355268.5 6688433.5 31.1, 355267.4 6688447.4 31.1, 355268.9 6688447.4 31.1, 355268.7 6688450.4 31.1, 355267 6688450.3 31.1, 355266.4 6688456.3 31.1, 355267.9 6688456.4 31.1, 355267.7 6688459.1 31.1, 355266.4 6688459.1 31.1, 355265.3 6688470.6 31.1, 355266.8 6688470.7 31.1, 355266.5 6688473.4 31.1, 355265 6688473.3 31.1, 355264.1 6688484.4 31.1, 355261.6 6688512.2 14.7, 355268.6 6688513.6 30, 355279.8 6688514.4 30, 355279.9 6688512.9 30, 355292 6688513.9 25.5, 355293.3 6688497.8 25.3))
BATIMENT0000000302930043;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;00;00;9.3;6.9;16.2;17.5;7.8;Cadastre;C 0.2;POLYGON Z ((355081.8 6688338.1 16.2, 355091 6688339 16.2, 355091.6 6688332.7 16.2, 355093.4 6688332.9 16.2, 355094.4 6688322.2 16.2, 355083.3 6688321.1 16.2, 355081.8 6688338.1 16.2))
BATIMENT0000000302929996;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;00;00;7.5;8.0;15.5;;;Cadastre;C 0.4;POLYGON Z ((355113.4 6688340.9 15.5, 355114.8 6688326.9 15.5, 355103.5 6688325.8 15.5, 355102.5 6688335.7 15.5, 355104.3 6688335.9 15.5, 355103.9 6688339.9 15.5, 355113.4 6688340.9 15.5))
BATIMENT0000000302930044;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;7.3;13.5;16.7;7.8;Cadastre;;POLYGON Z ((355091 6688339 13.5, 355092.8 6688339.2 13.5, 355093.4 6688332.9 13.5, 355091.6 6688332.7 13.5, 355091 6688339 13.5))
BATIMENT0000000302929995;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;7.9;15.5;;;Cadastre;;POLYGON Z ((355102.1 6688339.8 15.5, 355103.9 6688339.9 15.5, 355104.3 6688335.9 15.5, 355102.5 6688335.7 15.5, 355102.1 6688339.8 15.5))
BATIMENT0000002275363183;Industriel, agricole ou commercial;Industriel;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;33.9;6.1;;;;Imagerie aérienne;;POLYGON Z ((355031.1 6688326.3 18.4, 355059.3 6688329.4 17.9, 355058.4 6688335.3 18, 355057.7 6688347.1 40, 355045.4 6688346.3 40, 355042.5 6688354.1 40, 355028.9 6688353.7 24.5, 355027.6 6688368.7 23.9, 355041.1 6688369.8 24.9, 355041.7 6688365.1 25.2, 355044 6688365.1 39.4, 355067.1 6688367.4 39.4, 355068.6 6688352.6 39.4, 355069.7 6688336.3 18.4, 355070.7 6688324.4 17.9, 355071.2 6688320 17.9, 355031.8 6688316.4 18.4, 355031.1 6688326.3 18.4))
BATIMENT0000002000615683;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2016-12-19 12:06:24;2023-01-31 17:48:52;;;;;Image satellite;10.0;Z corrigé;2.5;;;;;12.6;5.6;;19.7;7.5;Imagerie aérienne;;POLYGON Z ((355049.8 6688385.3 18.2, 355042.7 6688460.8 18.2, 355073.4 6688464.4 18.2, 355081.1 6688391.2 18.2, 355077.8 6688387.6 18.2, 355049.8 6688385.3 18.2))
BATIMENT0000000302929919;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;6.0;10.8;11.4;7.2;Cadastre;;POLYGON Z ((355105.8 6688459.7 10.8, 355109 6688466.9 10.8, 355113.9 6688464.5 10.8, 355110.2 6688457.3 10.8, 355105.8 6688459.7 10.8))
BATIMENT0000002011295488;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;20.9;6.0;;;;Imagerie aérienne;;POLYGON Z ((355127.7 6688480.5 19.1, 355087.2 6688477.6 19.1, 355085.9 6688495.1 19.3, 355088.5 6688495.1 26.9, 355108 6688496.9 26.9, 355126.5 6688498.2 19.5, 355127.7 6688480.5 19.1))
BATIMENT0000000291501136;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2010-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;32.0;8.0;00;00;23.4;2.9;;30.6;6.9;Imagerie aérienne;C 0.9;POLYGON Z ((355090.7 6688526.9 25.4, 355099.6 6688527.4 24.5, 355099.8 6688525.9 24.5, 355119.4 6688527.6 24.3, 355119.1 6688530 23.6, 355123 6688530.2 23.6, 355123.9 6688530.2 23.6, 355125.2 6688528.8 22.6, 355123.4 6688528 24.7, 355125.1 6688514 24.3, 355127.3 6688513.6 23, 355125.8 6688511.7 23.6, 355083 6688508.3 26.3, 355081.2 6688510.9 26.3, 355080.1 6688524.9 26.3, 355081.4 6688526.3 26.3, 355090.7 6688526.9 25.4))
BATIMENT0000000291501072;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.8;5.4;;17.7;6.6;Imagerie aérienne;C 0.4;POLYGON Z ((355119.1 6688530 11.2, 355119.4 6688527.6 11.2, 355099.8 6688525.9 11.2, 355099.6 6688527.4 11.2, 355090.7 6688526.9 11.2, 355088.8 6688540.9 11.2, 355094.5 6688541.4 11.2, 355096.3 6688543 11.2, 355093.6 6688573.6 11.2, 355119.9 6688564.5 11.2, 355123 6688530.2 11.2, 355119.1 6688530 11.2))
BATIMENT0000000302930006;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;7.7;6.9;14.6;16.1;7.8;Cadastre;A 1.0;POLYGON Z ((355184 6688383.3 14.6, 355185.4 6688374.5 14.6, 355179.7 6688374 14.6, 355180.4 6688366.3 14.6, 355167.2 6688365.2 14.6, 355165.8 6688381.6 14.6, 355184 6688383.3 14.6))
BATIMENT0000000302929632;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;7.1;12.7;16.0;7.5;Cadastre;;POLYGON Z ((355117.7 6688407.7 12.7, 355121.7 6688408.1 12.7, 355121 6688415.6 12.7, 355123.5 6688415.8 12.7, 355124.3 6688406.5 12.7, 355117.9 6688405.9 12.7, 355117.7 6688407.7 12.7))
BATIMENT0000000302929633;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.2;7.2;18.5;21.4;8.0;Cadastre;C 0.3;POLYGON Z ((355237.8 6688415.8 18.5, 355238.9 6688413 18.5, 355230.2 6688402.8 18.5, 355094.5 6688389.8 18.5, 355091.9 6688392.1 18.5, 355090.8 6688403.2 18.5, 355090.2 6688408.3 18.5, 355093.5 6688408.7 18.5, 355094.1 6688403.5 18.5, 355117.9 6688405.9 18.5, 355124.3 6688406.5 18.5, 355123.5 6688415.8 18.5, 355121 6688415.6 18.5, 355120.8 6688418.6 18.5, 355123.3 6688418.8 18.5, 355122.3 6688430 18.5, 355129.6 6688430.8 18.5, 355142.8 6688432.2 18.5, 355152.7 6688433.2 18.5, 355151.3 6688443.6 18.5, 355157.3 6688457.8 18.5, 355237.8 6688415.8 18.5))
BATIMENT0000002011294802;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;26.8;5.7;;;;Imagerie aérienne;;POLYGON Z ((355159.2 6688476.4 32.5, 355141 6688474.8 32.5, 355138.5 6688477.2 32.5, 355137.1 6688495.1 32.5, 355157.3 6688496.7 32.5, 355159.2 6688476.4 32.5))
BATIMENT0000000291501149;Indifférenciée;Résidentiel;Annexe;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2007-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;38.0;7.0;00;00;23.4;7.1;;31.7;7.1;Imagerie aérienne;C 0.4;POLYGON Z ((355141.8 6688538.6 26.7, 355143.9 6688536.9 26.7, 355146.5 6688537.3 26.7, 355147.6 6688539.1 26.7, 355153.9 6688539.7 26.7, 355156 6688538.3 26.7, 355157.1 6688538.3 26.7, 355157.8 6688529.9 30.5, 355162.5 6688530.3 30.5, 355161.1 6688538.6 26.3, 355163.3 6688540.7 26.3, 355173.5 6688541.6 26.3, 355175.6 6688518.5 26.3, 355164 6688517.5 26.3, 355163.2 6688527.7 30, 355158.6 6688527.2 30, 355159.6 6688517.3 26.6, 355149.6 6688516.3 26.6, 355149.6 6688517.6 26.6, 355146.5 6688517.4 26.6, 355146.7 6688516.3 26.6, 355135 6688515.4 26.6, 355132.8 6688537.9 26.5, 355141.8 6688538.6 26.7))
BATIMENT0000000291501065;Indifférenciée;Indifférencié;;Non;En service;2011-11-16 11:33:40;2018-09-18 13:45:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.6;5.3;;28.0;7.0;Imagerie aérienne;;POLYGON Z ((355163.3 6688540.7 13.9, 355161.1 6688538.6 13.9, 355162.5 6688530.3 13.9, 355157.8 6688529.9 13.9, 355157.1 6688538.3 13.9, 355156 6688538.3 13.9, 355153.9 6688539.7 13.9, 355147.6 6688539.1 13.9, 355146.5 6688537.3 13.9, 355143.9 6688536.9 13.9, 355141.8 6688538.6 13.9, 355132.8 6688537.9 13.9, 355130.7 6688560.5 13.9, 355173.7 6688545.7 13.9, 355173.5 6688541.6 13.9, 355163.3 6688540.7 13.9))
BATIMENT0000000302929553;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;31.8;6.6;38.5;41.0;9.2;Cadastre;;POLYGON Z ((355144.9 6688773.3 38.5, 355146.4 6688783.1 38.5, 355149.1 6688773 38.5, 355144.9 6688773.3 38.5))
BATIMENT0000000302930191;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;11.0;00;00;31.7;6.3;38.0;43.5;9.9;Cadastre;C 0.1;POLYGON Z ((355164.6 6688786.2 38, 355165.8 6688771.8 38, 355149.1 6688773 38, 355146.4 6688783.1 38, 355145.5 6688786.4 38, 355164.6 6688786.2 38))
BATIMENT0000000302930166;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;30.8;6.8;37.6;38.2;9.7;Cadastre;C 0.4;POLYGON Z ((355180.5 6688790 37.6, 355177.5 6688770 37.6, 355165.8 6688771.8 37.6, 355164.6 6688786.2 37.6, 355164.3 6688789.7 37.6, 355180.5 6688790 37.6))
BATIMENT0000000302929554;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;85.0;13.0;30;49;16.5;7.0;23.6;49.2;9.7;Cadastre;A 1.0;POLYGON Z ((355137.4 6688774.3 23.6, 355129.3 6688779.9 23.6, 355107.3 6688823.8 23.6, 355118 6688829.1 23.6, 355120 6688825.2 23.6, 355126.7 6688826.4 23.6, 355133.1 6688827.5 23.6, 355135.6 6688828 23.6, 355136.5 6688822.4 23.6, 355138 6688814.8 23.6, 355138.6 6688814.1 23.6, 355145.5 6688786.4 23.6, 355146.4 6688783.1 23.6, 355144.9 6688773.3 23.6, 355137.4 6688774.3 23.6))
BATIMENT0000000302929977;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.0;6.9;29.9;;;Cadastre;;POLYGON Z ((355249.1 6688511.4 29.9, 355250.4 6688494.7 29.9, 355248.8 6688498.8 29.9, 355246.4 6688504 29.9, 355243.7 6688509 29.9, 355242.5 6688510.8 29.9, 355249.1 6688511.4 29.9))
BATIMENT0000000302929705;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.2;6.4;18.7;20.2;7.0;Cadastre;;POLYGON Z ((355291.8 6688517.3 18.7, 355295.2 6688516.4 18.7, 355295.2 6688517.4 18.7, 355298.3 6688516.7 18.7, 355298.4 6688517.7 18.7, 355301.5 6688516.9 18.7, 355301.7 6688517.9 18.7, 355304.7 6688517.2 18.7, 355305.7 6688517 18.7, 355292.3 6688512.4 18.7, 355291.8 6688517.3 18.7))
BATIMENT0000000302929978;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;6.4;22.1;23.3;7.0;Cadastre;;POLYGON Z ((355183.7 6688543.2 22.1, 355215.2 6688536.3 22.1, 355221.6 6688534.9 22.1, 355222.7 6688522.4 22.1, 355216.5 6688521.9 22.1, 355185.9 6688519.1 22.1, 355183.7 6688543.2 22.1))
BATIMENT0000000327821904;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;1968-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;35.0;13.0;39;40;40.1;6.7;;49.3;7.2;Imagerie aérienne;C 0.3;POLYGON Z ((355290 6688768 46.5, 355290.2 6688769.7 46.5, 355295.7 6688769.3 46.5, 355295.5 6688767.5 46.5, 355306.2 6688766.4 46.5, 355307.7 6688766.1 46.5, 355307 6688751.7 46.5, 355279.7 6688754.1 46.5, 355279.9 6688755.8 46.5, 355281.2 6688767.8 46.5, 355281.3 6688769 46.8, 355290 6688768 46.5))
BATIMENT0000000302930057;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;6.5;21.0;31.4;7.1;Cadastre;;POLYGON Z ((355248.2 6688764.1 21, 355247.7 6688760.6 21, 355238 6688762 21, 355224.3 6688764 21, 355217.9 6688765 21, 355191.3 6688769 21, 355191.6 6688770.8 21, 355191.9 6688772.6 21, 355192.5 6688772.5 21, 355192.2 6688770.7 21, 355192.1 6688769.7 21, 355206.5 6688767.5 21, 355224.2 6688764.9 21, 355238 6688762.8 21, 355247.2 6688761.4 21, 355247.6 6688764.2 21, 355248.2 6688764.1 21))
BATIMENT0000000327821843;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2013-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;50.0;13.0;00;00;40.5;6.0;;48.1;7.1;Imagerie aérienne;C 0.1;POLYGON Z ((355272.9 6688768.9 46.5, 355281.2 6688767.8 46.5, 355279.9 6688755.8 46.5, 355259 6688758.8 46.5, 355261.3 6688777.9 46.5, 355262 6688777.8 46.5, 355262.6 6688782 46.5, 355274.2 6688780.4 46.5, 355272.9 6688768.9 46.5))
BATIMENT0000000327821806;Indifférenciée;Annexe;Commercial et services;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;1968-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;0.0;00;00;2.4;6.5;;39.2;7.3;Imagerie aérienne;C 0.4;POLYGON Z ((355295.7 6688769.3 8.9, 355290.2 6688769.7 8.9, 355290 6688768 8.9, 355281.3 6688769 8.9, 355281.2 6688767.8 8.9, 355272.9 6688768.9 8.9, 355274.2 6688780.4 8.9, 355262.6 6688782 8.9, 355263.1 6688785.7 8.9, 355275.4 6688783.9 8.9, 355278.8 6688806.4 8.9, 355279.7 6688815.8 8.9, 355283.7 6688816 8.9, 355283.5 6688818.8 8.9, 355289.4 6688819.1 8.9, 355289.6 6688815.8 8.9, 355296.4 6688815.7 8.9, 355296.4 6688818.6 8.9, 355300.3 6688818.8 8.9, 355300.2 6688815.4 8.9, 355295.7 6688769.3 8.9))
BATIMENT0000000302930058;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;25.7;6.7;32.4;36.2;7.3;Cadastre;;POLYGON Z ((355192.2 6688770.7 32.4, 355192.5 6688772.5 32.4, 355199.2 6688817.7 32.4, 355200 6688822.6 32.4, 355200.5 6688826.5 32.4, 355206.1 6688825.7 32.4, 355217.2 6688824 32.4, 355220.3 6688822.5 32.4, 355232.2 6688816.6 32.4, 355234.6 6688821.4 32.4, 355234.7 6688821.6 32.4, 355234.8 6688821.8 32.4, 355234.9 6688822 32.4, 355235.1 6688822.2 32.4, 355235.2 6688822.3 32.4, 355235.3 6688822.4 32.4, 355235.4 6688822.5 32.4, 355235.6 6688822.6 32.4, 355235.7 6688822.7 32.4, 355235.9 6688822.8 32.4, 355236.3 6688822.9 32.4, 355236.5 6688822.9 32.4, 355236.9 6688822.9 32.4, 355237 6688822.9 32.4, 355237.1 6688822.9 32.4, 355237.4 6688822.8 32.4, 355237.5 6688822.8 32.4, 355237.6 6688822.7 32.4, 355237.9 6688822.6 32.4, 355238 6688822.5 32.4, 355238.1 6688822.5 32.4, 355238.2 6688822.3 32.4, 355238.5 6688822.1 32.4, 355238.5 6688822 32.4, 355238.6 6688821.9 32.4, 355238.7 6688821.7 32.4, 355238.8 6688821.4 32.4, 355238.9 6688821.2 32.4, 355238.9 6688821 32.4, 355239 6688821 32.4, 355239 6688820.8 32.4, 355239.6 6688816.2 32.4, 355244.4 6688816.8 32.4, 355255.3 6688818.3 32.4, 355256.3 6688818.2 32.4, 355255.8 6688814.8 32.4, 355255.1 6688814.9 32.4, 355249.2 6688774.9 32.4, 355247.6 6688764.2 32.4, 355247.2 6688761.4 32.4, 355238 6688762.8 32.4, 355224.2 6688764.9 32.4, 355206.5 6688767.5 32.4, 355192.1 6688769.7 32.4, 355192.2 6688770.7 32.4))
BATIMENT0000000327821824;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2013-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;19.2;6.3;;26.0;7.4;Imagerie aérienne;C 0.4;POLYGON Z ((355279.6 6688816.9 25.5, 355279.7 6688815.8 25.5, 355278.8 6688806.4 25.5, 355275.4 6688783.9 25.5, 355263.1 6688785.7 25.5, 355267.3 6688816.4 25.5, 355279.6 6688816.9 25.5))
BATIMENT0000000302930059;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;26.8;6.9;33.7;36.0;7.1;Cadastre;;POLYGON Z ((355244.4 6688816.8 33.7, 355239.6 6688816.2 33.7, 355239 6688820.8 33.7, 355243.7 6688820.1 33.7, 355255.3 6688818.3 33.7, 355244.4 6688816.8 33.7))
BATIMENT0000000291499382;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2010-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;27.0;6.0;00;00;17.8;5.0;;25.4;6.6;Imagerie aérienne;C 0.9;POLYGON Z ((355078.3 6688541.6 22.8, 355075 6688572 21.9, 355077.3 6688572.3 21.9, 355076.5 6688581.6 21.6, 355093.4 6688575.2 21.5, 355093.6 6688573.6 21.4, 355096.3 6688543 21.4, 355094.5 6688541.4 21.4, 355088.8 6688540.9 21.9, 355080 6688540.1 22.8, 355078.3 6688541.6 22.8))
BATIMENT0000000302923050;Indifférenciée;Sportif;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.7;7.0;16.8;21.4;7.5;Cadastre;A 1.0;POLYGON Z ((355080.2 6688784 16.8, 355075.7 6688782 16.8, 355075.2 6688782.9 16.8, 355072.3 6688781.4 16.8, 355071.6 6688783 16.8, 355074.6 6688784.4 16.8, 355069.7 6688793.7 16.8, 355045.3 6688781.1 16.8, 355026 6688782.6 16.8, 354996.1 6688788.6 16.8, 354993.6 6688789.7 16.8, 354991.9 6688790.8 16.8, 354989.9 6688792.6 16.8, 354988.3 6688794.7 16.8, 354986.9 6688797.1 16.8, 354986.1 6688799.6 16.8, 354986.2 6688802.6 16.8, 354986.6 6688805.1 16.8, 354987.8 6688807.5 16.8, 354989.9 6688810.1 16.8, 354997.4 6688814.2 16.8, 355077.3 6688854.4 16.8, 355084.1 6688841.3 16.8, 355083.8 6688841.1 16.8, 355086.3 6688836 16.8, 355086.9 6688836.1 16.8, 355087.2 6688835.6 16.8, 355086.6 6688835.1 16.8, 355089 6688830.4 16.8, 355089.5 6688830.8 16.8, 355089.8 6688829.9 16.8, 355089.4 6688829.6 16.8, 355092.1 6688825 16.8, 355092.3 6688825 16.8, 355092.7 6688824.6 16.8, 355092.2 6688824.2 16.8, 355094.6 6688819.3 16.8, 355095 6688819.5 16.8, 355095.5 6688818.9 16.8, 355095.1 6688818.7 16.8, 355097.3 6688814 16.8, 355097.8 6688814.2 16.8, 355098.1 6688813.6 16.8, 355097.9 6688813.4 16.8, 355100.3 6688808.4 16.8, 355100.6 6688808.7 16.8, 355101 6688808 16.8, 355100.7 6688807.8 16.8, 355103.1 6688802.9 16.8, 355103.4 6688803 16.8, 355103.8 6688802.4 16.8, 355103.3 6688802.1 16.8, 355105.6 6688797.4 16.8, 355106 6688797.5 16.8, 355106.4 6688796.9 16.8, 355105.8 6688796.5 16.8, 355108.5 6688791.5 16.8, 355109 6688791.4 16.8, 355110.6 6688788 16.8, 355102.5 6688784 16.8, 355100.7 6688787.5 16.8, 355083.3 6688778.4 16.8, 355080.2 6688784 16.8))
BATIMENT0000000302929561;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;14.0;00;00;40.4;7.0;47.4;51.1;7.5;Cadastre;A 1.0;POLYGON Z ((355099.8 6688838.7 47.4, 355098 6688842.8 47.4, 355101.9 6688844.7 47.4, 355108.1 6688848 47.4, 355118 6688829.1 47.4, 355107.3 6688823.8 47.4, 355099.8 6688838.7 47.4))
BATIMENT0000000302929560;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;11.0;00;00;35.8;6.9;42.7;47.0;7.5;Cadastre;A 1.0;POLYGON Z ((355088.8 6688860.2 42.7, 355093.9 6688862.9 42.7, 355095.7 6688864 42.7, 355100.6 6688855 42.7, 355101 6688854.4 42.7, 355102.2 6688855.1 42.7, 355103.5 6688852.8 42.7, 355104.8 6688850.6 42.7, 355106.4 6688851.3 42.7, 355108.1 6688848 42.7, 355101.9 6688844.7 42.7, 355098 6688842.8 42.7, 355088.8 6688860.2 42.7))
BATIMENT0000000302930463;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;30;40;11.7;7.0;18.7;21.2;7.6;Cadastre;C 0.3;POLYGON Z ((355056.6 6689016.8 18.7, 355058.2 6689022.6 18.7, 355063.6 6689020.8 18.7, 355066.7 6689021.7 18.7, 355070.3 6689017 18.7, 355066 6689013.9 18.7, 355056.6 6689016.8 18.7))
BATIMENT0000000302930461;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;6.9;21.0;22.2;7.4;Cadastre;;POLYGON Z ((355069.4 6689024.3 21, 355073.6 6689019.6 21, 355071.7 6689018.1 21, 355070.3 6689017 21, 355066.7 6689021.7 21, 355067.9 6689022.8 21, 355069.4 6689024.3 21))
BATIMENT0000000302930466;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;9.0;7.1;16.2;18.9;8.4;Cadastre;C 0.3;POLYGON Z ((355059.1 6689030.4 16.2, 355060.6 6689031.5 16.2, 355065.1 6689026.2 16.2, 355063.4 6689024.9 16.2, 355059.1 6689030.4 16.2))
BATIMENT0000000302930464;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;16.5;6.9;23.5;26.3;10.5;Cadastre;A 1.0;POLYGON Z ((355073.6 6689019.6 23.5, 355069.4 6689024.3 23.5, 355056.3 6689038.7 23.5, 355058.3 6689041.1 23.5, 355078.8 6689026.2 23.5, 355073.6 6689019.6 23.5))
BATIMENT0000000302930465;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;14.9;7.0;22.0;26.0;10.4;Cadastre;A 1.0;POLYGON Z ((355057.6 6689041.6 22, 355057.6 6689042.6 22, 355058.3 6689043.9 22, 355081.8 6689030.5 22, 355078.8 6689026.2 22, 355058.3 6689041.1 22, 355057.6 6689041.6 22))
BATIMENT0000000302930467;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;14.5;7.0;21.5;26.2;10.4;Cadastre;A 1.0;POLYGON Z ((355059.3 6689045.8 21.5, 355060.5 6689045.2 21.5, 355063.6 6689044.2 21.5, 355084.9 6689034.5 21.5, 355081.8 6689030.5 21.5, 355058.3 6689043.9 21.5, 355059.3 6689045.8 21.5))
BATIMENT0000000302930060;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;26.2;6.9;33.2;36.5;7.3;Cadastre;;POLYGON Z ((355223.1 6688823.1 33.2, 355234.6 6688821.4 33.2, 355232.2 6688816.6 33.2, 355220.3 6688822.5 33.2, 355217.2 6688824 33.2, 355223.1 6688823.1 33.2))
BATIMENT0000000327821903;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;85.0;6.0;00;00;15.8;6.4;;23.9;7.3;Imagerie aérienne;C 0.6;POLYGON Z ((355300.3 6688818.8 22.2, 355296.4 6688818.6 22.2, 355296.4 6688815.7 22.2, 355289.6 6688815.8 22.2, 355289.4 6688819.1 22.2, 355283.5 6688818.8 22.2, 355283.7 6688816 22.2, 355279.7 6688815.8 22.2, 355279.6 6688816.9 22.2, 355267.3 6688816.4 22.2, 355268.6 6688824.8 22.2, 355312 6688827.8 22.2, 355310.9 6688814.2 21.8, 355300.2 6688815.4 21.8, 355300.3 6688818.8 22.2))
BATIMENT0000000302929564;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.7;6.7;10.5;13.5;7.0;Cadastre;C 1.0;POLYGON Z ((355212.9 6688883.8 10.5, 355215.1 6688880.4 10.5, 355212.3 6688878.3 10.5, 355209.8 6688881.8 10.5, 355212.9 6688883.8 10.5))
BATIMENT0000000029192239;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:45:21;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.1;6.5;;35.2;6.8;Imagerie aérienne;;POLYGON Z ((355197.5 6688869 10.1, 355180.7 6688894.5 10.1, 355187 6688897.9 10.1, 355203.3 6688872.7 10.1, 355197.5 6688869 10.1))
BATIMENT0000000302929563;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;6.7;10.5;37.2;7.0;Cadastre;;POLYGON Z ((355208.1 6688884.7 10.5, 355211.1 6688886.8 10.5, 355212.9 6688883.8 10.5, 355209.8 6688881.8 10.5, 355208.1 6688884.7 10.5))
BATIMENT0000000302929878;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.6;6.9;24.5;26.7;7.6;Cadastre;;POLYGON Z ((355232.9 6688924.6 24.5, 355234.1 6688924.5 24.5, 355234.8 6688924.1 24.5, 355235.7 6688922.1 24.5, 355247.4 6688927.8 24.5, 355245.9 6688930.8 24.5, 355260.3 6688934.4 24.5, 355265.4 6688921 24.5, 355268.3 6688913.7 24.5, 355272.3 6688913 24.5, 355279.5 6688900.1 24.5, 355282.5 6688895.2 24.5, 355299.7 6688863.7 24.5, 355305.9 6688852 24.5, 355306.1 6688851.7 24.5, 355307.1 6688850.1 24.5, 355277.8 6688845.7 24.5, 355242 6688837.8 24.5, 355241.8 6688837.3 24.5, 355223.7 6688878.1 24.5, 355233.3 6688883.8 24.5, 355237.7 6688890.6 24.5, 355235.7 6688896.5 24.5, 355235.4 6688896.9 24.5, 355241.3 6688900.1 24.5, 355240.3 6688902.5 24.5, 355236.9 6688911.8 24.5, 355231.9 6688924.3 24.5, 355232.9 6688924.6 24.5))
BATIMENT0000000302929562;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;34.0;9.0;35;20;32.5;6.5;39.0;39.3;7.0;Cadastre;A 1.0;POLYGON Z ((355193.4 6688910.7 39, 355194 6688910.5 39, 355195.3 6688909.7 39, 355195.7 6688909 39, 355198 6688902.9 39, 355198.9 6688902.5 39, 355199.9 6688902.2 39, 355200.6 6688901.8 39, 355201.5 6688901 39, 355202.4 6688899.8 39, 355211.1 6688886.8 39, 355208.1 6688884.7 39, 355209.8 6688881.8 39, 355212.3 6688878.3 39, 355203.3 6688872.7 39, 355187 6688897.9 39, 355181.4 6688906.2 39, 355193.4 6688910.7 39))
BATIMENT0000000302929881;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;30;40;3.3;5.7;9.1;10.2;6.5;Cadastre;B 0.2;POLYGON Z ((355279.5 6688900.1 9.1, 355290.2 6688904.8 9.1, 355292.6 6688899.3 9.1, 355282.5 6688895.2 9.1, 355279.5 6688900.1 9.1))
BATIMENT0000000302929882;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;4.0;;;13.0;6.6;19.7;26.4;7.3;Cadastre;A 1.0;POLYGON Z ((355218.1 6688920.4 19.7, 355218.2 6688920.9 19.7, 355228.9 6688925 19.7, 355229.4 6688924.7 19.7, 355231.4 6688925.5 19.7, 355231.9 6688924.3 19.7, 355236.9 6688911.8 19.7, 355240.3 6688902.5 19.7, 355241.3 6688900.1 19.7, 355235.4 6688896.9 19.7, 355235.7 6688896.5 19.7, 355222.6 6688889.1 19.7, 355222 6688890 19.7, 355217 6688887.9 19.7, 355210.8 6688897.6 19.7, 355215.1 6688899.2 19.7, 355213.6 6688903.2 19.7, 355212.6 6688902.9 19.7, 355211.8 6688905 19.7, 355212.8 6688905.4 19.7, 355212.1 6688907.4 19.7, 355206 6688905.3 19.7, 355202.5 6688914.7 19.7, 355218.1 6688920.4 19.7))
BATIMENT0000000302929888;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;6.1;10.0;12.0;6.3;Cadastre;;POLYGON Z ((355278.6 6688917.1 10, 355278.9 6688915.8 10, 355276 6688915 10, 355275.8 6688916.3 10, 355278.6 6688917.1 10))
BATIMENT0000000302930168;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;8.6;10.3;30.7;9.9;Cadastre;;POLYGON Z ((355161.7 6688823.1 10.3, 355164.3 6688789.7 10.3, 355164.6 6688786.2 10.3, 355145.5 6688786.4 10.3, 355138.6 6688814.1 10.3, 355138 6688814.8 10.3, 355136.5 6688822.4 10.3, 355161.7 6688823.1 10.3))
BATIMENT0000000302930167;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;10.0;00;00;10.8;6.9;17.7;25.9;9.8;Cadastre;C 0.5;POLYGON Z ((355170.3 6688830.1 17.7, 355177.2 6688829.1 17.7, 355180.5 6688828.6 17.7, 355186.1 6688827.8 17.7, 355180.5 6688790 17.7, 355164.3 6688789.7 17.7, 355161.7 6688823.1 17.7, 355161.5 6688826 17.7, 355160.4 6688831.5 17.7, 355170.3 6688830.1 17.7))
BATIMENT0000000302929559;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;7.0;10.3;17.0;7.8;Cadastre;;POLYGON Z ((355135 6688842.9 10.3, 355137.5 6688844.1 10.3, 355137.7 6688838.4 10.3, 355137.8 6688834 10.3, 355134.4 6688834 10.3, 355135.6 6688828 10.3, 355133.1 6688827.5 10.3, 355119 6688854.4 10.3, 355127.8 6688858.9 10.3, 355129.5 6688854.5 10.3, 355135 6688842.9 10.3))
BATIMENT0000000302929555;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;4.2;6.9;11.2;37.7;7.9;Cadastre;C 0.1;POLYGON Z ((355111.6 6688855 11.2, 355126.7 6688826.4 11.2, 355120 6688825.2 11.2, 355118 6688829.1 11.2, 355108.1 6688848 11.2, 355106.4 6688851.3 11.2, 355104.9 6688853.7 11.2, 355103.5 6688852.8 11.2, 355102.2 6688855.1 11.2, 355101 6688854.4 11.2, 355100.6 6688855 11.2, 355095.7 6688864 11.2, 355112.1 6688872.6 11.2, 355116.3 6688865.5 11.2, 355124.3 6688869.6 11.2, 355125.4 6688867.1 11.2, 355126.1 6688865.7 11.2, 355127.4 6688862.9 11.2, 355111.6 6688855 11.2))
BATIMENT0000000302929557;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;6.8;12.7;21.2;7.1;Cadastre;;POLYGON Z ((355138.8 6688864.9 12.7, 355138.2 6688866.2 12.7, 355141.7 6688868.2 12.7, 355142.3 6688866.8 12.7, 355138.8 6688864.9 12.7))
BATIMENT0000000302929556;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;51.0;10.0;00;00;29.5;6.3;35.8;36.5;7.4;Cadastre;A 1.0;POLYGON Z ((355134.5 6688884.1 35.8, 355141 6688887.3 35.8, 355145.6 6688878 35.8, 355146.6 6688875.8 35.8, 355141.4 6688873.2 35.8, 355143.4 6688869.1 35.8, 355141.7 6688868.2 35.8, 355138.2 6688866.2 35.8, 355138.8 6688864.9 35.8, 355135.4 6688863.2 35.8, 355132.3 6688868.9 35.8, 355126.1 6688865.7 35.8, 355125.4 6688867.1 35.8, 355124.3 6688869.6 35.8, 355116.3 6688865.5 35.8, 355112.1 6688872.6 35.8, 355134.5 6688884.1 35.8))
BATIMENT0000000302930169;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.3;7.0;9.3;;;Cadastre;;POLYGON Z ((355172.5 6688890.6 9.3, 355181.3 6688874.5 9.3, 355176 6688871.5 9.3, 355175.5 6688872.6 9.3, 355172.5 6688871.1 9.3, 355170.1 6688876 9.3, 355168.4 6688878.7 9.3, 355164.6 6688886.8 9.3, 355172.5 6688890.6 9.3))
BATIMENT0000000302929558;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;9.0;35;20;29.1;6.5;35.6;37.2;7.1;Cadastre;A 1.0;POLYGON Z ((355160.1 6688896.3 35.6, 355164.6 6688886.8 35.6, 355151.8 6688880.7 35.6, 355145.6 6688878 35.6, 355141 6688887.3 35.6, 355160.1 6688896.3 35.6))
BATIMENT0000000302930192;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;9.0;39;40;29.0;6.5;35.6;37.3;6.8;Cadastre;A 1.0;POLYGON Z ((355181.4 6688906.2 35.6, 355187 6688897.9 35.6, 355180.7 6688894.5 35.6, 355172.5 6688890.6 35.6, 355164.6 6688886.8 35.6, 355160.1 6688896.3 35.6, 355181.4 6688906.2 35.6))
BATIMENT0000000302930989;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.5;6.5;23.0;25.7;7.6;Cadastre;A 1.0;POLYGON Z ((355165.8 6689097.5 23, 355142.3 6689116.5 23, 355142.2 6689116.6 23, 355143.2 6689117.9 23, 355143.5 6689117.8 23, 355144.7 6689119.2 23, 355144.5 6689119.4 23, 355154.3 6689131.3 23, 355153.8 6689131.7 23, 355175.1 6689157.8 23, 355175.2 6689157.8 23, 355176.7 6689158.5 23, 355176.8 6689158.6 23, 355184 6689152.9 23, 355184.6 6689153.7 23, 355185.2 6689153.2 23, 355186.4 6689154.7 23, 355194.3 6689148.2 23, 355193.2 6689146.8 23, 355193.7 6689146.3 23, 355193.1 6689145.5 23, 355200.1 6689139.8 23, 355200 6689139.6 23, 355199.6 6689137.9 23, 355199.8 6689137.7 23, 355178.7 6689111.8 23, 355178 6689112.2 23, 355168.3 6689100.4 23, 355168.1 6689100.5 23, 355166.8 6689098.9 23, 355167 6689098.7 23, 355165.9 6689097.4 23, 355165.8 6689097.5 23))
BATIMENT0000000302929889;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;6.9;10.2;;;Cadastre;;POLYGON Z ((355287.2 6688918.8 10.2, 355288.3 6688915 10.2, 355285 6688914.4 10.2, 355283.9 6688918.5 10.2, 355287.2 6688918.8 10.2))
BATIMENT0000000302929884;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;6.3;11.0;21.0;6.8;Cadastre;;POLYGON Z ((355292.8 6688919.1 11, 355296.5 6688919.2 11, 355304 6688919.6 11, 355304.8 6688916 11, 355295.8 6688915.6 11, 355288.3 6688915 11, 355287.2 6688918.8 11, 355292.8 6688919.1 11))
BATIMENT0000000302929880;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;7.9;6.9;14.8;;;Cadastre;A 1.0;POLYGON Z ((355294 6688925.6 14.8, 355295.5 6688925.9 14.8, 355296.5 6688919.2 14.8, 355292.8 6688919.1 14.8, 355287.2 6688918.8 14.8, 355283.9 6688918.5 14.8, 355278.6 6688917.1 14.8, 355275.8 6688916.3 14.8, 355268.3 6688913.7 14.8, 355265.4 6688921 14.8, 355278.8 6688923.3 14.8, 355278.8 6688923.7 14.8, 355291.2 6688925.2 14.8, 355294 6688925.6 14.8))
BATIMENT0000000302930114;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;6.7;21.6;26.5;7.1;Cadastre;;POLYGON Z ((355247.4 6688927.8 21.6, 355235.7 6688922.1 21.6, 355234.8 6688924.1 21.6, 355234.1 6688924.5 21.6, 355232.9 6688924.6 21.6, 355245.9 6688930.8 21.6, 355247.4 6688927.8 21.6))
BATIMENT0000000302930115;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;00;00;11.6;6.9;18.5;21.2;7.1;Cadastre;A 1.0;POLYGON Z ((355274.3 6688937.6 18.5, 355278.8 6688923.7 18.5, 355278.8 6688923.3 18.5, 355265.4 6688921 18.5, 355260.3 6688934.4 18.5, 355274.3 6688937.6 18.5), (355266.9 6688922.6 18.5, 355268.5 6688923 18.5, 355267.9 6688925.5 18.5, 355266 6688924.9 18.5, 355266.9 6688922.6 18.5))
BATIMENT0000000302929885;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;14;20;18.5;6.9;25.4;28.6;7.6;Cadastre;A 1.0;POLYGON Z ((355293.4 6688929.4 25.4, 355286.6 6688928.3 25.4, 355285.9 6688932.8 25.4, 355282.5 6688932.3 25.4, 355281.7 6688932.5 25.4, 355281.5 6688934.5 25.4, 355280.5 6688934.3 25.4, 355279.7 6688938.8 25.4, 355284.5 6688939.5 25.4, 355284.8 6688939.9 25.4, 355292.5 6688940.9 25.4, 355292.6 6688941.1 25.4, 355300.4 6688942.5 25.4, 355304 6688919.6 25.4, 355296.5 6688919.2 25.4, 355295.5 6688925.9 25.4, 355294 6688925.6 25.4, 355293.4 6688929.4 25.4))
BATIMENT0000000302931574;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.0;6.2;25.2;29.1;7.4;Cadastre;;POLYGON Z ((355290.3 6689039.1 25.2, 355294.1 6689032 25.2, 355306.3 6689038.3 25.2, 355312.3 6689027.2 25.2, 355287.9 6689014.5 25.2, 355278.3 6689032.8 25.2, 355290.3 6689039.1 25.2))
BATIMENT0000000302931573;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;6.0;10;30;19.8;5.8;25.7;28.7;6.8;Cadastre;A 1.0;POLYGON Z ((355270.8 6689047 25.7, 355304.7 6689064.3 25.7, 355313.3 6689048.2 25.7, 355307 6689045 25.7, 355304.1 6689050.4 25.7, 355288.7 6689042.4 25.7, 355290.3 6689039.1 25.7, 355278.3 6689032.8 25.7, 355270.8 6689047 25.7))
BATIMENT0000000302931584;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1730-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;20.0;5.6;25.7;28.7;6.8;Cadastre;A 1.0;POLYGON Z ((355267.4 6689053.6 25.7, 355258.9 6689070.1 25.7, 355272.4 6689076.9 25.7, 355285 6689083.4 25.7, 355292.4 6689087.4 25.7, 355301.2 6689071 25.7, 355267.4 6689053.6 25.7))
BATIMENT0000000302931585;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;10;20;19.0;5.7;24.7;27.1;7.3;Cadastre;A 1.0;POLYGON Z ((355250.7 6689086.1 24.7, 355283.7 6689103.6 24.7, 355292.4 6689087.4 24.7, 355285 6689083.4 24.7, 355281.6 6689089.6 24.7, 355280.5 6689090.3 24.7, 355272.2 6689086.2 24.7, 355269 6689085.7 24.7, 355268.9 6689083.2 24.7, 355272.4 6689076.9 24.7, 355258.9 6689070.1 24.7, 355250.7 6689086.1 24.7))
BATIMENT0000000302927385;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;3.4;11.7;15.1;18.7;13.2;Cadastre;A 1.0;POLYGON Z ((354936.3 6689026.3 15.1, 354930.6 6689022.3 15.1, 354929 6689024.8 15.1, 354934.8 6689028.6 15.1, 354936.3 6689026.3 15.1))
BATIMENT0000000302927384;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;3.0;12.0;15.0;18.0;13.7;Cadastre;A 1.0;POLYGON Z ((354932.8 6689031.9 15, 354934.8 6689028.6 15, 354929 6689024.8 15, 354928.7 6689025.6 15, 354929.4 6689026.2 15, 354927.9 6689028.3 15, 354930.5 6689030.2 15, 354932.8 6689031.9 15))
BATIMENT0000000302927387;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.9;11.4;26.3;30.4;14.8;Cadastre;C 0.2;POLYGON Z ((354930.5 6689030.2 26.3, 354927.9 6689028.3 26.3, 354922.6 6689024.6 26.3, 354914.4 6689034.5 26.3, 354915.5 6689035.2 26.3, 354919 6689037.8 26.3, 354919.6 6689036.6 26.3, 354922.3 6689038.7 26.3, 354930.5 6689030.2 26.3))
BATIMENT0000000302927393;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;50;20;15.1;14.8;30.0;31.3;15.8;Cadastre;A 1.0;POLYGON Z ((354903.6 6689038.3 30, 354907.6 6689033.3 30, 354909.5 6689030.6 30, 354908.9 6689030.2 30, 354906.1 6689027.8 30, 354904.9 6689029.2 30, 354902.4 6689027.2 30, 354896.7 6689032.4 30, 354903.6 6689038.3 30))
BATIMENT0000000302927394;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;14.4;24.8;25.7;15.0;Cadastre;;POLYGON Z ((354912.5 6689035.2 24.8, 354914.5 6689036.4 24.8, 354915.5 6689035.2 24.8, 354914.4 6689034.5 24.8, 354913.6 6689033.9 24.8, 354912.5 6689035.2 24.8))
BATIMENT0000000302927392;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;12.4;14.0;26.5;28.0;15.4;Cadastre;A 1.0;POLYGON Z ((354927.6 6689042.8 26.5, 354922.3 6689038.7 26.5, 354919.6 6689036.6 26.5, 354919 6689037.8 26.5, 354915.5 6689035.2 26.5, 354914.5 6689036.4 26.5, 354912.5 6689035.2 26.5, 354913.6 6689033.9 26.5, 354909.5 6689030.6 26.5, 354907.6 6689033.3 26.5, 354911.9 6689036.3 26.5, 354914.7 6689038.6 26.5, 354916.2 6689039.7 26.5, 354924.6 6689046.1 26.5, 354927.6 6689042.8 26.5))
BATIMENT0000000302927396;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.8;14.6;30.5;32.4;15.3;Cadastre;;POLYGON Z ((354913.1 6689040.6 30.5, 354914.5 6689041.7 30.5, 354916.2 6689039.7 30.5, 354914.7 6689038.6 30.5, 354913.1 6689040.6 30.5))
BATIMENT0000000302927395;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1775-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;16.3;14.6;31.0;32.7;15.9;Cadastre;A 1.0;POLYGON Z ((354904.1 6689038.8 31, 354904.5 6689038.6 31, 354907.4 6689042.4 31, 354919.8 6689051.8 31, 354924.6 6689046.1 31, 354916.2 6689039.7 31, 354914.5 6689041.7 31, 354913.1 6689040.6 31, 354914.7 6689038.6 31, 354911.9 6689036.3 31, 354907.6 6689033.3 31, 354903.6 6689038.3 31, 354904.1 6689038.8 31))
BATIMENT0000000302927382;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;35;20;17.2;13.0;30.2;33.4;15.7;Cadastre;A 1.0;POLYGON Z ((354939.6 6689037.3 30.2, 354935.8 6689041.7 30.2, 354925.3 6689053.7 30.2, 354931 6689058.2 30.2, 354937.3 6689057.7 30.2, 354943.3 6689051.4 30.2, 354948.5 6689046 30.2, 354941.4 6689039 30.2, 354939.6 6689037.3 30.2))
BATIMENT0000000302927417;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;22.2;15.6;37.8;41.2;19.7;Cadastre;A 1.0;POLYGON Z ((354890.5 6689078.8 37.8, 354898.4 6689069.7 37.8, 354895.7 6689067.7 37.8, 354897.8 6689065 37.8, 354900.3 6689067.1 37.8, 354901.1 6689066.4 37.8, 354909.6 6689056.3 37.8, 354904.3 6689051.8 37.8, 354895.8 6689061.9 37.8, 354885.3 6689053.8 37.8, 354893.9 6689043 37.8, 354889.1 6689039 37.8, 354880.2 6689049.7 37.8, 354879.2 6689051 37.8, 354880.3 6689051.8 37.8, 354880.8 6689055.1 37.8, 354879.9 6689056.2 37.8, 354876.9 6689053.8 37.8, 354870.3 6689061.7 37.8, 354890.5 6689078.8 37.8))
BATIMENT0000000302927378;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;19.5;9.2;28.7;32.2;12.2;Cadastre;A 1.0;POLYGON Z ((354975.3 6689018 28.7, 354979.2 6689026.9 28.7, 354988.9 6689023.8 28.7, 354985.5 6689014.2 28.7, 354975.3 6689018 28.7))
BATIMENT0000000302927379;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;34;20;19.4;9.7;29.1;32.4;13.1;Cadastre;A 1.0;POLYGON Z ((354962.4 6689024 29.1, 354967.2 6689032.5 29.1, 354972.2 6689029.9 29.1, 354979.2 6689026.9 29.1, 354975.3 6689018 29.1, 354962.4 6689024 29.1))
BATIMENT0000000302927380;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.7;10.2;29.9;33.6;13.8;Cadastre;A 1.0;POLYGON Z ((354952.6 6689029.7 29.9, 354958.8 6689037.8 29.9, 354962.9 6689035.3 29.9, 354967.2 6689032.5 29.9, 354962.4 6689024 29.9, 354952.6 6689029.7 29.9))
BATIMENT0000000302927381;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;30;20;18.5;11.4;30.0;33.6;14.5;Cadastre;A 1.0;POLYGON Z ((354941.4 6689039 30, 354948.5 6689046 30, 354953.9 6689041.5 30, 354958.8 6689037.8 30, 354952.6 6689029.7 30, 354941.4 6689039 30))
BATIMENT0000000302927659;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:37;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;9.7;16.5;25.2;16.7;Cadastre;;POLYGON Z ((355048.8 6689031.7 16.5, 355045.5 6689032.6 16.5, 355045.6 6689032.4 16.5, 355045 6689032.4 16.5, 355045.1 6689032.8 16.5, 355037.2 6689035 16.5, 355037.2 6689034.8 16.5, 355036.6 6689034.9 16.5, 355036.6 6689035.3 16.5, 355028.9 6689037.4 16.5, 355028.8 6689037.1 16.5, 355028.1 6689037.3 16.5, 355028.1 6689037.8 16.5, 355020.2 6689040.2 16.5, 355020.2 6689039.8 16.5, 355019.4 6689040 16.5, 355019.7 6689041.5 16.5, 355015.9 6689042.6 16.5, 355015.6 6689042.3 16.5, 355015.8 6689041.7 16.5, 355015.4 6689041.4 16.5, 355015.1 6689042 16.5, 355011.9 6689039.9 16.5, 355012.2 6689039.5 16.5, 355011.7 6689039.2 16.5, 355011.4 6689039.6 16.5, 355008.2 6689037.7 16.5, 355008.5 6689037.3 16.5, 355007.9 6689036.8 16.5, 355007.6 6689037.2 16.5, 355004.8 6689035.5 16.5, 355004.8 6689035.2 16.5, 355004.5 6689034.7 16.5, 355004 6689034.9 16.5, 355002.3 6689033.8 16.5, 355000.4 6689036.5 16.5, 354998.8 6689035.8 16.5, 354987.3 6689039.2 16.5, 354987 6689039 16.5, 354986.3 6689039 16.5, 354987.9 6689044.2 16.5, 354988.2 6689044.3 16.5, 355000.2 6689041.9 16.5, 355017.7 6689052.9 16.5, 355019.7 6689050.5 16.5, 355040.9 6689043.9 16.5, 355041 6689043.9 16.5, 355052.9 6689040.5 16.5, 355052 6689037.8 16.5, 355051.5 6689037.9 16.5, 355049.4 6689031.3 16.5, 355048.9 6689031.2 16.5, 355048.8 6689031.7 16.5))
BATIMENT0000000302930223;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;10;20;17.1;11.1;28.2;32.6;15.6;Cadastre;C 0.4;POLYGON Z ((355046.2 6689078 28.2, 355033.7 6689058.1 28.2, 355022.1 6689056.9 28.2, 355022.9 6689064.8 28.2, 355028.2 6689072.4 28.2, 355026.9 6689073.1 28.2, 355029.4 6689076.9 28.2, 355030.7 6689076.2 28.2, 355031.9 6689077.9 28.2, 355031.6 6689078.7 28.2, 355031.7 6689079.9 28.2, 355032.3 6689080.8 28.2, 355031.3 6689081.8 28.2, 355030.5 6689080.7 28.2, 355030.1 6689080.9 28.2, 355033.5 6689085.8 28.2, 355046.2 6689078 28.2))
BATIMENT0000000302927699;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:37;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;16.7;28.5;29.9;17.2;Cadastre;;POLYGON Z ((354959.3 6689082.5 28.5, 355005.9 6689064.4 28.5, 355002.4 6689055.4 28.5, 354954.7 6689074.2 28.5, 354957.8 6689082 28.5, 354949.1 6689083.8 28.5, 354956.3 6689095.1 28.5, 354962.5 6689091.3 28.5, 354959.3 6689082.5 28.5))
BATIMENT0000000302930224;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;10;20;17.4;13.2;30.6;34.4;17.4;Cadastre;A 1.0;POLYGON Z ((355033.5 6689085.8 30.6, 355030.1 6689080.9 30.6, 355029 6689078.9 30.6, 355028.5 6689079.1 30.6, 355027.7 6689078.1 30.6, 355027 6689077.1 30.6, 355026.3 6689077.6 30.6, 355025.9 6689076.9 30.6, 355025 6689077.3 30.6, 355018.4 6689067.3 30.6, 355019.2 6689065.7 30.6, 355021 6689066.1 30.6, 355022.9 6689064.8 30.6, 355022.1 6689056.9 30.6, 355019.2 6689056.6 30.6, 355018.5 6689058.1 30.6, 355016.4 6689057.9 30.6, 355012.7 6689069.3 30.6, 355013.8 6689069.8 30.6, 355014.2 6689072.2 30.6, 355009.4 6689075.6 30.6, 355011.9 6689079.7 30.6, 355015.2 6689077.7 30.6, 355015.9 6689078.7 30.6, 355018.4 6689082.7 30.6, 355015.1 6689084.8 30.6, 355021 6689094 30.6, 355033.5 6689085.8 30.6))
BATIMENT0000000302930226;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.7;13.0;31.8;32.6;15.6;Cadastre;;POLYGON Z ((355030.1 6689080.9 31.8, 355030.5 6689080.7 31.8, 355031.7 6689079.9 31.8, 355031.6 6689078.7 31.8, 355031.9 6689077.9 31.8, 355030.7 6689076.2 31.8, 355029.4 6689076.9 31.8, 355027.7 6689078.1 31.8, 355028.5 6689079.1 31.8, 355029 6689078.9 31.8, 355030.1 6689080.9 31.8))
BATIMENT0000000302930227;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;15.9;32.3;33.7;17.3;Cadastre;;POLYGON Z ((355012.5 6689080.7 32.3, 355015.9 6689078.7 32.3, 355015.2 6689077.7 32.3, 355011.9 6689079.7 32.3, 355012.5 6689080.7 32.3))
BATIMENT0000000302927419;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;21.1;16.2;37.4;38.6;18.6;Cadastre;A 1.0;POLYGON Z ((354924.4 6689074 37.4, 354923.9 6689068.3 37.4, 354909.6 6689056.3 37.4, 354901.1 6689066.4 37.4, 354903.4 6689068.3 37.4, 354903.2 6689068.8 37.4, 354904.4 6689069.8 37.4, 354906 6689067.2 37.4, 354910.4 6689070.5 37.4, 354908.4 6689073 37.4, 354912.2 6689076.2 37.4, 354910.9 6689077.5 37.4, 354907.2 6689081.7 37.4, 354913.4 6689086.9 37.4, 354924.4 6689074 37.4))
BATIMENT0000000302927420;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;21.4;17.7;39.2;41.7;19.7;Cadastre;A 1.0;POLYGON Z ((354888.5 6689081 39.2, 354899.5 6689090.3 39.2, 354893.3 6689097.6 39.2, 354900 6689103.1 39.2, 354913.4 6689086.9 39.2, 354907.2 6689081.7 39.2, 354910.9 6689077.5 39.2, 354902.1 6689070.3 39.2, 354903.2 6689068.8 39.2, 354903.4 6689068.3 39.2, 354901.1 6689066.4 39.2, 354900.3 6689067.1 39.2, 354898.4 6689069.7 39.2, 354890.5 6689078.8 39.2, 354888.5 6689081 39.2))
BATIMENT0000000302927491;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1790-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;22.0;16.7;38.7;41.3;18.0;Cadastre;A 1.0;POLYGON Z ((354939.5 6689102.4 38.7, 354943.9 6689097.6 38.7, 354935.8 6689085.4 38.7, 354936.3 6689085 38.7, 354932.4 6689079.2 38.7, 354926.9 6689085.7 38.7, 354927.4 6689086 38.7, 354917.8 6689096.7 38.7, 354923.4 6689102.6 38.7, 354925 6689100.7 38.7, 354927.7 6689097.7 38.7, 354929.2 6689101.2 38.7, 354927.4 6689103.3 38.7, 354925.7 6689105 38.7, 354931.7 6689111.1 38.7, 354939.5 6689102.4 38.7))
BATIMENT0000000302927496;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.6;17.3;40.0;41.9;17.8;Cadastre;;POLYGON Z ((354923.4 6689102.6 40, 354925.7 6689105 40, 354927.4 6689103.3 40, 354925 6689100.7 40, 354923.4 6689102.6 40))
BATIMENT0000000302927490;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;21.5;17.6;39.1;41.2;18.5;Cadastre;C 0.1;POLYGON Z ((354911.8 6689103.7 39.1, 354916.4 6689107.3 39.1, 354917 6689106.4 39.1, 354919.2 6689106.5 39.1, 354920.5 6689107.8 39.1, 354918.8 6689109.5 39.1, 354926.9 6689116.4 39.1, 354931.7 6689111.1 39.1, 354925.7 6689105 39.1, 354924.9 6689106 39.1, 354922.4 6689104 39.1, 354923.4 6689102.6 39.1, 354917.8 6689096.7 39.1, 354911.8 6689103.7 39.1))
BATIMENT0000000302927497;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;13;20;16.2;16.9;33.2;40.6;17.9;Cadastre;A 1.0;POLYGON Z ((354947.9 6689104.3 33.2, 354946.7 6689104.2 33.2, 354933.8 6689118.6 33.2, 354938.3 6689123 33.2, 354953.2 6689112.3 33.2, 354947.9 6689104.3 33.2))
BATIMENT0000000302927487;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;12;30;21.6;18.0;39.6;41.5;18.9;Cadastre;A 1.0;POLYGON Z ((354904 6689112.6 39.6, 354908.8 6689116.8 39.6, 354912.3 6689112.5 39.6, 354917.8 6689117.1 39.6, 354914.1 6689121.3 39.6, 354918.8 6689125.2 39.6, 354926.9 6689116.4 39.6, 354918.8 6689109.5 39.6, 354917.9 6689108.6 39.6, 354917.1 6689109.5 39.6, 354917.3 6689111.2 39.6, 354916.7 6689112.1 39.6, 354914.1 6689110 39.6, 354916.4 6689107.3 39.6, 354911.8 6689103.7 39.6, 354904 6689112.6 39.6))
BATIMENT0000000302927485;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.6;18.3;40.9;42.2;18.9;Cadastre;;POLYGON Z ((354917.8 6689117.1 40.9, 354912.3 6689112.5 40.9, 354908.8 6689116.8 40.9, 354912 6689119.5 40.9, 354914.1 6689121.3 40.9, 354917.8 6689117.1 40.9))
BATIMENT0000000302927488;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.4;18.3;37.7;40.7;18.9;Cadastre;;POLYGON Z ((354912.2 6689123.4 37.7, 354914.1 6689121.3 37.7, 354912 6689119.5 37.7, 354910.2 6689121.7 37.7, 354912.2 6689123.4 37.7))
BATIMENT0000000302927486;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.9;18.7;39.6;42.0;19.1;Cadastre;;POLYGON Z ((354910.2 6689121.7 39.6, 354912 6689119.5 39.6, 354908.8 6689116.8 39.6, 354902.6 6689123.7 39.6, 354906 6689126.4 39.6, 354910.2 6689121.7 39.6))
BATIMENT0000000302930225;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.2;12.5;30.8;32.2;14.6;Cadastre;;POLYGON Z ((355031.7 6689079.9 30.8, 355030.5 6689080.7 30.8, 355031.3 6689081.8 30.8, 355032.3 6689080.8 30.8, 355031.7 6689079.9 30.8))
BATIMENT0000000302930228;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;16.7;28.7;32.9;17.9;Cadastre;;POLYGON Z ((355003.6 6689082.7 28.7, 355002.3 6689083.6 28.7, 355003.1 6689085 28.7, 355004.5 6689084.1 28.7, 355003.6 6689082.7 28.7))
BATIMENT0000000302927576;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;13.8;16.7;17.9;16.6;Cadastre;;POLYGON Z ((354989.2 6689086 16.7, 354993.3 6689083.4 16.7, 354991.7 6689080.8 16.7, 354987.3 6689083.5 16.7, 354987.5 6689083.9 16.7, 354983.9 6689086.2 16.7, 354983.2 6689085.2 16.7, 354981.7 6689086.1 16.7, 354983.8 6689089.5 16.7, 354985.3 6689088.6 16.7, 354989.2 6689086 16.7))
BATIMENT0000000302927572;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;;;21.6;13.2;34.9;37.9;17.9;Cadastre;A 1.0;POLYGON Z ((355009 6689075 34.9, 355004.6 6689077.8 34.9, 355007.4 6689082.2 34.9, 355004.5 6689084.1 34.9, 355003.1 6689085 34.9, 355002.3 6689083.6 34.9, 354997.1 6689075 34.9, 354993.3 6689077.5 34.9, 354999.3 6689087.5 34.9, 354996.7 6689089.1 34.9, 355005.5 6689103.6 34.9, 355021 6689094 34.9, 355015.1 6689084.8 34.9, 355012.5 6689080.7 34.9, 355011.9 6689079.7 34.9, 355009.4 6689075.6 34.9, 355009 6689075 34.9))
BATIMENT0000000302927577;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.1;14.0;32.1;36.9;15.1;Cadastre;;POLYGON Z ((354995.7 6689093.5 32.1, 354992.9 6689089.2 32.1, 354991.9 6689090 32.1, 354987.3 6689093.5 32.1, 354986.5 6689094 32.1, 354989 6689097.7 32.1, 354995.7 6689093.5 32.1))
BATIMENT0000000302927700;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.7;16.9;23.6;23.8;17.1;Cadastre;A 1.0;POLYGON Z ((354958.8 6689098.8 23.6, 354964.7 6689094.9 23.6, 354962.5 6689091.3 23.6, 354956.3 6689095.1 23.6, 354958.8 6689098.8 23.6))
BATIMENT0000000302927573;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;7.0;10;20;22.8;13.9;36.7;39.2;16.4;Cadastre;A 1.0;POLYGON Z ((354992.9 6689089.2 36.7, 354995.7 6689093.5 36.7, 354989 6689097.7 36.7, 354986.5 6689094 36.7, 354987.3 6689093.5 36.7, 354986.8 6689092.7 36.7, 354987.6 6689092.2 36.7, 354985.3 6689088.6 36.7, 354983.8 6689089.5 36.7, 354978.6 6689092.8 36.7, 354978.8 6689093.1 36.7, 354981.7 6689097.6 36.7, 354983.9 6689101.2 36.7, 354984.5 6689102.1 36.7, 354991.3 6689112.8 36.7, 355005.5 6689103.6 36.7, 354996.7 6689089.1 36.7, 354995.7 6689087.5 36.7, 354993.3 6689083.4 36.7, 354989.2 6689086 36.7, 354991.9 6689090 36.7, 354992.9 6689089.2 36.7))
BATIMENT0000000302927574;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.5;13.3;36.8;39.7;16.5;Cadastre;;POLYGON Z ((354983.9 6689101.2 36.8, 354980.8 6689103.2 36.8, 354979.6 6689102.9 36.8, 354977.8 6689100.3 36.8, 354976.9 6689100.8 36.8, 354979.9 6689104.9 36.8, 354984.5 6689102.1 36.8, 354983.9 6689101.2 36.8))
BATIMENT0000000302927575;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;24.2;14.8;39.0;42.0;16.9;Cadastre;A 1.0;POLYGON Z ((354971.6 6689097.8 39, 354974 6689101.5 39, 354984.1 6689117.4 39, 354991.3 6689112.8 39, 354984.5 6689102.1 39, 354979.9 6689104.9 39, 354976.9 6689100.8 39, 354977.8 6689100.3 39, 354981.7 6689097.6 39, 354978.8 6689093.1 39, 354971.6 6689097.8 39))
BATIMENT0000000302927578;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;00;00;25.6;13.2;38.8;42.1;17.0;Cadastre;A 1.0;POLYGON Z ((354970.7 6689122.8 38.8, 354973.4 6689124.4 38.8, 354984.1 6689117.4 38.8, 354974 6689101.5 38.8, 354971.9 6689102.9 38.8, 354971.2 6689103.4 38.8, 354974.2 6689108 38.8, 354973.3 6689109.5 38.8, 354971.3 6689110.9 38.8, 354968.5 6689106.8 38.8, 354970.8 6689105.2 38.8, 354970.1 6689104.1 38.8, 354969.8 6689103.8 38.8, 354961.5 6689109.3 38.8, 354961.7 6689109.6 38.8, 354970.7 6689122.8 38.8))
BATIMENT0000000302928336;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;23;20;15.5;21.7;37.2;38.7;21.9;Cadastre;C 0.6;POLYGON Z ((354811.4 6689083.2 37.2, 354801.7 6689095 37.2, 354805.7 6689098.4 37.2, 354810.9 6689092.1 37.2, 354814.2 6689094.8 37.2, 354811.3 6689098.3 37.2, 354818.4 6689104.2 37.2, 354818.6 6689105.8 37.2, 354816.3 6689108.6 37.2, 354821.6 6689113 37.2, 354824 6689110.1 37.2, 354831.9 6689100.4 37.2, 354811.4 6689083.2 37.2))
BATIMENT0000000302928334;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;23;20;18.7;21.4;40.2;43.6;22.0;Cadastre;C 0.9;POLYGON Z ((354813.4 6689123 40.2, 354819.8 6689115.2 40.2, 354799.2 6689098.1 40.2, 354792.8 6689105.9 40.2, 354813.4 6689123 40.2))
BATIMENT0000000302928338;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;21.5;35.2;38.2;21.9;Cadastre;;POLYGON Z ((354824 6689110.1 35.2, 354821.6 6689113 35.2, 354820.8 6689114 35.2, 354822.8 6689115.6 35.2, 354823.5 6689114.7 35.2, 354824.3 6689115.3 35.2, 354825.9 6689113.4 35.2, 354825.1 6689112.8 35.2, 354825.9 6689111.7 35.2, 354824 6689110.1 35.2))
BATIMENT0000000302928339;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1770-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;18.8;20.1;39.0;41.4;21.9;Cadastre;A 1.0;POLYGON Z ((354824.6 6689132.3 39, 354831.7 6689123.7 39, 354830.4 6689122.7 39, 354834.4 6689117.9 39, 354835.7 6689119 39, 354843.3 6689109.9 39, 354831.9 6689100.4 39, 354824 6689110.1 39, 354825.9 6689111.7 39, 354828.1 6689113.5 39, 354824.9 6689117.4 39, 354822.8 6689115.6 39, 354820.8 6689114 39, 354819.8 6689115.2 39, 354813.4 6689123 39, 354824.6 6689132.3 39))
BATIMENT0000000302928340;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;17.9;19.8;37.7;40.9;21.4;Cadastre;A 1.0;POLYGON Z ((354828.3 6689135.5 37.7, 354837.1 6689125.4 37.7, 354841.2 6689128.6 37.7, 354834.6 6689136.7 37.7, 354832.7 6689139.1 37.7, 354836.3 6689142.1 37.7, 354842 6689135.3 37.7, 354840.6 6689134.2 37.7, 354843.7 6689130.3 37.7, 354845.2 6689131.3 37.7, 354846.8 6689129.3 37.7, 354854.8 6689119.6 37.7, 354843.3 6689109.9 37.7, 354835.7 6689119 37.7, 354837.2 6689120.3 37.7, 354835 6689122.9 37.7, 354833.4 6689121.7 37.7, 354831.7 6689123.7 37.7, 354824.6 6689132.3 37.7, 354828.3 6689135.5 37.7))
BATIMENT0000000302928289;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;12;20;14.4;21.5;36.0;39.4;22.7;Cadastre;A 1.0;POLYGON Z ((354809 6689138.9 36, 354811.6 6689134.1 36, 354792.7 6689118.4 36, 354784.9 6689128.6 36, 354809 6689138.9 36))
BATIMENT0000000302928348;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.1;20.6;39.7;41.5;20.8;Cadastre;;POLYGON Z ((354843.7 6689130.3 39.7, 354840.6 6689134.2 39.7, 354842 6689135.3 39.7, 354843.6 6689133.3 39.7, 354845.2 6689131.3 39.7, 354843.7 6689130.3 39.7))
BATIMENT0000000302928342;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;19.7;19.5;39.2;43.2;20.3;Cadastre;A 1.0;POLYGON Z ((354866.4 6689129.3 39.2, 354863.8 6689132.4 39.2, 354858.5 6689138.6 39.2, 354859.5 6689139.5 39.2, 354870.7 6689147.8 39.2, 354873.1 6689144.5 39.2, 354873.4 6689144.2 39.2, 354873.5 6689144 39.2, 354873.6 6689143.8 39.2, 354874.1 6689143.4 39.2, 354874.6 6689142.9 39.2, 354874.8 6689142.8 39.2, 354875.3 6689142.3 39.2, 354875.6 6689142.1 39.2, 354875.8 6689141.9 39.2, 354876.2 6689141.6 39.2, 354876.7 6689141.2 39.2, 354876.9 6689141 39.2, 354877.3 6689140.8 39.2, 354878 6689140.3 39.2, 354878.1 6689140.2 39.2, 354879.2 6689139.6 39.2, 354880.3 6689139 39.2, 354880.7 6689138.8 39.2, 354880.9 6689138.8 39.2, 354881.8 6689138.6 39.2, 354882 6689138.6 39.2, 354882.5 6689138.5 39.2, 354882.9 6689138.4 39.2, 354883 6689138.3 39.2, 354883.2 6689138.2 39.2, 354883.4 6689138.1 39.2, 354883.5 6689137.9 39.2, 354883.5 6689137.6 39.2, 354883 6689125.6 39.2, 354875 6689119.2 39.2, 354868.6 6689126.7 39.2, 354866.4 6689129.3 39.2), (354871.2 6689133.4 39.2, 354873.5 6689135.4 39.2, 354870.4 6689138.8 39.2, 354865.9 6689138.7 39.2, 354865.8 6689137.5 39.2, 354867.7 6689137.6 39.2, 354868.6 6689136.5 39.2, 354871.2 6689133.4 39.2))
BATIMENT0000000302928346;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.7;22.2;35.9;;;Cadastre;;POLYGON Z ((354833.6 6689136 35.9, 354831.7 6689138.3 35.9, 354832.7 6689139.1 35.9, 354834.6 6689136.7 35.9, 354833.6 6689136 35.9))
BATIMENT0000000302928341;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;20;20;20.5;19.8;40.4;44.8;21.2;Cadastre;A 1.0;POLYGON Z ((354856.7 6689159.3 40.4, 354866.8 6689158.8 40.4, 354867.6 6689154.2 40.4, 354867.7 6689153.7 40.4, 354867.8 6689153.3 40.4, 354868.2 6689152.6 40.4, 354868.7 6689151.6 40.4, 354868.9 6689151.2 40.4, 354869.2 6689150.7 40.4, 354869.4 6689150.3 40.4, 354870 6689149.2 40.4, 354870.1 6689149 40.4, 354870.6 6689148.1 40.4, 354870.7 6689147.8 40.4, 354859.5 6689139.5 40.4, 354857.8 6689142 40.4, 354854.9 6689141.6 40.4, 354859 6689144.9 40.4, 354860 6689146.7 40.4, 354859.1 6689147.1 40.4, 354858 6689145.6 40.4, 354854.7 6689142.4 40.4, 354848.8 6689137.7 40.4, 354852.3 6689133.7 40.4, 354858.5 6689138.6 40.4, 354863.8 6689132.4 40.4, 354866.4 6689129.3 40.4, 354854.8 6689119.6 40.4, 354846.8 6689129.3 40.4, 354848.3 6689130.5 40.4, 354845.2 6689134.5 40.4, 354843.6 6689133.3 40.4, 354842 6689135.3 40.4, 354836.3 6689142.1 40.4, 354856.7 6689159.3 40.4))
BATIMENT0000000302930249;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;50;20;6.3;12.8;19.2;33.4;14.2;Cadastre;A 1.0;POLYGON Z ((355023.4 6689103.8 19.2, 355022.9 6689103.9 19.2, 355022.4 6689104.1 19.2, 355021.9 6689104.2 19.2, 355019.3 6689105.6 19.2, 355018.8 6689105.5 19.2, 355008.5 6689112.1 19.2, 355016.8 6689125.5 19.2, 355017.5 6689126.4 19.2, 355031 6689126.3 19.2, 355030.6 6689111.8 19.2, 355030.5 6689111.6 19.2, 355030.4 6689109.8 19.2, 355030.3 6689109.2 19.2, 355030.2 6689108.6 19.2, 355030 6689108 19.2, 355029.7 6689107.4 19.2, 355029.4 6689106.8 19.2, 355029.1 6689106.3 19.2, 355028.7 6689105.8 19.2, 355028.2 6689105.3 19.2, 355027.8 6689105 19.2, 355027.4 6689104.7 19.2, 355027.1 6689104.5 19.2, 355026.5 6689104.2 19.2, 355026.1 6689104.1 19.2, 355025.6 6689104 19.2, 355025.1 6689103.9 19.2, 355024.6 6689103.8 19.2, 355024.4 6689103.8 19.2, 355023.9 6689103.8 19.2, 355023.4 6689103.8 19.2), (355020.3 6689114.8 19.2, 355020.9 6689115.7 19.2, 355022.3 6689115.8 19.2, 355022.2 6689119.5 19.2, 355020.1 6689119.6 19.2, 355018.5 6689118.5 19.2, 355017.3 6689116.6 19.2, 355020.3 6689114.8 19.2))
BATIMENT0000000302927737;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:48:58;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;23.3;13.8;37.2;38.7;15.8;Cadastre;A 1.0;POLYGON Z ((354995.3 6689120.7 37.2, 355005.6 6689136.9 37.2, 355009.5 6689134.2 37.2, 355007.2 6689130.7 37.2, 355004.4 6689129.8 37.2, 355004.7 6689128.8 37.2, 355006.6 6689128.6 37.2, 355008.3 6689127.6 37.2, 355009.1 6689126 37.2, 355009.9 6689126.2 37.2, 355010.6 6689126.1 37.2, 355013.1 6689130 37.2, 355013.3 6689129.9 37.2, 355015.6 6689128.4 37.2, 355014.9 6689126.9 37.2, 355016.8 6689125.5 37.2, 355008.5 6689112.1 37.2, 354995.3 6689120.7 37.2))
BATIMENT0000000302927495;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;22.8;16.7;39.5;43.3;17.9;Cadastre;A 1.0;POLYGON Z ((354948.4 6689139.5 39.5, 354962.8 6689130.4 39.5, 354963.2 6689127.6 39.5, 354953.2 6689112.3 39.5, 354938.3 6689123 39.5, 354948.4 6689139.5 39.5), (354944.8 6689122.2 39.5, 354946.2 6689123.2 39.5, 354945.5 6689125.4 39.5, 354948.6 6689126.6 39.5, 354948.2 6689127.8 39.5, 354946.1 6689128.9 39.5, 354942.7 6689123.5 39.5, 354944.8 6689122.2 39.5))
BATIMENT0000000302930248;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;20;20;6.4;13.7;20.2;34.5;16.1;Cadastre;A 1.0;POLYGON Z ((355020.1 6689129.3 20.2, 355020.2 6689130.7 20.2, 355023.2 6689130.8 20.2, 355023.2 6689136.7 20.2, 355022.3 6689137.7 20.2, 355022.4 6689140.4 20.2, 355031.1 6689140 20.2, 355031.3 6689140 20.2, 355031 6689126.3 20.2, 355017.5 6689126.4 20.2, 355018.3 6689129.3 20.2, 355020.1 6689129.3 20.2))
BATIMENT0000000302930247;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;7.0;00;00;21.8;15.0;36.8;39.6;17.8;Cadastre;A 1.0;POLYGON Z ((355009.5 6689134.2 36.8, 355005.6 6689136.9 36.8, 355003.1 6689138.9 36.8, 355004.1 6689140.6 36.8, 355006.1 6689143.6 36.8, 355006.4 6689143.4 36.8, 355012.9 6689139.1 36.8, 355013.7 6689140.3 36.8, 355012.2 6689141.2 36.8, 355012.9 6689142.5 36.8, 355013.9 6689141.8 36.8, 355019.9 6689139.5 36.8, 355020.3 6689140.5 36.8, 355022.4 6689140.4 36.8, 355022.3 6689137.7 36.8, 355022.1 6689137.3 36.8, 355019.9 6689137.5 36.8, 355019.7 6689135.4 36.8, 355016.9 6689130.9 36.8, 355018.3 6689129.3 36.8, 355017.5 6689126.4 36.8, 355016.8 6689125.5 36.8, 355014.9 6689126.9 36.8, 355015.6 6689128.4 36.8, 355013.3 6689129.9 36.8, 355013.9 6689130.9 36.8, 355009.5 6689134.2 36.8))
BATIMENT0000000302927736;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;12;20;23.4;15.0;38.4;41.2;17.4;Cadastre;C 0.7;POLYGON Z ((354980.9 6689129.9 38.4, 354980.6 6689129.8 38.4, 354977.2 6689132 38.4, 354977.5 6689132.3 38.4, 354976.9 6689134.7 38.4, 354976.6 6689134.8 38.4, 354978.9 6689138.3 38.4, 354979 6689138.1 38.4, 354985.7 6689148.4 38.4, 354995.7 6689142 38.4, 354993.3 6689138.4 38.4, 354993.9 6689136.7 38.4, 354994.1 6689136.6 38.4, 354993.9 6689136.3 38.4, 354996.6 6689134.5 38.4, 355000.6 6689135 38.4, 355003.1 6689138.9 38.4, 355005.6 6689136.9 38.4, 354995.3 6689120.7 38.4, 354980.9 6689129.9 38.4))
BATIMENT0000000302927738;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;15.8;27.7;37.2;18.2;Cadastre;;POLYGON Z ((355000.3 6689149 27.7, 355004.6 6689146.1 27.7, 355007.1 6689144.6 27.7, 355006.4 6689143.4 27.7, 355006.1 6689143.6 27.7, 355004.1 6689140.6 27.7, 354997.5 6689144.7 27.7, 355000.3 6689149 27.7))
BATIMENT0000000302930250;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;12;20;19.9;15.0;34.9;38.7;18.7;Cadastre;A 1.0;POLYGON Z ((355012.9 6689142.5 34.9, 355005.4 6689147.4 34.9, 355006.7 6689149.7 34.9, 355006.5 6689149.8 34.9, 355007.5 6689154.7 34.9, 355008 6689156.6 34.9, 355015.3 6689156.1 34.9, 355015.6 6689156.3 34.9, 355023.4 6689155.4 34.9, 355023.5 6689161 34.9, 355023.9 6689161.6 34.9, 355025 6689161.6 34.9, 355025 6689161.3 34.9, 355034.5 6689161 34.9, 355034.1 6689140 34.9, 355031.3 6689140 34.9, 355031.1 6689140 34.9, 355022.4 6689140.4 34.9, 355020.3 6689140.5 34.9, 355019.9 6689139.5 34.9, 355013.9 6689141.8 34.9, 355012.9 6689142.5 34.9), (355018.4 6689145.1 34.9, 355021.2 6689145.7 34.9, 355021.4 6689147.3 34.9, 355014.7 6689148.3 34.9, 355014.3 6689145.6 34.9, 355018.4 6689145.1 34.9))
BATIMENT0000000302927739;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;12;20;20.5;16.9;37.4;41.4;18.7;Cadastre;A 1.0;POLYGON Z ((354993.4 6689160.4 37.4, 355003.5 6689153.9 37.4, 355002.6 6689152.4 37.4, 355006.5 6689149.8 37.4, 355006.7 6689149.7 37.4, 355005.4 6689147.4 37.4, 355004.6 6689146.1 37.4, 355000.3 6689149 37.4, 354997.5 6689144.7 37.4, 354995.7 6689142 37.4, 354985.7 6689148.4 37.4, 354993.4 6689160.4 37.4))
BATIMENT0000000302927595;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;20;22.3;16.8;39.1;42.5;18.7;Cadastre;A 1.0;POLYGON Z ((354964.5 6689140.4 39.1, 354954 6689147.1 39.1, 354962.4 6689160.4 39.1, 354959.8 6689162 39.1, 354962 6689165.6 39.1, 354962.3 6689165.5 39.1, 354980 6689154.1 39.1, 354972.2 6689142.1 39.1, 354972.3 6689141.9 39.1, 354970.2 6689138.6 39.1, 354969.9 6689138.8 39.1, 354967.9 6689138.3 39.1, 354967.8 6689138.1 39.1, 354964.4 6689140.3 39.1, 354964.5 6689140.4 39.1), (354965.5 6689151.1 39.1, 354967.8 6689154.8 39.1, 354967.5 6689155.3 39.1, 354967.6 6689155.6 39.1, 354969.9 6689159.3 39.1, 354967.2 6689161 39.1, 354963 6689154.4 39.1, 354963.6 6689152.9 39.1, 354964.9 6689152 39.1, 354965.5 6689151.1 39.1))
BATIMENT0000000302927594;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;21.0;17.9;39.0;42.7;19.5;Cadastre;A 1.0;POLYGON Z ((354951.2 6689148.9 39, 354951.1 6689148.8 39, 354942.7 6689154.3 39, 354942.8 6689154.4 39, 354951.1 6689167.4 39, 354953.8 6689165.8 39, 354956.1 6689169.5 39, 354956.8 6689169 39, 354961.3 6689166.1 39, 354962 6689165.6 39, 354959.8 6689162 39, 354962.4 6689160.4 39, 354954 6689147.1 39, 354951.2 6689148.9 39), (354957.4 6689159 39, 354959.3 6689162 39, 354953.7 6689165.5 39, 354952.4 6689163.4 39, 354952.3 6689161.7 39, 354952.9 6689161.8 39, 354953.3 6689161.6 39, 354953.9 6689161.1 39, 354954.6 6689161.1 39, 354955.2 6689160.9 39, 354955.9 6689160.3 39, 354956.1 6689159.9 39, 354957.4 6689159 39))
BATIMENT0000000302927740;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;22.6;17.8;40.5;42.9;18.7;Cadastre;A 1.0;POLYGON Z ((354999.6 6689170 40.5, 354999.4 6689170.1 40.5, 355001.6 6689173.7 40.5, 355005.4 6689174 40.5, 355005.5 6689173.9 40.5, 355014.3 6689174.9 40.5, 355015.5 6689165.9 40.5, 355015.9 6689165.8 40.5, 355016.9 6689158.6 40.5, 355015.6 6689156.3 40.5, 355015.3 6689156.1 40.5, 355008 6689156.6 40.5, 355010.6 6689159.5 40.5, 355011.6 6689159.8 40.5, 355012.7 6689162.9 40.5, 355012 6689163.8 40.5, 355011.1 6689163.1 40.5, 355010.4 6689162.8 40.5, 355009.5 6689162.9 40.5, 355009 6689162.1 40.5, 355007.6 6689161.1 40.5, 355005.5 6689160.5 40.5, 355006 6689158.3 40.5, 355006.9 6689158 40.5, 355006.2 6689155.2 40.5, 355007.5 6689154.7 40.5, 355006.5 6689149.8 40.5, 355002.6 6689152.4 40.5, 355003.5 6689153.9 40.5, 354993.4 6689160.4 40.5, 354999.6 6689170 40.5))
BATIMENT0000000302927592;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1977-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;12;20;24.0;17.3;41.3;43.7;19.5;Cadastre;A 1.0;POLYGON Z ((354980 6689154.1 41.3, 354962.3 6689165.5 41.3, 354964.6 6689168.7 41.3, 354961.7 6689169.3 41.3, 354961.9 6689172.1 41.3, 354959.5 6689172.6 41.3, 354960 6689177.5 41.3, 354967.4 6689172.3 41.3, 354969.1 6689174.6 41.3, 354971.9 6689172.9 41.3, 354972.4 6689172.6 41.3, 354971.2 6689170.5 41.3, 354971.1 6689169.3 41.3, 354971.5 6689169 41.3, 354971.8 6689168.4 41.3, 354971.7 6689167.9 41.3, 354973.9 6689166.7 41.3, 354975.2 6689167.1 41.3, 354975.5 6689168.1 41.3, 354976.6 6689170.1 41.3, 354977.2 6689169.8 41.3, 354986.5 6689164.1 41.3, 354980 6689154.1 41.3))
BATIMENT0000000302927599;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.0;18.7;39.7;40.7;19.7;Cadastre;;POLYGON Z ((354953.8 6689165.8 39.7, 354951.1 6689167.4 39.7, 354953.6 6689171.4 39.7, 354956.2 6689169.7 39.7, 354956.1 6689169.5 39.7, 354953.8 6689165.8 39.7))
BATIMENT0000000302930251;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;16.8;15.6;32.4;35.3;18.1;Cadastre;A 1.0;POLYGON Z ((355029.8 6689176.5 32.4, 355030 6689176.7 32.4, 355034.3 6689176.8 32.4, 355034.9 6689176.3 32.4, 355034.5 6689161 32.4, 355025 6689161.3 32.4, 355025 6689161.6 32.4, 355025 6689165.6 32.4, 355023.9 6689165.9 32.4, 355023.5 6689166.3 32.4, 355023.3 6689166.8 32.4, 355015.9 6689165.8 32.4, 355015.5 6689165.9 32.4, 355014.3 6689174.9 32.4, 355029.8 6689176.5 32.4))
BATIMENT0000000302927593;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;21.3;17.8;39.2;42.3;19.1;Cadastre;A 1.0;POLYGON Z ((354989.9 6689179.2 39.2, 354989.8 6689179 39.2, 354991.7 6689172 39.2, 354986.5 6689164.1 39.2, 354977.2 6689169.8 39.2, 354978.5 6689171.9 39.2, 354979.2 6689172.4 39.2, 354978.5 6689174.6 39.2, 354973.8 6689175.9 39.2, 354971.9 6689172.9 39.2, 354969.1 6689174.6 39.2, 354968.8 6689174.9 39.2, 354969.3 6689175.7 39.2, 354970.7 6689177.8 39.2, 354978.5 6689181.2 39.2, 354979.2 6689181.4 39.2, 354980.1 6689178.8 39.2, 354982.1 6689179.6 39.2, 354981.6 6689181.5 39.2, 354987.9 6689183.8 39.2, 354989.9 6689179.2 39.2))
BATIMENT0000000302930253;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;10;20;15.2;16.4;31.6;34.7;18.8;Cadastre;A 1.0;POLYGON Z ((355007.5 6689181.1 31.6, 355006.5 6689188 31.6, 355013.5 6689188.9 31.6, 355013.4 6689189.1 31.6, 355014.6 6689189.2 31.6, 355015.4 6689182.1 31.6, 355007.5 6689181.1 31.6))
BATIMENT0000000302927598;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1798-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;10;20;21.4;19.0;40.4;43.4;20.1;Cadastre;A 1.0;POLYGON Z ((354960 6689178.2 40.4, 354960.4 6689180.9 40.4, 354959.4 6689182 40.4, 354955.5 6689180.5 40.4, 354948 6689198.4 40.4, 354951.2 6689199.8 40.4, 354951.2 6689200 40.4, 354960.8 6689203.9 40.4, 354968.4 6689185.7 40.4, 354965.8 6689184.3 40.4, 354969.3 6689175.7 40.4, 354968.8 6689174.9 40.4, 354969.1 6689174.6 40.4, 354967.4 6689172.3 40.4, 354960 6689177.5 40.4, 354960 6689178.2 40.4), (354958.8 6689183.3 40.4, 354964.3 6689185.7 40.4, 354963.4 6689188.1 40.4, 354963.3 6689190 40.4, 354962.1 6689190.8 40.4, 354960.9 6689189.1 40.4, 354959.6 6689188.5 40.4, 354959.4 6689188.9 40.4, 354956 6689187.4 40.4, 354955.8 6689186.1 40.4, 354958 6689185.2 40.4, 354958.8 6689183.3 40.4))
BATIMENT0000000302927741;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;20;20;22.7;16.5;39.2;43.5;19.0;Cadastre;A 1.0;POLYGON Z ((354999.1 6689180.1 39.2, 354997.4 6689181.2 39.2, 354991.4 6689195.2 39.2, 355002.2 6689199.7 39.2, 355003.2 6689200.1 39.2, 355005.3 6689195.2 39.2, 355009 6689196.8 39.2, 355011 6689192.6 39.2, 355011.6 6689192.9 39.2, 355013.4 6689189.1 39.2, 355013.5 6689188.9 39.2, 355006.5 6689188 39.2, 355007.5 6689181.1 39.2, 354999.1 6689180.1 39.2))
BATIMENT0000000302927596;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;7.0;00;00;22.0;18.4;40.5;43.2;19.6;Cadastre;A 1.0;POLYGON Z ((354968.4 6689185.7 40.5, 354960.8 6689203.9 40.5, 354971.6 6689208.7 40.5, 354971.7 6689208.8 40.5, 354975.8 6689210.6 40.5, 354976.5 6689210.2 40.5, 354987.9 6689183.8 40.5, 354981.6 6689181.5 40.5, 354981.2 6689182.4 40.5, 354981 6689183.2 40.5, 354978.1 6689182.1 40.5, 354978.5 6689181.2 40.5, 354970.7 6689177.8 40.5, 354969.3 6689175.7 40.5, 354965.8 6689184.3 40.5, 354968.4 6689185.7 40.5), (354971.6 6689188.7 40.5, 354973.6 6689189.5 40.5, 354973.9 6689189 40.5, 354975.4 6689189.6 40.5, 354973.2 6689195.3 40.5, 354971.4 6689197.1 40.5, 354968.2 6689195.6 40.5, 354969.1 6689193.3 40.5, 354969.5 6689193.4 40.5, 354970.3 6689191.5 40.5, 354971.6 6689188.7 40.5))
BATIMENT0000000302928347;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.4;20.1;40.5;41.5;20.3;Cadastre;;POLYGON Z ((354859 6689144.9 40.5, 354858 6689145.6 40.5, 354859.1 6689147.1 40.5, 354860 6689146.7 40.5, 354859 6689144.9 40.5))
BATIMENT0000000302928026;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;19.3;21.3;40.7;45.6;26.4;Cadastre;A 1.0;POLYGON Z ((354818.5 6689153.1 40.7, 354811.6 6689169.2 40.7, 354815.2 6689170.8 40.7, 354814.8 6689175.2 40.7, 354823.9 6689174.8 40.7, 354834.4 6689159.9 40.7, 354818.5 6689153.1 40.7))
BATIMENT0000000302928036;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;24.1;27.5;33.5;26.0;Cadastre;;POLYGON Z ((354808.7 6689175.5 27.5, 354802.6 6689189.7 27.5, 354809.1 6689189.3 27.5, 354809.3 6689175.6 27.5, 354808.7 6689175.5 27.5))
BATIMENT0000000302928027;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;16.9;20.8;37.7;42.5;26.3;Cadastre;C 0.8;POLYGON Z ((354838 6689208.1 37.7, 354859.1 6689194.9 37.7, 354857.4 6689169.8 37.7, 354834.4 6689159.9 37.7, 354823.9 6689174.8 37.7, 354814.8 6689175.2 37.7, 354821.1 6689178.6 37.7, 354822 6689195.6 37.7, 354825.1 6689195.5 37.7, 354828.3 6689195.5 37.7, 354830.2 6689197.8 37.7, 354830.7 6689195.7 37.7, 354832.6 6689195.8 37.7, 354834.2 6689196.9 37.7, 354836.1 6689196.8 37.7, 354836.3 6689197.3 37.7, 354837.4 6689199.1 37.7, 354833.3 6689201.8 37.7, 354838 6689208.1 37.7))
BATIMENT0000000302928028;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;24.0;25.8;36.7;26.2;Cadastre;;POLYGON Z ((354822 6689195.6 25.8, 354821.1 6689178.6 25.8, 354814.8 6689175.2 25.8, 354809.3 6689175.6 25.8, 354809.1 6689189.3 25.8, 354809.3 6689196 25.8, 354822 6689195.6 25.8))
BATIMENT0000000302928035;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;24.2;27.1;31.7;26.0;Cadastre;;POLYGON Z ((354809.3 6689196 27.1, 354809.1 6689189.3 27.1, 354802.6 6689189.7 27.1, 354807.4 6689197.3 27.1, 354809.3 6689196 27.1))
BATIMENT0000000302928038;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;23.9;29.0;37.2;26.1;Cadastre;;POLYGON Z ((354804.2 6689200.8 29, 354808 6689198.3 29, 354807.4 6689197.3 29, 354802.6 6689189.7 29, 354800.4 6689194.8 29, 354804.2 6689200.8 29))
BATIMENT0000000302928040;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.5;23.7;40.2;40.7;24.9;Cadastre;;POLYGON Z ((354833.3 6689201.8 40.2, 354837.4 6689199.1 40.2, 354836.3 6689197.3 40.2, 354831.8 6689199.8 40.2, 354833.3 6689201.8 40.2))
BATIMENT0000000302928029;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;20.1;22.5;42.6;47.2;25.6;Cadastre;C 0.9;POLYGON Z ((354822 6689195.6 42.6, 354809.3 6689196 42.6, 354807.4 6689197.3 42.6, 354808 6689198.3 42.6, 354808.9 6689199.9 42.6, 354821.1 6689218.8 42.6, 354838 6689208.1 42.6, 354833.3 6689201.8 42.6, 354831.8 6689199.8 42.6, 354830.2 6689197.8 42.6, 354828.3 6689195.5 42.6, 354825.1 6689195.5 42.6, 354822 6689195.6 42.6), (354825.8 6689198.3 42.6, 354826.7 6689199.5 42.6, 354823.1 6689201.8 42.6, 354822.2 6689201.2 42.6, 354821.4 6689201.5 42.6, 354821.1 6689202.3 42.6, 354821.2 6689203.8 42.6, 354820 6689204.2 42.6, 354819.2 6689205.9 42.6, 354818.7 6689205.6 42.6, 354818.6 6689202.8 42.6, 354816 6689198.8 42.6, 354823.6 6689198.4 42.6, 354825.8 6689198.3 42.6))
BATIMENT0000000302928042;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;12;20;17.4;23.9;41.3;44.2;25.7;Cadastre;C 0.6;POLYGON Z ((354808.5 6689227 41.3, 354821.1 6689218.8 41.3, 354808.9 6689199.9 41.3, 354796.5 6689208.4 41.3, 354808.5 6689227 41.3), (354810.9 6689210.4 41.3, 354813.8 6689214.8 41.3, 354808.3 6689218.4 41.3, 354805.5 6689214.2 41.3, 354810.9 6689210.4 41.3))
BATIMENT0000000302927489;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;;;19.7;18.3;38.0;43.2;19.7;Cadastre;C 0.6;POLYGON Z ((354902.3 6689114.6 38, 354901.9 6689114.4 38, 354893 6689125.1 38, 354894.1 6689136.8 38, 354897.5 6689137.5 38, 354902.3 6689139.4 38, 354906 6689142 38, 354907.8 6689143.9 38, 354912.2 6689138.9 38, 354910 6689137 38, 354909 6689136 38, 354918.8 6689125.2 38, 354914.1 6689121.3 38, 354912.2 6689123.4 38, 354910.2 6689121.7 38, 354906 6689126.4 38, 354902.6 6689123.7 38, 354908.8 6689116.8 38, 354904 6689112.6 38, 354902.3 6689114.6 38))
BATIMENT0000000302927498;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.4;17.7;40.1;42.0;18.5;Cadastre;;POLYGON Z ((354936.7 6689131.2 40.1, 354938.1 6689131.3 40.1, 354939.5 6689130.5 40.1, 354938 6689128.2 40.1, 354936.3 6689128 40.1, 354934.9 6689128.9 40.1, 354935.4 6689129.7 40.1, 354936.7 6689131.2 40.1))
BATIMENT0000000302927493;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;7.0;20;20;23.3;17.6;41.0;43.2;19.0;Cadastre;A 1.0;POLYGON Z ((354924.9 6689134.9 41, 354926.8 6689138.2 41, 354933.5 6689148.9 41, 354948.4 6689139.5 41, 354938.3 6689123 41, 354933.8 6689118.6 41, 354922 6689131.8 41, 354924.9 6689134.9 41), (354933.5 6689127.8 41, 354934.9 6689128.9 41, 354936.3 6689128 41, 354938 6689128.2 41, 354939.5 6689130.5 41, 354938.1 6689131.3 41, 354936.7 6689131.2 41, 354935.4 6689129.7 41, 354933.6 6689131.4 41, 354934.6 6689133 41, 354933.6 6689134.4 41, 354932.8 6689133.7 41, 354931.2 6689131.6 41, 354931.3 6689129.3 41, 354933.5 6689127.8 41))
BATIMENT0000000302927494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.0;18.6;40.7;41.8;19.3;Cadastre;;POLYGON Z ((354918.5 6689141.6 40.7, 354919.2 6689143.3 40.7, 354922.7 6689141 40.7, 354922.9 6689140 40.7, 354923.5 6689139.3 40.7, 354924.7 6689139 40.7, 354925.4 6689139.2 40.7, 354926.8 6689138.2 40.7, 354924.9 6689134.9 40.7, 354918.5 6689141.6 40.7))
BATIMENT0000000302927492;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;22.2;18.7;41.0;43.6;19.8;Cadastre;A 1.0;POLYGON Z ((354908.3 6689144.4 41, 354910.8 6689147.4 41, 354912.8 6689150.7 41, 354914.4 6689155.4 41, 354925 6689154.6 41, 354933.5 6689148.9 41, 354926.8 6689138.2 41, 354925.4 6689139.2 41, 354924.7 6689139 41, 354923.5 6689139.3 41, 354922.9 6689140 41, 354922.7 6689141 41, 354919.2 6689143.3 41, 354918.5 6689141.6 41, 354924.9 6689134.9 41, 354922 6689131.8 41, 354913.8 6689140.5 41, 354912.8 6689139.4 41, 354912.2 6689138.9 41, 354907.8 6689143.9 41, 354908.3 6689144.4 41))
BATIMENT0000000302927600;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;10;20;22.4;18.7;41.1;44.2;20.3;Cadastre;A 1.0;POLYGON Z ((354928.9 6689163.1 41.1, 354925.7 6689165.1 41.1, 354926.1 6689169.1 41.1, 354925.8 6689169.2 41.1, 354926.4 6689175.9 41.1, 354939.2 6689174.5 41.1, 354948.4 6689173.6 41.1, 354954.2 6689172.4 41.1, 354953.6 6689171.4 41.1, 354951.1 6689167.4 41.1, 354942.8 6689154.4 41.1, 354929 6689163.2 41.1, 354928.9 6689163.1 41.1), (354946.1 6689168.7 41.1, 354947.7 6689169.3 41.1, 354948.2 6689171.1 41.1, 354943.5 6689172.5 41.1, 354943.3 6689171.5 41.1, 354944 6689171.2 41.1, 354944.4 6689170.9 41.1, 354944.6 6689170.2 41.1, 354944.6 6689169.5 41.1, 354946.1 6689168.7 41.1))
BATIMENT0000000302927597;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;;;22.1;19.1;41.2;44.2;20.5;Cadastre;A 0.3;POLYGON Z ((354927.4 6689186.1 41.2, 354927.7 6689186.2 41.2, 354928.1 6689190.2 41.2, 354931.6 6689191.8 41.2, 354931.7 6689191.6 41.2, 354948 6689198.4 41.2, 354955.5 6689180.5 41.2, 354954.8 6689180.8 41.2, 354954 6689180.4 41.2, 354954.5 6689178.8 41.2, 354960 6689178.2 41.2, 354960 6689177.5 41.2, 354959.5 6689172.6 41.2, 354961.9 6689172.1 41.2, 354961.7 6689169.3 41.2, 354961.3 6689166.1 41.2, 354956.8 6689169 41.2, 354957.2 6689172.5 41.2, 354954.9 6689173.1 41.2, 354954.2 6689172.4 41.2, 354948.4 6689173.6 41.2, 354948.8 6689178.7 41.2, 354948.5 6689179.1 41.2, 354948.5 6689179.4 41.2, 354948.4 6689179.7 41.2, 354948.3 6689180 41.2, 354948.2 6689180.3 41.2, 354948.1 6689180.6 41.2, 354948 6689180.8 41.2, 354947.8 6689181.1 41.2, 354947.6 6689181.3 41.2, 354947.4 6689181.5 41.2, 354947.2 6689181.7 41.2, 354946.9 6689181.9 41.2, 354946.4 6689182.2 41.2, 354946.2 6689182.3 41.2, 354945.8 6689182.5 41.2, 354945.5 6689182.6 41.2, 354945.1 6689182.7 41.2, 354944.7 6689182.7 41.2, 354944 6689182.8 41.2, 354943.7 6689182.7 41.2, 354943.3 6689182.7 41.2, 354942.9 6689182.6 41.2, 354942.6 6689182.5 41.2, 354942.2 6689182.4 41.2, 354941.9 6689182.2 41.2, 354941.6 6689182.1 41.2, 354941.3 6689181.8 41.2, 354941 6689181.6 41.2, 354940.8 6689181.3 41.2, 354940.6 6689181.1 41.2, 354940.3 6689180.8 41.2, 354940.2 6689180.5 41.2, 354940 6689180.1 41.2, 354939.9 6689179.8 41.2, 354939.6 6689179.7 41.2, 354939.2 6689174.5 41.2, 354926.4 6689175.9 41.2, 354927.4 6689186.1 41.2))
BATIMENT0000000302927482;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;21.1;20.3;41.4;44.5;23.9;Cadastre;C 0.2;POLYGON Z ((354956.5 6689212.6 41.4, 354933.1 6689202.6 41.4, 354933 6689202.4 41.4, 354928.6 6689200.6 41.4, 354918.4 6689201.5 41.4, 354919 6689209.1 41.4, 354919.3 6689209.1 41.4, 354920.2 6689219.5 41.4, 354920 6689219.5 41.4, 354922.7 6689255 41.4, 354929.3 6689254.5 41.4, 354928.7 6689247.1 41.4, 354932.4 6689246.8 41.4, 354932.2 6689244.2 41.4, 354932.7 6689244 41.4, 354932.9 6689243.9 41.4, 354933.1 6689243.8 41.4, 354933.3 6689243.6 41.4, 354933.4 6689243.5 41.4, 354933.6 6689243.3 41.4, 354933.7 6689243.2 41.4, 354933.8 6689243 41.4, 354933.9 6689242.7 41.4, 354933.9 6689242.6 41.4, 354933.9 6689242.4 41.4, 354933.9 6689242.3 41.4, 354933.5 6689236.9 41.4, 354935.4 6689236.7 41.4, 354935 6689231.6 41.4, 354938.3 6689229.6 41.4, 354941.1 6689231.8 41.4, 354941.7 6689231 41.4, 354945.1 6689230 41.4, 354948.8 6689230.7 41.4, 354949.2 6689229.7 41.4, 354956.5 6689212.8 41.4, 354956.5 6689212.6 41.4))
BATIMENT0000000302927580;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.2;21.1;37.4;42.4;25.5;Cadastre;A 1.0;POLYGON Z ((354882.4 6689199.6 37.4, 354882.4 6689201 37.4, 354882.8 6689201 37.4, 354883 6689204.1 37.4, 354878.9 6689204.4 37.4, 354878.5 6689204.4 37.4, 354879.1 6689212.5 37.4, 354879.4 6689212.5 37.4, 354880.6 6689227.4 37.4, 354880.3 6689227.5 37.4, 354882 6689248.8 37.4, 354881.8 6689248.9 37.4, 354883.5 6689269 37.4, 354889.6 6689268.5 37.4, 354889.7 6689269.3 37.4, 354909.5 6689267.7 37.4, 354909.5 6689266.9 37.4, 354915.4 6689266.3 37.4, 354913.8 6689246.4 37.4, 354913.6 6689246.3 37.4, 354911.8 6689225 37.4, 354910.7 6689210.2 37.4, 354911.1 6689210 37.4, 354910.5 6689201.9 37.4, 354910.1 6689201.9 37.4, 354906 6689202.2 37.4, 354905.7 6689199.2 37.4, 354905.9 6689199.1 37.4, 354905.9 6689197.7 37.4, 354882.4 6689199.6 37.4))
BATIMENT0000000302927483;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;15.5;21.3;36.8;39.8;23.8;Cadastre;A 1.0;POLYGON Z ((354923.7 6689268.1 36.8, 354934.3 6689269.4 36.8, 354934.1 6689263.8 36.8, 354930.5 6689263.9 36.8, 354930.4 6689259.8 36.8, 354934 6689259.6 36.8, 354933.7 6689254.4 36.8, 354933.7 6689254.2 36.8, 354929.3 6689254.5 36.8, 354922.7 6689255 36.8, 354923.7 6689268.1 36.8))
BATIMENT0000000302930252;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;;;16.2;15.8;32.0;36.0;18.7;Cadastre;A 1.0;POLYGON Z ((355035.2 6689184.4 32, 355015.4 6689182.1 32, 355014.6 6689189.2 32, 355017.2 6689189.5 32, 355016.8 6689193 32, 355021.1 6689192.8 32, 355021.7 6689201 32, 355015.6 6689200.6 32, 355015.3 6689203.8 32, 355022 6689205.4 32, 355035.5 6689205.2 32, 355035.2 6689184.4 32))
BATIMENT0000000302927742;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;10;20;23.0;16.2;39.2;43.0;18.8;Cadastre;A 1.0;POLYGON Z ((354985.7 6689208.9 39.2, 354985.5 6689208.8 39.2, 354983.6 6689213.3 39.2, 354983.9 6689214.1 39.2, 355001.5 6689221.5 39.2, 355009.3 6689202.7 39.2, 355006.9 6689201.6 39.2, 355005.1 6689200.9 39.2, 355002.4 6689207 39.2, 355003.1 6689210 39.2, 355002.1 6689210.1 39.2, 355001.3 6689208.5 39.2, 354999.2 6689207.5 39.2, 354997.8 6689208.1 39.2, 354997.2 6689206.9 39.2, 354998.2 6689206.3 39.2, 355000.6 6689200.8 39.2, 355001.1 6689200.7 39.2, 355001.6 6689200.7 39.2, 355001.8 6689200.3 39.2, 355002.2 6689199.7 39.2, 354991.4 6689195.2 39.2, 354985.7 6689208.9 39.2))
BATIMENT0000000302930254;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;6.0;;;22.6;15.6;38.2;42.6;18.6;Cadastre;C 0.2;POLYGON Z ((355026.6 6689232.3 38.2, 355026.5 6689232.5 38.2, 355030 6689234 38.2, 355030.4 6689233.8 38.2, 355032.1 6689234.8 38.2, 355032.3 6689234.9 38.2, 355032.8 6689234.9 38.2, 355033.3 6689234.9 38.2, 355033.6 6689234.8 38.2, 355034 6689234.7 38.2, 355034.3 6689234.6 38.2, 355034.5 6689234.4 38.2, 355034.7 6689234.3 38.2, 355034.9 6689234.1 38.2, 355035 6689233.9 38.2, 355035.2 6689233.8 38.2, 355035.3 6689233.7 38.2, 355035.4 6689233.6 38.2, 355035.5 6689233.5 38.2, 355035.6 6689233.4 38.2, 355035.8 6689233.1 38.2, 355035.9 6689232.8 38.2, 355036 6689232.5 38.2, 355036 6689232.3 38.2, 355036 6689232 38.2, 355035.6 6689230.1 38.2, 355036 6689229.9 38.2, 355035.5 6689205.2 38.2, 355022 6689205.4 38.2, 355015.3 6689203.8 38.2, 355010 6689203 38.2, 355009.3 6689202.7 38.2, 355001.5 6689221.5 38.2, 355026.6 6689232.3 38.2), (355019.1 6689207.7 38.2, 355021.8 6689208.7 38.2, 355024.3 6689211.9 38.2, 355024.4 6689212.6 38.2, 355025 6689213.1 38.2, 355025.2 6689217.5 38.2, 355025.9 6689219.3 38.2, 355024.4 6689220.2 38.2, 355023.6 6689218.7 38.2, 355018.6 6689216.6 38.2, 355015.2 6689216.2 38.2, 355014.9 6689214.8 38.2, 355016.8 6689213.1 38.2, 355019.1 6689207.7 38.2))
BATIMENT0000000302927478;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;22.2;18.6;40.9;43.3;23.6;Cadastre;A 1.0;POLYGON Z ((354956.5 6689212.8 40.9, 354949.2 6689229.7 40.9, 354950.7 6689230.2 40.9, 354956.4 6689231.8 40.9, 354956.8 6689230.6 40.9, 354954.1 6689229.7 40.9, 354954.7 6689228.1 40.9, 354954.4 6689226.8 40.9, 354955.5 6689226.1 40.9, 354957.1 6689227.5 40.9, 354957.6 6689227.9 40.9, 354958.6 6689227.9 40.9, 354959.1 6689227.7 40.9, 354961.5 6689228.8 40.9, 354962.8 6689228.6 40.9, 354963.1 6689229.8 40.9, 354962.4 6689230.6 40.9, 354961.5 6689233.3 40.9, 354965.4 6689234.4 40.9, 354971.7 6689219.2 40.9, 354956.5 6689212.8 40.9))
BATIMENT0000000302927475;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;22.6;18.0;40.6;43.4;19.6;Cadastre;A 1.0;POLYGON Z ((354982.6 6689240.3 40.6, 354987.5 6689226 40.6, 354971.7 6689219.2 40.6, 354965.4 6689234.4 40.6, 354982.6 6689240.3 40.6))
BATIMENT0000000302927476;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;00;00;20.9;16.7;37.6;41.6;19.4;Cadastre;A 1.0;POLYGON Z ((354982.6 6689240.3 37.6, 354993.8 6689244.1 37.6, 354996.8 6689245.1 37.6, 354997.1 6689244 37.6, 354996.1 6689243.5 37.6, 354996.6 6689242.4 37.6, 355000.7 6689244 37.6, 354999.7 6689246 37.6, 355004.6 6689247.4 37.6, 355007.5 6689241.5 37.6, 355004.2 6689240.2 37.6, 355006.6 6689234.4 37.6, 354987.5 6689226 37.6, 354982.6 6689240.3 37.6))
BATIMENT0000000302930200;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;19.8;16.2;36.0;40.2;17.5;Cadastre;A 1.0;POLYGON Z ((355006.6 6689234.4 36, 355004.2 6689240.2 36, 355007.5 6689241.5 36, 355004.6 6689247.4 36, 355007.7 6689248 36, 355005.4 6689258.2 36, 355010.3 6689259.2 36, 355011.8 6689252.8 36, 355011.6 6689252.7 36, 355017.2 6689238.9 36, 355006.6 6689234.4 36))
BATIMENT0000000302927477;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.0;19.6;33.6;41.0;23.5;Cadastre;;POLYGON Z ((354966.6 6689273.4 33.6, 354968.6 6689254.1 33.6, 354969.3 6689254.2 33.6, 354969.4 6689254 33.6, 354976 6689254.9 33.6, 354975.9 6689255.2 33.6, 354982.2 6689256.1 33.6, 354983.5 6689249.2 33.6, 354991.7 6689251.1 33.6, 354991.9 6689251.2 33.6, 354993.8 6689244.1 33.6, 354982.6 6689240.3 33.6, 354965.4 6689234.4 33.6, 354961.5 6689233.3 33.6, 354956.4 6689231.8 33.6, 354950.7 6689230.2 33.6, 354948 6689253.5 33.6, 354947.3 6689258.7 33.6, 354945.8 6689270.8 33.6, 354966.6 6689273.4 33.6))
BATIMENT0000000302927479;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.6;16.7;34.3;38.5;19.2;Cadastre;;POLYGON Z ((354999.7 6689246 34.3, 354996.8 6689245.1 34.3, 354993.8 6689244.1 34.3, 354991.9 6689251.2 34.3, 354991.7 6689251.1 34.3, 354991.4 6689252.3 34.3, 354994.3 6689253 34.3, 354994.3 6689253.1 34.3, 354994.3 6689253.2 34.3, 354994.3 6689253.4 34.3, 354994.4 6689253.5 34.3, 354994.5 6689253.6 34.3, 354994.6 6689253.8 34.3, 354994.7 6689253.8 34.3, 354994.8 6689253.9 34.3, 355001.9 6689255.6 34.3, 355002.5 6689256.5 34.3, 355002 6689259.2 34.3, 355003.6 6689259.6 34.3, 355005.3 6689258.8 34.3, 355005.4 6689258.2 34.3, 355007.7 6689248 34.3, 355004.6 6689247.4 34.3, 354999.7 6689246 34.3))
BATIMENT0000000302930201;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;21.8;15.6;37.5;42.0;17.8;Cadastre;A 1.0;POLYGON Z ((355015.6 6689253.9 37.5, 355016.8 6689254.3 37.5, 355016.3 6689256.3 37.5, 355018 6689256.8 37.5, 355018.2 6689256.1 37.5, 355019.3 6689256.4 37.5, 355019.9 6689255.8 37.5, 355019.8 6689255.3 37.5, 355023.3 6689256.4 37.5, 355022.1 6689257.5 37.5, 355020.7 6689263.2 37.5, 355010 6689260.8 37.5, 355010.3 6689259.2 37.5, 355005.4 6689258.2 37.5, 355005.3 6689258.8 37.5, 355004 6689263.8 37.5, 355015.3 6689267.2 37.5, 355015.1 6689267.7 37.5, 355021.8 6689269.8 37.5, 355022.8 6689269.7 37.5, 355030.1 6689271.4 37.5, 355031.3 6689265.6 37.5, 355034.1 6689252.9 37.5, 355034.3 6689253 37.5, 355035.4 6689247.7 37.5, 355035.1 6689246.4 37.5, 355029.9 6689244.1 37.5, 355029.8 6689244.2 37.5, 355023 6689241.3 37.5, 355020.9 6689240.4 37.5, 355017.2 6689238.9 37.5, 355011.6 6689252.7 37.5, 355011.8 6689252.8 37.5, 355015.6 6689253.9 37.5))
BATIMENT0000000302930468;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;17.1;6.8;24.0;28.2;10.1;Cadastre;A 1.0;POLYGON Z ((355064.7 6689047.1 24, 355086.8 6689038.4 24, 355084.9 6689034.5 24, 355063.6 6689044.2 24, 355064.7 6689047.1 24))
BATIMENT0000000302930470;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.8;9.9;27.7;27.7;10.0;Cadastre;;POLYGON Z ((355070.2 6689047.4 27.7, 355071.2 6689049.8 27.7, 355073.9 6689048.6 27.7, 355072.8 6689046.3 27.7, 355070.2 6689047.4 27.7))
BATIMENT0000000302930469;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;20.8;7.2;28.1;30.9;10.1;Cadastre;A 1.0;POLYGON Z ((355061.8 6689048.4 28.1, 355064.3 6689056 28.1, 355068.9 6689063.3 28.1, 355091.1 6689049.8 28.1, 355086.8 6689038.4 28.1, 355064.7 6689047.1 28.1, 355061.8 6689048.4 28.1), (355075.4 6689045.4 28.1, 355076.4 6689047.8 28.1, 355073.9 6689048.6 28.1, 355071.2 6689049.8 28.1, 355070.2 6689047.4 28.1, 355072.8 6689046.3 28.1, 355075.4 6689045.4 28.1))
BATIMENT0000000302931215;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;20.1;9.6;29.7;33.0;11.8;Cadastre;A 1.0;POLYGON Z ((355053.3 6689045.5 29.7, 355051.6 6689048.5 29.7, 355050 6689049.8 29.7, 355045.2 6689052.5 29.7, 355041 6689052.3 29.7, 355038.9 6689053.8 29.7, 355051.8 6689073.9 29.7, 355066.1 6689065.1 29.7, 355059.1 6689052.9 29.7, 355056.6 6689054.4 29.7, 355055.7 6689052.9 29.7, 355058.2 6689051.4 29.7, 355054.6 6689045.1 29.7, 355053.3 6689045.5 29.7))
BATIMENT0000000302930423;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;21.6;7.3;29.0;32.3;9.5;Cadastre;A 1.0;POLYGON Z ((355083 6689080.5 29, 355083.6 6689080.2 29, 355083.1 6689079.1 29, 355083.4 6689078.9 29, 355083.6 6689078.5 29, 355084 6689077.6 29, 355085.8 6689076.6 29, 355086.4 6689077.6 29, 355088.1 6689076.5 29, 355088.4 6689074.6 29, 355089.6 6689075.1 29, 355090.5 6689077.7 29, 355100.5 6689074.1 29, 355094.6 6689058.7 29, 355069.6 6689074.4 29, 355073 6689082.6 29, 355083 6689080.5 29))
BATIMENT0000000302930424;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;00;00;18.8;8.1;26.9;27.9;10.0;Cadastre;A 1.0;POLYGON Z ((355082.9 6689090 26.9, 355103.8 6689082.6 26.9, 355101.2 6689075.9 26.9, 355071.8 6689086.4 26.9, 355074 6689093.2 26.9, 355082.9 6689090 26.9))
BATIMENT0000000302930425;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;12;20;19.6;9.4;29.0;33.2;11.4;Cadastre;A 1.0;POLYGON Z ((355074.6 6689095 29, 355074 6689093.2 29, 355071.8 6689086.4 29, 355068.6 6689087.5 29, 355068 6689085.4 29, 355070.4 6689084.5 29, 355067 6689075.9 29, 355054.3 6689083.8 29, 355058.6 6689089.6 29, 355061.5 6689098.8 29, 355074.6 6689095 29))
BATIMENT0000000302930427;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;18.4;7.8;26.2;28.5;8.1;Cadastre;A 1.0;POLYGON Z ((355085.7 6689098 26.2, 355085.9 6689097.9 26.2, 355093.6 6689095.3 26.2, 355093 6689093.2 26.2, 355106.2 6689089 26.2, 355103.8 6689082.6 26.2, 355082.9 6689090 26.2, 355083.7 6689092.8 26.2, 355085.7 6689098 26.2))
BATIMENT0000000302930430;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.5;10.9;31.5;33.9;11.4;Cadastre;;POLYGON Z ((355053.9 6689096.8 31.5, 355056.4 6689095.3 31.5, 355054.5 6689092.5 31.5, 355052 6689094 31.5, 355053.9 6689096.8 31.5))
BATIMENT0000000302930432;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;19;20;18.9;8.3;27.2;;;Cadastre;A 1.0;POLYGON Z ((355108.4 6689094.8 27.2, 355106.2 6689089 27.2, 355093 6689093.2 27.2, 355093.6 6689095.3 27.2, 355085.9 6689097.9 27.2, 355085.7 6689098 27.2, 355084.8 6689098.5 27.2, 355085.5 6689102.3 27.2, 355092.3 6689100.6 27.2, 355091.8 6689098.8 27.2, 355095.5 6689097.5 27.2, 355095.9 6689098.8 27.2, 355096.1 6689098.7 27.2, 355108.4 6689094.8 27.2))
BATIMENT0000000302930426;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;6.0;;;16.7;7.1;23.9;27.0;9.5;Cadastre;A 1.0;POLYGON Z ((355085.5 6689102.3 23.9, 355084.8 6689098.5 23.9, 355085.7 6689098 23.9, 355083.7 6689092.8 23.9, 355082.9 6689090 23.9, 355074 6689093.2 23.9, 355074.6 6689095 23.9, 355076.6 6689104.6 23.9, 355085.5 6689102.3 23.9))
BATIMENT0000000302930428;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;10;20;15.9;8.8;24.7;34.7;13.0;Cadastre;A 1.0;POLYGON Z ((355046.2 6689104.5 24.7, 355047.4 6689105.9 24.7, 355047.5 6689106.4 24.7, 355052 6689106.2 24.7, 355052.2 6689111.8 24.7, 355059.2 6689109.5 24.7, 355056.4 6689100.9 24.7, 355053.9 6689096.8 24.7, 355052 6689094 24.7, 355054.5 6689092.5 24.7, 355056.4 6689095.3 24.7, 355057 6689096.2 24.7, 355057.8 6689095.9 24.7, 355059.4 6689099.7 24.7, 355059.7 6689099.6 24.7, 355061.9 6689102 24.7, 355062.7 6689101.8 24.7, 355064.4 6689101.3 24.7, 355064.9 6689102.7 24.7, 355067.4 6689110.5 24.7, 355068.6 6689114.5 24.7, 355078 6689111.8 24.7, 355077.6 6689109.9 24.7, 355077.5 6689109.7 24.7, 355077.3 6689109.5 24.7, 355074.9 6689109.8 24.7, 355074.6 6689108.1 24.7, 355073.8 6689105.3 24.7, 355076.6 6689104.6 24.7, 355074.6 6689095 24.7, 355061.5 6689098.8 24.7, 355058.6 6689089.6 24.7, 355054.3 6689083.8 24.7, 355043.8 6689090.2 24.7, 355043.2 6689090.5 24.7, 355042.6 6689090.8 24.7, 355042.5 6689090.9 24.7, 355042.2 6689091.1 24.7, 355041.9 6689091.3 24.7, 355041.5 6689091.6 24.7, 355041.3 6689091.9 24.7, 355041 6689092.2 24.7, 355040.8 6689092.6 24.7, 355040.7 6689092.6 24.7, 355040.6 6689092.9 24.7, 355040.4 6689093.3 24.7, 355040.3 6689093.6 24.7, 355040.2 6689094 24.7, 355040.1 6689094.3 24.7, 355040 6689095 24.7, 355040.1 6689095.7 24.7, 355040.1 6689095.8 24.7, 355040.2 6689096.1 24.7, 355040.3 6689096.8 24.7, 355040.5 6689104.7 24.7, 355046.2 6689104.5 24.7))
BATIMENT0000000302930434;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;11.1;22.0;22.3;11.7;Cadastre;;POLYGON Z ((355063.1 6689103.2 22, 355064.9 6689102.7 22, 355064.4 6689101.3 22, 355062.7 6689101.8 22, 355063.1 6689103.2 22))
BATIMENT0000000302930431;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;12;20;22.7;6.8;29.5;33.0;9.6;Cadastre;A 1.0;POLYGON Z ((355078 6689111.8 29.5, 355080.6 6689111.1 29.5, 355082.3 6689110.7 29.5, 355090.8 6689108.7 29.5, 355089.8 6689104.8 29.5, 355096.5 6689103.2 29.5, 355097.4 6689107.3 29.5, 355097.7 6689107.3 29.5, 355098.3 6689109.4 29.5, 355112.5 6689105.7 29.5, 355108.4 6689094.8 29.5, 355096.1 6689098.7 29.5, 355096.4 6689099.6 29.5, 355092.3 6689100.6 29.5, 355085.5 6689102.3 29.5, 355076.6 6689104.6 29.5, 355073.8 6689105.3 29.5, 355074.6 6689108.1 29.5, 355079.4 6689106.4 29.5, 355080.1 6689109.3 29.5, 355077.6 6689109.9 29.5, 355078 6689111.8 29.5))
BATIMENT0000000302930435;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;11.6;17.5;24.0;13.1;Cadastre;;POLYGON Z ((355068.6 6689114.5 17.5, 355067.4 6689110.5 17.5, 355066.4 6689110.9 17.5, 355066.2 6689110.3 17.5, 355063.9 6689110.9 17.5, 355063.8 6689110.6 17.5, 355060 6689111.9 17.5, 355061.5 6689116.6 17.5, 355068.6 6689114.5 17.5))
BATIMENT0000000302930429;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;19.4;12.2;31.6;34.7;14.2;Cadastre;C 0.1;POLYGON Z ((355040.9 6689122.7 31.6, 355052 6689119.4 31.6, 355061.5 6689116.6 31.6, 355060 6689111.9 31.6, 355059.2 6689109.5 31.6, 355052.2 6689111.8 31.6, 355052 6689106.2 31.6, 355047.5 6689106.4 31.6, 355047.4 6689105.9 31.6, 355046.2 6689104.5 31.6, 355040.5 6689104.7 31.6, 355040.9 6689122.7 31.6))
BATIMENT0000000302930433;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;12;20;21.2;7.0;28.2;32.5;14.6;Cadastre;A 1.0;POLYGON Z ((355097.7 6689107.3 28.2, 355097.4 6689107.3 28.2, 355090.8 6689108.7 28.2, 355082.3 6689110.7 28.2, 355082.6 6689111.8 28.2, 355083.1 6689112 28.2, 355083.4 6689112 28.2, 355083.9 6689113.7 28.2, 355082.8 6689115.6 28.2, 355081.9 6689115.9 28.2, 355080.6 6689111.1 28.2, 355078 6689111.8 28.2, 355068.6 6689114.5 28.2, 355061.5 6689116.6 28.2, 355052 6689119.4 28.2, 355053.1 6689124 28.2, 355053.8 6689126.9 28.2, 355055.1 6689132.3 28.2, 355069.7 6689127.1 28.2, 355074 6689126.1 28.2, 355079.6 6689124.8 28.2, 355079.7 6689125.1 28.2, 355081.8 6689124.6 28.2, 355088 6689122.9 28.2, 355086.3 6689116.9 28.2, 355098.9 6689113.4 28.2, 355100.6 6689119.5 28.2, 355116 6689115.1 28.2, 355116.1 6689115 28.2, 355112.5 6689105.7 28.2, 355098.3 6689109.4 28.2, 355097.7 6689107.3 28.2), (355070.1 6689117 28.2, 355071.9 6689123.3 28.2, 355068.8 6689124.2 28.2, 355068.3 6689122.9 28.2, 355059.7 6689126 28.2, 355057.5 6689126.7 28.2, 355057.7 6689125.9 28.2, 355056.3 6689120 28.2, 355060.2 6689118.8 28.2, 355060.3 6689119.2 28.2, 355066.6 6689117.2 28.2, 355066.9 6689117.9 28.2, 355070.1 6689117 28.2))
BATIMENT0000000302930438;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;12.4;15.9;20.7;13.6;Cadastre;;POLYGON Z ((355068.3 6689122.9 15.9, 355067.4 6689120.3 15.9, 355058.8 6689123.4 15.9, 355059.7 6689126 15.9, 355068.3 6689122.9 15.9))
BATIMENT0000000302930439;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1732-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;12;20;21.0;6.9;28.0;31.5;9.6;Cadastre;A 1.0;POLYGON Z ((355081.8 6689124.6 28, 355082.8 6689129.1 28, 355080.7 6689129.6 28, 355081.4 6689132.4 28, 355098 6689127.6 28, 355098.4 6689128.5 28, 355118.4 6689121.3 28, 355116 6689115.1 28, 355100.6 6689119.5 28, 355100.2 6689119.7 28, 355100.4 6689121.5 28, 355089.1 6689124.3 28, 355088.6 6689122.7 28, 355088 6689122.9 28, 355081.8 6689124.6 28))
BATIMENT0000000302930440;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;12;20;19.7;7.0;26.8;30.7;12.0;Cadastre;A 1.0;POLYGON Z ((355120.6 6689126.7 26.8, 355118.4 6689121.3 26.8, 355098.4 6689128.5 26.8, 355098 6689127.6 26.8, 355081.4 6689132.4 26.8, 355080.7 6689129.6 26.8, 355079.7 6689125.1 26.8, 355079.6 6689124.8 26.8, 355074 6689126.1 26.8, 355076.5 6689133.6 26.8, 355077.1 6689135.7 26.8, 355081.1 6689134.5 26.8, 355082.3 6689138.7 26.8, 355120.6 6689126.7 26.8))
BATIMENT0000000302931586;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1760-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;12;20;20.2;5.5;25.7;28.8;6.4;Cadastre;A 1.0;POLYGON Z ((355283.7 6689103.6 25.7, 355297.9 6689111.1 25.7, 355306.6 6689094.5 25.7, 355315.1 6689078.6 25.7, 355301.2 6689071 25.7, 355292.4 6689087.4 25.7, 355283.7 6689103.6 25.7), (355298.6 6689085.2 25.7, 355303.7 6689087.6 25.7, 355304 6689089.7 25.7, 355303.9 6689090 25.7, 355302.8 6689089.6 25.7, 355300 6689094.8 25.7, 355301 6689095.4 25.7, 355300.3 6689096.3 25.7, 355299.3 6689096.5 25.7, 355293.8 6689094 25.7, 355293.7 6689092 25.7, 355296.7 6689085.6 25.7, 355298.6 6689085.2 25.7))
BATIMENT0000000302931789;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.5;6.7;15.3;16.3;7.1;Cadastre;;POLYGON Z ((355257.9 6689138.3 15.3, 355259.1 6689136 15.3, 355252.3 6689132.5 15.3, 355251.1 6689134.8 15.3, 355257.9 6689138.3 15.3))
BATIMENT0000000302931791;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;7.4;6.2;13.7;14.7;6.9;Cadastre;;POLYGON Z ((355275.6 6689147.5 13.7, 355276.8 6689145.2 13.7, 355269.9 6689141.7 13.7, 355268.8 6689144 13.7, 355275.6 6689147.5 13.7))
BATIMENT0000000302931790;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;7.8;6.1;14.0;16.7;6.6;Cadastre;;POLYGON Z ((355288.1 6689151.1 14, 355287 6689153.4 14, 355293.8 6689156.9 14, 355294.9 6689154.7 14, 355288.1 6689151.1 14))
BATIMENT0000000302931788;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.0;6.5;15.6;18.1;6.7;Cadastre;;POLYGON Z ((355262 6689157.3 15.6, 355260.8 6689159.5 15.6, 355267.4 6689163.1 15.6, 355268.6 6689161 15.6, 355262 6689157.3 15.6))
BATIMENT0000000029192554;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:45:40;;;;;BDTopo;2.5;BDTopo;1.5;;;;;2.1;7.2;;10.6;7.2;Imagerie aérienne;;POLYGON Z ((355232.5 6689181.6 9.3, 355241.5 6689172.7 9.2, 355228.4 6689160 9.3, 355225.4 6689163 9.3, 355219.8 6689168.7 9.3, 355225.5 6689174.4 9.2, 355232.5 6689181.6 9.3))
BATIMENT0000000302931787;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;8.4;6.3;14.7;20.4;6.6;Cadastre;C 0.2;POLYGON Z ((355281.7 6689162.7 14.7, 355280.4 6689165.1 14.7, 355278.3 6689164 14.7, 355277.2 6689166.1 14.7, 355276 6689165.5 14.7, 355272.6 6689163.7 14.7, 355270.3 6689168.1 14.7, 355276.9 6689171.7 14.7, 355290.2 6689178.9 14.7, 355292.5 6689174.4 14.7, 355290.6 6689173.3 14.7, 355291.9 6689170.9 14.7, 355287.5 6689168.4 14.7, 355288.5 6689166.4 14.7, 355281.7 6689162.7 14.7))
BATIMENT0000000302931090;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;6.9;13.5;27.5;7.4;Cadastre;;POLYGON Z ((355253.1 6689191.2 13.5, 355255.1 6689192.7 13.5, 355258.3 6689188.7 13.5, 355256.3 6689187.2 13.5, 355253.1 6689191.2 13.5))
BATIMENT0000000302930815;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;6.7;10.3;10.6;7.2;Cadastre;;POLYGON Z ((355207.4 6689196.7 10.3, 355203 6689191.5 10.3, 355201.5 6689192.8 10.3, 355205.1 6689197.4 10.3, 355205.6 6689198 10.3, 355207.4 6689196.7 10.3))
BATIMENT0000000302931088;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;7.0;14.5;27.9;7.3;Cadastre;;POLYGON Z ((355249 6689196.2 14.5, 355251 6689197.8 14.5, 355254.4 6689193.6 14.5, 355252.4 6689192.1 14.5, 355249 6689196.2 14.5))
BATIMENT0000000302930436;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;23.1;13.0;36.2;39.2;15.6;Cadastre;A 1.0;POLYGON Z ((355041.5 6689146.9 36.2, 355052.9 6689146.6 36.2, 355051.1 6689139.5 36.2, 355048.5 6689139.6 36.2, 355048.5 6689136.4 36.2, 355050.2 6689135.9 36.2, 355049.8 6689134.1 36.2, 355055.1 6689132.3 36.2, 355053.8 6689126.9 36.2, 355051.5 6689127 36.2, 355051.4 6689124.1 36.2, 355053.1 6689124 36.2, 355052 6689119.4 36.2, 355040.9 6689122.7 36.2, 355041.5 6689146.9 36.2))
BATIMENT0000000302930444;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;21.8;7.1;28.9;32.2;8.7;Cadastre;C 0.7;POLYGON Z ((355083.8 6689144.1 28.9, 355095.3 6689140.8 28.9, 355095.8 6689140.5 28.9, 355095.3 6689138.9 28.9, 355102.4 6689137 28.9, 355102.8 6689138.5 28.9, 355122.7 6689131.8 28.9, 355120.6 6689126.7 28.9, 355082.3 6689138.7 28.9, 355083.8 6689143.9 28.9, 355083.8 6689144.1 28.9))
BATIMENT0000000302930437;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;20;12.7;8.7;21.5;28.6;14.6;Cadastre;C 0.3;POLYGON Z ((355069.7 6689127.1 21.5, 355055.1 6689132.3 21.5, 355049.8 6689134.1 21.5, 355050.2 6689135.9 21.5, 355051.1 6689139.5 21.5, 355052.9 6689146.6 21.5, 355054 6689150.6 21.5, 355066.4 6689146.5 21.5, 355068.2 6689150.8 21.5, 355074.5 6689146.3 21.5, 355070.3 6689136.1 21.5, 355076.5 6689133.6 21.5, 355074 6689126.1 21.5, 355069.7 6689127.1 21.5))
BATIMENT0000000302930445;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.0;7.4;28.4;29.0;7.9;Cadastre;;POLYGON Z ((355095.3 6689140.8 28.4, 355096.4 6689143.6 28.4, 355103.6 6689141.1 28.4, 355102.8 6689138.5 28.4, 355095.8 6689140.5 28.4, 355095.3 6689140.8 28.4))
BATIMENT0000000302930443;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;14.9;7.3;22.2;31.6;15.2;Cadastre;A 1.0;POLYGON Z ((355072.1 6689161.5 22.2, 355072.8 6689161.3 22.2, 355087 6689158.3 22.2, 355087.8 6689158.1 22.2, 355085.8 6689150.8 22.2, 355097.6 6689147 22.2, 355105.7 6689144.3 22.2, 355107.6 6689143.4 22.2, 355124.6 6689137.5 22.2, 355122.7 6689131.8 22.2, 355102.8 6689138.5 22.2, 355103.6 6689141.1 22.2, 355096.4 6689143.6 22.2, 355095.3 6689140.8 22.2, 355083.8 6689144.1 22.2, 355083.8 6689143.9 22.2, 355083.5 6689144 22.2, 355084.9 6689148.8 22.2, 355076.8 6689152 22.2, 355074.5 6689146.3 22.2, 355068.2 6689150.8 22.2, 355066.4 6689146.5 22.2, 355054 6689150.6 22.2, 355056.5 6689160.1 22.2, 355058.5 6689166 22.2, 355072.1 6689161.5 22.2))
BATIMENT0000000302930456;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;20.4;7.2;27.7;31.9;11.9;Cadastre;A 1.0;POLYGON Z ((355105.7 6689144.3 27.7, 355097.6 6689147 27.7, 355085.8 6689150.8 27.7, 355087.8 6689158.1 27.7, 355092.5 6689156.8 27.7, 355092.8 6689158.1 27.7, 355080.2 6689161.4 27.7, 355081.5 6689166.6 27.7, 355088.8 6689164.7 27.7, 355088.6 6689164.2 27.7, 355090.7 6689163.5 27.7, 355101.7 6689160.2 27.7, 355108.2 6689158.2 27.7, 355128.6 6689151.9 27.7, 355127 6689146 27.7, 355124.6 6689137.5 27.7, 355107.6 6689143.4 27.7, 355105.7 6689144.3 27.7), (355108.3 6689147.5 27.7, 355110.2 6689150.3 27.7, 355110.3 6689150.8 27.7, 355110.8 6689152.5 27.7, 355111.5 6689154.8 27.7, 355102 6689157.9 27.7, 355101.4 6689155.4 27.7, 355100.9 6689153.9 27.7, 355100 6689150.2 27.7, 355108.3 6689147.5 27.7))
BATIMENT0000000302930457;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.4;7.5;24.0;27.0;8.7;Cadastre;;POLYGON Z ((355102 6689157.9 24, 355111.5 6689154.8 24, 355110.8 6689152.5 24, 355106.4 6689153.8 24, 355101.4 6689155.4 24, 355102 6689157.9 24))
BATIMENT0000000302930441;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;20.9;13.8;34.8;37.7;16.5;Cadastre;A 1.0;POLYGON Z ((355058.5 6689166 34.8, 355056.5 6689160.1 34.8, 355054 6689150.6 34.8, 355052.9 6689146.6 34.8, 355041.5 6689146.9 34.8, 355041.9 6689167.6 34.8, 355054.7 6689167 34.8, 355054.9 6689167.3 34.8, 355058.5 6689166 34.8))
BATIMENT0000000302930455;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;00;00;19.2;7.2;26.5;29.6;12.2;Cadastre;A 1.0;POLYGON Z ((355128.6 6689151.9 26.5, 355108.2 6689158.2 26.5, 355108.9 6689160.9 26.5, 355102.5 6689162.9 26.5, 355101.7 6689160.2 26.5, 355090.7 6689163.5 26.5, 355091.7 6689167 26.5, 355090.4 6689167.5 26.5, 355090.1 6689166.3 26.5, 355089.3 6689166.5 26.5, 355088.8 6689164.7 26.5, 355081.5 6689166.6 26.5, 355083.1 6689172.4 26.5, 355090.1 6689170.4 26.5, 355089.8 6689169.1 26.5, 355116.7 6689161.6 26.5, 355129.9 6689156.5 26.5, 355128.6 6689151.9 26.5))
BATIMENT0000000302930460;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1770-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;12;20;15.1;10.5;25.6;28.5;12.3;Cadastre;A 1.0;POLYGON Z ((355081.3 6689176 25.6, 355081.1 6689176.1 25.6, 355081.8 6689179 25.6, 355091.7 6689176.2 25.6, 355090.1 6689170.4 25.6, 355083.1 6689172.4 25.6, 355083.7 6689175.5 25.6, 355081.3 6689176 25.6))
BATIMENT0000000302930984;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;6.0;12;20;20.8;6.3;27.1;31.1;7.3;Cadastre;A 1.0;POLYGON Z ((355134.1 6689150 27.1, 355134.3 6689149.9 27.1, 355136.4 6689157.1 27.1, 355138.8 6689165.3 27.1, 355140.2 6689170.9 27.1, 355141.7 6689175.9 27.1, 355142 6689176.4 27.1, 355153.6 6689169.6 27.1, 355169.5 6689160 27.1, 355165.3 6689155.9 27.1, 355158.1 6689148.2 27.1, 355148.8 6689136.9 27.1, 355133.9 6689149.1 27.1, 355134.1 6689150 27.1), (355146.4 6689147.7 27.1, 355150.1 6689152.7 27.1, 355145.1 6689155.8 27.1, 355142.8 6689152.1 27.1, 355144 6689152.1 27.1, 355146.1 6689150.6 27.1, 355145.9 6689150.4 27.1, 355146.4 6689150.1 27.1, 355145.2 6689148.6 27.1, 355146.4 6689147.7 27.1))
BATIMENT0000000302930448;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;6.0;12;20;19.0;7.0;26.0;31.0;11.3;Cadastre;A 1.0;POLYGON Z ((355089.8 6689169.1 26, 355090.1 6689170.4 26, 355091.7 6689176.2 26, 355092.3 6689178.2 26, 355097.2 6689176.9 26, 355097.3 6689177.2 26, 355098.3 6689176.9 26, 355098.9 6689180.8 26, 355099.3 6689183.9 26, 355099.3 6689184.2 26, 355109.1 6689180.9 26, 355111.9 6689180 26, 355113 6689182.6 26, 355113.1 6689182.8 26, 355117.8 6689180.7 26, 355116.8 6689178.4 26, 355134.4 6689172.6 26, 355129.9 6689156.5 26, 355116.7 6689161.6 26, 355089.8 6689169.1 26), (355117.5 6689165 26, 355120.5 6689174.6 26, 355118.1 6689175.5 26, 355117.6 6689174 26, 355112.7 6689175.4 26, 355113.2 6689177.5 26, 355110.7 6689178 26, 355107.9 6689167.3 26, 355110.4 6689166.8 26, 355110.9 6689168 26, 355115.5 6689166.8 26, 355115.2 6689165.6 26, 355117.5 6689165 26))
BATIMENT0000000302930810;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;18.7;6.2;25.0;27.3;6.8;Cadastre;A 1.0;POLYGON Z ((355162.7 6689172.7 25, 355157 6689176.7 25, 355159 6689179.5 25, 355177 6689167.2 25, 355172.4 6689162.6 25, 355161.2 6689170.5 25, 355162.7 6689172.7 25), (355160.2 6689175.1 25, 355161.6 6689176.9 25, 355159.5 6689178.8 25, 355157.9 6689176.9 25, 355160.2 6689175.1 25))
BATIMENT0000000302930809;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;18.8;6.4;25.2;28.5;6.9;Cadastre;A 1.0;POLYGON Z ((355159 6689179.5 25.2, 355158.7 6689179.7 25.2, 355161.9 6689184 25.2, 355165.6 6689181.1 25.2, 355167.6 6689183.9 25.2, 355172.9 6689182.1 25.2, 355176.6 6689179.3 25.2, 355179.6 6689176.6 25.2, 355181.4 6689175 25.2, 355182.9 6689173.2 25.2, 355177 6689167.2 25.2, 355159 6689179.5 25.2))
BATIMENT0000000302930814;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.8;6.7;25.5;26.3;7.0;Cadastre;;POLYGON Z ((355151 6689184.1 25.5, 355150.2 6689183.7 25.5, 355150.1 6689183.6 25.5, 355150 6689183.2 25.5, 355150 6689183 25.5, 355150 6689182.9 25.5, 355150 6689182.8 25.5, 355150.1 6689182.7 25.5, 355150.2 6689182.6 25.5, 355150.3 6689182.5 25.5, 355150.5 6689182.5 25.5, 355150.6 6689182.5 25.5, 355150.7 6689182.5 25.5, 355150.9 6689182.5 25.5, 355151.5 6689182.7 25.5, 355152.1 6689180.9 25.5, 355153 6689180.5 25.5, 355153.2 6689179.7 25.5, 355149.7 6689182 25.5, 355149.6 6689182.1 25.5, 355150.5 6689185.6 25.5, 355151 6689184.1 25.5))
BATIMENT0000000302930813;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.1;6.6;24.7;26.1;7.0;Cadastre;;POLYGON Z ((355147.1 6689186.2 24.7, 355147.1 6689186.7 24.7, 355147.1 6689187.2 24.7, 355147.2 6689187.4 24.7, 355147.2 6689187.6 24.7, 355147.3 6689188.3 24.7, 355147.9 6689188.2 24.7, 355148 6689188.6 24.7, 355150.4 6689188 24.7, 355150.7 6689187.3 24.7, 355150.3 6689186 24.7, 355150.5 6689185.6 24.7, 355150.1 6689183.6 24.7, 355149.8 6689182.6 24.7, 355149.6 6689182.1 24.7, 355149.7 6689182 24.7, 355153.2 6689179.7 24.7, 355153.3 6689179.3 24.7, 355151.9 6689177.3 24.7, 355151.5 6689177.6 24.7, 355151.3 6689177.2 24.7, 355151.2 6689177.2 24.7, 355150.7 6689177.7 24.7, 355150.6 6689177.7 24.7, 355150.6 6689177.8 24.7, 355150.5 6689178 24.7, 355150.2 6689178.3 24.7, 355149.9 6689178.6 24.7, 355149.6 6689179 24.7, 355149.3 6689179.5 24.7, 355149.1 6689179.8 24.7, 355148.8 6689180.2 24.7, 355148.4 6689181 24.7, 355148.3 6689181.3 24.7, 355148.1 6689181.7 24.7, 355148 6689182.1 24.7, 355147.7 6689182.9 24.7, 355147.6 6689183.2 24.7, 355147.4 6689183.8 24.7, 355147.4 6689184 24.7, 355147.3 6689184.5 24.7, 355147.2 6689185 24.7, 355147.2 6689185.2 24.7, 355147.1 6689185.5 24.7, 355147.1 6689186 24.7, 355147.1 6689186.2 24.7))
BATIMENT0000000302930449;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;20;20;17.4;7.0;24.5;28.9;7.8;Cadastre;A 1.0;POLYGON Z ((355138.7 6689188.2 24.5, 355125.7 6689192.4 24.5, 355126.3 6689194.5 24.5, 355125.5 6689194.8 24.5, 355125.4 6689195.4 24.5, 355124.1 6689195.7 24.5, 355124.3 6689196.5 24.5, 355121.6 6689197.3 24.5, 355120.5 6689193.3 24.5, 355113.2 6689195 24.5, 355114.8 6689200.7 24.5, 355118.5 6689199.6 24.5, 355140.1 6689193.3 24.5, 355138.7 6689188.2 24.5))
BATIMENT0000000302930811;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;20.6;6.7;27.3;28.7;8.0;Cadastre;A 1.0;POLYGON Z ((355153 6689180.5 27.3, 355152.1 6689180.9 27.3, 355151.5 6689182.7 27.3, 355150.9 6689182.5 27.3, 355150.7 6689182.5 27.3, 355150.6 6689182.5 27.3, 355150.5 6689182.5 27.3, 355150.3 6689182.5 27.3, 355150.2 6689182.6 27.3, 355150.1 6689182.7 27.3, 355150 6689182.8 27.3, 355150 6689182.9 27.3, 355150 6689183 27.3, 355150 6689183.2 27.3, 355150.1 6689183.6 27.3, 355150.2 6689183.7 27.3, 355151 6689184.1 27.3, 355150.5 6689185.6 27.3, 355157.9 6689213.7 27.3, 355158.6 6689216.5 27.3, 355158.7 6689216.8 27.3, 355164.2 6689213.6 27.3, 355163.2 6689211.9 27.3, 355172.7 6689204.8 27.3, 355175.2 6689207.6 27.3, 355180.8 6689202.7 27.3, 355184.3 6689207 27.3, 355187.1 6689205.1 27.3, 355185.9 6689203.5 27.3, 355200.2 6689191.4 27.3, 355199.7 6689190.9 27.3, 355198 6689189 27.3, 355194.1 6689186.3 27.3, 355192.8 6689183.7 27.3, 355189.5 6689180.2 27.3, 355188.8 6689179.5 27.3, 355188.6 6689179.4 27.3, 355188.5 6689179.3 27.3, 355188.4 6689179.3 27.3, 355188 6689179.1 27.3, 355187.9 6689179.1 27.3, 355187.7 6689179 27.3, 355187.7 6689178.9 27.3, 355187.6 6689178.9 27.3, 355187.3 6689178.7 27.3, 355187.2 6689178.7 27.3, 355187.1 6689178.6 27.3, 355186.9 6689178.5 27.3, 355186.8 6689178.4 27.3, 355186.7 6689178.3 27.3, 355186.4 6689178.1 27.3, 355186.1 6689177.8 27.3, 355186 6689177.7 27.3, 355185.9 6689177.6 27.3, 355183.1 6689174.1 27.3, 355183.4 6689173.7 27.3, 355182.9 6689173.2 27.3, 355181.4 6689175 27.3, 355179.6 6689176.6 27.3, 355176.6 6689179.3 27.3, 355172.9 6689182.1 27.3, 355167.6 6689183.9 27.3, 355165.6 6689181.1 27.3, 355161.9 6689184 27.3, 355158.7 6689179.7 27.3, 355159 6689179.5 27.3, 355157 6689176.7 27.3, 355155.4 6689174.3 27.3, 355152.5 6689176.2 27.3, 355151.8 6689176.7 27.3, 355151.5 6689176.9 27.3, 355151.4 6689177.1 27.3, 355151.3 6689177.2 27.3, 355151.5 6689177.6 27.3, 355151.9 6689177.3 27.3, 355153.3 6689179.3 27.3, 355153.2 6689179.7 27.3, 355153 6689180.5 27.3))
BATIMENT0000000302930454;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;12;20;18.3;7.0;25.4;29.3;8.0;Cadastre;A 1.0;POLYGON Z ((355142.1 6689201.7 25.4, 355140.1 6689193.3 25.4, 355118.5 6689199.6 25.4, 355119.5 6689203.1 25.4, 355120.7 6689202.8 25.4, 355121.8 6689206.8 25.4, 355123.5 6689206.4 25.4, 355142.1 6689201.7 25.4))
BATIMENT0000000302930818;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.3;6.8;26.1;28.2;7.8;Cadastre;A 1.0;POLYGON Z ((355157.9 6689213.7 26.1, 355150.5 6689185.6 26.1, 355150.3 6689186 26.1, 355150.7 6689187.3 26.1, 355150.4 6689188 26.1, 355148 6689188.6 26.1, 355147.9 6689188.2 26.1, 355147.3 6689188.3 26.1, 355147.5 6689189.1 26.1, 355147.5 6689189.2 26.1, 355152 6689206.6 26.1, 355153 6689206.4 26.1, 355154.8 6689213.2 26.1, 355153.7 6689213.4 26.1, 355155 6689218.4 26.1, 355155.9 6689218.1 26.1, 355158.6 6689216.5 26.1, 355157.9 6689213.7 26.1))
BATIMENT0000000302931074;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;7.0;;;21.8;6.8;28.6;31.6;7.2;Cadastre;C 0.1;POLYGON Z ((355259.4 6689187.4 28.6, 355258.3 6689188.7 28.6, 355255.1 6689192.7 28.6, 355254.4 6689193.6 28.6, 355251 6689197.8 28.6, 355250.7 6689198.2 28.6, 355255.3 6689200.8 28.6, 355255.2 6689201 28.6, 355258.2 6689202.7 28.6, 355258.6 6689203 28.6, 355265.9 6689191.5 28.6, 355259.4 6689187.4 28.6))
BATIMENT0000000302930822;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;6.8;18.0;22.7;7.1;Cadastre;;POLYGON Z ((355205.6 6689198 18, 355209.3 6689202.7 18, 355211.1 6689201.2 18, 355207.4 6689196.7 18, 355205.6 6689198 18))
BATIMENT0000000302931087;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.9;7.0;24.0;28.1;7.5;Cadastre;;POLYGON Z ((355244.9 6689201.4 24, 355246.9 6689203 24, 355250.3 6689198.7 24, 355248.4 6689197.1 24, 355244.9 6689201.4 24))
BATIMENT0000000302931072;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;23;20;19.9;6.8;26.7;30.9;7.2;Cadastre;A 1.0;POLYGON Z ((355281.7 6689201.3 26.7, 355265.9 6689191.5 26.7, 355258.6 6689203 26.7, 355258.2 6689202.7 26.7, 355256.4 6689205.4 26.7, 355256.8 6689205.7 26.7, 355259.2 6689207.1 26.7, 355260 6689207.5 26.7, 355263.4 6689202.3 26.7, 355273.3 6689208.3 26.7, 355276.1 6689210 26.7, 355281.7 6689201.3 26.7))
BATIMENT0000000302931073;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;7.0;10;20;22.7;6.9;29.7;31.7;7.4;Cadastre;A 1.0;POLYGON Z ((355250.3 6689198.7 29.7, 355246.9 6689203 29.7, 355246.7 6689203.2 29.7, 355255.1 6689208.2 29.7, 355256.8 6689205.7 29.7, 355256.4 6689205.4 29.7, 355258.2 6689202.7 29.7, 355255.2 6689201 29.7, 355255.3 6689200.8 29.7, 355250.7 6689198.2 29.7, 355250.3 6689198.7 29.7))
BATIMENT0000000302930816;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;20;20;18.2;6.8;25.0;27.9;8.1;Cadastre;A 1.0;POLYGON Z ((355185.9 6689203.5 25, 355187.1 6689205.1 25, 355184.3 6689207 25, 355178.5 6689211.6 25, 355181.6 6689215.5 25, 355188.1 6689210.2 25, 355195.3 6689204.7 25, 355205.1 6689197.4 25, 355201.5 6689192.8 25, 355200.2 6689191.4 25, 355185.9 6689203.5 25))
BATIMENT0000000302931083;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.5;7.1;20.7;28.5;7.5;Cadastre;;POLYGON Z ((355244 6689202.9 20.7, 355243.5 6689203.1 20.7, 355241.3 6689205.8 20.7, 355241.3 6689206.4 20.7, 355241.4 6689207 20.7, 355242.8 6689208.1 20.7, 355246.2 6689203.8 20.7, 355244.8 6689202.8 20.7, 355244 6689202.9 20.7))
BATIMENT0000000302930826;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.2;6.9;23.2;27.2;7.3;Cadastre;;POLYGON Z ((355212.4 6689205.7 23.2, 355211.8 6689205.7 23.2, 355210.4 6689207.1 23.2, 355212.2 6689209 23.2, 355213.8 6689207.6 23.2, 355213.8 6689207.1 23.2, 355212.4 6689205.7 23.2))
BATIMENT0000000302931075;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.8;8.0;27.8;;;Cadastre;;POLYGON Z ((355255.1 6689208.2 27.8, 355253.7 6689210.6 27.8, 355256.1 6689212.1 27.8, 355258.5 6689208.4 27.8, 355259.2 6689207.1 27.8, 355256.8 6689205.7 27.8, 355255.1 6689208.2 27.8))
BATIMENT0000000302930823;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;00;00;15.2;8.0;23.2;25.7;8.2;Cadastre;A 1.0;POLYGON Z ((355195.3 6689204.7 23.2, 355188.1 6689210.2 23.2, 355181.6 6689215.5 23.2, 355178.7 6689217.9 23.2, 355181.3 6689223 23.2, 355208.7 6689205.1 23.2, 355209.2 6689204.7 23.2, 355209.4 6689204.8 23.2, 355210.3 6689203.9 23.2, 355209.3 6689202.7 23.2, 355205.6 6689198 23.2, 355205.1 6689197.4 23.2, 355195.3 6689204.7 23.2))
BATIMENT0000000302930442;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;00;00;16.9;10.5;27.4;35.4;16.9;Cadastre;A 1.0;POLYGON Z ((355054.7 6689167 27.4, 355041.9 6689167.6 27.4, 355042.6 6689199.6 27.4, 355049.2 6689199 27.4, 355049.2 6689199.3 27.4, 355057.4 6689196.5 27.4, 355059.5 6689202.5 27.4, 355068 6689199.6 27.4, 355080.9 6689195 27.4, 355090.9 6689190.6 27.4, 355094.1 6689182.9 27.4, 355097.9 6689182 27.4, 355097.7 6689181 27.4, 355097.3 6689177.2 27.4, 355097.2 6689176.9 27.4, 355092.3 6689178.2 27.4, 355091.7 6689176.2 27.4, 355081.8 6689179 27.4, 355081.1 6689176.1 27.4, 355081.3 6689176 27.4, 355080 6689170.9 27.4, 355080.9 6689170.7 27.4, 355078 6689161.8 27.4, 355055.3 6689168.5 27.4, 355054.9 6689167.3 27.4, 355054.7 6689167 27.4))
BATIMENT0000000302930447;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;10.9;25.3;;;Cadastre;;POLYGON Z ((355098.2 6689184.2 25.3, 355099.3 6689183.9 25.3, 355098.9 6689180.8 25.3, 355097.7 6689181 25.3, 355097.9 6689182 25.3, 355098.2 6689184.2 25.3))
BATIMENT0000000302930459;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;7.2;20.4;26.2;12.1;Cadastre;;POLYGON Z ((355095.7 6689199.1 20.4, 355094.2 6689196.3 20.4, 355074.1 6689207.3 20.4, 355079.1 6689216.5 20.4, 355099.2 6689205.7 20.4, 355097.8 6689202.9 20.4, 355128.2 6689186.4 20.4, 355127.3 6689181.9 20.4, 355095.7 6689199.1 20.4))
BATIMENT0000000302930446;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1852-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;10;20;17.5;7.1;24.7;33.5;16.4;Cadastre;C 0.6;POLYGON Z ((355116.8 6689178.4 24.7, 355117.8 6689180.7 24.7, 355113.1 6689182.8 24.7, 355113 6689182.6 24.7, 355110.2 6689183.7 24.7, 355109.1 6689180.9 24.7, 355099.3 6689184.2 24.7, 355099.3 6689183.9 24.7, 355098.2 6689184.2 24.7, 355097.9 6689182 24.7, 355094.1 6689182.9 24.7, 355090.9 6689190.6 24.7, 355080.9 6689195 24.7, 355068 6689199.6 24.7, 355069.1 6689201.9 24.7, 355058.5 6689207.5 24.7, 355058.7 6689208.6 24.7, 355056.8 6689209.5 24.7, 355056.7 6689207.3 24.7, 355059.4 6689206 24.7, 355059.2 6689202.6 24.7, 355059.5 6689202.5 24.7, 355057.4 6689196.5 24.7, 355049.2 6689199.3 24.7, 355049.2 6689199 24.7, 355042.6 6689199.6 24.7, 355043 6689226.8 24.7, 355043.3 6689227.4 24.7, 355043.5 6689227.3 24.7, 355045.5 6689230.9 24.7, 355045.4 6689231.1 24.7, 355045.8 6689231.8 24.7, 355090.1 6689227.5 24.7, 355088 6689213.1 24.7, 355091.3 6689212.6 24.7, 355093.6 6689227.2 24.7, 355098.2 6689226.6 24.7, 355099.2 6689226.2 24.7, 355099.1 6689225.3 24.7, 355108.1 6689223.8 24.7, 355106 6689218.1 24.7, 355111.4 6689216.2 24.7, 355110.1 6689210.1 24.7, 355109.4 6689207.5 24.7, 355106.2 6689208.4 24.7, 355106.2 6689208.7 24.7, 355107 6689211 24.7, 355103.2 6689212.6 24.7, 355101.4 6689213.3 24.7, 355099.1 6689210.7 24.7, 355102.3 6689209.8 24.7, 355104 6689209.3 24.7, 355102.4 6689204.2 24.7, 355114.8 6689200.7 24.7, 355113.2 6689195 24.7, 355120.5 6689193.3 24.7, 355125.7 6689192.4 24.7, 355138.7 6689188.2 24.7, 355135.8 6689177.5 24.7, 355134.4 6689172.6 24.7, 355116.8 6689178.4 24.7), (355128.2 6689186.4 24.7, 355097.8 6689202.9 24.7, 355099.2 6689205.7 24.7, 355079.1 6689216.5 24.7, 355074.1 6689207.3 24.7, 355094.2 6689196.3 24.7, 355095.7 6689199.1 24.7, 355127.3 6689181.9 24.7, 355128.2 6689186.4 24.7), (355073 6689216.3 24.7, 355054.2 6689226.5 24.7, 355052.2 6689222.6 24.7, 355071.1 6689212.5 24.7, 355073 6689216.3 24.7))
BATIMENT0000000302930451;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.6;10.8;23.4;;;Cadastre;;POLYGON Z ((355103.2 6689212.6 23.4, 355102.3 6689209.8 23.4, 355099.1 6689210.7 23.4, 355101.4 6689213.3 23.4, 355103.2 6689212.6 23.4))
BATIMENT0000000302930458;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;12.1;26.4;29.2;15.2;Cadastre;;POLYGON Z ((355052.2 6689222.6 26.4, 355054.2 6689226.5 26.4, 355073 6689216.3 26.4, 355071.1 6689212.5 26.4, 355052.2 6689222.6 26.4))
BATIMENT0000000302930452;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;11.5;25.9;29.5;11.5;Cadastre;;POLYGON Z ((355093.6 6689227.2 25.9, 355091.3 6689212.6 25.9, 355088 6689213.1 25.9, 355090.1 6689227.5 25.9, 355093.6 6689227.2 25.9))
BATIMENT0000000302930988;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;12;20;20.4;14.3;34.8;36.9;15.4;Cadastre;A 1.0;POLYGON Z ((355045.2 6689237.8 34.8, 355044.5 6689238.2 34.8, 355044.1 6689238.8 34.8, 355044.3 6689239.7 34.8, 355044.6 6689240.3 34.8, 355057.2 6689245.6 34.8, 355058.5 6689236.5 34.8, 355045.2 6689237.8 34.8))
BATIMENT0000000302930987;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;19.1;13.3;32.5;33.8;14.6;Cadastre;A 1.0;POLYGON Z ((355058.5 6689236.5 32.5, 355057.2 6689245.6 32.5, 355070.3 6689251.2 32.5, 355070.6 6689235.3 32.5, 355058.5 6689236.5 32.5))
BATIMENT0000000302930985;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;30;17.3;12.6;30.0;33.1;14.0;Cadastre;A 1.0;POLYGON Z ((355077.8 6689235.1 30, 355070.6 6689235.3 30, 355070.3 6689251.2 30, 355082 6689256.2 30, 355082 6689234.4 30, 355077.8 6689235.1 30))
BATIMENT0000000302931084;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.0;7.1;26.2;28.2;7.5;Cadastre;;POLYGON Z ((355240 6689207.8 26.2, 355239.3 6689208.2 26.2, 355237.5 6689210.6 26.2, 355237.5 6689211.3 26.2, 355237.5 6689212 26.2, 355238.8 6689213.1 26.2, 355242.2 6689208.8 26.2, 355240.9 6689207.8 26.2, 355240 6689207.8 26.2))
BATIMENT0000000302931086;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;00;00;20.1;7.9;28.0;;;Cadastre;A 1.0;POLYGON Z ((355246.2 6689203.8 28, 355242.8 6689208.1 28, 355242.5 6689208.4 28, 355259.4 6689218.5 28, 355261.5 6689215.6 28, 355256.1 6689212.1 28, 355253.7 6689210.6 28, 355255.1 6689208.2 28, 355246.7 6689203.2 28, 355246.2 6689203.8 28))
BATIMENT0000000302930825;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;7.1;22.2;24.5;7.6;Cadastre;;POLYGON Z ((355214.5 6689211.5 22.2, 355214.1 6689210.7 22.2, 355212.3 6689210 22.2, 355211.4 6689212 22.2, 355211.1 6689212.7 22.2, 355213 6689213.6 22.2, 355213.6 6689213.5 22.2, 355214.5 6689211.5 22.2))
BATIMENT0000000302930824;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.6;6.9;25.6;27.6;7.8;Cadastre;A 1.0;POLYGON Z ((355207.3 6689215.3 25.6, 355210.1 6689213.7 25.6, 355210.8 6689213.3 25.6, 355211.1 6689212.7 25.6, 355211.4 6689212 25.6, 355212.3 6689210 25.6, 355212.5 6689209.4 25.6, 355212.2 6689209 25.6, 355210.4 6689207.1 25.6, 355209.4 6689206 25.6, 355200.3 6689211.8 25.6, 355195.5 6689215.1 25.6, 355198.5 6689220.2 25.6, 355200.1 6689219.3 25.6, 355202.8 6689217.8 25.6, 355203.7 6689217.3 25.6, 355205.5 6689216.3 25.6, 355206.5 6689215.7 25.6, 355207.3 6689215.3 25.6))
BATIMENT0000000302930827;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.8;8.5;22.3;;;Cadastre;;POLYGON Z ((355211 6689216 22.3, 355211.2 6689215.5 22.3, 355210.1 6689213.7 22.3, 355207.3 6689215.3 22.3, 355208.3 6689217.1 22.3, 355208.8 6689217.2 22.3, 355211 6689216 22.3))
BATIMENT0000000302931094;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.9;7.3;24.2;28.0;7.6;Cadastre;;POLYGON Z ((355237.2 6689215.1 24.2, 355235.1 6689213.4 24.2, 355233.4 6689215.5 24.2, 355233.7 6689215.8 24.2, 355233 6689216.8 24.2, 355234.7 6689218.2 24.2, 355237.2 6689215.1 24.2))
BATIMENT0000000302930828;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;7.1;21.0;25.2;7.8;Cadastre;;POLYGON Z ((355207.3 6689217.9 21, 355207.5 6689217.5 21, 355206.5 6689215.7 21, 355205.5 6689216.3 21, 355203.7 6689217.3 21, 355204.8 6689219.2 21, 355205.2 6689219.3 21, 355207.3 6689217.9 21))
BATIMENT0000000302931085;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;;;8.2;7.0;15.2;31.7;7.6;Cadastre;A 1.0;POLYGON Z ((355242.2 6689208.8 15.2, 355238.8 6689213.1 15.2, 355237.2 6689215.1 15.2, 355234.7 6689218.2 15.2, 355234.4 6689218.6 15.2, 355244.6 6689225.7 15.2, 355247.7 6689227 15.2, 355247.8 6689227 15.2, 355250.8 6689228.9 15.2, 355250.6 6689229.3 15.2, 355251.3 6689229.8 15.2, 355259.4 6689218.5 15.2, 355242.5 6689208.4 15.2, 355242.2 6689208.8 15.2))
BATIMENT0000000302930829;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;7.3;21.0;25.2;7.9;Cadastre;;POLYGON Z ((355203.6 6689220 21, 355203.8 6689219.5 21, 355202.8 6689217.8 21, 355200.1 6689219.3 21, 355201.1 6689221 21, 355201.5 6689221.1 21, 355203.6 6689220 21))
BATIMENT0000000302931098;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.2;7.4;23.7;27.1;7.7;Cadastre;;POLYGON Z ((355234.4 6689218.6 23.7, 355232.3 6689217 23.7, 355228.4 6689222 23.7, 355230.5 6689223.5 23.7, 355234.4 6689218.6 23.7))
BATIMENT0000000302930450;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;16.2;7.2;23.5;25.5;9.4;Cadastre;A 1.0;POLYGON Z ((355110.1 6689210.1 23.5, 355114.2 6689208.9 23.5, 355113.6 6689206.8 23.5, 355119.9 6689204.9 23.5, 355119.5 6689203.1 23.5, 355118.5 6689199.6 23.5, 355114.8 6689200.7 23.5, 355102.4 6689204.2 23.5, 355104 6689209.3 23.5, 355106.2 6689208.7 23.5, 355106.2 6689208.4 23.5, 355109.4 6689207.5 23.5, 355110.1 6689210.1 23.5))
BATIMENT0000000302930820;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.6;7.0;25.7;26.2;7.6;Cadastre;;POLYGON Z ((355153 6689206.4 25.7, 355152 6689206.6 25.7, 355153.7 6689213.4 25.7, 355154.8 6689213.2 25.7, 355153 6689206.4 25.7))
BATIMENT0000000302930453;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;20;20;18.7;7.2;26.0;29.1;9.9;Cadastre;A 1.0;POLYGON Z ((355144.5 6689213.3 26, 355144.9 6689212.7 26, 355142.1 6689201.7 26, 355123.5 6689206.4 26, 355124.2 6689209.6 26, 355116.1 6689211.7 26, 355115.4 6689208.6 26, 355114.2 6689208.9 26, 355110.1 6689210.1 26, 355111.4 6689216.2 26, 355106 6689218.1 26, 355108.1 6689223.8 26, 355144.5 6689213.3 26))
BATIMENT0000000302930819;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.7;7.7;22.5;25.7;8.0;Cadastre;;POLYGON Z ((355168.3 6689213.8 22.5, 355170.2 6689216.9 22.5, 355175.6 6689215.1 22.5, 355172.1 6689209.1 22.5, 355168.3 6689213.8 22.5))
BATIMENT0000000302930817;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;19.5;7.4;27.0;28.8;8.1;Cadastre;A 1.0;POLYGON Z ((355180.8 6689202.7 27, 355175.2 6689207.6 27, 355172.7 6689204.8 27, 355163.2 6689211.9 27, 355164.2 6689213.6 27, 355158.7 6689216.8 27, 355155.2 6689219 27, 355159.5 6689231.9 27, 355163.2 6689230.3 27, 355167.5 6689228.3 27, 355170.6 6689226.2 27, 355173.8 6689222.8 27, 355173.8 6689221.8 27, 355178.7 6689217.9 27, 355181.6 6689215.5 27, 355178.5 6689211.6 27, 355184.3 6689207 27, 355180.8 6689202.7 27), (355175.6 6689215.1 27, 355170.2 6689216.9 27, 355168.3 6689213.8 27, 355172.1 6689209.1 27, 355175.6 6689215.1 27))
BATIMENT0000000302930962;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;7.0;10;20;21.3;7.2;28.6;31.1;8.6;Cadastre;A 1.0;POLYGON Z ((355145.7 6689217 28.6, 355145.4 6689216.8 28.6, 355126.2 6689222.3 28.6, 355127.2 6689225.4 28.6, 355127.4 6689225.4 28.6, 355128.2 6689227.7 28.6, 355130.5 6689227 28.6, 355131.8 6689226.9 28.6, 355132 6689227.5 28.6, 355146.9 6689221.4 28.6, 355145.7 6689217 28.6))
BATIMENT0000000302930963;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;19.8;7.3;27.2;30.7;8.4;Cadastre;A 1.0;POLYGON Z ((355146.9 6689221.4 27.2, 355132 6689227.5 27.2, 355132.1 6689227.9 27.2, 355131.8 6689228.7 27.2, 355131.2 6689228.8 27.2, 355132.2 6689232.2 27.2, 355148.3 6689226.5 27.2, 355146.9 6689221.4 27.2))
BATIMENT0000000302930821;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;14.5;8.8;23.3;;;Cadastre;A 1.0;POLYGON Z ((355173.8 6689221.8 23.3, 355173.8 6689222.8 23.3, 355170.6 6689226.2 23.3, 355167.5 6689228.3 23.3, 355163.2 6689230.3 23.3, 355159.5 6689231.9 23.3, 355162.2 6689239.8 23.3, 355174.6 6689235.4 23.3, 355182 6689232.5 23.3, 355183.3 6689232 23.3, 355191.4 6689227.8 23.3, 355186.6 6689220.9 23.3, 355181.8 6689224.1 23.3, 355181.6 6689223.5 23.3, 355181.3 6689223 23.3, 355178.7 6689217.9 23.3, 355173.8 6689221.8 23.3))
BATIMENT0000000302930960;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;10;20;14.4;8.3;22.7;27.7;9.9;Cadastre;A 1.0;POLYGON Z ((355110.1 6689230.4 22.7, 355111.9 6689238.9 22.7, 355132.2 6689232.2 22.7, 355131.2 6689228.8 22.7, 355128.7 6689229.5 22.7, 355128.5 6689228.8 22.7, 355128.2 6689227.7 22.7, 355127.4 6689225.4 22.7, 355127.2 6689225.4 22.7, 355110.1 6689230.4 22.7))
BATIMENT0000000302930971;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.3;7.9;25.2;27.9;8.3;Cadastre;;POLYGON Z ((355133.5 6689238.7 25.2, 355134.8 6689238.8 25.2, 355136.9 6689238 25.2, 355137.3 6689235 25.2, 355131.8 6689236.9 25.2, 355133.5 6689238.7 25.2))
BATIMENT0000000302930830;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;10.5;7.1;17.7;26.0;8.2;Cadastre;A 1.0;POLYGON Z ((355186.6 6689220.9 17.7, 355191.4 6689227.8 17.7, 355196.2 6689224.4 17.7, 355198.7 6689222.4 17.7, 355199.1 6689221.2 17.7, 355198.5 6689220.2 17.7, 355195.5 6689215.1 17.7, 355186.6 6689220.9 17.7))
BATIMENT0000000302931099;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;6.0;;;20.1;7.9;28.0;;;Cadastre;A 1.0;POLYGON Z ((355230.5 6689223.5 28, 355241.4 6689230.8 28, 355244.6 6689225.7 28, 355234.4 6689218.6 28, 355230.5 6689223.5 28))
BATIMENT0000000302931093;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;7.2;16.5;22.2;7.6;Cadastre;;POLYGON Z ((355244.6 6689225.7 16.5, 355241.4 6689230.8 16.5, 355244.2 6689232.7 16.5, 355247.7 6689227 16.5, 355244.6 6689225.7 16.5))
BATIMENT0000000302931036;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;7.6;9.7;28.0;8.2;Cadastre;;POLYGON Z ((355200.2 6689228.4 9.7, 355202.8 6689230.9 9.7, 355203.4 6689230.2 9.7, 355203.4 6689229.5 9.7, 355203.2 6689229 9.7, 355201.7 6689227.8 9.7, 355201.2 6689227.7 9.7, 355200.6 6689227.7 9.7, 355200.2 6689228.4 9.7))
BATIMENT0000002275362746;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.5;7.9;;;;Imagerie aérienne;;POLYGON Z ((355288 6689206.3 22.8, 355273.4 6689228.4 22.8, 355262.6 6689244.8 17.1, 355275.6 6689253.1 15.6, 355286.2 6689237 23.4, 355300.8 6689214.2 23.4, 355288 6689206.3 22.8))
BATIMENT0000000302931082;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;20;20;20.0;8.0;28.0;;;Cadastre;A 1.0;POLYGON Z ((355226.5 6689228.5 28, 355231.7 6689232.3 28, 355231.9 6689232.1 28, 355237.9 6689236.3 28, 355241.4 6689230.8 28, 355230.5 6689223.5 28, 355226.5 6689228.5 28))
BATIMENT0000000302931089;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;7.6;22.5;27.2;8.0;Cadastre;;POLYGON Z ((355222.8 6689233.1 22.5, 355225.3 6689230 22.5, 355223.4 6689228.4 22.5, 355220.8 6689231.5 22.5, 355222.8 6689233.1 22.5))
BATIMENT0000000302931076;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.2;6.9;24.1;27.0;8.1;Cadastre;C 0.8;POLYGON Z ((355237.4 6689244.5 24.1, 355236.5 6689244.1 24.1, 355235.9 6689244.8 24.1, 355235.1 6689244.6 24.1, 355235.9 6689245 24.1, 355236.8 6689245.3 24.1, 355237.3 6689245.9 24.1, 355237.7 6689246.5 24.1, 355248.9 6689254.2 24.1, 355257.8 6689242 24.1, 355262.3 6689235.7 24.1, 355262.5 6689235.9 24.1, 355266.5 6689229.7 24.1, 355274.5 6689217.6 24.1, 355273.3 6689216.7 24.1, 355275 6689214.1 24.1, 355274.1 6689213.5 24.1, 355274.5 6689212.9 24.1, 355276.1 6689210 24.1, 355273.3 6689208.3 24.1, 355271.5 6689211.1 24.1, 355268.9 6689214.9 24.1, 355268 6689214.2 24.1, 355264 6689211.8 24.1, 355258.5 6689208.4 24.1, 355256.1 6689212.1 24.1, 355261.5 6689215.6 24.1, 355262.5 6689216.3 24.1, 355262 6689218.5 24.1, 355263.4 6689219.5 24.1, 355260.9 6689223.1 24.1, 355259 6689225.5 24.1, 355254.4 6689231.7 24.1, 355252.8 6689230.5 24.1, 355252.6 6689230.6 24.1, 355252.4 6689231 24.1, 355251.3 6689229.8 24.1, 355250.6 6689229.3 24.1, 355248.5 6689227.9 24.1, 355244.7 6689233 24.1, 355240.6 6689238.2 24.1, 355239.7 6689239.3 24.1, 355240.6 6689239.9 24.1, 355237.4 6689244.5 24.1))
BATIMENT0000000302931092;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;7.5;20.2;25.5;7.9;Cadastre;;POLYGON Z ((355237.9 6689236.3 20.2, 355240.6 6689238.2 20.2, 355244.2 6689232.7 20.2, 355241.4 6689230.8 20.2, 355237.9 6689236.3 20.2))
BATIMENT0000000302931080;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;6.0;00;00;20.1;8.0;28.1;31.3;8.1;Cadastre;A 0.3;POLYGON Z ((355225.3 6689230 28.1, 355222.8 6689233.1 28.1, 355221.3 6689235 28.1, 355232.2 6689243.3 28.1, 355231.8 6689243.9 28.1, 355232.6 6689244.4 28.1, 355233.1 6689243.8 28.1, 355237.1 6689237.6 28.1, 355237.9 6689236.3 28.1, 355231.9 6689232.1 28.1, 355231.7 6689232.3 28.1, 355226.5 6689228.5 28.1, 355225.3 6689230 28.1))
BATIMENT0000000302928330;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;23;18.9;20.2;39.2;42.0;22.0;Cadastre;A 1.0;POLYGON Z ((354755.3 6689054.6 39.2, 354748.7 6689062.4 39.2, 354745.9 6689060.3 39.2, 354744.9 6689060.5 39.2, 354742.2 6689063.8 39.2, 354751.3 6689071.3 39.2, 354758.4 6689062.7 39.2, 354760.1 6689060.7 39.2, 354761.5 6689058.9 39.2, 354759.5 6689057.3 39.2, 354761 6689055.5 39.2, 354762.9 6689057.2 39.2, 354770 6689048.6 39.2, 354759.9 6689040.1 39.2, 354750.8 6689051 39.2, 354755.3 6689054.6 39.2))
BATIMENT0000000302928278;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.8;23.3;38.1;;;Cadastre;C 0.2;POLYGON Z ((354711.7 6689050.5 38.1, 354704.7 6689058.9 38.1, 354708.9 6689062.3 38.1, 354715 6689067.5 38.1, 354718.8 6689070.6 38.1, 354725.8 6689062.3 38.1, 354711.7 6689050.5 38.1))
BATIMENT0000000302928329;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;19.0;19.9;39.0;42.2;21.9;Cadastre;A 1.0;POLYGON Z ((354761.5 6689058.9 39, 354760.1 6689060.7 39, 354780.9 6689077.8 39, 354783.2 6689075 39, 354785.7 6689072 39, 354790.8 6689065.9 39, 354770 6689048.6 39, 354762.9 6689057.2 39, 354761.5 6689058.9 39), (354776.8 6689064.6 39, 354779.8 6689067.2 39, 354778.3 6689069 39, 354774.9 6689066.7 39, 354776.8 6689064.6 39))
BATIMENT0000000302928333;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;00;00;4.3;21.7;26.0;39.4;22.0;Cadastre;A 1.0;POLYGON Z ((354751.3 6689071.3 26, 354755.5 6689074.9 26, 354762.7 6689066.2 26, 354758.4 6689062.7 26, 354751.3 6689071.3 26))
BATIMENT0000000302928279;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;23.8;37.9;;;Cadastre;;POLYGON Z ((354718.8 6689070.6 37.9, 354715 6689067.5 37.9, 354714.1 6689068.9 37.9, 354717.6 6689072 37.9, 354718.8 6689070.6 37.9))
BATIMENT0000000302928274;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.7;22.5;42.2;45.2;23.9;Cadastre;;POLYGON Z ((354711.7 6689075.6 42.2, 354713.6 6689076.8 42.2, 354717.6 6689072 42.2, 354714.1 6689068.9 42.2, 354713.6 6689068.6 42.2, 354711.1 6689071.8 42.2, 354709.3 6689074 42.2, 354711.7 6689075.6 42.2))
BATIMENT0000000302928280;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;21.2;21.9;43.1;44.9;24.0;Cadastre;A 1.0;POLYGON Z ((354725.8 6689062.3 43.1, 354718.8 6689070.6 43.1, 354717.6 6689072 43.1, 354713.6 6689076.8 43.1, 354716 6689078.4 43.1, 354718.3 6689079.9 43.1, 354720.5 6689076.8 43.1, 354721.8 6689076.5 43.1, 354727.1 6689080.6 43.1, 354725.6 6689082.7 43.1, 354724.6 6689084 43.1, 354728.1 6689086.3 43.1, 354738.7 6689073 43.1, 354725.8 6689062.3 43.1))
BATIMENT0000000302928335;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;00;00;8.4;21.5;30.0;39.1;22.0;Cadastre;A 1.0;POLYGON Z ((354779.2 6689079.9 30, 354775.2 6689076.5 30, 354767.9 6689085.3 30, 354771.9 6689088.6 30, 354779.2 6689079.9 30))
BATIMENT0000000302928285;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.7;22.7;41.5;44.0;24.0;Cadastre;;POLYGON Z ((354724.6 6689084 41.5, 354725.6 6689082.7 41.5, 354724.3 6689082 41.5, 354723.6 6689083.3 41.5, 354724.6 6689084 41.5))
BATIMENT0000000302928284;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;19.2;22.5;41.7;44.5;23.9;Cadastre;A 1.0;POLYGON Z ((354738.7 6689073 41.7, 354728.1 6689086.3 41.7, 354731.4 6689088.3 41.7, 354732.2 6689088.9 41.7, 354733 6689087.7 41.7, 354734.4 6689086.1 41.7, 354734.4 6689084.2 41.7, 354735.4 6689084.2 41.7, 354735.4 6689085.7 41.7, 354736.4 6689086.3 41.7, 354736.7 6689087.8 41.7, 354737.8 6689087.7 41.7, 354739.2 6689088.7 41.7, 354740.6 6689088.6 41.7, 354740.6 6689089.4 41.7, 354739 6689089.7 41.7, 354737.2 6689092.1 41.7, 354737.9 6689092.6 41.7, 354741.8 6689095.1 41.7, 354751.3 6689083.6 41.7, 354738.7 6689073 41.7))
BATIMENT0000000302928273;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;20;20;22.2;23.2;45.4;48.0;24.4;Cadastre;A 1.0;POLYGON Z ((354717.5 6689099.7 45.4, 354728.1 6689086.3 45.4, 354724.6 6689084 45.4, 354723.6 6689083.3 45.4, 354721.8 6689082.1 45.4, 354719.8 6689086.7 45.4, 354718.2 6689086.1 45.4, 354717.5 6689087.5 45.4, 354712.8 6689085.3 45.4, 354716 6689078.4 45.4, 354713.6 6689076.8 45.4, 354711.7 6689075.6 45.4, 354709.6 6689079.6 45.4, 354707.7 6689083.3 45.4, 354702.6 6689093.2 45.4, 354717.5 6689099.7 45.4))
BATIMENT0000000302928282;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;23.1;39.5;41.1;23.6;Cadastre;;POLYGON Z ((354732.2 6689088.9 39.5, 354733 6689089.4 39.5, 354733.7 6689088.1 39.5, 354733 6689087.7 39.5, 354732.2 6689088.9 39.5))
BATIMENT0000000302928288;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;23.2;37.5;41.0;23.8;Cadastre;;POLYGON Z ((354737.9 6689092.6 37.5, 354737.2 6689092.1 37.5, 354733 6689089.4 37.5, 354732.2 6689088.9 37.5, 354731.4 6689088.3 37.5, 354730.5 6689089.8 37.5, 354737.4 6689093.6 37.5, 354737.9 6689092.6 37.5))
BATIMENT0000000302928281;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;10;20;19.6;23.2;42.8;46.4;24.3;Cadastre;A 1.0;POLYGON Z ((354732.6 6689106.3 42.8, 354741.8 6689095.1 42.8, 354737.9 6689092.6 42.8, 354737.4 6689093.6 42.8, 354736.5 6689095.7 42.8, 354728.7 6689092.9 42.8, 354728.6 6689091.2 42.8, 354729.2 6689091.5 42.8, 354730.2 6689089.7 42.8, 354730.5 6689089.8 42.8, 354731.4 6689088.3 42.8, 354728.1 6689086.3 42.8, 354717.5 6689099.7 42.8, 354732.6 6689106.3 42.8))
BATIMENT0000000302928283;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;10;20;22.1;22.1;44.2;46.0;24.0;Cadastre;A 1.0;POLYGON Z ((354732.6 6689106.3 44.2, 354756.4 6689116.4 44.2, 354770.3 6689099.4 44.2, 354751.3 6689083.6 44.2, 354741.8 6689095.1 44.2, 354732.6 6689106.3 44.2), (354760.4 6689102 44.2, 354758.5 6689104 44.2, 354756.7 6689107.7 44.2, 354754 6689106.3 44.2, 354756.1 6689102 44.2, 354757.8 6689099.8 44.2, 354760.4 6689102 44.2), (354749 6689097.8 44.2, 354746.4 6689103.3 44.2, 354744.2 6689102.4 44.2, 354746.6 6689096.9 44.2, 354749 6689097.8 44.2))
BATIMENT0000000302928286;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;20;23;18.7;23.3;42.0;43.0;23.6;Cadastre;A 1.0;POLYGON Z ((354768.9 6689121.7 42, 354780 6689107.6 42, 354770.3 6689099.4 42, 354756.4 6689116.4 42, 354768.9 6689121.7 42))
BATIMENT0000000302928287;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;;;16.9;21.7;38.7;39.9;23.2;Cadastre;A 1.0;POLYGON Z ((354784.9 6689128.6 38.7, 354792.7 6689118.4 38.7, 354780 6689107.6 38.7, 354768.9 6689121.7 38.7, 354784.9 6689128.6 38.7))
BATIMENT0000000302928031;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.5;23.4;41.9;43.0;23.7;Cadastre;;POLYGON Z ((354740.6 6689130.8 41.9, 354745.1 6689132.7 41.9, 354746.5 6689129.4 41.9, 354742.1 6689127.5 41.9, 354740.6 6689130.8 41.9))
BATIMENT0000000302928030;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.2;23.9;40.1;;;Cadastre;;POLYGON Z ((354737.1 6689139.1 40.1, 354741.6 6689140.9 40.1, 354743.2 6689137.1 40.1, 354738.7 6689135.3 40.1, 354737.1 6689139.1 40.1))
BATIMENT0000000302928033;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;50;10;16.0;23.7;39.7;43.0;23.7;Cadastre;A 1.0;POLYGON Z ((354760 6689128.1 39.7, 354753.2 6689144.2 39.7, 354755.6 6689145.2 39.7, 354757.6 6689140.6 39.7, 354764.2 6689143.4 39.7, 354762.2 6689148 39.7, 354767.1 6689150 39.7, 354773.8 6689134 39.7, 354760 6689128.1 39.7))
BATIMENT0000000302928130;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;10;20;16.1;24.8;40.9;44.2;25.7;Cadastre;A 1.0;POLYGON Z ((354639.3 6689114.1 40.9, 354654.4 6689128.6 40.9, 354660.1 6689131.3 40.9, 354676.9 6689092.6 40.9, 354659.9 6689085.3 40.9, 354630.9 6689106 40.9, 354639.3 6689114.1 40.9), (354653.7 6689104.7 40.9, 354654.2 6689104.7 40.9, 354654.6 6689104.8 40.9, 354655 6689104.9 40.9, 354655.4 6689105 40.9, 354655.8 6689105.1 40.9, 354656.2 6689105.3 40.9, 354662 6689107.8 40.9, 354658 6689117.3 40.9, 354654.2 6689115.6 40.9, 354654 6689116.2 40.9, 354654.5 6689116.6 40.9, 354652.8 6689119.4 40.9, 354649.8 6689116.9 40.9, 354650.7 6689114.9 40.9, 354651.7 6689115.3 40.9, 354651.9 6689114.7 40.9, 354651.6 6689114.5 40.9, 354651.2 6689114.4 40.9, 354650.9 6689114.2 40.9, 354650.6 6689114 40.9, 354650 6689113.5 40.9, 354649.8 6689113.2 40.9, 354649.6 6689112.9 40.9, 354649.4 6689112.6 40.9, 354649.2 6689112.3 40.9, 354649 6689112 40.9, 354648.8 6689111.7 40.9, 354648.7 6689111.4 40.9, 354648.6 6689111.1 40.9, 354648.5 6689110.8 40.9, 354648.5 6689110.3 40.9, 354648.5 6689110.1 40.9, 354648.5 6689109.7 40.9, 354648.5 6689109.4 40.9, 354648.6 6689109.1 40.9, 354648.7 6689108.7 40.9, 354648.8 6689108.4 40.9, 354649 6689108.1 40.9, 354649.1 6689107.8 40.9, 354649.3 6689107.4 40.9, 354649.5 6689107.1 40.9, 354649.7 6689106.8 40.9, 354649.9 6689106.5 40.9, 354650.2 6689106.2 40.9, 354650.5 6689105.9 40.9, 354650.8 6689105.7 40.9, 354651.1 6689105.5 40.9, 354651.4 6689105.3 40.9, 354651.8 6689105.1 40.9, 354652.1 6689105 40.9, 354652.5 6689104.9 40.9, 354652.9 6689104.8 40.9, 354653.3 6689104.7 40.9, 354653.7 6689104.7 40.9))
BATIMENT0000000302928126;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;25.2;33.5;36.2;26.1;Cadastre;;POLYGON Z ((354619.5 6689128.4 33.5, 354621.6 6689129.3 33.5, 354627.3 6689116.2 33.5, 354625.3 6689115.2 33.5, 354619.5 6689128.4 33.5))
BATIMENT0000000302928354;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.7;25.4;38.1;;;Cadastre;;POLYGON Z ((354666.9 6689139.7 38.1, 354675.9 6689143.5 38.1, 354673.5 6689149.2 38.1, 354675.6 6689150 38.1, 354675.2 6689151.2 38.1, 354680 6689153.2 38.1, 354687.8 6689156.5 38.1, 354692.4 6689158.5 38.1, 354692.9 6689157.6 38.1, 354694.7 6689158.4 38.1, 354696.4 6689154.6 38.1, 354705.4 6689158.5 38.1, 354725 6689113.2 38.1, 354715 6689108.8 38.1, 354711.8 6689115.5 38.1, 354707.5 6689113.6 38.1, 354697.1 6689109.1 38.1, 354692.7 6689107.3 38.1, 354695.6 6689100.4 38.1, 354685.5 6689096.1 38.1, 354666.9 6689139.7 38.1))
BATIMENT0000000302928129;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;20;20;10.8;24.8;35.6;45.1;26.2;Cadastre;A 1.0;POLYGON Z ((354660.1 6689131.3 35.6, 354654.4 6689128.6 35.6, 354639.3 6689114.1 35.6, 354636.7 6689120.2 35.6, 354632.1 6689130.3 35.6, 354631.6 6689131.5 35.6, 354631.7 6689131.7 35.6, 354635 6689134.7 35.6, 354637.9 6689128.2 35.6, 354636.3 6689127.5 35.6, 354639.3 6689121.2 35.6, 354640.1 6689122.1 35.6, 354642.7 6689124.7 35.6, 354643.8 6689125.7 35.6, 354648.1 6689127.6 35.6, 354646.2 6689131.9 35.6, 354645.5 6689131.7 35.6, 354644.4 6689133.8 35.6, 354643.5 6689133.5 35.6, 354642.9 6689134.9 35.6, 354644.4 6689135.5 35.6, 354642 6689140.8 35.6, 354653.6 6689146.4 35.6, 354660.1 6689131.3 35.6))
BATIMENT0000000302928127;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;9.4;24.8;34.2;38.9;27.2;Cadastre;A 1.0;POLYGON Z ((354628.1 6689107.9 34.2, 354624.9 6689115.1 34.2, 354625.3 6689115.2 34.2, 354627.3 6689116.2 34.2, 354621.6 6689129.3 34.2, 354619.5 6689128.4 34.2, 354619.2 6689128.2 34.2, 354617.3 6689132.7 34.2, 354619.8 6689132.9 34.2, 354619.7 6689133.4 34.2, 354620.7 6689134 34.2, 354621.6 6689134 34.2, 354622.4 6689133.1 34.2, 354622.5 6689132.5 34.2, 354626.8 6689134.3 34.2, 354635.5 6689142.8 34.2, 354634.4 6689144.1 34.2, 354630.3 6689144.2 34.2, 354630.3 6689140.1 34.2, 354629.9 6689139.9 34.2, 354627.7 6689139.9 34.2, 354622.6 6689140.1 34.2, 354621.7 6689140.1 34.2, 354621.8 6689146.4 34.2, 354620.1 6689146.5 34.2, 354620.3 6689153.7 34.2, 354622 6689153.7 34.2, 354622.1 6689159.9 34.2, 354630.8 6689159.7 34.2, 354630.8 6689155.3 34.2, 354634.2 6689155 34.2, 354635.1 6689154.6 34.2, 354635.8 6689153.7 34.2, 354633.1 6689151.7 34.2, 354642 6689140.8 34.2, 354635 6689134.7 34.2, 354631.7 6689131.7 34.2, 354631.6 6689131.5 34.2, 354632.1 6689130.3 34.2, 354630.3 6689130.5 34.2, 354629.3 6689129.8 34.2, 354628.8 6689129.6 34.2, 354628.2 6689129.3 34.2, 354633 6689118.7 34.2, 354636.7 6689120.2 34.2, 354639.3 6689114.1 34.2, 354630.9 6689106 34.2, 354628.1 6689107.9 34.2))
BATIMENT0000000302928128;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;16.8;24.8;41.6;45.1;27.2;Cadastre;A 1.0;POLYGON Z ((354639 6689156.3 41.6, 354640.6 6689156.7 41.6, 354640.5 6689157.7 41.6, 354639.4 6689157.8 41.6, 354637.6 6689162 41.6, 354634.8 6689160.8 41.6, 354631.1 6689164.6 41.6, 354643.5 6689169.6 41.6, 354653.6 6689146.4 41.6, 354642 6689140.8 41.6, 354633.1 6689151.7 41.6, 354635.8 6689153.7 41.6, 354639 6689156.3 41.6))
BATIMENT0000000302928131;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;15.9;24.8;40.7;44.3;27.2;Cadastre;A 1.0;POLYGON Z ((354618.8 6689178.4 40.7, 354618.5 6689178.5 40.7, 354618.4 6689179 40.7, 354619.8 6689181.2 40.7, 354638 6689182 40.7, 354643.5 6689169.6 40.7, 354631.1 6689164.6 40.7, 354619.2 6689177 40.7, 354618.8 6689178.4 40.7), (354630 6689169.3 40.7, 354632.4 6689170 40.7, 354629.8 6689175.8 40.7, 354627.5 6689175.5 40.7, 354627.8 6689173.5 40.7, 354629.5 6689171.2 40.7, 354630 6689169.3 40.7))
BATIMENT0000000302928252;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;12;10;17.2;26.2;43.5;45.7;27.8;Cadastre;C 0.9;POLYGON Z ((354656.4 6689201.4 43.5, 354634.1 6689192 43.5, 354623.8 6689191.5 43.5, 354623.1 6689205.9 43.5, 354630 6689206.2 43.5, 354633.5 6689207.7 43.5, 354633.1 6689208.4 43.5, 354633.5 6689209.1 43.5, 354636.2 6689210.1 43.5, 354636.7 6689209.9 43.5, 354637 6689209.2 43.5, 354642 6689211.4 43.5, 354637.6 6689221.1 43.5, 354646 6689224.8 43.5, 354656.4 6689201.4 43.5))
BATIMENT0000000302928248;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;26.3;32.0;38.5;28.4;Cadastre;;POLYGON Z ((354622.6 6689214.6 32, 354634.8 6689219.9 32, 354637.1 6689214.7 32, 354623 6689208.4 32, 354622.9 6689208.6 32, 354622.6 6689214.6 32))
BATIMENT0000000302928124;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;7.0;30;20;18.4;26.2;44.7;50.6;28.5;Cadastre;A 1.0;POLYGON Z ((354690.5 6689216.3 44.7, 354668 6689206.7 44.7, 354660.4 6689224.2 44.7, 354661 6689224.5 44.7, 354670.6 6689235.4 44.7, 354671.6 6689236.5 44.7, 354684.9 6689226.8 44.7, 354694.1 6689220.1 44.7, 354690.5 6689216.3 44.7))
BATIMENT0000000302928022;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;16;20;18.4;23.3;41.7;44.1;25.5;Cadastre;C 0.8;POLYGON Z ((354733.5 6689116.7 41.7, 354724.3 6689138.2 41.7, 354731.7 6689165.6 41.7, 354735.4 6689164.9 41.7, 354739.2 6689164 41.7, 354736.3 6689153.3 41.7, 354735.2 6689152.4 41.7, 354734.4 6689150.7 41.7, 354734.3 6689148.5 41.7, 354734.6 6689148.4 41.7, 354734.7 6689147.5 41.7, 354735.3 6689147.4 41.7, 354735.6 6689144.6 41.7, 354749.2 6689150.1 41.7, 354750.4 6689150.6 41.7, 354753.2 6689144.2 41.7, 354760 6689128.1 41.7, 354733.5 6689116.7 41.7), (354753 6689138.8 41.7, 354751.2 6689143.2 41.7, 354748.4 6689142 41.7, 354750.2 6689137.6 41.7, 354753 6689138.8 41.7), (354746.5 6689129.4 41.7, 354745.1 6689132.7 41.7, 354743.2 6689137.1 41.7, 354741.6 6689140.9 41.7, 354737.1 6689139.1 41.7, 354738.7 6689135.3 41.7, 354740.6 6689130.8 41.7, 354742.1 6689127.5 41.7, 354746.5 6689129.4 41.7))
BATIMENT0000000302928034;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;19.6;22.4;42.0;45.2;24.0;Cadastre;A 1.0;POLYGON Z ((354773.8 6689134 42, 354767.1 6689150 42, 354766.6 6689151.6 42, 354771.7 6689153.7 42, 354773 6689150.7 42, 354783.4 6689155 42, 354782.1 6689157.9 42, 354788 6689160.4 42, 354795.4 6689143.3 42, 354773.8 6689134 42))
BATIMENT0000000302928037;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;23.1;29.7;34.5;23.5;Cadastre;;POLYGON Z ((354753.2 6689144.2 29.7, 354750.4 6689150.6 29.7, 354750.1 6689151.3 29.7, 354753.8 6689152.8 29.7, 354756.7 6689145.8 29.7, 354755.6 6689145.2 29.7, 354753.2 6689144.2 29.7))
BATIMENT0000000302928023;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;23.3;31.7;39.9;23.5;Cadastre;;POLYGON Z ((354749.2 6689150.1 31.7, 354748.4 6689151.8 31.7, 354749.7 6689152.3 31.7, 354750.1 6689151.3 31.7, 354750.4 6689150.6 31.7, 354749.2 6689150.1 31.7))
BATIMENT0000000302928032;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;23.3;35.2;37.4;23.6;Cadastre;;POLYGON Z ((354747 6689151.3 35.2, 354744.6 6689150.2 35.2, 354744.2 6689151.3 35.2, 354746.5 6689152.3 35.2, 354747 6689151.3 35.2))
BATIMENT0000000302928039;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;12;12;11.7;23.9;35.6;;;Cadastre;A 1.0;POLYGON Z ((354766.6 6689151.6 35.6, 354767.1 6689150 35.6, 354762.2 6689148 35.6, 354760.6 6689150.1 35.6, 354758.5 6689152.7 35.6, 354757.9 6689154.6 35.6, 354764.1 6689157.3 35.6, 354766.6 6689151.6 35.6))
BATIMENT0000000302928021;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.6;23.3;32.0;36.2;24.8;Cadastre;C 0.1;POLYGON Z ((354745.2 6689162.7 32, 354749.7 6689152.3 32, 354748.4 6689151.8 32, 354747 6689151.3 32, 354746.5 6689152.3 32, 354744.2 6689151.3 32, 354743.5 6689151.3 32, 354743.1 6689151.8 32, 354742.2 6689151.7 32, 354741.8 6689152.7 32, 354740.5 6689152.5 32, 354739.5 6689153.3 32, 354738.8 6689154.8 32, 354739.8 6689156.3 32, 354740.5 6689157.2 32, 354740.5 6689158.4 32, 354740.6 6689159.3 32, 354741.9 6689159.8 32, 354740.9 6689161.3 32, 354740.5 6689162.3 32, 354741.1 6689163.6 32, 354745.2 6689162.7 32))
BATIMENT0000000302928020;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.3;22.6;35.0;42.5;27.6;Cadastre;C 0.2;POLYGON Z ((354795.4 6689143.3 35, 354788 6689160.4 35, 354782.1 6689157.9 35, 354781 6689160.5 35, 354775.9 6689172.3 35, 354765.5 6689168 35, 354770.6 6689156.1 35, 354771.7 6689153.7 35, 354766.6 6689151.6 35, 354764.1 6689157.3 35, 354756.5 6689175 35, 354753.3 6689182.7 35, 354759.5 6689180.9 35, 354799.2 6689197.7 35, 354800.4 6689194.8 35, 354802.6 6689189.7 35, 354808.7 6689175.5 35, 354809.3 6689175.6 35, 354814.8 6689175.2 35, 354815.2 6689170.8 35, 354811.6 6689169.2 35, 354818.5 6689153.1 35, 354795.4 6689143.3 35))
BATIMENT0000000302928018;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.2;24.6;43.9;46.9;27.5;Cadastre;C 0.2;POLYGON Z ((354742.2 6689191.4 43.9, 354750.6 6689189 43.9, 354751.8 6689186 43.9, 354751 6689183.3 43.9, 354753.3 6689182.7 43.9, 354756.5 6689175 43.9, 354753.1 6689176 43.9, 354752.5 6689174.1 43.9, 354748.7 6689175.1 43.9, 354745.2 6689162.7 43.9, 354741.1 6689163.6 43.9, 354739.2 6689164 43.9, 354735.4 6689164.9 43.9, 354742.2 6689191.4 43.9))
BATIMENT0000000302928133;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;15;20;20.5;25.1;45.6;50.0;27.1;Cadastre;A 1.0;POLYGON Z ((354721.5 6689151.7 45.6, 354719 6689150.6 45.6, 354694.7 6689206.5 45.6, 354697.1 6689209 45.6, 354706.8 6689201.9 45.6, 354712.3 6689198 45.6, 354712.5 6689197.9 45.6, 354713.2 6689196.2 45.6, 354720.3 6689179.5 45.6, 354722.6 6689174.1 45.6, 354727.1 6689172.8 45.6, 354721.5 6689151.7 45.6))
BATIMENT0000000302927996;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;26.1;35.2;43.9;27.2;Cadastre;;POLYGON Z ((354606.8 6689116.2 35.2, 354595.8 6689116.5 35.2, 354595.8 6689116.2 35.2, 354595.2 6689116.2 35.2, 354595.2 6689116.3 35.2, 354595.2 6689117.6 35.2, 354594.9 6689117.6 35.2, 354595 6689119.5 35.2, 354595.5 6689119.5 35.2, 354595.5 6689122.5 35.2, 354595 6689122.5 35.2, 354595.1 6689124.7 35.2, 354595.7 6689124.7 35.2, 354595.7 6689127.1 35.2, 354593.2 6689127.2 35.2, 354593.2 6689126.8 35.2, 354585.6 6689127 35.2, 354586.2 6689135.4 35.2, 354563.7 6689135.8 35.2, 354563.5 6689132.6 35.2, 354556.5 6689133.1 35.2, 354556.2 6689133.6 35.2, 354555 6689133.4 35.2, 354553.7 6689134.7 35.2, 354553.9 6689135.6 35.2, 354537.5 6689136.1 35.2, 354537.4 6689133.3 35.2, 354532.2 6689133.4 35.2, 354530.9 6689133.5 35.2, 354531.2 6689140.1 35.2, 354533.8 6689140 35.2, 354533.8 6689140.5 35.2, 354537.7 6689140.3 35.2, 354537.7 6689146.1 35.2, 354538.4 6689146.2 35.2, 354538.5 6689145.7 35.2, 354541 6689145.6 35.2, 354541.2 6689153.1 35.2, 354548.1 6689152.9 35.2, 354547.8 6689148.3 35.2, 354556.7 6689148.1 35.2, 354556.9 6689152.5 35.2, 354563.3 6689152.3 35.2, 354563.4 6689152.8 35.2, 354564.4 6689152.6 35.2, 354564.4 6689151.7 35.2, 354567.4 6689151.5 35.2, 354569.2 6689149.8 35.2, 354569.1 6689146.7 35.2, 354586.5 6689146.3 35.2, 354586.6 6689150.8 35.2, 354594.2 6689150.6 35.2, 354594 6689145.3 35.2, 354597 6689145.2 35.2, 354596.8 6689142.3 35.2, 354597.3 6689142.2 35.2, 354597.1 6689137.5 35.2, 354596.5 6689137.6 35.2, 354596.3 6689131.1 35.2, 354602.7 6689130.8 35.2, 354602.8 6689132.9 35.2, 354601.9 6689133 35.2, 354602 6689137.4 35.2, 354608.2 6689137.1 35.2, 354607.7 6689123.9 35.2, 354608.1 6689123.8 35.2, 354608 6689121.9 35.2, 354607.3 6689121.9 35.2, 354607.2 6689119 35.2, 354607.9 6689119 35.2, 354607.8 6689116.9 35.2, 354607.5 6689116.9 35.2, 354607.4 6689116 35.2, 354606.9 6689116 35.2, 354606.8 6689116.2 35.2))
BATIMENT0000000302928304;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;35;29;14.1;27.8;41.9;43.4;29.4;Cadastre;A 0.8;POLYGON Z ((354546.3 6689188.5 41.9, 354545.9 6689200.7 41.9, 354562.9 6689201.9 41.9, 354562.8 6689202.9 41.9, 354566.6 6689203.2 41.9, 354567 6689199.3 41.9, 354566.9 6689196.6 41.9, 354567.2 6689189.9 41.9, 354546.3 6689188.5 41.9))
BATIMENT0000000302928305;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;8.9;27.5;36.5;40.2;28.6;Cadastre;A 1.0;POLYGON Z ((354567.4 6689187.8 36.5, 354567.2 6689189.9 36.5, 354566.9 6689196.6 36.5, 354569.9 6689196.9 36.5, 354569.6 6689199.5 36.5, 354567 6689199.3 36.5, 354566.6 6689203.2 36.5, 354566.6 6689205 36.5, 354573.7 6689205.8 36.5, 354574.9 6689195.6 36.5, 354575.6 6689188.4 36.5, 354567.4 6689187.8 36.5))
BATIMENT0000000302928306;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;10;20;14.0;27.8;41.8;44.0;28.5;Cadastre;A 1.0;POLYGON Z ((354597.3 6689191.5 41.8, 354596.8 6689189.8 41.8, 354575.6 6689188.4 41.8, 354574.9 6689195.6 41.8, 354579.5 6689196.1 41.8, 354579.3 6689198.1 41.8, 354578.8 6689198.2 41.8, 354578.5 6689200.2 41.8, 354576.8 6689199.9 41.8, 354576.1 6689206.1 41.8, 354579.3 6689206.7 41.8, 354582 6689207.4 41.8, 354597.3 6689191.5 41.8))
BATIMENT0000000302928251;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;10;20;13.7;27.6;41.3;44.2;28.6;Cadastre;A 1.0;POLYGON Z ((354612.7 6689191 41.3, 354603.5 6689200.5 41.3, 354610.6 6689207.6 41.3, 354612.9 6689205.1 41.3, 354615 6689205.1 41.3, 354619.2 6689208.3 41.3, 354622.9 6689208.6 41.3, 354623 6689208.4 41.3, 354623.1 6689205.9 41.3, 354623.8 6689191.5 41.3, 354612.7 6689191 41.3))
BATIMENT0000000302928308;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;28.4;32.5;44.2;28.9;Cadastre;;POLYGON Z ((354561.6 6689202.9 32.5, 354560.7 6689218 32.5, 354565.2 6689217.6 32.5, 354566.6 6689205 32.5, 354566.6 6689203.2 32.5, 354562.8 6689202.9 32.5, 354561.6 6689202.9 32.5))
BATIMENT0000000302928303;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;10;20;17.9;27.8;45.7;48.7;29.0;Cadastre;A 1.0;POLYGON Z ((354568.2 6689220 45.7, 354569 6689220.7 45.7, 354582 6689207.4 45.7, 354579.3 6689206.7 45.7, 354576.1 6689206.1 45.7, 354573.7 6689205.8 45.7, 354566.6 6689205 45.7, 354565.2 6689217.6 45.7, 354568.2 6689220 45.7))
BATIMENT0000000302928249;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;20;20;10.6;27.6;38.2;44.0;28.9;Cadastre;A 1.0;POLYGON Z ((354592.9 6689211.3 38.2, 354597.5 6689216.1 38.2, 354598.8 6689214.8 38.2, 354601.1 6689217.1 38.2, 354599.8 6689218.5 38.2, 354607.9 6689226.7 38.2, 354613.9 6689221.7 38.2, 354618.2 6689218.2 38.2, 354622.6 6689214.6 38.2, 354622.9 6689208.6 38.2, 354619.2 6689208.3 38.2, 354620.3 6689209.1 38.2, 354618.7 6689210.9 38.2, 354618.4 6689210.6 38.2, 354611.8 6689217.5 38.2, 354612.1 6689217.8 38.2, 354610.6 6689219.4 38.2, 354604.7 6689213.8 38.2, 354610.6 6689207.6 38.2, 354603.5 6689200.5 38.2, 354592.9 6689211.3 38.2))
BATIMENT0000000302928307;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;00;00;19.1;27.8;46.9;47.1;29.5;Cadastre;A 1.0;POLYGON Z ((354560.7 6689218 46.9, 354546.7 6689219.1 46.9, 354546.7 6689224.8 46.9, 354546.8 6689226.1 46.9, 354546.8 6689230.2 46.9, 354554.5 6689234.1 46.9, 354555.7 6689234.7 46.9, 354569 6689220.7 46.9, 354568.2 6689220 46.9, 354565.2 6689217.6 46.9, 354560.7 6689218 46.9))
BATIMENT0000000302928245;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;54.0;4.0;10;20;13.9;27.7;41.6;45.5;29.5;Cadastre;A 1.0;POLYGON Z ((354572.8 6689233.2 41.6, 354595.5 6689260.3 41.6, 354608.7 6689249.8 41.6, 354613.4 6689245.9 41.6, 354618.2 6689242.1 41.6, 354620.6 6689240.1 41.6, 354607.9 6689226.7 41.6, 354599.8 6689218.5 41.6, 354597.5 6689216.1 41.6, 354592.9 6689211.3 41.6, 354572.5 6689232.2 41.6, 354572.8 6689233.2 41.6), (354594 6689224.3 41.6, 354601.9 6689233.1 41.6, 354601.7 6689233.6 41.6, 354602.1 6689234.2 41.6, 354602.7 6689234 41.6, 354604.1 6689235.4 41.6, 354603.9 6689236.1 41.6, 354604.3 6689236.7 41.6, 354605 6689236.4 41.6, 354606.2 6689237.9 41.6, 354606 6689238.3 41.6, 354606.5 6689238.8 41.6, 354607 6689238.6 41.6, 354608.3 6689240.1 41.6, 354598.1 6689248.8 41.6, 354588.4 6689237.6 41.6, 354587.5 6689238.7 41.6, 354587.2 6689238.3 41.6, 354586.8 6689238.7 41.6, 354584.2 6689235.5 41.6, 354585.7 6689233.8 41.6, 354587 6689234.9 41.6, 354587.9 6689234.8 41.6, 354588.2 6689234.4 41.6, 354589 6689235 41.6, 354590.8 6689233.2 41.6, 354590.1 6689232.4 41.6, 354590.3 6689232.3 41.6, 354590.3 6689231 41.6, 354589.3 6689230.1 41.6, 354591.8 6689227.4 41.6, 354591.4 6689226.9 41.6, 354594 6689224.3 41.6))
BATIMENT0000000302928132;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;;;7.9;25.3;33.2;39.0;27.8;Cadastre;A 1.0;POLYGON Z ((354714.9 6689200.6 33.2, 354717.7 6689202.8 33.2, 354732.5 6689192.6 33.2, 354727.1 6689172.8 33.2, 354722.6 6689174.1 33.2, 354720.3 6689179.5 33.2, 354723.1 6689180.7 33.2, 354724.3 6689185.4 33.2, 354723.3 6689186.1 33.2, 354721.2 6689187.8 33.2, 354716.9 6689197.7 33.2, 354714.7 6689196.8 33.2, 354713.2 6689196.2 33.2, 354712.5 6689197.9 33.2, 354712.3 6689198 33.2, 354713.6 6689199.4 33.2, 354714.9 6689200.6 33.2))
BATIMENT0000000302928019;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.1;26.5;48.6;50.0;27.5;Cadastre;;POLYGON Z ((354747.4 6689210.7 48.6, 354757.2 6689207.9 48.6, 354757.8 6689207.8 48.6, 354751.8 6689186 48.6, 354750.6 6689189 48.6, 354742.2 6689191.4 48.6, 354747.4 6689210.7 48.6))
BATIMENT0000000302928135;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;23;17.2;26.4;43.7;45.7;28.0;Cadastre;A 1.0;POLYGON Z ((354732.5 6689192.6 43.7, 354717.7 6689202.8 43.7, 354718.4 6689203.6 43.7, 354719 6689204.2 43.7, 354722.7 6689201.7 43.7, 354728.1 6689210.3 43.7, 354735.7 6689204.9 43.7, 354732.5 6689192.6 43.7))
BATIMENT0000000302928134;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;10;20;18.5;25.3;43.8;48.5;28.0;Cadastre;A 1.0;POLYGON Z ((354710.1 6689222.7 43.8, 354718.4 6689216.8 43.8, 354719.2 6689216.3 43.8, 354714.2 6689210.1 43.8, 354716.3 6689208.9 43.8, 354716.9 6689209.8 43.8, 354717.9 6689209.2 43.8, 354714.9 6689206 43.8, 354718.4 6689203.6 43.8, 354717.7 6689202.8 43.8, 354714.9 6689200.6 43.8, 354711.2 6689203.4 43.8, 354713.2 6689206.5 43.8, 354711.2 6689208 43.8, 354706.8 6689201.9 43.8, 354697.1 6689209 43.8, 354710.1 6689222.7 43.8))
BATIMENT0000000302928047;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;10.1;26.0;36.1;38.1;28.0;Cadastre;C 0.3;POLYGON Z ((354768.2 6689205.3 36.1, 354766.7 6689205.7 36.1, 354775 6689220.5 36.1, 354776.4 6689219.7 36.1, 354777.7 6689219 36.1, 354780.7 6689217.3 36.1, 354779.5 6689214.7 36.1, 354773.6 6689203.8 36.1, 354768.2 6689205.3 36.1))
BATIMENT0000000302928048;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;26.8;33.2;34.7;28.0;Cadastre;;POLYGON Z ((354782.7 6689213.1 33.2, 354779.5 6689214.7 33.2, 354780.7 6689217.3 33.2, 354783.4 6689215.8 33.2, 354784 6689215.3 33.2, 354782.7 6689213.1 33.2))
BATIMENT0000000302928024;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;20;20;20.0;27.2;47.2;51.0;27.8;Cadastre;C 0.8;POLYGON Z ((354752.5 6689230.1 47.2, 354762.2 6689227.1 47.2, 354759.5 6689217.2 47.2, 354760.8 6689216.4 47.2, 354761.3 6689215.4 47.2, 354760.9 6689214.3 47.2, 354760.3 6689213.6 47.2, 354759.5 6689213.4 47.2, 354758.5 6689213.7 47.2, 354757.2 6689207.9 47.2, 354747.4 6689210.7 47.2, 354752.5 6689230.1 47.2))
BATIMENT0000000302928137;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;;;22.3;25.3;47.6;52.7;27.8;Cadastre;A 1.0;POLYGON Z ((354721.3 6689234.4 47.6, 354723.3 6689232.5 47.6, 354727.2 6689229.6 47.6, 354730.3 6689227.7 47.6, 354733.1 6689226.2 47.6, 354737.4 6689224.4 47.6, 354739.5 6689223.6 47.6, 354740.7 6689223.5 47.6, 354735.7 6689204.9 47.6, 354728.1 6689210.3 47.6, 354729.9 6689216 47.6, 354729.5 6689216 47.6, 354729.2 6689216.1 47.6, 354728.9 6689216.1 47.6, 354728.6 6689216.3 47.6, 354728.1 6689216.5 47.6, 354727.8 6689216.7 47.6, 354727.6 6689216.9 47.6, 354727.4 6689217.1 47.6, 354727.3 6689217.3 47.6, 354727.2 6689217.4 47.6, 354727.2 6689217.7 47.6, 354727.1 6689217.8 47.6, 354727.1 6689218 47.6, 354727.1 6689218.4 47.6, 354727.1 6689218.8 47.6, 354727.2 6689219.1 47.6, 354727.3 6689219.5 47.6, 354727.4 6689219.9 47.6, 354723.4 6689222.1 47.6, 354718.4 6689216.8 47.6, 354710.1 6689222.7 47.6, 354721.3 6689234.4 47.6))
BATIMENT0000000302928044;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;25.0;27.8;41.0;28.0;Cadastre;;POLYGON Z ((354784 6689215.3 27.8, 354783.4 6689215.8 27.8, 354780.7 6689217.3 27.8, 354777.7 6689219 27.8, 354776.4 6689219.7 27.8, 354775 6689220.5 27.8, 354774.7 6689220.8 27.8, 354772 6689222.3 27.8, 354768.8 6689224 27.8, 354770.5 6689229.3 27.8, 354774.6 6689227 27.8, 354777.4 6689225.5 27.8, 354780.5 6689223.8 27.8, 354783.4 6689222.3 27.8, 354786.3 6689220.8 27.8, 354789.3 6689219.1 27.8, 354786.1 6689214.2 27.8, 354784 6689215.3 27.8))
BATIMENT0000000302928043;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;25.0;31.0;37.7;27.6;Cadastre;;POLYGON Z ((354766.3 6689233.4 31, 354767.1 6689236.6 31, 354771.6 6689232.8 31, 354770.9 6689231.1 31, 354766.3 6689233.4 31))
BATIMENT0000000302929189;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;20.7;26.7;47.5;49.2;28.1;Cadastre;C 0.9;POLYGON Z ((354693.4 6689239.4 47.5, 354694 6689240.4 47.5, 354694 6689240.5 47.5, 354696.1 6689239 47.5, 354705.6 6689232.2 47.5, 354694.1 6689220.1 47.5, 354684.9 6689226.8 47.5, 354688.3 6689232.1 47.5, 354693.4 6689239.4 47.5))
BATIMENT0000000302928247;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;5.0;10;20;17.7;26.9;44.6;47.1;28.7;Cadastre;A 1.0;POLYGON Z ((354646 6689224.8 44.6, 354637.6 6689221.1 44.6, 354634.8 6689219.9 44.6, 354622.6 6689214.6 44.6, 354618.2 6689218.2 44.6, 354631.5 6689224.1 44.6, 354632.8 6689221.1 44.6, 354635.3 6689222.2 44.6, 354634.4 6689224.3 44.6, 354633.9 6689224.2 44.6, 354630.2 6689232.5 44.6, 354628.9 6689232.4 44.6, 354628.3 6689232.6 44.6, 354625.8 6689234.7 44.6, 354613.9 6689221.7 44.6, 354607.9 6689226.7 44.6, 354620.6 6689240.1 44.6, 354620.8 6689239.9 44.6, 354622 6689240.5 44.6, 354636.3 6689246.7 44.6, 354646 6689224.8 44.6))
BATIMENT0000000302928125;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;26.9;33.2;34.1;28.5;Cadastre;;POLYGON Z ((354668.7 6689236.8 33.2, 354669.5 6689238 33.2, 354671.6 6689236.5 33.2, 354670.6 6689235.4 33.2, 354668.7 6689236.8 33.2))
BATIMENT0000000302929191;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.9;27.2;41.2;45.5;28.1;Cadastre;;POLYGON Z ((354694 6689240.4 41.2, 354693.4 6689239.4 41.2, 354690.2 6689241.6 41.2, 354690.9 6689242.6 41.2, 354694 6689240.4 41.2))
BATIMENT0000000302929190;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;;;6.5;27.8;34.3;40.2;28.5;Cadastre;C 0.6;POLYGON Z ((354670.9 6689246.9 34.3, 354670.9 6689246.5 34.3, 354668.4 6689241.1 34.3, 354669.2 6689240.6 34.3, 354673.2 6689246.2 34.3, 354671.6 6689247.5 34.3, 354672.4 6689249.1 34.3, 354674.2 6689247.8 34.3, 354675.1 6689248.8 34.3, 354671 6689251.4 34.3, 354672.9 6689256 34.3, 354675 6689254.9 34.3, 354674.6 6689254.2 34.3, 354685.5 6689246.5 34.3, 354687.8 6689244.8 34.3, 354689.2 6689243.8 34.3, 354683.5 6689235.5 34.3, 354688.3 6689232.1 34.3, 354684.9 6689226.8 34.3, 354671.6 6689236.5 34.3, 354669.5 6689238 34.3, 354666.3 6689240.1 34.3, 354669.4 6689247.5 34.3, 354670.9 6689246.9 34.3))
BATIMENT0000000302928119;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;19.8;27.3;47.1;49.4;28.1;Cadastre;A 1.0;POLYGON Z ((354705.6 6689232.2 47.1, 354696.1 6689239 47.1, 354697.1 6689239.9 47.1, 354697.7 6689239.3 47.1, 354699.7 6689241.4 47.1, 354697.2 6689243.4 47.1, 354699.7 6689245.9 47.1, 354700.2 6689245.4 47.1, 354702.1 6689243.9 47.1, 354710.2 6689252.3 47.1, 354717.9 6689245 47.1, 354705.6 6689232.2 47.1))
BATIMENT0000000302928118;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;27.6;34.2;40.0;28.2;Cadastre;;POLYGON Z ((354694 6689240.4 34.2, 354690.9 6689242.6 34.2, 354689.2 6689243.8 34.2, 354687.8 6689244.8 34.2, 354690.4 6689248.5 34.2, 354696.5 6689244.1 34.2, 354694 6689240.5 34.2, 354694 6689240.4 34.2))
BATIMENT0000000302928123;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;27.7;44.0;45.2;28.1;Cadastre;;POLYGON Z ((354700.2 6689245.4 44, 354708.3 6689253.7 44, 354710.2 6689252.3 44, 354702.1 6689243.9 44, 354700.2 6689245.4 44))
BATIMENT0000000302928105;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;4.0;10;20;13.1;26.8;40.0;41.7;28.6;Cadastre;A 1.0;POLYGON Z ((354643.1 6689263.2 40, 354654.1 6689268.5 40, 354654.3 6689269.3 40, 354653.6 6689269.6 40, 354654 6689270.5 40, 354655.5 6689269.9 40, 354655.6 6689269.7 40, 354655.2 6689268.9 40, 354658.4 6689267.4 40, 354665.7 6689264.1 40, 354664 6689260.1 40, 354664.2 6689260 40, 354661.2 6689252.3 40, 354662 6689250.4 40, 354662.5 6689250.2 40, 354660.3 6689245.7 40, 354664.7 6689235.8 40, 354663.2 6689231.4 40, 354660.6 6689228.6 40, 354659 6689227.7 40, 354643.1 6689263.2 40))
BATIMENT0000000302928250;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;10;20;22.0;27.4;49.5;51.7;28.4;Cadastre;A 1.0;POLYGON Z ((354636.3 6689246.7 49.5, 354622 6689240.5 49.5, 354621.3 6689241.8 49.5, 354622.2 6689242.2 49.5, 354621.1 6689244.5 49.5, 354619.8 6689245.1 49.5, 354618.3 6689244.5 49.5, 354618.8 6689243.1 49.5, 354618.2 6689242.1 49.5, 354613.4 6689245.9 49.5, 354613.9 6689246.5 49.5, 354617.8 6689248 49.5, 354618.8 6689247.6 49.5, 354619.2 6689248.7 49.5, 354616.7 6689254.7 49.5, 354616 6689255.1 49.5, 354615.4 6689255.4 49.5, 354615 6689256.1 49.5, 354615 6689257.5 49.5, 354619 6689262.2 49.5, 354619.5 6689261.3 49.5, 354622.7 6689262.7 49.5, 354621.6 6689265.5 49.5, 354623 6689267.4 49.5, 354628.2 6689265.2 49.5, 354636.3 6689246.7 49.5))
BATIMENT0000000302928117;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;00;00;12.1;27.5;39.6;42.1;29.3;Cadastre;A 1.0;POLYGON Z ((354674.6 6689260.1 39.6, 354679.8 6689272.7 39.6, 354684 6689269.9 39.6, 354687.3 6689267.7 39.6, 354695.9 6689261.9 39.6, 354696 6689261.6 39.6, 354685.5 6689246.5 39.6, 354674.6 6689254.2 39.6, 354675 6689254.9 39.6, 354672.9 6689256 39.6, 354674.6 6689260.1 39.6))
BATIMENT0000000302929231;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;12.4;27.7;40.2;41.6;28.5;Cadastre;C 0.5;POLYGON Z ((354643.2 6689274.1 40.2, 354648.5 6689271.6 40.2, 354653.6 6689269.6 40.2, 354654.3 6689269.3 40.2, 354654.1 6689268.5 40.2, 354643.1 6689263.2 40.2, 354640.9 6689268.5 40.2, 354643.2 6689274.1 40.2))
BATIMENT0000000302929187;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;28.9;33.7;42.0;29.1;Cadastre;;POLYGON Z ((354698.3 6689281.6 33.7, 354702 6689279.2 33.7, 354710.9 6689273.1 33.7, 354716.7 6689269.2 33.7, 354712 6689262.5 33.7, 354711.6 6689262.7 33.7, 354710.1 6689263.7 33.7, 354703.6 6689267.9 33.7, 354703.4 6689267.8 33.7, 354699.1 6689270.9 33.7, 354693.7 6689274.6 33.7, 354696.3 6689278.6 33.7, 354698.3 6689281.6 33.7))
BATIMENT0000000302928116;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;27.5;34.8;42.5;29.5;Cadastre;;POLYGON Z ((354679.8 6689272.7 34.8, 354683.6 6689281.7 34.8, 354689.2 6689277.8 34.8, 354684.8 6689271.1 34.8, 354684 6689269.9 34.8, 354679.8 6689272.7 34.8))
BATIMENT0000000302928106;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;3.4;27.7;31.1;34.7;28.8;Cadastre;C 0.3;POLYGON Z ((354658.6 6689268 31.1, 354655.6 6689269.7 31.1, 354655.5 6689269.9 31.1, 354654 6689270.5 31.1, 354654.4 6689271.6 31.1, 354654 6689271.5 31.1, 354661.2 6689288.8 31.1, 354666.4 6689286.8 31.1, 354658.6 6689268 31.1))
BATIMENT0000000302928109;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.9;29.1;37.0;;;Cadastre;A 0.9;POLYGON Z ((354645.2 6689281.4 37, 354644.9 6689280.1 37, 354641.9 6689278.8 37, 354642.7 6689276.9 37, 354642.1 6689275.4 37, 354638.6 6689273.7 37, 354632.7 6689287.3 37, 354641.9 6689288.3 37, 354645.2 6689281.4 37))
BATIMENT0000000302929232;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.3;29.1;31.4;;;Cadastre;C 0.6;POLYGON Z ((354648.2 6689286.1 31.4, 354651 6689292.9 31.4, 354656.3 6689290.9 31.4, 354648.5 6689271.6 31.4, 354643.2 6689274.1 31.4, 354646.9 6689282.9 31.4, 354648.2 6689286.1 31.4))
BATIMENT0000000302928110;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.8;28.4;33.2;35.6;28.7;Cadastre;A 0.2;POLYGON Z ((354645 6689287.5 33.2, 354648.2 6689286.1 33.2, 354646.9 6689282.9 33.2, 354645 6689287.5 33.2))
BATIMENT0000000302928115;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;7.0;30;23;22.9;28.0;51.0;51.8;29.3;Cadastre;A 1.0;POLYGON Z ((354718.2 6689284.5 51, 354710.9 6689273.1 51, 354702 6689279.2 51, 354704 6689282.7 51, 354702.6 6689283.1 51, 354692.4 6689288.6 51, 354691.7 6689288.2 51, 354691.9 6689287.2 51, 354690.1 6689282.9 51, 354696.3 6689278.6 51, 354693.7 6689274.6 51, 354689.2 6689277.8 51, 354683.6 6689281.7 51, 354684.7 6689284.6 51, 354690.5 6689298.7 51, 354691.7 6689301.5 51, 354718.2 6689284.5 51))
BATIMENT0000000302928107;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.8;28.9;31.7;34.8;29.0;Cadastre;;POLYGON Z ((354642.4 6689288.5 31.7, 354641.8 6689292 31.7, 354643.8 6689292.3 31.7, 354647.8 6689301.6 31.7, 354650.4 6689300.3 31.7, 354653.3 6689298.8 31.7, 354651 6689292.9 31.7, 354648.2 6689286.1 31.7, 354645 6689287.5 31.7, 354642.4 6689288.5 31.7))
BATIMENT0000000302928045;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;20;20;20.7;23.9;44.6;48.9;26.3;Cadastre;C 0.9;POLYGON Z ((354798.2 6689233.7 44.6, 354793 6689225.2 44.6, 354786.9 6689228.8 44.6, 354786.2 6689227.8 44.6, 354783 6689229.9 44.6, 354783.5 6689230.7 44.6, 354774.3 6689236.7 44.6, 354779.6 6689245.4 44.6, 354798.2 6689233.7 44.6))
BATIMENT0000000302928025;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;20;20;20.2;27.1;47.3;51.0;28.0;Cadastre;A 0.5;POLYGON Z ((354752.5 6689230.1 47.3, 354758.3 6689252 47.3, 354758.4 6689252.4 47.3, 354758.6 6689252.8 47.3, 354758.7 6689253.1 47.3, 354758.9 6689253.5 47.3, 354759.2 6689253.8 47.3, 354759.4 6689254.1 47.3, 354759.7 6689254.4 47.3, 354760 6689254.6 47.3, 354760.3 6689254.9 47.3, 354760.7 6689255.1 47.3, 354761 6689255.2 47.3, 354761.5 6689255.4 47.3, 354761.9 6689255.4 47.3, 354762.4 6689255.5 47.3, 354762.8 6689255.5 47.3, 354763.2 6689255.4 47.3, 354763.7 6689255.3 47.3, 354764.2 6689255.2 47.3, 354764.6 6689255 47.3, 354765 6689254.8 47.3, 354765.4 6689254.6 47.3, 354765.8 6689254.3 47.3, 354766.1 6689254 47.3, 354769.8 6689251.6 47.3, 354768 6689247.8 47.3, 354767 6689247.8 47.3, 354765.7 6689247.6 47.3, 354765 6689246.6 47.3, 354765.1 6689244.8 47.3, 354765.5 6689244.3 47.3, 354766.7 6689243.7 47.3, 354762.2 6689227.1 47.3, 354752.5 6689230.1 47.3))
BATIMENT0000000302928041;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;7.0;;;21.3;23.9;45.2;51.0;27.7;Cadastre;A 1.0;POLYGON Z ((354765.5 6689244.3 45.2, 354765.1 6689244.8 45.2, 354765 6689246.6 45.2, 354765.7 6689247.6 45.2, 354767 6689247.8 45.2, 354768 6689247.8 45.2, 354769.8 6689251.6 45.2, 354779.6 6689245.4 45.2, 354774.3 6689236.7 45.2, 354771.6 6689232.8 45.2, 354767.1 6689236.6 45.2, 354768.7 6689242.9 45.2, 354766.7 6689243.7 45.2, 354765.5 6689244.3 45.2))
BATIMENT0000000302928120;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;13;23;19.3;27.6;47.0;49.4;28.0;Cadastre;A 1.0;POLYGON Z ((354717.9 6689245 47, 354710.2 6689252.3 47, 354719 6689261.5 47, 354717.2 6689263.2 47, 354716.7 6689263.7 47, 354720 6689267.1 47, 354724 6689264.3 47, 354724.4 6689264.9 47, 354725.4 6689264.3 47, 354732.5 6689260.3 47, 354717.9 6689245 47))
BATIMENT0000000302928102;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;10;20;20.4;25.7;46.2;49.5;27.6;Cadastre;A 1.0;POLYGON Z ((354775.5 6689258.8 46.2, 354774.7 6689260.1 46.2, 354774.6 6689260.4 46.2, 354774.5 6689260.7 46.2, 354774.5 6689261.4 46.2, 354774.5 6689261.7 46.2, 354774.6 6689262 46.2, 354774.6 6689262.3 46.2, 354774.7 6689262.6 46.2, 354774.8 6689262.9 46.2, 354775 6689263.1 46.2, 354775.1 6689263.4 46.2, 354775.3 6689263.7 46.2, 354775.5 6689263.9 46.2, 354775.7 6689264.1 46.2, 354775.9 6689264.2 46.2, 354776.2 6689264.4 46.2, 354776.4 6689264.5 46.2, 354776.7 6689264.6 46.2, 354777 6689264.7 46.2, 354777.5 6689264.9 46.2, 354777.8 6689264.9 46.2, 354792.9 6689266.2 46.2, 354793.1 6689262.8 46.2, 354793.1 6689262.5 46.2, 354793.5 6689262.2 46.2, 354793.9 6689261.9 46.2, 354795 6689259.9 46.2, 354795.2 6689259.3 46.2, 354800.1 6689256.3 46.2, 354794.2 6689246.9 46.2, 354779.2 6689256.3 46.2, 354775.5 6689258.8 46.2), (354789.7 6689260.6 46.2, 354791.4 6689260.6 46.2, 354791.4 6689261.7 46.2, 354791.4 6689262.1 46.2, 354789.6 6689262.1 46.2, 354789.7 6689260.6 46.2))
BATIMENT0000000302928121;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.2;27.7;44.0;45.2;28.2;Cadastre;;POLYGON Z ((354719 6689261.5 44, 354710.2 6689252.3 44, 354708.3 6689253.7 44, 354717.2 6689263.2 44, 354719 6689261.5 44))
BATIMENT0000000302928122;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1942-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;;;16.1;28.9;45.0;;;Cadastre;A 1.0;POLYGON Z ((354740.9 6689270.2 45, 354741 6689269.3 45, 354732.5 6689260.3 45, 354725.4 6689264.3 45, 354727 6689267.1 45, 354725.7 6689267.7 45, 354730.1 6689276.9 45, 354740.9 6689270.2 45))
BATIMENT0000000302929188;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;;;20.1;27.8;48.0;51.4;28.4;Cadastre;C 0.1;POLYGON Z ((354718.2 6689284.5 48, 354730.1 6689276.9 48, 354725.7 6689267.7 48, 354724.4 6689264.9 48, 354724 6689264.3 48, 354720 6689267.1 48, 354716.7 6689269.2 48, 354710.9 6689273.1 48, 354718.2 6689284.5 48))
BATIMENT0000000302929183;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;8.0;;;17.4;27.3;44.7;54.0;27.9;Cadastre;C 0.5;POLYGON Z ((354746.3 6689288.2 44.7, 354759.3 6689283.9 44.7, 354760.7 6689281.6 44.7, 354760.1 6689275.8 44.7, 354754.1 6689277.5 44.7, 354754 6689277.3 44.7, 354746.5 6689279.8 44.7, 354746.5 6689280 44.7, 354740.8 6689282.5 44.7, 354743.7 6689287.3 44.7, 354746.3 6689288.2 44.7))
BATIMENT0000000302929184;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;8.0;;;23.2;27.2;50.5;58.7;28.4;Cadastre;C 0.2;POLYGON Z ((354728.4 6689298.7 50.5, 354732.7 6689296.1 50.5, 354733.8 6689297.9 50.5, 354733.2 6689298.2 50.5, 354734.8 6689300.9 50.5, 354736.3 6689306.4 50.5, 354737.7 6689312.1 50.5, 354734.2 6689313.5 50.5, 354738.2 6689323.9 50.5, 354754 6689316.6 50.5, 354753.9 6689316.5 50.5, 354748.4 6689298.5 50.5, 354763.9 6689293.8 50.5, 354769 6689307.3 50.5, 354769.3 6689309.5 50.5, 354770.8 6689308.8 50.5, 354775.5 6689320.2 50.5, 354778.6 6689327.6 50.5, 354787.7 6689324.5 50.5, 354785.6 6689314 50.5, 354784 6689306.7 50.5, 354777.5 6689274.5 50.5, 354773.5 6689274.5 50.5, 354760.1 6689275.8 50.5, 354760.7 6689281.6 50.5, 354759.3 6689283.9 50.5, 354746.3 6689288.2 50.5, 354743.7 6689287.3 50.5, 354740.8 6689282.5 50.5, 354725.6 6689291 50.5, 354726.7 6689293.7 50.5, 354728.4 6689298.7 50.5))
BATIMENT0000000302928004;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;11.7;29.0;40.7;42.9;29.5;Cadastre;A 1.0;POLYGON Z ((354553.3 6689252.4 40.7, 354560.5 6689260.5 40.7, 354566.8 6689254.9 40.7, 354565.3 6689254.7 40.7, 354560.6 6689258.6 40.7, 354559.2 6689257 40.7, 354563.8 6689253.3 40.7, 354564.3 6689253.6 40.7, 354564.8 6689253.1 40.7, 354564.8 6689252.5 40.7, 354565.7 6689251.6 40.7, 354565.5 6689251.3 40.7, 354565.7 6689251.1 40.7, 354566 6689250.9 40.7, 354571.3 6689246.5 40.7, 354565.8 6689239.8 40.7, 354565.3 6689239.8 40.7, 354553.3 6689252.4 40.7))
BATIMENT0000000302928000;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;9.6;28.8;38.4;42.1;29.3;Cadastre;A 1.0;POLYGON Z ((354571.5 6689272.9 38.4, 354585 6689263 38.4, 354571.3 6689246.5 38.4, 354566 6689250.9 38.4, 354565.7 6689251.1 38.4, 354565.5 6689251.3 38.4, 354565.7 6689251.6 38.4, 354567.7 6689254 38.4, 354569.8 6689256.6 38.4, 354569 6689257.4 38.4, 354567 6689254.9 38.4, 354566.8 6689254.9 38.4, 354560.5 6689260.5 38.4, 354571.5 6689272.9 38.4))
BATIMENT0000000302928244;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;16.0;27.6;43.6;48.1;29.0;Cadastre;A 1.0;POLYGON Z ((354607.1 6689274.6 43.6, 354618.3 6689269.4 43.6, 354607 6689255.9 43.6, 354611 6689252.7 43.6, 354608.7 6689249.8 43.6, 354595.5 6689260.3 43.6, 354607.1 6689274.6 43.6))
BATIMENT0000000302928001;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;3.0;28.7;31.7;42.9;29.5;Cadastre;A 1.0;POLYGON Z ((354542.8 6689263.2 31.7, 354547 6689267.4 31.7, 354548.8 6689269.1 31.7, 354551.2 6689271.5 31.7, 354545.1 6689277.9 31.7, 354549.1 6689281.9 31.7, 354550.5 6689283.3 31.7, 354562.5 6689294.9 31.7, 354578.8 6689287.5 31.7, 354569 6689276.3 31.7, 354572 6689273.4 31.7, 354571.5 6689272.9 31.7, 354560.5 6689260.5 31.7, 354553.3 6689252.4 31.7, 354542.8 6689263.2 31.7))
BATIMENT0000000302928246;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;15.5;27.9;43.4;46.1;28.8;Cadastre;A 1.0;POLYGON Z ((354614.3 6689283.1 43.4, 354620.6 6689282.2 43.4, 354628.2 6689265.2 43.4, 354623 6689267.4 43.4, 354618.3 6689269.4 43.4, 354607.1 6689274.6 43.4, 354614.3 6689283.1 43.4))
BATIMENT0000000302927999;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.9;28.5;42.5;45.6;29.1;Cadastre;A 1.0;POLYGON Z ((354572 6689273.4 42.5, 354582.9 6689285.6 42.5, 354585.1 6689284.4 42.5, 354598 6689278.8 42.5, 354585 6689263 42.5, 354571.5 6689272.9 42.5, 354572 6689273.4 42.5), (354577.7 6689271.8 42.5, 354586.2 6689281.7 42.5, 354586 6689282 42.5, 354581.2 6689280 42.5, 354580.8 6689280.5 42.5, 354580.3 6689279.7 42.5, 354580.5 6689279.5 42.5, 354577.3 6689275.7 42.5, 354577.5 6689271.8 42.5, 354577.7 6689271.8 42.5))
BATIMENT0000000302928002;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;;;10.4;29.7;40.1;42.1;29.8;Cadastre;A 1.0;POLYGON Z ((354599.8 6689299.7 40.1, 354609.5 6689298.2 40.1, 354608.6 6689291.6 40.1, 354598 6689278.8 40.1, 354585.1 6689284.4 40.1, 354591.2 6689303.1 40.1, 354591.7 6689302.9 40.1, 354599.8 6689299.7 40.1))
BATIMENT0000000302928007;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;00;00;9.4;28.0;37.4;40.5;30.0;Cadastre;C 0.6;POLYGON Z ((354550.5 6689283.3 37.4, 354540.4 6689295.5 37.4, 354544 6689299 37.4, 354545.3 6689300 37.4, 354548.5 6689298.6 37.4, 354559.3 6689293.9 37.4, 354560.2 6689295.9 37.4, 354562.5 6689294.9 37.4, 354550.5 6689283.3 37.4))
BATIMENT0000000302928003;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;46.0;3.0;00;00;8.7;29.2;37.9;40.4;29.8;Cadastre;C 1.0;POLYGON Z ((354579.4 6689294.5 37.9, 354581.6 6689295.6 37.9, 354586.2 6689305.7 37.9, 354586.6 6689305.5 37.9, 354593.3 6689320 37.9, 354588 6689322.2 37.9, 354586.4 6689314.6 37.9, 354583.6 6689313.3 37.9, 354579 6689314.4 37.9, 354579.1 6689314.5 37.9, 354581.2 6689324.1 37.9, 354582.1 6689328 37.9, 354597.7 6689335 37.9, 354601.2 6689327 37.9, 354597.6 6689318.4 37.9, 354595.4 6689319.3 37.9, 354594.2 6689316.7 37.9, 354596.2 6689315.9 37.9, 354595.4 6689313.9 37.9, 354595.6 6689313.4 37.9, 354593.2 6689307.2 37.9, 354591.7 6689302.9 37.9, 354591.2 6689303.1 37.9, 354585.1 6689284.4 37.9, 354582.9 6689285.6 37.9, 354578.8 6689287.5 37.9, 354562.5 6689294.9 37.9, 354560.2 6689295.9 37.9, 354549.8 6689300.5 37.9, 354547.1 6689301.8 37.9, 354544.4 6689303 37.9, 354545.3 6689306.2 37.9, 354546.3 6689309.9 37.9, 354579.4 6689294.5 37.9))
BATIMENT0000000302929111;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.1;29.5;30.6;31.4;29.8;Cadastre;;POLYGON Z ((354565.4 6689318.6 30.6, 354568.2 6689317.5 30.6, 354566.3 6689313 30.6, 354563.5 6689314.2 30.6, 354565.4 6689318.6 30.6))
BATIMENT0000000302931558;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;20.0;6.9;26.9;30.2;7.4;Cadastre;A 1.0;POLYGON Z ((355364.9 6689105.3 26.9, 355347.8 6689137.8 26.9, 355362.8 6689145.5 26.9, 355380 6689113.5 26.9, 355364.9 6689105.3 26.9))
BATIMENT0000000302931557;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;;;14.7;7.0;21.7;28.2;7.7;Cadastre;A 1.0;POLYGON Z ((355377.4 6689153 21.7, 355394 6689120.6 21.7, 355390.7 6689119.1 21.7, 355390.7 6689118.7 21.7, 355382.9 6689114.6 21.7, 355382.6 6689114.8 21.7, 355380 6689113.5 21.7, 355362.8 6689145.5 21.7, 355377.4 6689153 21.7))
BATIMENT0000000302931559;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;5.0;10;20;17.6;7.3;24.9;27.9;7.8;Cadastre;A 1.0;POLYGON Z ((355377.4 6689153 24.9, 355391.8 6689160.5 24.9, 355408.9 6689128 24.9, 355394.2 6689120.4 24.9, 355394 6689120.6 24.9, 355377.4 6689153 24.9), (355391.2 6689133.6 24.9, 355399.4 6689137.6 24.9, 355394.7 6689146 24.9, 355386.9 6689141.9 24.9, 355388.5 6689139.2 24.9, 355389.5 6689139.9 24.9, 355390.2 6689139.9 24.9, 355391.5 6689138 24.9, 355391.4 6689136.8 24.9, 355390 6689136.3 24.9, 355391.2 6689133.6 24.9))
BATIMENT0000000302931802;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.9;6.2;13.2;18.4;6.6;Cadastre;;POLYGON Z ((355305.8 6689160.3 13.2, 355304.7 6689162.6 13.2, 355311.5 6689166.2 13.2, 355312.7 6689163.9 13.2, 355305.8 6689160.3 13.2))
BATIMENT0000000302931803;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;7.6;6.3;14.0;16.2;6.8;Cadastre;;POLYGON Z ((355322.4 6689171.8 14, 355329.1 6689175.5 14, 355330.2 6689173.2 14, 355323.6 6689169.6 14, 355322.4 6689171.8 14))
BATIMENT0000000302931797;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;6.5;;;;Cadastre;;POLYGON Z ((355340 6689181 -1000, 355346.8 6689184.7 -1000, 355348 6689182.4 -1000, 355341.2 6689178.7 -1000, 355340 6689181 -1000))
BATIMENT0000000302931793;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;6.4;;;;Cadastre;;POLYGON Z ((355299.7 6689182.4 -1000, 355298.4 6689184.8 -1000, 355300.8 6689186.1 -1000, 355302 6689183.7 -1000, 355304.3 6689184.9 -1000, 355305.5 6689182.7 -1000, 355306.7 6689180.4 -1000, 355302 6689178 -1000, 355299.7 6689182.4 -1000))
BATIMENT0000000302931794;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;6.3;;;;Cadastre;;POLYGON Z ((355317.5 6689191.8 -1000, 355319.8 6689187.4 -1000, 355315.4 6689185 -1000, 355314.2 6689187.3 -1000, 355311.8 6689191.8 -1000, 355316.1 6689194 -1000, 355316.3 6689194.1 -1000, 355317.5 6689191.8 -1000))
BATIMENT0000000302931796;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.2;6.7;16.0;17.2;7.2;Cadastre;;POLYGON Z ((355364.5 6689193.9 16, 355365.7 6689191.6 16, 355358.9 6689188.1 16, 355357.7 6689190.4 16, 355364.5 6689193.9 16))
BATIMENT0000000302931795;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;2009-01-01;;;;BDParcellaire;5.0;Pas de Z;9999.0;0.0;1.0;;;;6.3;;;;Cadastre;C 0.2;POLYGON Z ((355325.3 6689193 -1000, 355322.9 6689191.7 -1000, 355320.6 6689196.2 -1000, 355327.4 6689199.8 -1000, 355328.5 6689197.7 -1000, 355330.8 6689198.9 -1000, 355329.6 6689201 -1000, 355334 6689203.4 -1000, 355335.2 6689201.3 -1000, 355337.3 6689202.4 -1000, 355339.7 6689197.8 -1000, 355326.4 6689190.8 -1000, 355325.3 6689193 -1000))
BATIMENT0000000302931658;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;12.3;8.0;20.3;;;Cadastre;A 1.0;POLYGON Z ((355542.6 6689147.7 20.3, 355537.2 6689163.1 20.3, 355552.6 6689168.3 20.3, 355553.6 6689167.2 20.3, 355554.1 6689167.5 20.3, 355559.3 6689155.3 20.3, 355558.5 6689154.1 20.3, 355548.8 6689149.1 20.3, 355548.1 6689149.3 20.3, 355545.2 6689147.7 20.3, 355545.2 6689147.4 20.3, 355543.7 6689146.7 20.3, 355542.6 6689147.7 20.3))
BATIMENT0000000302931028;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;6.9;12.5;18.5;7.5;Cadastre;;POLYGON Z ((355509 6689163.7 12.5, 355507.2 6689168.6 12.5, 355506.7 6689169.4 12.5, 355509.7 6689171 12.5, 355512 6689164.8 12.5, 355509 6689163.7 12.5))
BATIMENT0000000302931030;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;30;10;12.0;7.0;19.0;22.7;7.9;Cadastre;A 1.0;POLYGON Z ((355527.1 6689180 19, 355532.4 6689164.9 19, 355521.1 6689161 19, 355514.1 6689158.7 19, 355512 6689164.8 19, 355509.7 6689171 19, 355527.1 6689180 19))
BATIMENT0000000302931252;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;20;20;13.8;7.7;21.5;25.2;7.7;Cadastre;A 1.0;POLYGON Z ((355551.2 6689172.3 21.5, 355535 6689166.2 21.5, 355532.7 6689171.9 21.5, 355548.8 6689177.4 21.5, 355551.2 6689172.3 21.5))
BATIMENT0000000302930909;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;20;20;16.9;7.3;24.3;27.1;8.0;Cadastre;A 1.0;POLYGON Z ((355558 6689183.2 24.3, 355571.2 6689188.1 24.3, 355572 6689185.8 24.3, 355573.6 6689181.1 24.3, 355577 6689182.1 24.3, 355578 6689179.2 24.3, 355580.2 6689179.9 24.3, 355580.3 6689179.1 24.3, 355580.5 6689178.5 24.3, 355563.1 6689172.3 24.3, 355558 6689183.2 24.3))
BATIMENT0000000302931253;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;17.2;7.3;24.5;27.5;8.1;Cadastre;A 1.0;POLYGON Z ((355528.8 6689181.6 24.5, 355543.3 6689189 24.5, 355548.8 6689177.4 24.5, 355532.7 6689171.9 24.5, 355528.8 6689181.6 24.5))
BATIMENT0000000302931711;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;17.1;6.7;23.9;25.8;7.5;Cadastre;A 1.0;POLYGON Z ((355506.4 6689189.7 23.9, 355510.7 6689179.2 23.9, 355501.1 6689174.3 23.9, 355497.5 6689186.3 23.9, 355506.4 6689189.7 23.9))
BATIMENT0000000302931712;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;13.5;7.3;20.8;23.7;7.7;Cadastre;A 1.0;POLYGON Z ((355517.4 6689193.6 20.8, 355521.6 6689184.9 20.8, 355510.7 6689179.2 20.8, 355506.4 6689189.7 20.8, 355517.4 6689193.6 20.8))
BATIMENT0000000302931710;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;;;10.0;6.9;16.9;28.8;8.5;Cadastre;A 1.0;POLYGON Z ((355486 6689166.4 16.9, 355468.8 6689198.7 16.9, 355486.7 6689208.2 16.9, 355497.5 6689186.3 16.9, 355501.1 6689174.3 16.9, 355486 6689166.4 16.9))
BATIMENT0000000302931714;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;;;13.8;7.5;21.3;22.6;8.1;Cadastre;A 1.0;POLYGON Z ((355522 6689194.5 21.3, 355523.9 6689195.1 21.3, 355523.7 6689196.4 21.3, 355537.8 6689201.2 21.3, 355541 6689194.9 21.3, 355527.1 6689187.8 21.3, 355521.6 6689184.9 21.3, 355517.4 6689193.6 21.3, 355522 6689194.5 21.3))
BATIMENT0000000302931713;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;13.3;7.8;21.1;;;Cadastre;A 1.0;POLYGON Z ((355499.8 6689189.6 21.1, 355497.4 6689194.7 21.1, 355506.2 6689197.9 21.1, 355508.1 6689192.3 21.1, 355499.8 6689189.6 21.1))
BATIMENT0000000302931715;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;14.3;7.7;22.0;;;Cadastre;A 1.0;POLYGON Z ((355514.3 6689193.4 22, 355514 6689193.8 22, 355508.1 6689192.3 22, 355506.2 6689197.9 22, 355518.7 6689202.7 22, 355520.9 6689195.6 22, 355514.3 6689193.4 22))
BATIMENT0000000302931716;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;16.4;7.8;24.2;27.3;8.2;Cadastre;A 1.0;POLYGON Z ((355520.9 6689195.6 24.2, 355518.7 6689202.7 24.2, 355518.2 6689204.5 24.2, 355533.8 6689209.8 24.2, 355537.8 6689201.2 24.2, 355523.7 6689196.4 24.2, 355520.9 6689195.6 24.2))
BATIMENT0000000302931717;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;18.6;6.5;25.2;28.6;8.4;Cadastre;A 1.0;POLYGON Z ((355493.5 6689199.5 25.2, 355488.8 6689209.2 25.2, 355498 6689214.1 25.2, 355502.9 6689202.5 25.2, 355493.5 6689199.5 25.2))
BATIMENT0000000302930918;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;15.1;8.0;23.1;26.4;8.1;Cadastre;A 1.0;POLYGON Z ((355550.5 6689200.8 23.1, 355547 6689208.5 23.1, 355558.6 6689213.8 23.1, 355560 6689209.9 23.1, 355561.4 6689206.5 23.1, 355550.5 6689200.8 23.1))
BATIMENT0000000302931718;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;19.1;6.6;25.8;28.6;8.5;Cadastre;A 1.0;POLYGON Z ((355509.9 6689220.4 25.8, 355515.1 6689206.6 25.8, 355502.9 6689202.5 25.8, 355498 6689214.1 25.8, 355509.9 6689220.4 25.8))
BATIMENT0000000302930917;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;00;00;15.7;7.8;23.5;26.6;8.2;Cadastre;A 1.0;POLYGON Z ((355546.3 6689210.1 23.5, 355544.2 6689214.7 23.5, 355553 6689218 23.5, 355554.6 6689214.2 23.5, 355546.3 6689210.1 23.5))
BATIMENT0000000302930915;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;00;00;15.2;8.0;23.2;26.1;8.5;Cadastre;A 1.0;POLYGON Z ((355557.6 6689215.9 23.2, 355560.2 6689218.9 23.2, 355562.2 6689222 23.2, 355565.7 6689220.2 23.2, 355567.5 6689222.2 23.2, 355567.3 6689222.6 23.2, 355568.1 6689223.2 23.2, 355573.5 6689221.7 23.2, 355577.7 6689224 23.2, 355581.1 6689216.7 23.2, 355561.4 6689206.5 23.2, 355560 6689209.9 23.2, 355558.6 6689213.8 23.2, 355557.6 6689215.9 23.2))
BATIMENT0000000302931719;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;;;19.9;7.0;27.0;28.9;8.6;Cadastre;A 1.0;POLYGON Z ((355522.7 6689227.1 27, 355526.5 6689226 27, 355532.6 6689212.7 27, 355524.5 6689209.6 27, 355515.1 6689206.6 27, 355509.9 6689220.4 27, 355522.7 6689227.1 27))
BATIMENT0000000302930914;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;00;00;17.0;8.0;25.0;26.7;8.3;Cadastre;A 1.0;POLYGON Z ((355556 6689214.9 25, 355554.6 6689214.2 25, 355553 6689218 25, 355544.2 6689214.7 25, 355542.6 6689218.3 25, 355553.8 6689221.2 25, 355552.3 6689225.2 25, 355558.7 6689226.9 25, 355560.2 6689222.4 25, 355562.5 6689222.6 25, 355562.2 6689222 25, 355560.2 6689218.9 25, 355557.6 6689215.9 25, 355556 6689214.9 25))
BATIMENT0000000302931800;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;6.9;;;;Cadastre;;POLYGON Z ((355375.5 6689199.7 -1000, 355382.2 6689203.2 -1000, 355383.4 6689201 -1000, 355376.7 6689197.4 -1000, 355375.5 6689199.7 -1000))
BATIMENT0000000302931792;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;6.5;;;;Cadastre;;POLYGON Z ((355345.3 6689203.5 -1000, 355343 6689202.3 -1000, 355340.7 6689206.8 -1000, 355345 6689209.1 -1000, 355346.2 6689206.9 -1000, 355348.5 6689208.1 -1000, 355347.3 6689210.3 -1000, 355354.2 6689214 -1000, 355357.6 6689207.4 -1000, 355346.5 6689201.3 -1000, 355345.3 6689203.5 -1000))
BATIMENT0000000302931801;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;7.2;;;;Cadastre;;POLYGON Z ((355393.2 6689209 -1000, 355400 6689212.6 -1000, 355401.2 6689210.4 -1000, 355394.4 6689206.8 -1000, 355393.2 6689209 -1000))
BATIMENT0000000302931799;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;2009-01-01;;;;BDParcellaire;5.0;Pas de Z;9999.0;0.0;1.0;;;;6.7;;;;Cadastre;C 0.2;POLYGON Z ((355361.7 6689215 -1000, 355373 6689221.1 -1000, 355374.2 6689218.8 -1000, 355371.8 6689217.5 -1000, 355372.9 6689215.3 -1000, 355364 6689210.6 -1000, 355361.7 6689215 -1000))
BATIMENT0000000302931798;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;7.1;;;;Cadastre;;POLYGON Z ((355383.6 6689224.1 -1000, 355390.3 6689227.6 -1000, 355391.5 6689225.4 -1000, 355384.9 6689221.8 -1000, 355383.6 6689224.1 -1000))
BATIMENT0000000302931375;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1852-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;5.0;;;16.6;7.0;23.6;28.1;7.4;Cadastre;C 0.4;POLYGON Z ((355323 6689220.6 23.6, 355323.1 6689220.2 23.6, 355312.1 6689215.3 23.6, 355311.8 6689215.6 23.6, 355311.6 6689215.5 23.6, 355308.2 6689220.9 23.6, 355308.3 6689221 23.6, 355303.4 6689229.1 23.6, 355312.4 6689235.3 23.6, 355314.7 6689231.6 23.6, 355329.4 6689237.8 23.6, 355334.6 6689225.6 23.6, 355323 6689220.6 23.6))
BATIMENT0000000302931373;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.4;7.8;23.2;;;Cadastre;;POLYGON Z ((355301.6 6689232 23.2, 355310.4 6689238.2 23.2, 355312.4 6689235.3 23.2, 355303.4 6689229.1 23.2, 355301.6 6689232 23.2))
BATIMENT0000000302931377;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;00;00;17.1;6.9;24.0;28.3;7.2;Cadastre;A 1.0;POLYGON Z ((355346.3 6689229.9 24, 355346 6689230.4 24, 355334.6 6689225.6 24, 355329.4 6689237.8 24, 355353.8 6689248.2 24, 355359.2 6689235.6 24, 355346.3 6689229.9 24))
BATIMENT0000000302931374;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.9;7.8;14.7;22.8;8.0;Cadastre;A 1.0;POLYGON Z ((355301.1 6689232.9 14.7, 355301.3 6689233 14.7, 355296.5 6689240.6 14.7, 355298.2 6689245.2 14.7, 355310.9 6689249.5 14.7, 355313.6 6689242.1 14.7, 355310.8 6689241.1 14.7, 355310.4 6689238.2 14.7, 355301.6 6689232 14.7, 355301.1 6689232.9 14.7))
BATIMENT0000000302931376;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.6;7.8;14.4;15.4;7.9;Cadastre;;POLYGON Z ((355323.3 6689253.8 14.4, 355325.9 6689246.2 14.4, 355313.6 6689242.1 14.4, 355310.9 6689249.5 14.4, 355323.3 6689253.8 14.4))
BATIMENT0000000302931564;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;6.0;12;20;19.3;6.9;26.2;29.6;7.8;Cadastre;A 1.0;POLYGON Z ((355453 6689150.8 26.2, 355437.7 6689142.9 26.2, 355434.9 6689149 26.2, 355437.9 6689150.4 26.2, 355437.5 6689151.6 26.2, 355436.4 6689151.6 26.2, 355436 6689152.1 26.2, 355435.2 6689153.6 26.2, 355433 6689152.6 26.2, 355429.4 6689159.3 26.2, 355436.1 6689163 26.2, 355444.4 6689167.3 26.2, 355453 6689150.8 26.2))
BATIMENT0000000302931566;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;7.7;21.7;24.2;8.3;Cadastre;;POLYGON Z ((355417.8 6689157.8 21.7, 355422.4 6689160.2 21.7, 355424.2 6689160 21.7, 355425.1 6689158.8 21.7, 355425.1 6689158.4 21.7, 355421.6 6689156.5 21.7, 355418 6689154.8 21.7, 355417.9 6689155.2 21.7, 355417.8 6689157.8 21.7))
BATIMENT0000000302931563;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;20;20;18.5;7.4;26.0;28.7;8.3;Cadastre;A 1.0;POLYGON Z ((355421 6689175.7 26, 355425.1 6689167.6 26, 355428.6 6689160.9 26, 355425.1 6689158.8 26, 355424.2 6689160 26, 355422.4 6689160.2 26, 355417.8 6689157.8 26, 355417.9 6689155.2 26, 355414.1 6689153.3 26, 355406.6 6689167.9 26, 355421 6689175.7 26))
BATIMENT0000000302931565;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;18.6;7.3;26.0;28.0;7.9;Cadastre;A 1.0;POLYGON Z ((355435.9 6689183.3 26, 355444.4 6689167.3 26, 355436.1 6689163 26, 355431.9 6689171 26, 355425.1 6689167.6 26, 355421 6689175.7 26, 355435.9 6689183.3 26))
BATIMENT0000000302931363;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;16.7;7.4;24.1;28.5;8.4;Cadastre;A 1.0;POLYGON Z ((355447.9 6689266.1 24.1, 355448 6689265.8 24.1, 355436.6 6689262.9 24.1, 355431.8 6689272.7 24.1, 355431.6 6689272.6 24.1, 355425.9 6689283.9 24.1, 355426.1 6689284 24.1, 355432.8 6689285.3 24.1, 355436.6 6689288.6 24.1, 355440.2 6689291.8 24.1, 355442.1 6689289.5 24.1, 355442.5 6689289.8 24.1, 355446.5 6689285.1 24.1, 355446.6 6689285 24.1, 355446.4 6689284.9 24.1, 355445.6 6689284.9 24.1, 355450.8 6689266.8 24.1, 355447.9 6689266.1 24.1), (355439.5 6689277.5 24.1, 355442.6 6689278.4 24.1, 355440.4 6689286.1 24.1, 355437.7 6689283.7 24.1, 355439.5 6689277.5 24.1))
BATIMENT0000000302931364;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;18.1;7.9;26.0;29.2;8.6;Cadastre;A 1.0;POLYGON Z ((355446.4 6689284.9 26, 355446.6 6689285 26, 355451.8 6689285.5 26, 355451.7 6689287.2 26, 355452 6689288.1 26, 355455.7 6689290 26, 355457 6689290.6 26, 355458.2 6689287 26, 355460 6689287.3 26, 355462.2 6689287.8 26, 355464.5 6689288.3 26, 355465.1 6689287.4 26, 355464.8 6689287.2 26, 355467.6 6689280 26, 355469.5 6689271.5 26, 355450.8 6689266.8 26, 355445.6 6689284.9 26, 355446.4 6689284.9 26), (355455.9 6689276.1 26, 355460.2 6689277.2 26, 355458.6 6689283.2 26, 355454.3 6689282.1 26, 355455.9 6689276.1 26))
BATIMENT0000000302931367;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;16.6;8.0;24.6;28.4;8.8;Cadastre;A 1.0;POLYGON Z ((355469.5 6689271.5 24.6, 355467.6 6689280 24.6, 355464.8 6689287.2 24.6, 355465.1 6689287.4 24.6, 355466.9 6689288.1 24.6, 355469 6689289 24.6, 355471.3 6689290 24.6, 355473.8 6689283.7 24.6, 355473.9 6689283.6 24.6, 355475 6689278.2 24.6, 355474.7 6689278.2 24.6, 355475.7 6689273 24.6, 355469.5 6689271.5 24.6))
BATIMENT0000000302931365;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;18.6;7.0;25.7;28.1;7.7;Cadastre;A 1.0;POLYGON Z ((355423.7 6689288.8 25.7, 355423.4 6689288.7 25.7, 355421.1 6689293.5 25.7, 355432 6689303.1 25.7, 355437.7 6689296.3 25.7, 355439.4 6689294.3 25.7, 355438.5 6689293.8 25.7, 355437.6 6689293.3 25.7, 355437 6689294.1 25.7, 355435.8 6689293.6 25.7, 355434.9 6689294.9 25.7, 355433.7 6689294.1 25.7, 355436.6 6689288.6 25.7, 355432.8 6689285.3 25.7, 355426.1 6689284 25.7, 355423.7 6689288.8 25.7))
BATIMENT0000000302931366;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;30;20;13.8;8.0;21.8;26.7;8.6;Cadastre;A 1.0;POLYGON Z ((355459.9 6689311.2 21.8, 355488.7 6689317.8 21.8, 355495.1 6689301.3 21.8, 355495.2 6689301 21.8, 355475.2 6689292.7 21.8, 355473 6689302.5 21.8, 355463 6689300.2 21.8, 355462.7 6689301.6 21.8, 355458.8 6689300.8 21.8, 355450.5 6689300.2 21.8, 355450.7 6689297.2 21.8, 355455.7 6689290 21.8, 355452 6689288.1 21.8, 355446.5 6689285.1 21.8, 355442.5 6689289.8 21.8, 355442.1 6689289.5 21.8, 355440.2 6689291.8 21.8, 355439.8 6689292.4 21.8, 355443.8 6689295.9 21.8, 355443.6 6689299.5 21.8, 355443 6689309.7 21.8, 355459.9 6689311.2 21.8))
BATIMENT0000000302931368;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;13;20;16.5;7.2;23.7;26.6;7.5;Cadastre;A 1.0;POLYGON Z ((355439.1 6689309.4 23.7, 355443 6689309.7 23.7, 355443.6 6689299.5 23.7, 355441.4 6689299.3 23.7, 355437.7 6689296.3 23.7, 355432 6689303.1 23.7, 355439.1 6689309.4 23.7))
BATIMENT0000000302930911;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;18.3;7.9;26.2;29.2;8.5;Cadastre;A 1.0;POLYGON Z ((355538.5 6689227.4 26.2, 355547.2 6689229.5 26.2, 355548.2 6689225.1 26.2, 355540.5 6689222.9 26.2, 355538.5 6689227.4 26.2))
BATIMENT0000000302930916;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;;;14.8;8.0;22.8;24.0;8.3;Cadastre;A 1.0;POLYGON Z ((355577.7 6689224 22.8, 355573.5 6689221.7 22.8, 355568.1 6689223.2 22.8, 355567.3 6689222.6 22.8, 355567.5 6689222.2 22.8, 355565.7 6689220.2 22.8, 355562.2 6689222 22.8, 355562.5 6689222.6 22.8, 355563.9 6689225.4 22.8, 355564.5 6689225 22.8, 355573.4 6689232.4 22.8, 355577.7 6689224 22.8))
BATIMENT0000000302930912;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1730-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;20;20;21.2;7.3;28.6;30.7;8.5;Cadastre;A 1.0;POLYGON Z ((355540.5 6689222.9 28.6, 355548.2 6689225.1 28.6, 355547.2 6689229.5 28.6, 355554.6 6689229.4 28.6, 355554.5 6689236.2 28.6, 355561.6 6689236.2 28.6, 355561.7 6689231.4 28.6, 355559.1 6689227.4 28.6, 355558.7 6689226.9 28.6, 355552.3 6689225.2 28.6, 355553.8 6689221.2 28.6, 355542.6 6689218.3 28.6, 355540.5 6689222.9 28.6))
BATIMENT0000000302930913;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;20;20;13.4;7.1;20.5;23.4;8.3;Cadastre;A 1.0;POLYGON Z ((355571.6 6689235.9 20.5, 355573.4 6689232.4 20.5, 355564.5 6689225 20.5, 355563.9 6689225.4 20.5, 355559.1 6689227.4 20.5, 355561.7 6689231.4 20.5, 355561.6 6689236.2 20.5, 355571.6 6689235.9 20.5))
BATIMENT0000000302930910;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;16.0;8.0;24.0;28.4;8.6;Cadastre;A 1.0;POLYGON Z ((355536.2 6689232.5 24, 355537.3 6689236.4 24, 355538.7 6689236.4 24, 355554.5 6689236.2 24, 355554.6 6689229.4 24, 355547.2 6689229.5 24, 355538.5 6689227.4 24, 355536.2 6689232.5 24))
BATIMENT0000000302931370;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.3;8.1;25.5;28.3;8.8;Cadastre;;POLYGON Z ((355475.7 6689273 25.5, 355474.7 6689278.2 25.5, 355475 6689278.2 25.5, 355478 6689278.9 25.5, 355478.3 6689279 25.5, 355479.3 6689273.9 25.5, 355475.7 6689273 25.5))
BATIMENT0000000302931371;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;18.6;8.1;26.7;28.5;9.0;Cadastre;A 1.0;POLYGON Z ((355488.3 6689275.9 26.7, 355488.2 6689276.1 26.7, 355479.3 6689273.9 26.7, 355478.3 6689279 26.7, 355478 6689278.9 26.7, 355476.1 6689288.7 26.7, 355484.6 6689292.1 26.7, 355486.5 6689288.4 26.7, 355487.5 6689285.8 26.7, 355489.6 6689276.2 26.7, 355488.3 6689275.9 26.7))
BATIMENT0000000302931372;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;17.7;8.3;26.0;28.2;9.0;Cadastre;A 1.0;POLYGON Z ((355499.8 6689288.6 26, 355499.1 6689288.4 26, 355501.8 6689282.7 26, 355499.7 6689278.8 26, 355489.6 6689276.2 26, 355487.5 6689285.8 26, 355486.5 6689288.4 26, 355484.6 6689292.1 26, 355496.9 6689297.1 26, 355497 6689296.8 26, 355499.8 6689288.6 26))
BATIMENT0000000302931369;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;19.8;8.0;27.9;29.0;8.6;Cadastre;A 1.0;POLYGON Z ((355495.6 6689301.5 27.9, 355497.6 6689297.2 27.9, 355497 6689296.8 27.9, 355496.9 6689297.1 27.9, 355484.6 6689292.1 27.9, 355476.1 6689288.7 27.9, 355475.2 6689292.7 27.9, 355495.2 6689301 27.9, 355495.1 6689301.3 27.9, 355495.6 6689301.5 27.9))
BATIMENT0000000302931514;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;;;20.2;8.0;28.2;31.6;8.7;Cadastre;A 1.0;POLYGON Z ((355531 6689286.7 28.2, 355527.1 6689300.8 28.2, 355542.2 6689304.8 28.2, 355543.6 6689299.3 28.2, 355544.2 6689297.2 28.2, 355545.8 6689290.6 28.2, 355531 6689286.7 28.2))
BATIMENT0000000302931381;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;00;00;6.4;7.8;14.2;;;Cadastre;A 1.0;POLYGON Z ((355335.3 6689257.9 14.2, 355338.1 6689250.5 14.2, 355325.9 6689246.2 14.2, 355323.3 6689253.8 14.2, 355335.3 6689257.9 14.2))
BATIMENT0000000302931378;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;00;00;18.8;6.9;25.8;28.5;7.5;Cadastre;A 1.0;POLYGON Z ((355351.1 6689254.9 25.8, 355348 6689262.2 25.8, 355348 6689262.3 25.8, 355365.6 6689268.7 25.8, 355375.6 6689243.1 25.8, 355359.6 6689236.3 25.8, 355359.7 6689235.7 25.8, 355359.2 6689235.6 25.8, 355353.8 6689248.2 25.8, 355351.1 6689254.9 25.8), (355359.3 6689248.7 25.8, 355366.2 6689251.4 25.8, 355364.3 6689256.1 25.8, 355357.3 6689253.5 25.8, 355359.3 6689248.7 25.8))
BATIMENT0000000302931379;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;6.6;7.6;14.2;;;Cadastre;A 1.0;POLYGON Z ((355348 6689262.2 14.2, 355351.1 6689254.9 14.2, 355338.1 6689250.5 14.2, 355335.3 6689257.9 14.2, 355348 6689262.2 14.2))
BATIMENT0000000302931380;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1650-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;12;20;18.2;7.0;25.3;28.1;7.2;Cadastre;A 1.0;POLYGON Z ((355373.3 6689271.4 25.3, 355377.6 6689260.7 25.3, 355372.1 6689258.7 25.3, 355373.8 6689254.6 25.3, 355379.1 6689256.8 25.3, 355383.1 6689246.4 25.3, 355375.6 6689243.1 25.3, 355365.6 6689268.7 25.3, 355373.3 6689271.4 25.3))
BATIMENT0000000302931382;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.9;7.0;25.0;25.9;7.1;Cadastre;;POLYGON Z ((355373.8 6689254.6 25, 355372.1 6689258.7 25, 355377.6 6689260.7 25, 355379.1 6689256.8 25, 355373.8 6689254.6 25))
BATIMENT0000000302931383;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;18.0;6.9;24.9;28.0;7.6;Cadastre;A 1.0;POLYGON Z ((355380.1 6689273.8 24.9, 355380 6689274.1 24.9, 355380.8 6689274.3 24.9, 355380.8 6689274.2 24.9, 355381.7 6689274 24.9, 355382 6689273.5 24.9, 355381.8 6689273.3 24.9, 355393.8 6689252.2 24.9, 355394 6689252.3 24.9, 355394.3 6689251.5 24.9, 355394.2 6689251.4 24.9, 355394.5 6689250.9 24.9, 355383.3 6689245.9 24.9, 355383.1 6689246.4 24.9, 355379.1 6689256.8 24.9, 355377.6 6689260.7 24.9, 355373.3 6689271.4 24.9, 355380.1 6689273.8 24.9))
BATIMENT0000000302931384;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;22.0;6.2;28.3;31.6;7.7;Cadastre;A 1.0;POLYGON Z ((355289.4 6689253 28.3, 355288.9 6689253.1 28.3, 355288.6 6689253.4 28.3, 355288.1 6689253.8 28.3, 355287.3 6689255.1 28.3, 355277.6 6689269.2 28.3, 355293.9 6689277.7 28.3, 355295.6 6689278.6 28.3, 355300 6689280.8 28.3, 355301.8 6689281.8 28.3, 355307.7 6689284.8 28.3, 355305.2 6689288.9 28.3, 355311 6689291.6 28.3, 355314.5 6689293.3 28.3, 355316.1 6689290 28.3, 355317 6689290.4 28.3, 355330.1 6689296.5 28.3, 355328.4 6689300 28.3, 355338.3 6689304.6 28.3, 355343 6689295.5 28.3, 355346.8 6689288.1 28.3, 355342.2 6689286 28.3, 355339.7 6689284.8 28.3, 355338.5 6689284.3 28.3, 355341.2 6689278 28.3, 355343.3 6689278.8 28.3, 355345 6689279.6 28.3, 355347.5 6689280.8 28.3, 355350.6 6689273.9 28.3, 355342.5 6689271 28.3, 355331.2 6689267 28.3, 355291 6689252.9 28.3, 355290 6689252.9 28.3, 355289.4 6689253 28.3))
BATIMENT0000000302931390;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;50;20;16.7;6.5;23.2;25.0;7.2;Cadastre;A 1.0;POLYGON Z ((355350.6 6689273.9 23.2, 355347.5 6689280.8 23.2, 355355.3 6689283.9 23.2, 355358.7 6689276.9 23.2, 355350.6 6689273.9 23.2))
BATIMENT0000000302931404;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;17.3;6.6;24.0;25.9;7.2;Cadastre;A 1.0;POLYGON Z ((355358.7 6689276.9 24, 355355.3 6689283.9 24, 355362.9 6689287.1 24, 355366.5 6689279.8 24, 355358.7 6689276.9 24))
BATIMENT0000000302931405;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;17.7;6.5;24.2;26.8;7.1;Cadastre;A 1.0;POLYGON Z ((355376.6 6689284.8 24.2, 355375.9 6689283.3 24.2, 355366.5 6689279.8 24.2, 355362.9 6689287.1 24.2, 355372.3 6689293.3 24.2, 355376.6 6689284.8 24.2))
BATIMENT0000000302931391;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;12;20;16.3;6.3;22.6;26.2;6.8;Cadastre;A 1.0;POLYGON Z ((355372.3 6689293.3 22.6, 355362.9 6689287.1 22.6, 355355.3 6689283.9 22.6, 355347.5 6689280.8 22.6, 355345 6689279.6 22.6, 355344.2 6689281.5 22.6, 355342.2 6689286 22.6, 355346.8 6689288.1 22.6, 355349.5 6689289.6 22.6, 355351.2 6689290.4 22.6, 355352.3 6689290.7 22.6, 355354.5 6689286.1 22.6, 355357.6 6689287.5 22.6, 355355.5 6689292.3 22.6, 355369.3 6689299.3 22.6, 355372.3 6689293.3 22.6))
BATIMENT0000000302931392;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.7;6.0;22.7;28.0;6.7;Cadastre;;POLYGON Z ((355314.5 6689293.3 22.7, 355311 6689291.6 22.7, 355309.2 6689295.6 22.7, 355311 6689296.3 22.7, 355311.5 6689295.4 22.7, 355314 6689296.6 22.7, 355314.5 6689295.7 22.7, 355315.4 6689293.7 22.7, 355314.5 6689293.3 22.7))
BATIMENT0000000302931394;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;12.7;5.9;18.7;28.2;7.1;Cadastre;C 0.2;POLYGON Z ((355305.2 6689288.9 18.7, 355303.2 6689291.9 18.7, 355302.4 6689293.5 18.7, 355306.9 6689295.8 18.7, 355323.1 6689303.9 18.7, 355324.1 6689302 18.7, 355323.9 6689301.2 18.7, 355314 6689296.6 18.7, 355311.5 6689295.4 18.7, 355311 6689296.3 18.7, 355309.2 6689295.6 18.7, 355311 6689291.6 18.7, 355305.2 6689288.9 18.7))
BATIMENT0000000302931386;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;6.0;16.2;20.0;6.5;Cadastre;;POLYGON Z ((355315.4 6689293.7 16.2, 355314.5 6689295.7 16.2, 355324.8 6689300.6 16.2, 355325.8 6689298.7 16.2, 355315.4 6689293.7 16.2))
BATIMENT0000000302931406;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.2;7.2;19.4;;;Cadastre;;POLYGON Z ((355356.7 6689299.7 19.4, 355358 6689297.2 19.4, 355355.2 6689295.8 19.4, 355354 6689298.3 19.4, 355356.7 6689299.7 19.4))
BATIMENT0000000302931395;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;;;12.0;7.3;19.3;;;Cadastre;A 1.0;POLYGON Z ((355347.1 6689297.7 19.3, 355363.7 6689310.2 19.3, 355369.3 6689299.3 19.3, 355355.5 6689292.3 19.3, 355352.3 6689290.7 19.3, 355351.2 6689290.4 19.3, 355347.9 6689296.2 19.3, 355346.6 6689295.4 19.3, 355349.5 6689289.6 19.3, 355346.8 6689288.1 19.3, 355343 6689295.5 19.3, 355347.1 6689297.7 19.3), (355355.2 6689295.8 19.3, 355358 6689297.2 19.3, 355356.7 6689299.7 19.3, 355354 6689298.3 19.3, 355355.2 6689295.8 19.3))
BATIMENT0000000302931393;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.4;6.0;16.5;19.0;6.2;Cadastre;;POLYGON Z ((355325.8 6689298.7 16.5, 355324.8 6689300.6 16.5, 355325.4 6689303.7 16.5, 355326.3 6689304.1 16.5, 355328.4 6689300 16.5, 355325.8 6689298.7 16.5))
BATIMENT0000000302931401;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;11.5;7.6;19.1;;;Cadastre;A 1.0;POLYGON Z ((355325.9 6689305.3 19.1, 355323.1 6689303.9 19.1, 355306.9 6689295.8 19.1, 355305.7 6689298.2 19.1, 355306.8 6689298.8 19.1, 355306.7 6689299.2 19.1, 355307.2 6689299.5 19.1, 355310 6689300.9 19.1, 355309 6689302.9 19.1, 355321.1 6689309.4 19.1, 355320.8 6689310.1 19.1, 355322.8 6689311.2 19.1, 355325.9 6689305.3 19.1))
BATIMENT0000000302931400;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;6.2;21.6;24.0;6.4;Cadastre;;POLYGON Z ((355346.8 6689307.7 21.6, 355349.5 6689302.8 21.6, 355346.8 6689301.2 21.6, 355344.1 6689306.1 21.6, 355346.8 6689307.7 21.6))
BATIMENT0000000302931388;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;00;00;14.7;6.2;21.0;30.1;6.7;Cadastre;A 1.0;POLYGON Z ((355359.4 6689318.9 21, 355363.7 6689310.2 21, 355347.1 6689297.7 21, 355343 6689295.5 21, 355338.3 6689304.6 21, 355359.4 6689318.9 21), (355346.8 6689301.2 21, 355349.5 6689302.8 21, 355346.8 6689307.7 21, 355344.1 6689306.1 21, 355346.8 6689301.2 21))
BATIMENT0000000302931516;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;6.0;10;23;20.0;8.0;28.0;31.4;9.1;Cadastre;A 1.0;POLYGON Z ((355527.7 6689285.9 28, 355527.8 6689285.5 28, 355516.5 6689282.7 28, 355511.9 6689285.3 28, 355503.1 6689308.5 28, 355507.8 6689310.2 28, 355507.8 6689311.5 28, 355517.3 6689314.2 28, 355521.3 6689299.3 28, 355527.1 6689300.8 28, 355531 6689286.7 28, 355527.7 6689285.9 28))
BATIMENT0000000302931513;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;23.6;8.2;31.9;32.1;8.5;Cadastre;;POLYGON Z ((355548 6689300.4 31.9, 355548.5 6689298.2 31.9, 355544.2 6689297.2 31.9, 355543.6 6689299.3 31.9, 355548 6689300.4 31.9))
BATIMENT0000000302931515;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1848-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;10;20;20.1;8.0;28.1;32.8;8.8;Cadastre;C 0.3;POLYGON Z ((355551.6 6689329.5 28.1, 355560.4 6689294.1 28.1, 355549.2 6689291.2 28.1, 355549.1 6689291.5 28.1, 355545.8 6689290.6 28.1, 355544.2 6689297.2 28.1, 355548.5 6689298.2 28.1, 355548 6689300.4 28.1, 355543.6 6689299.3 28.1, 355542.2 6689304.8 28.1, 355538.7 6689318.9 28.1, 355538.9 6689318.9 28.1, 355537.3 6689325.1 28.1, 355537.6 6689325.1 28.1, 355540.2 6689325.8 28.1, 355540.1 6689326.7 28.1, 355537.5 6689327.2 28.1, 355538.6 6689332.2 28.1, 355551.6 6689329.5 28.1))
BATIMENT0000000302931517;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;00;00;14.0;8.4;22.5;29.2;8.9;Cadastre;A 1.0;POLYGON Z ((355497.3 6689323.8 22.5, 355502.8 6689327.8 22.5, 355506.7 6689316.9 22.5, 355507.8 6689311.5 22.5, 355507.8 6689310.2 22.5, 355503.1 6689308.5 22.5, 355497.3 6689323.8 22.5))
BATIMENT0000000302931518;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;35.0;5.0;10;20;18.9;8.0;26.9;29.1;9.0;Cadastre;A 1.0;POLYGON Z ((355508.3 6689317.3 26.9, 355504.6 6689329.2 26.9, 355509.2 6689332.5 26.9, 355518.4 6689336.5 26.9, 355538.6 6689332.2 26.9, 355537.5 6689327.2 26.9, 355537.1 6689327.3 26.9, 355537.6 6689325.1 26.9, 355537.3 6689325.1 26.9, 355538.9 6689318.9 26.9, 355538.7 6689318.9 26.9, 355520.6 6689314.3 26.9, 355518.4 6689322.4 26.9, 355515.3 6689321.5 26.9, 355517.3 6689314.2 26.9, 355507.8 6689311.5 26.9, 355506.7 6689316.9 26.9, 355508.3 6689317.3 26.9))
BATIMENT0000000302930956;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;22.3;8.3;30.7;33.5;9.3;Cadastre;A 1.0;POLYGON Z ((355508.1 6689338.8 30.7, 355496.7 6689330.8 30.7, 355494.2 6689331.7 30.7, 355489.9 6689343.3 30.7, 355495 6689346.3 30.7, 355498.2 6689346.5 30.7, 355501 6689346.6 30.7, 355507.6 6689347 30.7, 355508.1 6689338.8 30.7))
BATIMENT0000000302931262;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;6.0;10;20;18.3;8.2;26.5;29.0;11.0;Cadastre;A 1.0;POLYGON Z ((355526 6689350.2 26.5, 355525.8 6689355.3 26.5, 355525.7 6689357.5 26.5, 355529.7 6689357.8 26.5, 355547.9 6689358.9 26.5, 355548.3 6689354.4 26.5, 355548.6 6689350 26.5, 355548.7 6689348.6 26.5, 355545.1 6689348.6 26.5, 355544.7 6689345.6 26.5, 355553 6689344.1 26.5, 355552.9 6689346.9 26.5, 355550.7 6689348.3 26.5, 355550.6 6689350.2 26.5, 355554.8 6689350.5 26.5, 355557.6 6689350.7 26.5, 355558.7 6689335.1 26.5, 355525.6 6689340.8 26.5, 355526 6689350.2 26.5), (355538.3 6689348.7 26.5, 355538.4 6689349.7 26.5, 355535.5 6689350.2 26.5, 355535.7 6689352.1 26.5, 355533.5 6689352.1 26.5, 355533.2 6689349.5 26.5, 355538.3 6689348.7 26.5))
BATIMENT0000000302930958;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;19.4;8.3;27.8;32.5;8.9;Cadastre;C 0.3;POLYGON Z ((355487.3 6689350.2 27.8, 355492.8 6689352.3 27.8, 355495 6689346.3 27.8, 355489.9 6689343.3 27.8, 355487.3 6689350.2 27.8))
BATIMENT0000000302931264;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;19.1;8.0;27.1;29.6;10.3;Cadastre;A 1.0;POLYGON Z ((355519.3 6689341.9 27.1, 355518.9 6689355.1 27.1, 355525.8 6689355.3 27.1, 355526 6689350.2 27.1, 355525.6 6689340.8 27.1, 355519.3 6689341.9 27.1))
BATIMENT0000000302931266;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;15.1;9.0;24.2;28.2;9.9;Cadastre;A 1.0;POLYGON Z ((355514 6689342.8 24.2, 355513.4 6689354.9 24.2, 355518.9 6689355.1 24.2, 355519.3 6689341.9 24.2, 355514 6689342.8 24.2))
BATIMENT0000000302931239;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;19.0;4.0;10;20;15.7;7.2;22.9;26.1;7.6;Cadastre;A 1.0;POLYGON Z ((355429.1 6689306.1 22.9, 355429.3 6689305.8 22.9, 355428.5 6689305.3 22.9, 355427.8 6689306 22.9, 355419.2 6689298.3 22.9, 355418.5 6689298.5 22.9, 355412.4 6689310.5 22.9, 355410.3 6689314.7 22.9, 355403.4 6689328.2 22.9, 355403.7 6689328.9 22.9, 355408.2 6689330.7 22.9, 355418.2 6689318.9 22.9, 355421.2 6689315.3 22.9, 355419.1 6689314.2 22.9, 355420 6689312.4 22.9, 355422.6 6689313.7 22.9, 355422.8 6689313.5 22.9, 355429.1 6689306.1 22.9))
BATIMENT0000000302931240;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;24;20;14.1;7.9;22.0;24.2;7.9;Cadastre;A 1.0;POLYGON Z ((355435.6 6689319.1 22, 355435.1 6689320.3 22, 355433.5 6689324.1 22, 355434.7 6689324.4 22, 355439.5 6689325.7 22, 355442.5 6689326.5 22, 355443.9 6689319.9 22, 355435.6 6689319.1 22))
BATIMENT0000000302931238;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;50;20;12.9;7.8;20.7;24.2;7.9;Cadastre;A 1.0;POLYGON Z ((355428.7 6689315.4 20.7, 355422.8 6689313.5 20.7, 355422.6 6689313.7 20.7, 355421.2 6689315.3 20.7, 355418.2 6689318.9 20.7, 355408.2 6689330.7 20.7, 355417.7 6689334.3 20.7, 355422 6689325.6 20.7, 355429.4 6689328.6 20.7, 355430.7 6689326.3 20.7, 355432.2 6689323.7 20.7, 355432.3 6689323.7 20.7, 355432.3 6689322.4 20.7, 355431.4 6689322.5 20.7, 355426.5 6689321.1 20.7, 355428.7 6689315.4 20.7))
BATIMENT0000000302931244;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;13.6;7.9;21.5;;;Cadastre;A 1.0;POLYGON Z ((355443.9 6689319.9 21.5, 355442.5 6689326.5 21.5, 355444.6 6689327.1 21.5, 355450.4 6689328.2 21.5, 355452.1 6689328.5 21.5, 355453.6 6689320.8 21.5, 355443.9 6689319.9 21.5))
BATIMENT0000000302931241;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.0;7.5;22.5;23.2;7.9;Cadastre;;POLYGON Z ((355432.3 6689323.7 22.5, 355432.2 6689323.7 22.5, 355430.7 6689326.3 22.5, 355434 6689327.6 22.5, 355434.7 6689324.4 22.5, 355433.5 6689324.1 22.5, 355432.3 6689323.7 22.5))
BATIMENT0000000302931246;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;12;20;15.7;7.3;23.1;24.5;8.2;Cadastre;A 1.0;POLYGON Z ((355464.1 6689321.6 23.1, 355453.6 6689320.8 23.1, 355452.1 6689328.5 23.1, 355450.4 6689328.2 23.1, 355450.2 6689329.8 23.1, 355454.6 6689330.5 23.1, 355454 6689333.3 23.1, 355461.5 6689335 23.1, 355464.1 6689321.6 23.1))
BATIMENT0000000302931243;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;;;14.2;7.7;21.9;24.8;7.7;Cadastre;A 1.0;POLYGON Z ((355421.2 6689335.7 21.9, 355426.7 6689337.8 21.9, 355429.1 6689338.8 21.9, 355431.1 6689331.6 21.9, 355428.8 6689330.8 21.9, 355429.4 6689328.6 21.9, 355422 6689325.6 21.9, 355417.7 6689334.3 21.9, 355421.2 6689335.7 21.9))
BATIMENT0000000302931242;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;01;02;17.7;7.0;24.7;28.4;7.9;Cadastre;A 1.0;POLYGON Z ((355433.2 6689340.5 24.7, 355434.7 6689335.5 24.7, 355435.2 6689335.6 24.7, 355439.5 6689325.7 24.7, 355434.7 6689324.4 24.7, 355434 6689327.6 24.7, 355430.7 6689326.3 24.7, 355429.4 6689328.6 24.7, 355428.8 6689330.8 24.7, 355431.1 6689331.6 24.7, 355429.1 6689338.8 24.7, 355433.2 6689340.5 24.7))
BATIMENT0000000302931245;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.3;7.1;26.5;29.7;7.7;Cadastre;A 1.0;POLYGON Z ((355441.8 6689344.1 26.5, 355443.2 6689336.8 26.5, 355442.4 6689336.6 26.5, 355444.6 6689327.1 26.5, 355442.5 6689326.5 26.5, 355439.5 6689325.7 26.5, 355435.2 6689335.6 26.5, 355434.7 6689335.5 26.5, 355433.2 6689340.5 26.5, 355441.8 6689344.1 26.5))
BATIMENT0000000302931249;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;7.9;22.0;;;Cadastre;;POLYGON Z ((355448.6 6689336.8 22, 355450.5 6689337.3 22, 355451.2 6689335 22, 355449.2 6689334.6 22, 355448.6 6689336.8 22))
BATIMENT0000000302927589;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;19;20;19.5;21.2;40.7;45.1;22.7;Cadastre;A 0.9;POLYGON Z ((354851.1 6689212.1 40.7, 354850.3 6689212.8 40.7, 354849.5 6689213.5 40.7, 354848.8 6689214.3 40.7, 354848.1 6689215.1 40.7, 354847.5 6689216.3 40.7, 354847 6689217.4 40.7, 354846.5 6689218.6 40.7, 354846.4 6689218.8 40.7, 354846.1 6689219.9 40.7, 354845.8 6689221.1 40.7, 354853.2 6689222.4 40.7, 354853.7 6689223.7 40.7, 354855.2 6689223.8 40.7, 354855.7 6689222.2 40.7, 354857.6 6689220.9 40.7, 354858.1 6689221.9 40.7, 354858.8 6689221.5 40.7, 354859.3 6689222.1 40.7, 354860.3 6689222.1 40.7, 354860.3 6689222.5 40.7, 354862.9 6689222.6 40.7, 354863 6689222.2 40.7, 354864.1 6689222.2 40.7, 354864.1 6689222.6 40.7, 354871.7 6689222 40.7, 354871 6689212.3 40.7, 354871.2 6689212.3 40.7, 354870.6 6689205.2 40.7, 354860.3 6689206 40.7, 354851.9 6689211.2 40.7, 354852 6689211.5 40.7, 354851.1 6689212.1 40.7))
BATIMENT0000000302928046;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;20;20;18.1;23.9;42.0;43.4;27.8;Cadastre;A 0.9;POLYGON Z ((354808.5 6689227 42, 354796.5 6689208.4 42, 354795.7 6689207.4 42, 354794.7 6689208 42, 354785.7 6689213.7 42, 354786.1 6689214.2 42, 354789.3 6689219.1 42, 354790.1 6689220.1 42, 354796.4 6689216.8 42, 354797.5 6689218.8 42, 354797.5 6689219.4 42, 354797.6 6689220.3 42, 354792.1 6689223.5 42, 354793 6689225.2 42, 354798.2 6689233.7 42, 354808.5 6689227 42))
BATIMENT0000000302927587;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;19;20;21.1;21.8;43.0;44.4;22.0;Cadastre;A 0.9;POLYGON Z ((354862.9 6689222.6 43, 354864.1 6689222.6 43, 354864.1 6689222.2 43, 354863 6689222.2 43, 354862.9 6689222.6 43))
BATIMENT0000000302927588;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;22.0;28.3;38.6;23.4;Cadastre;;POLYGON Z ((354852 6689235.8 28.3, 354854.8 6689236.2 28.3, 354854.7 6689234.6 28.3, 354857 6689234.6 28.3, 354858.1 6689229.5 28.3, 354852.7 6689228.4 28.3, 354851.4 6689234.4 28.3, 354851.2 6689234.4 28.3, 354851 6689235.6 28.3, 354852 6689235.8 28.3))
BATIMENT0000000302927586;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;18.5;22.1;40.7;42.6;24.7;Cadastre;A 1.0;POLYGON Z ((354839.7 6689251.5 40.7, 354847.7 6689253 40.7, 354848.5 6689248.9 40.7, 354848.8 6689247.2 40.7, 354849.3 6689245.4 40.7, 354849.5 6689243.8 40.7, 354849.8 6689242.3 40.7, 354849.6 6689242.3 40.7, 354849.9 6689241 40.7, 354851.1 6689241.1 40.7, 354851.1 6689240.8 40.7, 354851.1 6689240.5 40.7, 354850.9 6689240 40.7, 354851.5 6689239.3 40.7, 354851.8 6689238.9 40.7, 354851.9 6689238.5 40.7, 354852 6689238 40.7, 354852 6689237.6 40.7, 354851.8 6689237 40.7, 354851.9 6689236.7 40.7, 354852.1 6689236.3 40.7, 354852 6689235.8 40.7, 354851 6689235.6 40.7, 354851.2 6689234.4 40.7, 354851.4 6689234.4 40.7, 354852.7 6689228.4 40.7, 354853.3 6689225.5 40.7, 354853.7 6689223.7 40.7, 354853.2 6689222.4 40.7, 354845.8 6689221.1 40.7, 354839.7 6689251.5 40.7))
BATIMENT0000000302928104;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;20.2;23.5;43.8;47.2;25.2;Cadastre;A 1.0;POLYGON Z ((354830.3 6689231.3 43.8, 354830.6 6689231.3 43.8, 354831.3 6689227.4 43.8, 354828.7 6689225.7 43.8, 354828.5 6689225.3 43.8, 354824.9 6689227.5 43.8, 354825 6689227.7 43.8, 354809.2 6689237.5 43.8, 354813.1 6689243.8 43.8, 354808.3 6689246.9 43.8, 354810.3 6689248.7 43.8, 354810.8 6689249.3 43.8, 354812.4 6689250.7 43.8, 354814.2 6689252.3 43.8, 354818 6689247.5 43.8, 354827 6689249.1 43.8, 354830.3 6689231.3 43.8))
BATIMENT0000000302927591;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;23.6;36.0;37.2;24.1;Cadastre;;POLYGON Z ((354849.3 6689245.4 36, 354850.2 6689245.5 36, 354850.4 6689243.9 36, 354849.5 6689243.8 36, 354849.3 6689245.4 36))
BATIMENT0000000302927582;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.6;22.0;35.7;39.8;26.1;Cadastre;A 1.0;POLYGON Z ((354871.1 6689270.3 35.7, 354875.2 6689266 35.7, 354871.7 6689222 35.7, 354864.1 6689222.6 35.7, 354862.9 6689222.6 35.7, 354860.3 6689222.5 35.7, 354859.5 6689222.5 35.7, 354858.6 6689226.7 35.7, 354858.1 6689229.5 35.7, 354857 6689234.6 35.7, 354854.7 6689234.6 35.7, 354854.8 6689236.2 35.7, 354855.5 6689242 35.7, 354856 6689246.6 35.7, 354856.1 6689249 35.7, 354855.9 6689250.4 35.7, 354855.3 6689254.6 35.7, 354855 6689257.1 35.7, 354854.1 6689262.2 35.7, 354852.9 6689270.4 35.7, 354871.1 6689270.3 35.7))
BATIMENT0000000302928100;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;10;20;18.5;25.2;43.7;46.7;26.5;Cadastre;A 0.7;POLYGON Z ((354794.2 6689246.9 43.7, 354800.1 6689256.3 43.7, 354801.3 6689258.1 43.7, 354807.8 6689253.9 43.7, 354806.7 6689252.2 43.7, 354807 6689251.8 43.7, 354807.2 6689251.5 43.7, 354807 6689250.9 43.7, 354810.3 6689248.7 43.7, 354808.3 6689246.9 43.7, 354813.1 6689243.8 43.7, 354809.2 6689237.5 43.7, 354794.2 6689246.9 43.7))
BATIMENT0000000302927590;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;23.9;29.7;31.5;24.4;Cadastre;;POLYGON Z ((354848.5 6689248.9 29.7, 354849.5 6689249 29.7, 354849.7 6689247.4 29.7, 354848.8 6689247.2 29.7, 354848.5 6689248.9 29.7))
BATIMENT0000000302928103;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;24.8;36.0;40.2;25.2;Cadastre;;POLYGON Z ((354812.4 6689250.7 36, 354810.8 6689249.3 36, 354810 6689250.1 36, 354811.1 6689251.6 36, 354812.4 6689250.7 36))
BATIMENT0000000302927583;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;24.1;27.9;36.6;24.8;Cadastre;;POLYGON Z ((354847.7 6689253 27.9, 354855.3 6689254.6 27.9, 354855.9 6689250.4 27.9, 354849.5 6689249 27.9, 354848.5 6689248.9 27.9, 354847.7 6689253 27.9))
BATIMENT0000000302927584;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;24.4;28.0;34.5;25.1;Cadastre;;POLYGON Z ((354848 6689255.8 28, 354849.6 6689256.1 28, 354855 6689257.1 28, 354855.3 6689254.6 28, 354847.7 6689253 28, 354847.4 6689254.4 28, 354847.2 6689254.4 28, 354847 6689255.6 28, 354848 6689255.8 28))
BATIMENT0000000302928099;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;6.0;34;90;20.2;24.5;44.8;47.9;27.0;Cadastre;C 0.9;POLYGON Z ((354822.8 6689268.7 44.8, 354823.1 6689268.4 44.8, 354827 6689249.1 44.8, 354818 6689247.5 44.8, 354814.2 6689252.3 44.8, 354812.4 6689250.7 44.8, 354811.1 6689251.6 44.8, 354807.8 6689253.9 44.8, 354801.3 6689258.1 44.8, 354804 6689262.4 44.8, 354803.5 6689267.1 44.8, 354822.8 6689268.7 44.8))
BATIMENT0000000302927585;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;7.0;24.7;31.7;36.7;25.5;Cadastre;A 1.0;POLYGON Z ((354854.1 6689262.2 31.7, 354855 6689257.1 31.7, 354849.6 6689256.1 31.7, 354848.8 6689260.4 31.7, 354847.2 6689261.1 31.7, 354846 6689261 31.7, 354845.8 6689262.3 31.7, 354854.1 6689262.2 31.7))
BATIMENT0000000302927581;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;15.2;24.5;39.7;43.4;25.9;Cadastre;A 1.0;POLYGON Z ((354836.8 6689265.3 39.7, 354840.6 6689270 39.7, 354852.9 6689270.4 39.7, 354854.1 6689262.2 39.7, 354845.8 6689262.3 39.7, 354846 6689261 39.7, 354847.2 6689261.1 39.7, 354847.2 6689260.6 39.7, 354847.2 6689260.5 39.7, 354847.2 6689260.2 39.7, 354847.4 6689259.9 39.7, 354847.6 6689259.5 39.7, 354847.8 6689258.9 39.7, 354847.9 6689258.5 39.7, 354847.9 6689258.1 39.7, 354847.8 6689257.7 39.7, 354847.8 6689257.5 39.7, 354847.6 6689257.1 39.7, 354847.8 6689256.9 39.7, 354847.9 6689256.6 39.7, 354848 6689256.4 39.7, 354848 6689255.8 39.7, 354847 6689255.6 39.7, 354847.2 6689254.4 39.7, 354847.4 6689254.4 39.7, 354847.7 6689253 39.7, 354839.7 6689251.5 39.7, 354836.8 6689265.3 39.7))
BATIMENT0000000302928101;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.2;27.2;48.4;49.1;27.6;Cadastre;;POLYGON Z ((354791.4 6689262.1 48.4, 354791.4 6689261.7 48.4, 354791.4 6689260.6 48.4, 354789.7 6689260.6 48.4, 354789.6 6689262.1 48.4, 354791.4 6689262.1 48.4))
BATIMENT0000000302928098;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.6;26.1;37.7;46.2;27.6;Cadastre;A 1.0;POLYGON Z ((354803.5 6689267.1 37.7, 354804 6689262.4 37.7, 354801.3 6689258.1 37.7, 354800.1 6689256.3 37.7, 354795.2 6689259.3 37.7, 354795 6689259.9 37.7, 354793.9 6689261.9 37.7, 354793.5 6689262.2 37.7, 354793.1 6689262.5 37.7, 354793.1 6689262.8 37.7, 354792.9 6689266.2 37.7, 354803.5 6689267.1 37.7))
BATIMENT0000000302928072;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.3;27.3;41.6;;;Cadastre;;POLYGON Z ((354790.9 6689284.2 41.6, 354793.8 6689284.4 41.6, 354792 6689275.8 41.6, 354790.9 6689275.7 41.6, 354790.9 6689284.2 41.6))
BATIMENT0000000302927465;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.9;26.0;43.9;45.4;26.4;Cadastre;;POLYGON Z ((354860.4 6689277.4 43.9, 354855.6 6689277.4 43.9, 354855.7 6689286.8 43.9, 354860.5 6689287 43.9, 354860.4 6689277.4 43.9))
BATIMENT0000000302927481;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;6.0;12;20;17.9;20.3;38.2;39.7;21.9;Cadastre;A 1.0;POLYGON Z ((354978.1 6689274.8 38.2, 354979 6689266 38.2, 354978.9 6689266 38.2, 354978 6689265.9 38.2, 354978.5 6689262.9 38.2, 354978.3 6689262.9 38.2, 354975.1 6689262.6 38.2, 354975.5 6689260.4 38.2, 354978.6 6689260.9 38.2, 354981.5 6689261.3 38.2, 354981.9 6689258.4 38.2, 354975.7 6689257.5 38.2, 354975.9 6689255.2 38.2, 354976 6689254.9 38.2, 354969.4 6689254 38.2, 354969.3 6689254.2 38.2, 354968.6 6689254.1 38.2, 354966.6 6689273.4 38.2, 354978.1 6689274.8 38.2))
BATIMENT0000000302927484;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;17.8;17.6;35.5;38.6;21.0;Cadastre;A 1.0;POLYGON Z ((355000 6689277.6 35.5, 355004 6689263.8 35.5, 355005.3 6689258.8 35.5, 355003.6 6689259.6 35.5, 355002 6689259.2 35.5, 355000.6 6689266.4 35.5, 354979.1 6689263 35.5, 354978.9 6689266 35.5, 354979 6689266 35.5, 354978.1 6689274.8 35.5, 355000 6689277.6 35.5))
BATIMENT0000000302929167;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;20.6;16.7;37.3;40.6;19.1;Cadastre;A 1.0;POLYGON Z ((355025.2 6689280.7 37.3, 355027.5 6689279.1 37.3, 355030.1 6689271.4 37.3, 355022.8 6689269.7 37.3, 355021.8 6689269.8 37.3, 355015.1 6689267.7 37.3, 355015.3 6689267.2 37.3, 355004 6689263.8 37.3, 355000 6689277.6 37.3, 355025.2 6689280.7 37.3))
BATIMENT0000000302927508;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;20;16.4;21.3;37.7;40.5;23.8;Cadastre;A 1.0;POLYGON Z ((354955 6689282 37.7, 354954.9 6689285.3 37.7, 354957.4 6689285.7 37.7, 354956.2 6689296.8 37.7, 354959.7 6689297.2 37.7, 354960.2 6689293.9 37.7, 354962.2 6689294.2 37.7, 354961.8 6689297.5 37.7, 354965 6689297.9 37.7, 354967 6689283.5 37.7, 354955 6689282 37.7))
BATIMENT0000000302927504;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1981-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;;;12.3;22.1;34.4;41.8;23.7;Cadastre;A 1.0;POLYGON Z ((354948.6 6689281.2 34.4, 354945.8 6689299 34.4, 354945.4 6689301.7 34.4, 354955.5 6689303.4 34.4, 354955.8 6689300.3 34.4, 354956.2 6689296.8 34.4, 354957.4 6689285.7 34.4, 354954.9 6689285.3 34.4, 354955 6689282 34.4, 354948.6 6689281.2 34.4))
BATIMENT0000000302927516;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;22.5;33.5;35.4;23.6;Cadastre;;POLYGON Z ((354979.1 6689298.5 33.5, 354979.5 6689296.3 33.5, 354972.2 6689295.4 33.5, 354971.9 6689297.6 33.5, 354978.8 6689298.5 33.5, 354979.1 6689298.5 33.5))
BATIMENT0000000302927511;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;14.9;20.5;35.4;38.1;24.4;Cadastre;A 1.0;POLYGON Z ((354979.5 6689296.3 35.4, 354979.1 6689298.5 35.4, 354978.8 6689298.5 35.4, 354977.6 6689311.6 35.4, 354979.6 6689311.7 35.4, 354979.2 6689315.1 35.4, 354981.7 6689315.3 35.4, 354981.6 6689314.8 35.4, 354982.1 6689312.4 35.4, 354987.2 6689313.1 35.4, 354989.5 6689286.2 35.4, 354973.6 6689284.3 35.4, 354972.2 6689295.4 35.4, 354979.5 6689296.3 35.4), (354981.4 6689299.5 35.4, 354986.2 6689300 35.4, 354985.6 6689304 35.4, 354980.9 6689303.6 35.4, 354981.4 6689299.5 35.4))
BATIMENT0000000302927512;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;23.6;32.2;34.0;24.3;Cadastre;;POLYGON Z ((354985.6 6689304 32.2, 354986.2 6689300 32.2, 354981.4 6689299.5 32.2, 354980.9 6689303.6 32.2, 354985.6 6689304 32.2))
BATIMENT0000000302927509;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.8;21.6;32.4;35.4;23.9;Cadastre;A 1.0;POLYGON Z ((354967 6689283.5 32.4, 354965 6689297.9 32.4, 354961.7 6689320.9 32.4, 354976.1 6689323.5 32.4, 354977.4 6689314.9 32.4, 354977.2 6689314.8 32.4, 354977.6 6689311.6 32.4, 354978.8 6689298.5 32.4, 354971.9 6689297.6 32.4, 354972.2 6689295.4 32.4, 354973.6 6689284.3 32.4, 354967 6689283.5 32.4))
BATIMENT0000000302927514;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;10.7;19.0;29.7;40.8;25.6;Cadastre;A 1.0;POLYGON Z ((354989.5 6689286.2 29.7, 354987.2 6689313.1 29.7, 354987 6689315.5 29.7, 354986.5 6689321.6 29.7, 354996.1 6689323.3 29.7, 355003.4 6689295.7 29.7, 355009.3 6689296.5 29.7, 355011.2 6689289.3 29.7, 354989.5 6689286.2 29.7))
BATIMENT0000000302928074;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;50;20;14.4;26.8;41.2;43.7;27.2;Cadastre;A 1.0;POLYGON Z ((354805.1 6689274.8 41.2, 354805.1 6689277 41.2, 354803.2 6689289.7 41.2, 354806.4 6689290.1 41.2, 354812.8 6689290.9 41.2, 354815.6 6689275.4 41.2, 354805.1 6689274.8 41.2))
BATIMENT0000000302928073;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;30;30;17.9;26.6;44.5;46.0;27.1;Cadastre;A 1.0;POLYGON Z ((354792 6689275.8 44.5, 354793.8 6689284.4 44.5, 354800.8 6689285.2 44.5, 354800.7 6689290 44.5, 354803.2 6689290 44.5, 354803.2 6689289.7 44.5, 354805.1 6689277 44.5, 354792 6689275.8 44.5))
BATIMENT0000000302928075;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;16.9;25.8;42.7;44.0;27.1;Cadastre;A 1.0;POLYGON Z ((354822.4 6689276.3 42.7, 354822.1 6689275.8 42.7, 354815.6 6689275.4 42.7, 354812.8 6689290.9 42.7, 354819.3 6689291.9 42.7, 354822.4 6689276.3 42.7))
BATIMENT0000000302927467;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;15;20;14.9;26.0;41.0;45.0;26.5;Cadastre;A 1.0;POLYGON Z ((354860.9 6689277 41, 354860.4 6689277.4 41, 354860.5 6689287 41, 354863.2 6689287.2 41, 354862.9 6689292.7 41, 354870.5 6689293.1 41, 354872.1 6689293.1 41, 354871.4 6689276.9 41, 354860.9 6689277 41))
BATIMENT0000000302927463;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.6;25.1;41.7;44.5;27.5;Cadastre;A 1.0;POLYGON Z ((354855.7 6689286.8 41.7, 354855.6 6689277.4 41.7, 354855.1 6689276.9 41.7, 354832.8 6689276.2 41.7, 354832.1 6689276.8 41.7, 354830.9 6689283.4 41.7, 354840.5 6689285 41.7, 354840.8 6689295.3 41.7, 354845.5 6689295.9 41.7, 354845.7 6689289.4 41.7, 354855.7 6689290 41.7, 354855.7 6689286.8 41.7))
BATIMENT0000000302927464;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;12;20;15.5;25.1;40.6;44.0;27.5;Cadastre;A 1.0;POLYGON Z ((354828.5 6689295.7 40.6, 354839.9 6689297.9 40.6, 354840 6689295.7 40.6, 354840.7 6689295.7 40.6, 354840.8 6689295.3 40.6, 354840.5 6689285 40.6, 354830.9 6689283.4 40.6, 354828.5 6689295.7 40.6))
BATIMENT0000000302928070;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;;;9.3;26.9;36.2;42.2;27.7;Cadastre;A 1.0;POLYGON Z ((354784 6689306.7 36.2, 354791 6689307.1 36.2, 354805.6 6689308.9 36.2, 354806.4 6689290.1 36.2, 354803.2 6689289.7 36.2, 354803.2 6689290 36.2, 354800.7 6689290 36.2, 354794.8 6689289.7 36.2, 354791 6689289.6 36.2, 354790.9 6689284.2 36.2, 354790.9 6689275.7 36.2, 354777.5 6689274.5 36.2, 354784 6689306.7 36.2))
BATIMENT0000000302928071;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;15.1;26.5;41.6;46.2;27.2;Cadastre;A 1.0;POLYGON Z ((354819.3 6689291.9 41.6, 354812.8 6689290.9 41.6, 354806.4 6689290.1 41.6, 354805.6 6689308.9 41.6, 354815.5 6689310.5 41.6, 354819.3 6689291.9 41.6))
BATIMENT0000000302927466;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;;;12.2;25.1;37.3;41.7;27.9;Cadastre;A 1.0;POLYGON Z ((354824.9 6689313.5 37.3, 354836.9 6689314.6 37.3, 354837.2 6689312.5 37.3, 354839.1 6689312.4 37.3, 354839.9 6689297.9 37.3, 354828.5 6689295.7 37.3, 354824.9 6689313.5 37.3))
BATIMENT0000000302927460;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;;;10.9;25.3;36.2;38.7;27.9;Cadastre;A 1.0;POLYGON Z ((354854.5 6689329.4 36.2, 354855.3 6689323.9 36.2, 354855.6 6689321.6 36.2, 354855.7 6689290 36.2, 354845.7 6689289.4 36.2, 354845.5 6689295.9 36.2, 354849.5 6689296.8 36.2, 354849.2 6689315.7 36.2, 354836.9 6689314.6 36.2, 354836.2 6689319.3 36.2, 354835.9 6689321.4 36.2, 354835.3 6689325.8 36.2, 354840.2 6689326.9 36.2, 354845.4 6689327.8 36.2, 354853.2 6689329.1 36.2, 354854.5 6689329.4 36.2))
BATIMENT0000000302927480;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;23;20;8.2;22.7;31.0;40.9;23.3;Cadastre;A 1.0;POLYGON Z ((354945.8 6689270.8 31, 354947.3 6689258.7 31, 354948 6689253.5 31, 354933.7 6689254.4 31, 354934 6689259.6 31, 354930.4 6689259.8 31, 354930.5 6689263.9 31, 354934.1 6689263.8 31, 354934.3 6689269.4 31, 354945.8 6689270.8 31))
BATIMENT0000000302927472;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.5;24.1;45.7;46.6;24.6;Cadastre;;POLYGON Z ((354912.1 6689279.6 45.7, 354908.4 6689279.8 45.7, 354908.5 6689285.1 45.7, 354909 6689285.1 45.7, 354912.3 6689284.9 45.7, 354912.1 6689279.8 45.7, 354912.1 6689279.6 45.7))
BATIMENT0000000302927469;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;17.1;25.1;42.2;42.5;25.8;Cadastre;A 1.0;POLYGON Z ((354878.6 6689276.4 42.2, 354878.6 6689282.8 42.2, 354880.5 6689282.6 42.2, 354881 6689283.1 42.2, 354880.8 6689285.6 42.2, 354885.1 6689285.4 42.2, 354884.9 6689290 42.2, 354884.8 6689291.8 42.2, 354886.5 6689291.8 42.2, 354889.6 6689292 42.2, 354890.2 6689275.7 42.2, 354878.6 6689276.4 42.2))
BATIMENT0000000302927468;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;10;20;14.4;25.5;40.0;45.5;26.4;Cadastre;A 1.0;POLYGON Z ((354871.4 6689276.9 40, 354872.1 6689293.1 40, 354886.2 6689293.8 40, 354886.5 6689291.8 40, 354884.8 6689291.8 40, 354884.9 6689290 40, 354880.1 6689288.8 40, 354880.8 6689285.6 40, 354881 6689283.1 40, 354880.5 6689282.6 40, 354878.6 6689282.8 40, 354878.6 6689276.4 40, 354871.4 6689276.9 40))
BATIMENT0000000302927499;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;14.5;23.0;37.5;40.8;24.2;Cadastre;A 1.0;POLYGON Z ((354927.4 6689278.6 37.5, 354926.1 6689286.7 37.5, 354926.3 6689289.7 37.5, 354929.1 6689289.5 37.5, 354929.1 6689290.6 37.5, 354931.3 6689290.9 37.5, 354930.4 6689298.1 37.5, 354935.3 6689297.7 37.5, 354936.4 6689290.5 37.5, 354938.5 6689280 37.5, 354927.4 6689278.6 37.5))
BATIMENT0000000302927501;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;20;20;17.2;22.4;39.6;43.1;23.8;Cadastre;A 1.0;POLYGON Z ((354938.5 6689280 39.6, 354936.4 6689290.5 39.6, 354940.4 6689291 39.6, 354938.7 6689300.7 39.6, 354943.2 6689301.4 39.6, 354943.7 6689298.7 39.6, 354945.8 6689299 39.6, 354948.6 6689281.2 39.6, 354938.5 6689280 39.6))
BATIMENT0000000302927473;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;30;90;21.1;24.0;45.2;46.5;24.9;Cadastre;A 1.0;POLYGON Z ((354916.6 6689279.5 45.2, 354912.1 6689279.8 45.2, 354912.3 6689284.9 45.2, 354909 6689285.1 45.2, 354910.8 6689307.6 45.2, 354918.8 6689306.9 45.2, 354916.6 6689279.5 45.2))
BATIMENT0000000302927500;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;7.0;30;90;12.8;23.6;36.5;37.7;24.5;Cadastre;A 1.0;POLYGON Z ((354927 6689298.5 36.5, 354930.4 6689298.1 36.5, 354931.3 6689290.9 36.5, 354929.1 6689290.6 36.5, 354929.1 6689289.5 36.5, 354926.3 6689289.7 36.5, 354927 6689298.5 36.5))
BATIMENT0000000302927502;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;15.6;23.3;38.9;41.4;24.4;Cadastre;A 0.5;POLYGON Z ((354936 6689317.6 38.9, 354947.8 6689318.4 38.9, 354950.2 6689318.5 38.9, 354953.9 6689319 38.9, 354954.2 6689315.7 38.9, 354947.2 6689314.5 38.9, 354948.4 6689306.2 38.9, 354955.1 6689307.1 38.9, 354955.5 6689303.4 38.9, 354945.4 6689301.7 38.9, 354943.2 6689301.4 38.9, 354938.7 6689300.7 38.9, 354936 6689317.6 38.9))
BATIMENT0000000302927470;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;7.0;;;19.3;25.1;44.4;45.9;28.3;Cadastre;C 0.6;POLYGON Z ((354860.7 6689340.9 44.4, 354859.5 6689340.9 44.4, 354858.2 6689346.6 44.4, 354860 6689348.1 44.4, 354862.8 6689347 44.4, 354863.7 6689348.7 44.4, 354872 6689349.1 44.4, 354907.2 6689350.7 44.4, 354907.9 6689332.1 44.4, 354911.5 6689330.8 44.4, 354908.4 6689320.9 44.4, 354911.6 6689320.7 44.4, 354911 6689314.1 44.4, 354911.3 6689314 44.4, 354910.8 6689307.6 44.4, 354909 6689285.1 44.4, 354908.5 6689285.1 44.4, 354908.4 6689279.8 44.4, 354905.6 6689280 44.4, 354903.7 6689282.5 44.4, 354900.5 6689280.3 44.4, 354893.7 6689275.5 44.4, 354890.2 6689275.7 44.4, 354889.6 6689292 44.4, 354889.4 6689294 44.4, 354887.3 6689338.6 44.4, 354860.9 6689337.3 44.4, 354860.7 6689340.9 44.4))
BATIMENT0000000302928069;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;;;10.9;27.0;38.0;46.5;27.8;Cadastre;A 1.0;POLYGON Z ((354815.5 6689310.5 38, 354805.6 6689308.9 38, 354791 6689307.1 38, 354784 6689306.7 38, 354785.6 6689314 38, 354787.4 6689314.2 38, 354794.2 6689315.2 38, 354813.9 6689318.4 38, 354815.5 6689310.5 38))
BATIMENT0000000302927474;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;7.0;;;18.2;25.7;44.0;46.7;27.9;Cadastre;C 0.5;POLYGON Z ((354870.2 6689297.4 44, 354868.7 6689297.3 44, 354862.5 6689303 44, 354860.9 6689337.3 44, 354887.3 6689338.6 44, 354889.4 6689294 44, 354886.2 6689293.8 44, 354872.1 6689293.1 44, 354870.5 6689293.1 44, 354870.2 6689297.4 44))
BATIMENT0000000302927462;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;15;20;12.0;27.1;39.2;41.5;27.9;Cadastre;A 1.0;POLYGON Z ((354823 6689323.2 39.2, 354835.3 6689325.8 39.2, 354835.9 6689321.4 39.2, 354832.9 6689321.1 39.2, 354833.3 6689318.9 39.2, 354836.2 6689319.3 39.2, 354836.9 6689314.6 39.2, 354824.9 6689313.5 39.2, 354823 6689323.2 39.2))
BATIMENT0000000302928068;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;;;10.8;27.3;38.1;46.2;28.0;Cadastre;A 1.0;POLYGON Z ((354811.8 6689328.4 38.1, 354813.9 6689318.4 38.1, 354794.2 6689315.2 38.1, 354787.4 6689314.2 38.1, 354785.6 6689314 38.1, 354787.7 6689324.5 38.1, 354793.2 6689324.5 38.1, 354800.7 6689335.8 38.1, 354811.8 6689328.4 38.1))
BATIMENT0000000302927458;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;20;20;10.4;27.5;38.0;46.2;27.9;Cadastre;A 1.0;POLYGON Z ((354833.8 6689332.9 38, 354833.2 6689334.1 38, 354831.9 6689339.7 38, 354835.7 6689340.5 38, 354837.1 6689340.8 38, 354837.9 6689337.7 38, 354839.2 6689331.3 38, 354840.2 6689326.9 38, 354835.3 6689325.8 38, 354823 6689323.2 38, 354821.6 6689330 38, 354830.5 6689332.1 38, 354833.8 6689332.9 38))
BATIMENT0000000302927461;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;13.9;27.8;41.7;45.2;27.9;Cadastre;A 1.0;POLYGON Z ((354853.1 6689337.8 41.7, 354853.2 6689329.1 41.7, 354845.4 6689327.8 41.7, 354844.6 6689332.3 41.7, 354839.2 6689331.3 41.7, 354837.9 6689337.7 41.7, 354843.7 6689338.8 41.7, 354847 6689338.4 41.7, 354852.7 6689339 41.7, 354853.1 6689337.8 41.7))
BATIMENT0000000302927459;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;16;20;18.0;27.7;45.8;47.1;28.0;Cadastre;A 1.0;POLYGON Z ((354820.1 6689337.7 45.8, 354822.5 6689338.2 45.8, 354831.1 6689340 45.8, 354831.3 6689340 45.8, 354831.4 6689339.6 45.8, 354831 6689339.4 45.8, 354831.8 6689334.6 45.8, 354830.5 6689332.1 45.8, 354821.6 6689330 45.8, 354820.1 6689337.7 45.8))
BATIMENT0000000302927457;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;17.3;27.8;45.1;48.4;28.5;Cadastre;A 1.0;POLYGON Z ((354852.7 6689339 45.1, 354847 6689338.4 45.1, 354843.7 6689338.8 45.1, 354837.9 6689337.7 45.1, 354837.1 6689340.8 45.1, 354838.7 6689341.2 45.1, 354838.7 6689341.3 45.1, 354840.9 6689341 45.1, 354840.3 6689343.8 45.1, 354838.3 6689343.3 45.1, 354838 6689344.9 45.1, 354837.7 6689344.9 45.1, 354836.5 6689350.6 45.1, 354849 6689353.9 45.1, 354852.7 6689339 45.1))
BATIMENT0000000302927456;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;90;20;14.3;27.8;42.2;46.0;28.3;Cadastre;C 0.7;POLYGON Z ((354822.6 6689338.6 42.2, 354817.9 6689358.4 42.2, 354817.8 6689358.8 42.2, 354826.3 6689360.5 42.2, 354827.5 6689355.4 42.2, 354827.9 6689355.4 42.2, 354828.7 6689351.8 42.2, 354828.4 6689351.7 42.2, 354831.3 6689340 42.2, 354831.1 6689340 42.2, 354822.5 6689338.2 42.2, 354822.6 6689338.6 42.2))
BATIMENT0000000302927455;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;27.8;38.5;45.5;28.6;Cadastre;;POLYGON Z ((354835.7 6689340.5 38.5, 354831.2 6689361.5 38.5, 354834 6689362 38.5, 354834.5 6689360.1 38.5, 354836.3 6689352 38.5, 354836.5 6689350.6 38.5, 354837.7 6689344.9 38.5, 354838 6689344.9 38.5, 354838.3 6689343.3 38.5, 354838.7 6689341.3 38.5, 354838.7 6689341.2 38.5, 354837.1 6689340.8 38.5, 354835.7 6689340.5 38.5))
BATIMENT0000000302927505;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;23.4;29.2;33.0;23.9;Cadastre;;POLYGON Z ((354952.5 6689313.4 29.2, 354954.4 6689313.6 29.2, 354954.9 6689308.7 29.2, 354953.1 6689308.5 29.2, 354952.5 6689313.4 29.2))
BATIMENT0000000302927510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;23.3;32.6;34.8;23.9;Cadastre;;POLYGON Z ((354979.6 6689311.7 32.6, 354977.6 6689311.6 32.6, 354977.2 6689314.8 32.6, 354977.4 6689314.9 32.6, 354979.2 6689315.1 32.6, 354979.6 6689311.7 32.6))
BATIMENT0000000302927513;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.4;23.5;34.0;34.5;24.5;Cadastre;;POLYGON Z ((354987.2 6689313.1 34, 354982.1 6689312.4 34, 354981.6 6689314.8 34, 354987 6689315.5 34, 354987.2 6689313.1 34))
BATIMENT0000000302927515;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;;;17.0;16.9;33.9;37.2;25.6;Cadastre;A 1.0;POLYGON Z ((355024.9 6689291.2 33.9, 355011.2 6689289.3 33.9, 355009.3 6689296.5 33.9, 355003.4 6689295.7 33.9, 354996.1 6689323.3 33.9, 354994.6 6689328.8 33.9, 355000.5 6689329.8 33.9, 355008.5 6689299.7 33.9, 355011.6 6689300.3 33.9, 355005.8 6689345.3 33.9, 355018.2 6689347.2 33.9, 355024.9 6689291.2 33.9))
BATIMENT0000000302927507;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;22.1;28.2;33.2;25.6;Cadastre;;POLYGON Z ((354959.7 6689325.2 28.2, 354974.8 6689328 28.2, 354975.2 6689325.1 28.2, 354994.6 6689328.8 28.2, 354996.1 6689323.3 28.2, 354986.5 6689321.6 28.2, 354987 6689315.5 28.2, 354981.6 6689314.8 28.2, 354981.7 6689315.3 28.2, 354979.2 6689315.1 28.2, 354977.4 6689314.9 28.2, 354976.1 6689323.5 28.2, 354961.7 6689320.9 28.2, 354960.2 6689320.6 28.2, 354959.8 6689324.1 28.2, 354959.7 6689325.2 28.2))
BATIMENT0000000302931472;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;00;00;18.3;17.6;36.0;37.9;18.8;Cadastre;A 1.0;POLYGON Z ((355029.2 6689348.3 36, 355037.8 6689349.4 36, 355041.7 6689336.2 36, 355030.8 6689335 36, 355029.2 6689348.3 36))
BATIMENT0000000302927518;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.1;20.4;40.5;42.4;23.2;Cadastre;;POLYGON Z ((354995.3 6689363 40.5, 354997.8 6689349.1 40.5, 354957.5 6689343.1 40.5, 354956.2 6689355.3 40.5, 354957.6 6689355.6 40.5, 354957.5 6689357.3 40.5, 354995.3 6689363 40.5))
BATIMENT0000000302927517;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;18.5;19.0;37.5;42.1;21.8;Cadastre;A 1.0;POLYGON Z ((355015.9 6689366.2 37.5, 355018.2 6689347.2 37.5, 355005.8 6689345.3 37.5, 354998.8 6689344.3 37.5, 354997.8 6689349.1 37.5, 354995.3 6689363 37.5, 355015.9 6689366.2 37.5))
BATIMENT0000000302927569;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;7.0;;;19.3;19.4;38.7;47.4;23.3;Cadastre;A 1.0;POLYGON Z ((354977.1 6689409.9 38.7, 354978.7 6689402.8 38.7, 354984.9 6689373.5 38.7, 354985.3 6689371.5 38.7, 354966.5 6689368.4 38.7, 354964 6689370.4 38.7, 354957.2 6689406.5 38.7, 354974.1 6689409.4 38.7, 354977.1 6689409.9 38.7))
BATIMENT0000000302927571;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;19.3;30.8;40.2;20.8;Cadastre;;POLYGON Z ((354982.9 6689403.6 30.8, 354982.8 6689405 30.8, 354996.7 6689407.3 30.8, 355000.8 6689404.2 30.8, 355000.6 6689403.7 30.8, 355000.5 6689403.4 30.8, 355000.4 6689402.9 30.8, 355000.4 6689402.6 30.8, 355000.3 6689402.3 30.8, 355000.3 6689401.7 30.8, 355000.4 6689401.2 30.8, 355000.5 6689400.9 30.8, 355000.8 6689397 30.8, 355002 6689387.7 30.8, 355002.2 6689385.9 30.8, 355002.3 6689384.8 30.8, 354999.7 6689384.4 30.8, 355001 6689375.7 30.8, 354985.2 6689373.5 30.8, 354984.9 6689373.5 30.8, 354978.7 6689402.8 30.8, 354982.9 6689403.6 30.8))
BATIMENT0000000302927471;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;7.0;30;90;20.2;25.1;45.3;46.3;25.4;Cadastre;A 1.0;POLYGON Z ((354920.6 6689327.9 45.3, 354918.8 6689306.9 45.3, 354910.8 6689307.6 45.3, 354911.3 6689314 45.3, 354911 6689314.1 45.3, 354911.6 6689320.7 45.3, 354908.4 6689320.9 45.3, 354911.5 6689330.8 45.3, 354920.6 6689327.9 45.3))
BATIMENT0000000302927503;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;30;30;4.2;23.0;27.3;44.9;24.6;Cadastre;A 1.0;POLYGON Z ((354934.6 6689336.6 27.3, 354958 6689339.2 27.3, 354959.7 6689325.2 27.3, 354959.8 6689324.1 27.3, 354947.1 6689321.9 27.3, 354947.8 6689318.4 27.3, 354936 6689317.6 27.3, 354934.6 6689336.6 27.3))
BATIMENT0000000302927506;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;50;90;14.4;22.0;36.5;44.0;24.4;Cadastre;A 1.0;POLYGON Z ((354933.2 6689354.7 36.5, 354957.5 6689357.3 36.5, 354957.6 6689355.6 36.5, 354956.2 6689355.3 36.5, 354957.5 6689343.1 36.5, 354958 6689339.2 36.5, 354934.6 6689336.6 36.5, 354933.2 6689354.7 36.5))
BATIMENT0000000302927652;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;26.4;30.8;31.7;26.9;Cadastre;;POLYGON Z ((354888.1 6689361.7 30.8, 354888.5 6689363.4 30.8, 354889.7 6689363.5 30.8, 354889.8 6689361.9 30.8, 354888.1 6689361.7 30.8))
BATIMENT0000000302929112;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;12.1;24.3;36.4;39.2;26.2;Cadastre;;POLYGON Z ((354925.6 6689367.1 36.4, 354925.8 6689365.9 36.4, 354916.6 6689364.9 36.4, 354905.1 6689363.6 36.4, 354905 6689364.8 36.4, 354925.6 6689367.1 36.4))
BATIMENT0000000302927658;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;23.3;29.5;36.2;24.9;Cadastre;;POLYGON Z ((354935.1 6689373 29.5, 354935.3 6689373 29.5, 354935.5 6689373.1 29.5, 354935.7 6689373.1 29.5, 354936.1 6689373.3 29.5, 354936.8 6689373.4 29.5, 354937.4 6689370.6 29.5, 354937.2 6689370.5 29.5, 354937 6689370.5 29.5, 354936.9 6689370.4 29.5, 354936.6 6689370.2 29.5, 354936.5 6689370.1 29.5, 354936.3 6689370 29.5, 354936.2 6689369.9 29.5, 354936.1 6689369.8 29.5, 354936 6689369.6 29.5, 354935.9 6689369.4 29.5, 354931.6 6689370.8 29.5, 354931.9 6689371.1 29.5, 354932 6689371.2 29.5, 354932.1 6689371.3 29.5, 354932.6 6689371.7 29.5, 354932.9 6689371.8 29.5, 354933 6689371.9 29.5, 354933.4 6689372.1 29.5, 354933.8 6689372.4 29.5, 354933.9 6689372.4 29.5, 354934 6689372.5 29.5, 354934.2 6689372.6 29.5, 354934.6 6689372.7 29.5, 354935.1 6689373 29.5))
BATIMENT0000000302927647;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.6;27.1;37.7;39.5;27.5;Cadastre;;POLYGON Z ((354880.8 6689379.2 37.7, 354880.3 6689383.6 37.7, 354880.6 6689383.7 37.7, 354880.6 6689384.1 37.7, 354886.2 6689385.6 37.7, 354886.3 6689384.6 37.7, 354887.2 6689379.5 37.7, 354888.5 6689364.1 37.7, 354888.5 6689363.4 37.7, 354882.4 6689363.9 37.7, 354881.9 6689369.9 37.7, 354880.8 6689379.2 37.7))
BATIMENT0000000302927656;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.4;22.0;36.5;39.9;24.9;Cadastre;C 0.1;POLYGON Z ((354931.2 6689369.7 36.5, 354931.2 6689369.9 36.5, 354931.2 6689370.1 36.5, 354931.3 6689370.5 36.5, 354931.4 6689370.6 36.5, 354931.5 6689370.7 36.5, 354931.5 6689370.8 36.5, 354931.6 6689370.8 36.5, 354935.9 6689369.4 36.5, 354936 6689369.6 36.5, 354936.1 6689369.8 36.5, 354936.2 6689369.9 36.5, 354936.3 6689370 36.5, 354936.5 6689370.1 36.5, 354936.6 6689370.2 36.5, 354936.9 6689370.4 36.5, 354937 6689370.5 36.5, 354937.2 6689370.5 36.5, 354937.4 6689370.6 36.5, 354936.8 6689373.4 36.5, 354939.9 6689374.1 36.5, 354939.4 6689376.3 36.5, 354936.3 6689391.8 36.5, 354935.7 6689395.4 36.5, 354940.2 6689396.1 36.5, 354940.3 6689395.9 36.5, 354946.6 6689396.9 36.5, 354946.6 6689396.3 36.5, 354951.1 6689374.6 36.5, 354946.2 6689368 36.5, 354936.9 6689367 36.5, 354931.5 6689366.4 36.5, 354931.2 6689369.7 36.5))
BATIMENT0000000302927649;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;26.9;29.4;30.7;27.1;Cadastre;;POLYGON Z ((354887.2 6689379.5 29.4, 354886.3 6689384.6 29.4, 354895 6689386.2 29.4, 354897.8 6689386.7 29.4, 354914.3 6689389.6 29.4, 354915.2 6689384.6 29.4, 354887.2 6689379.5 29.4))
BATIMENT0000000302929224;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;24.6;28.7;29.5;25.6;Cadastre;;POLYGON Z ((354932.8 6689387.8 28.7, 354933.6 6689384 28.7, 354932.6 6689383.7 28.7, 354931.7 6689383.3 28.7, 354931.3 6689383.1 28.7, 354930.9 6689383 28.7, 354930.7 6689383 28.7, 354930.6 6689383 28.7, 354930.2 6689382.9 28.7, 354929.6 6689382.8 28.7, 354929.5 6689382.8 28.7, 354929.3 6689382.8 28.7, 354929 6689382.8 28.7, 354928.9 6689382.8 28.7, 354928.7 6689382.8 28.7, 354928.4 6689382.8 28.7, 354928.2 6689382.8 28.7, 354927.6 6689382.8 28.7, 354927.1 6689382.9 28.7, 354926.9 6689382.9 28.7, 354926.7 6689382.9 28.7, 354926.1 6689383.1 28.7, 354926 6689383.1 28.7, 354925.9 6689383.1 28.7, 354925.3 6689383.3 28.7, 354925.2 6689383.3 28.7, 354924.8 6689383.4 28.7, 354924.6 6689383.5 28.7, 354924.4 6689383.5 28.7, 354923.8 6689383.6 28.7, 354923.7 6689383.6 28.7, 354923.5 6689383.6 28.7, 354923 6689383.7 28.7, 354922.8 6689383.7 28.7, 354922.4 6689383.7 28.7, 354922.1 6689383.7 28.7, 354922 6689383.7 28.7, 354921.9 6689383.7 28.7, 354921.2 6689383.6 28.7, 354920.9 6689383.6 28.7, 354920.5 6689383.5 28.7, 354920.2 6689384.5 28.7, 354915.4 6689383.6 28.7, 354915.2 6689384.6 28.7, 354932.8 6689387.8 28.7))
BATIMENT0000000302928327;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;12;20;17.2;28.0;45.2;48.0;29.0;Cadastre;A 1.0;POLYGON Z ((354792.1 6689364.1 45.2, 354794.2 6689367.5 45.2, 354794.7 6689367.2 45.2, 354797.9 6689372.2 45.2, 354797.6 6689372.5 45.2, 354800.2 6689376.6 45.2, 354804 6689374.1 45.2, 354809.7 6689344.8 45.2, 354806.1 6689342.2 45.2, 354786.3 6689355.4 45.2, 354792.1 6689364.1 45.2), (354793.9 6689357.1 45.2, 354795.2 6689359.2 45.2, 354794.4 6689361.6 45.2, 354792.2 6689358.2 45.2, 354793.9 6689357.1 45.2))
BATIMENT0000000302927646;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;26.6;39.2;40.0;28.3;Cadastre;;POLYGON Z ((354882.4 6689363.9 39.2, 354888.5 6689363.4 39.2, 354888.1 6689361.7 39.2, 354863.8 6689358.7 39.2, 354861.3 6689360.4 39.2, 354860.6 6689364.2 39.2, 354870.7 6689366.3 39.2, 354870.7 6689368.4 39.2, 354881.9 6689369.9 39.2, 354882.4 6689363.9 39.2))
BATIMENT0000000302927454;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;15.7;28.2;43.9;50.6;28.8;Cadastre;A 1.0;POLYGON Z ((354815.9 6689358.5 43.9, 354811.9 6689378.3 43.9, 354814 6689381.4 43.9, 354813.8 6689381.5 43.9, 354818.8 6689388.6 43.9, 354828.2 6689380.9 43.9, 354830.5 6689379 43.9, 354826.5 6689372.2 43.9, 354827.7 6689366.6 43.9, 354835.2 6689368.1 43.9, 354833.2 6689377 43.9, 354837.9 6689378.1 43.9, 354839.1 6689373.1 43.9, 354844 6689374.2 43.9, 354849 6689353.9 43.9, 354836.5 6689350.6 43.9, 354836.3 6689352 43.9, 354837.8 6689352.3 43.9, 354836.3 6689360.3 43.9, 354834.5 6689360.1 43.9, 354834 6689362 43.9, 354831.2 6689361.5 43.9, 354826.3 6689360.5 43.9, 354817.8 6689358.8 43.9, 354815.9 6689358.5 43.9))
BATIMENT0000000302927645;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.3;27.2;32.5;39.6;28.3;Cadastre;A 0.4;POLYGON Z ((354856.9 6689363.5 32.5, 354854 6689374.7 32.5, 354868.7 6689377.6 32.5, 354869 6689376.9 32.5, 354870.5 6689377.2 32.5, 354870.5 6689377.1 32.5, 354879 6689378.9 32.5, 354880.8 6689379.2 32.5, 354881.9 6689369.9 32.5, 354870.7 6689368.4 32.5, 354870.7 6689366.3 32.5, 354860.6 6689364.2 32.5, 354861.3 6689360.4 32.5, 354856.9 6689363.5 32.5))
BATIMENT0000000302927452;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.8;28.1;41.0;43.6;28.5;Cadastre;A 1.0;POLYGON Z ((354844 6689374.2 41, 354839.1 6689373.1 41, 354837.9 6689378.1 41, 354842.6 6689379.3 41, 354844 6689374.2 41))
BATIMENT0000000302929222;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;26.9;30.8;35.7;27.5;Cadastre;;POLYGON Z ((354875.7 6689383 30.8, 354878.4 6689383.4 30.8, 354879 6689378.9 30.8, 354870.5 6689377.1 30.8, 354870.5 6689377.2 30.8, 354870 6689380.3 30.8, 354869.8 6689381.8 30.8, 354875.7 6689383 30.8))
BATIMENT0000000302927453;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;11.3;28.1;39.5;42.7;28.8;Cadastre;A 1.0;POLYGON Z ((354820.2 6689390.9 39.5, 354820.4 6689390.8 39.5, 354822.5 6689393.7 39.5, 354838.2 6689396.6 39.5, 354843.6 6689379.5 39.5, 354842.6 6689379.3 39.5, 354837.9 6689378.1 39.5, 354833.2 6689377 39.5, 354831.9 6689376.5 39.5, 354831.4 6689376.8 39.5, 354830.9 6689378.7 39.5, 354830.5 6689379 39.5, 354833 6689379.5 39.5, 354832.6 6689380.3 39.5, 354832 6689381.4 39.5, 354831.6 6689383.2 39.5, 354830.3 6689383 39.5, 354830.5 6689381.6 39.5, 354828.2 6689380.9 39.5, 354818.8 6689388.6 39.5, 354820.2 6689390.9 39.5))
BATIMENT0000000302929223;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;;;17.6;27.6;45.2;48.8;28.3;Cadastre;C 0.8;POLYGON Z ((354879.3 6689403.7 45.2, 354880.7 6689396.1 45.2, 354881.5 6689391.5 45.2, 354876.8 6689390.8 45.2, 354876.7 6689391.2 45.2, 354874.6 6689390.8 45.2, 354875.2 6689385.7 45.2, 354875.7 6689383 45.2, 354869.8 6689381.8 45.2, 354867.7 6689381.4 45.2, 354851 6689378.6 45.2, 354846.4 6689395.6 45.2, 354848.2 6689398.3 45.2, 354879.3 6689403.7 45.2))
BATIMENT0000000302927604;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;;;15.0;28.2;43.3;47.5;29.1;Cadastre;A 1.0;POLYGON Z ((354821.8 6689403.4 43.3, 354818.2 6689406.1 43.3, 354818 6689405.8 43.3, 354807.3 6689413.3 43.3, 354807.4 6689413.8 43.3, 354803.8 6689416.3 43.3, 354802.8 6689421.5 43.3, 354807.4 6689422.7 43.3, 354811.6 6689426.2 43.3, 354811.4 6689428.5 43.3, 354814.7 6689429.3 43.3, 354815.4 6689429 43.3, 354824.6 6689435.4 43.3, 354827 6689430.2 43.3, 354817.5 6689425.3 43.3, 354816.2 6689423.2 43.3, 354819.3 6689421.2 43.3, 354819.7 6689421.8 43.3, 354823 6689419.6 43.3, 354823.3 6689418.6 43.3, 354823 6689417.6 43.3, 354823.6 6689417.1 43.3, 354822.1 6689414.9 43.3, 354823.5 6689413.9 43.3, 354824.3 6689415 43.3, 354825.8 6689415.3 43.3, 354825.7 6689415.5 43.3, 354825.7 6689415.8 43.3, 354825.6 6689416 43.3, 354825.6 6689416.3 43.3, 354825.6 6689416.6 43.3, 354825.7 6689416.9 43.3, 354825.7 6689417.1 43.3, 354825.8 6689417.4 43.3, 354825.9 6689417.6 43.3, 354826 6689417.8 43.3, 354826.1 6689418 43.3, 354826.2 6689418.1 43.3, 354826.3 6689418.3 43.3, 354826.4 6689418.4 43.3, 354826.7 6689418.7 43.3, 354827.1 6689418.8 43.3, 354827.2 6689418.9 43.3, 354823.8 6689425.4 43.3, 354823.9 6689426.7 43.3, 354828.1 6689428.2 43.3, 354836.1 6689406 43.3, 354821.8 6689403.4 43.3))
BATIMENT0000000302927602;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;15.6;27.7;43.4;46.4;28.5;Cadastre;A 1.0;POLYGON Z ((354836.1 6689406 43.4, 354828.1 6689428.2 43.4, 354829.8 6689428.9 43.4, 354828.9 6689431 43.4, 354828.7 6689431.8 43.4, 354841.3 6689433.2 43.4, 354842.6 6689426.6 43.4, 354842.2 6689426.5 43.4, 354832.9 6689425.5 43.4, 354834.2 6689420.1 43.4, 354836.2 6689420.3 43.4, 354836.5 6689417.7 43.4, 354842.7 6689418.8 43.4, 354847.5 6689419.6 43.4, 354849.4 6689408.4 43.4, 354836.1 6689406 43.4))
BATIMENT0000000302929225;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;24.4;29.4;30.0;25.6;Cadastre;;POLYGON Z ((354919.1 6689390.5 29.4, 354931.2 6689392.6 29.4, 354931.5 6689391 29.4, 354932.2 6689391.1 29.4, 354932.8 6689387.8 29.4, 354915.2 6689384.6 29.4, 354914.3 6689389.6 29.4, 354919.1 6689390.5 29.4))
BATIMENT0000000302927650;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;25.2;30.7;39.7;26.3;Cadastre;;POLYGON Z ((354918.5 6689393.4 30.7, 354919.1 6689390.5 30.7, 354914.3 6689389.6 30.7, 354897.8 6689386.7 30.7, 354897.3 6689389.6 30.7, 354918.5 6689393.4 30.7))
BATIMENT0000000302927648;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;10;30;16.9;26.0;43.0;50.7;27.3;Cadastre;A 1.0;POLYGON Z ((354894.5 6689389.2 43, 354875.2 6689385.7 43, 354874.6 6689390.8 43, 354876.7 6689391.2 43, 354876.8 6689390.8 43, 354881.5 6689391.5 43, 354880.7 6689396.1 43, 354881.2 6689396.2 43, 354895.6 6689398.7 43, 354897.3 6689389.6 43, 354897.8 6689386.7 43, 354895 6689386.2 43, 354894.5 6689389.2 43))
BATIMENT0000000302927655;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;23.8;30.0;39.7;24.8;Cadastre;;POLYGON Z ((354933.3 6689393 30, 354933 6689395 30, 354933.8 6689395.1 30, 354935.7 6689395.4 30, 354936.3 6689391.8 30, 354935.1 6689391.5 30, 354932.2 6689391.1 30, 354931.5 6689391 30, 354931.2 6689392.6 30, 354933.3 6689393 30))
BATIMENT0000000302927653;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;24.1;29.5;41.0;25.5;Cadastre;;POLYGON Z ((354933 6689395 29.5, 354933.3 6689393 29.5, 354931.2 6689392.6 29.5, 354919.1 6689390.5 29.5, 354918.5 6689393.4 29.5, 354933.5 6689396.1 29.5, 354933.8 6689395.1 29.5, 354933 6689395 29.5))
BATIMENT0000000302927651;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;7.0;20;30;22.6;25.1;47.7;50.1;26.2;Cadastre;A 0.3;POLYGON Z ((354917 6689402.5 47.7, 354918.5 6689393.4 47.7, 354897.3 6689389.6 47.7, 354895.6 6689398.7 47.7, 354917 6689402.5 47.7))
BATIMENT0000000302927654;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;20;30;22.2;24.2;46.5;49.6;25.4;Cadastre;A 1.0;POLYGON Z ((354932 6689405.1 46.5, 354932.4 6689405.1 46.5, 354932.9 6689402.3 46.5, 354932.9 6689400.5 46.5, 354933.1 6689398.1 46.5, 354933.5 6689396.1 46.5, 354918.5 6689393.4 46.5, 354917 6689402.5 46.5, 354932 6689405.1 46.5))
BATIMENT0000000302927657;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;12;20;21.0;22.9;44.0;46.8;24.5;Cadastre;A 1.0;POLYGON Z ((354931.1 6689412.8 44, 354947 6689415.7 44, 354950.7 6689397.5 44, 354946.6 6689396.9 44, 354940.3 6689395.9 44, 354940.2 6689396.1 44, 354935.7 6689395.4 44, 354933.8 6689395.1 44, 354933.5 6689396.1 44, 354933.1 6689398.1 44, 354932.9 6689400.5 44, 354932.9 6689402.3 44, 354932.4 6689405.1 44, 354931.1 6689412.8 44))
BATIMENT0000000302927612;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;35;90;21.8;25.9;47.7;51.2;27.3;Cadastre;A 1.0;POLYGON Z ((354870.7 6689419.9 47.7, 354870.2 6689419.8 47.7, 354869.1 6689425.9 47.7, 354868.7 6689425.8 47.7, 354868.7 6689426.1 47.7, 354869.6 6689426 47.7, 354868.1 6689433.4 47.7, 354882 6689435.7 47.7, 354882.8 6689431.8 47.7, 354893.5 6689433.6 47.7, 354895.2 6689424.2 47.7, 354870.7 6689419.9 47.7))
BATIMENT0000000302927621;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.7;24.4;41.2;43.5;25.0;Cadastre;;POLYGON Z ((354919.9 6689428.8 41.2, 354919.1 6689434.3 41.2, 354923.6 6689434.9 41.2, 354924.3 6689429.5 41.2, 354919.9 6689428.8 41.2))
BATIMENT0000000302930961;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;20;20;18.4;7.5;26.0;30.7;9.9;Cadastre;A 1.0;POLYGON Z ((355111.9 6689238.9 26, 355111.7 6689239 26, 355111.7 6689239.5 26, 355112.8 6689245.6 26, 355113.8 6689248.8 26, 355114.5 6689248.6 26, 355150.8 6689236.3 26, 355148.3 6689226.5 26, 355132.2 6689232.2 26, 355111.9 6689238.9 26), (355137.3 6689235 26, 355136.9 6689238 26, 355134.8 6689238.8 26, 355133.5 6689238.7 26, 355131.8 6689236.9 26, 355137.3 6689235 26))
BATIMENT0000000302931035;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;00;00;18.5;9.0;27.5;;;Cadastre;A 1.0;POLYGON Z ((355180.4 6689237 27.5, 355176 6689238.3 27.5, 355181 6689245.9 27.5, 355182.6 6689244.3 27.5, 355183.9 6689246.1 27.5, 355185.5 6689244.3 27.5, 355185.9 6689243.9 27.5, 355181.2 6689238 27.5, 355180.4 6689237 27.5))
BATIMENT0000000302930970;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;12;20;14.9;7.5;22.5;27.0;10.6;Cadastre;A 1.0;POLYGON Z ((355150.8 6689236.3 22.5, 355114.5 6689248.6 22.5, 355115 6689250.8 22.5, 355116.1 6689254.2 22.5, 355121.3 6689252.4 22.5, 355136.2 6689247.2 22.5, 355139.3 6689246 22.5, 355152.2 6689241.5 22.5, 355150.8 6689236.3 22.5))
BATIMENT0000000302931041;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.0;8.1;29.1;29.9;8.5;Cadastre;;POLYGON Z ((355182.6 6689244.3 29.1, 355181 6689245.9 29.1, 355182.3 6689247.9 29.1, 355183.9 6689246.1 29.1, 355182.6 6689244.3 29.1))
BATIMENT0000000302931040;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;6.0;;;17.6;8.6;26.2;;;Cadastre;A 1.0;POLYGON Z ((355164 6689243.1 26.2, 355163.7 6689243.8 26.2, 355167.7 6689255.1 26.2, 355176.3 6689248.4 26.2, 355171.9 6689240 26.2, 355164 6689243.1 26.2))
BATIMENT0000000302930969;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;14.3;7.6;22.0;27.4;10.0;Cadastre;A 1.0;POLYGON Z ((355121.3 6689252.4 22, 355122.8 6689256.6 22, 355127.8 6689255.3 22, 355131.6 6689254.2 22, 355131.7 6689254.5 22, 355139.8 6689251.5 22, 355138.4 6689250.5 22, 355129.6 6689253.5 22, 355129.1 6689252.2 22, 355130.1 6689252.1 22, 355137.2 6689249.6 22, 355138 6689249.4 22, 355140.2 6689248.3 22, 355141.1 6689251.1 22, 355144.8 6689249.8 22, 355144.9 6689249.4 22, 355153.9 6689246.1 22, 355152.2 6689241.5 22, 355139.3 6689246 22, 355136.2 6689247.2 22, 355121.3 6689252.4 22))
BATIMENT0000000302931039;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;;;20.3;7.8;28.2;30.5;8.5;Cadastre;A 1.0;POLYGON Z ((355171.9 6689240 28.2, 355176.3 6689248.4 28.2, 355167.7 6689255.1 28.2, 355169.8 6689261.1 28.2, 355178.3 6689252.2 28.2, 355181.8 6689248.4 28.2, 355182.3 6689247.9 28.2, 355181 6689245.9 28.2, 355176 6689238.3 28.2, 355171.9 6689240 28.2))
BATIMENT0000000302931038;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.9;8.2;29.2;30.5;8.5;Cadastre;;POLYGON Z ((355178.3 6689252.2 29.2, 355179.1 6689252.9 29.2, 355182.6 6689249.2 29.2, 355181.8 6689248.4 29.2, 355178.3 6689252.2 29.2))
BATIMENT0000000302930974;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;19;30;14.6;7.9;22.5;25.0;9.1;Cadastre;A 1.0;POLYGON Z ((355157.9 6689256.2 22.5, 355156 6689251.4 22.5, 355144.8 6689256.3 22.5, 355146.7 6689260.7 22.5, 355157.9 6689256.2 22.5))
BATIMENT0000000302931037;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;20;20;22.0;8.2;30.2;34.5;8.8;Cadastre;A 1.0;POLYGON Z ((355172.3 6689268 30.2, 355191.7 6689247.5 30.2, 355185.5 6689244.3 30.2, 355183.9 6689246.1 30.2, 355182.3 6689247.9 30.2, 355181.8 6689248.4 30.2, 355182.6 6689249.2 30.2, 355179.1 6689252.9 30.2, 355178.3 6689252.2 30.2, 355169.8 6689261.1 30.2, 355172.3 6689268 30.2))
BATIMENT0000000302931033;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;;;22.5;7.6;30.2;32.4;8.6;Cadastre;A 1.0;POLYGON Z ((355203.4 6689231.4 30.2, 355202.8 6689230.9 30.2, 355200.2 6689228.4 30.2, 355199.4 6689227.9 30.2, 355181.2 6689238 30.2, 355185.9 6689243.9 30.2, 355185.5 6689244.3 30.2, 355191.7 6689247.5 30.2, 355195.5 6689249.3 30.2, 355203.4 6689231.4 30.2))
BATIMENT0000000302931077;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;7.8;19.7;22.7;8.1;Cadastre;;POLYGON Z ((355234.3 6689244.5 19.7, 355234.9 6689244.5 19.7, 355235.1 6689244.6 19.7, 355239.7 6689239.3 19.7, 355237.1 6689237.6 19.7, 355233.1 6689243.8 19.7, 355234.3 6689244.5 19.7))
BATIMENT0000000302931081;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.9;7.8;17.7;18.7;8.1;Cadastre;;POLYGON Z ((355235.1 6689244.6 17.7, 355235.9 6689244.8 17.7, 355236.5 6689244.1 17.7, 355237.4 6689244.5 17.7, 355240.6 6689239.9 17.7, 355239.7 6689239.3 17.7, 355235.1 6689244.6 17.7))
BATIMENT0000000302931096;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.4;8.3;24.7;28.5;9.0;Cadastre;;POLYGON Z ((355211.6 6689247.1 24.7, 355209.7 6689245.6 24.7, 355207.8 6689248 24.7, 355209.8 6689249.4 24.7, 355211.6 6689247.1 24.7))
BATIMENT0000000302931078;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.7;7.2;24.0;26.3;8.2;Cadastre;C 0.7;POLYGON Z ((355238.3 6689248.6 24, 355238.1 6689249 24, 355234.7 6689254.1 24, 355243.5 6689260 24, 355245.3 6689259.7 24, 355247.2 6689259.1 24, 355262.5 6689235.9 24, 355262.3 6689235.7 24, 355257.8 6689242 24, 355248.9 6689254.2 24, 355237.7 6689246.5 24, 355237.3 6689245.9 24, 355236.8 6689245.3 24, 355235.9 6689245 24, 355235.1 6689244.6 24, 355234.9 6689244.9 24, 355234.2 6689245.8 24, 355235 6689246.3 24, 355238.3 6689248.6 24))
BATIMENT0000000302931079;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;;;22.3;7.9;30.2;34.5;9.0;Cadastre;C 0.2;POLYGON Z ((355211.6 6689247.1 30.2, 355209.8 6689249.4 30.2, 355204.3 6689256.3 30.2, 355213.6 6689263 30.2, 355215.6 6689264.3 30.2, 355218 6689265.6 30.2, 355219.5 6689263.1 30.2, 355221.3 6689264.4 30.2, 355227.2 6689256.5 30.2, 355234.7 6689246.7 30.2, 355235 6689246.3 30.2, 355234.2 6689245.8 30.2, 355233.1 6689244.9 30.2, 355232.6 6689244.4 30.2, 355231.8 6689243.9 30.2, 355232.2 6689243.3 30.2, 355221.3 6689235 30.2, 355211.6 6689247.1 30.2))
BATIMENT0000000302931034;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;10;23;21.5;8.4;30.0;34.7;8.9;Cadastre;C 1.0;POLYGON Z ((355174.2 6689273.4 30, 355177.2 6689273.1 30, 355180.3 6689273 30, 355182.3 6689273.2 30, 355184.6 6689273.6 30, 355186.8 6689268.8 30, 355186.6 6689268.8 30, 355189.2 6689262.7 30, 355189.5 6689262.7 30, 355195.5 6689249.3 30, 355191.7 6689247.5 30, 355172.3 6689268 30, 355174.2 6689273.4 30))
BATIMENT0000000302931097;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;6.0;;;22.5;8.4;31.0;34.1;9.1;Cadastre;A 1.0;POLYGON Z ((355199.5 6689262.3 31, 355199.2 6689262.2 31, 355192.8 6689270.4 31, 355192.3 6689271.8 31, 355208.2 6689278.3 31, 355212.1 6689268.6 31, 355215.6 6689264.3 31, 355213.6 6689263 31, 355204.3 6689256.3 31, 355199.5 6689262.3 31))
BATIMENT0000000302931004;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;22.7;7.6;30.3;34.0;8.0;Cadastre;C 0.1;POLYGON Z ((355261.8 6689276 30.3, 355262 6689276.1 30.3, 355267.8 6689266.8 30.3, 355255.4 6689258.4 30.3, 355249.3 6689268.5 30.3, 355252.3 6689270.4 30.3, 355248.3 6689277.2 30.3, 355257.9 6689282.8 30.3, 355261.8 6689276 30.3))
BATIMENT0000000302931095;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;22.6;8.1;30.7;33.9;8.6;Cadastre;A 1.0;POLYGON Z ((355226.8 6689285.9 30.7, 355231.9 6689277.4 30.7, 355228 6689275 30.7, 355227.8 6689275.1 30.7, 355216.4 6689268.5 30.7, 355218 6689265.6 30.7, 355215.6 6689264.3 30.7, 355212.1 6689268.6 30.7, 355208.2 6689278.3 30.7, 355226.8 6689285.9 30.7))
BATIMENT0000000302930986;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;6.0;;;14.3;12.6;26.9;31.4;13.3;Cadastre;A 1.0;POLYGON Z ((355094 6689261.2 26.9, 355094.6 6689260.3 26.9, 355092.5 6689246.8 26.9, 355088 6689247.5 26.9, 355087.5 6689244.2 26.9, 355092.1 6689243.5 26.9, 355090.9 6689235.1 26.9, 355087.7 6689233.5 26.9, 355082 6689234.4 26.9, 355082 6689256.2 26.9, 355094 6689261.2 26.9))
BATIMENT0000000302930964;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;;;17.5;9.7;27.2;33.7;12.3;Cadastre;A 1.0;POLYGON Z ((355098.2 6689233.8 27.2, 355098.1 6689234 27.2, 355096.1 6689234.6 27.2, 355095.1 6689235.8 27.2, 355095.2 6689237.3 27.2, 355095.3 6689237.9 27.2, 355095.2 6689238 27.2, 355096.5 6689247.5 27.2, 355099.1 6689264.5 27.2, 355112.9 6689270.3 27.2, 355110.9 6689259.3 27.2, 355106.5 6689259.8 27.2, 355105.5 6689252.8 27.2, 355107.1 6689252.5 27.2, 355107.1 6689252.3 27.2, 355106.9 6689250.7 27.2, 355112.5 6689250 27.2, 355112.5 6689247.8 27.2, 355110.6 6689248.1 27.2, 355109.3 6689239.9 27.2, 355111.7 6689239.5 27.2, 355111.7 6689239 27.2, 355111.9 6689238.9 27.2, 355110.1 6689230.4 27.2, 355098.2 6689233.8 27.2))
BATIMENT0000000302930792;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;;;20.4;14.7;35.1;39.2;16.2;Cadastre;A 1.0;POLYGON Z ((355042.1 6689249.5 35.1, 355041.1 6689249.8 35.1, 355038.3 6689262.4 35.1, 355039.5 6689262.9 35.1, 355039.7 6689262.5 35.1, 355051.9 6689266.5 35.1, 355053.8 6689254.6 35.1, 355042.1 6689249.5 35.1))
BATIMENT0000000302930793;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;21.7;13.5;35.2;38.2;15.6;Cadastre;A 1.0;POLYGON Z ((355053.8 6689254.6 35.2, 355051.9 6689266.5 35.2, 355063.5 6689270.1 35.2, 355063.3 6689270.8 35.2, 355070.3 6689273.9 35.2, 355071.2 6689261.9 35.2, 355053.8 6689254.6 35.2))
BATIMENT0000000302930795;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;16.3;12.9;29.2;35.9;16.6;Cadastre;A 1.0;POLYGON Z ((355071.2 6689261.9 29.2, 355070.3 6689273.9 29.2, 355067.8 6689283.6 29.2, 355059.5 6689281.5 29.2, 355057.9 6689284.4 29.2, 355066.6 6689287.3 29.2, 355067.2 6689285.6 29.2, 355071 6689286.4 29.2, 355072.7 6689279.6 29.2, 355072.9 6689278.8 29.2, 355073.7 6689276 29.2, 355076.6 6689276.8 29.2, 355075.8 6689279.6 29.2, 355080.6 6689280.9 29.2, 355084.1 6689267.5 29.2, 355071.2 6689261.9 29.2))
BATIMENT0000000302930798;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.8;14.8;32.6;;;Cadastre;;POLYGON Z ((355072.9 6689278.8 32.6, 355075.8 6689279.6 32.6, 355076.6 6689276.8 32.6, 355073.7 6689276 32.6, 355072.9 6689278.8 32.6))
BATIMENT0000000302930796;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;20.4;12.1;32.5;35.6;15.3;Cadastre;A 1.0;POLYGON Z ((355084.1 6689267.5 32.5, 355080.6 6689280.9 32.5, 355079 6689287.5 32.5, 355084.7 6689288.3 32.5, 355085.4 6689284.2 32.5, 355092.7 6689285.6 32.5, 355092.8 6689285.3 32.5, 355093.2 6689282.8 32.5, 355094 6689278.3 32.5, 355094.6 6689276.1 32.5, 355101 6689276 32.5, 355101 6689274.9 32.5, 355084.1 6689267.5 32.5))
BATIMENT0000000302930794;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;17.1;15.3;32.5;38.2;17.8;Cadastre;C 0.1;POLYGON Z ((355039.4 6689264.2 32.5, 355036.5 6689288.5 32.5, 355050.3 6689297.4 32.5, 355057.9 6689284.4 32.5, 355059.5 6689281.5 32.5, 355063.3 6689270.8 32.5, 355063.5 6689270.1 32.5, 355051.9 6689266.5 32.5, 355039.7 6689262.5 32.5, 355039.5 6689262.9 32.5, 355039.4 6689264.2 32.5))
BATIMENT0000000302930801;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;18.4;11.5;30.0;31.7;14.2;Cadastre;C 0.2;POLYGON Z ((355094.6 6689276.1 30, 355094 6689278.3 30, 355093.2 6689282.8 30, 355092.8 6689285.3 30, 355093.2 6689285.4 30, 355096 6689285.4 30, 355095.9 6689289.4 30, 355109.2 6689290.3 30, 355109.1 6689289.2 30, 355103.6 6689288.3 30, 355103.7 6689286.6 30, 355105.6 6689286.4 30, 355106.2 6689285.8 30, 355106.2 6689283.9 30, 355108.9 6689283.7 30, 355109.1 6689283.6 30, 355108.9 6689278.3 30, 355101 6689274.9 30, 355101 6689276 30, 355094.6 6689276.1 30))
BATIMENT0000000302930800;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.7;14.8;30.5;;;Cadastre;;POLYGON Z ((355093.3 6689289.2 30.5, 355094.4 6689289.3 30.5, 355095.9 6689289.4 30.5, 355096 6689285.4 30.5, 355093.2 6689285.4 30.5, 355093.3 6689289.2 30.5))
BATIMENT0000000302930973;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;18.0;7.8;25.8;28.7;9.7;Cadastre;A 1.0;POLYGON Z ((355146.7 6689260.7 25.8, 355144.8 6689256.3 25.8, 355156 6689251.4 25.8, 355153.9 6689246.1 25.8, 355144.9 6689249.4 25.8, 355144.8 6689249.8 25.8, 355141.1 6689251.1 25.8, 355139.8 6689251.5 25.8, 355131.7 6689254.5 25.8, 355135.6 6689266.6 25.8, 355146.7 6689260.7 25.8))
BATIMENT0000000302930972;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.9;8.5;18.5;21.7;10.0;Cadastre;A 1.0;POLYGON Z ((355124.2 6689260.3 18.5, 355124.4 6689260.2 18.5, 355127.2 6689259.1 18.5, 355128.8 6689258.3 18.5, 355127.8 6689255.3 18.5, 355122.8 6689256.6 18.5, 355124.2 6689260.3 18.5))
BATIMENT0000000302930968;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;13.0;8.4;21.5;27.0;10.2;Cadastre;C 0.2;POLYGON Z ((355135.6 6689266.6 21.5, 355131.7 6689254.5 21.5, 355131.6 6689254.2 21.5, 355127.8 6689255.3 21.5, 355128.8 6689258.3 21.5, 355127.2 6689259.1 21.5, 355128.8 6689262.6 21.5, 355127.8 6689262.9 21.5, 355129.8 6689269.4 21.5, 355135.6 6689266.6 21.5))
BATIMENT0000000302930966;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;15.8;9.1;25.0;27.5;11.0;Cadastre;A 1.0;POLYGON Z ((355129.8 6689269.4 25, 355127.8 6689262.9 25, 355123.8 6689263.8 25, 355123.3 6689262.5 25, 355124.3 6689260.9 25, 355124.5 6689260.6 25, 355124.4 6689260.2 25, 355124.2 6689260.3 25, 355122.8 6689256.6 25, 355121.3 6689252.4 25, 355116.1 6689254.2 25, 355114.5 6689254.7 25, 355115.4 6689258.2 25, 355115.6 6689258.1 25, 355118.7 6689267.4 25, 355122.8 6689266.2 25, 355123.3 6689268.9 25, 355124.3 6689268.9 25, 355124.7 6689271.9 25, 355129.8 6689269.4 25))
BATIMENT0000000302930965;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;5.0;;;18.8;9.8;28.7;30.9;11.6;Cadastre;A 1.0;POLYGON Z ((355120.8 6689273.7 28.7, 355118.7 6689267.4 28.7, 355115.6 6689258.1 28.7, 355115.4 6689258.2 28.7, 355112.2 6689258.3 28.7, 355111.6 6689255.9 28.7, 355110.8 6689255.6 28.7, 355111.6 6689254.4 28.7, 355114.4 6689254.4 28.7, 355114.5 6689254.7 28.7, 355116.1 6689254.2 28.7, 355115 6689250.8 28.7, 355112.3 6689251.4 28.7, 355112.2 6689251.3 28.7, 355107.1 6689252.3 28.7, 355107.1 6689252.5 28.7, 355105.5 6689252.8 28.7, 355106.5 6689259.8 28.7, 355110.9 6689259.3 28.7, 355112.9 6689270.3 28.7, 355120.8 6689273.7 28.7))
BATIMENT0000000302930967;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.9;10.0;27.0;28.9;11.3;Cadastre;A 1.0;POLYGON Z ((355124.7 6689271.9 27, 355124.3 6689268.9 27, 355123.3 6689268.9 27, 355122.8 6689266.2 27, 355118.7 6689267.4 27, 355120.8 6689273.7 27, 355124.7 6689271.9 27))
BATIMENT0000000302930832;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;22.0;8.6;30.7;32.9;10.7;Cadastre;A 1.0;POLYGON Z ((355133.6 6689271.5 30.7, 355133.5 6689271.4 30.7, 355128.8 6689273.5 30.7, 355128.7 6689276.8 30.7, 355133.3 6689279 30.7, 355133.4 6689278.8 30.7, 355145.6 6689284.2 30.7, 355145.5 6689284.4 30.7, 355150.1 6689286.4 30.7, 355150.8 6689285.4 30.7, 355151.1 6689285.1 30.7, 355151.2 6689284.9 30.7, 355151.8 6689284.1 30.7, 355152.3 6689283.4 30.7, 355152.7 6689282.9 30.7, 355153 6689282.6 30.7, 355153.1 6689282.5 30.7, 355153.3 6689282.3 30.7, 355153.7 6689281.8 30.7, 355154 6689281.5 30.7, 355154.1 6689281.4 30.7, 355154.4 6689281.1 30.7, 355154.7 6689280.8 30.7, 355155.1 6689280.4 30.7, 355155.6 6689279.9 30.7, 355155.7 6689279.8 30.7, 355155.9 6689279.7 30.7, 355156 6689279.5 30.7, 355156.7 6689279 30.7, 355157.2 6689278.5 30.7, 355157.7 6689278.1 30.7, 355157.8 6689278 30.7, 355158 6689277.8 30.7, 355158.4 6689277.6 30.7, 355158.5 6689277.4 30.7, 355159.1 6689277.1 30.7, 355159.4 6689276.8 30.7, 355160 6689276.5 30.7, 355160.5 6689276.3 30.7, 355164.6 6689274.6 30.7, 355162.7 6689269.5 30.7, 355162.2 6689269.6 30.7, 355159 6689260.7 30.7, 355158.3 6689260.4 30.7, 355133.6 6689271.5 30.7))
BATIMENT0000000302930807;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;18.3;10.8;29.2;32.4;11.8;Cadastre;C 0.9;POLYGON Z ((355119.3 6689282.9 29.2, 355108.9 6689278.3 29.2, 355109.1 6689283.6 29.2, 355108.9 6689283.7 29.2, 355109.1 6689289.2 29.2, 355109.2 6689290.3 29.2, 355119.2 6689291 29.2, 355119.3 6689282.9 29.2))
BATIMENT0000000302931000;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;6.0;;;21.0;9.2;30.2;32.7;11.3;Cadastre;A 1.0;POLYGON Z ((355146.7 6689301.8 30.2, 355146.7 6689301.1 30.2, 355146.7 6689300.6 30.2, 355146.8 6689299.7 30.2, 355146.8 6689299.4 30.2, 355146.9 6689298.7 30.2, 355147 6689298.2 30.2, 355147.1 6689297.4 30.2, 355147.2 6689296.8 30.2, 355147.4 6689296.2 30.2, 355147.4 6689296 30.2, 355147.5 6689295.6 30.2, 355147.6 6689295.4 30.2, 355147.7 6689295 30.2, 355137.3 6689290.7 30.2, 355137.5 6689290.2 30.2, 355129.6 6689286.7 30.2, 355126.8 6689288.8 30.2, 355126.3 6689303.2 30.2, 355132.8 6689303.4 30.2, 355133 6689299.9 30.2, 355134.8 6689299.9 30.2, 355135.6 6689299.4 30.2, 355137.1 6689299.5 30.2, 355136.9 6689303.6 30.2, 355146.8 6689304.9 30.2, 355146.7 6689301.8 30.2))
BATIMENT0000000302930999;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;20;20;21.5;9.1;30.7;34.2;12.1;Cadastre;C 0.7;POLYGON Z ((355126 6689312.5 30.7, 355124.3 6689318.6 30.7, 355135.4 6689325.7 30.7, 355138 6689319.7 30.7, 355148.3 6689313.1 30.7, 355147.2 6689308.5 30.7, 355146.8 6689304.9 30.7, 355136.9 6689303.6 30.7, 355136.9 6689305 30.7, 355132.7 6689304.9 30.7, 355132.8 6689303.4 30.7, 355126.3 6689303.2 30.7, 355126 6689312.5 30.7))
BATIMENT0000000302931385;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;19.0;6.0;12;20;17.6;7.5;25.1;29.1;7.9;Cadastre;A 1.0;POLYGON Z ((355293.9 6689277.7 25.1, 355277.6 6689269.2 25.1, 355277.4 6689269.5 25.1, 355277.1 6689269.3 25.1, 355268.7 6689283.7 25.1, 355274 6689286.7 25.1, 355281 6689290.8 25.1, 355284.6 6689292.7 25.1, 355285.5 6689291.3 25.1, 355293.9 6689277.7 25.1))
BATIMENT0000000302931387;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.4;7.4;24.9;29.1;7.6;Cadastre;;POLYGON Z ((355293.8 6689282.3 24.9, 355298.1 6689284.4 24.9, 355300 6689280.8 24.9, 355295.6 6689278.6 24.9, 355293.8 6689282.3 24.9))
BATIMENT0000000302931005;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;6.0;;;22.3;7.9;30.2;34.3;8.6;Cadastre;A 1.0;POLYGON Z ((355243.7 6689284.5 30.2, 355240.7 6689282.9 30.2, 355234.9 6689292.8 30.2, 355248.6 6689299 30.2, 355253.6 6689290.5 30.2, 355253.5 6689290.3 30.2, 355257.9 6689282.8 30.2, 355248.3 6689277.2 30.2, 355243.7 6689284.5 30.2))
BATIMENT0000000302931389;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;19.6;6.7;26.4;29.2;8.0;Cadastre;A 1.0;POLYGON Z ((355294.8 6689293.8 26.4, 355297.2 6689295.2 26.4, 355300.6 6689296.9 26.4, 355302.4 6689293.5 26.4, 355303.2 6689291.9 26.4, 355305.2 6689288.9 26.4, 355307.7 6689284.8 26.4, 355301.8 6689281.8 26.4, 355294.8 6689293.8 26.4))
BATIMENT0000000302931399;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1848-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;12;20;19.5;7.6;27.2;29.4;8.3;Cadastre;A 1.0;POLYGON Z ((355257.5 6689302.9 27.2, 355275.9 6689311.4 27.2, 355278.7 6689304.9 27.2, 355275.5 6689303.7 27.2, 355279.5 6689294.9 27.2, 355282.9 6689296.3 27.2, 355284.6 6689292.7 27.2, 355281 6689290.8 27.2, 355279.4 6689293.8 27.2, 355272.3 6689289.8 27.2, 355274 6689286.7 27.2, 355268.7 6689283.7 27.2, 355257.5 6689302.9 27.2))
BATIMENT0000000302931398;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.3;7.6;21.9;24.2;8.0;Cadastre;C 0.4;POLYGON Z ((355300.6 6689296.9 21.9, 355295.6 6689306.2 21.9, 355294.9 6689305.9 21.9, 355293.5 6689309.3 21.9, 355298.5 6689311.5 21.9, 355299.5 6689309.2 21.9, 355301.5 6689310 21.9, 355302.8 6689307.3 21.9, 355303.1 6689307.4 21.9, 355307.2 6689299.5 21.9, 355306.7 6689299.2 21.9, 355306.8 6689298.8 21.9, 355305.7 6689298.2 21.9, 355306.9 6689295.8 21.9, 355302.4 6689293.5 21.9, 355300.6 6689296.9 21.9))
BATIMENT0000000302931397;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;19.5;7.3;26.8;29.2;8.3;Cadastre;A 1.0;POLYGON Z ((355290 6689317.9 26.8, 355293.5 6689309.3 26.8, 355294.9 6689305.9 26.8, 355295.6 6689306.2 26.8, 355300.6 6689296.9 26.8, 355297.2 6689295.2 26.8, 355296.1 6689297.6 26.8, 355287.3 6689295.2 26.8, 355285.5 6689291.3 26.8, 355284.6 6689292.7 26.8, 355282.9 6689296.3 26.8, 355278.7 6689304.9 26.8, 355275.9 6689311.4 26.8, 355290 6689317.9 26.8))
BATIMENT0000000302931410;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;16.9;7.6;24.5;27.4;8.3;Cadastre;C 0.6;POLYGON Z ((355294.6 6689320 24.5, 355298.5 6689311.5 24.5, 355293.5 6689309.3 24.5, 355290 6689317.9 24.5, 355294.6 6689320 24.5))
BATIMENT0000000302931403;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;5.0;10;10;20.0;6.1;26.1;27.6;8.5;Cadastre;C 0.1;POLYGON Z ((355299.4 6689322.2 26.1, 355305.9 6689308.9 26.1, 355303.1 6689307.4 26.1, 355302.8 6689307.3 26.1, 355301.5 6689310 26.1, 355299.5 6689309.2 26.1, 355298.5 6689311.5 26.1, 355294.6 6689320 26.1, 355299.4 6689322.2 26.1))
BATIMENT0000000302930977;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;10;20;21.0;8.5;29.5;34.3;8.9;Cadastre;C 0.7;POLYGON Z ((355237.5 6689318.4 29.5, 355237.8 6689318.4 29.5, 355242.9 6689308.7 29.5, 355229.4 6689302.7 29.5, 355225 6689313 29.5, 355225.2 6689313.1 29.5, 355225.1 6689313.5 29.5, 355219.4 6689326.7 29.5, 355219.2 6689327.1 29.5, 355230.2 6689332 29.5, 355237.5 6689318.4 29.5))
BATIMENT0000000302930797;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;;;9.1;15.5;24.7;34.8;17.3;Cadastre;A 1.0;POLYGON Z ((355059 6689303 24.7, 355062 6689296.9 24.7, 355063.1 6689294.7 24.7, 355066.6 6689287.3 24.7, 355057.9 6689284.4 24.7, 355050.3 6689297.4 24.7, 355059 6689303 24.7))
BATIMENT0000000302930803;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;19.8;11.1;31.0;34.0;14.2;Cadastre;A 1.0;POLYGON Z ((355119.2 6689291 31, 355109.2 6689290.3 31, 355095.9 6689289.4 31, 355094.4 6689289.3 31, 355093.4 6689296.6 31, 355096.3 6689297.2 31, 355096.2 6689297.8 31, 355103.5 6689298.4 31, 355118.8 6689298.5 31, 355119.2 6689291 31))
BATIMENT0000000302930799;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;11.6;13.8;25.5;35.4;16.0;Cadastre;A 1.0;POLYGON Z ((355084.1 6689312.6 25.5, 355084.7 6689310.7 25.5, 355084.4 6689310.7 25.5, 355087.9 6689296.3 25.5, 355089.7 6689288.5 25.5, 355093.3 6689289.2 25.5, 355093.2 6689285.4 25.5, 355092.8 6689285.3 25.5, 355092.7 6689285.6 25.5, 355085.4 6689284.2 25.5, 355084.7 6689288.3 25.5, 355079 6689287.5 25.5, 355078.1 6689291 25.5, 355084.9 6689292.1 25.5, 355083.7 6689297.3 25.5, 355084.3 6689297.4 25.5, 355082.8 6689302.2 25.5, 355072.7 6689299.1 25.5, 355072.9 6689298.7 25.5, 355071.2 6689298 25.5, 355068.1 6689307.2 25.5, 355084.1 6689312.6 25.5))
BATIMENT0000000302930802;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;15.7;15.4;31.1;35.6;16.6;Cadastre;A 1.0;POLYGON Z ((355062.8 6689305.4 31.1, 355068.1 6689307.2 31.1, 355071.2 6689298 31.1, 355066.7 6689296.2 31.1, 355065.8 6689298.5 31.1, 355062 6689296.9 31.1, 355059 6689303 31.1, 355062.8 6689305.4 31.1))
BATIMENT0000000302930808;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;23;90;14.8;14.7;29.5;30.7;15.1;Cadastre;A 1.0;POLYGON Z ((355090.8 6689312.7 29.5, 355092.8 6689305.7 29.5, 355093.6 6689301.7 29.5, 355094 6689299.5 29.5, 355094.1 6689298.4 29.5, 355087.9 6689296.3 29.5, 355084.4 6689310.7 29.5, 355084.7 6689310.7 29.5, 355090.8 6689312.7 29.5))
BATIMENT0000000302930804;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;;;20.4;11.4;31.9;34.5;13.8;Cadastre;A 1.0;POLYGON Z ((355096.3 6689306.6 31.9, 355096.7 6689302.6 31.9, 355107.9 6689303.5 31.9, 355107.8 6689308.9 31.9, 355108.1 6689309 31.9, 355108 6689309.9 31.9, 355108.7 6689310.1 31.9, 355112.3 6689311 31.9, 355112.3 6689311.6 31.9, 355118.3 6689311.8 31.9, 355118.8 6689298.5 31.9, 355103.5 6689298.4 31.9, 355096.2 6689297.8 31.9, 355096.2 6689299.3 31.9, 355096 6689302 31.9, 355093.6 6689301.7 31.9, 355092.8 6689305.7 31.9, 355096.3 6689306.6 31.9))
BATIMENT0000000302930805;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;16.7;12.3;29.0;30.6;14.4;Cadastre;C 0.2;POLYGON Z ((355100.5 6689319.6 29, 355102.1 6689313.8 29, 355103.5 6689308.5 29, 355096.3 6689306.6 29, 355092.8 6689305.7 29, 355090.8 6689312.7 29, 355090.4 6689314.6 29, 355100.5 6689319.6 29))
BATIMENT0000000302930806;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;14.9;11.9;26.8;30.2;13.6;Cadastre;A 1.0;POLYGON Z ((355107.6 6689314.5 26.8, 355102.1 6689313.8 26.8, 355100.5 6689319.6 26.8, 355108.8 6689322.1 26.8, 355117.4 6689323.2 26.8, 355118.3 6689311.8 26.8, 355112.3 6689311.6 26.8, 355112.3 6689311 26.8, 355108.7 6689310.1 26.8, 355107.6 6689314.5 26.8))
BATIMENT0000000302931474;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.5;16.3;29.8;32.9;18.9;Cadastre;A 1.0;POLYGON Z ((355064.6 6689314.2 29.8, 355064.4 6689314.8 29.8, 355060 6689313.4 29.8, 355059 6689312.5 29.8, 355058.8 6689312.8 29.8, 355044.1 6689301.5 29.8, 355044.2 6689301.2 29.8, 355043.1 6689300.4 29.8, 355042.6 6689299.8 29.8, 355042.4 6689300 29.8, 355042.2 6689299.8 29.8, 355034.4 6689304.4 29.8, 355034.6 6689304.7 29.8, 355034.2 6689304.8 29.8, 355033 6689315.6 29.8, 355032.8 6689315.6 29.8, 355032.4 6689318.6 29.8, 355032.6 6689318.7 29.8, 355032.3 6689321.5 29.8, 355032.1 6689321.6 29.8, 355031.7 6689324.5 29.8, 355032 6689324.6 29.8, 355030.8 6689335 29.8, 355041.7 6689336.2 29.8, 355043.5 6689330.9 29.8, 355062.6 6689340.2 29.8, 355062.5 6689342.5 29.8, 355063 6689342.6 29.8, 355064.5 6689337.6 29.8, 355065.4 6689334.6 29.8, 355066.9 6689330.3 29.8, 355071 6689316.8 29.8, 355064.6 6689314.2 29.8))
BATIMENT0000000302931473;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;17.1;14.8;32.0;34.4;15.9;Cadastre;A 1.0;POLYGON Z ((355071 6689316.8 32, 355066.9 6689330.3 32, 355068.4 6689330.7 32, 355070.6 6689331.5 32, 355069.9 6689334 32, 355068.7 6689333.7 32, 355067.8 6689336.8 32, 355068.8 6689337.1 32, 355068.2 6689338.8 32, 355064.5 6689337.6 32, 355063 6689342.6 32, 355069.5 6689345 32, 355068.9 6689346.7 32, 355070.7 6689347.1 32, 355075.2 6689331.6 32, 355079 6689319.4 32, 355071 6689316.8 32))
BATIMENT0000000302931481;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;16.5;13.5;30.1;32.9;14.6;Cadastre;A 1.0;POLYGON Z ((355093.2 6689324 30.1, 355092.3 6689333.5 30.1, 355094.4 6689333.8 30.1, 355093.6 6689340.3 30.1, 355100.1 6689341.1 30.1, 355100.2 6689340.8 30.1, 355102.7 6689326.2 30.1, 355093.2 6689324 30.1))
BATIMENT0000000302931476;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.7;15.9;28.6;;;Cadastre;;POLYGON Z ((355066.9 6689330.3 28.6, 355065.4 6689334.6 28.6, 355066.9 6689335.2 28.6, 355068.4 6689330.7 28.6, 355066.9 6689330.3 28.6))
BATIMENT0000000302931482;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1756-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;00;00;18.8;13.1;32.0;35.2;14.3;Cadastre;A 1.0;POLYGON Z ((355102.7 6689326.2 32, 355100.2 6689340.8 32, 355105.1 6689341.5 32, 355105.2 6689340.5 32, 355107.6 6689327.3 32, 355102.7 6689326.2 32))
BATIMENT0000000302931483;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;20;20;20.6;12.7;33.4;35.6;14.0;Cadastre;A 1.0;POLYGON Z ((355113.5 6689331 33.4, 355111.7 6689328.3 33.4, 355107.6 6689327.3 33.4, 355105.2 6689340.5 33.4, 355107.3 6689340.9 33.4, 355107.2 6689341.8 33.4, 355113 6689342.7 33.4, 355113.5 6689331 33.4))
BATIMENT0000000302931475;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;14.1;14.1;28.2;32.9;15.6;Cadastre;A 1.0;POLYGON Z ((355070.7 6689347.1 28.2, 355076.3 6689348.4 28.2, 355077.8 6689348.8 28.2, 355078.9 6689349 28.2, 355090.7 6689351.8 28.2, 355090.8 6689350.7 28.2, 355091.2 6689345.6 28.2, 355091.8 6689340.1 28.2, 355092.3 6689333.5 28.2, 355093.2 6689324 28.2, 355079 6689319.4 28.2, 355075.2 6689331.6 28.2, 355070.7 6689347.1 28.2), (355081.4 6689333.3 28.2, 355083.2 6689333.8 28.2, 355082.4 6689336.6 28.2, 355088 6689338.1 28.2, 355088 6689340.6 28.2, 355086 6689340.5 28.2, 355085.7 6689343.2 28.2, 355087.8 6689343.3 28.2, 355087.6 6689346.3 28.2, 355082 6689344.8 28.2, 355081.5 6689345.4 28.2, 355078 6689343.7 28.2, 355079.6 6689338.7 28.2, 355081.4 6689333.3 28.2))
BATIMENT0000000302931478;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.2;14.2;22.5;29.7;15.0;Cadastre;A 0.2;POLYGON Z ((355097.4 6689347.6 22.5, 355098.9 6689347.9 22.5, 355100.1 6689341.1 22.5, 355093.6 6689340.3 22.5, 355091.8 6689340.1 22.5, 355091.2 6689345.6 22.5, 355090.8 6689350.7 22.5, 355096.1 6689351.7 22.5, 355097.4 6689347.6 22.5))
BATIMENT0000000302931468;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;15.7;27.4;30.2;18.2;Cadastre;;POLYGON Z ((355037.8 6689349.4 27.4, 355048.5 6689351.1 27.4, 355046.6 6689356.6 27.4, 355046.9 6689356.7 27.4, 355063.4 6689362.8 27.4, 355068.9 6689346.7 27.4, 355069.5 6689345 27.4, 355063 6689342.6 27.4, 355062.5 6689342.5 27.4, 355062.6 6689340.2 27.4, 355043.5 6689330.9 27.4, 355041.7 6689336.2 27.4, 355037.8 6689349.4 27.4))
BATIMENT0000000302931480;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;10;20;17.4;13.3;30.8;32.7;14.9;Cadastre;A 1.0;POLYGON Z ((355098.9 6689347.9 30.8, 355097.4 6689347.6 30.8, 355096.1 6689351.7 30.8, 355094.3 6689357.7 30.8, 355092.2 6689365.2 30.8, 355096.4 6689368 30.8, 355101.8 6689371.3 30.8, 355113.1 6689359.8 30.8, 355114.8 6689343.3 30.8, 355113 6689342.7 30.8, 355107.2 6689341.8 30.8, 355105.1 6689341.5 30.8, 355100.2 6689340.8 30.8, 355100.1 6689341.1 30.8, 355098.9 6689347.9 30.8), (355100.9 6689350.9 30.8, 355105.8 6689352.6 30.8, 355100.5 6689362.6 30.8, 355097.3 6689361.3 30.8, 355100.9 6689350.9 30.8))
BATIMENT0000000302931479;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;14.0;26.0;32.0;15.0;Cadastre;;POLYGON Z ((355090.1 6689359.2 26, 355089.5 6689365.7 26, 355092.2 6689365.2 26, 355094.3 6689357.7 26, 355096.1 6689351.7 26, 355090.8 6689350.7 26, 355090.7 6689351.8 26, 355090.1 6689359.2 26))
BATIMENT0000000302931471;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;;;21.0;17.3;38.4;41.5;19.0;Cadastre;A 1.0;POLYGON Z ((355026.9 6689367.6 38.4, 355042.7 6689369.7 38.4, 355044.6 6689363 38.4, 355044.9 6689362.9 38.4, 355045.3 6689361.4 38.4, 355045.6 6689361.4 38.4, 355046.9 6689356.7 38.4, 355046.6 6689356.6 38.4, 355048.5 6689351.1 38.4, 355037.8 6689349.4 38.4, 355029.2 6689348.3 38.4, 355026.9 6689367.6 38.4))
BATIMENT0000000302930975;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;8.7;16.0;28.5;9.0;Cadastre;;POLYGON Z ((355220.9 6689311.6 16, 355215.1 6689324.9 16, 355219.4 6689326.7 16, 355225.1 6689313.5 16, 355220.9 6689311.6 16))
BATIMENT0000000302930395;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;12;20;18.8;7.0;25.8;30.8;8.4;Cadastre;A 1.0;POLYGON Z ((355249.1 6689346.9 25.8, 355262.8 6689346 25.8, 355261.8 6689331.1 25.8, 355267.2 6689318.5 25.8, 355253 6689312 25.8, 355246.7 6689323.6 25.8, 355249.1 6689346.9 25.8), (355253.7 6689332 25.8, 355253.8 6689332.8 25.8, 355254.8 6689332.7 25.8, 355255.1 6689335.5 25.8, 355249.9 6689336 25.8, 355249.5 6689332.4 25.8, 355253.7 6689332 25.8))
BATIMENT0000000302930396;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;20.3;7.7;28.1;30.4;8.5;Cadastre;A 1.0;POLYGON Z ((355267.1 6689346.6 28.1, 355270.4 6689347 28.1, 355281.8 6689348.4 28.1, 355289.6 6689328.8 28.1, 355267.2 6689318.5 28.1, 355261.8 6689331.1 28.1, 355262.8 6689346 28.1, 355267.1 6689346.6 28.1))
BATIMENT0000000302930397;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1836-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;20.7;8.0;28.7;30.0;8.8;Cadastre;A 1.0;POLYGON Z ((355234.6 6689345.8 28.7, 355235.8 6689347.7 28.7, 355249.1 6689346.9 28.7, 355246.7 6689323.6 28.7, 355234.6 6689345.8 28.7))
BATIMENT0000000302930976;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;;;21.3;8.2;29.5;34.3;8.9;Cadastre;A 1.0;POLYGON Z ((355216.9 6689332.6 29.5, 355216.6 6689332.5 29.5, 355212.1 6689342.9 29.5, 355222.3 6689347.4 29.5, 355227.7 6689337.5 29.5, 355227.3 6689337.3 29.5, 355230.2 6689332 29.5, 355219.2 6689327.1 29.5, 355216.9 6689332.6 29.5))
BATIMENT0000000302930398;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;12;20;15.7;7.5;23.2;28.7;8.6;Cadastre;C 0.7;POLYGON Z ((355298.5 6689332.9 23.2, 355289.6 6689328.8 23.2, 355281.8 6689348.4 23.2, 355288 6689352.2 23.2, 355298.5 6689332.9 23.2))
BATIMENT0000000302930399;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;30;40;20.5;7.4;28.0;31.5;8.7;Cadastre;C 0.7;POLYGON Z ((355291.4 6689354.3 28, 355293.9 6689355.8 28, 355298 6689348.1 28, 355298.8 6689346.4 28, 355299.5 6689346.7 28, 355300.7 6689344.5 28, 355306.2 6689336.4 28, 355298.5 6689332.9 28, 355288 6689352.2 28, 355291.4 6689354.3 28), (355297 6689341.5 28, 355298.5 6689342.3 28, 355296.3 6689346.8 28, 355295.7 6689346.5 28, 355294.6 6689346 28, 355297 6689341.5 28))
BATIMENT0000000302930992;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;20.4;8.8;29.2;34.1;9.5;Cadastre;A 1.0;POLYGON Z ((355183.3 6689359.3 29.2, 355183 6689360 29.2, 355192.6 6689364.1 29.2, 355197 6689353.8 29.2, 355197.2 6689353.8 29.2, 355199 6689349.4 29.2, 355185.9 6689343.9 29.2, 355179.9 6689357.9 29.2, 355183.3 6689359.3 29.2))
BATIMENT0000000302930982;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;21.3;8.6;30.0;34.0;9.1;Cadastre;A 1.0;POLYGON Z ((355218.6 6689361 30, 355218.9 6689360.8 30, 355218.7 6689355.7 30, 355208 6689351.1 30, 355204.5 6689362.4 30, 355205.2 6689362.6 30, 355205 6689366.2 30, 355208.1 6689366.6 30, 355211.7 6689367.6 30, 355218.8 6689368.2 30, 355218.6 6689361 30))
BATIMENT0000000302931484;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;17.6;7.3;24.9;28.0;9.6;Cadastre;A 1.0;POLYGON Z ((355267.9 6689369.6 24.9, 355269.8 6689371.1 24.9, 355270 6689387.7 24.9, 355270.6 6689387.8 24.9, 355296.2 6689367.9 24.9, 355291.2 6689360.9 24.9, 355277.8 6689352.8 24.9, 355277.3 6689352.9 24.9, 355267.9 6689369.6 24.9), (355278.1 6689366.6 24.9, 355281.1 6689370.9 24.9, 355275.7 6689374.7 24.9, 355274.6 6689373.2 24.9, 355275.2 6689372 24.9, 355278 6689369.9 24.9, 355277 6689368.6 24.9, 355278 6689368 24.9, 355277.3 6689367.2 24.9, 355278.1 6689366.6 24.9))
BATIMENT0000000302930998;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;;;16.7;10.0;26.7;33.2;12.6;Cadastre;A 0.4;POLYGON Z ((355123.2 6689330.1 26.7, 355135 6689332 26.7, 355135.4 6689325.7 26.7, 355124.3 6689318.6 26.7, 355123.2 6689330.1 26.7))
BATIMENT0000000302930996;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;18.3;9.1;27.5;29.4;13.1;Cadastre;A 1.0;POLYGON Z ((355122.4 6689339.4 27.5, 355134.5 6689340.8 27.5, 355135 6689332 27.5, 355123.2 6689330.1 27.5, 355122.4 6689339.4 27.5))
BATIMENT0000000302931268;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;;;21.7;8.9;30.7;34.2;9.6;Cadastre;A 1.0;POLYGON Z ((355140 6689327.4 30.7, 355138.7 6689349.2 30.7, 355148.9 6689353.7 30.7, 355157.5 6689333.1 30.7, 355157.8 6689333.3 30.7, 355159.7 6689328.7 30.7, 355156.6 6689326 30.7, 355156.4 6689325.8 30.7, 355156.4 6689325.7 30.7, 355156.3 6689325.7 30.7, 355156.1 6689325.4 30.7, 355156 6689325.4 30.7, 355155.7 6689325.1 30.7, 355155.6 6689325 30.7, 355155.5 6689324.9 30.7, 355155.4 6689324.8 30.7, 355155.2 6689324.6 30.7, 355155.2 6689324.5 30.7, 355155.1 6689324.5 30.7, 355155 6689324.3 30.7, 355154.9 6689324.3 30.7, 355154.7 6689324 30.7, 355154.5 6689323.8 30.7, 355154.5 6689323.7 30.7, 355154.3 6689323.5 30.7, 355152 6689320 30.7, 355140 6689327.4 30.7))
BATIMENT0000000302930994;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;14.4;10.0;24.4;29.0;13.2;Cadastre;C 0.7;POLYGON Z ((355121.5 6689348.9 24.4, 355134 6689348.6 24.4, 355134.5 6689340.8 24.4, 355122.4 6689339.4 24.4, 355121.5 6689348.9 24.4))
BATIMENT0000000302930991;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;21.2;8.9;30.2;34.2;9.3;Cadastre;C 0.8;POLYGON Z ((355164.3 6689334.7 30.2, 355162.4 6689339.2 30.2, 355162.6 6689339.3 30.2, 355158.2 6689349.4 30.2, 355167.7 6689353.4 30.2, 355167.9 6689352.8 30.2, 355171.2 6689354.2 30.2, 355177.3 6689340.2 30.2, 355164.3 6689334.7 30.2))
BATIMENT0000000302930990;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;35;20;21.2;8.9;30.1;34.1;9.3;Cadastre;A 1.0;POLYGON Z ((355179.9 6689357.9 30.1, 355185.9 6689343.9 30.1, 355177.3 6689340.2 30.1, 355171.2 6689354.2 30.1, 355179.9 6689357.9 30.1))
BATIMENT0000000302930993;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;5.0;;;16.4;9.0;25.5;28.2;13.6;Cadastre;C 0.1;POLYGON Z ((355123 6689358.2 25.5, 355134.3 6689355.7 25.5, 355134.7 6689355.5 25.5, 355134 6689348.6 25.5, 355121.5 6689348.9 25.5, 355123 6689358.2 25.5))
BATIMENT0000000302930995;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;15.9;9.2;25.1;26.2;13.5;Cadastre;A 1.0;POLYGON Z ((355124.4 6689362.7 25.1, 355126.4 6689366.8 25.1, 355135.1 6689364.1 25.1, 355137 6689363.4 25.1, 355134.3 6689355.7 25.1, 355123 6689358.2 25.1, 355124.4 6689362.7 25.1))
BATIMENT0000000302930997;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;12.8;10.0;22.8;29.7;14.0;Cadastre;A 1.0;POLYGON Z ((355130.5 6689375.5 22.8, 355139 6689371 22.8, 355135.1 6689364.1 22.8, 355126.4 6689366.8 22.8, 355130.5 6689375.5 22.8))
BATIMENT0000000302931221;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;23;12.6;9.3;22.0;24.2;10.0;Cadastre;A 1.0;POLYGON Z ((355186.9 6689377 22, 355169.7 6689369.8 22, 355167.3 6689375.6 22, 355173.4 6689378.2 22, 355184.4 6689382.9 22, 355186.9 6689377 22))
BATIMENT0000000302930981;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;19.3;8.9;28.2;31.5;10.4;Cadastre;A 1.0;POLYGON Z ((355202.8 6689366.1 28.2, 355202.8 6689384.9 28.2, 355218.7 6689384.4 28.2, 355218.6 6689379.5 28.2, 355215 6689379.5 28.2, 355214.5 6689378.9 28.2, 355214.1 6689378.5 28.2, 355213.5 6689378.5 28.2, 355213.6 6689376.9 28.2, 355215.5 6689376.9 28.2, 355215.5 6689375.7 28.2, 355218.5 6689375.7 28.2, 355218.8 6689368.2 28.2, 355211.7 6689367.6 28.2, 355208.1 6689366.6 28.2, 355205 6689366.2 28.2, 355202.8 6689366.1 28.2))
BATIMENT0000000302930983;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;9.2;13.2;16.7;9.7;Cadastre;;POLYGON Z ((355220.9 6689378.6 13.2, 355220.9 6689376.1 13.2, 355219.6 6689376.1 13.2, 355219.6 6689375.8 13.2, 355218.5 6689375.9 13.2, 355218.6 6689378.7 13.2, 355220.9 6689378.6 13.2))
BATIMENT0000000302931485;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1872-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;18.5;6.9;25.5;28.5;9.7;Cadastre;A 1.0;POLYGON Z ((355287.3 6689382.6 25.5, 355301.7 6689375.5 25.5, 355296.2 6689367.9 25.5, 355270.6 6689387.8 25.5, 355272.1 6689390.4 25.5, 355287.3 6689382.6 25.5))
BATIMENT0000000302931487;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1872-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;17.7;6.9;24.6;27.8;7.8;Cadastre;A 1.0;POLYGON Z ((355289.3 6689387.8 24.6, 355301.4 6689384.8 24.6, 355304.7 6689383.9 24.6, 355305.2 6689383.7 24.6, 355301.7 6689375.5 24.6, 355287.3 6689382.6 24.6, 355289.3 6689387.8 24.6))
BATIMENT0000000302930978;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;15.8;9.2;25.1;28.0;11.7;Cadastre;A 1.0;POLYGON Z ((355202.5 6689403.5 25.1, 355204.8 6689403.5 25.1, 355219.3 6689403.6 25.1, 355218.7 6689384.4 25.1, 355202.8 6689384.9 25.1, 355202.5 6689403.5 25.1), (355217.6 6689393.4 25.1, 355217.6 6689398.4 25.1, 355213.3 6689398.7 25.1, 355213.3 6689397.5 25.1, 355213.9 6689396.7 25.1, 355213.8 6689394.8 25.1, 355213.3 6689393.5 25.1, 355217.6 6689393.4 25.1))
BATIMENT0000000302931100;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;13;20;14.8;9.3;24.2;27.1;10.7;Cadastre;A 1.0;POLYGON Z ((355189.1 6689386.4 24.2, 355187.1 6689391.1 24.2, 355187.1 6689391.4 24.2, 355179.5 6689409.1 24.2, 355189.3 6689419.7 24.2, 355195.8 6689417.3 24.2, 355195.9 6689413.1 24.2, 355196.2 6689412.9 24.2, 355196.2 6689408.3 24.2, 355195.9 6689408.2 24.2, 355196.1 6689392.9 24.2, 355196.3 6689392.7 24.2, 355196.3 6689387.9 24.2, 355196.1 6689387.6 24.2, 355196.2 6689380.7 24.2, 355192.2 6689379.5 24.2, 355189.2 6689386.5 24.2, 355189.1 6689386.4 24.2), (355189.2 6689406.4 24.2, 355190.6 6689407.1 24.2, 355190.6 6689409 24.2, 355189.9 6689410.1 24.2, 355189.6 6689409.6 24.2, 355188.6 6689409.5 24.2, 355188.3 6689410 24.2, 355187.7 6689409.5 24.2, 355187.8 6689407.2 24.2, 355189.2 6689406.4 24.2))
BATIMENT0000000302931486;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;12.8;9.2;22.0;25.2;10.6;Cadastre;A 1.0;POLYGON Z ((355270.4 6689414.5 22, 355280.2 6689414 22, 355280.3 6689411.3 22, 355280.5 6689402.5 22, 355284.3 6689401.9 22, 355289.7 6689401.2 22, 355287.8 6689395.7 22, 355290.2 6689394.8 22, 355289.1 6689391.6 22, 355286.7 6689392.4 22, 355285.3 6689388.8 22, 355273.1 6689392.4 22, 355272.1 6689390.4 22, 355270.6 6689387.8 22, 355270 6689387.7 22, 355270.4 6689414.5 22), (355279.9 6689394.4 22, 355281.6 6689399.1 22, 355277.3 6689400.7 22, 355277.1 6689395.3 22, 355279.9 6689394.4 22))
BATIMENT0000000302931854;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.5;10.1;25.6;;;Cadastre;;POLYGON Z ((355259.1 6689417.2 25.6, 355259 6689414.8 25.6, 355260.3 6689414.8 25.6, 355260.3 6689413.7 25.6, 355259 6689413.7 25.6, 355258.9 6689410 25.6, 355260.2 6689409.9 25.6, 355260.2 6689408.9 25.6, 355258.9 6689408.9 25.6, 355258.8 6689405.1 25.6, 355260.1 6689405.1 25.6, 355260.1 6689404.1 25.6, 355258.7 6689404.1 25.6, 355258.6 6689400.4 25.6, 355260 6689400.2 25.6, 355260.1 6689399.2 25.6, 355258.6 6689399.2 25.6, 355258.4 6689395.6 25.6, 355259 6689395.5 25.6, 355259 6689394.3 25.6, 355259.9 6689394.2 25.6, 355259.9 6689393.4 25.6, 355258.5 6689393.4 25.6, 355258.4 6689391.5 25.6, 355259.2 6689390.7 25.6, 355259.1 6689390.5 25.6, 355259.8 6689390 25.6, 355259.8 6689388.9 25.6, 355258.8 6689388 25.6, 355258 6689388 25.6, 355257.4 6689388.9 25.6, 355256.6 6689388.9 25.6, 355256.6 6689390.3 25.6, 355255 6689390.3 25.6, 355254.5 6689389 25.6, 355254.1 6689389 25.6, 355254 6689387.9 25.6, 355252.9 6689388 25.6, 355252.9 6689389 25.6, 355250.5 6689389 25.6, 355249.6 6689417.5 25.6, 355259.1 6689417.2 25.6))
BATIMENT0000000302931853;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.5;10.1;25.6;;;Cadastre;;POLYGON Z ((355229.9 6689392.2 25.6, 355229.9 6689394 25.6, 355228.7 6689394 25.6, 355228.7 6689394.8 25.6, 355229.4 6689394.8 25.6, 355229.4 6689396.3 25.6, 355229.9 6689396.3 25.6, 355230 6689399.8 25.6, 355228.7 6689399.8 25.6, 355228.8 6689401 25.6, 355230.1 6689400.9 25.6, 355230.1 6689404.7 25.6, 355228.8 6689404.8 25.6, 355228.8 6689405.8 25.6, 355229.1 6689405.9 25.6, 355229.4 6689409.3 25.6, 355228.9 6689409.4 25.6, 355228.9 6689410.6 25.6, 355230.1 6689410.5 25.6, 355230.2 6689414.2 25.6, 355228.8 6689414.3 25.6, 355228.9 6689415.2 25.6, 355230.1 6689415.2 25.6, 355230.1 6689417.4 25.6, 355239.3 6689417.5 25.6, 355238.8 6689394.7 25.6, 355237.9 6689394.6 25.6, 355237.7 6689389.2 25.6, 355235.7 6689389.2 25.6, 355235.8 6689388.3 25.6, 355234.6 6689388.3 25.6, 355234.6 6689389.3 25.6, 355234.1 6689389.3 25.6, 355233.6 6689390.8 25.6, 355232 6689390.7 25.6, 355231.9 6689389.4 25.6, 355231.1 6689389.4 25.6, 355230.1 6689388.7 25.6, 355229.1 6689388.7 25.6, 355228.7 6689389.7 25.6, 355228.7 6689391 25.6, 355229.9 6689392.2 25.6))
BATIMENT0000000302930980;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.7;10.5;23.2;;;Cadastre;;POLYGON Z ((355202.5 6689404 23.2, 355204.9 6689403.9 23.2, 355204.8 6689403.5 23.2, 355202.5 6689403.5 23.2, 355202.5 6689404 23.2))
BATIMENT0000000302923343;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.9;6.3;10.3;12.5;6.6;Cadastre;;POLYGON Z ((354346.6 6688322.4 10.3, 354346.9 6688321 10.3, 354356.5 6688323.1 10.3, 354357.5 6688319.2 10.3, 354347.9 6688316.7 10.3, 354348.5 6688314.3 10.3, 354337.78927941294 6688312.003221275 10.3, 354300.0620380877 6688312.003221275 10.3, 354346.6 6688322.4 10.3))
BATIMENT0000000302923198;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;10;20;9.2;6.5;15.7;20.7;6.9;Cadastre;A 1.0;POLYGON Z ((354257.2 6688685.2 15.7, 354264 6688688.3 15.7, 354274.8 6688693.3 15.7, 354284.6 6688675.6 15.7, 354265.5 6688666.9 15.7, 354261.2 6688676.1 15.7, 354257.2 6688685.2 15.7))
BATIMENT0000000302923199;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;17.7;6.0;23.7;26.8;6.9;Cadastre;A 1.0;POLYGON Z ((354278.8 6688695 23.7, 354278.9 6688695 23.7, 354293.3 6688701.1 23.7, 354301.4 6688683.2 23.7, 354284.6 6688675.6 23.7, 354274.8 6688693.3 23.7, 354278.8 6688695 23.7), (354281.3 6688687.6 23.7, 354283.9 6688688.8 23.7, 354283.8 6688689.3 23.7, 354288.4 6688691.5 23.7, 354288.8 6688691 23.7, 354292.9 6688693 23.7, 354291.7 6688695.4 23.7, 354279.9 6688690 23.7, 354281.3 6688687.6 23.7))
BATIMENT0000000302923201;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;10;20;17.8;6.0;23.8;27.0;6.6;Cadastre;A 1.0;POLYGON Z ((354324.3 6688694.4 23.8, 354323.9 6688693.4 23.8, 354301.4 6688683.2 23.8, 354293.3 6688701.1 23.8, 354297.1 6688702.7 23.8, 354299.7 6688696.9 23.8, 354303 6688698.4 23.8, 354300.4 6688704.1 23.8, 354304.1 6688705.7 23.8, 354324.3 6688694.4 23.8))
BATIMENT0000000302923200;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;12.3;6.0;18.3;21.5;6.9;Cadastre;A 1.0;POLYGON Z ((354268.3 6688705.4 18.3, 354272.4 6688707.2 18.3, 354274.4 6688708 18.3, 354274.6 6688708.1 18.3, 354277.5 6688702.2 18.3, 354286.1 6688706.2 18.3, 354279.3 6688710.2 18.3, 354283.1 6688711.8 18.3, 354285.6 6688716.4 18.3, 354304.1 6688705.7 18.3, 354300.4 6688704.1 18.3, 354297.1 6688702.7 18.3, 354293.3 6688701.1 18.3, 354278.9 6688695 18.3, 354278.8 6688695 18.3, 354274.8 6688693.3 18.3, 354268.3 6688705.4 18.3))
BATIMENT0000000302923202;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1868-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;12.3;6.0;18.3;19.5;6.9;Cadastre;A 1.0;POLYGON Z ((354263.4 6688714.5 18.3, 354271.3 6688718.8 18.3, 354274.2 6688723.1 18.3, 354285.6 6688716.4 18.3, 354283.1 6688711.8 18.3, 354279.3 6688710.2 18.3, 354276.2 6688708.8 18.3, 354275.9 6688710 18.3, 354276.1 6688710.7 18.3, 354274.3 6688711.6 18.3, 354272.8 6688711.4 18.3, 354270.8 6688713.3 18.3, 354269.6 6688712.4 18.3, 354272.4 6688707.2 18.3, 354268.3 6688705.4 18.3, 354263.4 6688714.5 18.3))
BATIMENT0000000302923251;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;20;13.3;5.6;19.0;27.0;8.1;Cadastre;A 1.0;POLYGON Z ((354325.3 6688716.6 19, 354327.4 6688712.1 19, 354328.1 6688711.7 19, 354335.1 6688714.6 19, 354334.7 6688715.6 19, 354335.2 6688716.1 19, 354339.2 6688718 19, 354340 6688717.8 19, 354340.2 6688717.1 19, 354347.1 6688720 19, 354347.5 6688721.4 19, 354343.8 6688729.2 19, 354340.8 6688727.9 19, 354332 6688745.4 19, 354339.2 6688749.1 19, 354343.5 6688740.6 19, 354345.8 6688735.9 19, 354348.1 6688731.1 19, 354359.3 6688708.1 19, 354337.7 6688698.9 19, 354318.3 6688710.1 19, 354320.5 6688714.2 19, 354325.3 6688716.6 19))
BATIMENT0000000302923253;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.6;5.6;24.2;27.6;7.8;Cadastre;A 1.0;POLYGON Z ((354275.6 6688744.2 24.2, 354299.9 6688756.7 24.2, 354301.8 6688752.9 24.2, 354303.7 6688749.1 24.2, 354301.3 6688747.9 24.2, 354304 6688743.2 24.2, 354295.9 6688738.9 24.2, 354305.1 6688733.6 24.2, 354306.3 6688730.4 24.2, 354305.9 6688730 24.2, 354315.5 6688720.9 24.2, 354317.3 6688717.7 24.2, 354316.6 6688716.2 24.2, 354317.1 6688715.9 24.2, 354320.5 6688714.2 24.2, 354318.3 6688710.1 24.2, 354315 6688712 24.2, 354282.6 6688730.7 24.2, 354275.6 6688744.2 24.2))
BATIMENT0000000302923548;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;2.9;6.7;9.6;20.7;8.2;Cadastre;C 0.4;POLYGON Z ((354311.1 6688748.5 9.6, 354312.7 6688744.8 9.6, 354331.2 6688753.8 9.6, 354328.6 6688758.3 9.6, 354333.5 6688760.6 9.6, 354338.8 6688749.8 9.6, 354311.1 6688735 9.6, 354306 6688744.2 9.6, 354305.4 6688745.4 9.6, 354311.1 6688748.5 9.6))
BATIMENT0000000302923255;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.2;6.7;23.9;25.7;7.3;Cadastre;;POLYGON Z ((354299.9 6688756.7 23.9, 354302.5 6688758.1 23.9, 354304.6 6688754.4 23.9, 354303.5 6688753.9 23.9, 354301.8 6688752.9 23.9, 354299.9 6688756.7 23.9))
BATIMENT0000000302922997;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;5.0;00;00;17.0;6.4;23.4;25.8;7.5;Cadastre;A 1.0;POLYGON Z ((354098.1 6688587.8 23.4, 354089.3 6688590.3 23.4, 354082.6 6688597.7 23.4, 354092.5 6688608 23.4, 354083.6 6688616.3 23.4, 354084.1 6688616.8 23.4, 354087.9 6688613.3 23.4, 354092.7 6688618.2 23.4, 354107.7 6688603.8 23.4, 354109.7 6688601.7 23.4, 354112 6688604.1 23.4, 354112.2 6688603.8 23.4, 354114.1 6688605.4 23.4, 354113.4 6688605.8 23.4, 354114 6688606.5 23.4, 354119.6 6688601.5 23.4, 354122.5 6688605 23.4, 354127.9 6688599.8 23.4, 354098.1 6688587.8 23.4))
BATIMENT0000000302923003;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;6.8;21.0;23.0;7.3;Cadastre;;POLYGON Z ((354107.7 6688603.8 21, 354110 6688606.2 21, 354112 6688604.1 21, 354109.7 6688601.7 21, 354107.7 6688603.8 21))
BATIMENT0000000302923005;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.3;7.0;25.3;28.1;7.2;Cadastre;;POLYGON Z ((354114 6688606.5 25.3, 354117.1 6688610 25.3, 354122.5 6688605 25.3, 354119.6 6688601.5 25.3, 354114 6688606.5 25.3))
BATIMENT0000000302923001;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;18.8;6.6;25.4;28.7;7.2;Cadastre;A 1.0;POLYGON Z ((354127.9 6688599.8 25.4, 354122.5 6688605 25.4, 354117.1 6688610 25.4, 354122.6 6688616.7 25.4, 354129.4 6688623.9 25.4, 354137 6688616.9 25.4, 354136.8 6688616.6 25.4, 354145.3 6688609 25.4, 354127.9 6688599.8 25.4))
BATIMENT0000000302923002;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;14.3;6.5;20.8;27.2;7.2;Cadastre;A 1.0;POLYGON Z ((354140.5 6688620.3 20.8, 354143.8 6688617.8 20.8, 354145.9 6688619.2 20.8, 354146.8 6688619.8 20.8, 354148.9 6688621.5 20.8, 354154.7 6688613.8 20.8, 354145.3 6688609 20.8, 354136.8 6688616.6 20.8, 354137 6688616.9 20.8, 354139.9 6688619.9 20.8, 354140.5 6688620.3 20.8))
BATIMENT0000000302923000;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;6.7;14.2;23.0;7.2;Cadastre;;POLYGON Z ((354132.1 6688626.7 14.2, 354139.9 6688619.9 14.2, 354137 6688616.9 14.2, 354129.4 6688623.9 14.2, 354132.1 6688626.7 14.2))
BATIMENT0000000302922999;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;7.0;24.0;26.7;7.6;Cadastre;;POLYGON Z ((354129.4 6688623.9 24, 354122.6 6688616.7 24, 354117.1 6688622.2 24, 354123.8 6688629.2 24, 354129.4 6688623.9 24))
BATIMENT0000000302923007;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;30.0;7.0;00;00;17.9;7.1;25.0;29.6;7.5;Cadastre;A 1.0;POLYGON Z ((354174.1 6688638.1 25, 354174.9 6688636.8 25, 354171.5 6688633.5 25, 354176 6688624.8 25, 354154.7 6688613.8 25, 354148.9 6688621.5 25, 354147.2 6688623.4 25, 354147.3 6688623.4 25, 354152.8 6688626.6 25, 354149.2 6688633.6 25, 354169.3 6688644 25, 354174.1 6688638.1 25))
BATIMENT0000000302922996;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;00;00;17.3;6.9;24.2;28.6;7.3;Cadastre;A 1.0;POLYGON Z ((354123.8 6688629.2 24.2, 354117.1 6688622.2 24.2, 354102.3 6688636.7 24.2, 354107.2 6688642.1 24.2, 354103.8 6688645.4 24.2, 354104.8 6688646.5 24.2, 354123.8 6688629.2 24.2))
BATIMENT0000000302923010;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;6.5;13.5;16.5;7.5;Cadastre;;POLYGON Z ((354182.7 6688654.4 13.5, 354180.6 6688652.8 13.5, 354177.7 6688656.4 13.5, 354180 6688657.9 13.5, 354182.7 6688654.4 13.5))
BATIMENT0000000302923009;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;9.6;6.5;16.2;22.5;7.5;Cadastre;A 1.0;POLYGON Z ((354186.3 6688645.7 16.2, 354188.1 6688646.7 16.2, 354187.2 6688647.6 16.2, 354190.8 6688650 16.2, 354190.6 6688651 16.2, 354191 6688652.1 16.2, 354190.6 6688652.6 16.2, 354197.6 6688657.8 16.2, 354208.6 6688642.9 16.2, 354208.3 6688641.5 16.2, 354188.8 6688631.4 16.2, 354179.7 6688642.6 16.2, 354170 6688654.5 16.2, 354180 6688661.5 16.2, 354189.9 6688668.4 16.2, 354194.6 6688661.9 16.2, 354193.8 6688661.3 16.2, 354195.4 6688659 16.2, 354195 6688658.6 16.2, 354191.6 6688656.1 16.2, 354190.3 6688658 16.2, 354185.8 6688654.8 16.2, 354184.6 6688655.8 16.2, 354182.7 6688654.4 16.2, 354180 6688657.9 16.2, 354177.7 6688656.4 16.2, 354180.6 6688652.8 16.2, 354186.3 6688645.7 16.2))
BATIMENT0000000302923191;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;;;19.4;6.8;26.2;29.4;7.4;Cadastre;B 0.7;POLYGON Z ((354219.6 6688660.5 26.2, 354219.3 6688662 26.2, 354222.8 6688663.5 26.2, 354223.4 6688662.4 26.2, 354236.3 6688668.3 26.2, 354237.7 6688665.4 26.2, 354235.8 6688664.5 26.2, 354237.2 6688662 26.2, 354240.7 6688663.5 26.2, 354243.4 6688657 26.2, 354217.7 6688645.4 26.2, 354210.7 6688655 26.2, 354216 6688658.9 26.2, 354219.6 6688660.5 26.2))
BATIMENT0000000302923195;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;6.7;15.0;17.7;7.1;Cadastre;;POLYGON Z ((354213.2 6688662.6 15, 354210 6688667.6 15, 354211.2 6688668.5 15, 354214.9 6688663.4 15, 354213.2 6688662.6 15))
BATIMENT0000000302923192;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;13.3;6.0;19.3;24.5;7.5;Cadastre;A 1.0;POLYGON Z ((354196.7 6688674.1 19.3, 354202.1 6688678 19.3, 354203 6688676.8 19.3, 354206.9 6688671.4 19.3, 354207.9 6688672.2 19.3, 354207.6 6688672.7 19.3, 354208.7 6688673.4 19.3, 354211.4 6688669.9 19.3, 354211.2 6688668.5 19.3, 354210 6688667.6 19.3, 354213.2 6688662.6 19.3, 354216 6688658.9 19.3, 354210.7 6688655 19.3, 354196.7 6688674.1 19.3))
BATIMENT0000000302923197;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.5;6.3;17.8;20.2;6.9;Cadastre;;POLYGON Z ((354261.2 6688676.1 17.8, 354265.5 6688666.9 17.8, 354261.8 6688665.3 17.8, 354257.7 6688674.5 17.8, 354261.2 6688676.1 17.8))
BATIMENT0000000302923193;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;;;7.5;6.6;14.2;20.8;7.4;Cadastre;A 1.0;POLYGON Z ((354237.2 6688662 14.2, 354235.8 6688664.5 14.2, 354237.7 6688665.4 14.2, 354236.3 6688668.3 14.2, 354233.4 6688674.8 14.2, 354237.5 6688676.8 14.2, 354234.2 6688683.7 14.2, 354250.1 6688691 14.2, 354257.7 6688674.5 14.2, 354261.8 6688665.3 14.2, 354243.4 6688657 14.2, 354240.7 6688663.5 14.2, 354237.2 6688662 14.2), (354243.7 6688668.6 14.2, 354248.6 6688670.7 14.2, 354248.5 6688671.4 14.2, 354249.3 6688672.3 14.2, 354250.2 6688672.1 14.2, 354250.5 6688671.4 14.2, 354253.3 6688672.7 14.2, 354252.7 6688674.4 14.2, 354243.8 6688670.6 14.2, 354243.2 6688669.8 14.2, 354243.7 6688668.6 14.2))
BATIMENT0000000302923194;Industriel, agricole ou commercial;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;00;00;6.4;6.8;13.2;17.2;7.8;Cadastre;B 0.1;POLYGON Z ((354209.6 6688681.4 13.2, 354211.7 6688678.4 13.2, 354228.1 6688690.3 13.2, 354227.9 6688686.1 13.2, 354227.5 6688679.7 13.2, 354228.8 6688674.1 13.2, 354220.4 6688670.1 13.2, 354221.7 6688666.7 13.2, 354214.9 6688663.4 13.2, 354211.2 6688668.5 13.2, 354211.4 6688669.9 13.2, 354208.7 6688673.4 13.2, 354207.6 6688672.7 13.2, 354207.9 6688672.2 13.2, 354206.9 6688671.4 13.2, 354203 6688676.8 13.2, 354209.6 6688681.4 13.2))
BATIMENT0000000302923196;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;00;00;13.9;7.1;21.0;25.1;7.9;Cadastre;C 0.3;POLYGON Z ((354190.4 6688699.4 21, 354191.2 6688700.1 21, 354194.4 6688702.4 21, 354196.8 6688704.1 21, 354202 6688697 21, 354202.5 6688696.4 21, 354203.5 6688691.5 21, 354206.3 6688687.6 21, 354205.5 6688687 21, 354209.6 6688681.4 21, 354203 6688676.8 21, 354202.1 6688678 21, 354196.7 6688674.1 21, 354181.7 6688694.8 21, 354190.4 6688699.4 21))
BATIMENT0000000302923203;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.1;6.9;9.1;9.9;7.5;Cadastre;C 0.2;POLYGON Z ((354223.1 6688692.2 9.1, 354220 6688696.7 9.1, 354215.6 6688693.6 9.1, 354211.6 6688699.4 9.1, 354212.4 6688700 9.1, 354210.3 6688703 9.1, 354205.4 6688709.9 9.1, 354210 6688713.2 9.1, 354210 6688713.1 9.1, 354214.8 6688706.3 9.1, 354217 6688703.1 9.1, 354216.2 6688702.5 9.1, 354219.7 6688697.6 9.1, 354225.5 6688701.6 9.1, 354228.3 6688696.2 9.1, 354223.1 6688692.2 9.1))
BATIMENT0000000302923309;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.3;6.1;11.4;13.0;6.9;Cadastre;C 0.5;POLYGON Z ((354228.4 6688716.5 11.4, 354234.9 6688721.5 11.4, 354244.1 6688703 11.4, 354236.8 6688699.6 11.4, 354228.4 6688716.5 11.4))
BATIMENT0000000302923008;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.6;6.2;13.9;17.2;7.4;Cadastre;A 1.0;POLYGON Z ((354154 6688674.6 13.9, 354170 6688654.5 13.9, 354179.7 6688642.6 13.9, 354174.1 6688638.1 13.9, 354169.3 6688644 13.9, 354168.5 6688645.2 13.9, 354148.4 6688670.3 13.9, 354154 6688674.6 13.9))
BATIMENT0000000302923004;Industriel, agricole ou commercial;Annexe;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.7;6.4;15.2;18.5;7.2;Cadastre;C 0.1;POLYGON Z ((354106.3 6688667.7 15.2, 354109.5 6688670.4 15.2, 354126.7 6688648.3 15.2, 354123.2 6688645.4 15.2, 354106.3 6688667.7 15.2))
BATIMENT0000000302923011;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;64.0;5.0;00;00;14.0;7.1;21.2;24.8;7.8;Cadastre;A 1.0;POLYGON Z ((354165.2 6688701.9 21.2, 354172.7 6688691.8 21.2, 354171.5 6688690.9 21.2, 354182.1 6688676 21.2, 354183.5 6688677 21.2, 354189.9 6688668.4 21.2, 354180 6688661.5 21.2, 354178 6688664.2 21.2, 354175.9 6688662.5 21.2, 354151.3 6688696.1 21.2, 354137.9 6688691.2 21.2, 354137.2 6688691.6 21.2, 354136.6 6688692 21.2, 354136.2 6688692.2 21.2, 354135.9 6688692.4 21.2, 354135.5 6688692.7 21.2, 354134.9 6688693.1 21.2, 354133.9 6688693.8 21.2, 354132.6 6688694.8 21.2, 354132.3 6688695 21.2, 354131.8 6688695.6 21.2, 354131.5 6688695.8 21.2, 354130.9 6688696.4 21.2, 354130 6688697.2 21.2, 354129.8 6688697.6 21.2, 354129.5 6688697.8 21.2, 354129 6688698.4 21.2, 354128.2 6688699.4 21.2, 354127.5 6688700.3 21.2, 354127.3 6688700.7 21.2, 354126.4 6688702 21.2, 354147.4 6688709.9 21.2, 354147.8 6688709.1 21.2, 354150.2 6688710.8 21.2, 354149.2 6688712.1 21.2, 354154.7 6688716.2 21.2, 354158.7 6688710.8 21.2, 354165.2 6688701.9 21.2))
BATIMENT0000000302923574;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;7.3;14.1;15.5;8.0;Cadastre;;POLYGON Z ((354175.6 6688713.5 14.1, 354170.6 6688709.9 14.1, 354160.4 6688723.9 14.1, 354165.3 6688727.4 14.1, 354175.6 6688713.5 14.1))
BATIMENT0000000302923307;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;7.2;19.2;21.1;7.3;Cadastre;;POLYGON Z ((354129.4 6688724.1 19.2, 354129 6688725.3 19.2, 354132.2 6688726.4 19.2, 354132.7 6688725.3 19.2, 354129.4 6688724.1 19.2))
BATIMENT0000000302923306;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.8;7.2;21.0;24.7;8.1;Cadastre;A 1.0;POLYGON Z ((354122.7 6688721.6 21, 354113.5 6688746.2 21, 354105.1 6688743 21, 354105.6 6688741.8 21, 354103.7 6688741.1 21, 354103.2 6688742.3 21, 354100.3 6688750.2 21, 354097.8 6688756.9 21, 354117.1 6688764.7 21, 354117.7 6688763 21, 354118.4 6688761.2 21, 354121 6688762.2 21, 354122.9 6688759.3 21, 354124.2 6688757.3 21, 354125.2 6688755.8 21, 354131.7 6688747 21, 354129.9 6688745.7 21, 354132.7 6688738.7 21, 354131.8 6688738.4 21, 354133 6688735.7 21, 354133.8 6688735.9 21, 354136.9 6688728.1 21, 354132.2 6688726.4 21, 354129 6688725.3 21, 354129.4 6688724.1 21, 354122.7 6688721.6 21))
BATIMENT0000000302923277;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;00;00;12.6;7.0;19.7;24.0;7.7;Cadastre;C 0.7;POLYGON Z ((354133 6688761.4 19.7, 354133.8 6688769.9 19.7, 354137.9 6688771.4 19.7, 354156.9 6688779 19.7, 354161.1 6688773.1 19.7, 354163.1 6688770.3 19.7, 354165.1 6688767.6 19.7, 354166 6688766.3 19.7, 354150.2 6688759.8 19.7, 354155.9 6688752.7 19.7, 354171 6688731.5 19.7, 354165.3 6688727.4 19.7, 354160.4 6688723.9 19.7, 354133 6688761.4 19.7))
BATIMENT0000000302923352;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.9;7.0;9.0;9.7;7.5;Cadastre;;POLYGON Z ((354166.8 6688751.4 9, 354164.8 6688750.3 9, 354163.6 6688752.7 9, 354165.5 6688753.8 9, 354166.8 6688751.4 9))
BATIMENT0000000302923271;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;7.0;10.8;11.2;7.2;Cadastre;;POLYGON Z ((354172 6688761 10.8, 354176 6688758.7 10.8, 354174.8 6688756.9 10.8, 354176 6688755.1 10.8, 354174.8 6688754.1 10.8, 354170.7 6688759.7 10.8, 354172 6688761 10.8))
BATIMENT0000000302923270;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;6.9;11.7;15.5;7.2;Cadastre;;POLYGON Z ((354177 6688758.5 11.7, 354179 6688761.2 11.7, 354182.8 6688759.4 11.7, 354177.8 6688756.1 11.7, 354177 6688758.5 11.7))
BATIMENT0000000302923189;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;7.0;9.3;9.6;7.4;Cadastre;;POLYGON Z ((354209.3 6688719 9.3, 354211.2 6688720.4 9.3, 354214 6688716.6 9.3, 354211.9 6688715.2 9.3, 354209.3 6688719 9.3))
BATIMENT0000000302923190;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:49;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.2;6.1;11.3;11.7;7.7;Cadastre;C 0.1;POLYGON Z ((354219.2 6688735.7 11.3, 354223.5 6688733.6 11.3, 354217.9 6688723.5 11.3, 354219.7 6688719.3 11.3, 354221.6 6688716.5 11.3, 354218.7 6688714.6 11.3, 354217.5 6688713.8 11.3, 354214.7 6688716.5 11.3, 354211.1 6688721.8 11.3, 354212.2 6688723.7 11.3, 354219.2 6688735.7 11.3))
BATIMENT0000000302923575;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.5;6.9;11.4;11.8;7.6;Cadastre;C 0.4;POLYGON Z ((354183.3 6688740.4 11.4, 354184.1 6688739.2 11.4, 354192.6 6688745 11.4, 354196.5 6688743.8 11.4, 354200.9 6688737.3 11.4, 354202.5 6688734.8 11.4, 354204.1 6688732.4 11.4, 354205.6 6688730.2 11.4, 354184.7 6688715 11.4, 354180.9 6688712.4 11.4, 354179.3 6688714.9 11.4, 354176.2 6688712.8 11.4, 354175.6 6688713.5 11.4, 354165.3 6688727.4 11.4, 354171 6688731.5 11.4, 354183.3 6688740.4 11.4))
BATIMENT0000000302923314;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;5.9;17.0;23.5;6.5;Cadastre;;POLYGON Z ((354254.8 6688732.2 17, 354256.9 6688733.5 17, 354258.4 6688725.2 17, 354254.8 6688732.2 17))
BATIMENT0000000302923315;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;25;90;20.0;6.0;26.0;26.7;7.0;Cadastre;C 0.4;POLYGON Z ((354248.4 6688723 26, 354238.1 6688728.7 26, 354237.7 6688730.2 26, 354238.8 6688732.1 26, 354235.7 6688733.5 26, 354235.2 6688732.8 26, 354231.1 6688735 26, 354231.5 6688736 26, 354223 6688740.8 26, 354226.8 6688747.2 26, 354228.3 6688749.7 26, 354256.9 6688733.5 26, 354254.8 6688732.2 26, 354258.4 6688725.2 26, 354260.9 6688711.6 26, 354251.5 6688709.6 26, 354248.4 6688723 26))
BATIMENT0000000302923278;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;6.8;10.2;11.7;7.3;Cadastre;;POLYGON Z ((354208.2 6688744.4 10.2, 354210.4 6688743 10.2, 354204.1 6688732.4 10.2, 354202.5 6688734.8 10.2, 354208.2 6688744.4 10.2))
BATIMENT0000000302923572;Industriel, agricole ou commercial;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.1;6.6;11.7;14.7;7.2;Cadastre;C 0.1;POLYGON Z ((354201.2 6688751.8 11.7, 354207.4 6688748.3 11.7, 354200.9 6688737.3 11.7, 354196.5 6688743.8 11.7, 354201.2 6688751.8 11.7))
BATIMENT0000000302923573;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.2;6.9;17.1;19.9;7.1;Cadastre;;POLYGON Z ((354206.9 6688761.5 17.1, 354217.7 6688755.2 17.1, 354212 6688745.7 17.1, 354207.4 6688748.3 17.1, 354201.2 6688751.8 17.1, 354202 6688753.2 17.1, 354206.9 6688761.5 17.1))
BATIMENT0000000302923272;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;35;23;14.6;7.0;21.6;25.8;7.0;Cadastre;C 0.3;POLYGON Z ((354206.9 6688761.5 21.6, 354202 6688753.2 21.6, 354196.7 6688756.2 21.6, 354195.7 6688754.3 21.6, 354190.7 6688756.5 21.6, 354189.9 6688755 21.6, 354183.8 6688758.2 21.6, 354184.9 6688760.1 21.6, 354191.1 6688770.5 21.6, 354206.9 6688761.5 21.6))
BATIMENT0000000302923351;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;6.3;9.5;10.9;7.0;Cadastre;;POLYGON Z ((354200.2 6688796.4 9.5, 354207.9 6688799.6 9.5, 354209.4 6688796.1 9.5, 354201.7 6688792.8 9.5, 354200.2 6688796.4 9.5))
BATIMENT0000000302923549;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;39.0;6.0;00;00;17.2;6.7;23.9;27.6;8.2;Cadastre;C 0.3;POLYGON Z ((354304.6 6688754.4 23.9, 354302.5 6688758.1 23.9, 354310.9 6688762.5 23.9, 354311.8 6688760.9 23.9, 354313.4 6688761.6 23.9, 354312.9 6688762.6 23.9, 354313.4 6688763.8 23.9, 354314.3 6688764.2 23.9, 354315.7 6688763.8 23.9, 354316 6688763 23.9, 354317.5 6688764 23.9, 354316.7 6688765.5 23.9, 354325.3 6688769.9 23.9, 354327.2 6688766 23.9, 354330.2 6688767.5 23.9, 354333.5 6688760.6 23.9, 354328.6 6688758.3 23.9, 354331.2 6688753.8 23.9, 354312.7 6688744.8 23.9, 354311.1 6688748.5 23.9, 354305.4 6688745.4 23.9, 354303.7 6688749.1 23.9, 354301.8 6688752.9 23.9, 354303.5 6688753.9 23.9, 354304.6 6688754.4 23.9))
BATIMENT0000000302923258;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.1;6.8;23.9;24.5;7.1;Cadastre;;POLYGON Z ((354313.4 6688763.8 23.9, 354312.9 6688762.6 23.9, 354313.4 6688761.6 23.9, 354311.8 6688760.9 23.9, 354310.9 6688762.5 23.9, 354313.4 6688763.8 23.9))
BATIMENT0000000302923279;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;13;90;8.1;7.0;15.1;18.1;7.1;Cadastre;A 1.0;POLYGON Z ((354279.6 6688764.2 15.1, 354282.9 6688758.3 15.1, 354271.5 6688752.4 15.1, 354270.9 6688752.8 15.1, 354266.2 6688761 15.1, 354264.1 6688772.6 15.1, 354269.3 6688773.6 15.1, 354270.2 6688769.7 15.1, 354269.4 6688769.6 15.1, 354270.4 6688763.3 15.1, 354281.1 6688769.4 15.1, 354283 6688766 15.1, 354279.6 6688764.2 15.1))
BATIMENT0000000302923257;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.0;6.9;23.9;24.2;7.0;Cadastre;;POLYGON Z ((354316.7 6688765.5 23.9, 354317.5 6688764 23.9, 354316 6688763 23.9, 354315.7 6688763.8 23.9, 354314.3 6688764.2 23.9, 354316.7 6688765.5 23.9))
BATIMENT0000000302923281;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;7.0;00;00;19.6;6.3;26.0;28.6;7.1;Cadastre;A 1.0;POLYGON Z ((354294.6 6688776.5 26, 354305.3 6688771.1 26, 354305.8 6688769.9 26, 354285.7 6688759.7 26, 354284.6 6688762 26, 354285.2 6688762.3 26, 354283 6688766 26, 354281.1 6688769.4 26, 354294.6 6688776.5 26))
BATIMENT0000000302923256;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;6.7;24.0;25.8;7.5;Cadastre;;POLYGON Z ((354328.2 6688771.5 24, 354328.8 6688770.3 24, 354330.2 6688767.5 24, 354327.2 6688766 24, 354325.3 6688769.9 24, 354328.2 6688771.5 24))
BATIMENT0000000302923254;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.7;6.7;21.5;23.6;7.3;Cadastre;;POLYGON Z ((354332.2 6688773.4 21.5, 354349.5 6688765 21.5, 354349.1 6688764.6 21.5, 354347.5 6688765.3 21.5, 354347 6688765 21.5, 354332.1 6688772 21.5, 354328.8 6688770.3 21.5, 354328.2 6688771.5 21.5, 354332.2 6688773.4 21.5))
BATIMENT0000000302923284;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.2;6.3;25.5;28.6;6.7;Cadastre;;POLYGON Z ((354305.3 6688771.1 25.5, 354294.6 6688776.5 25.5, 354300.9 6688779.8 25.5, 354305.3 6688771.1 25.5))
BATIMENT0000000302923282;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;62.0;7.0;00;00;13.3;6.4;19.7;28.5;7.0;Cadastre;A 1.0;POLYGON Z ((354322.5 6688778.7 19.7, 354321 6688777.9 19.7, 354313.2 6688773.4 19.7, 354310.9 6688772.3 19.7, 354309.2 6688771.5 19.7, 354306.7 6688770.3 19.7, 354305.8 6688769.9 19.7, 354305.3 6688771.1 19.7, 354300.9 6688779.8 19.7, 354294.6 6688776.5 19.7, 354281.1 6688769.4 19.7, 354279.4 6688772.5 19.7, 354273.8 6688775 19.7, 354273.2 6688774.2 19.7, 354271.5 6688773.9 19.7, 354269.8 6688781.4 19.7, 354270.5 6688781.9 19.7, 354270.1 6688783.3 19.7, 354273.7 6688788.6 19.7, 354274 6688789.1 19.7, 354275 6688790.9 19.7, 354275.8 6688792.2 19.7, 354280.2 6688799.7 19.7, 354322.5 6688778.7 19.7))
BATIMENT0000000302923283;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.7;6.4;20.2;26.2;6.7;Cadastre;;POLYGON Z ((354268.8 6688785.8 20.2, 354268.5 6688788.6 20.2, 354273 6688788.9 20.2, 354273 6688788.4 20.2, 354271.2 6688785.6 20.2, 354268.8 6688785.8 20.2))
BATIMENT0000000302923308;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;7.2;15.5;18.7;7.5;Cadastre;;POLYGON Z ((354117.7 6688763 15.5, 354120.4 6688763.1 15.5, 354121 6688762.2 15.5, 354118.4 6688761.2 15.5, 354117.7 6688763 15.5))
BATIMENT0000000302923273;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;15.2;7.0;22.2;25.5;7.1;Cadastre;C 0.8;POLYGON Z ((354172.7 6688781 22.2, 354191.1 6688770.5 22.2, 354184.9 6688760.1 22.2, 354167.1 6688770.1 22.2, 354171.1 6688778.1 22.2, 354172.7 6688781 22.2))
BATIMENT0000000302923275;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;7.0;;;;Cadastre;;POLYGON Z ((354163.1 6688770.3 -1000, 354166 6688775.3 -1000, 354167.4 6688774.6 -1000, 354169.5 6688778.7 -1000, 354171.1 6688778.1 -1000, 354167.1 6688770.1 -1000, 354165.8 6688767.8 -1000, 354168.1 6688764.6 -1000, 354167.6 6688763.9 -1000, 354166 6688766.3 -1000, 354165.1 6688767.6 -1000, 354163.1 6688770.3 -1000))
BATIMENT0000000302923274;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.1;7.0;22.1;23.4;7.1;Cadastre;A 1.0;POLYGON Z ((354161.1 6688773.1 22.1, 354156.9 6688779 22.1, 354168.3 6688783.6 22.1, 354171.2 6688781.9 22.1, 354170.3 6688780 22.1, 354161.1 6688773.1 22.1))
BATIMENT0000000302923333;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;;;6.8;7.0;13.9;14.3;7.8;Cadastre;A 1.0;POLYGON Z ((354134.9 6688795.8 13.9, 354129.9 6688785.9 13.9, 354124 6688783.7 13.9, 354106.9 6688805.1 13.9, 354109.3 6688808.9 13.9, 354134.9 6688795.8 13.9))
BATIMENT0000000302922982;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;6.3;19.6;21.6;10.5;Cadastre;;POLYGON Z ((354146.3 6688836.9 19.6, 354154.5 6688832.8 19.6, 354138.7 6688801.4 19.6, 354103.9 6688819.1 19.6, 354110.7 6688833.1 19.6, 354111.4 6688834.7 19.6, 354113.4 6688839 19.6, 354117.9 6688836.5 19.6, 354140.7 6688825.3 19.6, 354141 6688825.7 19.6, 354143.4 6688830.8 19.6, 354146.3 6688836.9 19.6))
BATIMENT0000000302923318;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;67.0;5.0;00;00;12.8;6.7;19.5;23.1;6.9;Cadastre;A 1.0;POLYGON Z ((354150.4 6688807.4 19.5, 354151.3 6688809.3 19.5, 354152.7 6688812.1 19.5, 354172.3 6688852.2 19.5, 354199 6688838.9 19.5, 354193.8 6688828.1 19.5, 354178.5 6688835.7 19.5, 354171.7 6688821.9 19.5, 354169.9 6688822.8 19.5, 354167.4 6688817.9 19.5, 354172.6 6688815.3 19.5, 354178 6688817.4 19.5, 354177.6 6688818.5 19.5, 354186.7 6688822 19.5, 354188.3 6688821.4 19.5, 354194.8 6688823.9 19.5, 354195.8 6688823.3 19.5, 354196.8 6688824.2 19.5, 354198 6688820.9 19.5, 354198.8 6688819.6 19.5, 354201.2 6688814.3 19.5, 354153.7 6688795.2 19.5, 354153.6 6688795.2 19.5, 354152.7 6688794.9 19.5, 354152.2 6688794.9 19.5, 354151.2 6688795 19.5, 354150.4 6688795.1 19.5, 354149.5 6688795.6 19.5, 354148.7 6688796.1 19.5, 354147.9 6688797.1 19.5, 354147.6 6688797.7 19.5, 354147.2 6688798.7 19.5, 354147.1 6688799.6 19.5, 354147.2 6688800.9 19.5, 354150.4 6688807.4 19.5))
BATIMENT0000000302922989;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;2.7;7.8;10.5;;;Cadastre;C 0.4;POLYGON Z ((354150.5 6688844.6 10.5, 354158.4 6688840.7 10.5, 354157.6 6688839 10.5, 354149.6 6688843 10.5, 354150.5 6688844.6 10.5))
BATIMENT0000000302922988;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;8.0;00;00;2.7;6.1;8.8;15.2;7.9;Cadastre;B 0.2;POLYGON Z ((354147.1 6688838.4 8.8, 354142.3 6688840.7 8.8, 354141.7 6688839.4 8.8, 354124 6688848.3 8.8, 354126.5 6688853.4 8.8, 354143.5 6688844.9 8.8, 354143.9 6688845.9 8.8, 354149.6 6688843 8.8, 354157.6 6688839 8.8, 354154.5 6688832.8 8.8, 354146.3 6688836.9 8.8, 354147.1 6688838.4 8.8))
BATIMENT0000000302922983;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;6.0;11.0;12.9;6.6;Cadastre;;POLYGON Z ((354160.9 6688845.6 11, 354155.2 6688848.3 11, 354156.5 6688850.4 11, 354162 6688847.7 11, 354160.9 6688845.6 11))
BATIMENT0000000302923280;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;7.0;00;00;18.3;7.0;25.3;;;Cadastre;A 1.0;POLYGON Z ((354259.5 6688798.3 25.3, 354262.2 6688804.3 25.3, 354268.2 6688805.7 25.3, 354280.2 6688799.7 25.3, 354275.8 6688792.2 25.3, 354275 6688790.9 25.3, 354268.6 6688794.2 25.3, 354267.9 6688792.6 25.3, 354268.5 6688788.6 25.3, 354268.8 6688785.8 25.3, 354269 6688784.2 25.3, 354270.6 6688784.4 25.3, 354271.2 6688785.6 25.3, 354273 6688788.4 25.3, 354273.7 6688788.6 25.3, 354270.1 6688783.3 25.3, 354270.5 6688781.9 25.3, 354269.8 6688781.4 25.3, 354271.5 6688773.9 25.3, 354269.3 6688773.6 25.3, 354264.1 6688772.6 25.3, 354259.5 6688798.3 25.3))
BATIMENT0000000302923220;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;7.0;;;16.5;6.7;23.3;26.6;8.4;Cadastre;A 0.1;POLYGON Z ((354334.6 6688804.9 23.3, 354337.1 6688803.7 23.3, 354338.4 6688805.9 23.3, 354343.7 6688803.2 23.3, 354342.3 6688800.9 23.3, 354349.2 6688796.4 23.3, 354349.1 6688796.1 23.3, 354347.2 6688790.8 23.3, 354346.1 6688787.6 23.3, 354344.6 6688783 23.3, 354323.3 6688793.6 23.3, 354326.6 6688808.8 23.3, 354334.6 6688804.9 23.3))
BATIMENT0000000302923223;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;00;00;10.2;6.8;17.0;23.8;9.8;Cadastre;A 1.0;POLYGON Z ((354317.8 6688805.6 17, 354318.4 6688809.4 17, 354320.8 6688822.7 17, 354321.8 6688822.6 17, 354329.1 6688820.8 17, 354326.6 6688808.8 17, 354323.3 6688793.6 17, 354314.4 6688798 17, 354317.8 6688805.6 17))
BATIMENT0000000302923234;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;8.0;00;00;20.2;6.5;26.7;29.1;9.7;Cadastre;A 1.0;POLYGON Z ((354288.4 6688810.9 26.7, 354288.3 6688811 26.7, 354288 6688811.3 26.7, 354287.8 6688811.4 26.7, 354287.7 6688811.5 26.7, 354287.6 6688811.7 26.7, 354287.5 6688811.8 26.7, 354287.3 6688812.2 26.7, 354287.2 6688812.5 26.7, 354287.1 6688812.9 26.7, 354287.1 6688813.3 26.7, 354287.1 6688813.5 26.7, 354287.1 6688813.7 26.7, 354287.2 6688814 26.7, 354287.3 6688814.4 26.7, 354290.7 6688822.6 26.7, 354292.1 6688823.8 26.7, 354295.2 6688823.8 26.7, 354295.2 6688820.9 26.7, 354298.4 6688819.4 26.7, 354298.6 6688819.8 26.7, 354301.4 6688818.4 26.7, 354302 6688819.6 26.7, 354307.2 6688819.4 26.7, 354306.1 6688817 26.7, 354311 6688814.6 26.7, 354310.4 6688813.4 26.7, 354318.4 6688809.4 26.7, 354317.8 6688805.6 26.7, 354314.4 6688798 26.7, 354288.4 6688810.9 26.7))
BATIMENT0000000302923543;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;00;00;18.0;6.5;24.5;27.9;7.8;Cadastre;C 0.8;POLYGON Z ((354290.9 6688837.5 24.5, 354292.6 6688832.9 24.5, 354287.1 6688831.1 24.5, 354285.4 6688829.4 24.5, 354283.6 6688830.3 24.5, 354282.7 6688830.7 24.5, 354281.5 6688828.4 24.5, 354284.1 6688827 24.5, 354283.3 6688825.7 24.5, 354290.7 6688822.6 24.5, 354287.3 6688814.4 24.5, 354273 6688821.3 24.5, 354278.4 6688833.2 24.5, 354290.9 6688837.5 24.5))
BATIMENT0000000302923225;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;10.0;15.7;16.7;10.2;Cadastre;;POLYGON Z ((354321.8 6688822.6 15.7, 354320.8 6688822.7 15.7, 354319 6688827.8 15.7, 354323.4 6688829.3 15.7, 354324.5 6688829.6 15.7, 354327.4 6688827.9 15.7, 354340.9 6688832.6 15.7, 354343 6688826 15.7, 354338.8 6688822.5 15.7, 354338.4 6688822.1 15.7, 354334.5 6688819.5 15.7, 354329.1 6688820.8 15.7, 354321.8 6688822.6 15.7))
BATIMENT0000000302923542;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;6.7;20.0;25.7;8.0;Cadastre;;POLYGON Z ((354285.4 6688829.4 20, 354287.1 6688831.1 20, 354287.9 6688829.1 20, 354293.3 6688831 20, 354295.6 6688823.9 20, 354295.2 6688823.8 20, 354292.1 6688823.8 20, 354290.7 6688822.6 20, 354283.3 6688825.7 20, 354284.1 6688827 20, 354285.4 6688829.4 20))
BATIMENT0000000302923245;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;7.5;10.1;11.2;9.7;Cadastre;;POLYGON Z ((354304.2 6688828.9 10.1, 354305 6688824 10.1, 354302.8 6688824 10.1, 354301.3 6688824 10.1, 354299.6 6688829.5 10.1, 354302.6 6688830.5 10.1, 354302.8 6688828.7 10.1, 354304.2 6688828.9 10.1))
BATIMENT0000000302923229;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;20;20;5.0;7.9;13.0;16.9;9.8;Cadastre;C 0.6;POLYGON Z ((354312.3 6688823.6 13, 354310.3 6688830.4 13, 354317.3 6688832.6 13, 354317.7 6688831.5 13, 354318.3 6688829.9 13, 354319 6688827.8 13, 354320.8 6688822.7 13, 354312.3 6688823.6 13))
BATIMENT0000000302923243;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;12;20;13.5;6.9;20.5;26.7;9.7;Cadastre;C 0.8;POLYGON Z ((354312.7 6688845.1 20.5, 354315.1 6688838.6 20.5, 354315.8 6688836.7 20.5, 354316.4 6688835.1 20.5, 354305.4 6688831.4 20.5, 354304.1 6688835.2 20.5, 354302 6688834.6 20.5, 354302.6 6688830.5 20.5, 354299.6 6688829.5 20.5, 354301.3 6688824 20.5, 354295.6 6688823.9 20.5, 354293.3 6688831 20.5, 354292.6 6688832.9 20.5, 354290.9 6688837.5 20.5, 354312.7 6688845.1 20.5))
BATIMENT0000000302923242;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;8.3;27.7;30.4;10.4;Cadastre;;POLYGON Z ((354334.4 6688852.4 27.7, 354337.1 6688844.2 27.7, 354337.5 6688843.2 27.7, 354337.6 6688842.5 27.7, 354338.8 6688839.1 27.7, 354332.9 6688837.2 27.7, 354333.2 6688836.3 27.7, 354329.3 6688835.3 27.7, 354329.6 6688834.1 27.7, 354326.1 6688833 27.7, 354325.3 6688835.3 27.7, 354323.8 6688834.9 27.7, 354324 6688833.4 27.7, 354317.7 6688831.5 27.7, 354317.3 6688832.6 27.7, 354316.4 6688835.1 27.7, 354315.8 6688836.7 27.7, 354315.1 6688838.6 27.7, 354312.7 6688845.1 27.7, 354334.4 6688852.4 27.7))
BATIMENT0000000302923293;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;36.0;6.0;01;02;13.6;6.5;20.2;26.5;7.8;Cadastre;A 1.0;POLYGON Z ((354288 6688847.1 20.2, 354286.3 6688848.1 20.2, 354280.2 6688846 20.2, 354279.7 6688844.3 20.2, 354273.3 6688842 20.2, 354256.5 6688849.9 20.2, 354255.3 6688857.7 20.2, 354279.4 6688877.5 20.2, 354285 6688863.4 20.2, 354291 6688848.2 20.2, 354288 6688847.1 20.2))
BATIMENT0000000302923295;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;8.1;13.9;17.0;9.2;Cadastre;;POLYGON Z ((354326.2 6688869.8 13.9, 354311.3 6688857.9 13.9, 354309.3 6688856.3 13.9, 354309.1 6688856.7 13.9, 354309 6688857.2 13.9, 354308.7 6688857.5 13.9, 354325.3 6688870.9 13.9, 354326.2 6688869.8 13.9))
BATIMENT0000000302923301;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.8;7.9;20.7;22.2;8.2;Cadastre;;POLYGON Z ((354303 6688862.5 20.7, 354300.9 6688865 20.7, 354301.7 6688865.7 20.7, 354303.8 6688863.2 20.7, 354303 6688862.5 20.7))
BATIMENT0000000302923296;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.7;8.0;22.7;22.9;8.2;Cadastre;;POLYGON Z ((354297.4 6688869 22.7, 354296.1 6688871 22.7, 354296.9 6688871.6 22.7, 354298.4 6688869.8 22.7, 354297.4 6688869 22.7))
BATIMENT0000000302923297;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;8.0;21.7;23.0;8.5;Cadastre;;POLYGON Z ((354296.3 6688872.5 21.7, 354301.5 6688876.7 21.7, 354302.4 6688876 21.7, 354302.5 6688876 21.7, 354296.9 6688871.6 21.7, 354296.3 6688872.5 21.7))
BATIMENT0000000302923294;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;8.9;22.5;;;Cadastre;;POLYGON Z ((354283.1 6688880.6 22.5, 354283.7 6688879.9 22.5, 354285.7 6688875.5 22.5, 354281.8 6688873.9 22.5, 354280.1 6688878.1 22.5, 354283.1 6688880.6 22.5))
BATIMENT0000000302923551;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;107.0;7.0;00;00;14.7;7.7;22.5;31.4;11.8;Cadastre;C 0.5;POLYGON Z ((354281.8 6688873.9 22.5, 354285.7 6688875.5 22.5, 354283.7 6688879.9 22.5, 354283.1 6688880.6 22.5, 354289.1 6688885.5 22.5, 354289.7 6688884.6 22.5, 354297.4 6688890.6 22.5, 354297.8 6688892.6 22.5, 354300.8 6688895.1 22.5, 354301.3 6688894.2 22.5, 354303.6 6688896.1 22.5, 354303 6688896.9 22.5, 354323.8 6688913.9 22.5, 354327.1 6688909.9 22.5, 354320.9 6688904.3 22.5, 354321.9 6688899.5 22.5, 354319.2 6688897.4 22.5, 354320.4 6688895.6 22.5, 354318.8 6688894.4 22.5, 354327.9 6688885.1 22.5, 354331.2 6688890.9 22.5, 354331.7 6688891 22.5, 354332.6 6688885.8 22.5, 354343.6 6688889.4 22.5, 354345.2 6688884.4 22.5, 354347.1 6688878.6 22.5, 354350.6 6688868.4 22.5, 354345.4 6688866.7 22.5, 354336.3 6688863.5 22.5, 354325.3 6688859.8 22.5, 354324.8 6688861 22.5, 354324.4 6688861.6 22.5, 354324 6688862.3 22.5, 354323.7 6688862.6 22.5, 354323.1 6688862.8 22.5, 354322.6 6688863.1 22.5, 354321.9 6688863.3 22.5, 354321.2 6688863.4 22.5, 354320.4 6688863.3 22.5, 354319.9 6688863.3 22.5, 354319.2 6688863.1 22.5, 354318.6 6688862.7 22.5, 354318 6688862.4 22.5, 354317.6 6688862 22.5, 354317.1 6688861.5 22.5, 354316.9 6688860.9 22.5, 354316.6 6688860.3 22.5, 354316.5 6688859.7 22.5, 354316.4 6688859.1 22.5, 354316.5 6688858.1 22.5, 354316.7 6688856.9 22.5, 354291 6688848.2 22.5, 354285 6688863.4 22.5, 354279.4 6688877.5 22.5, 354280.1 6688878.1 22.5, 354281.8 6688873.9 22.5), (354296.1 6688871 22.5, 354297.4 6688869 22.5, 354298.4 6688869.8 22.5, 354301.7 6688865.7 22.5, 354300.9 6688865 22.5, 354303 6688862.5 22.5, 354303.8 6688863.2 22.5, 354306 6688860.4 22.5, 354305.3 6688859.6 22.5, 354306.7 6688857.9 22.5, 354307.3 6688858 22.5, 354307.9 6688857.9 22.5, 354308.5 6688857.7 22.5, 354308.7 6688857.5 22.5, 354309 6688857.2 22.5, 354309.1 6688856.7 22.5, 354309.3 6688856.3 22.5, 354311.3 6688857.9 22.5, 354326.2 6688869.8 22.5, 354325.3 6688870.9 22.5, 354313.8 6688885.4 22.5, 354313.2 6688886.2 22.5, 354310.5 6688884 22.5, 354307.5 6688881.6 22.5, 354307.6 6688881.4 22.5, 354307.8 6688881 22.5, 354307.8 6688880.8 22.5, 354307.9 6688880.6 22.5, 354308.1 6688880.1 22.5, 354308.2 6688879.7 22.5, 354308.2 6688879.2 22.5, 354308.1 6688878.6 22.5, 354307.8 6688877.8 22.5, 354307.6 6688877.3 22.5, 354307.1 6688876.8 22.5, 354306.5 6688876.3 22.5, 354306.1 6688876 22.5, 354305.6 6688875.8 22.5, 354304.9 6688875.6 22.5, 354304.2 6688875.6 22.5, 354303.6 6688875.6 22.5, 354303 6688875.8 22.5, 354302.5 6688876 22.5, 354302.4 6688876 22.5, 354301.5 6688876.7 22.5, 354296.3 6688872.5 22.5, 354296.9 6688871.6 22.5, 354296.1 6688871 22.5))
BATIMENT0000000302923298;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;8.1;23.0;23.7;9.2;Cadastre;;POLYGON Z ((354307.8 6688881 23, 354307.6 6688881.4 23, 354307.5 6688881.6 23, 354310.5 6688884 23, 354313.2 6688886.2 23, 354313.8 6688885.4 23, 354307.8 6688880.8 23, 354307.8 6688881 23))
BATIMENT0000000302923299;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.5;6.5;27.0;27.9;8.8;Cadastre;;POLYGON Z ((354297.8 6688892.6 27, 354297.4 6688890.6 27, 354289.7 6688884.6 27, 354289.1 6688885.5 27, 354297.8 6688892.6 27))
BATIMENT0000000302923319;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;12;20;12.2;6.6;18.8;;;Cadastre;A 1.0;POLYGON Z ((354198 6688820.9 18.8, 354196.8 6688824.2 18.8, 354195.8 6688823.3 18.8, 354194.8 6688823.9 18.8, 354192.5 6688825.3 18.8, 354193.8 6688828.1 18.8, 354199 6688838.9 18.8, 354219.5 6688828.8 18.8, 354215.1 6688819.9 18.8, 354201.2 6688814.3 18.8, 354198.8 6688819.6 18.8, 354198 6688820.9 18.8), (354198.1 6688824.3 18.8, 354200.7 6688825.1 18.8, 354201.6 6688825.9 18.8, 354199.3 6688827.2 18.8, 354197.7 6688825 18.8, 354198.1 6688824.3 18.8))
BATIMENT0000000302923017;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.0;5.3;15.4;25.0;6.3;Cadastre;;POLYGON Z ((354233.6 6688855 15.4, 354229.5 6688846.4 15.4, 354192.7 6688864.4 15.4, 354198.2 6688875.9 15.4, 354202.1 6688874.2 15.4, 354201.5 6688877.3 15.4, 354215 6688879.7 15.4, 354220.9 6688880.8 15.4, 354222.5 6688872.5 15.4, 354222 6688873 15.4, 354221.4 6688873.4 15.4, 354220.9 6688873.8 15.4, 354220.3 6688874.2 15.4, 354219.6 6688874.5 15.4, 354219 6688874.8 15.4, 354218.3 6688875 15.4, 354217.6 6688875.1 15.4, 354216.9 6688875.2 15.4, 354216.2 6688875.3 15.4, 354215.5 6688875.2 15.4, 354214.8 6688875.2 15.4, 354214.1 6688875 15.4, 354213.4 6688874.8 15.4, 354212.8 6688874.6 15.4, 354212.3 6688874.4 15.4, 354211.7 6688874.1 15.4, 354211.2 6688873.8 15.4, 354210.7 6688873.4 15.4, 354210.3 6688873 15.4, 354209.8 6688872.5 15.4, 354209.4 6688872 15.4, 354209.1 6688871.5 15.4, 354208.8 6688871 15.4, 354223.4 6688863.5 15.4, 354227.9 6688861.2 15.4, 354232.2 6688862 15.4, 354233.6 6688855 15.4))
BATIMENT0000000302923018;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;10;90;9.2;7.0;16.2;;;Cadastre;A 1.0;POLYGON Z ((354181.7 6688869.8 16.2, 354187.4 6688881.4 16.2, 354197.6 6688876.5 16.2, 354198.2 6688875.9 16.2, 354192.7 6688864.4 16.2, 354181.7 6688869.8 16.2))
BATIMENT0000000302923020;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;00;00;6.9;5.5;12.5;15.7;6.4;Cadastre;A 1.0;POLYGON Z ((354232.2 6688862 12.5, 354227.9 6688861.2 12.5, 354223.4 6688863.5 12.5, 354223.7 6688864.1 12.5, 354223.9 6688864.7 12.5, 354224.1 6688865.4 12.5, 354224.2 6688866.1 12.5, 354224.3 6688866.7 12.5, 354224.3 6688867.4 12.5, 354224.3 6688868.1 12.5, 354224.2 6688868.8 12.5, 354224 6688869.4 12.5, 354223.8 6688870.1 12.5, 354223.5 6688870.7 12.5, 354223.2 6688871.3 12.5, 354222.9 6688871.9 12.5, 354222.5 6688872.5 12.5, 354220.9 6688880.8 12.5, 354215 6688879.7 12.5, 354214 6688883.4 12.5, 354218.7 6688884 12.5, 354218 6688887.3 12.5, 354213.5 6688886.2 12.5, 354212.8 6688889.6 12.5, 354226.6 6688892.3 12.5, 354232.2 6688862 12.5))
BATIMENT0000000302923019;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.7;5.8;10.5;14.2;6.5;Cadastre;A 1.0;POLYGON Z ((354195.7 6688886.4 10.5, 354212.8 6688889.6 10.5, 354213.5 6688886.2 10.5, 354214 6688883.4 10.5, 354215 6688879.7 10.5, 354201.5 6688877.3 10.5, 354202.1 6688874.2 10.5, 354198.2 6688875.9 10.5, 354197.6 6688876.5 10.5, 354195.7 6688886.4 10.5))
BATIMENT0000000302923022;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;6.2;12.9;15.9;6.8;Cadastre;A 1.0;POLYGON Z ((354189.4 6688885.1 12.9, 354193.1 6688893.4 12.9, 354225.3 6688899.4 12.9, 354226.6 6688892.3 12.9, 354212.8 6688889.6 12.9, 354195.7 6688886.4 12.9, 354189.4 6688885.1 12.9))
BATIMENT0000000302923214;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;20;20;12.6;4.8;17.4;25.5;8.4;Cadastre;C 0.6;POLYGON Z ((354241.6 6688935.7 17.4, 354241.1 6688939.2 17.4, 354246.2 6688940.2 17.4, 354251.4 6688941.1 17.4, 354251.8 6688939.5 17.4, 354248.7 6688939 17.4, 354249.6 6688934.9 17.4, 354242.6 6688933.5 17.4, 354244.5 6688924.6 17.4, 354245.8 6688924.9 17.4, 354246.4 6688922 17.4, 354244.9 6688921.8 17.4, 354248.2 6688904.6 17.4, 354251.6 6688886.9 17.4, 354256.2 6688885.2 17.4, 354264.9 6688892.5 17.4, 354264.7 6688892.9 17.4, 354270.1 6688897.4 17.4, 354270.5 6688896.9 17.4, 354279.7 6688904.5 17.4, 354280.9 6688902.8 17.4, 354280.4 6688902.3 17.4, 354285.8 6688896.2 17.4, 354251.8 6688868.2 17.4, 354246 6688870.5 17.4, 354234.2 6688934.5 17.4, 354241.6 6688935.7 17.4))
BATIMENT0000000302923212;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;5.9;9.8;19.0;6.5;Cadastre;;POLYGON Z ((354279.4 6688905.2 9.8, 354269.8 6688901.4 9.8, 354269.1 6688904.4 9.8, 354254 6688901.5 9.8, 354253.1 6688906.5 9.8, 354278.3 6688911 9.8, 354278.9 6688907.9 9.8, 354279.4 6688905.2 9.8))
BATIMENT0000000302923027;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;90;10;8.9;6.3;15.2;21.4;7.5;Cadastre;A 1.0;POLYGON Z ((354197.1 6688917.9 15.2, 354221 6688922.6 15.2, 354225.3 6688899.4 15.2, 354193.1 6688893.4 15.2, 354189.9 6688911.6 15.2, 354189.2 6688916.4 15.2, 354189.5 6688916.4 15.2, 354197.1 6688917.9 15.2))
BATIMENT0000000302923213;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;6.1;9.6;15.5;6.7;Cadastre;;POLYGON Z ((354251.9 6688912.5 9.6, 354284 6688918.7 9.6, 354284.8 6688914.6 9.6, 354282.8 6688913.1 9.6, 354278.3 6688911 9.6, 354253.1 6688906.5 9.6, 354251.9 6688912.5 9.6))
BATIMENT0000000291499603;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2018-09-18 13:36:27;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.4;5.4;;14.0;6.8;Imagerie aérienne;;POLYGON Z ((354361.5 6688325.1 9.5, 354360.5 6688329.6 13.8, 354360.1 6688332.1 13.8, 354366.1 6688333.3 13.8, 354366.6 6688330.6 13.8, 354367.3 6688326.5 9.5, 354361.5 6688325.1 9.5))
BATIMENT0000000291500249;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2023-01-31 17:40:49;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;6.0;;9.3;6.8;Imagerie aérienne;;POLYGON Z ((354376.5 6688335.8 9.3, 354377.9 6688329.9 9.3, 354370.8 6688328.5 9.3, 354369.4 6688334.3 9.3, 354376.5 6688335.8 9.3))
BATIMENT0000000291501759;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;6.1;;;;Imagerie aérienne;;POLYGON Z ((354395.4 6688340.3 9.4, 354396.9 6688335.5 9.4, 354384.7 6688332.8 9.4, 354383.7 6688337.7 9.4, 354395.4 6688340.3 9.4))
BATIMENT0000000302923344;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2021-06-15 12:25:42;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.3;6.3;10.6;12.9;6.6;Cadastre;;POLYGON Z ((354318.9 6688355.7 10.6, 354369.8 6688366.8 10.6, 354372.1 6688354.2 10.6, 354322 6688343.4 10.6, 354318.9 6688355.7 10.6))
BATIMENT0000000327814957;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.4;6.5;;;;Imagerie aérienne;;POLYGON Z ((354397.3 6688417.1 11.3, 354397.7 6688416.8 11.3, 354399.1 6688416 11.3, 354401.7 6688415.2 11.3, 354407.1 6688414.8 11.8, 354411.1 6688414.7 12.5, 354416.3 6688415.4 12.9, 354409.9 6688403.9 12.2, 354408.2 6688389.3 12.7, 354378.5 6688394.3 10.5, 354379.3 6688399.6 10.5, 354377.2 6688403.8 10.3, 354397.3 6688417.1 11.3))
BATIMENT0000000327814876;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2016-05-27 18:14:18;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;7.8;0.9;;;;Imagerie aérienne;;POLYGON Z ((354389.9 6688517.3 8.7, 354379.4 6688511.3 8.7, 354381 6688508.4 8.7, 354357.9 6688495.7 8.7, 354356.2 6688498.6 8.7, 354343.1 6688491.2 8.7, 354339.5 6688507.5 8.7, 354378.8 6688529.1 8.7, 354389.9 6688517.3 8.7))
BATIMENT0000000302923248;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;16;23;16.1;6.7;22.8;25.6;7.1;Cadastre;A 1.0;POLYGON Z ((354359.3 6688708.1 22.8, 354348.1 6688731.1 22.8, 354350.6 6688732.1 22.8, 354355.9 6688722.4 22.8, 354364.9 6688726.1 22.8, 354362.3 6688732 22.8, 354366.8 6688734 22.8, 354368.4 6688730.5 22.8, 354369.8 6688731.1 22.8, 354366.5 6688738.7 22.8, 354369.8 6688740.4 22.8, 354374.9 6688729.4 22.8, 354375.8 6688727.5 22.8, 354376.8 6688725.6 22.8, 354380.6 6688717.1 22.8, 354359.3 6688708.1 22.8))
BATIMENT0000000302923247;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;00;00;20.9;6.7;27.6;31.3;7.3;Cadastre;C 0.8;POLYGON Z ((354401.5 6688739.3 27.6, 354405.7 6688727.7 27.6, 354380.6 6688717.1 27.6, 354376.8 6688725.6 27.6, 354386.3 6688729.4 27.6, 354385.8 6688730.6 27.6, 354390.6 6688732.6 27.6, 354391.2 6688731.3 27.6, 354395.2 6688732.9 27.6, 354394.6 6688734.5 27.6, 354391.8 6688735.9 27.6, 354391.6 6688735.7 27.6, 354386.3 6688738.4 27.6, 354386.4 6688738.8 27.6, 354380.8 6688741.4 27.6, 354384 6688747.9 27.6, 354401.5 6688739.3 27.6))
BATIMENT0000000302923250;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;6.8;18.2;22.9;7.3;Cadastre;;POLYGON Z ((354379.7 6688739.2 18.2, 354382.8 6688737.8 18.2, 354378.7 6688729.9 18.2, 354377.4 6688730.7 18.2, 354375.8 6688727.5 18.2, 354374.9 6688729.4 18.2, 354379.4 6688738.7 18.2, 354379.7 6688739.2 18.2))
BATIMENT0000000302923546;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;2.5;6.7;9.2;22.0;8.2;Cadastre;C 0.4;POLYGON Z ((354341.2 6688758.6 9.2, 354340.4 6688755.6 9.2, 354357.7 6688747 9.2, 354358.4 6688749.6 9.2, 354361.1 6688748.5 9.2, 354364.9 6688751.1 9.2, 354367.1 6688746.4 9.2, 354345.8 6688735.9 9.2, 354343.5 6688740.6 9.2, 354339.2 6688749.1 9.2, 354338.8 6688749.8 9.2, 354333.5 6688760.7 9.2, 354335.1 6688761.5 9.2, 354341.2 6688758.6 9.2))
BATIMENT0000000302923324;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;6.0;12.2;12.9;6.6;Cadastre;;POLYGON Z ((354496.8 6688325.1 12.2, 354498.9 6688326.4 12.2, 354501.3 6688326.5 12.2, 354503.6 6688325.4 12.2, 354505.2 6688323.3 12.2, 354505.5 6688320.9 12.2, 354504.6 6688318.6 12.2, 354502.8 6688317 12.2, 354500.5 6688316.3 12.2, 354498.1 6688316.8 12.2, 354496.2 6688318.4 12.2, 354495.3 6688320.6 12.2, 354495.5 6688323.1 12.2, 354496.8 6688325.1 12.2))
BATIMENT0000000302923144;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;7.0;10;20;19.3;8.1;27.4;;;Cadastre;A 1.0;POLYGON Z ((354533.6 6688773.5 27.4, 354507.4 6688764 27.4, 354502.9 6688776.9 27.4, 354508.3 6688781.3 27.4, 354511.8 6688777.3 27.4, 354511.4 6688777 27.4, 354511.5 6688776.7 27.4, 354511.2 6688776.4 27.4, 354511.9 6688774.7 27.4, 354528.2 6688780.7 27.4, 354528.3 6688780.5 27.4, 354528.6 6688780.6 27.4, 354532.5 6688782 27.4, 354533.6 6688773.5 27.4))
BATIMENT0000000302923149;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;7.2;18.2;22.2;7.8;Cadastre;;POLYGON Z ((354515 6688779.5 18.2, 354511.4 6688783.9 18.2, 354513.5 6688785.6 18.2, 354517.1 6688781.2 18.2, 354515 6688779.5 18.2))
BATIMENT0000000302923148;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;7.2;15.4;21.2;7.8;Cadastre;;POLYGON Z ((354517.1 6688781.2 15.4, 354513.5 6688785.6 15.4, 354514.4 6688786.4 15.4, 354518.1 6688782.1 15.4, 354517.1 6688781.2 15.4))
BATIMENT0000000302923147;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;7.2;15.7;21.5;7.9;Cadastre;;POLYGON Z ((354518.1 6688782.1 15.7, 354514.4 6688786.4 15.7, 354515.5 6688787.3 15.7, 354519.1 6688782.9 15.7, 354518.1 6688782.1 15.7))
BATIMENT0000000302923146;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;8.7;7.3;16.0;22.7;7.9;Cadastre;A 1.0;POLYGON Z ((354519.1 6688782.9 16, 354515.5 6688787.3 16, 354517.6 6688789.1 16, 354521.3 6688784.7 16, 354519.1 6688782.9 16))
BATIMENT0000000302923062;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;12;20;17.5;8.0;25.5;27.6;9.0;Cadastre;A 1.0;POLYGON Z ((354543.7 6688777.2 25.5, 354539.1 6688795.3 25.5, 354540.5 6688795.7 25.5, 354546.1 6688797.2 25.5, 354547.2 6688793.5 25.5, 354551.1 6688779.9 25.5, 354543.7 6688777.2 25.5))
BATIMENT0000000302923145;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;6.9;7.3;14.2;17.2;8.0;Cadastre;C 1.0;POLYGON Z ((354521.3 6688784.7 14.2, 354517.6 6688789.1 14.2, 354519.5 6688790.8 14.2, 354523.3 6688786.3 14.2, 354521.3 6688784.7 14.2))
BATIMENT0000000302923141;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;7.1;15.5;26.5;8.1;Cadastre;;POLYGON Z ((354527 6688789.4 15.5, 354526.7 6688790.7 15.5, 354523.6 6688794.1 15.5, 354525 6688795.3 15.5, 354530.5 6688793 15.5, 354532.5 6688782 15.5, 354528.6 6688780.6 15.5, 354527 6688789.4 15.5))
BATIMENT0000000302923143;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;5.1;7.3;12.5;16.7;8.1;Cadastre;C 1.0;POLYGON Z ((354523.3 6688786.3 12.5, 354519.5 6688790.8 12.5, 354521.6 6688792.4 12.5, 354525.3 6688788.1 12.5, 354523.3 6688786.3 12.5))
BATIMENT0000000302923326;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;5.6;8.5;9.0;6.5;Cadastre;;POLYGON Z ((354456.136632961 6688312.003221275 8.5, 354448.7315482152 6688312.003221275 8.5, 354448 6688315.6 8.5, 354455.1 6688317.1 8.5, 354456.136632961 6688312.003221275 8.5))
BATIMENT0000000302923345;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;6.4;8.7;9.2;6.6;Cadastre;;POLYGON Z ((354455.1 6688323.1 8.7, 354452.7 6688322.6 8.7, 354452 6688326.2 8.7, 354454.4 6688326.7 8.7, 354455.1 6688323.1 8.7))
BATIMENT0000000291501091;Industriel, agricole ou commercial;Industriel;Commercial et services;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2009-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.9;6.5;;13.0;6.7;Imagerie aérienne;C 0.3;POLYGON Z ((354444 6688341.8 10.3, 354448.7 6688323.6 10.3, 354397.4300309022 6688312.003221275 10.3, 354383.01482874254 6688312.003221275 9.4, 354382.3 6688314.4 9.4, 354388.1 6688316.8 12.4, 354385.7 6688328.5 10.3, 354444 6688341.8 10.3))
BATIMENT0000000291500522;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 18:43:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.6;6.0;;;;Imagerie aérienne;;POLYGON Z ((354413.3 6688344.2 9.6, 354414.8 6688339.2 9.6, 354403.2 6688336.8 9.6, 354401.8 6688341.7 9.5, 354413.3 6688344.2 9.6))
BATIMENT0000000291499680;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;2012-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;2.6;6.2;;9.0;6.8;Imagerie aérienne;C 0.4;POLYGON Z ((354419.7 6688345.6 8.8, 354437.3 6688349.5 8.8, 354437.2 6688349.4 8.8, 354438.5 6688344.2 8.8, 354420.8 6688341.2 8.8, 354419.7 6688345.6 8.8))
BATIMENT0000000327814970;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:27;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.8;6.2;;24.9;6.8;Imagerie aérienne;;POLYGON Z ((354427.8 6688409.7 22, 354429.5 6688409.4 22, 354432.5 6688407.6 22, 354434.4 6688405.1 22, 354435.6 6688403.1 22, 354436 6688400.3 22, 354435.9 6688397.5 22, 354435.1 6688394.7 22, 354434 6688392.5 22, 354431.8 6688390.3 22, 354429.8 6688389.2 22, 354426.8 6688388.8 22, 354423.9 6688389.1 22, 354421.3 6688390 22, 354418.6 6688392 22, 354416.6 6688394.7 22, 354415.8 6688397.1 22, 354415.7 6688399.9 22, 354416.1 6688402.1 22, 354416.8 6688404.4 22, 354418.1 6688406.3 22, 354420 6688408 22, 354421.8 6688408.9 22, 354424.7 6688409.7 22, 354427.8 6688409.7 22))
BATIMENT0000000302923174;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;00;00;20.6;7.6;28.2;31.0;8.8;Cadastre;A 1.0;POLYGON Z ((354421.7 6688770.2 28.2, 354417.8 6688781.7 28.2, 354426.1 6688783.8 28.2, 354426.1 6688783.2 28.2, 354425.3 6688782.9 28.2, 354425.4 6688781.6 28.2, 354439.6 6688786.3 28.2, 354439.7 6688785.8 28.2, 354442.5 6688777.5 28.2, 354421.7 6688770.2 28.2))
BATIMENT0000000302923172;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.8;7.8;30.7;32.4;8.6;Cadastre;;POLYGON Z ((354446.3 6688788.1 30.7, 354447.6 6688788.6 30.7, 354450.7 6688780 30.7, 354447.8 6688779.1 30.7, 354444 6688777.9 30.7, 354442.5 6688777.5 30.7, 354439.7 6688785.8 30.7, 354441 6688786.3 30.7, 354446.3 6688788.1 30.7))
BATIMENT0000000302923176;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;8.0;00;00;17.4;7.8;25.2;31.2;9.7;Cadastre;C 0.2;POLYGON Z ((354447.6 6688788.6 25.2, 354447.4 6688789.1 25.2, 354446.3 6688791.8 25.2, 354457.1 6688795.9 25.2, 354454.5 6688803.1 25.2, 354464.5 6688806.8 25.2, 354465.5 6688807.2 25.2, 354471.9 6688789.7 25.2, 354471.7 6688787.7 25.2, 354456 6688781.9 25.2, 354450.7 6688780 25.2, 354447.6 6688788.6 25.2))
BATIMENT0000000302923165;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;17.6;8.2;25.9;28.3;10.0;Cadastre;C 0.7;POLYGON Z ((354407.1 6688812.8 25.9, 354412.6 6688813.5 25.9, 354412.4 6688814.9 25.9, 354413 6688815 25.9, 354414.3 6688815.2 25.9, 354419.4 6688815.9 25.9, 354423.8 6688803.6 25.9, 354424.3 6688801.5 25.9, 354424.9 6688800.1 25.9, 354429.8 6688785 25.9, 354426.1 6688783.8 25.9, 354417.8 6688781.7 25.9, 354412.6 6688797.2 25.9, 354412.1 6688798.6 25.9, 354407.1 6688812.8 25.9))
BATIMENT0000000302923249;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;12.8;6.8;19.6;22.3;7.3;Cadastre;A 1.0;POLYGON Z ((354361.8 6688759 19.6, 354384 6688747.9 19.6, 354380.8 6688741.4 19.6, 354379.7 6688739.2 19.6, 354379.4 6688738.7 19.6, 354374.4 6688741.1 19.6, 354374.2 6688740.8 19.6, 354371.1 6688742.3 19.6, 354371.1 6688742.6 19.6, 354368.1 6688744.1 19.6, 354367.1 6688746.4 19.6, 354364.9 6688751.1 19.6, 354360.9 6688759.4 19.6, 354361.8 6688759 19.6))
BATIMENT0000000302923252;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.6;6.9;23.5;25.8;7.2;Cadastre;;POLYGON Z ((354359.8 6688760 23.5, 354359.8 6688755.7 23.5, 354358.3 6688755.6 23.5, 354358.1 6688756.9 23.5, 354356.5 6688756.3 23.5, 354353.3 6688757.9 23.5, 354354.7 6688761 23.5, 354355.4 6688762.1 23.5, 354359.8 6688760 23.5))
BATIMENT0000000302923547;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;69.0;6.0;00;00;16.8;6.7;23.5;27.6;8.2;Cadastre;C 0.5;POLYGON Z ((354332.1 6688772 23.5, 354347 6688765 23.5, 354347.5 6688765.3 23.5, 354349.1 6688764.6 23.5, 354349.2 6688763.6 23.5, 354348.6 6688762.3 23.5, 354349.8 6688761.9 23.5, 354350.3 6688763.1 23.5, 354354.7 6688761 23.5, 354353.3 6688757.9 23.5, 354356.5 6688756.3 23.5, 354358.1 6688756.9 23.5, 354358.3 6688755.6 23.5, 354359.8 6688755.7 23.5, 354359.8 6688760 23.5, 354360.9 6688759.4 23.5, 354364.9 6688751.1 23.5, 354361.1 6688748.5 23.5, 354358.4 6688749.6 23.5, 354357.7 6688747 23.5, 354340.4 6688755.6 23.5, 354341.2 6688758.6 23.5, 354335.1 6688761.5 23.5, 354333.5 6688760.7 23.5, 354330.2 6688767.5 23.5, 354328.8 6688770.3 23.5, 354332.1 6688772 23.5))
BATIMENT0000000302923259;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.5;6.7;20.2;23.5;7.3;Cadastre;;POLYGON Z ((354355.4 6688762.1 20.2, 354354.7 6688761 20.2, 354350.3 6688763.1 20.2, 354349.8 6688761.9 20.2, 354348.6 6688762.3 20.2, 354349.2 6688763.6 20.2, 354349.1 6688764.6 20.2, 354349.5 6688765 20.2, 354355.4 6688762.1 20.2))
BATIMENT0000000302923537;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;13;20;20.9;7.2;28.2;31.8;8.2;Cadastre;B 0.6;POLYGON Z ((354397.7 6688770.4 28.2, 354399 6688771.6 28.2, 354397.3 6688776 28.2, 354404.8 6688778.2 28.2, 354409.2 6688765.5 28.2, 354399.4 6688762.2 28.2, 354388.3 6688767.8 28.2, 354391.2 6688774.2 28.2, 354397.7 6688770.4 28.2))
BATIMENT0000000302923536;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.4;7.6;27.0;29.5;8.3;Cadastre;;POLYGON Z ((354399 6688771.6 27, 354397.7 6688770.4 27, 354391.2 6688774.2 27, 354397.3 6688776 27, 354399 6688771.6 27))
BATIMENT0000000302923224;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;12.9;6.8;19.7;23.1;9.3;Cadastre;A 1.0;POLYGON Z ((354388 6688768 19.7, 354385.3 6688762.9 19.7, 354365 6688773 19.7, 354367.8 6688781.6 19.7, 354372.8 6688784.3 19.7, 354377.4 6688786.8 19.7, 354383.4 6688790.1 19.7, 354388 6688783.9 19.7, 354375.9 6688775.6 19.7, 354377.8 6688774.7 19.7, 354378.6 6688776.2 19.7, 354379.6 6688776.6 19.7, 354385 6688773.7 19.7, 354384.6 6688772.8 19.7, 354386.9 6688771.6 19.7, 354388 6688773.3 19.7, 354391.2 6688774.2 19.7, 354388.3 6688767.8 19.7, 354388 6688768 19.7))
BATIMENT0000000302923230;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;7.0;18.2;23.5;8.3;Cadastre;;POLYGON Z ((354388 6688773.3 18.2, 354386.1 6688778.8 18.2, 354389.3 6688779.8 18.2, 354389.9 6688778 18.2, 354390.5 6688776.2 18.2, 354391.2 6688774.2 18.2, 354388 6688773.3 18.2))
BATIMENT0000000302923239;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;7.6;21.2;22.0;8.3;Cadastre;;POLYGON Z ((354390.5 6688776.2 21.2, 354389.9 6688778 21.2, 354392.1 6688778.6 21.2, 354393.4 6688779.1 21.2, 354394 6688777.4 21.2, 354390.5 6688776.2 21.2))
BATIMENT0000000302923221;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1942-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;12;20;15.5;6.6;22.2;25.6;7.5;Cadastre;A 1.0;POLYGON Z ((354344.6 6688783 22.2, 354346.1 6688787.6 22.2, 354347.2 6688790.8 22.2, 354349.1 6688796.1 22.2, 354359.2 6688791.3 22.2, 354358.8 6688785.5 22.2, 354367.2 6688781.3 22.2, 354367.8 6688781.6 22.2, 354365 6688773 22.2, 354344.6 6688783 22.2))
BATIMENT0000000302923228;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;7.7;18.1;20.2;9.3;Cadastre;;POLYGON Z ((354383.4 6688790.1 18.1, 354387.7 6688791.3 18.1, 354392.1 6688778.6 18.1, 354389.9 6688778 18.1, 354389.3 6688779.8 18.1, 354388 6688783.9 18.1, 354383.4 6688790.1 18.1))
BATIMENT0000000302923231;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;15.1;7.9;23.0;25.3;9.3;Cadastre;A 1.0;POLYGON Z ((354404.8 6688778.2 23, 354397.3 6688776 23, 354391.2 6688774.2 23, 354390.5 6688776.2 23, 354394 6688777.4 23, 354393.4 6688779.1 23, 354389.2 6688791.8 23, 354387.7 6688791.3 23, 354383.4 6688790.1 23, 354381.2 6688793.1 23, 354385.9 6688794.4 23, 354388.2 6688795.1 23, 354398.2 6688798.1 23, 354404.8 6688778.2 23))
BATIMENT0000000302923240;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;8.9;21.2;23.4;9.4;Cadastre;;POLYGON Z ((354388.2 6688795.1 21.2, 354385.9 6688794.4 21.2, 354385 6688796.9 21.2, 354387.5 6688797.4 21.2, 354388.2 6688795.1 21.2))
BATIMENT0000000302923226;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2022-07-30 23:16:38;1900-01-01;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;0.0;1.0;;;;10.0;;;;Cadastre;A 1.0;POLYGON Z ((354368.3 6688808.1 -1000, 354371.1 6688807 -1000, 354377.8 6688797.8 -1000, 354381.2 6688793.1 -1000, 354383.4 6688790.1 -1000, 354377.4 6688786.8 -1000, 354372.8 6688784.3 -1000, 354358.7 6688804.2 -1000, 354359 6688805.1 -1000, 354362.1 6688803.8 -1000, 354365.8 6688802.2 -1000, 354366 6688802.7 -1000, 354368.3 6688808.1 -1000))
BATIMENT0000000302923238;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;8.9;14.7;22.7;9.5;Cadastre;;POLYGON Z ((354381.2 6688793.1 14.7, 354377.8 6688797.8 14.7, 354383.7 6688800.6 14.7, 354385 6688796.9 14.7, 354385.9 6688794.4 14.7, 354381.2 6688793.1 14.7))
BATIMENT0000000302923244;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;12.2;8.7;21.0;23.0;9.8;Cadastre;A 1.0;POLYGON Z ((354398.2 6688798.1 21, 354388.2 6688795.1 21, 354387.5 6688797.4 21, 354383.2 6688809.6 21, 354382.7 6688811 21, 354392.7 6688814.3 21, 354398.2 6688798.1 21))
BATIMENT0000000302923235;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.5;7.7;9.2;11.0;9.5;Cadastre;;POLYGON Z ((354364.6 6688809.7 9.2, 354365.3 6688809.5 9.2, 354368.3 6688808.1 9.2, 354366 6688802.7 9.2, 354365.8 6688802.2 9.2, 354362.1 6688803.8 9.2, 354364.6 6688809.7 9.2))
BATIMENT0000000302923241;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;9.4;14.0;18.7;9.9;Cadastre;;POLYGON Z ((354382.7 6688811 14, 354383.2 6688809.6 14, 354379 6688808.2 14, 354378.5 6688809.5 14, 354378.9 6688809.7 14, 354382.7 6688811 14))
BATIMENT0000000302923236;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;5.6;8.1;13.8;17.5;10.0;Cadastre;C 0.3;POLYGON Z ((354376.2 6688818 13.8, 354376.6 6688816.5 13.8, 354377.4 6688814.2 13.8, 354370.8 6688812.2 13.8, 354371.1 6688807 13.8, 354368.3 6688808.1 13.8, 354365.3 6688809.5 13.8, 354367.7 6688815.3 13.8, 354373.9 6688817.3 13.8, 354376.2 6688818 13.8))
BATIMENT0000000302923222;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;2.1;7.7;9.9;20.2;8.9;Cadastre;A 0.2;POLYGON Z ((354334.6 6688804.9 9.9, 354339.3 6688817.5 9.9, 354340.8 6688818.6 9.9, 354341.5 6688819.1 9.9, 354351 6688825.2 9.9, 354351.1 6688825 9.9, 354352 6688823.8 9.9, 354341.2 6688816.1 9.9, 354340.6 6688815 9.9, 354337.6 6688806.4 9.9, 354338.4 6688805.9 9.9, 354337.1 6688803.7 9.9, 354334.6 6688804.9 9.9))
BATIMENT0000000302923164;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;6.5;8.4;15.0;20.0;10.0;Cadastre;C 0.8;POLYGON Z ((354424.8 6688812.6 15, 354424 6688816.5 15, 354427.8 6688817.1 15, 354434.5 6688818.1 15, 354435.2 6688814.5 15, 354437.1 6688803.5 15, 354439.9 6688787.7 15, 354439.2 6688787.5 15, 354438.7 6688787.3 15, 354431.9 6688785.4 15, 354427.6 6688801.7 15, 354424.8 6688812.6 15))
BATIMENT0000000302923204;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;2.7;9.2;11.9;13.3;10.5;Cadastre;A 1.0;POLYGON Z ((354440 6688818.4 11.9, 354441.7 6688818.6 11.9, 354441.9 6688817.9 11.9, 354446.2 6688818.8 11.9, 354447.2 6688820.2 11.9, 354448.4 6688820.4 11.9, 354448.7 6688818.4 11.9, 354446.9 6688816.7 11.9, 354446.8 6688814.9 11.9, 354440.9 6688813.6 11.9, 354440 6688818.4 11.9))
BATIMENT0000000302923162;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;8.0;9.3;17.4;25.7;10.1;Cadastre;A 1.0;POLYGON Z ((354413.8 6688817.6 17.4, 354412.5 6688817 17.4, 354413 6688815 17.4, 354412.4 6688814.9 17.4, 354412.6 6688813.5 17.4, 354407.1 6688812.8 17.4, 354403.7 6688822.7 17.4, 354409.2 6688824.4 17.4, 354411.8 6688825.2 17.4, 354417.7 6688827 17.4, 354422.5 6688828.4 17.4, 354425.5 6688829.4 17.4, 354432.3 6688831.5 17.4, 354434.5 6688818.1 17.4, 354427.8 6688817.1 17.4, 354426 6688826.7 17.4, 354424.1 6688826.2 17.4, 354422.4 6688825.7 17.4, 354418.3 6688825.1 17.4, 354421.2 6688816.1 17.4, 354419.4 6688815.9 17.4, 354414.3 6688815.2 17.4, 354413.8 6688817.6 17.4))
BATIMENT0000000302923206;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;9.8;12.2;21.1;10.8;Cadastre;;POLYGON Z ((354446.4 6688827 12.2, 354447.4 6688827.1 12.2, 354448.2 6688821.6 12.2, 354447.2 6688821.5 12.2, 354446.4 6688827 12.2))
BATIMENT0000000029198465;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2000-01-01;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;124.0;6.0;90;20;13.2;8.2;;26.7;13.0;Imagerie aérienne;B 0.4;POLYGON Z ((354453.6 6688825.3 17.4, 354470.7 6688831.2 20.9, 354469.5 6688833.8 21, 354486.9 6688840.1 21.4, 354489.6 6688824.5 21.4, 354475.1 6688818.9 21.2, 354455.4 6688810.9 17.6, 354453.6 6688825.3 17.4))
BATIMENT0000000302923205;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1886-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;13.2;9.4;22.7;25.7;11.0;Cadastre;A 0.7;POLYGON Z ((354448 6688830.9 22.7, 354446.8 6688830.7 22.7, 354445 6688830.4 22.7, 354446.4 6688821.5 22.7, 354439.7 6688820.2 22.7, 354437.8 6688831 22.7, 354447.7 6688832.6 22.7, 354448 6688830.9 22.7))
BATIMENT0000000302923160;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;9.8;20.7;24.0;10.0;Cadastre;;POLYGON Z ((354422.5 6688828.4 20.7, 354417.7 6688827 20.7, 354417.3 6688828.4 20.7, 354422.1 6688829.7 20.7, 354422.5 6688828.4 20.7))
BATIMENT0000000302923161;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;9.9;22.0;25.5;10.1;Cadastre;;POLYGON Z ((354421.8 6688830.1 22, 354417 6688828.8 22, 354416.7 6688829.8 22, 354421.6 6688831.3 22, 354421.8 6688830.1 22))
BATIMENT0000000302923163;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;15.9;10.8;26.7;;;Cadastre;A 1.0;POLYGON Z ((354400.3 6688832.2 26.7, 354401.7 6688833 26.7, 354403 6688833.9 26.7, 354404.3 6688834.9 26.7, 354405.5 6688836 26.7, 354406.7 6688837.1 26.7, 354407.7 6688838.3 26.7, 354408.6 6688839.4 26.7, 354409.2 6688840.3 26.7, 354409.5 6688840.7 26.7, 354410.3 6688841.9 26.7, 354411 6688843.2 26.7, 354420.3 6688838 26.7, 354424.1 6688838.4 26.7, 354430.9 6688839.3 26.7, 354432.3 6688831.5 26.7, 354425.5 6688829.4 26.7, 354422.5 6688828.4 26.7, 354422.1 6688829.7 26.7, 354421.8 6688830.1 26.7, 354421.6 6688831.3 26.7, 354421.2 6688832.6 26.7, 354419.7 6688832.6 26.7, 354418.7 6688832.5 26.7, 354417.5 6688832.1 26.7, 354416.4 6688831.4 26.7, 354416.7 6688829.8 26.7, 354417 6688828.8 26.7, 354417.3 6688828.4 26.7, 354417.7 6688827 26.7, 354411.8 6688825.2 26.7, 354410.7 6688828.9 26.7, 354408.1 6688828.1 26.7, 354409.2 6688824.4 26.7, 354403.7 6688822.7 26.7, 354400.3 6688832.2 26.7))
BATIMENT0000000302923207;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;00;00;16.2;10.0;26.3;28.3;12.9;Cadastre;A 1.0;POLYGON Z ((354437.8 6688831 26.3, 354435.8 6688842 26.3, 354446.2 6688843.8 26.3, 354446.7 6688839.6 26.3, 354454.5 6688840.7 26.3, 354454.6 6688839.8 26.3, 354455.5 6688834.2 26.3, 354452.8 6688834 26.3, 354452.6 6688835.2 26.3, 354447.4 6688834.3 26.3, 354447.7 6688832.6 26.3, 354437.8 6688831 26.3))
BATIMENT0000000302923142;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;7.2;7.5;14.7;17.4;8.1;Cadastre;C 1.0;POLYGON Z ((354525.3 6688788.1 14.7, 354521.6 6688792.4 14.7, 354523.6 6688794.1 14.7, 354526.7 6688790.7 14.7, 354527 6688789.4 14.7, 354525.3 6688788.1 14.7))
BATIMENT0000000302923187;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;35;20;20.3;7.9;28.2;31.5;9.3;Cadastre;C 0.3;POLYGON Z ((354496.3 6688796.6 28.2, 354485 6688792.4 28.2, 354480.1 6688805.4 28.2, 354488 6688808.3 28.2, 354489.8 6688803.5 28.2, 354491.4 6688804 28.2, 354492.8 6688804.6 28.2, 354494.1 6688805.9 28.2, 354499.6 6688799.4 28.2, 354496.3 6688796.6 28.2))
BATIMENT0000000302923186;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;20;20;15.7;8.3;24.0;24.6;10.0;Cadastre;A 1.0;POLYGON Z ((354493.3 6688807 24, 354498.9 6688811.9 24, 354502 6688814.3 24, 354502.8 6688813.4 24, 354510.9 6688820.4 24, 354516.7 6688813.7 24, 354499.6 6688799.4 24, 354494.1 6688805.9 24, 354493.3 6688807 24))
BATIMENT0000000302923188;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;8.3;13.7;25.5;10.0;Cadastre;;POLYGON Z ((354477.8 6688812 13.7, 354489.8 6688816.3 13.7, 354491.9 6688810.7 13.7, 354479.8 6688806.3 13.7, 354477.8 6688812 13.7))
BATIMENT0000000302923185;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;19;30;15.3;10.8;26.1;;;Cadastre;C 1.0;POLYGON Z ((354514.9 6688823.9 26.1, 354516.5 6688828.7 26.1, 354516 6688832.4 26.1, 354525.5 6688834 26.1, 354526.4 6688828.2 26.1, 354522.2 6688818.4 26.1, 354516.7 6688813.7 26.1, 354510.9 6688820.4 26.1, 354514.9 6688823.9 26.1))
BATIMENT0000000302923209;Indifférenciée;Annexe;;Oui;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.4;10.5;12.9;13.2;11.4;Cadastre;C 0.5;POLYGON Z ((354505 6688830.7 12.9, 354507.8 6688823.8 12.9, 354506.2 6688822.1 12.9, 354502.7 6688821 12.9, 354497.4 6688819.7 12.9, 354496.5 6688822.2 12.9, 354501.3 6688824.2 12.9, 354499.4 6688829.9 12.9, 354505 6688830.7 12.9))
BATIMENT0000000302923210;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.4;10.5;12.9;13.0;11.4;Cadastre;C 0.5;POLYGON Z ((354499.4 6688829.9 12.9, 354501.3 6688824.2 12.9, 354496.5 6688822.2 12.9, 354494.3 6688827 12.9, 354493.8 6688827 12.9, 354493.7 6688829 12.9, 354499.4 6688829.9 12.9))
BATIMENT0000000302923184;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;23;20;15.8;10.8;26.6;30.1;11.8;Cadastre;B 0.5;POLYGON Z ((354515.1 6688838 26.6, 354513.8 6688837.8 26.6, 354511.6 6688850.2 26.6, 354513.2 6688850.4 26.6, 354512.9 6688852.8 26.6, 354522.1 6688854.1 26.6, 354525.5 6688834 26.6, 354516 6688832.4 26.6, 354515.1 6688838 26.6))
BATIMENT0000000302923211;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;11.8;14.8;15.2;13.0;Cadastre;;POLYGON Z ((354503.9 6688845.5 14.8, 354491.1 6688843.5 14.8, 354490.2 6688849.1 14.8, 354503.2 6688851.3 14.8, 354503.9 6688845.5 14.8))
BATIMENT0000000302923096;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.3;10.4;26.7;31.8;13.1;Cadastre;A 1.0;POLYGON Z ((354540.4 6688867.4 26.7, 354538.2 6688866.9 26.7, 354540.3 6688854.1 26.7, 354537.6 6688853.6 26.7, 354538.6 6688848.3 26.7, 354540.3 6688848.1 26.7, 354541.7 6688847.8 26.7, 354542.5 6688847.4 26.7, 354544.2 6688845.8 26.7, 354559.7 6688858.5 26.7, 354561.8 6688860.1 26.7, 354566 6688854.9 26.7, 354553.2 6688844.3 26.7, 354543.5 6688836.2 26.7, 354543.1 6688835.9 26.7, 354542.7 6688835.6 26.7, 354542.2 6688835.4 26.7, 354541.7 6688835.2 26.7, 354541.2 6688835 26.7, 354540.7 6688834.9 26.7, 354540.2 6688834.8 26.7, 354540 6688834.8 26.7, 354539.7 6688834.8 26.7, 354539.2 6688834.8 26.7, 354538.6 6688834.8 26.7, 354538.1 6688834.9 26.7, 354537.6 6688835 26.7, 354537.4 6688835.1 26.7, 354537.1 6688835.2 26.7, 354536.6 6688835.4 26.7, 354536.1 6688835.7 26.7, 354535.7 6688836 26.7, 354535.2 6688836.4 26.7, 354534.8 6688836.8 26.7, 354534.4 6688837.2 26.7, 354534.1 6688837.6 26.7, 354533.8 6688838.1 26.7, 354533.5 6688838.6 26.7, 354533.3 6688839.2 26.7, 354532.7 6688842.8 26.7, 354527 6688877.2 26.7, 354538.7 6688879.5 26.7, 354540.4 6688867.4 26.7))
BATIMENT0000000302923237;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;15;29;10.0;9.4;19.5;23.2;10.0;Cadastre;C 0.8;POLYGON Z ((354382.7 6688811 19.5, 354378.9 6688809.7 19.5, 354378 6688812.3 19.5, 354381.9 6688813.6 19.5, 354381.2 6688815.9 19.5, 354378 6688814.9 19.5, 354377.4 6688816.7 19.5, 354380.5 6688817.8 19.5, 354380.1 6688819.2 19.5, 354390 6688822.3 19.5, 354392.7 6688814.3 19.5, 354382.7 6688811 19.5))
BATIMENT0000000302923233;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;9.0;17.7;26.2;10.0;Cadastre;;POLYGON Z ((354380.1 6688819.2 17.7, 354380.5 6688817.8 17.7, 354377.4 6688816.7 17.7, 354376.6 6688816.5 17.7, 354376.2 6688818 17.7, 354380.1 6688819.2 17.7))
BATIMENT0000000302923539;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;7.9;13.5;15.0;8.8;Cadastre;;POLYGON Z ((354341.5 6688819.1 13.5, 354340.8 6688818.6 13.5, 354338.4 6688822.1 13.5, 354338.8 6688822.5 13.5, 354341.5 6688819.1 13.5))
BATIMENT0000000302923232;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;16.7;10.0;26.7;29.2;10.3;Cadastre;A 1.0;POLYGON Z ((354379.7 6688828.5 26.7, 354380 6688828.4 26.7, 354380.3 6688828.4 26.7, 354380.7 6688828.3 26.7, 354381.2 6688828.2 26.7, 354381.5 6688828.2 26.7, 354381.7 6688828.2 26.7, 354382.9 6688828.2 26.7, 354383.4 6688828.2 26.7, 354383.9 6688828.2 26.7, 354384.2 6688828.2 26.7, 354384.4 6688828.2 26.7, 354384.6 6688828.3 26.7, 354385.1 6688828.3 26.7, 354385.3 6688828.4 26.7, 354386 6688828.6 26.7, 354386.7 6688828.8 26.7, 354386.9 6688828.8 26.7, 354387.1 6688828.8 26.7, 354387.3 6688828.8 26.7, 354387.5 6688828.8 26.7, 354387.7 6688828.7 26.7, 354387.9 6688828.5 26.7, 354388 6688828.3 26.7, 354390 6688822.3 26.7, 354380.1 6688819.2 26.7, 354376.2 6688818 26.7, 354373.9 6688817.3 26.7, 354373.5 6688819.4 26.7, 354372.7 6688818.7 26.7, 354371.3 6688818.4 26.7, 354370.6 6688818.8 26.7, 354370.1 6688819.2 26.7, 354369.6 6688819.9 26.7, 354373.6 6688830.4 26.7, 354379.7 6688828.5 26.7))
BATIMENT0000000302923541;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.5;7.6;16.2;23.2;8.9;Cadastre;;POLYGON Z ((354352.7 6688826.6 16.2, 354353.4 6688825.8 16.2, 354353.7 6688825.4 16.2, 354353.9 6688824.8 16.2, 354353.9 6688824.4 16.2, 354353.9 6688824 16.2, 354353.6 6688823.7 16.2, 354353.2 6688823.5 16.2, 354352.7 6688823.5 16.2, 354352.3 6688823.6 16.2, 354352 6688823.8 16.2, 354351.1 6688825 16.2, 354352.7 6688826.6 16.2))
BATIMENT0000000302923538;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;7.9;16.4;25.0;10.0;Cadastre;;POLYGON Z ((354343 6688826 16.4, 354350.6 6688831.9 16.4, 354350.8 6688832 16.4, 354353.6 6688827.9 16.4, 354353.9 6688827.2 16.4, 354352.7 6688826.6 16.4, 354351.1 6688825 16.4, 354351 6688825.2 16.4, 354341.5 6688819.1 16.4, 354338.8 6688822.5 16.4, 354343 6688826 16.4))
BATIMENT0000000302923540;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;20.3;7.7;28.0;29.3;10.4;Cadastre;C 0.1;POLYGON Z ((354361.2 6688840 28, 354363.1 6688837.7 28, 354363.3 6688837.5 28, 354363.6 6688837.2 28, 354364.4 6688836.4 28, 354364.6 6688836.3 28, 354365.1 6688835.8 28, 354366 6688835.1 28, 354367.4 6688834.1 28, 354368.1 6688833.6 28, 354368.8 6688833.1 28, 354368.9 6688833 28, 354369.1 6688832.9 28, 354370 6688832.3 28, 354370.1 6688832.2 28, 354371.2 6688831.6 28, 354371.4 6688831.5 28, 354371.8 6688831.3 28, 354372.6 6688830.9 28, 354373.4 6688830.5 28, 354373.6 6688830.4 28, 354369.6 6688819.9 28, 354368.7 6688817.8 28, 354368.6 6688817.6 28, 354363.6 6688819.6 28, 354353.9 6688827.2 28, 354353.6 6688827.9 28, 354350.8 6688832 28, 354361.2 6688840 28))
BATIMENT0000000302923544;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;9.0;8.8;17.9;25.5;10.5;Cadastre;C 0.5;POLYGON Z ((354348.1 6688837 17.9, 354350.6 6688831.9 17.9, 354343 6688826 17.9, 354340.9 6688832.6 17.9, 354348.1 6688837 17.9))
BATIMENT0000000302923545;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1837-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;16.8;10.0;26.8;29.5;10.8;Cadastre;C 0.9;POLYGON Z ((354353.7 6688859.1 26.8, 354357.3 6688848.4 26.8, 354356.8 6688848.1 26.8, 354359.4 6688843.9 26.8, 354361.2 6688840 26.8, 354350.8 6688832 26.8, 354350.6 6688831.9 26.8, 354348.1 6688837 26.8, 354348.9 6688837.5 26.8, 354345.1 6688845 26.8, 354337.6 6688842.5 26.8, 354337.5 6688843.2 26.8, 354337.1 6688844.2 26.8, 354334.4 6688852.4 26.8, 354353.7 6688859.1 26.8))
BATIMENT0000000302923530;Eglise;Religieux;;Non;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;26.4;14.6;41.0;;;Cadastre;;POLYGON Z ((354361.6 6688902.5 41, 354362.8 6688904.6 41, 354365.4 6688907.2 41, 354367.8 6688908.1 41, 354370.5 6688908.6 41, 354374.3 6688908.5 41, 354377.4 6688906.8 41, 354380.3 6688903.5 41, 354381.5 6688900.4 41, 354381.4 6688895.4 41, 354379.5 6688892.3 41, 354376.2 6688889.4 41, 354372.7 6688887.7 41, 354368.4 6688888.2 41, 354364.9 6688889.9 41, 354362.4 6688893.1 41, 354361.3 6688897 41, 354361.3 6688902 41, 354361.6 6688902.5 41))
BATIMENT0000000302923166;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;00;00;17.4;10.3;27.7;30.0;11.3;Cadastre;A 1.0;POLYGON Z ((354411 6688843.2 27.7, 354411.7 6688844.5 27.7, 354412.3 6688845.8 27.7, 354412.9 6688847.2 27.7, 354413.4 6688848.6 27.7, 354413.7 6688849.7 27.7, 354414 6688850.6 27.7, 354414.3 6688851.8 27.7, 354414.5 6688853.1 27.7, 354414.6 6688854.7 27.7, 354414.7 6688856.3 27.7, 354414.6 6688857.8 27.7, 354427.7 6688858.6 27.7, 354430.1 6688844.8 27.7, 354430.9 6688839.3 27.7, 354424.1 6688838.4 27.7, 354420.3 6688838 27.7, 354411 6688843.2 27.7))
BATIMENT0000000302923208;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;20;23;16.4;10.3;26.7;28.3;13.0;Cadastre;A 1.0;POLYGON Z ((354445.4 6688847.7 26.7, 354446.2 6688843.8 26.7, 354435.8 6688842 26.7, 354434 6688852.9 26.7, 354435.7 6688855.3 26.7, 354450.8 6688858.9 26.7, 354452.8 6688849.2 26.7, 354445.4 6688847.7 26.7))
BATIMENT0000000029198464;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:27;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;14.6;9.7;;30.6;13.0;Imagerie aérienne;;POLYGON Z ((354460.6 6688861.2 24.2, 354482.5 6688866.2 24.3, 354484.7 6688850.4 24.3, 354463.4 6688845.1 24.2, 354460.6 6688861.2 24.2))
BATIMENT0000000302923167;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;6.0;00;00;16.3;10.8;27.1;30.4;11.9;Cadastre;C 0.4;POLYGON Z ((354413 6688867.1 27.1, 354412.7 6688867.1 27.1, 354409.3 6688877.7 27.1, 354414.1 6688879.4 27.1, 354414.3 6688879.1 27.1, 354420.9 6688881.5 27.1, 354421.8 6688878.5 27.1, 354423.9 6688879.4 27.1, 354424.9 6688874.2 27.1, 354425.9 6688868.8 27.1, 354427.7 6688858.6 27.1, 354414.6 6688857.8 27.1, 354414.1 6688862.2 27.1, 354413 6688867.1 27.1))
BATIMENT0000000302923183;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.0;10.8;15.8;16.7;14.6;Cadastre;C 0.2;POLYGON Z ((354467.3 6688876.3 15.8, 354468.1 6688875.7 15.8, 354474.9 6688877.1 15.8, 354475 6688877.2 15.8, 354476.4 6688871.6 15.8, 354461.7 6688868 15.8, 354460 6688874.5 15.8, 354467.3 6688876.3 15.8))
BATIMENT0000000302923168;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.9;11.3;31.2;34.7;12.1;Cadastre;C 0.1;POLYGON Z ((354432.3 6688871 31.2, 354426.5 6688869 31.2, 354424.9 6688874.2 31.2, 354423.9 6688879.4 31.2, 354428.9 6688881.3 31.2, 354432.3 6688871 31.2))
BATIMENT0000000302923169;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.2;11.4;29.7;35.5;12.2;Cadastre;;POLYGON Z ((354428.9 6688881.3 29.7, 354430.5 6688882 29.7, 354434 6688871.6 29.7, 354432.3 6688871 29.7, 354428.9 6688881.3 29.7))
BATIMENT0000000302923170;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;20;20;9.4;11.3;20.7;35.3;14.2;Cadastre;C 0.5;POLYGON Z ((354449.9 6688883.3 20.7, 354452.1 6688872.2 20.7, 354455.3 6688872.9 20.7, 354455.6 6688871.1 20.7, 354456.4 6688871.1 20.7, 354456.9 6688867.7 20.7, 354455.9 6688867.7 20.7, 354455.9 6688867.1 20.7, 354451 6688866.4 20.7, 354451.5 6688864.9 20.7, 354435.2 6688860.8 20.7, 354434 6688871.6 20.7, 354430.5 6688882 20.7, 354451.4 6688889.3 20.7, 354450.5 6688891.7 20.7, 354455.3 6688893.3 20.7, 354457.7 6688885.6 20.7, 354449.9 6688883.3 20.7))
BATIMENT0000000302923179;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.3;12.9;18.3;32.0;14.5;Cadastre;C 0.1;POLYGON Z ((354460 6688874.5 18.3, 354457.5 6688874.1 18.3, 354456 6688881.1 18.3, 354455.1 6688881.2 18.3, 354455.1 6688882.6 18.3, 354458.2 6688883.5 18.3, 354458.7 6688881.4 18.3, 354460 6688874.5 18.3))
BATIMENT0000000302923171;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;00;00;18.8;13.4;32.2;34.8;14.4;Cadastre;C 0.5;POLYGON Z ((354473.8 6688882.5 32.2, 354467.4 6688881.2 32.2, 354467.3 6688881.6 32.2, 354466.3 6688881.4 32.2, 354466.3 6688882.3 32.2, 354467.7 6688882.5 32.2, 354468.8 6688882.6 32.2, 354468.8 6688883.4 32.2, 354466.7 6688884.1 32.2, 354458.7 6688881.4 32.2, 354458.2 6688883.5 32.2, 354457.7 6688885.6 32.2, 354455.3 6688893.3 32.2, 354470.1 6688898.2 32.2, 354472.4 6688889.7 32.2, 354473.8 6688882.5 32.2))
BATIMENT0000000302923182;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;20;20;16.9;10.8;27.7;31.2;13.7;Cadastre;A 1.0;POLYGON Z ((354508.5 6688867 27.7, 354507.8 6688872 27.7, 354518.8 6688874.3 27.7, 354522.1 6688854.1 27.7, 354512.9 6688852.8 27.7, 354510.9 6688852.5 27.7, 354508.5 6688867 27.7))
BATIMENT0000000302923181;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;30;20;15.3;12.8;28.1;31.5;14.0;Cadastre;A 1.0;POLYGON Z ((354503.9 6688887 28.1, 354505.4 6688887.3 28.1, 354506.1 6688885.6 28.1, 354516.7 6688887.4 28.1, 354518.8 6688874.3 28.1, 354507.8 6688872 28.1, 354506.5 6688871.7 28.1, 354503.9 6688887 28.1))
BATIMENT0000000302923532;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;12.7;21.7;25.5;15.4;Cadastre;;POLYGON Z ((354542.2 6688911.2 21.7, 354545.7 6688889.8 21.7, 354547 6688890.1 21.7, 354548 6688883.2 21.7, 354548.3 6688881.2 21.7, 354539 6688879.5 21.7, 354534.3 6688909.3 21.7, 354542.2 6688911.2 21.7))
BATIMENT0000000302923177;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;16.4;14.0;30.5;33.9;14.7;Cadastre;A 1.0;POLYGON Z ((354485.6 6688894.1 30.5, 354485.9 6688893.3 30.5, 354475.4 6688889.9 30.5, 354475.2 6688890.6 30.5, 354472.4 6688889.7 30.5, 354470.1 6688898.2 30.5, 354484.9 6688903.2 30.5, 354487.8 6688894.8 30.5, 354485.6 6688894.1 30.5))
BATIMENT0000000302923178;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;30;20;14.6;14.1;28.7;33.3;15.4;Cadastre;A 1.0;POLYGON Z ((354498.3 6688907.7 28.7, 354501 6688899.8 28.7, 354501.9 6688896.1 28.7, 354497.8 6688894.6 28.7, 354499.2 6688890.6 28.7, 354498.8 6688889.4 28.7, 354490.6 6688886.7 28.7, 354488.9 6688891.6 28.7, 354487.8 6688894.8 28.7, 354484.9 6688903.2 28.7, 354498.3 6688907.7 28.7))
BATIMENT0000000302923180;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;30;20;13.2;13.8;27.0;32.2;15.4;Cadastre;A 1.0;POLYGON Z ((354503.9 6688887 27, 354501.9 6688896.1 27, 354501 6688899.8 27, 354498.3 6688907.7 27, 354508.8 6688911.2 27, 354513.2 6688908.5 27, 354514.4 6688901 27, 354516.7 6688887.4 27, 354506.1 6688885.6 27, 354505.4 6688887.3 27, 354503.9 6688887 27), (354506.9 6688887.3 27, 354508.6 6688887.6 27, 354507.7 6688893 27, 354506.6 6688892.9 27, 354506.2 6688895.2 27, 354507.2 6688895.5 27, 354507 6688896.9 27, 354505.9 6688896.7 27, 354505.5 6688898.9 27, 354506.6 6688899.2 27, 354506 6688902.4 27, 354503.1 6688901.3 27, 354506 6688887.7 27, 354506.8 6688887.9 27, 354506.9 6688887.3 27))
BATIMENT0000000302923533;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;90;17.0;12.9;30.0;31.0;15.8;Cadastre;C 0.8;POLYGON Z ((354526 6688916.3 30, 354540.5 6688921.4 30, 354541.4 6688916.2 30, 354542.2 6688911.2 30, 354534.3 6688909.3 30, 354539 6688879.5 30, 354538.7 6688879.5 30, 354527 6688877.2 30, 354525.6 6688886.6 30, 354523.8 6688898.7 30, 354523.5 6688898.7 30, 354522.3 6688906.2 30, 354521.7 6688909.8 30, 354526 6688916.3 30), (354530.5 6688887.5 30, 354530.7 6688886.1 30, 354534.3 6688886.9 30, 354533.8 6688889.9 30, 354530.2 6688889.1 30, 354530.5 6688887.5 30), (354530 6688906.4 30, 354533.3 6688906.9 30, 354532.3 6688911.9 30, 354529 6688911.2 30, 354530 6688906.4 30))
BATIMENT0000000302923267;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;17.8;14.3;32.1;34.0;17.5;Cadastre;A 1.0;POLYGON Z ((354486.6 6688914.8 32.1, 354471.6 6688909.6 32.1, 354467.8 6688920.6 32.1, 354482.9 6688926 32.1, 354486.4 6688915.6 32.1, 354486.6 6688914.8 32.1))
BATIMENT0000000302923479;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;90;16.1;15.8;32.0;33.1;17.7;Cadastre;A 1.0;POLYGON Z ((354518.2 6688937.2 32, 354517.3 6688942.8 32, 354519.2 6688945.1 32, 354541.1 6688945.9 32, 354542.1 6688939.4 32, 354541.5 6688939.3 32, 354543.3 6688933.5 32, 354522.3 6688926.5 32, 354519.6 6688928.3 32, 354518.2 6688937.2 32), (354526.3 6688935.2 32, 354531.4 6688936.8 32, 354530.5 6688943.7 32, 354525.4 6688943.4 32, 354525.9 6688938.5 32, 354526.3 6688935.2 32))
BATIMENT0000000302923268;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;140.0;7.0;00;00;20.1;15.4;35.5;39.5;18.8;Cadastre;B 0.6;POLYGON Z ((354509 6688927.1 35.5, 354506.2 6688922.4 35.5, 354486.4 6688915.6 35.5, 354482.9 6688926 35.5, 354495.6 6688930.5 35.5, 354497 6688932.4 35.5, 354494.5 6688945.8 35.5, 354491.3 6688945.2 35.5, 354489.1 6688959 35.5, 354493.4 6688959.6 35.5, 354503.2 6688961 35.5, 354509 6688927.1 35.5))
BATIMENT0000000029198232;Indifférenciée;Commercial et services;;Non;En service;2006-10-04 09:41:10;2019-07-01 11:16:15;;;;;BDTopo;2.5;BDTopo;1.5;;;;;14.1;6.9;;;;Imagerie aérienne;;POLYGON Z ((353946.7 6688388.3 7.7, 353938.6 6688394.9 8, 353925.4 6688405.7 21, 353929.2 6688410.5 19.2, 353942.5 6688399.6 8, 353950.6 6688393.1 7.7, 353958.7 6688386.5 20.1, 353954.7 6688381.5 19.3, 353946.7 6688388.3 7.7))
BATIMENT0000000302910660;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.5;7.7;19.2;25.2;10.1;Cadastre;C 0.2;POLYGON Z ((353903.5 6688450.1 19.2, 353938.3 6688421.7 19.2, 353929.2 6688410.5 19.2, 353925.4 6688405.7 19.2, 353916.2 6688394.4 19.2, 353911.2 6688388.2 19.2, 353896.2 6688369.9 19.2, 353893.2 6688367.7 19.2, 353892.0022898072 6688367.400572452 19.2, 353892.0022898072 6688382.490017283 19.2, 353902.5 6688395.5 19.2, 353907.4 6688401.5 19.2, 353892.0022898072 6688414.212981236 19.2, 353892.0022898072 6688435.906275003 19.2, 353903.5 6688450.1 19.2))
BATIMENT0000000302913108;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;7.4;7.5;15.0;23.7;10.4;Cadastre;C 0.3;POLYGON Z ((353905 6688464 15, 353892.0022898072 6688448.436952269 15, 353892.0022898072 6688474.910486658 15, 353905 6688464 15))
BATIMENT0000000302910658;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;17.1;7.4;24.6;29.4;11.3;Cadastre;A 1.0;POLYGON Z ((353910.9 6688459.1 24.6, 353948.1 6688504.4 24.6, 353948.7 6688503.9 24.6, 353949.6 6688503 24.6, 353982.6 6688476.4 24.6, 353938.3 6688421.7 24.6, 353903.5 6688450.1 24.6, 353910.9 6688459.1 24.6))
BATIMENT0000000302913104;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;10.6;9.1;19.7;28.0;11.9;Cadastre;C 0.3;POLYGON Z ((353903.2 6688508.1 19.7, 353905.2 6688510.6 19.7, 353907.9 6688508.4 19.7, 353908.5 6688507.9 19.7, 353911.6 6688511.5 19.7, 353913.3 6688511.5 19.7, 353916.5 6688508.8 19.7, 353921.3 6688515.1 19.7, 353923.2 6688513.9 19.7, 353924.9 6688515.8 19.7, 353926.8 6688514.5 19.7, 353928.6 6688516.6 19.7, 353930.6 6688515.3 19.7, 353932.4 6688517.3 19.7, 353948.1 6688504.4 19.7, 353910.9 6688459.1 19.7, 353905 6688464 19.7, 353892.0022898072 6688474.910486658 19.7, 353892.0022898072 6688494.828639771 19.7, 353903.2 6688508.1 19.7))
BATIMENT0000000302911735;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:33;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.6;10.5;22.1;22.1;11.3;Cadastre;;POLYGON Z ((353901.6 6688555 22.1, 353934.2 6688563.3 22.1, 353936.5 6688555 22.1, 353903.5 6688546.6 22.1, 353901.6 6688555 22.1))
BATIMENT0000000302911183;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.7;8.3;22.0;24.7;11.1;Cadastre;;POLYGON Z ((353946.8 6688575.7 22, 353941.6 6688574 22, 353927.2 6688616.4 22, 353938.3 6688620.4 22, 353954.9 6688570.9 22, 353949.3 6688569 22, 353946.8 6688575.7 22))
BATIMENT0000000302913100;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;11.6;25.9;30.5;13.5;Cadastre;;POLYGON Z ((353897 6688606.9 25.9, 353900.4 6688598 25.9, 353892.0022898072 6688594.966190359 25.9, 353892.0022898072 6688605.105950188 25.9, 353897 6688606.9 25.9))
BATIMENT0000000302912851;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.6;10.9;16.6;20.8;12.5;Cadastre;;POLYGON Z ((353919.4 6688605.3 16.6, 353919.1 6688605.3 16.6, 353918.9 6688605.4 16.6, 353918.6 6688605.4 16.6, 353918.4 6688605.5 16.6, 353918.1 6688605.6 16.6, 353917.9 6688605.8 16.6, 353917.5 6688606.1 16.6, 353917.3 6688606.3 16.6, 353917.2 6688606.5 16.6, 353917 6688606.7 16.6, 353916.9 6688606.9 16.6, 353916.8 6688607.2 16.6, 353916.7 6688607.6 16.6, 353916.8 6688608 16.6, 353916.8 6688608.4 16.6, 353916.8 6688608.8 16.6, 353916.9 6688609.2 16.6, 353915 6688614.8 16.6, 353919.2 6688616.1 16.6, 353921 6688610.9 16.6, 353921.2 6688610.7 16.6, 353921.4 6688610.6 16.6, 353921.6 6688610.4 16.6, 353921.8 6688610.2 16.6, 353922 6688609.9 16.6, 353922.1 6688609.7 16.6, 353922.3 6688609.4 16.6, 353922.4 6688609.2 16.6, 353922.5 6688608.9 16.6, 353922.5 6688608.7 16.6, 353922.6 6688608.1 16.6, 353922.5 6688607.5 16.6, 353922.5 6688607.3 16.6, 353922.4 6688607 16.6, 353922.3 6688606.7 16.6, 353922.1 6688606.5 16.6, 353921.8 6688606.1 16.6, 353921.6 6688605.9 16.6, 353921.4 6688605.8 16.6, 353921.1 6688605.6 16.6, 353920.9 6688605.5 16.6, 353920.7 6688605.4 16.6, 353920.4 6688605.4 16.6, 353920.2 6688605.3 16.6, 353919.9 6688605.3 16.6, 353919.6 6688605.3 16.6, 353919.4 6688605.3 16.6))
BATIMENT0000000302912850;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.3;10.4;18.7;23.2;12.7;Cadastre;;POLYGON Z ((353896.9 6688639.7 18.7, 353901.4 6688641.8 18.7, 353903.2 6688638.4 18.7, 353898.5 6688636.3 18.7, 353896.9 6688639.7 18.7))
BATIMENT0000000302910663;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:33;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.5;7.1;20.6;21.0;7.3;Cadastre;;POLYGON Z ((353958.7 6688386.5 20.6, 353968.8 6688398.6 20.6, 353983.5 6688386.6 20.6, 353979.1 6688381.1 20.6, 353984.4 6688376.9 20.6, 353970.7 6688359.7 20.6, 353965.1 6688363.8 20.6, 353960.7 6688358.2 20.6, 353945.7 6688370.3 20.6, 353954.7 6688381.5 20.6, 353958.7 6688386.5 20.6))
BATIMENT0000000302910659;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;18.1;7.7;25.8;;;Cadastre;A 1.0;POLYGON Z ((353994.7 6688499.6 25.8, 353992.1 6688496.5 25.8, 353996.2 6688493.5 25.8, 353995 6688491.9 25.8, 353982.6 6688476.4 25.8, 353949.6 6688503 25.8, 353948.7 6688503.9 25.8, 353950.3 6688505.8 25.8, 353953.1 6688503.6 25.8, 353960.7 6688512.5 25.8, 353964.6 6688509.3 25.8, 353967.4 6688512.7 25.8, 353979.1 6688503.9 25.8, 353982.4 6688508.4 25.8, 353982.5 6688508.5 25.8, 353982.9 6688509 25.8, 353984.2 6688508 25.8, 353994.7 6688499.6 25.8))
BATIMENT0000000302910359;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.0;7.1;17.2;21.8;9.4;Cadastre;;POLYGON Z ((353975.4 6688577.2 17.2, 353996.3 6688582.3 17.2, 353998.1 6688575.8 17.2, 353998.3 6688575.2 17.2, 353999.1 6688571.6 17.2, 353979 6688566.6 17.2, 353977.8 6688570.7 17.2, 353968.5 6688568.5 17.2, 353962.6 6688585.7 17.2, 353971.1 6688588.6 17.2, 353975.4 6688577.2 17.2))
BATIMENT0000000291500477;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-07-01 11:16:15;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.7;7.0;;11.9;8.1;Imagerie aérienne;;POLYGON Z ((353991.9 6688595.6 10.7, 353993.9 6688588.8 10.2, 353979 6688585.2 10.2, 353976.9 6688591.4 10.7, 353991.9 6688595.6 10.7))
BATIMENT0000000302922980;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.4;7.3;19.7;23.4;8.3;Cadastre;;POLYGON Z ((354020.5 6688592.5 19.7, 354018.6 6688592 19.7, 354017.9 6688594.9 19.7, 354019.8 6688595.1 19.7, 354020.5 6688592.5 19.7))
BATIMENT0000000302910360;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;4.0;00;00;11.5;7.9;19.5;25.2;8.6;Cadastre;C 0.7;POLYGON Z ((353996.3 6688582.3 19.5, 353995.1 6688587 19.5, 354011.1 6688590.5 19.5, 354010.5 6688593.5 19.5, 354009.3 6688593.3 19.5, 354000.3 6688603.1 19.5, 353985.6 6688619 19.5, 353995.9 6688628.3 19.5, 354010.2 6688612.6 19.5, 354023.4 6688598.5 19.5, 354019.8 6688595.1 19.5, 354017.9 6688594.9 19.5, 354018.6 6688592 19.5, 354020.5 6688592.5 19.5, 354030.2 6688594.5 19.5, 354034.5 6688598.5 19.5, 354039.5 6688592.8 19.5, 354040.6 6688593.7 19.5, 354037.8 6688596.7 19.5, 354039.5 6688598.1 19.5, 354046.1 6688590.4 19.5, 354038.5 6688583.6 19.5, 354008.7 6688577.4 19.5, 354008.6 6688578 19.5, 353998.1 6688575.8 19.5, 353996.3 6688582.3 19.5))
BATIMENT0000000029199410;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1966-01-01;;;;BDTopo;2.5;BDTopo;1.5;20.0;4.0;25;49;12.9;7.9;;;;Imagerie aérienne;A 1.0;POLYGON Z ((353951.8 6688614.8 20.7, 353962.4 6688618.3 20.7, 353969.8 6688594.6 20.5, 353959.9 6688591.4 20.8, 353951.8 6688614.8 20.7))
BATIMENT0000000302910366;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.2;7.7;14.0;16.6;9.3;Cadastre;A 1.0;POLYGON Z ((353952 6688637.4 14, 353953.4 6688637.2 14, 353954.3 6688627 14, 353949.2 6688626.5 14, 353948.1 6688638.7 14, 353951.8 6688638.9 14, 353952 6688637.4 14))
BATIMENT0000000302912344;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.5;6.8;15.3;16.2;9.4;Cadastre;A 1.0;POLYGON Z ((353975.8 6688635.6 15.3, 353972.5 6688632.3 15.3, 353963.8 6688640.5 15.3, 353966.8 6688644.7 15.3, 353975.8 6688635.6 15.3))
BATIMENT0000000302910362;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;11.2;7.2;18.4;22.4;9.3;Cadastre;A 1.0;POLYGON Z ((353959.1 6688650.5 18.4, 353962.7 6688647.7 18.4, 353955.5 6688638 18.4, 353951.8 6688638.9 18.4, 353948.1 6688638.7 18.4, 353947.8 6688642.1 18.4, 353947.5 6688645.8 18.4, 353949.4 6688645.9 18.4, 353949.3 6688647.6 18.4, 353949.1 6688647.6 18.4, 353948.7 6688647.7 18.4, 353948.5 6688647.8 18.4, 353948.3 6688647.9 18.4, 353948.1 6688648 18.4, 353947.9 6688648.1 18.4, 353947.7 6688648.2 18.4, 353947.6 6688648.3 18.4, 353947.4 6688648.6 18.4, 353947.2 6688648.8 18.4, 353946.5 6688655.7 18.4, 353948 6688659.6 18.4, 353949.1 6688658.7 18.4, 353959.1 6688650.5 18.4))
BATIMENT0000000302923342;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.6;7.0;12.6;12.7;7.3;Cadastre;;POLYGON Z ((354028.1 6688426.1 12.6, 354034 6688433.4 12.6, 354039.9 6688428.6 12.6, 354033.9 6688421.3 12.6, 354028.1 6688426.1 12.6))
BATIMENT0000000302923341;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;5.7;6.8;12.5;12.8;7.3;Cadastre;A 0.1;POLYGON Z ((354037.9 6688438.1 12.5, 354045.6 6688431.8 12.5, 354035.8 6688419.8 12.5, 354033.9 6688421.3 12.5, 354039.9 6688428.6 12.5, 354034 6688433.4 12.5, 354037.9 6688438.1 12.5))
BATIMENT0000000302923311;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.1;7.0;23.1;27.0;7.9;Cadastre;;POLYGON Z ((354061.4 6688582.6 23.1, 354066.5 6688583.8 23.1, 354066.3 6688584.7 23.1, 354066 6688586.4 23.1, 354068.3 6688587 23.1, 354067.2 6688592.3 23.1, 354070.1 6688592.9 23.1, 354070.3 6688591.8 23.1, 354072.5 6688581.3 23.1, 354061.8 6688579.1 23.1, 354061.4 6688582.6 23.1))
BATIMENT0000000302923310;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;15.9;7.0;22.9;26.9;8.3;Cadastre;C 0.5;POLYGON Z ((354050.8 6688576.9 22.9, 354050 6688580.9 22.9, 354049 6688586 22.9, 354047.7 6688593.4 22.9, 354056 6688600.8 22.9, 354064.8 6688602.9 22.9, 354069.2 6688598 22.9, 354070.1 6688592.9 22.9, 354067.2 6688592.3 22.9, 354068.3 6688587 22.9, 354066 6688586.4 22.9, 354066.3 6688584.7 22.9, 354066.5 6688583.8 22.9, 354061.4 6688582.6 22.9, 354061.8 6688579.1 22.9, 354050.8 6688576.9 22.9))
BATIMENT0000000302923014;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;16.1;7.0;23.1;25.3;8.5;Cadastre;C 0.8;POLYGON Z ((354047.6 6688621.6 23.1, 354047.1 6688621.1 23.1, 354055.1 6688612.4 23.1, 354055.7 6688612.8 23.1, 354060 6688608.1 23.1, 354049.7 6688598.9 23.1, 354034.5 6688615.3 23.1, 354044.6 6688624.9 23.1, 354047.6 6688621.6 23.1))
BATIMENT0000000302923013;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.2;7.1;23.3;25.6;8.5;Cadastre;A 1.0;POLYGON Z ((354034.5 6688615.3 23.3, 354028.2 6688622.2 23.3, 354038.1 6688631 23.3, 354038.6 6688631.5 23.3, 354044.6 6688624.9 23.3, 354034.5 6688615.3 23.3))
BATIMENT0000000302923012;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;15.7;7.1;22.9;25.9;8.3;Cadastre;C 0.1;POLYGON Z ((354024.3 6688626.7 22.9, 354034 6688635.6 22.9, 354038.1 6688631 22.9, 354028.2 6688622.2 22.9, 354024.3 6688626.7 22.9))
BATIMENT0000000302922994;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;68.0;4.0;39;90;12.0;6.8;18.8;22.0;7.9;Cadastre;C 0.7;POLYGON Z ((354059.7 6688648.4 18.8, 354054.1 6688654.2 18.8, 354056.3 6688656.2 18.8, 354063.3 6688663.4 18.8, 354083.7 6688683.7 18.8, 354089.9 6688677.7 18.8, 354092.9 6688672.6 18.8, 354087.6 6688667.1 18.8, 354099 6688655.4 18.8, 354104.8 6688646.5 18.8, 354103.8 6688645.4 18.8, 354098.7 6688640.1 18.8, 354102.3 6688636.7 18.8, 354089.1 6688622.1 18.8, 354088.2 6688621.2 18.8, 354084.6 6688625 18.8, 354080.4 6688620.5 18.8, 354084.1 6688616.8 18.8, 354083.6 6688616.3 18.8, 354092.5 6688608 18.8, 354082.6 6688597.7 18.8, 354047.5 6688636 18.8, 354059.7 6688648.4 18.8), (354083.8 6688635.1 18.8, 354095.8 6688647 18.8, 354081.4 6688661.1 18.8, 354069.4 6688649 18.8, 354083.8 6688635.1 18.8))
BATIMENT0000000302923568;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;7.2;16.2;19.0;8.5;Cadastre;;POLYGON Z ((354050 6688658.3 16.2, 354051.2 6688657.1 16.2, 354054.1 6688654.2 16.2, 354059.7 6688648.4 16.2, 354047.5 6688636 16.2, 354037.8 6688646.6 16.2, 354050 6688658.3 16.2))
BATIMENT0000000302923569;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;7.3;14.4;15.5;8.6;Cadastre;;POLYGON Z ((354026 6688681.8 14.4, 354028.9 6688678.9 14.4, 354050 6688658.3 14.4, 354037.8 6688646.6 14.4, 354014.5 6688672 14.4, 354025.1 6688682.6 14.4, 354026 6688681.8 14.4))
BATIMENT0000000302911528;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;43.0;5.0;00;00;10.1;7.0;17.1;23.0;8.2;Cadastre;C 0.6;POLYGON Z ((354022.5 6688625.1 17.1, 354016 6688632 17.1, 354010.8 6688629.3 17.1, 354005.4 6688640.4 17.1, 354007.4 6688641.4 17.1, 353999.3 6688650.1 17.1, 353997.5 6688648.3 17.1, 353996.7 6688649.1 17.1, 353994.9 6688647.5 17.1, 353988.9 6688653.7 17.1, 353990.1 6688654.8 17.1, 353978.5 6688667.1 17.1, 353985.1 6688673.2 17.1, 353983.9 6688674.5 17.1, 353990.9 6688680.6 17.1, 353993.2 6688681 17.1, 354034.4 6688636 17.1, 354034 6688635.6 17.1, 354024.3 6688626.7 17.1, 354022.5 6688625.1 17.1))
BATIMENT0000000302910361;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;00;00;11.4;7.0;18.5;23.2;7.6;Cadastre;C 0.3;POLYGON Z ((353950.3 6688665.8 18.5, 353951.5 6688665.2 18.5, 353952.6 6688668.5 18.5, 353951.3 6688668.8 18.5, 353953.7 6688675.2 18.5, 353954.8 6688674.8 18.5, 353956.6 6688679.8 18.5, 353967.5 6688675.9 18.5, 353965.1 6688668.4 18.5, 353970.5 6688663.8 18.5, 353962.7 6688654.6 18.5, 353961 6688655.9 18.5, 353959.1 6688650.5 18.5, 353949.1 6688658.7 18.5, 353950.7 6688662.8 18.5, 353949.4 6688663.5 18.5, 353950.3 6688665.8 18.5))
BATIMENT0000000302910365;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.5;7.0;20.5;20.8;7.3;Cadastre;;POLYGON Z ((353951.3 6688668.8 20.5, 353952.6 6688668.5 20.5, 353951.5 6688665.2 20.5, 353950.3 6688665.8 20.5, 353951.3 6688668.8 20.5))
BATIMENT0000000029198469;Indifférenciée;Résidentiel;;Non;En service;2006-10-04 09:41:10;2023-01-31 17:32:33;1900-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;1.0;10;20;5.5;7.3;;13.3;8.2;Imagerie aérienne;C 0.6;POLYGON Z ((353981.2 6688674.2 12.8, 353976 6688670.2 12.5, 353969.8 6688678.1 12.6, 353974.4 6688681.9 12.5, 353981.2 6688674.2 12.8))
BATIMENT0000000302910364;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.4;7.0;20.4;20.7;7.3;Cadastre;;POLYGON Z ((353955.5 6688680.2 20.4, 353956.6 6688679.8 20.4, 353954.8 6688674.8 20.4, 353953.7 6688675.2 20.4, 353955.5 6688680.2 20.4))
BATIMENT0000000302911529;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2023-01-31 17:32:33;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.8;7.0;16.8;17.2;8.0;Cadastre;;POLYGON Z ((353979.7 6688678.9 16.8, 353988 6688686.6 16.8, 353993.2 6688681 16.8, 353990.9 6688680.6 16.8, 353983.9 6688674.5 16.8, 353979.7 6688678.9 16.8))
BATIMENT0000000302910369;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;10.8;6.9;17.8;19.5;7.4;Cadastre;C 0.7;POLYGON Z ((353970.9 6688683.5 17.8, 353969 6688685.6 17.8, 353966.5 6688679 17.8, 353956.2 6688682.2 17.8, 353961.3 6688696.4 17.8, 353971.3 6688685.5 17.8, 353972.1 6688684.5 17.8, 353970.9 6688683.5 17.8))
BATIMENT0000000302910368;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;00;00;6.2;6.9;13.2;18.2;7.5;Cadastre;A 1.0;POLYGON Z ((353984.1 6688691 13.2, 353974.5 6688682 13.2, 353972.1 6688684.5 13.2, 353971.3 6688685.5 13.2, 353981.1 6688694.3 13.2, 353984.1 6688691 13.2))
BATIMENT0000000302911400;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.4;7.0;16.4;18.6;7.6;Cadastre;A 1.0;POLYGON Z ((353982.2 6688707.3 16.4, 353982.9 6688709.4 16.4, 353993.8 6688713.8 16.4, 354009.7 6688698.3 16.4, 354016.1 6688692.1 16.4, 354015.9 6688691.5 16.4, 354025.1 6688682.6 16.4, 354014.5 6688672 16.4, 353982.2 6688707.3 16.4))
BATIMENT0000000302910367;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;13.0;7.0;20.0;22.7;7.4;Cadastre;A 1.0;POLYGON Z ((353962.6 6688700.2 20, 353972.2 6688704 20, 353981.1 6688694.3 20, 353971.3 6688685.5 20, 353961.3 6688696.4 20, 353962.6 6688700.2 20), (353971.8 6688689.4 20, 353972.4 6688690.7 20, 353970.3 6688693 20, 353969.3 6688692 20, 353971.8 6688689.4 20))
BATIMENT0000000302910328;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-07-01 11:16:15;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.7;9.9;30.6;;;Cadastre;;POLYGON Z ((353922.5 6688668.6 30.6, 353924.6 6688669.4 30.6, 353930.3 6688658.1 30.6, 353892.0022898072 6688639.406085306 30.6, 353892.0022898072 6688653.579714466 30.6, 353922.5 6688668.6 30.6))
BATIMENT0000000302910363;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;7.1;20.4;20.7;7.4;Cadastre;;POLYGON Z ((353948 6688659.6 20.4, 353949.4 6688663.5 20.4, 353950.7 6688662.8 20.4, 353949.1 6688658.7 20.4, 353948 6688659.6 20.4))
BATIMENT0000000302910434;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;8.4;11.5;19.0;8.7;Cadastre;;POLYGON Z ((353894.7 6688694.4 11.5, 353895.7 6688695 11.5, 353897.4 6688692.6 11.5, 353896.1 6688691.8 11.5, 353896.6 6688691.3 11.5, 353892.0022898072 6688689.297771367 11.5, 353892.0022898072 6688698.746310866 11.5, 353894.7 6688694.4 11.5))
BATIMENT0000000302911399;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.9;7.0;16.9;19.9;8.0;Cadastre;C 0.1;POLYGON Z ((353940 6688738.9 16.9, 353941.2 6688736.1 16.9, 353942 6688736.4 16.9, 353950.6 6688717.1 16.9, 353949.4 6688716.5 16.9, 353950 6688714.7 16.9, 353948.4 6688714 16.9, 353948.9 6688713 16.9, 353915.5 6688698.8 16.9, 353913.3 6688704.3 16.9, 353910.5 6688703.1 16.9, 353901 6688725.8 16.9, 353923 6688735.1 16.9, 353924.1 6688732.2 16.9, 353935.2 6688737 16.9, 353940 6688738.9 16.9))
BATIMENT0000000302911398;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.1;7.0;17.1;17.5;7.6;Cadastre;;POLYGON Z ((353934 6688739.9 17.1, 353935.2 6688737 17.1, 353924.1 6688732.2 17.1, 353923 6688735.1 17.1, 353934 6688739.9 17.1))
BATIMENT0000000302911181;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;7.2;11.4;18.2;7.8;Cadastre;;POLYGON Z ((353898.3 6688745.4 11.4, 353893.3 6688753.4 11.4, 353892.0022898072 6688755.908906372 11.4, 353892.0022898072 6688756.432266412 11.4, 353894.4 6688758 11.4, 353894 6688758.8 11.4, 353896.8 6688760.7 11.4, 353902.9 6688751 11.4, 353904 6688749.1 11.4, 353898.3 6688745.4 11.4))
BATIMENT0000000302910501;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:33;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;8.5;12.4;13.7;10.1;Cadastre;;POLYGON Z ((353892.3 6688768.7 12.4, 353893.6 6688769.6 12.4, 353896.5 6688765.5 12.4, 353892.0022898072 6688762.578806782 12.4, 353892.0022898072 6688768.835322815 12.4, 353892.3 6688768.7 12.4))
BATIMENT0000000302910503;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;7.7;10.7;13.5;8.5;Cadastre;;POLYGON Z ((353923.9 6688755.8 10.7, 353921 6688753.1 10.7, 353917.4 6688756.9 10.7, 353920.8 6688759.1 10.7, 353923.9 6688755.8 10.7))
BATIMENT0000000302913126;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;3.0;10;90;9.3;7.3;16.7;19.9;9.7;Cadastre;C 0.5;POLYGON Z ((353903.5 6688776.2 16.7, 353906.5 6688774.7 16.7, 353920.8 6688759.1 16.7, 353917.4 6688756.9 16.7, 353909.7 6688752.1 16.7, 353899.1 6688767.2 16.7, 353896.5 6688765.5 16.7, 353893.6 6688769.6 16.7, 353903.5 6688776.2 16.7))
BATIMENT0000000302910578;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.6;7.4;15.0;18.7;9.1;Cadastre;A 1.0;POLYGON Z ((353931.7 6688763.9 15, 353936.9 6688774.4 15, 353940.4 6688781.6 15, 353942.9 6688780.2 15, 353939.4 6688773.1 15, 353945.1 6688770.2 15, 353943.5 6688767.9 15, 353936.6 6688758.5 15, 353931.7 6688763.9 15))
BATIMENT0000000302922998;Industriel, agricole ou commercial;Annexe;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.2;6.5;11.7;20.2;7.8;Cadastre;C 0.1;POLYGON Z ((354093.9 6688676.7 11.7, 354107 6688673.3 11.7, 354105.7 6688668.5 11.7, 354092.6 6688671.7 11.7, 354092.9 6688672.6 11.7, 354093.9 6688676.7 11.7))
BATIMENT0000000302922995;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;19.0;4.0;00;00;;6.7;;;;Cadastre;C 0.2;POLYGON Z ((354048 6688696.5 17.2, 354051.1 6688693.2 17.2, 354047.5 6688690 17.2, 354051.3 6688686.1 17.2, 354054.5 6688689.1 17.2, 354064.2 6688685.4 17.2, 354071.7 6688678 17.2, 354053.2 6688659.1 17.2, 354051.2 6688657.1 17.2, 354050 6688658.3 17.2, 354028.9 6688678.9 17.2, 354032.4 6688682.4 17.2, 354032.9 6688681.8 17.2, 354034.3 6688680.2 17.2, 354038 6688683.5 17.2, 354036.3 6688685.3 17.2, 354036.5 6688685.5 17.2, 354036.2 6688685.8 17.2, 354042.3 6688691.3 17.2, 354048 6688696.5 17.2))
BATIMENT0000000302923313;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;2.0;35;20;5.1;7.0;12.1;13.7;8.3;Cadastre;C 0.3;POLYGON Z ((354095.9 6688722.2 12.1, 354095.2 6688723.5 12.1, 354102 6688726.1 12.1, 354107.8 6688711.6 12.1, 354080.6 6688700.3 12.1, 354074.7 6688714.9 12.1, 354081.2 6688717.5 12.1, 354081.5 6688716.3 12.1, 354095.9 6688722.2 12.1))
BATIMENT0000000302923303;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;6.0;00;00;11.3;6.9;18.2;25.1;8.1;Cadastre;A 1.0;POLYGON Z ((354027.8 6688728.9 18.2, 354056.5 6688740.3 18.2, 354062.3 6688726 18.2, 354064 6688721.9 18.2, 354058.9 6688719.7 18.2, 354056.6 6688722.9 18.2, 354052.8 6688721.2 18.2, 354054 6688717.8 18.2, 354034.5 6688709.9 18.2, 354033.8 6688710.2 18.2, 354035.3 6688711.8 18.2, 354034.5 6688713.6 18.2, 354032.9 6688716.9 18.2, 354027.8 6688728.9 18.2))
BATIMENT0000000302923305;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;43.0;5.0;35;20;13.7;7.4;21.2;25.3;8.1;Cadastre;C 0.9;POLYGON Z ((354103.2 6688742.3 21.2, 354087.4 6688736.1 21.2, 354088.1 6688734.2 21.2, 354077.3 6688729.9 21.2, 354076.6 6688731.8 21.2, 354062.3 6688726 21.2, 354056.5 6688740.3 21.2, 354060.9 6688742.1 21.2, 354061.4 6688740.8 21.2, 354066.5 6688742.9 21.2, 354066 6688744.1 21.2, 354097.8 6688756.9 21.2, 354100.3 6688750.2 21.2, 354103.2 6688742.3 21.2))
BATIMENT0000000302923328;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;00;00;14.0;7.5;21.5;25.6;9.0;Cadastre;C 0.7;POLYGON Z ((354046.6 6688771.3 21.5, 354048 6688769.2 21.5, 354052.6 6688771 21.5, 354053.3 6688769.2 21.5, 354056 6688770.4 21.5, 354055.5 6688771.7 21.5, 354071.2 6688778.1 21.5, 354074.4 6688785.6 21.5, 354078.8 6688781.1 21.5, 354085.3 6688783.6 21.5, 354090.9 6688776.3 21.5, 354091.8 6688775.2 21.5, 354090.4 6688774.6 21.5, 354091.1 6688772.8 21.5, 354087.5 6688771.2 21.5, 354088.2 6688769.3 21.5, 354084.9 6688768 21.5, 354042.1 6688750.7 21.5, 354041 6688752.3 21.5, 354033.9 6688763 21.5, 354046.6 6688771.3 21.5))
BATIMENT0000000302923329;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;7.4;19.9;22.5;8.2;Cadastre;;POLYGON Z ((354087.5 6688771.2 19.9, 354091.1 6688772.8 19.9, 354090.4 6688774.6 19.9, 354091.8 6688775.2 19.9, 354092.4 6688774.4 19.9, 354092.7 6688774 19.9, 354093.7 6688771.6 19.9, 354088.2 6688769.3 19.9, 354087.5 6688771.2 19.9))
BATIMENT0000000302923330;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;33.0;5.0;00;00;11.8;7.4;19.3;23.7;9.0;Cadastre;A 1.0;POLYGON Z ((354093.7 6688771.6 19.3, 354092.7 6688774 19.3, 354092.4 6688774.4 19.3, 354091.8 6688775.2 19.3, 354090.9 6688776.3 19.3, 354085.3 6688783.6 19.3, 354073.7 6688798.6 19.3, 354073.6 6688799.1 19.3, 354076.3 6688801.3 19.3, 354076 6688801.7 19.3, 354077.9 6688803.4 19.3, 354088.5 6688812.1 19.3, 354091.7 6688814.8 19.3, 354094 6688816.7 19.3, 354109.3 6688808.9 19.3, 354106.9 6688805.1 19.3, 354124 6688783.7 19.3, 354114 6688779.6 19.3, 354114.9 6688776.3 19.3, 354094.9 6688769.4 19.3, 354094.5 6688769.9 19.3, 354093.7 6688771.6 19.3), (354097.6 6688782.3 19.3, 354101.5 6688785.2 19.3, 354100.8 6688786.3 19.3, 354102.5 6688787.5 19.3, 354103.2 6688786.5 19.3, 354106.8 6688789.4 19.3, 354097.4 6688801.1 19.3, 354088.4 6688793.7 19.3, 354097.6 6688782.3 19.3))
BATIMENT0000000302923335;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;4.0;00;00;10.8;8.1;19.0;20.9;9.3;Cadastre;C 0.1;POLYGON Z ((354020.4 6688783.5 19, 354022.6 6688785.1 19, 354023.7 6688787.4 19, 354027.9 6688796.1 19, 354028.8 6688795.6 19, 354030.1 6688798.3 19, 354029.2 6688798.8 19, 354031.7 6688804 19, 354033.5 6688803.1 19, 354041.7 6688820.2 19, 354039.9 6688821 19, 354045 6688831.8 19, 354046 6688831.3 19, 354047.2 6688833.6 19, 354046.8 6688833.8 19, 354048.3 6688836.8 19, 354055.7 6688833 19, 354054.5 6688830.7 19, 354061.3 6688827.2 19, 354062.7 6688826.5 19, 354063.3 6688822.2 19, 354061.7 6688822.1 19, 354042.3 6688778.5 19, 354041.5 6688778.9 19, 354028.9 6688770.6 19, 354020.4 6688783.5 19))
BATIMENT0000000302923332;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;10.6;9.5;20.1;;;Cadastre;C 0.3;POLYGON Z ((354077.9 6688803.4 20.1, 354075 6688806.9 20.1, 354075.3 6688807.6 20.1, 354069.9 6688810.3 20.1, 354073.5 6688817.4 20.1, 354074.5 6688816.8 20.1, 354075.7 6688819.2 20.1, 354075.4 6688819.4 20.1, 354076.8 6688822.3 20.1, 354082.5 6688819.4 20.1, 354082.3 6688819.1 20.1, 354088.5 6688812.1 20.1, 354077.9 6688803.4 20.1))
BATIMENT0000000302911401;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.0;7.0;19.0;21.2;7.5;Cadastre;;POLYGON Z ((353993.8 6688713.8 19, 353994.6 6688714.1 19, 353994.9 6688713.4 19, 353996.7 6688714.3 19, 353996.4 6688714.8 19, 354008.5 6688719.7 19, 354016.1 6688701 19, 354009.7 6688698.3 19, 353993.8 6688713.8 19))
BATIMENT0000000302923304;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;11.7;7.0;18.7;21.3;7.4;Cadastre;C 0.5;POLYGON Z ((354032.6 6688710.5 18.7, 354032.7 6688709.1 18.7, 354020.6 6688704.4 18.7, 354013 6688722.9 18.7, 354027.8 6688728.9 18.7, 354032.9 6688716.9 18.7, 354032.6 6688710.5 18.7))
BATIMENT0000000302910577;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;6.0;00;00;15.8;7.3;23.1;26.6;9.1;Cadastre;C 0.6;POLYGON Z ((353973.4 6688734.4 23.1, 353975.9 6688733.8 23.1, 353982.5 6688736.7 23.1, 353981.9 6688738.1 23.1, 353990.9 6688741.9 23.1, 353991.3 6688741.1 23.1, 353997.5 6688743.5 23.1, 353997.2 6688744.5 23.1, 354000.2 6688745.8 23.1, 354000.5 6688745.3 23.1, 354014.1 6688750.8 23.1, 354013.3 6688752.7 23.1, 354029.5 6688759.4 23.1, 354036.9 6688748.2 23.1, 354028.4 6688744.8 23.1, 354027.8 6688744.6 23.1, 354020.8 6688741.8 23.1, 353979.5 6688725.3 23.1, 353970.5 6688721.6 23.1, 353973.4 6688734.4 23.1))
BATIMENT0000000302910576;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.1;7.4;18.5;25.7;9.1;Cadastre;;POLYGON Z ((353943.5 6688767.9 18.5, 353948 6688762.8 18.5, 353948.9 6688763.8 18.5, 353951.9 6688760.4 18.5, 353950.9 6688759.5 18.5, 353958.2 6688751.4 18.5, 353959.1 6688752.3 18.5, 353969.5 6688740.7 18.5, 353967.4 6688738.8 18.5, 353971.3 6688734.8 18.5, 353973.4 6688734.4 18.5, 353970.5 6688721.6 18.5, 353936.6 6688758.5 18.5, 353943.5 6688767.9 18.5))
BATIMENT0000000302923015;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.1;7.4;20.5;23.3;8.7;Cadastre;;POLYGON Z ((354001 6688774.7 20.5, 354002.5 6688775.7 20.5, 354006.4 6688778.5 20.5, 354009.9 6688773.2 20.5, 354008.6 6688772.4 20.5, 354004.4 6688769.5 20.5, 354001 6688774.7 20.5))
BATIMENT0000000302911618;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;90.0;4.0;00;00;12.7;8.0;20.8;23.4;9.1;Cadastre;C 0.1;POLYGON Z ((354003.6 6688779.5 20.8, 354003.6 6688779.4 20.8, 354003.5 6688779.1 20.8, 354003.5 6688779 20.8, 354003.4 6688778.8 20.8, 354003.3 6688778.6 20.8, 354003.1 6688778.3 20.8, 354002.8 6688778 20.8, 354001.5 6688777.2 20.8, 354002.5 6688775.7 20.8, 354001 6688774.7 20.8, 354004.4 6688769.5 20.8, 354008.6 6688772.4 20.8, 354009.9 6688773.2 20.8, 354013.7 6688767.4 20.8, 354008.1 6688763.6 20.8, 354007.5 6688764.5 20.8, 354006.6 6688763.9 20.8, 354007.1 6688762.9 20.8, 354001.8 6688759.4 20.8, 353981.4 6688790.8 20.8, 353977.4 6688799.5 20.8, 353988 6688806.5 20.8, 353999.4 6688789.5 20.8, 353997.8 6688788.4 20.8, 354003.6 6688779.7 20.8, 354003.6 6688779.5 20.8))
BATIMENT0000000302911619;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;8.0;19.7;20.7;8.6;Cadastre;;POLYGON Z ((354003.5 6688780.8 19.7, 354003.6 6688780.5 19.7, 354003.6 6688780.2 19.7, 354003.6 6688780.1 19.7, 354003.7 6688779.9 19.7, 354003.6 6688779.7 19.7, 353997.8 6688788.4 19.7, 353999.4 6688789.5 19.7, 354003.5 6688780.8 19.7))
BATIMENT0000000302923336;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.0;7.8;17.9;18.6;8.4;Cadastre;;POLYGON Z ((354019.6 6688784.8 17.9, 354023.7 6688787.4 17.9, 354022.6 6688785.1 17.9, 354020.4 6688783.5 17.9, 354019.6 6688784.8 17.9))
BATIMENT0000000302910345;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;59;20;12.4;9.0;21.4;23.8;9.8;Cadastre;C 0.7;POLYGON Z ((353962.9 6688828.3 21.4, 353973.7 6688823.2 21.4, 353973.9 6688823.1 21.4, 353970.6 6688816.7 21.4, 353971.7 6688816.2 21.4, 353968.9 6688810.5 21.4, 353967.7 6688811.2 21.4, 353960.6 6688796.9 21.4, 353961.9 6688796.2 21.4, 353958.8 6688790.4 21.4, 353957.8 6688790.9 21.4, 353954.8 6688784.8 21.4, 353944.3 6688790.4 21.4, 353947.3 6688796.5 21.4, 353951.6 6688805.3 21.4, 353962.9 6688828.3 21.4))
BATIMENT0000000302911480;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;5.4;9.5;14.9;17.4;9.9;Cadastre;C 0.1;POLYGON Z ((353982.5 6688817.7 14.9, 353988 6688829.4 14.9, 353998.9 6688824.4 14.9, 353993.4 6688812.8 14.9, 353982.5 6688817.7 14.9))
BATIMENT0000000302910502;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;10.6;8.0;18.7;21.6;10.2;Cadastre;A 1.0;POLYGON Z ((353903.5 6688776.2 18.7, 353893.6 6688769.6 18.7, 353892.3 6688768.7 18.7, 353892.0022898072 6688768.835322815 18.7, 353892.0022898072 6688781.822967758 18.7, 353903.5 6688776.2 18.7))
BATIMENT0000000302910347;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;8.6;15.7;20.7;9.5;Cadastre;;POLYGON Z ((353952.5 6688781.6 15.7, 353942.4 6688786.6 15.7, 353944.3 6688790.4 15.7, 353954.8 6688784.8 15.7, 353952.5 6688781.6 15.7))
BATIMENT0000000302912342;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;10.1;18.3;18.9;10.8;Cadastre;;POLYGON Z ((353949.4 6688819.8 18.3, 353926.1 6688771.7 18.3, 353924.7 6688771.2 18.3, 353899.9 6688798.4 18.3, 353896.4 6688808.3 18.3, 353914.2 6688811.9 18.3, 353935.3 6688826.8 18.3, 353949.4 6688819.8 18.3))
BATIMENT0000000302912343;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.1;10.4;16.5;18.7;10.9;Cadastre;A 1.0;POLYGON Z ((353893.8 6688816.4 16.5, 353919.5 6688834.7 16.5, 353935.3 6688826.8 16.5, 353914.2 6688811.9 16.5, 353896.4 6688808.3 16.5, 353893.8 6688816.4 16.5))
BATIMENT0000000302910370;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.6;9.3;18.0;21.4;10.8;Cadastre;C 0.5;POLYGON Z ((353952.6 6688826.9 18, 353928.2 6688838.9 18, 353930.5 6688866 18, 353934.1 6688865.7 18, 353933.8 6688861.9 18, 353933.1 6688852.5 18, 353938.5 6688849.8 18, 353943.1 6688847.6 18, 353958.9 6688839.9 18, 353952.6 6688826.9 18))
BATIMENT0000000302913116;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.8;10.3;17.1;19.2;12.1;Cadastre;C 0.7;POLYGON Z ((353899.1 6688871.6 17.1, 353904.8 6688863.6 17.1, 353911.6 6688854.5 17.1, 353913.6 6688851.8 17.1, 353918.5 6688845.7 17.1, 353918.8 6688843.6 17.1, 353892.0022898072 6688824.528636906 17.1, 353892.0022898072 6688866.399091668 17.1, 353899.1 6688871.6 17.1))
BATIMENT0000000302913115;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;46;20;8.2;9.7;18.0;24.2;11.1;Cadastre;C 0.4;POLYGON Z ((353918.9 6688870.1 18, 353920.1 6688870 18, 353926.1 6688869.2 18, 353923.4 6688841.2 18, 353918.8 6688843.6 18, 353918.5 6688845.7 18, 353913.6 6688851.8 18, 353916.9 6688854.3 18, 353918.9 6688870.1 18))
BATIMENT0000000302913119;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;20;20;4.4;9.9;14.3;15.4;10.7;Cadastre;C 0.3;POLYGON Z ((353945.4 6688864.6 14.3, 353943.3 6688865.7 14.3, 353944 6688867.3 14.3, 353950.8 6688864 14.3, 353943.1 6688847.6 14.3, 353938.5 6688849.8 14.3, 353939.6 6688852.1 14.3, 353945.4 6688864.6 14.3))
BATIMENT0000000302910371;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;9.9;13.2;16.9;10.8;Cadastre;;POLYGON Z ((353935.9 6688857.8 13.2, 353934 6688854.7 13.2, 353939.6 6688852.1 13.2, 353938.5 6688849.8 13.2, 353933.1 6688852.5 13.2, 353933.8 6688861.9 13.2, 353934.1 6688865.7 13.2, 353936.6 6688865.5 13.2, 353936.3 6688861.7 13.2, 353935.9 6688857.8 13.2))
BATIMENT0000000302913114;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.8;11.3;16.1;;;Cadastre;C 0.1;POLYGON Z ((353915.3 6688858.9 16.1, 353915.1 6688857 16.1, 353911.6 6688854.5 16.1, 353904.8 6688863.6 16.1, 353909.2 6688866.6 16.1, 353915.3 6688858.9 16.1))
BATIMENT0000000302912748;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;4.0;00;00;9.9;9.5;19.4;21.9;9.9;Cadastre;C 0.4;POLYGON Z ((353999.5 6688813.8 19.4, 354000.5 6688815.9 19.4, 354002.3 6688815 19.4, 354003.3 6688817.1 19.4, 354002.7 6688817.3 19.4, 354003.1 6688819 19.4, 354004.3 6688821.5 19.4, 354005.2 6688821 19.4, 354011.7 6688834.9 19.4, 354009.9 6688835.7 19.4, 354015.1 6688846.5 19.4, 354016.1 6688846 19.4, 354017.2 6688848.4 19.4, 354016.8 6688848.6 19.4, 354018.3 6688851.5 19.4, 354025.7 6688847.8 19.4, 354024.5 6688845.4 19.4, 354031.2 6688842 19.4, 354032.7 6688841.2 19.4, 354034.8 6688837.3 19.4, 354028.3 6688834.4 19.4, 354018.3 6688813.6 19.4, 354017.8 6688813.8 19.4, 354016.2 6688810.5 19.4, 354016.7 6688810.3 19.4, 354010.4 6688797.2 19.4, 353999.5 6688813.8 19.4))
BATIMENT0000000302910346;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;13;10;8.2;9.5;17.7;21.6;10.1;Cadastre;C 0.8;POLYGON Z ((353974 6688850.9 17.7, 353985.8 6688845.2 17.7, 353974.8 6688822.7 17.7, 353973.9 6688823.1 17.7, 353973.7 6688823.2 17.7, 353962.9 6688828.3 17.7, 353974 6688850.9 17.7))
BATIMENT0000000302913120;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;20;20;15.9;9.6;25.5;28.6;10.4;Cadastre;C 0.9;POLYGON Z ((353953.3 6688862.9 25.5, 353953.9 6688862.4 25.5, 353967 6688856.1 25.5, 353958.9 6688839.9 25.5, 353943.1 6688847.6 25.5, 353950.8 6688864 25.5, 353953.3 6688862.9 25.5), (353945.5 6688848 25.5, 353948.9 6688846.3 25.5, 353955.5 6688859.9 25.5, 353952.1 6688861.6 25.5, 353949.6 6688856.4 25.5, 353950 6688856.1 25.5, 353948.1 6688852.5 25.5, 353947.7 6688852.6 25.5, 353945.5 6688848 25.5))
BATIMENT0000000302910348;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;4.0;00;00;8.9;9.8;18.7;26.1;10.6;Cadastre;A 1.0;POLYGON Z ((353986.4 6688844.9 18.7, 353985.8 6688845.2 18.7, 353974 6688850.9 18.7, 353982.2 6688867.6 18.7, 353983.5 6688870.2 18.7, 353987.9 6688872.6 18.7, 353994.9 6688868.9 18.7, 353997.8 6688867.4 18.7, 354011.4 6688860.7 18.7, 354014.5 6688859 18.7, 354014.9 6688857 18.7, 354010.5 6688847.7 18.7, 354009.1 6688844.8 18.7, 354003.8 6688847.5 18.7, 354004.5 6688848.9 18.7, 354001.5 6688850.3 18.7, 354002.1 6688851.4 18.7, 353992 6688856.3 18.7, 353986.4 6688844.9 18.7))
BATIMENT0000000302910373;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;15.8;9.8;25.7;28.4;10.5;Cadastre;C 0.9;POLYGON Z ((353967 6688856.1 25.7, 353953.9 6688862.4 25.7, 353954.5 6688863.5 25.7, 353956.9 6688862.4 25.7, 353964.4 6688877.6 25.7, 353973.6 6688873.1 25.7, 353975.1 6688872.5 25.7, 353967 6688856.1 25.7))
BATIMENT0000000302910375;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;10.1;15.5;19.5;10.6;Cadastre;;POLYGON Z ((353950.8 6688864 15.5, 353958.7 6688880.4 15.5, 353961.4 6688879.2 15.5, 353953.3 6688862.9 15.5, 353950.8 6688864 15.5))
BATIMENT0000000302910376;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.5;9.9;18.5;21.0;10.3;Cadastre;;POLYGON Z ((353974.3 6688874.6 18.5, 353975.8 6688873.8 18.5, 353975.1 6688872.5 18.5, 353973.6 6688873.1 18.5, 353974.3 6688874.3 18.5, 353974.3 6688874.6 18.5))
BATIMENT0000000302910374;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;10.3;14.5;26.7;10.7;Cadastre;;POLYGON Z ((353974.3 6688874.3 14.5, 353973.6 6688873.1 14.5, 353964.4 6688877.6 14.5, 353961.4 6688879.2 14.5, 353958.7 6688880.4 14.5, 353959.4 6688881.8 14.5, 353974.3 6688874.3 14.5))
BATIMENT0000000302910380;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;11.0;18.1;23.5;11.1;Cadastre;;POLYGON Z ((353979.3 6688881 18.1, 353962.8 6688888.8 18.1, 353965.2 6688894 18.1, 353981.8 6688886 18.1, 353979.3 6688881 18.1))
BATIMENT0000000302913121;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;8.6;15.7;16.4;10.7;Cadastre;;POLYGON Z ((354004 6688910.9 15.7, 354017.1 6688903.6 15.7, 354022.3 6688900.6 15.7, 354015.6 6688886.7 15.7, 354010.6 6688889.3 15.7, 354008 6688884.1 15.7, 354013 6688881.3 15.7, 354011.2 6688876.8 15.7, 354012.4 6688876 15.7, 354011.2 6688873.3 15.7, 354000.8 6688879 15.7, 354004 6688885.7 15.7, 353994.2 6688890.8 15.7, 354004 6688910.9 15.7))
BATIMENT0000000302923331;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.5;8.0;19.6;25.0;8.6;Cadastre;;POLYGON Z ((354088.5 6688812.1 19.6, 354082.3 6688819.1 19.6, 354082.5 6688819.4 19.6, 354091.7 6688814.8 19.6, 354088.5 6688812.1 19.6))
BATIMENT0000000302923334;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;8.8;18.5;20.0;9.1;Cadastre;;POLYGON Z ((354061.3 6688827.2 18.5, 354054.5 6688830.7 18.5, 354055.7 6688833 18.5, 354062.5 6688829.5 18.5, 354061.3 6688827.2 18.5))
BATIMENT0000000302923577;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;3.0;00;00;8.9;7.4;16.3;18.7;10.7;Cadastre;C 0.2;POLYGON Z ((354090.1 6688845.1 16.3, 354111.4 6688834.7 16.3, 354110.7 6688833.1 16.3, 354103.9 6688819.1 16.3, 354082.6 6688829.9 16.3, 354089.6 6688844 16.3, 354090.1 6688845.1 16.3))
BATIMENT0000000302923350;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.4;9.0;11.5;11.8;9.6;Cadastre;;POLYGON Z ((354038.7 6688839.9 11.5, 354040.2 6688840.3 11.5, 354040.8 6688837.9 11.5, 354039.4 6688837.5 11.5, 354038.7 6688839.9 11.5))
BATIMENT0000000302923327;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.9;9.5;19.4;20.6;9.9;Cadastre;;POLYGON Z ((354032.4 6688844.4 19.4, 354031.2 6688842 19.4, 354024.5 6688845.4 19.4, 354025.7 6688847.8 19.4, 354032.4 6688844.4 19.4))
BATIMENT0000000302923565;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;8.5;13.1;22.6;10.4;Cadastre;;POLYGON Z ((354079.7 6688849.9 13.1, 354077.9 6688850.8 13.1, 354087.5 6688871.3 13.1, 354090.1 6688870.1 13.1, 354094.2 6688879.2 13.1, 354096.1 6688878.3 13.1, 354097.7 6688881.3 13.1, 354106.2 6688877 13.1, 354103.3 6688871.1 13.1, 354102.2 6688869.2 13.1, 354094.6 6688854 13.1, 354084.7 6688858.9 13.1, 354080.3 6688850 13.1, 354090.1 6688845.1 13.1, 354089.6 6688844 13.1, 354082.6 6688829.9 13.1, 354072.6 6688835 13.1, 354076.7 6688842.9 13.1, 354079.7 6688849.9 13.1))
BATIMENT0000000323902145;Indifférenciée;Indifférencié;;Non;En service;2013-07-09 15:50:40;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;8.6;19.4;26.2;10.8;Cadastre;;POLYGON Z ((354000.8 6688879 19.4, 354011.2 6688873.3 19.4, 354027.3 6688865.2 19.4, 354028.7 6688867.6 19.4, 354029.6 6688869.7 19.4, 354066.7 6688850.7 19.4, 354082.9 6688882.6 19.4, 354072.3 6688887.6 19.4, 354070.7 6688884.5 19.4, 354066.1 6688886.8 19.4, 354067.9 6688889.9 19.4, 354057.7 6688895 19.4, 354055.6 6688891.2 19.4, 354047.4 6688895.3 19.4, 354048.8 6688898.1 19.4, 354044.7 6688900.3 19.4, 354045.2 6688901.3 19.4, 354046.1 6688903.1 19.4, 354049.8 6688910.4 19.4, 354062.2 6688904.6 19.4, 354062.1 6688904.2 19.4, 354072.2 6688899 19.4, 354072.5 6688899.7 19.4, 354073.1 6688899.4 19.4, 354072.7 6688898.7 19.4, 354076.2 6688897 19.4, 354076.5 6688897.7 19.4, 354077.2 6688897.3 19.4, 354076.9 6688896.6 19.4, 354086.8 6688891.5 19.4, 354087.4 6688892 19.4, 354097.8 6688886.5 19.4, 354094.2 6688879.2 19.4, 354090.1 6688870.1 19.4, 354087.5 6688871.3 19.4, 354077.9 6688850.8 19.4, 354079.7 6688849.9 19.4, 354076.7 6688842.9 19.4, 354073.5 6688844.3 19.4, 354069.6 6688836.6 19.4, 353988 6688878 19.4, 353991 6688884.2 19.4, 354000.8 6688879 19.4))
BATIMENT0000000323902146;Indifférenciée;Sportif;;Non;En service;2013-07-09 15:50:40;2018-09-18 13:36:26;;;MSS;MSS:127778/MSS:279349;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;8.9;13.6;17.1;10.6;Cadastre;;POLYGON Z ((354028.7 6688867.6 13.6, 354013 6688875.5 13.6, 354012.4 6688876 13.6, 354011.2 6688876.8 13.6, 354013 6688881.3 13.6, 354015.6 6688886.7 13.6, 354022.3 6688900.6 13.6, 354023.1 6688902.1 13.6, 354032 6688897.5 13.6, 354041.1 6688893.1 13.6, 354029.6 6688869.7 13.6, 354028.7 6688867.6 13.6))
BATIMENT0000000302922981;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.8;8.2;19.0;22.2;10.4;Cadastre;A 1.0;POLYGON Z ((354051 6688912.7 19, 354049.8 6688910.4 19, 354046.1 6688903.1 19, 354045.2 6688901.3 19, 354044.7 6688900.3 19, 354043.5 6688897.9 19, 354043.3 6688897.4 19, 354043 6688896.9 19, 354041.5 6688897.6 19, 354042.1 6688898.7 19, 354041.1 6688899.2 19, 354040.7 6688900.2 19, 354041.7 6688902.2 19, 354042.7 6688902.5 19, 354043.7 6688904.4 19, 354041.9 6688905.4 19, 354041.2 6688904.2 19, 354036.5 6688906.6 19, 354039.6 6688913.6 19, 354040.6 6688913.2 19, 354042.5 6688916.9 19, 354051 6688912.7 19))
BATIMENT0000000302922986;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;9.9;12.7;14.7;10.7;Cadastre;;POLYGON Z ((354026.2 6688908.2 12.7, 354027.2 6688910.1 12.7, 354028.8 6688909.3 12.7, 354029.9 6688908.9 12.7, 354030.2 6688907.8 12.7, 354029.2 6688905.4 12.7, 354028.1 6688905.1 12.7, 354026.7 6688905.6 12.7, 354025.2 6688906.3 12.7, 354026.2 6688908.2 12.7))
BATIMENT0000000302910377;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;10.2;13.7;13.9;10.8;Cadastre;;POLYGON Z ((353940.3 6688865.6 13.7, 353941.9 6688868.3 13.7, 353944 6688867.3 13.7, 353943.3 6688865.7 13.7, 353942.8 6688864.6 13.7, 353940.3 6688865.6 13.7))
BATIMENT0000000302910372;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;2.8;10.4;13.3;14.1;10.9;Cadastre;C 0.3;POLYGON Z ((353934.5 6688872 13.3, 353941.2 6688868.6 13.3, 353939.6 6688865.3 13.3, 353936.6 6688865.5 13.3, 353934.1 6688865.7 13.3, 353934.5 6688872 13.3))
BATIMENT0000000302913117;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;11.3;16.6;17.6;12.2;Cadastre;;POLYGON Z ((353897 6688874.8 16.6, 353901.2 6688876.1 16.6, 353901.7 6688872.4 16.6, 353899.1 6688871.6 16.6, 353892.0022898072 6688866.399091668 16.6, 353892.0022898072 6688871.551488374 16.6, 353897 6688874.8 16.6))
BATIMENT0000000302910330;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;11.3;15.4;;;Cadastre;;POLYGON Z ((353926.1 6688869.2 15.4, 353920.1 6688870 15.4, 353920.7 6688874.4 15.4, 353926.8 6688873.6 15.4, 353926.1 6688869.2 15.4))
BATIMENT0000000302910331;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.8;10.6;15.5;16.7;11.3;Cadastre;C 0.1;POLYGON Z ((353926.8 6688873.6 15.5, 353920.7 6688874.4 15.5, 353921.1 6688876.3 15.5, 353918.4 6688876.6 15.5, 353918.5 6688878.3 15.5, 353927.3 6688878.3 15.5, 353926.8 6688873.6 15.5))
BATIMENT0000000302910378;Industriel, agricole ou commercial;Commercial et services;;Oui;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.7;10.4;16.2;20.7;11.7;Cadastre;A 0.4;POLYGON Z ((353944 6688867.3 16.2, 353941.9 6688868.3 16.2, 353941.2 6688868.6 16.2, 353934.5 6688872 16.2, 353935.8 6688888 16.2, 353936.3 6688896.6 16.2, 353936.7 6688896.8 16.2, 353937.5 6688907 16.2, 353947.1 6688902.3 16.2, 353953.2 6688899.5 16.2, 353964.9 6688894 16.2, 353965.2 6688894 16.2, 353962.8 6688888.8 16.2, 353959.4 6688881.8 16.2, 353958.7 6688880.4 16.2, 353950.8 6688864 16.2, 353944 6688867.3 16.2))
BATIMENT0000000302910332;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.6;12.2;13.8;14.6;12.5;Cadastre;A 1.0;POLYGON Z ((353900.7 6688883 13.8, 353900.6 6688883.4 13.8, 353903.2 6688905.3 13.8, 353904.2 6688914.1 13.8, 353909.3 6688911.4 13.8, 353921.1 6688905.2 13.8, 353930.4 6688900 13.8, 353929.4 6688893.7 13.8, 353911.3 6688903 13.8, 353909.1 6688902.9 13.8, 353907.6 6688884.1 13.8, 353910 6688882.7 13.8, 353925.2 6688884.5 13.8, 353928.1 6688884 13.8, 353927.3 6688878.3 13.8, 353918.5 6688878.3 13.8, 353916.9 6688878.4 13.8, 353901.7 6688872.4 13.8, 353901.2 6688876.1 13.8, 353900.7 6688883 13.8))
BATIMENT0000000302910379;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.8;11.3;18.1;19.7;11.7;Cadastre;A 1.0;POLYGON Z ((353947.1 6688902.3 18.1, 353948.3 6688904.8 18.1, 353954.4 6688901.9 18.1, 353953.2 6688899.5 18.1, 353947.1 6688902.3 18.1))
BATIMENT0000000302910342;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:33;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.9;11.4;14.3;15.1;12.1;Cadastre;A 1.0;POLYGON Z ((353928.4 6688908.3 14.3, 353930.2 6688911.9 14.3, 353931 6688913.7 14.3, 353933.6 6688912.4 14.3, 353936.3 6688911 14.3, 353933.7 6688905.7 14.3, 353930.9 6688907.1 14.3, 353928.4 6688908.3 14.3))
BATIMENT0000000302910336;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.5;12.0;14.5;15.0;12.1;Cadastre;A 1.0;POLYGON Z ((353927.2 6688913.7 14.5, 353930.2 6688911.9 14.5, 353928.4 6688908.3 14.5, 353927.9 6688907.5 14.5, 353927.3 6688908 14.5, 353926.9 6688907.5 14.5, 353924.6 6688908.8 14.5, 353927.2 6688913.7 14.5))
BATIMENT0000000302910381;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;9.4;10.2;19.7;27.1;11.7;Cadastre;A 1.0;POLYGON Z ((353976.6 6688918.3 19.7, 353978.8 6688917 19.7, 353974.9 6688909.1 19.7, 353975.6 6688908.4 19.7, 353968.5 6688894.1 19.7, 353973.5 6688891.8 19.7, 353980.4 6688906.1 19.7, 353989.7 6688901.7 19.7, 353981.8 6688886 19.7, 353965.2 6688894 19.7, 353964.9 6688894 19.7, 353976.6 6688918.3 19.7))
BATIMENT0000000302910382;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;7.3;11.4;18.8;21.5;11.7;Cadastre;A 1.0;POLYGON Z ((353948.3 6688904.8 18.8, 353949.6 6688907.4 18.8, 353955.6 6688904.5 18.8, 353954.4 6688901.9 18.8, 353948.3 6688904.8 18.8))
BATIMENT0000000302922991;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;10.1;13.5;15.0;10.6;Cadastre;;POLYGON Z ((354025.2 6688906.3 13.5, 354026.7 6688905.6 13.5, 354025.8 6688903.7 13.5, 354024.4 6688904.5 13.5, 354025.2 6688906.3 13.5))
BATIMENT0000000302910383;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.6;10.9;13.5;;;Cadastre;A 1.0;POLYGON Z ((353982.7 6688910.5 13.5, 353992 6688906.3 13.5, 353989.7 6688901.7 13.5, 353980.4 6688906.1 13.5, 353982.7 6688910.5 13.5))
BATIMENT0000000302910384;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.3;11.4;17.7;22.7;11.7;Cadastre;A 1.0;POLYGON Z ((353949.6 6688907.4 17.7, 353950.9 6688910.1 17.7, 353957 6688907.2 17.7, 353955.6 6688904.5 17.7, 353949.6 6688907.4 17.7))
BATIMENT0000000302910385;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.0;11.4;17.5;23.0;11.7;Cadastre;A 1.0;POLYGON Z ((353958.3 6688909.9 17.5, 353957 6688907.2 17.5, 353950.9 6688910.1 17.5, 353952.2 6688912.8 17.5, 353958.3 6688909.9 17.5))
BATIMENT0000000302923567;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.7;9.6;18.3;18.4;10.7;Cadastre;C 0.6;POLYGON Z ((354028.1 6688911.9 18.3, 354027.2 6688910.1 18.3, 354026.2 6688908.2 18.3, 354021.3 6688911.1 18.3, 354017.1 6688903.6 18.3, 354004 6688910.9 18.3, 354009.3 6688921.6 18.3, 354028.1 6688911.9 18.3))
BATIMENT0000000302910386;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2023-01-31 17:32:32;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.7;11.5;17.2;22.0;11.7;Cadastre;A 1.0;POLYGON Z ((353959.7 6688912.6 17.2, 353958.3 6688909.9 17.2, 353952.2 6688912.8 17.2, 353953.5 6688915.6 17.2, 353959.7 6688912.6 17.2))
BATIMENT0000000302923566;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;;;8.7;9.6;18.3;22.1;10.6;Cadastre;C 0.9;POLYGON Z ((354033 6688921.6 18.3, 354028.1 6688911.9 18.3, 354009.3 6688921.6 18.3, 354013.9 6688931.1 18.3, 354033 6688921.6 18.3))
BATIMENT0000000302912726;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;13.2;10.9;24.1;28.4;11.9;Cadastre;A 1.0;POLYGON Z ((354006.5 6688935.4 24.1, 353995.7 6688913.8 24.1, 353992.4 6688915.4 24.1, 353995.3 6688921.6 24.1, 353994.4 6688922.2 24.1, 353995.8 6688925.3 24.1, 353985.4 6688930.3 24.1, 353981.2 6688921.9 24.1, 353978.9 6688922.8 24.1, 353984.1 6688934 24.1, 353989.1 6688943.7 24.1, 354006.5 6688935.4 24.1))
BATIMENT0000000302922987;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;9.9;15.0;18.5;10.7;Cadastre;;POLYGON Z ((354028.1 6688911.9 15, 354029.7 6688911.3 15, 354028.8 6688909.3 15, 354027.2 6688910.1 15, 354028.1 6688911.9 15))
BATIMENT0000000302923287;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.7;7.5;17.2;20.7;8.6;Cadastre;B 0.8;POLYGON Z ((354095.1 6688911.6 17.2, 354098.2 6688918.1 17.2, 354099.1 6688919.8 17.2, 354107.6 6688915.6 17.2, 354103.7 6688907.2 17.2, 354095.1 6688911.6 17.2))
BATIMENT0000000302922985;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.5;8.1;18.6;22.6;10.5;Cadastre;A 1.0;POLYGON Z ((354042.5 6688916.9 18.6, 354040.6 6688913.2 18.6, 354039.6 6688913.6 18.6, 354036.5 6688906.6 18.6, 354031.3 6688909 18.6, 354031.9 6688910.5 18.6, 354029.7 6688911.3 18.6, 354028.1 6688911.9 18.6, 354033 6688921.6 18.6, 354042.5 6688916.9 18.6))
BATIMENT0000000302923289;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;7.9;14.3;19.5;8.5;Cadastre;;POLYGON Z ((354100 6688921.5 14.3, 354103.8 6688919.7 14.3, 354108.6 6688917.2 14.3, 354107.6 6688915.6 14.3, 354099.1 6688919.8 14.3, 354100 6688921.5 14.3))
BATIMENT0000000302923288;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;4.3;7.4;11.8;13.5;8.5;Cadastre;B 0.5;POLYGON Z ((354102.6 6688927.2 11.8, 354106.7 6688925.2 11.8, 354103.8 6688919.7 11.8, 354100 6688921.5 11.8, 354102.6 6688927.2 11.8))
BATIMENT0000000302923286;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;10;90;10.4;7.5;17.9;21.3;9.2;Cadastre;A 1.0;POLYGON Z ((354078.8 6688919.6 17.9, 354080.6 6688923.7 17.9, 354082.6 6688922.9 17.9, 354083.2 6688924 17.9, 354084.1 6688923.6 17.9, 354084.5 6688924.5 17.9, 354088.2 6688933.4 17.9, 354096.1 6688929.7 17.9, 354098.8 6688936.3 17.9, 354100.6 6688935.5 17.9, 354103.8 6688934.1 17.9, 354103.6 6688933.4 17.9, 354102.5 6688933.6 17.9, 354096.5 6688919.2 17.9, 354098.2 6688918.1 17.9, 354095.1 6688911.6 17.9, 354078.8 6688919.6 17.9))
BATIMENT0000000302923423;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;8.4;20.5;22.8;8.9;Cadastre;;POLYGON Z ((354081.6 6688925.8 20.5, 354081.7 6688925.8 20.5, 354084.5 6688924.5 20.5, 354084.1 6688923.6 20.5, 354083.2 6688924 20.5, 354082.6 6688922.9 20.5, 354080.6 6688923.7 20.5, 354081.6 6688925.8 20.5))
BATIMENT0000000302923421;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.6;8.9;27.5;28.7;9.3;Cadastre;;POLYGON Z ((354066.6 6688927.2 27.5, 354065.9 6688926.1 27.5, 354063.7 6688927.2 27.5, 354064.2 6688928.4 27.5, 354066.6 6688927.2 27.5))
BATIMENT0000000302923285;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;15.5;7.5;23.0;26.7;9.2;Cadastre;A 1.0;POLYGON Z ((354077.9 6688939 23, 354076.2 6688935 23, 354084.2 6688931.1 23, 354081.7 6688925.8 23, 354081.6 6688925.8 23, 354080.6 6688923.7 23, 354078.8 6688919.6 23, 354068.9 6688924.6 23, 354076.4 6688939.8 23, 354077.9 6688939 23))
BATIMENT0000000302923420;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;00;00;19.1;8.8;28.0;29.4;9.4;Cadastre;A 1.0;POLYGON Z ((354065.2 6688939.1 28, 354069.5 6688947.5 28, 354069.8 6688948.1 28, 354073 6688946.5 28, 354071.9 6688944.5 28, 354077.5 6688941.9 28, 354076.4 6688939.8 28, 354068.9 6688924.6 28, 354065.9 6688926.1 28, 354066.6 6688927.2 28, 354064.2 6688928.4 28, 354063.7 6688927.2 28, 354060.1 6688929 28, 354065.2 6688939.1 28))
BATIMENT0000000302910337;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;12.0;15.1;16.7;12.1;Cadastre;;POLYGON Z ((353925.8 6688914.6 15.1, 353927.2 6688913.7 15.1, 353924.6 6688908.8 15.1, 353924 6688909.1 15.1, 353924.2 6688909.7 15.1, 353923.5 6688910 15.1, 353925.8 6688914.6 15.1))
BATIMENT0000000302910338;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.1;11.9;14.0;15.1;12.1;Cadastre;A 1.0;POLYGON Z ((353931 6688913.7 14, 353932.4 6688916.4 14, 353937.6 6688913.7 14, 353936.3 6688911 14, 353933.6 6688912.4 14, 353931 6688913.7 14))
BATIMENT0000000302910340;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.1;11.9;14.0;15.4;12.0;Cadastre;A 1.0;POLYGON Z ((353932.4 6688916.4 14, 353933.6 6688919.1 14, 353938.9 6688916.4 14, 353937.6 6688913.7 14, 353932.4 6688916.4 14))
BATIMENT0000000302910334;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;12.0;17.0;19.7;12.5;Cadastre;;POLYGON Z ((353907.4 6688921.6 17, 353905.8 6688922.5 17, 353907.4 6688925.6 17, 353919 6688918.7 17, 353925.8 6688914.6 17, 353923.5 6688910 17, 353911.7 6688916.3 17, 353909.3 6688911.4 17, 353904.2 6688914.1 17, 353903.7 6688914.4 17, 353907.4 6688921.6 17))
BATIMENT0000000302910343;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.9;12.0;13.9;15.9;12.0;Cadastre;A 1.0;POLYGON Z ((353940.2 6688919 13.9, 353938.9 6688916.4 13.9, 353933.6 6688919.1 13.9, 353934.9 6688921.7 13.9, 353940.2 6688919 13.9))
BATIMENT0000000302910344;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.1;11.6;16.7;18.5;12.0;Cadastre;A 1.0;POLYGON Z ((353934.9 6688921.7 16.7, 353936.2 6688924.4 16.7, 353938.2 6688923.4 16.7, 353941.5 6688921.8 16.7, 353940.2 6688919 16.7, 353934.9 6688921.7 16.7))
BATIMENT0000000302912937;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;11.8;15.0;17.7;12.1;Cadastre;;POLYGON Z ((353947.5 6688943.2 15, 353945.1 6688937.9 15, 353943.4 6688938.7 15, 353946 6688943.9 15, 353947.5 6688943.2 15))
BATIMENT0000000302912933;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;6.9;11.5;18.4;20.1;12.1;Cadastre;A 1.0;POLYGON Z ((353954.4 6688961 18.4, 353950.3 6688952.9 18.4, 353946 6688943.9 18.4, 353943.4 6688938.7 18.4, 353940.6 6688940.1 18.4, 353939.2 6688937.3 18.4, 353938 6688938 18.4, 353940.6 6688943.4 18.4, 353940.1 6688943.8 18.4, 353941.7 6688947.3 18.4, 353942.5 6688947.1 18.4, 353945.1 6688952.6 18.4, 353944.5 6688953 18.4, 353945.1 6688953.9 18.4, 353942.4 6688955.2 18.4, 353941.7 6688953.8 18.4, 353941.5 6688953.7 18.4, 353941.2 6688953.5 18.4, 353941 6688953.4 18.4, 353940.7 6688953.3 18.4, 353940.4 6688953.2 18.4, 353940.1 6688953.2 18.4, 353939.8 6688953.1 18.4, 353939.5 6688953.1 18.4, 353939.1 6688953.4 18.4, 353938.9 6688953.5 18.4, 353938.5 6688953.8 18.4, 353938.4 6688954 18.4, 353938.2 6688954.1 18.4, 353938.1 6688954.3 18.4, 353938 6688954.6 18.4, 353937.8 6688955 18.4, 353937.8 6688955.2 18.4, 353937.7 6688955.8 18.4, 353938.7 6688957.8 18.4, 353943.2 6688966.5 18.4, 353954.4 6688961 18.4))
BATIMENT0000000302912935;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;11.5;19.5;23.4;12.5;Cadastre;A 1.0;POLYGON Z ((353930.9 6688972.5 19.5, 353943.2 6688966.5 19.5, 353938.7 6688957.8 19.5, 353930.6 6688961.8 19.5, 353929.7 6688960 19.5, 353925.6 6688962 19.5, 353926.5 6688963.8 19.5, 353930.3 6688971.5 19.5, 353930.9 6688972.5 19.5))
BATIMENT0000000302912936;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;12;23;9.9;12.0;21.9;26.6;13.7;Cadastre;B 0.4;POLYGON Z ((353904 6688977 21.9, 353906.9 6688982.8 21.9, 353909 6688981.8 21.9, 353909.2 6688982.3 21.9, 353928 6688973.1 21.9, 353927.8 6688972.6 21.9, 353930.3 6688971.5 21.9, 353926.5 6688963.8 21.9, 353925.6 6688962 21.9, 353925.3 6688961.4 21.9, 353922.9 6688962.5 21.9, 353921.1 6688958.9 21.9, 353902.5 6688968 21.9, 353902.5 6688968.7 21.9, 353900.4 6688969.7 21.9, 353901.1 6688971.1 21.9, 353904 6688977 21.9))
BATIMENT0000000302912934;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.0;10.8;21.9;24.9;11.9;Cadastre;A 1.0;POLYGON Z ((353989.1 6688943.7 21.9, 353984.1 6688934 21.9, 353977.4 6688937.2 21.9, 353976.7 6688935.9 21.9, 353972.4 6688937.9 21.9, 353974.1 6688941.4 21.9, 353978.1 6688949.3 21.9, 353989.1 6688943.7 21.9))
BATIMENT0000000302912932;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;8.2;11.4;19.6;21.8;11.8;Cadastre;A 1.0;POLYGON Z ((353978.1 6688949.3 19.6, 353974.1 6688941.4 19.6, 353967.3 6688944.8 19.6, 353966.7 6688945 19.6, 353970.7 6688952.9 19.6, 353978.1 6688949.3 19.6))
BATIMENT0000000302912930;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.6;11.3;19.9;22.5;11.8;Cadastre;A 1.0;POLYGON Z ((353970.7 6688952.9 19.9, 353966.7 6688945 19.9, 353966.5 6688944.5 19.9, 353957 6688949.3 19.9, 353957.2 6688949.7 19.9, 353961.4 6688957.5 19.9, 353970.7 6688952.9 19.9))
BATIMENT0000000302912931;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.7;11.5;19.2;21.7;11.7;Cadastre;C 0.8;POLYGON Z ((353950.3 6688952.9 19.2, 353954.4 6688961 19.2, 353961.4 6688957.5 19.2, 353957.2 6688949.7 19.2, 353950.3 6688952.9 19.2))
BATIMENT0000000302923354;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.2;10.4;17.6;18.5;10.4;Cadastre;A 1.0;POLYGON Z ((354013 6688971.3 17.6, 354022.3 6688966.7 17.6, 354015.2 6688952.1 17.6, 354004.9 6688957.2 17.6, 354011.2 6688969.3 17.6, 354012 6688969 17.6, 354012.7 6688970.7 17.6, 354013 6688971.3 17.6))
BATIMENT0000000302912941;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1973-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;11.6;10.4;22.0;24.9;10.8;Cadastre;A 1.0;POLYGON Z ((353991.2 6688963.9 22, 353994.3 6688970.3 22, 353996.8 6688975.9 22, 353997.8 6688978 22, 353999.6 6688982.2 22, 354001.7 6688981.1 22, 354000.6 6688978.5 22, 354000.1 6688978.7 22, 353998.3 6688974.6 22, 354009.6 6688968.8 22, 354010.9 6688971.5 22, 354012.7 6688970.7 22, 354012 6688969 22, 354011.2 6688969.3 22, 354004.9 6688957.2 22, 353991.2 6688963.9 22))
BATIMENT0000000302923355;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;90;20;7.7;10.2;17.9;18.5;10.3;Cadastre;A 1.0;POLYGON Z ((354021.5 6688987.6 17.9, 354030.4 6688983.4 17.9, 354022.3 6688966.7 17.9, 354013 6688971.3 17.9, 354021.5 6688987.6 17.9))
BATIMENT0000000302912942;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:39;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;10.4;16.7;21.0;10.7;Cadastre;;POLYGON Z ((353995.7 6688976.4 16.7, 353996.6 6688978.6 16.7, 353997.8 6688978 16.7, 353996.8 6688975.9 16.7, 353995.7 6688976.4 16.7))
BATIMENT0000000302912940;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:02:05;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;2.0;10;20;8.8;10.4;19.2;20.7;11.3;Cadastre;C 0.8;POLYGON Z ((353980.9 6688968.9 19.2, 353985.3 6688979.7 19.2, 353989.5 6688991.1 19.2, 353995.2 6688988.8 19.2, 353990.1 6688975.6 19.2, 353991.2 6688975 19.2, 353991.8 6688973.2 19.2, 353991.2 6688971.9 19.2, 353994.3 6688970.3 19.2, 353991.2 6688963.9 19.2, 353980.9 6688968.9 19.2))
BATIMENT0000000302902587;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1892-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;9.4;10.4;19.8;24.6;11.6;Cadastre;C 0.8;POLYGON Z ((353959.9 6688979.4 19.8, 353965.4 6688993.2 19.8, 353968.4 6689001.3 19.8, 353971.3 6689000.2 19.8, 353970.5 6688997.9 19.8, 353971.6 6688997.4 19.8, 353969.5 6688992.9 19.8, 353969.8 6688991 19.8, 353968.7 6688988.1 19.8, 353979.8 6688982.5 19.8, 353985.3 6688979.7 19.8, 353980.9 6688968.9 19.8, 353959.9 6688979.4 19.8))
BATIMENT0000000302923425;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;8.7;6.8;15.5;19.7;8.6;Cadastre;B 0.4;POLYGON Z ((354093.3 6688946.3 15.5, 354101.2 6688942.5 15.5, 354099.8 6688938.8 15.5, 354098.8 6688936.3 15.5, 354096.1 6688929.7 15.5, 354088.2 6688933.4 15.5, 354093.3 6688946.3 15.5))
BATIMENT0000000302923422;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.1;8.9;22.0;26.4;9.3;Cadastre;;POLYGON Z ((354071.9 6688944.5 22, 354073 6688946.5 22, 354078.5 6688943.9 22, 354077.5 6688941.9 22, 354071.9 6688944.5 22))
BATIMENT0000000302923419;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;7.0;35;40;13.2;9.2;22.5;29.7;10.1;Cadastre;A 1.0;POLYGON Z ((354028.4 6688944.5 22.5, 354025.7 6688952 22.5, 354032.7 6688965.6 22.5, 354069.5 6688947.5 22.5, 354065.2 6688939.1 22.5, 354060.1 6688929 22.5, 354028.4 6688944.5 22.5))
BATIMENT0000000302923433;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;7.0;19.7;22.0;7.6;Cadastre;;POLYGON Z ((354090.5 6688968.1 19.7, 354102.6 6688962.4 19.7, 354101.8 6688960.6 19.7, 354098.9 6688961.4 19.7, 354099.3 6688962.1 19.7, 354089 6688967 19.7, 354088.7 6688966.2 19.7, 354086.3 6688968.2 19.7, 354087.1 6688969.7 19.7, 354090.5 6688968.1 19.7))
BATIMENT0000000302923427;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;34.0;7.0;30;40;17.0;6.9;24.0;27.1;9.0;Cadastre;A 1.0;POLYGON Z ((354096.4 6688980.2 24, 354111.7 6688972.4 24, 354105.9 6688960.8 24, 354102.6 6688962.4 24, 354090.5 6688968.1 24, 354087.1 6688969.7 24, 354081.8 6688972.3 24, 354081.7 6688972.3 24, 354087.7 6688984.3 24, 354096.4 6688980.2 24))
BATIMENT0000000302923431;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;117.0;5.0;00;00;10.2;7.6;17.9;26.9;9.4;Cadastre;A 1.0;POLYGON Z ((354053 6689001.6 17.9, 354057.9 6688999 17.9, 354061.4 6688997.4 17.9, 354074.3 6688991.1 17.9, 354083.1 6688986.8 17.9, 354087.7 6688984.3 17.9, 354081.7 6688972.3 17.9, 354081.8 6688972.3 17.9, 354081.2 6688971.1 17.9, 354056.9 6688982.8 17.9, 354053 6688975 17.9, 354052.5 6688975.2 17.9, 354049.7 6688969.3 17.9, 354037.4 6688975.4 17.9, 354048.3 6688998 17.9, 354050.3 6688996.9 17.9, 354052.6 6689001.8 17.9, 354053 6689001.6 17.9))
BATIMENT0000000302923356;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;03;09;7.7;10.4;18.1;;;Cadastre;A 0.8;POLYGON Z ((354026.1 6688997.2 18.1, 354034.9 6688992.8 18.1, 354030.4 6688983.4 18.1, 354021.5 6688987.6 18.1, 354026.1 6688997.2 18.1))
BATIMENT0000000302923521;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:49;1900-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;0.0;00;00;15.1;7.1;;28.7;8.6;Imagerie aérienne;C 0.3;POLYGON Z ((354095.6 6689001.6 22.2, 354097.9 6689006.5 22.2, 354114.9 6688998.3 22.2, 354109.9 6688988.1 22.2, 354088.6 6688998 22.2, 354091.4 6689003.7 22.2, 354095.6 6689001.6 22.2))
BATIMENT0000000302923357;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;01;01;10.1;7.9;18.0;20.2;8.7;Cadastre;C 0.8;POLYGON Z ((354035.7 6688994.3 18, 354026.5 6688999 18, 354031.3 6689008.3 18, 354040.3 6689004 18, 354035.7 6688994.3 18))
BATIMENT0000000302927321;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;23;20;4.0;7.9;12.0;20.5;8.9;Cadastre;A 1.0;POLYGON Z ((354013.7 6689016.7 12, 354015.8 6689021 12, 354011 6689023.3 12, 354014.1 6689030 12, 354016.9 6689028.9 12, 354033.1 6689020.8 12, 354035.5 6689019.6 12, 354045.5 6689014.4 12, 354040.3 6689004 12, 354031.3 6689008.3 12, 354013.7 6689016.7 12))
BATIMENT0000000302912939;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:02:05;2018-09-18 13:31:41;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.0;12.6;22.6;24.7;13.7;Cadastre;;POLYGON Z ((353901.1 6688971.1 22.6, 353900.4 6688969.7 22.6, 353900.2 6688969.3 22.6, 353894.9 6688971.9 22.6, 353895.8 6688973.7 22.6, 353901.1 6688971.1 22.6))
BATIMENT0000000302902582;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;6.0;00;00;10.0;12.6;22.6;27.4;13.8;Cadastre;C 0.1;POLYGON Z ((353904.9 6688985.4 22.6, 353904.3 6688984.1 22.6, 353906.9 6688982.8 22.6, 353904 6688977 22.6, 353901.1 6688971.1 22.6, 353895.8 6688973.7 22.6, 353894.9 6688971.9 22.6, 353892.0022898072 6688973.32873211 22.6, 353892.0022898072 6688991.722406957 22.6, 353904.9 6688985.4 22.6))
BATIMENT0000000302902680;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.0;11.9;20.9;24.1;13.3;Cadastre;A 1.0;POLYGON Z ((353899.4 6689009 20.9, 353904 6689018.8 20.9, 353904.9 6689018.4 20.9, 353905.4 6689019.2 20.9, 353908.9 6689017.6 20.9, 353908.4 6689016.6 20.9, 353912.5 6689014.7 20.9, 353913.8 6689017.3 20.9, 353914.1 6689017.1 20.9, 353914.5 6689017.7 20.9, 353916.3 6689018.6 20.9, 353918.4 6689017.7 20.9, 353918.8 6689015.9 20.9, 353918.4 6689015 20.9, 353921.4 6689013.5 20.9, 353916.6 6689002.7 20.9, 353915.9 6689001 20.9, 353899.4 6689009 20.9))
BATIMENT0000000302902681;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;8.5;11.8;20.3;23.4;13.7;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6689012.835849729 20.3, 353892.0022898072 6689014.667005375 20.3, 353895.8 6689022.6 20.3, 353899.5 6689021.1 20.3, 353898.1 6689018.5 20.3, 353901 6689017 20.3, 353902.3 6689019.6 20.3, 353904 6689018.8 20.3, 353899.4 6689009 20.3, 353892.0022898072 6689012.835849729 20.3))
BATIMENT0000000302902585;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.1;12.0;22.1;24.6;13.7;Cadastre;A 1.0;POLYGON Z ((353916.6 6689002.7 22.1, 353921.4 6689013.5 22.1, 353932.3 6689037.7 22.1, 353936.9 6689047.7 22.1, 353947.5 6689071.3 22.1, 353949.7 6689070.5 22.1, 353948.6 6689073.7 22.1, 353951.3 6689074.5 22.1, 353951 6689075.8 22.1, 353973.4 6689082.8 22.1, 353974.2 6689079.7 22.1, 353975.5 6689074.3 22.1, 353975.5 6689072.3 22.1, 353975.2 6689071.3 22.1, 353972.9 6689066.6 22.1, 353968.1 6689067.9 22.1, 353951.5 6689062.5 22.1, 353943.8 6689044.7 22.1, 353931.6 6689018.1 22.1, 353928.2 6689019.8 22.1, 353925.7 6689014.4 22.1, 353930.4 6689012 22.1, 353930.6 6689012.5 22.1, 353934.9 6689010.5 22.1, 353934.7 6689009.8 22.1, 353944.8 6689004.8 22.1, 353944.2 6689003.6 22.1, 353938.6 6688991.7 22.1, 353916.6 6689002.7 22.1))
BATIMENT0000000302904785;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;49;17.9;13.3;31.2;32.6;13.8;Cadastre;A 1.0;POLYGON Z ((353914 6689060.8 31.2, 353909.2 6689059.5 31.2, 353907 6689066.5 31.2, 353910.5 6689067.6 31.2, 353918 6689069.9 31.2, 353915 6689062.7 31.2, 353914 6689060.8 31.2))
BATIMENT0000000302904784;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.9;13.1;17.0;20.6;13.7;Cadastre;A 1.0;POLYGON Z ((353941.1 6689077.1 17, 353943.7 6689073.3 17, 353942.5 6689066.8 17, 353935.4 6689064.6 17, 353926.8 6689061.9 17, 353921 6689060.1 17, 353915 6689062.7 17, 353918 6689069.9 17, 353941.1 6689077.1 17))
BATIMENT0000000302903606;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;23;5.7;13.5;19.2;25.1;15.7;Cadastre;A 1.0;POLYGON Z ((353905.6 6689089 19.2, 353917.7 6689087 19.2, 353921.9 6689086 19.2, 353923.5 6689081.7 19.2, 353900 6689074.3 19.2, 353894.8 6689091.1 19.2, 353895.3 6689091.1 19.2, 353905.6 6689089 19.2))
BATIMENT0000000302903605;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;11.6;13.1;24.7;27.1;14.3;Cadastre;C 0.9;POLYGON Z ((353918.4 6689090.3 24.7, 353922.3 6689089.6 24.7, 353932.4 6689093.9 24.7, 353936.2 6689085.8 24.7, 353923.5 6689081.7 24.7, 353921.9 6689086 24.7, 353917.7 6689087 24.7, 353918.4 6689090.3 24.7))
BATIMENT0000000302903607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;14.8;17.8;20.5;15.7;Cadastre;;POLYGON Z ((353896.1 6689094.9 17.8, 353906.4 6689093.3 17.8, 353905.6 6689089 17.8, 353895.3 6689091.1 17.8, 353896.1 6689094.9 17.8))
BATIMENT0000000302902586;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;23;8.5;10.4;18.9;24.2;12.8;Cadastre;A 1.0;POLYGON Z ((353937.9 6688990.1 18.9, 353938.6 6688991.7 18.9, 353944.2 6689003.6 18.9, 353947.8 6689002.2 18.9, 353948.2 6689001.3 18.9, 353946.4 6688997.4 18.9, 353948.4 6688996.3 18.9, 353948.5 6688996.8 18.9, 353958.6 6688991.7 18.9, 353958.5 6688991.2 18.9, 353960.2 6688990.3 18.9, 353962.1 6688994.3 18.9, 353962.7 6688994.7 18.9, 353965.4 6688993.2 18.9, 353959.9 6688979.4 18.9, 353937.9 6688990.1 18.9))
BATIMENT0000000302902588;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.7;10.0;12.7;15.0;10.7;Cadastre;C 0.3;POLYGON Z ((354005.7 6688994.9 12.7, 354003.5 6688990.5 12.7, 353994.8 6688994.6 12.7, 353993.4 6688991.4 12.7, 353990.2 6688992.8 12.7, 353990.8 6688994.3 12.7, 353993.2 6689000.5 12.7, 354001.1 6688997.1 12.7, 354005.7 6688994.9 12.7))
BATIMENT0000000302902589;Indifférenciée;Annexe;;Oui;En service;2012-06-19 17:38:43;2023-01-31 17:40:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.3;9.9;13.2;13.5;10.2;Cadastre;A 0.3;POLYGON Z ((353997.4 6689011 13.2, 354005 6689007.1 13.2, 354001.1 6688997.1 13.2, 353993.2 6689000.5 13.2, 353997.4 6689011 13.2))
BATIMENT0000000302928994;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;2.8;9.6;12.4;12.9;10.1;Cadastre;C 0.3;POLYGON Z ((354006.7 6689006.1 12.4, 354008.8 6689010.2 12.4, 354018 6689005.5 12.4, 354016 6689001.6 12.4, 354006.7 6689006.1 12.4))
BATIMENT0000002275362627;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.1;10.3;;;;Imagerie aérienne;;POLYGON Z ((353982.2 6689007.8 13, 353987.1 6689006.1 13, 353994.3 6689025.2 11.8, 353989.7 6689026.8 11.8, 353992.8 6689036 11.8, 353995.7 6689034.9 11.8, 353998.2 6689033.7 11.8, 353996.4 6689029 12, 353998.5 6689028.1 12, 353989.5 6689004.3 13.4, 353987 6689005.1 13.4, 353985.4 6689001.1 13.4, 353980.5 6689002.9 13.4, 353982.2 6689007.8 13))
BATIMENT0000002209616543;Indifférenciée;Indifférencié;;Non;En service;2020-10-01 09:32:48;2023-01-31 17:40:55;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.1;8.3;12.5;16.0;9.3;Cadastre;;POLYGON Z ((353992.6 6689043.6 12.5, 353994 6689043.1 12.5, 353998 6689053.6 12.5, 353999.6 6689053.1 12.5, 354000.6 6689055.7 12.5, 354001.7 6689055.3 12.5, 354004.2 6689061.9 12.5, 354010.8 6689059.4 12.5, 354007.1 6689049.9 12.5, 354011 6689048.5 12.5, 354008.7 6689042.5 12.5, 354002.3 6689044.9 12.5, 354001.2 6689042.1 12.5, 353998.8 6689043 12.5, 353995.7 6689034.9 12.5, 353990.1 6689037 12.5, 353992.6 6689043.6 12.5))
BATIMENT0000000302927324;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;11.4;9.7;21.2;21.7;10.9;Cadastre;C 0.5;POLYGON Z ((354014.5 6689068.9 21.2, 354012.6 6689075 21.2, 354013.8 6689075.5 21.2, 354014.2 6689074.2 21.2, 354023.7 6689077 21.2, 354025 6689072.2 21.2, 354014.5 6689068.9 21.2))
BATIMENT0000000302902682;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;7.7;11.2;19.0;21.4;12.9;Cadastre;A 1.0;POLYGON Z ((353986.7 6689076.6 19, 353986.9 6689078.3 19, 353983.9 6689079 19, 353982 6689079.5 19, 353979.3 6689079.8 19, 353976.5 6689079.9 19, 353974.2 6689079.7 19, 353973.4 6689082.8 19, 353973.3 6689083.3 19, 353972.4 6689086.9 19, 353976.4 6689088 19, 353976.6 6689087.2 19, 353986.3 6689086.8 19, 353989.1 6689086.3 19, 353989.5 6689087.3 19, 353995 6689085.6 19, 353999.3 6689087.2 19, 354000.2 6689084.1 19, 354001.3 6689080.5 19, 353999.3 6689079.7 19, 353996.6 6689072.8 19, 353986.7 6689076.6 19))
BATIMENT0000000302927294;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.0;10.6;16.7;19.4;11.4;Cadastre;C 0.5;POLYGON Z ((354009.9 6689084.1 16.7, 354015 6689085.8 16.7, 354016.9 6689080.1 16.7, 354011.5 6689078.4 16.7, 354009.9 6689084.1 16.7))
BATIMENT0000000302902683;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;25;20;14.8;11.1;26.0;29.0;11.8;Cadastre;A 1.0;POLYGON Z ((353999.3 6689087.2 26, 353996.8 6689094.4 26, 354006.2 6689097.5 26, 354008.8 6689087.8 26, 354009.2 6689087.1 26, 354007.8 6689086.7 26, 354008.8 6689083.9 26, 354002.8 6689082 26, 354001.7 6689084.7 26, 354000.2 6689084.1 26, 353999.3 6689087.2 26))
BATIMENT0000000302927323;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;15;20;10.2;7.8;18.0;19.6;8.1;Cadastre;A 1.0;POLYGON Z ((354039 6689026.2 18, 354039.8 6689025.9 18, 354048.7 6689021.4 18, 354045.5 6689014.4 18, 354035.5 6689019.6 18, 354039 6689026.2 18))
BATIMENT0000000029198414;Indifférenciée;Commercial et services;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2011-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;11.0;;;32.2;7.1;;;;Imagerie aérienne;C 0.5;POLYGON Z ((354091.4 6689003.7 30.5, 354071.3 6689014.2 38.1, 354085.3 6689042.1 38.9, 354108.9 6689030.5 39.3, 354097.9 6689006.5 38.1, 354095.6 6689001.6 29, 354091.4 6689003.7 30.5))
BATIMENT0000000302927322;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;9.6;7.8;17.5;20.5;8.1;Cadastre;A 1.0;POLYGON Z ((354043.1 6689032.6 17.5, 354052.1 6689028.1 17.5, 354048.7 6689021.4 17.5, 354039.8 6689025.9 17.5, 354043.1 6689032.6 17.5))
BATIMENT0000000302927319;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;00;00;6.2;8.0;14.2;22.1;9.6;Cadastre;A 1.0;POLYGON Z ((354036.8 6689036.1 14.2, 354038 6689038.6 14.2, 354014.7 6689050.1 14.2, 354023.2 6689067.3 14.2, 354042.1 6689057.5 14.2, 354043.7 6689061 14.2, 354054.4 6689058.7 14.2, 354055.8 6689058.3 14.2, 354065.8 6689056.2 14.2, 354052.1 6689028.1 14.2, 354043.1 6689032.6 14.2, 354036.8 6689036.1 14.2))
BATIMENT0000000302927320;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.7;8.9;16.6;20.6;8.9;Cadastre;;POLYGON Z ((354057 6689061 16.6, 354055.8 6689058.3 16.6, 354054.4 6689058.7 16.6, 354055.5 6689061.5 16.6, 354057 6689061 16.6))
BATIMENT0000000302927318;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;3.8;8.2;12.1;16.7;9.6;Cadastre;C 0.5;POLYGON Z ((354043.7 6689061 12.1, 354040.8 6689061.6 12.1, 354039.7 6689065 12.1, 354055.5 6689061.5 12.1, 354054.4 6689058.7 12.1, 354043.7 6689061 12.1))
BATIMENT0000000302927311;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.3;8.1;16.5;18.6;9.0;Cadastre;C 0.8;POLYGON Z ((354062.9 6689072.9 16.5, 354063.8 6689072.5 16.5, 354071.7 6689068.3 16.5, 354065.8 6689056.2 16.5, 354055.8 6689058.3 16.5, 354057 6689061 16.5, 354062.9 6689072.9 16.5))
BATIMENT0000000302929201;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1973-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;8.0;30;40;21.6;7.4;29.0;31.4;8.8;Cadastre;C 0.6;POLYGON Z ((354092.5 6689070.1 29, 354098.4 6689081.5 29, 354109.4 6689078 29, 354105 6689068.8 29, 354108.9 6689066.6 29, 354107.1 6689063.3 29, 354103.2 6689065.1 29, 354100.1 6689059.4 29, 354088.5 6689065.2 29, 354091.3 6689070.7 29, 354092.5 6689070.1 29))
BATIMENT0000000302929094;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.4;8.3;11.7;14.0;9.3;Cadastre;;POLYGON Z ((354053.2 6689072 11.7, 354053.5 6689077.5 11.7, 354058.3 6689074.9 11.7, 354057.9 6689071.8 11.7, 354053.2 6689072 11.7))
BATIMENT0000000302927315;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;25;20;10.7;9.9;20.6;22.1;10.9;Cadastre;C 0.1;POLYGON Z ((354032.3 6689079.7 20.6, 354031.9 6689081 20.6, 354034 6689081.5 20.6, 354035.7 6689076.3 20.6, 354035.8 6689076.3 20.6, 354036 6689075.5 20.6, 354025 6689072.2 20.6, 354023.7 6689077 20.6, 354032.3 6689079.7 20.6))
BATIMENT0000000302927306;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;25;14;4.6;8.9;13.5;16.7;9.6;Cadastre;A 1.0;POLYGON Z ((354065.8 6689076.3 13.5, 354064.6 6689077.1 13.5, 354064.9 6689078 13.5, 354064.1 6689078.4 13.5, 354065.1 6689080.4 13.5, 354066 6689080 13.5, 354066.4 6689080.9 13.5, 354067.6 6689080.4 13.5, 354068.9 6689082.7 13.5, 354063.6 6689085.5 13.5, 354062.6 6689085.3 13.5, 354061.7 6689085.9 13.5, 354060.3 6689083.4 13.5, 354056.3 6689085.6 13.5, 354056.6 6689086.1 13.5, 354060.2 6689092.3 13.5, 354062.6 6689090.2 13.5, 354078.1 6689081.6 13.5, 354071.7 6689068.3 13.5, 354063.8 6689072.5 13.5, 354065.8 6689076.3 13.5))
BATIMENT0000000302927303;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;20;5.1;8.9;14.0;14.2;10.2;Cadastre;C 0.5;POLYGON Z ((354042.5 6689083.5 14, 354049.3 6689084.9 14, 354049.6 6689083.2 14, 354050.5 6689078.1 14, 354044.6 6689075.9 14, 354042.8 6689082.3 14, 354042.5 6689083.5 14))
BATIMENT0000000302927304;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;45;20;5.5;8.9;14.4;17.1;10.9;Cadastre;B 0.5;POLYGON Z ((354037.6 6689075.3 14.4, 354037.2 6689076.8 14.4, 354035.8 6689076.3 14.4, 354035.7 6689076.3 14.4, 354034 6689081.5 14.4, 354033.4 6689083.1 14.4, 354032.7 6689085 14.4, 354030.7 6689090.6 14.4, 354030.4 6689091.6 14.4, 354033.7 6689092.7 14.4, 354036.4 6689084 14.4, 354035.3 6689083.7 14.4, 354036.4 6689080.3 14.4, 354042.8 6689082.3 14.4, 354044.6 6689075.9 14.4, 354037.1 6689073 14.4, 354036.3 6689074.9 14.4, 354037.6 6689075.3 14.4))
BATIMENT0000000302927301;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1854-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;34;23;4.4;8.9;13.3;13.4;10.1;Cadastre;C 0.5;POLYGON Z ((354056.6 6689086.1 13.3, 354056.3 6689085.6 13.3, 354052.2 6689078.8 13.3, 354050.5 6689078.1 13.3, 354049.6 6689083.2 13.3, 354051.8 6689083.5 13.3, 354050.9 6689088.9 13.3, 354050 6689088.8 13.3, 354049.5 6689092.3 13.3, 354054.6 6689093.7 13.3, 354054.3 6689094.9 13.3, 354057.1 6689095.6 13.3, 354057.3 6689095 13.3, 354057.4 6689094.4 13.3, 354060.2 6689092.3 13.3, 354056.6 6689086.1 13.3))
BATIMENT0000000302927305;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.7;8.9;13.6;15.9;10.9;Cadastre;C 0.5;POLYGON Z ((354026.9 6689083.3 13.6, 354025.1 6689089 13.6, 354030.7 6689090.6 13.6, 354032.7 6689085 13.6, 354026.9 6689083.3 13.6))
BATIMENT0000000302927309;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;3.7;8.9;12.6;14.2;9.4;Cadastre;C 0.6;POLYGON Z ((354069.1 6689093.8 12.6, 354069.5 6689092.2 12.6, 354068.8 6689090.1 12.6, 354073.1 6689087.8 12.6, 354073.9 6689089.7 12.6, 354080.7 6689086.4 12.6, 354078.1 6689081.6 12.6, 354062.6 6689090.2 12.6, 354066.4 6689092.3 12.6, 354069.1 6689093.8 12.6))
BATIMENT0000000302927316;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;45;09;8.0;10.1;18.2;22.1;10.5;Cadastre;B 0.1;POLYGON Z ((354038.1 6689089.6 18.2, 354037.5 6689092.3 18.2, 354039.9 6689093.1 18.2, 354040.6 6689090.6 18.2, 354040.6 6689090.2 18.2, 354038.1 6689089.6 18.2))
BATIMENT0000000302927314;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;10.0;14.0;17.2;10.5;Cadastre;;POLYGON Z ((354041.9 6689093.7 14, 354042.4 6689090.9 14, 354040.6 6689090.2 14, 354040.6 6689090.6 14, 354039.9 6689093.1 14, 354041.9 6689093.7 14))
BATIMENT0000000302927312;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.0;8.9;11.9;12.3;9.6;Cadastre;B 0.5;POLYGON Z ((354061.6 6689096.2 11.9, 354066.4 6689092.3 11.9, 354062.6 6689090.2 11.9, 354060.2 6689092.3 11.9, 354057.4 6689094.4 11.9, 354057.3 6689095 11.9, 354061.6 6689096.2 11.9))
BATIMENT0000000302927317;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;10.2;12.6;15.5;10.7;Cadastre;;POLYGON Z ((354036.9 6689094 12.6, 354039.5 6689094.8 12.6, 354039.9 6689093.1 12.6, 354037.5 6689092.3 12.6, 354036.9 6689094 12.6))
BATIMENT0000000302923125;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.8;11.2;17.1;22.2;15.1;Cadastre;C 0.4;POLYGON Z ((354672.3 6688900 17.1, 354677.5 6688894.2 17.1, 354672.1 6688890.1 17.1, 354668.3 6688896.4 17.1, 354672.3 6688900 17.1))
BATIMENT0000000302923534;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.3;9.9;31.2;35.3;15.1;Cadastre;;POLYGON Z ((354661.2 6688908.4 31.2, 354667.5 6688897.6 31.2, 354668.3 6688896.4 31.2, 354672.1 6688890.1 31.2, 354672.3 6688889.7 31.2, 354668 6688886.8 31.2, 354667.9 6688887.1 31.2, 354664.6 6688893.1 31.2, 354653.5 6688883.6 31.2, 354645.9 6688895.7 31.2, 354661.2 6688908.4 31.2))
BATIMENT0000000302923123;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;16.3;10.6;27.0;34.2;14.9;Cadastre;C 0.3;POLYGON Z ((354681.5 6688901.8 27, 354685.9 6688905.2 27, 354687.9 6688902.7 27, 354683.6 6688899.2 27, 354681.5 6688901.8 27))
BATIMENT0000000302923119;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;30;23;20.7;14.4;35.2;37.5;15.2;Cadastre;C 0.6;POLYGON Z ((354673.8 6688919.2 35.2, 354681.6 6688910.1 35.2, 354667.5 6688897.6 35.2, 354661.2 6688908.4 35.2, 354673.8 6688919.2 35.2))
BATIMENT0000000302923118;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;28.2;13.2;41.4;44.8;17.2;Cadastre;;POLYGON Z ((354699.6 6688888 41.4, 354688.3 6688902.3 41.4, 354687.9 6688902.7 41.4, 354685.9 6688905.2 41.4, 354681.6 6688910.1 41.4, 354673.8 6688919.2 41.4, 354697.7 6688939.3 41.4, 354728.5 6688902.5 41.4, 354704.2 6688882.3 41.4, 354701.7 6688885.5 41.4, 354699.6 6688888 41.4), (354702.9 6688897.8 41.4, 354714.8 6688907.7 41.4, 354708.2 6688915.9 41.4, 354706.7 6688914.7 41.4, 354698.7 6688924.5 41.4, 354688 6688915.4 41.4, 354694.4 6688907.2 41.4, 354694.8 6688907.5 41.4, 354698.9 6688902.7 41.4, 354702.9 6688897.8 41.4))
BATIMENT0000000302923116;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.7;13.5;34.2;38.2;15.5;Cadastre;;POLYGON Z ((354633.7 6688911.5 34.2, 354627.1 6688919.4 34.2, 354630.8 6688922.4 34.2, 354633.7 6688918 34.2, 354636.6 6688913.8 34.2, 354633.7 6688911.5 34.2))
BATIMENT0000000302923114;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.8;13.6;31.5;32.9;15.0;Cadastre;;POLYGON Z ((354620.8 6688916.6 31.5, 354619.7 6688916.2 31.5, 354618.7 6688919.4 31.5, 354623.7 6688921.2 31.5, 354624.6 6688918 31.5, 354620.8 6688916.6 31.5))
BATIMENT0000000302923379;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;35;20;21.0;14.9;36.0;38.8;16.5;Cadastre;C 0.8;POLYGON Z ((354651.1 6688925.9 36, 354643.4 6688935 36, 354652.3 6688942.3 36, 354651.5 6688943.2 36, 354652.7 6688943.9 36, 354655.2 6688945.8 36, 354655.2 6688946.2 36, 354655.9 6688946.9 36, 354656.6 6688945.8 36, 354667.2 6688954.5 36, 354672.8 6688944.2 36, 354651.1 6688925.9 36))
BATIMENT0000000302923113;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:49;1988-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;17.8;16.0;33.8;39.2;18.4;Cadastre;A 1.0;POLYGON Z ((354630.8 6688922.4 33.8, 354627.1 6688919.4 33.8, 354625.8 6688918.3 33.8, 354624.6 6688918 33.8, 354623.7 6688921.2 33.8, 354618.7 6688919.4 33.8, 354615.7 6688927.6 33.8, 354618.7 6688928.7 33.8, 354616.2 6688938.5 33.8, 354615.3 6688942.8 33.8, 354612.4 6688954.5 33.8, 354627.8 6688967.6 33.8, 354633.3 6688960.8 33.8, 354637.4 6688947.8 33.8, 354637.9 6688945.9 33.8, 354639.7 6688940.6 33.8, 354640 6688939.3 33.8, 354643.4 6688935 33.8, 354651.1 6688925.9 33.8, 354640.5 6688917.1 33.8, 354636.6 6688913.8 33.8, 354633.7 6688918 33.8, 354630.8 6688922.4 33.8))
BATIMENT0000000302923378;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.0;15.7;19.7;24.2;18.5;Cadastre;C 0.4;POLYGON Z ((354639.7 6688940.6 19.7, 354637.9 6688945.9 19.7, 354661.4 6688964.9 19.7, 354662.8 6688962.4 19.7, 354663.7 6688960.5 19.7, 354639.7 6688940.6 19.7))
BATIMENT0000000302923109;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;2.9;16.0;18.9;20.7;16.2;Cadastre;A 1.0;POLYGON Z ((354578 6688912.7 18.9, 354572.5 6688912 18.9, 354572.1 6688915.3 18.9, 354578.1 6688916.1 18.9, 354578.2 6688913.9 18.9, 354577.9 6688913.8 18.9, 354578 6688912.7 18.9))
BATIMENT0000000302923101;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;00;00;17.0;14.2;31.2;38.0;16.6;Cadastre;A 1.0;POLYGON Z ((354586.4 6688936.9 31.2, 354590.7 6688934.8 31.2, 354593.6 6688926.4 31.2, 354595.2 6688926.7 31.2, 354603.4 6688904.4 31.2, 354579.8 6688898.5 31.2, 354579.1 6688903.3 31.2, 354578.9 6688904.7 31.2, 354590.3 6688907.2 31.2, 354583.8 6688926.3 31.2, 354577.1 6688924 31.2, 354575.3 6688933.3 31.2, 354586.4 6688936.9 31.2))
BATIMENT0000000302923115;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;18.1;13.7;31.8;34.4;15.8;Cadastre;A 1.0;POLYGON Z ((354607.1 6688924.8 31.8, 354612.2 6688926.6 31.8, 354615 6688927.6 31.8, 354615.7 6688927.6 31.8, 354618.7 6688919.4 31.8, 354619.7 6688916.2 31.8, 354611.2 6688913.3 31.8, 354607.1 6688924.8 31.8))
BATIMENT0000000302923104;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.8;16.0;32.9;36.2;16.3;Cadastre;A 1.0;POLYGON Z ((354575.3 6688933.3 32.9, 354577.1 6688924 32.9, 354577.3 6688922.8 32.9, 354575.3 6688922.2 32.9, 354575.4 6688921.9 32.9, 354565.6 6688918.5 32.9, 354565.5 6688918.9 32.9, 354562.5 6688917.8 32.9, 354560.6 6688928.2 32.9, 354575.3 6688933.3 32.9))
BATIMENT0000000302923388;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;10;20;20.9;15.0;36.0;37.7;16.9;Cadastre;A 1.0;POLYGON Z ((354599.8 6688943.8 36, 354612.4 6688954.5 36, 354615.3 6688942.8 36, 354612.7 6688940.7 36, 354613.3 6688937.7 36, 354616.2 6688938.5 36, 354618.7 6688928.7 36, 354615.7 6688927.6 36, 354615 6688927.6 36, 354613.1 6688932.2 36, 354610.3 6688931.3 36, 354612.2 6688926.6 36, 354607.1 6688924.8 36, 354599.8 6688943.8 36))
BATIMENT0000000302923475;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;20;15.1;16.0;31.2;36.6;17.7;Cadastre;A 1.0;POLYGON Z ((354556.1 6688946.2 31.2, 354556.1 6688947.5 31.2, 354564.6 6688950.3 31.2, 354567.3 6688941.7 31.2, 354543.3 6688933.5 31.2, 354541.5 6688939.3 31.2, 354542.1 6688939.4 31.2, 354545.5 6688939.6 31.2, 354546.9 6688939.2 31.2, 354551.3 6688939.7 31.2, 354555.6 6688940.7 31.2, 354555.9 6688946.3 31.2, 354556.1 6688946.2 31.2))
BATIMENT0000000302923481;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;14.0;16.5;30.5;33.1;17.7;Cadastre;A 1.0;POLYGON Z ((354555.9 6688946.3 30.5, 354555.6 6688940.7 30.5, 354551.3 6688939.7 30.5, 354546.9 6688939.2 30.5, 354545.5 6688939.6 30.5, 354542.1 6688939.4 30.5, 354541.1 6688945.9 30.5, 354555.9 6688946.3 30.5))
BATIMENT0000000302923474;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;34;20;15.5;16.2;31.7;36.6;17.7;Cadastre;A 1.0;POLYGON Z ((354573.5 6688953.4 31.7, 354574 6688951.7 31.7, 354578.1 6688953.1 31.7, 354577.3 6688954.9 31.7, 354584.2 6688957.2 31.7, 354586.3 6688951.8 31.7, 354584.1 6688947.4 31.7, 354567.3 6688941.7 31.7, 354564.6 6688950.3 31.7, 354573.5 6688953.4 31.7))
BATIMENT0000000302923469;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.5;15.7;20.2;20.7;18.1;Cadastre;A 1.0;POLYGON Z ((354561.2 6688955.4 20.2, 354555.3 6688953.4 20.2, 354555.1 6688957.7 20.2, 354561.1 6688957.9 20.2, 354561.2 6688955.4 20.2))
BATIMENT0000000302923468;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.4;15.8;20.2;20.4;18.3;Cadastre;A 1.0;POLYGON Z ((354561.1 6688957.9 20.2, 354555.1 6688957.7 20.2, 354555 6688960.8 20.2, 354561 6688961 20.2, 354561 6688960.6 20.2, 354561.1 6688957.9 20.2))
BATIMENT0000000302923038;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;30;20;18.0;15.7;33.7;34.1;18.4;Cadastre;A 1.0;POLYGON Z ((354780.7 6688931.4 33.7, 354787.5 6688923.5 33.7, 354775.5 6688913.5 33.7, 354769.1 6688921.6 33.7, 354780.7 6688931.4 33.7))
BATIMENT0000000302923364;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;5.0;30;20;17.4;16.3;33.7;34.0;18.5;Cadastre;A 1.0;POLYGON Z ((354792.6 6688941.3 33.7, 354796.4 6688936.1 33.7, 354796.6 6688936.3 33.7, 354798.7 6688933 33.7, 354787.5 6688923.5 33.7, 354780.7 6688931.4 33.7, 354792.6 6688941.3 33.7))
BATIMENT0000000302923389;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;00;00;19.0;16.7;35.7;39.2;17.9;Cadastre;A 1.0;POLYGON Z ((354713.1 6688952.3 35.7, 354723 6688940.6 35.7, 354710.6 6688930.2 35.7, 354713.3 6688927.1 35.7, 354710.9 6688924.8 35.7, 354708.4 6688927.8 35.7, 354708.2 6688927.7 35.7, 354698.2 6688939.7 35.7, 354713.1 6688952.3 35.7))
BATIMENT0000000302923391;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.7;17.5;23.3;40.2;18.2;Cadastre;C 0.2;POLYGON Z ((354729.1 6688933.5 23.3, 354723.3 6688940.4 23.3, 354723 6688940.6 23.3, 354726.5 6688943.8 23.3, 354728.2 6688945.2 23.3, 354734.5 6688937.6 23.3, 354732.6 6688936.1 23.3, 354729.1 6688933.5 23.3))
BATIMENT0000000302923392;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;40.0;9.0;90;90;21.7;18.0;39.7;45.4;19.5;Cadastre;A 1.0;POLYGON Z ((354742.8 6688943.5 39.7, 354747.7 6688947.3 39.7, 354750 6688948.6 39.7, 354750.1 6688948.9 39.7, 354751 6688949.7 39.7, 354750.8 6688950 39.7, 354759.9 6688958.4 39.7, 354773.2 6688943.2 39.7, 354773 6688940.2 39.7, 354752.6 6688922.9 39.7, 354744.4 6688933.6 39.7, 354739.2 6688941.1 39.7, 354742.8 6688943.5 39.7))
BATIMENT0000000302923394;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;18.6;30.5;36.2;19.1;Cadastre;;POLYGON Z ((354750 6688948.6 30.5, 354747.7 6688947.3 30.5, 354744.1 6688951.3 30.5, 354746.5 6688953.4 30.5, 354750.1 6688948.9 30.5, 354750 6688948.6 30.5))
BATIMENT0000000302923390;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;19.6;17.6;37.2;40.2;18.8;Cadastre;A 1.0;POLYGON Z ((354726.5 6688963.6 37.2, 354734.5 6688954.3 37.2, 354724.7 6688946.2 37.2, 354726.5 6688943.8 37.2, 354723 6688940.6 37.2, 354713.1 6688952.3 37.2, 354726.5 6688963.6 37.2))
BATIMENT0000000302923487;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;20;20;9.2;17.9;27.1;29.2;18.8;Cadastre;A 1.0;POLYGON Z ((354791 6688965.4 27.1, 354795.6 6688960 27.1, 354781.8 6688948.3 27.1, 354777.2 6688953.9 27.1, 354782.3 6688958.2 27.1, 354791 6688965.4 27.1))
BATIMENT0000000302923395;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.0;18.9;37.0;39.5;19.2;Cadastre;;POLYGON Z ((354743 6688959.1 37, 354740.1 6688959.3 37, 354740.4 6688960.4 37, 354743.1 6688960 37, 354743 6688959.1 37))
BATIMENT0000000302923393;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;20.9;18.7;39.7;42.0;19.9;Cadastre;C 0.7;POLYGON Z ((354740.5 6688975.3 39.7, 354745.4 6688975 39.7, 354759.9 6688958.4 39.7, 354750.8 6688950 39.7, 354743 6688959.1 39.7, 354743.1 6688960 39.7, 354740.4 6688960.4 39.7, 354740.1 6688959.3 39.7, 354734.5 6688954.3 39.7, 354726.5 6688963.6 39.7, 354740.5 6688975.3 39.7))
BATIMENT0000000302923467;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.4;15.8;20.2;20.6;18.9;Cadastre;A 1.0;POLYGON Z ((354554.9 6688963.9 20.2, 354560.9 6688964.1 20.2, 354561 6688961 20.2, 354555 6688960.8 20.2, 354554.9 6688963.9 20.2))
BATIMENT0000000302923464;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;15;20;16.8;16.9;33.7;37.2;18.5;Cadastre;A 1.0;POLYGON Z ((354576.5 6688957.2 33.7, 354574.9 6688956.7 33.7, 354570.7 6688968.8 33.7, 354579 6688971.6 33.7, 354584.2 6688957.2 33.7, 354577.3 6688954.9 33.7, 354576.5 6688957.2 33.7))
BATIMENT0000000302923465;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;17.7;20.7;25.5;19.2;Cadastre;;POLYGON Z ((354564 6688967.5 20.7, 354564.2 6688960.8 20.7, 354561 6688960.6 20.7, 354561 6688961 20.7, 354560.9 6688964.1 20.7, 354560.8 6688967.5 20.7, 354564 6688967.5 20.7))
BATIMENT0000000302923463;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.9;17.5;24.5;29.2;19.2;Cadastre;A 1.0;POLYGON Z ((354567.2 6688967.4 24.5, 354567.2 6688960.9 24.5, 354564.2 6688960.8 24.5, 354564 6688967.5 24.5, 354567.2 6688967.4 24.5))
BATIMENT0000000302923461;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;90;90;12.1;16.6;28.7;31.5;18.4;Cadastre;C 0.7;POLYGON Z ((354591.2 6688968 28.7, 354591.1 6688968.2 28.7, 354596.8 6688970.2 28.7, 354597 6688970.3 28.7, 354600.8 6688973.2 28.7, 354608.8 6688963.8 28.7, 354599.1 6688955.6 28.7, 354598.8 6688955.9 28.7, 354598.7 6688955.8 28.7, 354598.5 6688955.6 28.7, 354598.2 6688955.5 28.7, 354598 6688955.4 28.7, 354597.9 6688955.4 28.7, 354597.5 6688955.4 28.7, 354597.3 6688955.4 28.7, 354597 6688955.5 28.7, 354596.7 6688955.7 28.7, 354596.4 6688955.9 28.7, 354596.3 6688956 28.7, 354596.2 6688956.2 28.7, 354595.7 6688955.9 28.7, 354591.2 6688968 28.7))
BATIMENT0000000302923466;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;17.8;20.7;21.5;19.2;Cadastre;A 1.0;POLYGON Z ((354560.8 6688967.5 20.7, 354560.9 6688964.1 20.7, 354554.9 6688963.9 20.7, 354554.8 6688967 20.7, 354554.8 6688967.4 20.7, 354560.8 6688967.5 20.7))
BATIMENT0000000302923458;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;14.6;16.9;31.6;34.8;18.7;Cadastre;A 0.9;POLYGON Z ((354607.5 6688979.1 31.6, 354608.9 6688980.3 31.6, 354615.2 6688973 31.6, 354616.9 6688970.7 31.6, 354608.8 6688963.8 31.6, 354600.8 6688973.2 31.6, 354607.5 6688979.1 31.6))
BATIMENT0000000302923462;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;00;00;16.7;18.0;34.7;38.3;20.2;Cadastre;A 1.0;POLYGON Z ((354570 6688968.6 34.7, 354567.2 6688967.4 34.7, 354563.5 6688977.7 34.7, 354565.5 6688978.5 34.7, 354575.2 6688982.3 34.7, 354579 6688971.6 34.7, 354570.7 6688968.8 34.7, 354570 6688968.6 34.7))
BATIMENT0000000302923559;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;19.2;24.7;33.5;21.1;Cadastre;;POLYGON Z ((354554.2 6688978.8 24.7, 354553.6 6688980.7 24.7, 354563.5 6688984 24.7, 354565.5 6688978.5 24.7, 354563.5 6688977.7 24.7, 354554.6 6688974.5 24.7, 354554.1 6688974.2 24.7, 354553.4 6688978.6 24.7, 354554.2 6688978.8 24.7))
BATIMENT0000000302923459;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;10;20;11.7;18.2;30.0;31.6;19.0;Cadastre;A 0.9;POLYGON Z ((354605.6 6688981.4 30, 354607.1 6688982.3 30, 354608.9 6688980.3 30, 354607.5 6688979.1 30, 354605.6 6688981.4 30))
BATIMENT0000000302923387;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;15.5;16.1;31.7;35.0;17.7;Cadastre;A 1.0;POLYGON Z ((354672.8 6688944.2 31.7, 354667.2 6688954.5 31.7, 354665.6 6688957.2 31.7, 354678 6688967.2 31.7, 354687.1 6688956.3 31.7, 354672.8 6688944.2 31.7))
BATIMENT0000000302923385;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;17.1;20.5;21.5;18.4;Cadastre;;POLYGON Z ((354657.6 6688965.4 20.5, 354658.1 6688964.8 20.5, 354656.6 6688963.5 20.5, 354656 6688964.2 20.5, 354657.6 6688965.4 20.5))
BATIMENT0000000302923384;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;20;20;21.6;16.1;37.7;41.5;20.1;Cadastre;C 0.7;POLYGON Z ((354679.2 6688967.5 37.7, 354679.9 6688967.1 37.7, 354686.7 6688972.9 37.7, 354685.5 6688974.3 37.7, 354679.1 6688982.1 37.7, 354687.5 6688989.1 37.7, 354689.3 6688990.5 37.7, 354690.7 6688988.9 37.7, 354697 6688981.2 37.7, 354703.6 6688986.9 37.7, 354703.4 6688987.9 37.7, 354704.2 6688988.4 37.7, 354705.1 6688987.3 37.7, 354713.2 6688978 37.7, 354687.1 6688956.3 37.7, 354678 6688967.2 37.7, 354679.2 6688967.5 37.7), (354691.5 6688976 37.7, 354694.2 6688978.3 37.7, 354691.8 6688981.1 37.7, 354689.1 6688978.8 37.7, 354690 6688977.8 37.7, 354691.5 6688976 37.7))
BATIMENT0000000302923377;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.3;17.5;26.9;33.0;19.3;Cadastre;A 1.0;POLYGON Z ((354653.9 6688962.5 26.9, 354649.7 6688967.7 26.9, 354648.1 6688966.4 26.9, 354649.2 6688965 26.9, 354643.6 6688960.4 26.9, 354643.3 6688960.8 26.9, 354639 6688957.4 26.9, 354629.6 6688969 26.9, 354642.7 6688980.2 26.9, 354654.4 6688990 26.9, 354668.4 6688973.4 26.9, 354666.6 6688971.8 26.9, 354660.7 6688967 26.9, 354658.1 6688964.8 26.9, 354657.6 6688965.4 26.9, 354656 6688964.2 26.9, 354653.9 6688962.5 26.9))
BATIMENT0000000302923376;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.5;17.9;26.4;31.0;19.5;Cadastre;C 0.4;POLYGON Z ((354672.2 6688976.5 26.4, 354677.3 6688980.7 26.4, 354680.2 6688976.9 26.4, 354674.1 6688971.7 26.4, 354670.9 6688975.4 26.4, 354672.2 6688976.5 26.4))
BATIMENT0000000302923386;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.2;18.2;38.5;39.5;20.1;Cadastre;;POLYGON Z ((354705.1 6688987.3 38.5, 354704.2 6688988.4 38.5, 354705.5 6688989.7 38.5, 354706.4 6688988.5 38.5, 354705.1 6688987.3 38.5))
BATIMENT0000000302923380;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;19.6;18.8;38.5;41.2;20.6;Cadastre;C 0.5;POLYGON Z ((354681.7 6688996.2 38.5, 354687.5 6688989.1 38.5, 354679.1 6688982.1 38.5, 354672.6 6688989.9 38.5, 354675.8 6688992.5 38.5, 354681.1 6688996.9 38.5, 354681.7 6688996.2 38.5))
BATIMENT0000000302923373;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;34;20;14.3;18.8;33.2;38.4;20.5;Cadastre;C 0.8;POLYGON Z ((354673.4 6689006 33.2, 354678.9 6688999.7 33.2, 354673.7 6688995.4 33.2, 354672.9 6688994.6 33.2, 354672.1 6688995.4 33.2, 354667.4 6688991.3 33.2, 354668.7 6688989.5 33.2, 354668.3 6688987 33.2, 354665.5 6688984.6 33.2, 354672.2 6688976.5 33.2, 354670.9 6688975.4 33.2, 354668.4 6688973.4 33.2, 354654.4 6688990 33.2, 354673.4 6689006 33.2))
BATIMENT0000000302923381;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;18.0;26.7;27.5;20.0;Cadastre;;POLYGON Z ((354690.7 6688991.6 26.7, 354692.1 6688989.8 26.7, 354690.7 6688988.9 26.7, 354689.3 6688990.5 26.7, 354690.7 6688991.6 26.7))
BATIMENT0000000302923382;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.2;17.9;26.2;30.2;21.2;Cadastre;C 0.3;POLYGON Z ((354696 6688996.2 26.2, 354696.9 6688996.8 26.2, 354700 6688993.4 26.2, 354693.5 6688988.2 26.2, 354692.1 6688989.8 26.2, 354690.7 6688991.6 26.2, 354696 6688996.2 26.2))
BATIMENT0000000302923456;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;18.1;29.0;30.9;19.7;Cadastre;;POLYGON Z ((354584.6 6688985 29, 354595.2 6688989 29, 354599.8 6688977.6 29, 354599.2 6688977 29, 354598 6688976.5 29, 354589.1 6688973.4 29, 354584.6 6688985 29))
BATIMENT0000000302923561;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;35;10;17.5;18.9;36.5;38.1;21.1;Cadastre;C 0.9;POLYGON Z ((354570.9 6688996.8 36.5, 354571.2 6688996.1 36.5, 354570.2 6688995.6 36.5, 354575.2 6688982.3 36.5, 354565.5 6688978.5 36.5, 354563.5 6688984 36.5, 354565.1 6688984.6 36.5, 354563.2 6688990.3 36.5, 354562 6688993.8 36.5, 354570.9 6688996.8 36.5))
BATIMENT0000000302923457;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.1;17.9;29.0;34.5;23.3;Cadastre;A 1.0;POLYGON Z ((354606.3 6688983 29, 354600.7 6688989.5 29, 354590.8 6689001.1 29, 354581.8 6688998.9 29, 354581.5 6688999.2 29, 354579.5 6688998.6 29, 354576.5 6689006.6 29, 354599.4 6689012 29, 354601.6 6689012.5 29, 354603.5 6689013 29, 354614.9 6689015.6 29, 354613.5 6689017.3 29, 354620.7 6689020.2 29, 354622 6689018.7 29, 354623 6689018.8 29, 354623.1 6689010.5 29, 354623.5 6689005.5 29, 354630 6688997.8 29, 354635.9 6688990.7 29, 354629.8 6688985.4 29, 354630 6688984.6 29, 354622.2 6688978.3 29, 354621.8 6688978.6 29, 354615.2 6688973 29, 354608.9 6688980.3 29, 354607.1 6688982.3 29, 354606.3 6688983 29))
BATIMENT0000000302923478;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;20.2;31.2;39.2;22.4;Cadastre;;POLYGON Z ((354560.9 6689007.2 31.2, 354561.8 6689004.9 31.2, 354567.3 6689006.8 31.2, 354570.9 6688996.8 31.2, 354562 6688993.8 31.2, 354552.1 6688990.5 31.2, 354548 6688990.7 31.2, 354545.8 6688995.5 31.2, 354544.6 6688998.1 31.2, 354553.8 6689002.5 31.2, 354553.2 6689004.1 31.2, 354560.9 6689007.2 31.2))
BATIMENT0000000302927416;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;20.6;36.0;38.2;21.5;Cadastre;;POLYGON Z ((354566.3 6689009.3 36, 354567.3 6689006.8 36, 354561.8 6689004.9 36, 354560.9 6689007.2 36, 354566.3 6689009.3 36))
BATIMENT0000000302927412;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;14.0;20.8;34.8;39.1;22.2;Cadastre;C 0.4;POLYGON Z ((354565.8 6689010.5 34.8, 354552.5 6689005.7 34.8, 354550 6689011.5 34.8, 354556.3 6689013.8 34.8, 354557.9 6689014.4 34.8, 354563.7 6689016.2 34.8, 354565.8 6689010.5 34.8))
BATIMENT0000000302927399;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.1;23.0;31.1;34.2;23.3;Cadastre;;POLYGON Z ((354601.6 6689012.5 31.1, 354601.3 6689015.1 31.1, 354602.9 6689015.4 31.1, 354603.5 6689013 31.1, 354601.6 6689012.5 31.1))
BATIMENT0000000302927414;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;20.8;35.2;36.5;22.1;Cadastre;;POLYGON Z ((354548.2 6689015.7 35.2, 354550.4 6689016.5 35.2, 354551.2 6689014.4 35.2, 354549.1 6689013.7 35.2, 354548.2 6689015.7 35.2))
BATIMENT0000000302929169;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.5;23.0;46.5;46.6;23.3;Cadastre;;POLYGON Z ((354599 6689022.9 46.5, 354601.5 6689023.4 46.5, 354602.9 6689015.4 46.5, 354601.3 6689015.1 46.5, 354599.2 6689014.6 46.5, 354597.2 6689014.1 46.5, 354594.4 6689022.1 46.5, 354596.9 6689022.6 46.5, 354599 6689022.9 46.5))
BATIMENT0000000302927413;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;19;20;15.8;20.8;36.6;40.5;22.4;Cadastre;A 1.0;POLYGON Z ((354558.3 6689030.6 36.6, 354563.7 6689016.2 36.6, 354557.9 6689014.4 36.6, 354557 6689016.1 36.6, 354555.5 6689015.4 36.6, 354556.3 6689013.8 36.6, 354550 6689011.5 36.6, 354549.1 6689013.7 36.6, 354551.2 6689014.4 36.6, 354550.4 6689016.5 36.6, 354548.2 6689015.7 36.6, 354544.4 6689024.7 36.6, 354558.3 6689030.6 36.6))
BATIMENT0000000302923486;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;12;20;6.8;18.7;25.5;39.6;20.0;Cadastre;A 1.0;POLYGON Z ((354762.3 6688970.8 25.5, 354781 6688986.5 25.5, 354787.9 6688978.3 25.5, 354791.9 6688973.5 25.5, 354793.7 6688971.3 25.5, 354789.2 6688967.5 25.5, 354785 6688972.6 25.5, 354785.1 6688972.7 25.5, 354783.5 6688974.8 25.5, 354779.7 6688971.6 25.5, 354779.5 6688971.7 25.5, 354774.5 6688967.4 25.5, 354782.3 6688958.2 25.5, 354777.2 6688953.9 25.5, 354762.3 6688970.8 25.5))
BATIMENT0000000302923519;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.4;19.8;23.3;23.6;20.0;Cadastre;;POLYGON Z ((354750.1 6688987.5 23.3, 354751.7 6688985.6 23.3, 354749.8 6688984 23.3, 354749.5 6688983.7 23.3, 354747.9 6688985.6 23.3, 354748.2 6688985.8 23.3, 354750.1 6688987.5 23.3))
BATIMENT0000000302923485;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;10;20.2;18.3;38.5;40.5;20.0;Cadastre;A 1.0;POLYGON Z ((354799.3 6688988 38.5, 354787.9 6688978.3 38.5, 354781 6688986.5 38.5, 354792.5 6688996.2 38.5, 354799.3 6688988 38.5))
BATIMENT0000000302923383;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;19.9;19.2;39.1;41.9;21.2;Cadastre;A 1.0;POLYGON Z ((354727.5 6688995.7 39.1, 354727.3 6688989.7 39.1, 354713.2 6688978 39.1, 354705.1 6688987.3 39.1, 354706.4 6688988.5 39.1, 354711.6 6688992.8 39.1, 354711.3 6688995.6 39.1, 354707.4 6688999.8 39.1, 354700 6688993.4 39.1, 354696.9 6688996.8 39.1, 354704.5 6689003.1 39.1, 354714.1 6689011 39.1, 354727.5 6688995.7 39.1))
BATIMENT0000000302923520;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.0;20.0;23.0;23.7;20.4;Cadastre;;POLYGON Z ((354738.4 6688997.1 23, 354738.1 6688996.8 23, 354736.5 6688998.7 23, 354736.6 6688998.9 23, 354738.8 6689000.8 23, 354740.5 6688998.7 23, 354738.4 6688997.1 23))
BATIMENT0000000302928343;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;00;00;18.2;20.3;38.6;41.1;21.9;Cadastre;A 1.0;POLYGON Z ((354724.7 6689028.1 38.6, 354729.2 6689031.9 38.6, 354737.9 6689021.7 38.6, 354726.4 6689012 38.6, 354707.4 6689033.8 38.6, 354707.4 6689034.8 38.6, 354714.3 6689040.5 38.6, 354718.3 6689035.9 38.6, 354724.7 6689028.1 38.6))
BATIMENT0000000302928337;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;19.2;19.7;38.9;41.1;22.0;Cadastre;A 1.0;POLYGON Z ((354734.5 6689036.3 38.9, 354728.2 6689044 38.9, 354724.2 6689048.7 38.9, 354730.6 6689054.1 38.9, 354741.4 6689041.1 38.9, 354739.5 6689039.5 38.9, 354741 6689037.6 38.9, 354742.9 6689039.2 38.9, 354749.5 6689031.3 38.9, 354737.9 6689021.7 38.9, 354729.2 6689031.9 38.9, 354734.5 6689036.3 38.9))
BATIMENT0000000302928344;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;21.4;25.0;38.2;21.7;Cadastre;;POLYGON Z ((354716.2 6689042.1 25, 354720.2 6689037.4 25, 354718.3 6689035.9 25, 354714.3 6689040.5 25, 354716.2 6689042.1 25))
BATIMENT0000000302928345;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.5;21.5;31.0;38.0;21.8;Cadastre;;POLYGON Z ((354726 6689042.3 31, 354722 6689047 31, 354724.2 6689048.7 31, 354728.2 6689044 31, 354726 6689042.3 31))
BATIMENT0000000302928332;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;19.3;19.6;39.0;42.1;22.0;Cadastre;A 1.0;POLYGON Z ((354740.2 6689062.3 39, 354742.9 6689059 39, 354743.1 6689057.8 39, 354740.3 6689055.5 39, 354746.7 6689047.6 39, 354750.8 6689051 39, 354759.9 6689040.1 39, 354749.5 6689031.3 39, 354742.9 6689039.2 39, 354745.1 6689040.9 39, 354743.5 6689042.8 39, 354741.4 6689041.1 39, 354730.6 6689054.1 39, 354740.2 6689062.3 39))
BATIMENT0000000302923375;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;19.5;36.3;38.0;20.6;Cadastre;;POLYGON Z ((354678.9 6688999.7 36.3, 354679.6 6688998.6 36.3, 354681.1 6688996.9 36.3, 354675.8 6688992.5 36.3, 354673.7 6688995.4 36.3, 354678.9 6688999.7 36.3))
BATIMENT0000000302923374;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;7.9;19.5;27.4;40.7;21.2;Cadastre;A 1.0;POLYGON Z ((354681.7 6689013 27.4, 354690 6689003.4 27.4, 354696 6688996.2 27.4, 354690.7 6688991.6 27.4, 354689.3 6688990.5 27.4, 354687.5 6688989.1 27.4, 354681.7 6688996.2 27.4, 354683 6688997.1 27.4, 354680.9 6688999.8 27.4, 354679.6 6688998.6 27.4, 354678.9 6688999.7 27.4, 354673.4 6689006 27.4, 354681.7 6689013 27.4))
BATIMENT0000000302923460;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;00;00;12.2;18.8;31.0;40.1;25.8;Cadastre;A 1.0;POLYGON Z ((354637.9 6688988.3 31, 354635.9 6688990.7 31, 354630 6688997.8 31, 354640.3 6689006.6 31, 354632.5 6689016.4 31, 354625.4 6689010.6 31, 354623.1 6689010.5 31, 354623 6689018.8 31, 354625.7 6689018.7 31, 354625.7 6689022.1 31, 354629.5 6689022.3 31, 354629.5 6689025.6 31, 354636.2 6689031.1 31, 354637.7 6689031.1 31, 354638.7 6689025.1 31, 354643.7 6689019.1 31, 354645.2 6689017.3 31, 354643.4 6689015.9 31, 354647.9 6689010.3 31, 354649.8 6689011.8 31, 354656.4 6689003.8 31, 354637.9 6688988.3 31))
BATIMENT0000000302927375;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;20;20;21.5;20.6;42.1;45.2;21.6;Cadastre;A 1.0;POLYGON Z ((354698.9 6689027.5 42.1, 354700.2 6689027.1 42.1, 354714.1 6689011 42.1, 354704.5 6689003.1 42.1, 354698.6 6689009.8 42.1, 354696.6 6689010.2 42.1, 354696.5 6689009.5 42.1, 354690 6689003.4 42.1, 354681.7 6689013 42.1, 354698.9 6689027.5 42.1))
BATIMENT0000000302927403;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;00;00;17.4;19.5;36.9;40.2;24.5;Cadastre;C 0.8;POLYGON Z ((354656.4 6689003.8 36.9, 354649.8 6689011.8 36.9, 354648.1 6689013.8 36.9, 354662.9 6689026.2 36.9, 354658.3 6689031.7 36.9, 354657.8 6689032.5 36.9, 354657.9 6689037 36.9, 354660.5 6689039.5 36.9, 354664.8 6689035.4 36.9, 354665.2 6689035 36.9, 354665.5 6689034.6 36.9, 354665.7 6689034.5 36.9, 354666 6689034.2 36.9, 354666.6 6689033.7 36.9, 354666.7 6689033.6 36.9, 354667.1 6689033.3 36.9, 354667.2 6689033.1 36.9, 354667.3 6689032.9 36.9, 354667.4 6689032.7 36.9, 354667.5 6689032.5 36.9, 354667.4 6689032.3 36.9, 354667.3 6689032.1 36.9, 354664.4 6689029.7 36.9, 354668.7 6689024.5 36.9, 354669.2 6689023.8 36.9, 354667.5 6689022.5 36.9, 354668.2 6689021.6 36.9, 354669.9 6689023 36.9, 354673.7 6689018.4 36.9, 354656.4 6689003.8 36.9))
BATIMENT0000000302927404;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;00;00;6.7;19.7;26.4;28.7;25.8;Cadastre;C 0.4;POLYGON Z ((354658.3 6689031.7 26.4, 354643.7 6689019.1 26.4, 354638.7 6689025.1 26.4, 354637.7 6689031.1 26.4, 354645 6689031.6 26.4, 354651.5 6689032 26.4, 354657.8 6689032.5 26.4, 354658.3 6689031.7 26.4))
BATIMENT0000000302929171;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.4;22.8;33.2;38.0;25.5;Cadastre;;POLYGON Z ((354628.4 6689043.9 33.2, 354629.5 6689025.6 33.2, 354629.5 6689022.3 33.2, 354625.7 6689022.1 33.2, 354625.7 6689018.7 33.2, 354623 6689018.8 33.2, 354622.6 6689042.7 33.2, 354628.4 6689043.9 33.2))
BATIMENT0000000302927408;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;12;20;17.6;20.7;38.4;42.2;24.4;Cadastre;A 1.0;POLYGON Z ((354692.6 6689035.8 38.4, 354692.7 6689034.5 38.4, 354673.7 6689018.4 38.4, 354669.9 6689023 38.4, 354669.5 6689023.6 38.4, 354671.5 6689025.3 38.4, 354670.8 6689026.2 38.4, 354668.7 6689024.5 38.4, 354664.4 6689029.7 38.4, 354667.3 6689032.1 38.4, 354667.4 6689032.3 38.4, 354667.5 6689032.5 38.4, 354667.4 6689032.7 38.4, 354667.3 6689032.9 38.4, 354667.2 6689033.1 38.4, 354667.1 6689033.3 38.4, 354666.7 6689033.6 38.4, 354666.6 6689033.7 38.4, 354666 6689034.2 38.4, 354665.7 6689034.5 38.4, 354665.5 6689034.6 38.4, 354665.2 6689035 38.4, 354664.8 6689035.4 38.4, 354660.5 6689039.5 38.4, 354667.2 6689046.2 38.4, 354671.1 6689041.5 38.4, 354666.2 6689037.5 38.4, 354673.1 6689029 38.4, 354679.1 6689034.2 38.4, 354668 6689047.1 38.4, 354675.8 6689054.9 38.4, 354692.6 6689035.8 38.4))
BATIMENT0000000302927406;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;3.6;23.8;27.5;31.5;25.8;Cadastre;C 0.5;POLYGON Z ((354636.2 6689031.1 27.5, 354634.6 6689031.1 27.5, 354633.6 6689038.1 27.5, 354631.4 6689038 27.5, 354630.2 6689038.5 27.5, 354629.7 6689044.4 27.5, 354636.1 6689044.9 27.5, 354637.5 6689035 27.5, 354639.9 6689035 27.5, 354644.7 6689035.1 27.5, 354645 6689031.6 27.5, 354637.7 6689031.1 27.5, 354636.2 6689031.1 27.5))
BATIMENT0000000302927407;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;6.1;23.3;29.5;37.9;25.1;Cadastre;A 1.0;POLYGON Z ((354657.8 6689032.5 29.5, 354651.5 6689032 29.5, 354651.3 6689046.1 29.5, 354655.6 6689046.1 29.5, 354657.9 6689046.1 29.5, 354657.9 6689037 29.5, 354657.8 6689032.5 29.5))
BATIMENT0000000302927402;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.1;23.0;46.1;47.0;23.1;Cadastre;;POLYGON Z ((354599 6689022.9 46.1, 354596.9 6689022.6 46.1, 354596.6 6689024.5 46.1, 354598 6689024.8 46.1, 354599 6689022.9 46.1))
BATIMENT0000000302927401;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.0;23.0;32.0;;;Cadastre;;POLYGON Z ((354579.4 6689024.6 32, 354583.7 6689025.5 32, 354583.9 6689023.4 32, 354579.6 6689022.8 32, 354579.4 6689024.6 32))
BATIMENT0000000302929170;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;13.8;20.8;34.7;43.5;23.3;Cadastre;C 0.8;POLYGON Z ((354589.5 6689044.1 34.7, 354592.3 6689037.5 34.7, 354590.6 6689036.7 34.7, 354592.7 6689032.3 34.7, 354578.6 6689026.1 34.7, 354579.4 6689024.6 34.7, 354579.6 6689022.8 34.7, 354583.9 6689023.4 34.7, 354593.7 6689025.2 34.7, 354594.4 6689022.1 34.7, 354597.2 6689014.1 34.7, 354599.2 6689014.6 34.7, 354599.4 6689012 34.7, 354576.5 6689006.6 34.7, 354572.1 6689018.1 34.7, 354566.8 6689032 34.7, 354568 6689034.7 34.7, 354589.5 6689044.1 34.7))
BATIMENT0000000302927400;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;23.1;31.2;31.4;23.5;Cadastre;;POLYGON Z ((354612.5 6689023.3 31.2, 354612 6689024.8 31.2, 354618.4 6689027.5 31.2, 354618.9 6689025.8 31.2, 354612.5 6689023.3 31.2))
BATIMENT0000000302927397;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.4;22.7;41.2;42.2;23.2;Cadastre;;POLYGON Z ((354590.6 6689036.7 41.2, 354592.3 6689037.5 41.2, 354594.3 6689033 41.2, 354592.7 6689032.3 41.2, 354590.6 6689036.7 41.2))
BATIMENT0000000302927398;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;12;20;15.6;22.9;38.5;43.4;24.4;Cadastre;A 1.0;POLYGON Z ((354601.5 6689023.4 38.5, 354599 6689022.9 38.5, 354598 6689024.8 38.5, 354594.3 6689033 38.5, 354592.3 6689037.5 38.5, 354589.5 6689044.1 38.5, 354622.4 6689058.5 38.5, 354622.6 6689042.7 38.5, 354623 6689018.8 38.5, 354622 6689018.7 38.5, 354620.7 6689020.2 38.5, 354613.5 6689017.3 38.5, 354614.9 6689015.6 38.5, 354603.5 6689013 38.5, 354602.9 6689015.4 38.5, 354601.5 6689023.4 38.5), (354612.5 6689023.3 38.5, 354618.9 6689025.8 38.5, 354621.3 6689027 38.5, 354615.9 6689039.1 38.5, 354605.1 6689034.7 38.5, 354610.1 6689022.4 38.5, 354612.5 6689023.3 38.5), (354601.4 6689035.8 38.5, 354600.5 6689037.9 38.5, 354598.1 6689037 38.5, 354598.9 6689034.8 38.5, 354601.4 6689035.8 38.5))
BATIMENT0000000302929198;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.2;24.5;26.7;;;Cadastre;;POLYGON Z ((354571.2 6689063.5 26.7, 354571 6689057.7 26.7, 354572 6689057.7 26.7, 354571.8 6689054.7 26.7, 354570.8 6689054.8 26.7, 354570.8 6689053.3 26.7, 354571.8 6689053.2 26.7, 354576.8 6689052.9 26.7, 354576.5 6689048.7 26.7, 354565 6689043.7 26.7, 354564.1 6689063.9 26.7, 354571.2 6689063.5 26.7))
BATIMENT0000000302929027;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;23.3;25.5;26.2;23.7;Cadastre;;POLYGON Z ((354570.8 6689053.3 25.5, 354570.8 6689054.8 25.5, 354571.8 6689054.7 25.5, 354571.8 6689053.2 25.5, 354570.8 6689053.3 25.5))
BATIMENT0000000302929028;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;23.3;;;;Cadastre;;POLYGON Z ((354572.2 6689063.5 -1000, 354572 6689057.7 -1000, 354571 6689057.7 -1000, 354571.2 6689063.5 -1000, 354572.2 6689063.5 -1000))
BATIMENT0000000302928254;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;25.4;39.6;43.9;25.9;Cadastre;;POLYGON Z ((354584.7 6689100.7 39.6, 354584.9 6689100.6 39.6, 354585.2 6689100.6 39.6, 354585.4 6689100.4 39.6, 354585.7 6689100.3 39.6, 354585.9 6689100.1 39.6, 354586.1 6689100 39.6, 354586.3 6689098.9 39.6, 354603.5 6689099.2 39.6, 354603.8 6689090.1 39.6, 354567.5 6689089.5 39.6, 354567.4 6689092.7 39.6, 354567 6689092.7 39.6, 354566.9 6689097.5 39.6, 354567.9 6689097.5 39.6, 354567.9 6689098.5 39.6, 354582.7 6689098.8 39.6, 354582.7 6689100 39.6, 354583.4 6689100.3 39.6, 354583.8 6689100.5 39.6, 354584.5 6689100.7 39.6, 354584.7 6689100.7 39.6))
BATIMENT0000000302927409;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.6;23.8;29.5;37.0;24.5;Cadastre;A 1.0;POLYGON Z ((354655.6 6689046.1 29.5, 354651.3 6689046.1 29.5, 354650 6689046 29.5, 354649.9 6689054.9 29.5, 354655.6 6689055.2 29.5, 354655.6 6689046.1 29.5))
BATIMENT0000000302928271;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;17.6;21.8;39.5;42.5;23.9;Cadastre;A 1.0;POLYGON Z ((354701.3 6689041.7 39.5, 354699.7 6689042.1 39.5, 354685.2 6689058.5 39.5, 354693.5 6689063.8 39.5, 354695 6689064.8 39.5, 354698 6689066.8 39.5, 354702.1 6689061.9 39.5, 354701.1 6689060.9 39.5, 354699.4 6689059.5 39.5, 354699.5 6689058.3 39.5, 354699 6689056.8 39.5, 354698 6689055.4 39.5, 354699.1 6689054.3 39.5, 354703.2 6689057.6 39.5, 354704.7 6689058.9 39.5, 354711.7 6689050.5 39.5, 354701.3 6689041.7 39.5))
BATIMENT0000000302929172;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.4;23.0;44.4;48.6;24.5;Cadastre;;POLYGON Z ((354642.7 6689067.2 44.4, 354647.9 6689055 44.4, 354628.4 6689046.9 44.4, 354628.4 6689043.9 44.4, 354622.6 6689042.7 44.4, 354622.4 6689058.5 44.4, 354642.7 6689067.2 44.4), (354636.3 6689057.4 44.4, 354636.8 6689056 44.4, 354642 6689058 44.4, 354641.2 6689060.3 44.4, 354635.9 6689058.4 44.4, 354636.3 6689057.4 44.4))
BATIMENT0000000302927410;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;18.7;23.0;41.7;44.4;24.4;Cadastre;A 1.0;POLYGON Z ((354675.8 6689054.9 41.7, 354668 6689047.1 41.7, 354657.5 6689059.3 41.7, 354659.1 6689060 41.7, 354662.1 6689061.8 41.7, 354666.5 6689065.5 41.7, 354675.8 6689054.9 41.7))
BATIMENT0000000302928276;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;22.1;38.9;41.0;22.8;Cadastre;;POLYGON Z ((354702.1 6689061.9 38.9, 354703.4 6689060.3 38.9, 354704.7 6689058.9 38.9, 354703.2 6689057.6 38.9, 354701.1 6689060.9 38.9, 354702.1 6689061.9 38.9))
BATIMENT0000000302928277;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;23.3;36.9;;;Cadastre;;POLYGON Z ((354704.7 6689058.9 36.9, 354703.4 6689060.3 36.9, 354707.6 6689063.6 36.9, 354708.9 6689062.3 36.9, 354704.7 6689058.9 36.9))
BATIMENT0000000302927405;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;00;00;21.9;23.1;45.0;48.6;24.2;Cadastre;A 1.0;POLYGON Z ((354657.2 6689073.4 45, 354659.8 6689073.1 45, 354666.5 6689065.5 45, 354662.1 6689061.8 45, 354659.1 6689060 45, 354657.6 6689061.9 45, 354655.8 6689061.1 45, 354656.9 6689059.1 45, 354655.6 6689058.3 45, 354647.9 6689055 45, 354642.7 6689067.2 45, 354657.2 6689073.4 45))
BATIMENT0000000302928272;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.5;22.3;36.9;41.0;23.9;Cadastre;;POLYGON Z ((354702.6 6689069.7 36.9, 354704.9 6689067.1 36.9, 354707.6 6689063.6 36.9, 354703.4 6689060.3 36.9, 354702.1 6689061.9 36.9, 354698 6689066.8 36.9, 354702.6 6689069.7 36.9))
BATIMENT0000000302928275;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;22.6;36.5;41.9;23.7;Cadastre;;POLYGON Z ((354709.3 6689074 36.5, 354711.1 6689071.8 36.5, 354704.9 6689067.1 36.5, 354702.6 6689069.7 36.5, 354709.3 6689074 36.5))
BATIMENT0000000302928270;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;21.8;23.2;45.0;47.2;24.4;Cadastre;A 1.0;POLYGON Z ((354669.3 6689076.5 45, 354670 6689079 45, 354702.6 6689093.2 45, 354707.7 6689083.3 45, 354702.4 6689081.1 45, 354703.9 6689077.2 45, 354709.6 6689079.6 45, 354711.7 6689075.6 45, 354709.3 6689074 45, 354702.6 6689069.7 45, 354698 6689066.8 45, 354695 6689064.8 45, 354694.2 6689066 45, 354695.6 6689066.6 45, 354696.7 6689068.4 45, 354697.1 6689071 45, 354696.6 6689073.3 45, 354694.7 6689077.7 45, 354686.4 6689074.1 45, 354687.2 6689071.9 45, 354689.1 6689067.8 45, 354690.1 6689066.7 45, 354691 6689066.1 45, 354692.9 6689065.3 45, 354693.5 6689063.8 45, 354685.2 6689058.5 45, 354669.3 6689076.5 45))
BATIMENT0000000302923578;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;9.3;10.5;18.5;10.7;Cadastre;;POLYGON Z ((354102.2 6688869.2 10.5, 354103.3 6688871.1 10.5, 354122.1 6688861.7 10.5, 354113.5 6688843.6 10.5, 354113.1 6688842.8 10.5, 354112.6 6688839.3 10.5, 354113.4 6688839 10.5, 354111.4 6688834.7 10.5, 354090.1 6688845.1 10.5, 354094.6 6688854 10.5, 354102.2 6688869.2 10.5))
BATIMENT0000000302922993;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.6;7.0;12.6;;;Cadastre;C 0.6;POLYGON Z ((354165.9 6688855.8 12.6, 354162 6688847.7 12.6, 354156.5 6688850.4 12.6, 354155.2 6688848.3 12.6, 354154.9 6688847.4 12.6, 354152.5 6688848.6 12.6, 354154 6688851.6 12.6, 354158 6688859.7 12.6, 354165.9 6688855.8 12.6))
BATIMENT0000000302922992;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;7.7;6.5;14.2;18.0;7.5;Cadastre;A 1.0;POLYGON Z ((354158 6688859.7 14.2, 354154 6688851.6 14.2, 354151.2 6688853 14.2, 354150.2 6688851.3 14.2, 354147.3 6688852.7 14.2, 354152.3 6688862.5 14.2, 354158 6688859.7 14.2))
BATIMENT0000000302922990;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;8.0;35;90;22.3;7.0;29.3;31.3;7.9;Cadastre;B 0.5;POLYGON Z ((354152.3 6688862.5 29.3, 354147.3 6688852.7 29.3, 354140.3 6688856 29.3, 354139.8 6688855.1 29.3, 354137.4 6688856.4 29.3, 354137.9 6688857.2 29.3, 354131.1 6688860.6 29.3, 354136 6688870.6 29.3, 354152.3 6688862.5 29.3))
BATIMENT0000000302922984;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;14.1;7.1;21.2;29.9;9.9;Cadastre;A 1.0;POLYGON Z ((354136 6688870.6 21.2, 354131.1 6688860.6 21.2, 354128.9 6688856.4 21.2, 354126.8 6688857.5 21.2, 354125.8 6688858.1 21.2, 354128 6688863.1 21.2, 354123.8 6688865.2 21.2, 354128.3 6688874.4 21.2, 354136 6688870.6 21.2))
BATIMENT0000000302923576;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;7.0;00;00;19.5;7.4;26.9;27.3;10.4;Cadastre;C 0.7;POLYGON Z ((354109.5 6688883.7 26.9, 354128.3 6688874.4 26.9, 354123.8 6688865.2 26.9, 354122.1 6688861.7 26.9, 354103.3 6688871.1 26.9, 354106.2 6688877 26.9, 354109.5 6688883.7 26.9))
BATIMENT0000000302923021;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;5.0;00;00;15.7;6.5;22.2;25.2;7.3;Cadastre;A 1.0;POLYGON Z ((354160.2 6688892.1 22.2, 354161.3 6688894.5 22.2, 354161.8 6688894.2 22.2, 354163.3 6688893.6 22.2, 354168.3 6688891 22.2, 354169.3 6688893 22.2, 354180.1 6688887.5 22.2, 354181.9 6688891 22.2, 354187.5 6688888.1 22.2, 354184.8 6688882.8 22.2, 354187.4 6688881.4 22.2, 354181.7 6688869.8 22.2, 354161.1 6688880 22.2, 354153.6 6688883.7 22.2, 354153.3 6688883.8 22.2, 354158.4 6688893 22.2, 354158.7 6688892.9 22.2, 354160.2 6688892.1 22.2))
BATIMENT0000000302923025;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;7.0;18.4;20.7;7.3;Cadastre;;POLYGON Z ((354164.2 6688895.6 18.4, 354169.3 6688893 18.4, 354168.3 6688891 18.4, 354163.3 6688893.6 18.4, 354164.2 6688895.6 18.4))
BATIMENT0000000302923291;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;11.4;7.5;18.9;22.1;8.1;Cadastre;A 1.0;POLYGON Z ((354124.1 6688897.2 18.9, 354111 6688903.5 18.9, 354116.1 6688913.9 18.9, 354122.7 6688910.6 18.9, 354124.4 6688914.1 18.9, 354130.9 6688910.8 18.9, 354124.1 6688897.2 18.9))
BATIMENT0000000302923024;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;47.0;6.0;00;00;13.6;6.9;20.5;25.0;7.8;Cadastre;A 1.0;POLYGON Z ((354145 6688887.8 20.5, 354132.9 6688893.6 20.5, 354139.8 6688907.6 20.5, 354140.8 6688907.1 20.5, 354142 6688909.7 20.5, 354141.9 6688909.9 20.5, 354141.9 6688910.1 20.5, 354141.9 6688910.2 20.5, 354141.8 6688910.3 20.5, 354141.8 6688910.6 20.5, 354141.7 6688910.6 20.5, 354141.7 6688910.7 20.5, 354141.7 6688911.2 20.5, 354141.7 6688911.4 20.5, 354143.1 6688914.2 20.5, 354144.7 6688917.6 20.5, 354146.1 6688920.2 20.5, 354147.5 6688922.8 20.5, 354148.8 6688925.3 20.5, 354151.4 6688930.8 20.5, 354156.8 6688928.2 20.5, 354160.5 6688926.1 20.5, 354162 6688925.4 20.5, 354159 6688919.5 20.5, 354160.7 6688918.7 20.5, 354159.2 6688915.5 20.5, 354159.6 6688915.3 20.5, 354159.6 6688915.1 20.5, 354159.6 6688914.7 20.5, 354159.6 6688914.2 20.5, 354159.5 6688913.7 20.5, 354159.5 6688913.5 20.5, 354159.4 6688913.1 20.5, 354159.3 6688912.8 20.5, 354159.2 6688912.4 20.5, 354159.1 6688912.2 20.5, 354159 6688911.7 20.5, 354158.9 6688911.5 20.5, 354158.6 6688910.9 20.5, 354158.5 6688910.7 20.5, 354158.3 6688910.3 20.5, 354158.2 6688910.1 20.5, 354158 6688909.7 20.5, 354157.7 6688909.3 20.5, 354157.4 6688908.9 20.5, 354157.1 6688908.6 20.5, 354157 6688908.4 20.5, 354156.7 6688908 20.5, 354156.3 6688907.7 20.5, 354156.2 6688907.6 20.5, 354155.8 6688907.3 20.5, 354155.3 6688907.6 20.5, 354153.9 6688904.6 20.5, 354152.6 6688905.2 20.5, 354150.3 6688900.4 20.5, 354159.7 6688895.8 20.5, 354159.5 6688895.3 20.5, 354158.4 6688893 20.5, 354153.3 6688883.8 20.5, 354145 6688887.8 20.5))
BATIMENT0000000302923300;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.4;7.3;27.7;;;Cadastre;;POLYGON Z ((354303 6688896.9 27.7, 354303.6 6688896.1 27.7, 354301.3 6688894.2 27.7, 354300.8 6688895.1 27.7, 354303 6688896.9 27.7))
BATIMENT0000000302923550;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;15.6;8.8;24.5;29.7;11.8;Cadastre;C 0.1;POLYGON Z ((354319.2 6688897.4 24.5, 354321.9 6688899.5 24.5, 354320.9 6688904.3 24.5, 354327.1 6688909.9 24.5, 354327.6 6688909.3 24.5, 354328.7 6688905.6 24.5, 354329 6688905.8 24.5, 354329.6 6688902.7 24.5, 354328.5 6688902.4 24.5, 354330.4 6688894.5 24.5, 354331.1 6688894.7 24.5, 354331.7 6688891 24.5, 354331.2 6688890.9 24.5, 354327.9 6688885.1 24.5, 354318.8 6688894.4 24.5, 354320.4 6688895.6 24.5, 354319.2 6688897.4 24.5))
BATIMENT0000000302923553;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.7;8.9;28.7;32.0;11.7;Cadastre;;POLYGON Z ((354330.2 6688899.8 28.7, 354331.1 6688894.7 28.7, 354330.4 6688894.5 28.7, 354328.5 6688902.4 28.7, 354329.6 6688902.7 28.7, 354330.2 6688899.8 28.7))
BATIMENT0000000302923302;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;20;20;21.0;9.1;30.2;32.8;12.2;Cadastre;A 0.9;POLYGON Z ((354331.6 6688920.1 30.2, 354333.5 6688919.7 30.2, 354343.6 6688889.4 30.2, 354332.6 6688885.8 30.2, 354331.7 6688891 30.2, 354331.1 6688894.7 30.2, 354330.2 6688899.8 30.2, 354329.6 6688902.7 30.2, 354329 6688905.8 30.2, 354328.6 6688908.1 30.2, 354327.6 6688909.3 30.2, 354327.1 6688909.9 30.2, 354323.8 6688913.9 30.2, 354331.6 6688920.1 30.2))
BATIMENT0000000302923218;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;15.9;5.0;20.9;23.7;9.6;Cadastre;A 1.0;POLYGON Z ((354297.7 6688916.9 20.9, 354303.1 6688910.4 20.9, 354285.8 6688896.2 20.9, 354280.4 6688902.3 20.9, 354280.9 6688902.8 20.9, 354297.7 6688916.9 20.9))
BATIMENT0000000302923552;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;20;20;18.4;11.6;30.0;31.7;11.7;Cadastre;A 0.9;POLYGON Z ((354329 6688905.8 30, 354328.7 6688905.6 30, 354327.6 6688909.3 30, 354328.6 6688908.1 30, 354329 6688905.8 30))
BATIMENT0000000302923215;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.3;5.8;19.1;20.8;6.4;Cadastre;;POLYGON Z ((354283.5 6688908.8 19.1, 354278.9 6688907.9 19.1, 354278.3 6688911 19.1, 354282.8 6688913.1 19.1, 354283.5 6688908.8 19.1))
BATIMENT0000000302923219;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;12;20;16.8;5.8;22.6;25.0;11.2;Cadastre;A 1.0;POLYGON Z ((354304.3 6688922.6 22.6, 354301.7 6688932.3 22.6, 354309.3 6688934.2 22.6, 354315.9 6688935.9 22.6, 354317.3 6688936.1 22.6, 354320.5 6688924.9 22.6, 354303.1 6688910.4 22.6, 354297.7 6688916.9 22.6, 354304.3 6688922.6 22.6))
BATIMENT0000000302923217;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;4.8;8.5;11.8;6.8;Cadastre;;POLYGON Z ((354284 6688918.7 8.5, 354282.7 6688924.5 8.5, 354280.9 6688934.8 8.5, 354280.1 6688938.9 8.5, 354285.1 6688939.8 8.5, 354289.1 6688918 8.5, 354284.8 6688914.6 8.5, 354284 6688918.7 8.5))
BATIMENT0000000302923399;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.7;4.8;7.5;10.4;6.9;Cadastre;C 0.1;POLYGON Z ((354263.7 6688920.8 7.5, 354261.6 6688931.1 7.5, 354280.9 6688934.8 7.5, 354282.7 6688924.5 7.5, 354263.7 6688920.8 7.5))
BATIMENT0000000302923290;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;13.2;7.2;20.5;25.0;8.5;Cadastre;A 1.0;POLYGON Z ((354103.7 6688907.2 20.5, 354107.6 6688915.6 20.5, 354108.6 6688917.2 20.5, 354111.8 6688915.7 20.5, 354113.1 6688918.3 20.5, 354112.3 6688918.6 20.5, 354113.1 6688920.2 20.5, 354113.8 6688919.8 20.5, 354119.5 6688931 20.5, 354123.6 6688929.1 20.5, 354123 6688927.6 20.5, 354119.3 6688920.2 20.5, 354117.9 6688917.5 20.5, 354116.1 6688913.9 20.5, 354111 6688903.5 20.5, 354103.7 6688907.2 20.5))
BATIMENT0000000302923292;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;10;16.4;7.0;23.4;26.2;8.5;Cadastre;A 1.0;POLYGON Z ((354125.1 6688926.7 23.4, 354125.7 6688925.5 23.4, 354126.7 6688926 23.4, 354126.4 6688926.9 23.4, 354130.4 6688934.9 23.4, 354140.2 6688929.9 23.4, 354130.9 6688910.8 23.4, 354124.4 6688914.1 23.4, 354125.8 6688917.1 23.4, 354119.3 6688920.2 23.4, 354123 6688927.6 23.4, 354125.1 6688926.7 23.4))
BATIMENT0000000302923026;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.6;6.6;11.2;14.5;7.6;Cadastre;A 1.0;POLYGON Z ((354177.7 6688937.7 11.2, 354176.4 6688942.8 11.2, 354177.8 6688944.8 11.2, 354184.2 6688945.8 11.2, 354189.5 6688916.4 11.2, 354189.2 6688916.4 11.2, 354189.9 6688911.6 11.2, 354175.4 6688918.8 11.2, 354162 6688925.4 11.2, 354160.5 6688926.1 11.2, 354163.6 6688932.4 11.2, 354166.6 6688935.9 11.2, 354167.1 6688936.4 11.2, 354170.5 6688940.5 11.2, 354172.8 6688938.7 11.2, 354169.5 6688934.7 11.2, 354166.5 6688931 11.2, 354181.7 6688923.6 11.2, 354182.8 6688925.7 11.2, 354181.7 6688928.3 11.2, 354178.4 6688934.2 11.2, 354177.7 6688937.7 11.2))
BATIMENT0000000302923358;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;7.2;7.0;14.2;19.7;7.4;Cadastre;A 1.0;POLYGON Z ((354156.5 6688940.9 14.2, 354164.6 6688937 14.2, 354163.4 6688935.1 14.2, 354161.2 6688936.1 14.2, 354159.1 6688931.9 14.2, 354160.7 6688930.9 14.2, 354161.9 6688933.4 14.2, 354163.6 6688932.4 14.2, 354160.5 6688926.1 14.2, 354156.8 6688928.2 14.2, 354151.4 6688930.8 14.2, 354156.5 6688940.9 14.2))
BATIMENT0000000302923424;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;7.5;11.3;14.0;8.4;Cadastre;;POLYGON Z ((354107.5 6688937.2 11.3, 354105.9 6688933.8 11.3, 354103.8 6688934.1 11.3, 354100.6 6688935.5 11.3, 354101.7 6688937.8 11.3, 354105.6 6688946.2 11.3, 354106.2 6688947.4 11.3, 354106.6 6688947.2 11.3, 354111.2 6688944.8 11.3, 354107.5 6688937.2 11.3))
BATIMENT0000000302923359;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;13;20;11.5;7.0;18.5;21.6;7.0;Cadastre;A 1.0;POLYGON Z ((354161.5 6688951.4 18.5, 354179.8 6688954.7 18.5, 354183.3 6688951.7 18.5, 354184.2 6688945.8 18.5, 354177.8 6688944.8 18.5, 354171.4 6688943.5 18.5, 354167.2 6688942.7 18.5, 354164.6 6688937 18.5, 354156.5 6688940.9 18.5, 354161.5 6688951.4 18.5))
BATIMENT0000000302923429;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;8.0;20.3;21.8;8.6;Cadastre;;POLYGON Z ((354133.8 6688944.8 20.3, 354133.3 6688943.9 20.3, 354132.7 6688944.2 20.3, 354132.2 6688943.2 20.3, 354132.1 6688943.3 20.3, 354131.8 6688943.5 20.3, 354131.7 6688943.6 20.3, 354131.4 6688944 20.3, 354131.1 6688944.4 20.3, 354130.9 6688944.7 20.3, 354130.8 6688944.9 20.3, 354130.7 6688945 20.3, 354130.6 6688945.3 20.3, 354130.5 6688945.7 20.3, 354130.4 6688946 20.3, 354130.3 6688946.7 20.3, 354130.3 6688946.9 20.3, 354130.3 6688947 20.3, 354130.3 6688947.2 20.3, 354130.3 6688947.5 20.3, 354130.4 6688948 20.3, 354130.5 6688948.4 20.3, 354130.6 6688948.7 20.3, 354130.7 6688948.8 20.3, 354131.2 6688948.6 20.3, 354131.5 6688949 20.3, 354132.4 6688948.9 20.3, 354132.6 6688948.5 20.3, 354133.8 6688944.8 20.3))
BATIMENT0000000302923428;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.4;6.6;22.1;22.4;7.3;Cadastre;;POLYGON Z ((354149.5 6688949.1 22.1, 354148.8 6688947.6 22.1, 354148 6688947.9 22.1, 354147.2 6688950.6 22.1, 354149.9 6688951.5 22.1, 354150.5 6688951.2 22.1, 354150.4 6688950.8 22.1, 354149.8 6688949.7 22.1, 354149.5 6688949.1 22.1))
BATIMENT0000000302923426;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;50.0;5.0;00;00;15.9;6.7;22.7;26.2;8.6;Cadastre;A 1.0;POLYGON Z ((354124.3 6688952.2 22.7, 354124.9 6688953.5 22.7, 354122.7 6688954.5 22.7, 354119.8 6688955.8 22.7, 354119.1 6688954.3 22.7, 354105.9 6688960.8 22.7, 354111.7 6688972.4 22.7, 354117.4 6688969.7 22.7, 354122.2 6688967.1 22.7, 354138.3 6688959.2 22.7, 354145.9 6688955.5 22.7, 354145.6 6688955.2 22.7, 354146.7 6688952 22.7, 354149.4 6688952.9 22.7, 354149.6 6688952.9 22.7, 354149.8 6688952.9 22.7, 354149.9 6688952.8 22.7, 354150 6688952.7 22.7, 354150.1 6688952.6 22.7, 354150.2 6688952.5 22.7, 354150.3 6688952.4 22.7, 354150.3 6688952.3 22.7, 354150.3 6688952.1 22.7, 354150.3 6688952 22.7, 354150.2 6688951.9 22.7, 354150.1 6688951.7 22.7, 354149.9 6688951.6 22.7, 354149.9 6688951.5 22.7, 354147.2 6688950.6 22.7, 354148 6688947.9 22.7, 354148.8 6688947.6 22.7, 354145.5 6688940.7 22.7, 354140.2 6688929.9 22.7, 354130.4 6688934.9 22.7, 354128.5 6688935.7 22.7, 354132.2 6688943.2 22.7, 354132.7 6688944.2 22.7, 354133.3 6688943.9 22.7, 354133.8 6688944.8 22.7, 354132.6 6688948.5 22.7, 354132.4 6688948.9 22.7, 354131.5 6688949 22.7, 354131.2 6688948.6 22.7, 354130.7 6688948.8 22.7, 354124.3 6688952.2 22.7))
BATIMENT0000000302923432;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;8.0;21.7;23.2;8.5;Cadastre;;POLYGON Z ((354122.7 6688954.5 21.7, 354124.9 6688953.5 21.7, 354124.3 6688952.2 21.7, 354124.1 6688951.6 21.7, 354123.9 6688951.6 21.7, 354123.2 6688951.7 21.7, 354122.9 6688951.8 21.7, 354122.5 6688951.9 21.7, 354122.4 6688951.9 21.7, 354122 6688952 21.7, 354121.8 6688952.1 21.7, 354121.7 6688952.1 21.7, 354121.5 6688952.2 21.7, 354121.1 6688952.3 21.7, 354120.7 6688952.5 21.7, 354120.5 6688952.6 21.7, 354120.4 6688952.7 21.7, 354120.2 6688952.8 21.7, 354119.9 6688953 21.7, 354119.6 6688953.1 21.7, 354119.3 6688953.4 21.7, 354119 6688953.5 21.7, 354118.9 6688953.6 21.7, 354118.8 6688953.7 21.7, 354119.1 6688954.3 21.7, 354119.8 6688955.8 21.7, 354122.7 6688954.5 21.7))
BATIMENT0000000302923216;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;6.2;14.5;18.2;6.7;Cadastre;;POLYGON Z ((354244.9 6688921.8 14.5, 354246.4 6688922 14.5, 354249.7 6688904.8 14.5, 354248.2 6688904.6 14.5, 354244.9 6688921.8 14.5))
BATIMENT0000000302923028;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;12.1;6.6;18.7;26.2;7.3;Cadastre;A 1.0;POLYGON Z ((354204.2 6688941.5 18.7, 354217.3 6688943.7 18.7, 354221 6688922.6 18.7, 354197.1 6688917.9 18.7, 354193.1 6688939.5 18.7, 354204.2 6688941.5 18.7), (354202 6688923.2 18.7, 354203.7 6688923.4 18.7, 354203.4 6688925.1 18.7, 354206.7 6688925.7 18.7, 354204.4 6688937.4 18.7, 354199.3 6688936.5 18.7, 354202 6688923.2 18.7))
BATIMENT0000000302923397;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;4.8;8.3;10.3;7.5;Cadastre;;POLYGON Z ((354253.3 6688935.5 8.3, 354252.2 6688941.2 8.3, 354254.6 6688941.8 8.3, 354278.5 6688946.6 8.3, 354279.8 6688940.6 8.3, 354253.3 6688935.5 8.3))
BATIMENT0000000302923361;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;6.5;14.0;22.7;7.0;Cadastre;A 1.0;POLYGON Z ((354189.8 6688956.7 14, 354200.9 6688958.7 14, 354202.4 6688950.8 14, 354200.9 6688950.6 14, 354200.7 6688952.5 14, 354197.7 6688952.1 14, 354199 6688946.2 14, 354200.8 6688946.6 14, 354201.1 6688945.7 14, 354203.4 6688946.1 14, 354204.2 6688941.5 14, 354193.1 6688939.5 14, 354189.8 6688956.7 14))
BATIMENT0000000302923360;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;10;20;15.5;6.8;22.3;26.6;7.3;Cadastre;A 1.0;POLYGON Z ((354214 6688961.2 22.3, 354217.3 6688943.7 22.3, 354204.2 6688941.5 22.3, 354203.4 6688946.1 22.3, 354202.4 6688950.8 22.3, 354200.9 6688958.7 22.3, 354214 6688961.2 22.3))
BATIMENT0000000302923400;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;54.0;7.0;00;00;13.7;6.7;20.5;26.2;7.4;Cadastre;A 1.0;POLYGON Z ((354234.4 6688941.3 20.5, 354233.1 6688941 20.5, 354232.9 6688941.7 20.5, 354229.4 6688959.5 20.5, 354230.6 6688959.8 20.5, 354230 6688963.2 20.5, 354234.8 6688964.2 20.5, 354234.5 6688965.4 20.5, 354266.2 6688971.5 20.5, 354273.5 6688972.9 20.5, 354276.1 6688959.5 20.5, 354249.2 6688954.2 20.5, 354243.7 6688953.1 20.5, 354244 6688951.4 20.5, 354245.3 6688951.7 20.5, 354246.3 6688946.4 20.5, 354245 6688946.1 20.5, 354246.2 6688940.2 20.5, 354241.1 6688939.2 20.5, 354240.1 6688939 20.5, 354235 6688938 20.5, 354234.4 6688941.3 20.5))
BATIMENT0000000302923506;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;00;00;13.9;6.6;20.5;23.4;7.5;Cadastre;A 1.0;POLYGON Z ((354212.1 6688970.9 20.5, 354211.6 6688970.1 20.5, 354206.2 6688969.1 20.5, 354206.1 6688969.6 20.5, 354188.1 6688965.9 20.5, 354186.6 6688976.5 20.5, 354190 6688977.1 20.5, 354189.8 6688977.9 20.5, 354193.2 6688978.6 20.5, 354194.2 6688978.2 20.5, 354194.8 6688976.1 20.5, 354198.9 6688976.9 20.5, 354198.7 6688978.1 20.5, 354197.6 6688979.1 20.5, 354198.3 6688979.8 20.5, 354197.9 6688982.5 20.5, 354196.5 6688983 20.5, 354194.4 6688982.8 20.5, 354193.6 6688985.8 20.5, 354208.7 6688988.7 20.5, 354212.1 6688970.9 20.5))
BATIMENT0000000302923516;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;14.0;6.6;20.6;23.7;7.0;Cadastre;A 0.8;POLYGON Z ((354232.6 6688975 20.6, 354232.7 6688974.5 20.6, 354227.4 6688973.4 20.6, 354226.9 6688974 20.6, 354223.8 6688991.4 20.6, 354236 6688993.7 20.6, 354237.7 6688985.1 20.6, 354241.6 6688985.6 20.6, 354243.3 6688977 20.6, 354232.6 6688975 20.6))
BATIMENT0000000302923512;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;4.4;7.0;11.4;14.2;7.1;Cadastre;A 1.0;POLYGON Z ((354250.2 6688992.3 11.4, 354250.3 6688992.3 11.4, 354250.6 6688990.3 11.4, 354251.5 6688985.9 11.4, 354252.9 6688978.9 11.4, 354243.3 6688977 11.4, 354241.6 6688985.6 11.4, 354241.4 6688986.9 11.4, 354240.1 6688993.2 11.4, 354239.8 6688994.4 11.4, 354239.1 6688998.2 11.4, 354248.8 6688999.9 11.4, 354250.2 6688992.3 11.4))
BATIMENT0000000302923517;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.8;7.0;14.8;;;Cadastre;;POLYGON Z ((354241.4 6688986.9 14.8, 354239.3 6688986.7 14.8, 354238 6688992.8 14.8, 354240.1 6688993.2 14.8, 354241.4 6688986.9 14.8))
BATIMENT0000000302923402;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;19;20;8.5;9.7;18.2;20.4;11.8;Cadastre;C 0.9;POLYGON Z ((354315.2 6688937.4 18.2, 354318.2 6688938.3 18.2, 354319 6688937.7 18.2, 354322.9 6688940.1 18.2, 354328.1 6688931.1 18.2, 354320.5 6688924.9 18.2, 354317.3 6688936.1 18.2, 354315.9 6688935.9 18.2, 354315.2 6688937.4 18.2))
BATIMENT0000000302923498;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;5.7;11.1;16.9;20.4;12.6;Cadastre;A 1.0;POLYGON Z ((354340.7 6688939.6 16.9, 354340.7 6688939.1 16.9, 354332.9 6688933.2 16.9, 354329.8 6688938 16.9, 354337 6688944 16.9, 354340.7 6688939.6 16.9))
BATIMENT0000000302923396;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;4.8;8.6;10.9;6.7;Cadastre;;POLYGON Z ((354284.5 6688962.5 8.6, 354289.8 6688963.7 8.6, 354299.1 6688926.2 8.6, 354292.4 6688920.8 8.6, 354284.5 6688962.5 8.6))
BATIMENT0000000302923398;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.9;6.2;12.1;12.7;7.5;Cadastre;C 0.2;POLYGON Z ((354279.8 6688940.6 12.1, 354278.5 6688946.6 12.1, 354277.7 6688951.5 12.1, 354282.5 6688952.2 12.1, 354285.1 6688939.8 12.1, 354280.1 6688938.9 12.1, 354279.8 6688940.6 12.1))
BATIMENT0000000302923404;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;8.9;13.0;14.5;10.9;Cadastre;;POLYGON Z ((354308.9 6688944 13, 354305.8 6688949.1 13, 354314.8 6688954.1 13, 354322.3 6688941.2 13, 354314.7 6688938.3 13, 354312.4 6688942.6 13, 354307.2 6688941.1 13, 354306.5 6688943.4 13, 354308.9 6688944 13))
BATIMENT0000000302923403;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;5.8;5.9;11.8;15.5;9.8;Cadastre;A 1.0;POLYGON Z ((354290.5 6688976.2 11.8, 354298.6 6688977.9 11.8, 354300.8 6688968.3 11.8, 354302 6688962.1 11.8, 354303 6688956.3 11.8, 354305.2 6688947.7 11.8, 354306.5 6688943.4 11.8, 354307.2 6688941.1 11.8, 354309.3 6688934.2 11.8, 354301.7 6688932.3 11.8, 354290.5 6688976.2 11.8))
BATIMENT0000000302923496;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.8;9.4;14.2;18.7;13.2;Cadastre;A 1.0;POLYGON Z ((354318.5 6688982.2 14.2, 354320 6688982.6 14.2, 354324.1 6688983.8 14.2, 354326.4 6688974.3 14.2, 354330.7 6688956.7 14.2, 354332.7 6688949.1 14.2, 354337 6688944 14.2, 354329.8 6688938 14.2, 354326.1 6688944.8 14.2, 354328.6 6688947 14.2, 354324.6 6688952.4 14.2, 354325.6 6688953.1 14.2, 354318.5 6688982.2 14.2))
BATIMENT0000000302923401;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.0;4.8;11.8;16.2;7.5;Cadastre;;POLYGON Z ((354285.6 6688975.1 11.8, 354287.9 6688965.6 11.8, 354280 6688964.2 11.8, 354282.5 6688952.2 11.8, 354277.7 6688951.5 11.8, 354276.1 6688959.5 11.8, 354273.5 6688972.9 11.8, 354285.6 6688975.1 11.8))
BATIMENT0000000302923405;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;7.4;12.0;18.2;9.3;Cadastre;;POLYGON Z ((354308.3 6688970.4 12, 354310.5 6688971.3 12, 354313.5 6688966.3 12, 354313.8 6688965.9 12, 354302 6688962.1 12, 354300.8 6688968.3 12, 354305.8 6688969.5 12, 354308.3 6688970.4 12))
BATIMENT0000000302923513;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;6.2;10.7;12.5;6.8;Cadastre;;POLYGON Z ((354279.3 6688985.5 10.7, 354279.6 6688984.1 10.7, 354279.2 6688984 10.7, 354263.3 6688980.9 10.7, 354263.1 6688982.2 10.7, 354279.3 6688985.5 10.7))
BATIMENT0000000302923430;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;6.6;21.7;22.2;7.1;Cadastre;;POLYGON Z ((354146.7 6688952 21.7, 354145.6 6688955.2 21.7, 354145.9 6688955.5 21.7, 354149.6 6688953.7 21.7, 354149.4 6688952.9 21.7, 354146.7 6688952 21.7))
BATIMENT0000000302923503;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;64.0;7.0;00;00;16.9;6.5;23.4;27.2;7.3;Cadastre;A 1.0;POLYGON Z ((354162.1 6688959.6 23.4, 354161.8 6688961.3 23.4, 354161.4 6688961.3 23.4, 354161 6688961.3 23.4, 354160.8 6688961.3 23.4, 354160.4 6688961.3 23.4, 354159.9 6688961.3 23.4, 354159.7 6688961.4 23.4, 354159.3 6688961.5 23.4, 354158.7 6688961.7 23.4, 354158.3 6688961.9 23.4, 354158.1 6688962 23.4, 354157.8 6688962.2 23.4, 354157.3 6688962.6 23.4, 354157.1 6688962.7 23.4, 354156.8 6688963 23.4, 354156.5 6688963.3 23.4, 354156.4 6688963.5 23.4, 354156.3 6688963.7 23.4, 354156 6688964 23.4, 354155.8 6688964.5 23.4, 354154.7 6688970.7 23.4, 354159.9 6688971.7 23.4, 354164.7 6688972.5 23.4, 354163.1 6688980.6 23.4, 354165.4 6688981 23.4, 354164.2 6688987.1 23.4, 354176.1 6688989.2 23.4, 354180.3 6688967.1 23.4, 354177.3 6688966.4 23.4, 354178 6688962.8 23.4, 354178 6688962.7 23.4, 354162.1 6688959.6 23.4))
BATIMENT0000000302923504;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.2;7.1;22.3;23.5;8.6;Cadastre;C 0.3;POLYGON Z ((354125.4 6689001.5 22.3, 354122.9 6688996.4 22.3, 354123.5 6688994.5 22.3, 354124.9 6688995.8 22.3, 354126 6688995.6 22.3, 354126.4 6688994.9 22.3, 354127.2 6688991.7 22.3, 354129.6 6688990.5 22.3, 354129.1 6688989.5 22.3, 354133.7 6688987.5 22.3, 354138.6 6688997.4 22.3, 354145.9 6688994 22.3, 354144.2 6688990.4 22.3, 354144.6 6688988.8 22.3, 354146.8 6688987.3 22.3, 354145.1 6688983.8 22.3, 354145.7 6688982.1 22.3, 354148.2 6688980.5 22.3, 354144 6688972.1 22.3, 354141.7 6688973.3 22.3, 354140.3 6688972.6 22.3, 354109.9 6688988.1 22.3, 354114.9 6688998.3 22.3, 354118.3 6689005.2 22.3, 354125.4 6689001.5 22.3))
BATIMENT0000000302923502;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;14.1;6.4;20.5;23.5;7.2;Cadastre;A 1.0;POLYGON Z ((354161.9 6688989 20.5, 354166.3 6688990 20.5, 354165.4 6688995.6 20.5, 354165.1 6688997.4 20.5, 354163.9 6688997.1 20.5, 354161.8 6689008.4 20.5, 354163.4 6689008.9 20.5, 354162.7 6689013 20.5, 354162.3 6689014.6 20.5, 354162.9 6689014.7 20.5, 354170.9 6689016.5 20.5, 354176.1 6688989.2 20.5, 354164.2 6688987.1 20.5, 354162.1 6688986.8 20.5, 354161.9 6688989 20.5))
BATIMENT0000000029198570;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:27;;;;;BDTopo;2.5;BDTopo;1.5;;;;;2.3;7.6;;10.2;8.5;Imagerie aérienne;;POLYGON Z ((354149.7 6689002.5 9.9, 354150.6 6688997.4 9.9, 354145.8 6688996.6 9.9, 354144.2 6689006.8 9.9, 354148.8 6689007.6 9.9, 354149.7 6689002.5 9.9))
BATIMENT0000000302927441;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;6.4;9.0;9.6;8.4;Cadastre;;POLYGON Z ((354150.8 6689010.1 9, 354152.2 6689003 9, 354149.7 6689002.5 9, 354148.8 6689007.6 9, 354148.4 6689009.6 9, 354150.8 6689010.1 9))
BATIMENT0000000302927442;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;8.3;7.2;15.5;16.9;8.6;Cadastre;A 1.0;POLYGON Z ((354160 6689012.5 15.5, 354148.4 6689010.5 15.5, 354147.5 6689016 15.5, 354161.7 6689018.7 15.5, 354162.1 6689018.7 15.5, 354162.9 6689014.7 15.5, 354162.3 6689014.6 15.5, 354162.7 6689013 15.5, 354160 6689012.5 15.5))
BATIMENT0000000302928982;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;20;20;9.9;7.6;17.5;21.0;7.6;Cadastre;A 1.0;POLYGON Z ((354169.5 6689024 17.5, 354161.2 6689022.2 17.5, 354159.3 6689032.6 17.5, 354167.7 6689034.3 17.5, 354169.5 6689024 17.5))
BATIMENT0000000302928981;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;12.7;6.5;19.3;21.3;7.7;Cadastre;A 1.0;POLYGON Z ((354157 6689047.5 19.3, 354161.3 6689050.3 19.3, 354165.3 6689043.9 19.3, 354165.9 6689044 19.3, 354167.7 6689034.3 19.3, 354159.3 6689032.6 19.3, 354157 6689047.5 19.3))
BATIMENT0000000029198405;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2002-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;2.4;9.0;;;;Imagerie aérienne;C 0.2;POLYGON Z ((354103.2 6689052.2 11.4, 354103.6 6689053.9 11.4, 354133.6 6689039.4 11.4, 354130.6 6689033.9 11.4, 354105.8 6689046.4 11.4, 354100 6689047.3 11.4, 354080 6689057.3 11.4, 354082.9 6689062.7 11.4, 354103.2 6689052.2 11.4))
BATIMENT0000000302923508;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;6.3;12.2;15.4;6.9;Cadastre;;POLYGON Z ((354263.1 6688982.2 12.2, 354262.5 6688986.4 12.2, 354261.3 6688992.1 12.2, 354276.7 6688995.1 12.2, 354276.4 6688997.1 12.2, 354280.8 6688997.9 12.2, 354282.8 6688986.2 12.2, 354279.3 6688985.5 12.2, 354263.1 6688982.2 12.2))
BATIMENT0000000302923515;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;6.3;10.7;11.2;6.7;Cadastre;;POLYGON Z ((354284.5 6688986.6 10.7, 354282.8 6688986.2 10.7, 354280.8 6688997.9 10.7, 354282.1 6688998.2 10.7, 354284.5 6688986.6 10.7))
BATIMENT0000000302923507;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;6.4;10.2;11.5;6.9;Cadastre;;POLYGON Z ((354276.4 6688997.1 10.2, 354276.7 6688995.1 10.2, 354261.3 6688992.1 10.2, 354261 6688994 10.2, 354276.4 6688997.1 10.2))
BATIMENT0000000302923500;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;11.1;16.5;17.4;13.3;Cadastre;;POLYGON Z ((354334.1 6688989.2 16.5, 354329.5 6688987.8 16.5, 354321 6689017.3 16.5, 354325.3 6689018.6 16.5, 354334.1 6688989.2 16.5))
BATIMENT0000000302923510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;6.8;;;;Cadastre;;POLYGON Z ((354276.4 6688997.1 -1000, 354273.8 6689010.8 -1000, 354278.4 6689011.6 -1000, 354279.8 6689011.8 -1000, 354282.1 6688998.2 -1000, 354280.8 6688997.9 -1000, 354276.4 6688997.1 -1000))
BATIMENT0000000302923564;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.2;8.5;14.7;33.6;15.8;Cadastre;C 0.1;POLYGON Z ((354308 6689020 14.7, 354319.3 6689022.6 14.7, 354319.4 6689022.7 14.7, 354319.9 6689021.1 14.7, 354324.3 6689022.5 14.7, 354349 6689029.9 14.7, 354359.1 6688994.2 14.7, 354344.3 6688990 14.7, 354335.4 6689021.4 14.7, 354333.5 6689020.9 14.7, 354329.1 6689019.7 14.7, 354325.3 6689018.6 14.7, 354321 6689017.3 14.7, 354329.5 6688987.8 14.7, 354334.1 6688989.2 14.7, 354334.7 6688987 14.7, 354324.1 6688983.8 14.7, 354320 6688982.6 14.7, 354316.9 6688993 14.7, 354318.2 6688993.3 14.7, 354315.9 6689000.8 14.7, 354314.9 6689000.5 14.7, 354314.2 6689003.1 14.7, 354315.3 6689003.3 14.7, 354313.4 6689009.5 14.7, 354312.2 6689009 14.7, 354309.3 6689019.4 14.7, 354306.3 6689018.4 14.7, 354306.3 6689018.8 14.7, 354306 6689018.9 14.7, 354308 6689020 14.7))
BATIMENT0000000302927445;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;6.6;9.6;10.2;7.1;Cadastre;;POLYGON Z ((354273.3 6689013.4 9.6, 354278 6689014.3 9.6, 354278.4 6689011.6 9.6, 354273.8 6689010.8 9.6, 354273.3 6689013.4 9.6))
BATIMENT0000000302927444;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;6.6;9.5;10.0;7.2;Cadastre;;POLYGON Z ((354279.4 6689014.5 9.5, 354279.8 6689011.8 9.5, 354278.4 6689011.6 9.5, 354278 6689014.3 9.5, 354279.4 6689014.5 9.5))
BATIMENT0000000302929168;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.8;7.5;12.3;15.3;11.2;Cadastre;C 0.1;POLYGON Z ((354315.7 6689034.6 12.3, 354319.4 6689022.7 12.3, 354319.3 6689022.6 12.3, 354308 6689020 12.3, 354306 6689018.9 12.3, 354303.5 6689020.2 12.3, 354303.1 6689020 12.3, 354300.2 6689030.5 12.3, 354315.7 6689034.6 12.3))
BATIMENT0000000302927430;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;5.0;00;00;11.4;11.4;22.9;32.5;16.1;Cadastre;A 1.0;POLYGON Z ((354320.4 6689035.9 22.9, 354318.3 6689043.4 22.9, 354322 6689044.4 22.9, 354318 6689057.3 22.9, 354320.4 6689058 22.9, 354329.1 6689060.5 22.9, 354339.4 6689063.5 22.9, 354345.3 6689042.4 22.9, 354349 6689029.9 22.9, 354324.3 6689022.5 22.9, 354320.4 6689035.9 22.9))
BATIMENT0000000302923509;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;2.7;7.0;9.7;13.1;7.1;Cadastre;A 1.0;POLYGON Z ((354253.3 6689000.8 9.7, 354252.7 6689003.2 9.7, 354252.5 6689004.4 9.7, 354255.7 6689004.9 9.7, 354256.2 6689002 9.7, 354259.2 6689002.5 9.7, 354261 6688994 9.7, 354261.3 6688992.1 9.7, 354262.5 6688986.4 9.7, 354263.1 6688982.2 9.7, 354263.3 6688980.9 9.7, 354258.6 6688979.9 9.7, 354257.3 6688979.8 9.7, 354252.9 6688978.9 9.7, 354251.5 6688985.9 9.7, 354255.6 6688986.7 9.7, 354254.3 6688993.1 9.7, 354250.3 6688992.3 9.7, 354250.2 6688992.3 9.7, 354248.8 6688999.9 9.7, 354253.3 6689000.8 9.7))
BATIMENT0000000302923511;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;6.3;10.2;11.7;6.7;Cadastre;;POLYGON Z ((354238.3 6689000.6 10.2, 354252.7 6689003.2 10.2, 354253.3 6689000.8 10.2, 354248.8 6688999.9 10.2, 354239.1 6688998.2 10.2, 354238.9 6688998.2 10.2, 354238.3 6689000.6 10.2))
BATIMENT0000000302923518;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;10;20;15.3;6.4;21.8;24.6;7.2;Cadastre;C 0.9;POLYGON Z ((354220.5 6689009.3 21.8, 354236.6 6689012.4 21.8, 354237.4 6689008.5 21.8, 354232.8 6689007.5 21.8, 354234.8 6688997.5 21.8, 354238.9 6688998.2 21.8, 354239.1 6688998.2 21.8, 354239.8 6688994.4 21.8, 354236 6688993.7 21.8, 354223.8 6688991.4 21.8, 354220.5 6689009.3 21.8))
BATIMENT0000000302927443;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;6.5;9.7;10.8;7.0;Cadastre;;POLYGON Z ((354258.6 6689005.4 9.7, 354255.7 6689004.9 9.7, 354252.5 6689004.4 9.7, 354251.9 6689006.9 9.7, 354251.4 6689009.5 9.7, 354251.4 6689009.6 9.7, 354262.4 6689011.5 9.7, 354263.5 6689006.4 9.7, 354258.6 6689005.4 9.7))
BATIMENT0000000302927446;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;6.5;10.4;11.1;6.9;Cadastre;;POLYGON Z ((354249.1 6689009.1 10.4, 354251.4 6689009.5 10.4, 354251.9 6689006.9 10.4, 354249.5 6689006.8 10.4, 354249.1 6689009.1 10.4))
BATIMENT0000000302927447;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.0;6.1;20.1;21.3;7.0;Cadastre;;POLYGON Z ((354220.5 6689013.1 20.1, 354221.1 6689010.7 20.1, 354220.2 6689010.5 20.1, 354219.7 6689012.9 20.1, 354219.8 6689012.9 20.1, 354220.5 6689013.1 20.1))
BATIMENT0000000302927448;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;46.0;6.0;00;00;7.0;6.6;13.6;24.7;7.2;Cadastre;A 1.0;POLYGON Z ((354241.2 6689030.5 13.6, 354241.6 6689028.4 13.6, 354244.1 6689028.8 13.6, 354243.9 6689029.8 13.6, 354244.6 6689029.9 13.6, 354245.3 6689030.9 13.6, 354245.2 6689031.3 13.6, 354247.1 6689031.6 13.6, 354249.7 6689019.1 13.6, 354237.5 6689016.5 13.6, 354238.3 6689012.7 13.6, 354236.6 6689012.4 13.6, 354220.5 6689009.3 13.6, 354220.2 6689010.5 13.6, 354221.1 6689010.7 13.6, 354220.5 6689013.1 13.6, 354219.8 6689012.9 13.6, 354219.7 6689012.9 13.6, 354219.5 6689014.3 13.6, 354218.9 6689017.7 13.6, 354219.5 6689017.9 13.6, 354219.4 6689018 13.6, 354219.2 6689018.4 13.6, 354219.2 6689018.5 13.6, 354219.1 6689018.8 13.6, 354219.1 6689019 13.6, 354219 6689019.3 13.6, 354219 6689019.5 13.6, 354219 6689019.8 13.6, 354219 6689020.1 13.6, 354219.1 6689020.3 13.6, 354219.2 6689020.7 13.6, 354219.2 6689020.9 13.6, 354219.3 6689021.2 13.6, 354219.5 6689021.6 13.6, 354219.6 6689021.7 13.6, 354219.6 6689021.8 13.6, 354219.7 6689021.9 13.6, 354220 6689022.3 13.6, 354220.2 6689022.5 13.6, 354220.3 6689022.6 13.6, 354220.4 6689022.7 13.6, 354220.5 6689022.8 13.6, 354220.6 6689022.9 13.6, 354220.9 6689023.1 13.6, 354221.1 6689023.5 13.6, 354221.2 6689023.6 13.6, 354221.3 6689023.7 13.6, 354221.7 6689024.2 13.6, 354221.9 6689024.4 13.6, 354222 6689024.6 13.6, 354222.1 6689024.7 13.6, 354222.3 6689024.9 13.6, 354222.7 6689025.3 13.6, 354222.8 6689025.4 13.6, 354223 6689025.6 13.6, 354223.4 6689025.9 13.6, 354223.6 6689026 13.6, 354231.5 6689027.6 13.6, 354232.4 6689028.9 13.6, 354235.9 6689029.5 13.6, 354241.2 6689030.5 13.6))
BATIMENT0000000302927450;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.7;6.1;19.8;21.3;7.1;Cadastre;;POLYGON Z ((354231.5 6689027.6 19.8, 354223.6 6689026 19.8, 354223.4 6689025.9 19.8, 354223 6689025.6 19.8, 354222.8 6689025.4 19.8, 354222.7 6689025.3 19.8, 354222.3 6689024.9 19.8, 354222.1 6689024.7 19.8, 354222 6689024.6 19.8, 354221.9 6689024.4 19.8, 354221.7 6689024.2 19.8, 354221.3 6689023.7 19.8, 354221.2 6689023.6 19.8, 354221.1 6689023.5 19.8, 354220.9 6689023.1 19.8, 354220.6 6689022.9 19.8, 354220.5 6689022.8 19.8, 354220.4 6689022.7 19.8, 354220.3 6689022.6 19.8, 354220.2 6689022.5 19.8, 354220 6689022.3 19.8, 354219.7 6689021.9 19.8, 354219.6 6689021.8 19.8, 354219.6 6689021.7 19.8, 354219.5 6689021.6 19.8, 354219.3 6689021.2 19.8, 354219.2 6689020.9 19.8, 354219.2 6689020.7 19.8, 354219.1 6689020.3 19.8, 354219 6689020.1 19.8, 354219 6689019.8 19.8, 354219 6689019.5 19.8, 354219 6689019.3 19.8, 354219.1 6689019 19.8, 354219.1 6689018.8 19.8, 354219.2 6689018.5 19.8, 354219.2 6689018.4 19.8, 354219.4 6689018 19.8, 354219.5 6689017.9 19.8, 354218.9 6689017.7 19.8, 354217.1 6689026.1 19.8, 354232.4 6689028.9 19.8, 354231.5 6689027.6 19.8))
BATIMENT0000000302923505;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;78.0;7.0;30;40;11.0;6.7;17.7;31.4;7.3;Cadastre;A 1.0;POLYGON Z ((354187 6688984.4 17.7, 354174.7 6689051 17.7, 354185.6 6689053.1 17.7, 354185 6689056.1 17.7, 354184.3 6689056.1 17.7, 354181.6 6689070.3 17.7, 354186.8 6689071.1 17.7, 354186.5 6689072.1 17.7, 354193 6689073.3 17.7, 354208.7 6688988.7 17.7, 354193.6 6688985.8 17.7, 354187 6688984.4 17.7))
BATIMENT0000000302927451;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;55.0;3.0;20;20;8.5;5.8;14.4;17.9;7.5;Cadastre;A 1.0;POLYGON Z ((354271.2 6689023.2 14.4, 354271.7 6689021 14.4, 354265.2 6689019.8 14.4, 354264.9 6689021.9 14.4, 354249.7 6689019.1 14.4, 354247.1 6689031.6 14.4, 354285.8 6689039 14.4, 354288.2 6689026.4 14.4, 354271.2 6689023.2 14.4))
BATIMENT0000000302927449;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.4;12.7;12.7;6.8;Cadastre;;POLYGON Z ((354245.3 6689030.9 12.7, 354244.6 6689029.9 12.7, 354243.9 6689029.8 12.7, 354244.1 6689028.8 12.7, 354241.6 6689028.4 12.7, 354241.2 6689030.5 12.7, 354245.2 6689031.3 12.7, 354245.3 6689030.9 12.7))
BATIMENT0000000302928727;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.1;6.7;15.8;;;Cadastre;;POLYGON Z ((354259.4 6689042.1 15.8, 354256.6 6689041.6 15.8, 354256.4 6689042.7 15.8, 354261.5 6689043.8 15.8, 354261.7 6689043 15.8, 354261.8 6689042.6 15.8, 354259.4 6689042.1 15.8))
BATIMENT0000000302928728;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.9;7.1;21.0;21.9;7.2;Cadastre;;POLYGON Z ((354213 6689043.8 21, 354214.5 6689044 21, 354214.8 6689042.1 21, 354213.4 6689041.8 21, 354213 6689043.8 21))
BATIMENT0000000302928725;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;4.0;00;00;12.0;5.8;17.8;21.1;7.8;Cadastre;C 0.7;POLYGON Z ((354260.7 6689057.8 17.8, 354260.3 6689059.4 17.8, 354265.8 6689060.5 17.8, 354265.6 6689062.1 17.8, 354278.6 6689064.5 17.8, 354279.3 6689059.9 17.8, 354279.9 6689060.1 17.8, 354282.3 6689047.6 17.8, 354279.3 6689047.1 17.8, 354279.3 6689046.4 17.8, 354273.3 6689045.2 17.8, 354273.1 6689046.1 17.8, 354267.7 6689045 17.8, 354267.8 6689044.2 17.8, 354261.7 6689043 17.8, 354261.5 6689043.8 17.8, 354256.4 6689042.7 17.8, 354256.6 6689041.6 17.8, 354250.8 6689040.5 17.8, 354248.5 6689053.9 17.8, 354252.9 6689054.7 17.8, 354252.7 6689056.3 17.8, 354260.7 6689057.8 17.8))
BATIMENT0000000302928724;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.5;7.1;17.6;17.8;7.9;Cadastre;;POLYGON Z ((354248.2 6689055.5 17.6, 354252.7 6689056.3 17.6, 354252.9 6689054.7 17.6, 354248.5 6689053.9 17.6, 354248.3 6689054.8 17.6, 354248.2 6689055.5 17.6))
BATIMENT0000000302928726;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;71.0;6.0;00;00;17.2;6.6;23.9;26.8;8.2;Cadastre;A 1.0;POLYGON Z ((354210.1 6689060 23.9, 354209.1 6689064.9 23.9, 354209.2 6689064.9 23.9, 354210.7 6689065.1 23.9, 354210.4 6689066.9 23.9, 354209.9 6689069.6 23.9, 354209.1 6689069.5 23.9, 354208.6 6689072 23.9, 354208.6 6689072.1 23.9, 354207.6 6689077.3 23.9, 354206.8 6689077.1 23.9, 354206.8 6689077.4 23.9, 354221.4 6689080.2 23.9, 354222.5 6689074.9 23.9, 354223.2 6689071.1 23.9, 354221.3 6689070.7 23.9, 354221.9 6689067.7 23.9, 354223.8 6689068 23.9, 354224.8 6689062.6 23.9, 354222.9 6689062.2 23.9, 354224 6689057 23.9, 354229.7 6689058 23.9, 354231.4 6689048.7 23.9, 354235.9 6689049.5 23.9, 354235.4 6689052.1 23.9, 354242.1 6689053.2 23.9, 354241.8 6689054.8 23.9, 354248.1 6689055.9 23.9, 354248.2 6689055.5 23.9, 354248.3 6689054.8 23.9, 354248.5 6689053.9 23.9, 354250.8 6689040.5 23.9, 354214.9 6689033.7 23.9, 354213.9 6689039.1 23.9, 354215.3 6689039.4 23.9, 354214.8 6689042.1 23.9, 354214.5 6689044 23.9, 354213 6689043.8 23.9, 354210.1 6689060 23.9))
BATIMENT0000000302928729;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.5;7.0;20.5;22.0;7.2;Cadastre;;POLYGON Z ((354210.7 6689065.1 20.5, 354209.2 6689064.9 20.5, 354209.1 6689064.9 20.5, 354208.8 6689066.6 20.5, 354210.4 6689066.9 20.5, 354210.7 6689065.1 20.5))
BATIMENT0000000302928992;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;6.4;15.0;16.7;7.8;Cadastre;;POLYGON Z ((354246.3 6689080.7 15, 354246.7 6689079 15, 354244.1 6689078.6 15, 354243.8 6689080.2 15, 354246.3 6689080.7 15))
BATIMENT0000000302928990;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;6.4;14.9;17.5;6.8;Cadastre;;POLYGON Z ((354267.1 6689084.3 14.9, 354267.4 6689082.7 14.9, 354264.3 6689082.1 14.9, 354264 6689083.6 14.9, 354267.1 6689084.3 14.9))
BATIMENT0000000302928730;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;;;13.6;6.7;20.3;22.8;7.8;Cadastre;A 1.0;POLYGON Z ((354206 6689081.9 20.3, 354209.3 6689086.9 20.3, 354237.2 6689092.5 20.3, 354238.7 6689084.5 20.3, 354238.9 6689083.5 20.3, 354221.4 6689080.2 20.3, 354206.8 6689077.4 20.3, 354206 6689081.9 20.3))
BATIMENT0000000302927431;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;13.6;13.3;27.0;31.0;15.9;Cadastre;A 1.0;POLYGON Z ((354326.7 6689068.6 27, 354327.2 6689068.7 27, 354337.3 6689071.5 27, 354339.4 6689063.5 27, 354329.1 6689060.5 27, 354326.7 6689068.6 27))
BATIMENT0000000302927432;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;11.7;12.9;24.6;26.7;15.8;Cadastre;A 1.0;POLYGON Z ((354325.1 6689075.8 24.6, 354324.1 6689075.5 24.6, 354322.5 6689076.3 24.6, 354321.5 6689080.1 24.6, 354322.2 6689080.6 24.6, 354321.9 6689081.6 24.6, 354323.4 6689082.1 24.6, 354322.8 6689084 24.6, 354332.9 6689086.6 24.6, 354337.3 6689071.5 24.6, 354327.2 6689068.7 24.6, 354325.1 6689075.8 24.6))
BATIMENT0000002275362611;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;17.8;8.7;;;;Imagerie aérienne;;POLYGON Z ((354322.8 6689084 24.6, 354322.4 6689085.9 25.9, 354320.1 6689085.2 25.9, 354318 6689093.2 25.9, 354313.2 6689091.9 25.9, 354311.9 6689096 25.9, 354309.4 6689095.3 26.1, 354307.7 6689101.3 26.3, 354310 6689101.9 26.5, 354307.7 6689110 26.5, 354311.1 6689110.9 26.5, 354319.4 6689113.2 26.5, 354324.9 6689114.8 26.5, 354332.2 6689086.4 26.5, 354322.8 6689084 24.6))
BATIMENT0000000302928720;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;7.9;14.1;14.1;9.6;Cadastre;;POLYGON Z ((354269.3 6689111.9 14.1, 354266.6 6689122.2 14.1, 354277.4 6689125.2 14.1, 354282.9 6689103.3 14.1, 354276.8 6689101.7 14.1, 354272.8 6689105.7 14.1, 354268.2 6689110.5 14.1, 354269.3 6689111.9 14.1))
BATIMENT0000000302927437;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.9;9.7;19.6;25.4;15.2;Cadastre;;POLYGON Z ((354321 6689123.2 19.6, 354322.4 6689123.6 19.6, 354324.9 6689114.8 19.6, 354319.4 6689113.2 19.6, 354311.1 6689110.9 19.6, 354308.6 6689119.9 19.6, 354321 6689123.2 19.6))
BATIMENT0000000302927439;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;10.5;16.2;19.4;15.1;Cadastre;;POLYGON Z ((354320 6689127.1 16.2, 354321.3 6689127.5 16.2, 354322.4 6689123.6 16.2, 354321 6689123.2 16.2, 354320 6689127.1 16.2))
BATIMENT0000000302927438;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.8;9.4;18.2;21.5;13.5;Cadastre;;POLYGON Z ((354302.8 6689108.6 18.2, 354301.7 6689112 18.2, 354301.2 6689111.8 18.2, 354289.1 6689153.8 18.2, 354290 6689153.9 18.2, 354288.4 6689159.3 18.2, 354296.6 6689159.9 18.2, 354296.6 6689159.8 18.2, 354300 6689148.7 18.2, 354308.6 6689119.9 18.2, 354311.1 6689110.9 18.2, 354305.4 6689109.3 18.2, 354302.8 6689108.6 18.2))
BATIMENT0000000302927440;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.2;9.9;19.1;22.6;14.8;Cadastre;;POLYGON Z ((354311.7 6689160.9 19.1, 354314.1 6689152.5 19.1, 354300 6689148.7 19.1, 354296.6 6689159.8 19.1, 354296.6 6689159.9 19.1, 354311.7 6689160.9 19.1))
BATIMENT0000000302928695;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;12.3;23.7;27.2;13.6;Cadastre;;POLYGON Z ((354286.8 6689171.2 23.7, 354287 6689169.2 23.7, 354281.7 6689168.9 23.7, 354281.5 6689170.8 23.7, 354286.8 6689171.2 23.7))
BATIMENT0000000302928696;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;42.0;7.0;00;00;17.2;13.4;30.6;35.5;18.7;Cadastre;A 1.0;POLYGON Z ((354290.9 6689183.9 30.6, 354297.3 6689184.4 30.6, 354297.2 6689185.7 30.6, 354331.1 6689187.6 30.6, 354331 6689188.9 30.6, 354346.8 6689189.9 30.6, 354347.2 6689173.2 30.6, 354326.5 6689171.8 30.6, 354326.5 6689171.9 30.6, 354326.4 6689173.2 30.6, 354323.9 6689173.1 30.6, 354323.8 6689174.2 30.6, 354320.1 6689174 30.6, 354314.6 6689173.6 30.6, 354310.5 6689173.4 30.6, 354310.6 6689172.2 30.6, 354308.1 6689172 30.6, 354308.2 6689170.6 30.6, 354293.3 6689169.6 30.6, 354287 6689169.2 30.6, 354286.8 6689171.2 30.6, 354281.5 6689170.8 30.6, 354280.6 6689178.6 30.6, 354280.4 6689180.4 30.6, 354286.1 6689180.8 30.6, 354285.9 6689183.6 30.6, 354290.9 6689183.9 30.6))
BATIMENT0000000302923269;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;3.0;19;20;7.2;11.5;18.8;21.9;14.7;Cadastre;A 1.0;POLYGON Z ((354409.4 6688906.4 18.8, 354410.8 6688902.1 18.8, 354411.9 6688902.6 18.8, 354416.3 6688890.7 18.8, 354406.3 6688887.2 18.8, 354399 6688908.5 18.8, 354408.6 6688911.4 18.8, 354410.3 6688907.1 18.8, 354410.5 6688906.8 18.8, 354409.4 6688906.4 18.8))
BATIMENT0000000302923263;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;2.0;10;20;7.4;12.0;19.4;28.0;15.2;Cadastre;A 1.0;POLYGON Z ((354419.4 6688891.7 19.4, 354413.5 6688907.9 19.4, 354411.8 6688907.5 19.4, 354410.3 6688907.1 19.4, 354408.6 6688911.4 19.4, 354417.9 6688914.3 19.4, 354420.4 6688907.1 19.4, 354425.2 6688893.7 19.4, 354419.4 6688891.7 19.4))
BATIMENT0000000302923264;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;12.0;16.3;18.2;13.5;Cadastre;;POLYGON Z ((354411.9 6688902.6 16.3, 354410.8 6688902.1 16.3, 354409.4 6688906.4 16.3, 354410.5 6688906.8 16.3, 354410.8 6688905.9 16.3, 354411.9 6688902.6 16.3))
BATIMENT0000000302923265;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;12.2;17.7;18.7;13.5;Cadastre;;POLYGON Z ((354412.3 6688906.3 17.7, 354410.8 6688905.9 17.7, 354410.5 6688906.8 17.7, 354410.3 6688907.1 17.7, 354411.8 6688907.5 17.7, 354412.3 6688906.3 17.7))
BATIMENT0000000302923262;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;10;20;15.2;12.3;27.5;31.1;16.2;Cadastre;A 1.0;POLYGON Z ((354417.9 6688914.3 27.5, 354423.9 6688916.3 27.5, 354429.3 6688918.3 27.5, 354428.7 6688920 27.5, 354427.9 6688923.1 27.5, 354442.7 6688926.3 27.5, 354445.6 6688915.8 27.5, 354446.6 6688915.8 27.5, 354446.9 6688915.4 27.5, 354447.2 6688914.4 27.5, 354455.1 6688916.4 27.5, 354459.2 6688905.4 27.5, 354425.2 6688893.7 27.5, 354420.4 6688907.1 27.5, 354417.9 6688914.3 27.5), (354427.8 6688907.2 27.5, 354431.5 6688908.6 27.5, 354430.3 6688913.6 27.5, 354428.1 6688912.8 27.5, 354427.2 6688915.1 27.5, 354424.8 6688914.3 27.5, 354427 6688909.1 27.5, 354427.8 6688907.2 27.5))
BATIMENT0000000302923260;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;8.8;13.9;22.7;29.7;14.6;Cadastre;A 1.0;POLYGON Z ((354459.2 6688905.4 22.7, 354455.1 6688916.4 22.7, 354454 6688919.8 22.7, 354453.3 6688921.9 22.7, 354456.6 6688923.3 22.7, 354457.9 6688920.7 22.7, 354463 6688922.7 22.7, 354462.6 6688925.4 22.7, 354465.7 6688926.5 22.7, 354467.8 6688920.6 22.7, 354471.6 6688909.6 22.7, 354459.2 6688905.4 22.7))
BATIMENT0000000302923406;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;14.3;18.2;;;Cadastre;;POLYGON Z ((354453.3 6688921.9 18.2, 354452.6 6688924.1 18.2, 354455.1 6688925 18.2, 354456.6 6688923.3 18.2, 354453.3 6688921.9 18.2))
BATIMENT0000000302923407;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;14.3;17.0;19.9;14.8;Cadastre;;POLYGON Z ((354462.6 6688925.4 17, 354462.3 6688927.5 17, 354464.9 6688928.6 17, 354465.7 6688926.5 17, 354462.6 6688925.4 17))
BATIMENT0000000302923261;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;14.3;23.0;28.2;19.5;Cadastre;;POLYGON Z ((354454 6688919.8 23, 354451.1 6688919.1 23, 354448.1 6688927.5 23, 354442.7 6688926.3 23, 354427.9 6688923.1 23, 354424.2 6688921.9 23, 354425 6688919.6 23, 354426.4 6688919.2 23, 354428.7 6688920 23, 354429.3 6688918.3 23, 354423.9 6688916.3 23, 354418.5 6688929.3 23, 354426 6688932.2 23, 354426.2 6688930.9 23, 354436.2 6688933.1 23, 354435.5 6688936 23, 354446.7 6688940.3 23, 354450.5 6688929.8 23, 354452.6 6688924.1 23, 354453.3 6688921.9 23, 354454 6688919.8 23))
BATIMENT0000000302923408;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;9.4;16.2;25.6;26.7;19.5;Cadastre;C 0.3;POLYGON Z ((354450.5 6688929.8 25.6, 354446.7 6688940.3 25.6, 354459.2 6688944.5 25.6, 354462.1 6688936.4 25.6, 354462.8 6688934.4 25.6, 354450.5 6688929.8 25.6))
BATIMENT0000000302923531;Eglise;Religieux;;Non;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.8;14.6;29.4;;;Cadastre;;POLYGON Z ((354353.2 6688911.8 29.4, 354358.5 6688913.5 29.4, 354357.6 6688916 29.4, 354357.5 6688916.3 29.4, 354360.9 6688917.5 29.4, 354360.8 6688917.8 29.4, 354360.7 6688918.2 29.4, 354360.7 6688918.6 29.4, 354360.7 6688919 29.4, 354360.7 6688919.4 29.4, 354360.8 6688919.8 29.4, 354360.9 6688920.2 29.4, 354361 6688920.6 29.4, 354361.2 6688920.9 29.4, 354361.4 6688921.3 29.4, 354361.6 6688921.6 29.4, 354361.9 6688921.9 29.4, 354362.1 6688922.2 29.4, 354362.4 6688922.4 29.4, 354362.8 6688922.6 29.4, 354363.1 6688922.8 29.4, 354363.4 6688923 29.4, 354363.8 6688923.2 29.4, 354364.9 6688923.5 29.4, 354364.8 6688924 29.4, 354381.1 6688929.4 29.4, 354383.7 6688921.7 29.4, 354383.9 6688921.8 29.4, 354386.6 6688914 29.4, 354386.3 6688913.9 29.4, 354387.9 6688909.3 29.4, 354388.2 6688909.3 29.4, 354389.4 6688905.9 29.4, 354389.1 6688905.8 29.4, 354389.8 6688904 29.4, 354390 6688904 29.4, 354390.9 6688901.6 29.4, 354390.6 6688901.5 29.4, 354392.4 6688896.6 29.4, 354392.6 6688896.7 29.4, 354395.5 6688888.4 29.4, 354393.9 6688887.9 29.4, 354394.5 6688886.3 29.4, 354385.4 6688883.2 29.4, 354386 6688881.2 29.4, 354370.6 6688876 29.4, 354369.9 6688878 29.4, 354361 6688875 29.4, 354360.4 6688876.7 29.4, 354358.8 6688876.2 29.4, 354355.9 6688884.5 29.4, 354356.2 6688884.5 29.4, 354354.6 6688889.2 29.4, 354354.4 6688889.2 29.4, 354353.4 6688892.2 29.4, 354353.7 6688892.3 29.4, 354353.1 6688893.9 29.4, 354352.9 6688893.8 29.4, 354351.8 6688896.9 29.4, 354352.1 6688897 29.4, 354350.7 6688901.2 29.4, 354350.4 6688901.1 29.4, 354347.5 6688910.1 29.4, 354353.2 6688911.8 29.4), (354361.3 6688897 29.4, 354362.4 6688893.1 29.4, 354364.9 6688889.9 29.4, 354368.4 6688888.2 29.4, 354372.7 6688887.7 29.4, 354376.2 6688889.4 29.4, 354379.5 6688892.3 29.4, 354381.4 6688895.4 29.4, 354381.5 6688900.4 29.4, 354380.3 6688903.5 29.4, 354377.4 6688906.8 29.4, 354374.3 6688908.5 29.4, 354370.5 6688908.6 29.4, 354367.8 6688908.1 29.4, 354365.4 6688907.2 29.4, 354362.8 6688904.6 29.4, 354361.6 6688902.5 29.4, 354361.3 6688902 29.4, 354361.3 6688897 29.4))
BATIMENT0000000302923088;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;20;17.9;11.8;29.7;31.0;13.8;Cadastre;A 1.0;POLYGON Z ((354341.7 6688927.3 29.7, 354342.1 6688929.6 29.7, 354356.9 6688941.7 29.7, 354358.2 6688938 29.7, 354359 6688935.6 29.7, 354358.5 6688934.5 29.7, 354356.4 6688933.1 29.7, 354357.7 6688931.6 29.7, 354355.6 6688930.2 29.7, 354359.8 6688925.7 29.7, 354360.4 6688924.6 29.7, 354362.3 6688926.3 29.7, 354364.8 6688924 29.7, 354364.9 6688923.5 29.7, 354363.8 6688923.2 29.7, 354363.4 6688923 29.7, 354363.1 6688922.8 29.7, 354362.8 6688922.6 29.7, 354362.4 6688922.4 29.7, 354362.1 6688922.2 29.7, 354361.9 6688921.9 29.7, 354361.6 6688921.6 29.7, 354361.4 6688921.3 29.7, 354361.2 6688920.9 29.7, 354361 6688920.6 29.7, 354360.9 6688920.2 29.7, 354360.8 6688919.8 29.7, 354360.7 6688919.4 29.7, 354360.7 6688919 29.7, 354360.7 6688918.6 29.7, 354360.7 6688918.2 29.7, 354360.8 6688917.8 29.7, 354360.9 6688917.5 29.7, 354357.5 6688916.3 29.7, 354357.6 6688916 29.7, 354352.4 6688914.3 29.7, 354353.2 6688911.8 29.7, 354347.5 6688910.1 29.7, 354341.7 6688927.3 29.7))
BATIMENT0000000302923368;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.5;12.8;28.3;;;Cadastre;;POLYGON Z ((354360.4 6688924.6 28.3, 354359.8 6688925.7 28.3, 354361.9 6688927.3 28.3, 354362.3 6688926.3 28.3, 354360.4 6688924.6 28.3))
BATIMENT0000000302923371;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;13.7;25.8;26.7;14.6;Cadastre;;POLYGON Z ((354374.9 6688932.7 25.8, 354375.3 6688931.5 25.8, 354372.2 6688930.5 25.8, 354371.9 6688931.7 25.8, 354374.9 6688932.7 25.8))
BATIMENT0000000302923266;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;6.0;90;90;16.0;12.9;29.0;37.0;17.9;Cadastre;A 1.0;POLYGON Z ((354388.8 6688937.4 29, 354384.8 6688949 29, 354385 6688949.6 29, 354387.8 6688956.7 29, 354393.4 6688959.2 29, 354395.6 6688954 29, 354405.8 6688958.3 29, 354410 6688948.8 29, 354397.2 6688943.7 29, 354398.2 6688940.7 29, 354408.6 6688911.4 29, 354399 6688908.5 29, 354388.8 6688937.4 29))
BATIMENT0000000302923372;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.9;12.8;26.7;27.9;14.0;Cadastre;;POLYGON Z ((354358.2 6688938 26.7, 354360.8 6688939.1 26.7, 354362.7 6688931.3 26.7, 354360.6 6688930.7 26.7, 354359 6688935.6 26.7, 354358.2 6688938 26.7))
BATIMENT0000000302923369;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;4.0;12;20;13.2;12.9;26.1;29.2;14.8;Cadastre;A 1.0;POLYGON Z ((354363.9 6688947.3 26.1, 354373.3 6688951.5 26.1, 354376 6688943.6 26.1, 354376.3 6688942.7 26.1, 354373.5 6688941.8 26.1, 354371.7 6688941.2 26.1, 354370.6 6688940.8 26.1, 354371.8 6688934.7 26.1, 354370.9 6688934.5 26.1, 354371.9 6688931.7 26.1, 354372.2 6688930.5 26.1, 354375.3 6688931.5 26.1, 354374.9 6688932.7 26.1, 354373.8 6688934.8 26.1, 354374.4 6688936.2 26.1, 354378.2 6688937.4 26.1, 354381.1 6688929.4 26.1, 354364.8 6688924 26.1, 354362.3 6688926.3 26.1, 354361.9 6688927.3 26.1, 354360.6 6688930.7 26.1, 354362.7 6688931.3 26.1, 354360.8 6688939.1 26.1, 354358.2 6688938 26.1, 354356.9 6688941.7 26.1, 354363.9 6688947.3 26.1))
BATIMENT0000000302923370;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;14.4;21.7;23.2;14.7;Cadastre;;POLYGON Z ((354373.8 6688940.8 21.7, 354372 6688940.2 21.7, 354371.7 6688941.2 21.7, 354373.5 6688941.8 21.7, 354373.8 6688940.8 21.7))
BATIMENT0000000302923501;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;45.0;8.0;00;00;19.4;13.9;33.3;37.7;15.5;Cadastre;A 1.0;POLYGON Z ((354361.3 6688967 33.3, 354360.4 6688966.7 33.3, 354361.2 6688963.9 33.3, 354345 6688951.2 33.3, 354342.2 6688954.6 33.3, 354339.9 6688952.8 33.3, 354335.3 6688958.9 33.3, 354337.5 6688960.4 33.3, 354336 6688961.9 33.3, 354342.7 6688967.3 33.3, 354345 6688964.3 33.3, 354347.5 6688966.1 33.3, 354344 6688979.2 33.3, 354344.9 6688979.5 33.3, 354351.1 6688981.2 33.3, 354356.7 6688982.7 33.3, 354361.3 6688967 33.3))
BATIMENT0000000302923495;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.5;15.2;24.8;28.7;17.7;Cadastre;;POLYGON Z ((354387.9 6688980.4 24.8, 354389.1 6688980.9 24.8, 354389.8 6688979.3 24.8, 354386.4 6688977.9 24.8, 354385.9 6688979.6 24.8, 354387.9 6688980.4 24.8))
BATIMENT0000000302923418;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;9.8;16.6;26.4;27.2;19.2;Cadastre;B 0.1;POLYGON Z ((354477.4 6688942 26.4, 354474.8 6688949.9 26.4, 354476.1 6688950.4 26.4, 354475.3 6688957 26.4, 354481.5 6688957.9 26.4, 354482.1 6688950.1 26.4, 354481.3 6688950 26.4, 354482.9 6688943.7 26.4, 354485.5 6688935.2 26.4, 354480.4 6688933.2 26.4, 354477.4 6688942 26.4))
BATIMENT0000000302923409;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;12.9;18.2;31.2;35.5;20.2;Cadastre;C 0.8;POLYGON Z ((354504 6688961.2 31.2, 354503.2 6688961 31.2, 354493.4 6688959.6 31.2, 354492.4 6688964 31.2, 354492 6688963.9 31.2, 354489.3 6688976.4 31.2, 354489.6 6688976.5 31.2, 354488.9 6688980.9 31.2, 354499.7 6688983.1 31.2, 354504 6688961.2 31.2))
BATIMENT0000000302923470;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;14.4;18.0;32.5;36.3;20.2;Cadastre;C 0.7;POLYGON Z ((354524.7 6688964.7 32.5, 354523.8 6688976.4 32.5, 354530.7 6688976.9 32.5, 354530.9 6688973.4 32.5, 354533 6688973.4 32.5, 354532.9 6688978.4 32.5, 354538.4 6688978.4 32.5, 354536.8 6688965.7 32.5, 354524.7 6688964.7 32.5))
BATIMENT0000000302923560;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;35;10;10.1;18.0;28.2;36.7;21.2;Cadastre;C 0.4;POLYGON Z ((354539 6688983.4 28.2, 354538 6688991.2 28.2, 354544.2 6688990.9 28.2, 354546.6 6688979.5 28.2, 354549.9 6688977.6 28.2, 354553.4 6688978.6 28.2, 354554.1 6688974.2 28.2, 354554.6 6688974.5 28.2, 354554.8 6688967.4 28.2, 354554.8 6688967 28.2, 354536.8 6688965.7 28.2, 354538.4 6688978.4 28.2, 354539 6688983.4 28.2))
BATIMENT0000000302923477;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.9;19.2;33.2;38.2;19.9;Cadastre;;POLYGON Z ((354523.4 6688980.7 33.2, 354523.2 6688983.9 33.2, 354523.1 6688985.5 33.2, 354526.3 6688985.7 33.2, 354526.3 6688978 33.2, 354523.7 6688977.7 33.2, 354523.4 6688980.7 33.2))
BATIMENT0000000302923471;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;18.6;19.4;38.0;40.9;21.2;Cadastre;A 1.0;POLYGON Z ((354516.5 6688999.4 38, 354515.6 6689001.6 38, 354519.3 6689003.1 38, 354528.1 6689002.8 38, 354528 6688992.2 38, 354522.4 6688992.7 38, 354523.1 6688985.5 38, 354523.2 6688983.9 38, 354520.8 6688983.7 38, 354521.2 6688980.5 38, 354523.4 6688980.7 38, 354523.7 6688977.7 38, 354523.8 6688976.4 38, 354524.7 6688964.7 38, 354510.8 6688963.5 38, 354506.4 6688995 38, 354516.5 6688999.4 38), (354520.1 6688974.4 38, 354520.1 6688974.9 38, 354521.8 6688975.1 38, 354521.6 6688976.8 38, 354519.4 6688976.6 38, 354518.5 6688976.5 38, 354518.8 6688974.2 38, 354520.1 6688974.4 38), (354518.2 6688986.9 38, 354519.9 6688987.1 38, 354519.5 6688989.9 38, 354516.3 6688989 38, 354516.7 6688986.7 38, 354518.2 6688986.9 38))
BATIMENT0000000302923472;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.3;20.8;27.1;34.2;20.8;Cadastre;A 1.0;POLYGON Z ((354538.4 6688978.4 27.1, 354532.9 6688978.4 27.1, 354530.9 6688978.3 27.1, 354530.7 6688986.1 27.1, 354526.3 6688985.7 27.1, 354523.1 6688985.5 27.1, 354522.4 6688992.7 27.1, 354528 6688992.2 27.1, 354530.2 6688991.9 27.1, 354535.4 6688991.4 27.1, 354538 6688991.2 27.1, 354539 6688983.4 27.1, 354538.4 6688978.4 27.1))
BATIMENT0000000302923415;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;14.0;19.7;33.7;36.6;21.0;Cadastre;A 1.0;POLYGON Z ((354482.8 6688998 33.7, 354487.9 6688986.6 33.7, 354498.3 6688991.1 33.7, 354499.7 6688983.1 33.7, 354488.9 6688980.9 33.7, 354483.3 6688979.8 33.7, 354480.8 6688985.9 33.7, 354476.7 6688995.3 33.7, 354482.8 6688998 33.7))
BATIMENT0000000302923473;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.2;20.5;24.7;29.8;22.2;Cadastre;A 1.0;POLYGON Z ((354544.2 6688990.9 24.7, 354538 6688991.2 24.7, 354535.4 6688991.4 24.7, 354535.6 6689002.6 24.7, 354542.7 6689002.4 24.7, 354544.6 6688998.1 24.7, 354541.2 6688998.1 24.7, 354541.1 6688995.4 24.7, 354545.8 6688995.5 24.7, 354548 6688990.7 24.7, 354544.2 6688990.9 24.7))
BATIMENT0000000302923476;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;20.1;24.2;28.2;21.7;Cadastre;;POLYGON Z ((354535.6 6689002.6 24.2, 354535.4 6688991.4 24.2, 354530.2 6688991.9 24.2, 354530.5 6688993.4 24.2, 354534.2 6688993.2 24.2, 354534.3 6689002.6 24.2, 354535.6 6689002.6 24.2))
BATIMENT0000000302923416;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:43:00;2023-01-31 17:40:48;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;12.0;14.8;26.8;29.5;19.3;Cadastre;A 1.0;POLYGON Z ((354464.8 6688937.4 26.8, 354466.2 6688933.6 26.8, 354463.4 6688932.7 26.8, 354462.8 6688934.4 26.8, 354462.1 6688936.4 26.8, 354459.2 6688944.5 26.8, 354464 6688946.2 26.8, 354470.2 6688948.3 26.8, 354474.8 6688949.9 26.8, 354477.4 6688942 26.8, 354464.8 6688937.4 26.8))
BATIMENT0000000302923410;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;7.0;30;40;2.2;16.2;18.5;39.3;18.9;Cadastre;A 1.0;POLYGON Z ((354405.8 6688958.3 18.5, 354417.6 6688963.2 18.5, 354416.2 6688966.8 18.5, 354420.9 6688968.7 18.5, 354422.4 6688965.3 18.5, 354434.3 6688970.3 18.5, 354438.2 6688960.9 18.5, 354442.8 6688949.7 18.5, 354414.7 6688937.7 18.5, 354410 6688948.8 18.5, 354405.8 6688958.3 18.5), (354424 6688958.8 18.5, 354426.4 6688959.8 18.5, 354425 6688963.4 18.5, 354422.6 6688962.4 18.5, 354424 6688958.8 18.5))
BATIMENT0000000302923411;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;13;34;5.7;18.0;23.7;41.3;20.8;Cadastre;A 1.0;POLYGON Z ((354438.2 6688960.9 23.7, 354434.3 6688970.3 23.7, 354443.6 6688974.2 23.7, 354442.8 6688976.2 23.7, 354445.1 6688978.7 23.7, 354446.5 6688980.7 23.7, 354449.6 6688978.9 23.7, 354450.4 6688977.3 23.7, 354451 6688977.5 23.7, 354462.3 6688982.4 23.7, 354463 6688980.6 23.7, 354463.9 6688978.2 23.7, 354463.1 6688977.9 23.7, 354467.3 6688968.7 23.7, 354469.4 6688964.1 23.7, 354470.4 6688961.8 23.7, 354447.6 6688951.9 23.7, 354442.8 6688962.9 23.7, 354438.2 6688960.9 23.7), (354450.6 6688971.8 23.7, 354453.2 6688972.9 23.7, 354451.6 6688976.9 23.7, 354451 6688976.6 23.7, 354449 6688975.8 23.7, 354450.6 6688971.8 23.7))
BATIMENT0000000302923412;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;19.4;24.8;25.9;20.7;Cadastre;;POLYGON Z ((354467.3 6688968.7 24.8, 354469.6 6688969.8 24.8, 354473.3 6688971.3 24.8, 354475.3 6688966.6 24.8, 354469.4 6688964.1 24.8, 354467.3 6688968.7 24.8))
BATIMENT0000000302923417;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;20.1;25.0;39.5;20.8;Cadastre;;POLYGON Z ((354463.1 6688977.9 25, 354463.9 6688978.2 25, 354465.4 6688978.8 25, 354469.6 6688969.8 25, 354467.3 6688968.7 25, 354463.1 6688977.9 25))
BATIMENT0000000302923413;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;19.9;33.5;35.5;20.5;Cadastre;;POLYGON Z ((354465.6 6688981.7 33.5, 354466.2 6688981.9 33.5, 354466.8 6688980.6 33.5, 354465.4 6688980 33.5, 354464.8 6688981.4 33.5, 354465.6 6688981.7 33.5))
BATIMENT0000000302923492;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.0;17.1;28.1;34.2;19.7;Cadastre;C 0.2;POLYGON Z ((354426.7 6688997.1 28.1, 354427 6688994.9 28.1, 354428.5 6688984.1 28.1, 354412.6 6688977.2 28.1, 354407.8 6688988.2 28.1, 354407.4 6688988.9 28.1, 354426.7 6688997.1 28.1))
BATIMENT0000000302923414;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.1;19.6;33.7;35.7;20.6;Cadastre;C 0.1;POLYGON Z ((354460.2 6688988.1 33.7, 354476.7 6688995.3 33.7, 354480.8 6688985.9 33.7, 354472.9 6688982.6 33.7, 354472.2 6688984.5 33.7, 354466.2 6688981.9 33.7, 354465.6 6688981.7 33.7, 354464.8 6688981.4 33.7, 354463 6688980.6 33.7, 354462.3 6688982.4 33.7, 354460.2 6688988.1 33.7))
BATIMENT0000000302923490;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;20;20;19.3;18.1;37.5;40.1;20.1;Cadastre;A 0.9;POLYGON Z ((354439.9 6689000.4 37.5, 354439.6 6689005.1 37.5, 354444.5 6689005.5 37.5, 354445.8 6689005.6 37.5, 354448.7 6689005.8 37.5, 354449.7 6688993.3 37.5, 354428.5 6688984.1 37.5, 354427 6688994.9 37.5, 354439.9 6689000.4 37.5))
BATIMENT0000000302923489;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;18.6;29.5;33.5;20.0;Cadastre;;POLYGON Z ((354428.9 6689000.2 29.5, 354428.8 6689000 29.5, 354426.4 6688999.4 29.5, 354426 6689002.3 29.5, 354428.7 6689003.2 29.5, 354428.9 6689001.2 29.5, 354428.9 6689000.2 29.5))
BATIMENT0000000302927415;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;22.0;30.2;33.7;22.3;Cadastre;;POLYGON Z ((354547 6689012.7 30.2, 354547.9 6689009.8 30.2, 354546.1 6689008.9 30.2, 354545.8 6689012.1 30.2, 354547 6689012.7 30.2))
BATIMENT0000000302927411;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;13.3;20.8;34.1;37.6;22.3;Cadastre;A 1.0;POLYGON Z ((354511.6 6689010.7 34.1, 354534.6 6689020.5 34.1, 354542.7 6689002.4 34.1, 354535.6 6689002.6 34.1, 354534.3 6689002.6 34.1, 354528.1 6689002.8 34.1, 354519.3 6689003.1 34.1, 354515.6 6689001.6 34.1, 354511.6 6689010.7 34.1), (354537.5 6689005.4 34.1, 354537.2 6689008 34.1, 354534.1 6689006.8 34.1, 354527.8 6689006.8 34.1, 354527.8 6689005.8 34.1, 354537.5 6689005.4 34.1))
BATIMENT0000000302923480;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;8.1;21.6;29.7;37.7;22.4;Cadastre;A 1.0;POLYGON Z ((354534.6 6689020.5 29.7, 354544.4 6689024.7 29.7, 354548.2 6689015.7 29.7, 354549.1 6689013.7 29.7, 354550 6689011.5 29.7, 354552.5 6689005.7 29.7, 354553.2 6689004.1 29.7, 354553.8 6689002.5 29.7, 354544.6 6688998.1 29.7, 354542.7 6689002.4 29.7, 354534.6 6689020.5 29.7), (354547.5 6689001.3 29.7, 354549.1 6689002 29.7, 354546.1 6689008.9 29.7, 354547.9 6689009.8 29.7, 354547 6689012.7 29.7, 354545.8 6689012.1 29.7, 354542.3 6689010.6 29.7, 354543.1 6689008.7 29.7, 354544.1 6689009.1 29.7, 354547.5 6689001.3 29.7))
BATIMENT0000000302928984;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;10;20;13.9;21.0;35.0;37.7;22.3;Cadastre;A 1.0;POLYGON Z ((354504 6689028.8 35, 354496.9 6689045 35, 354514.3 6689046.5 35, 354513.9 6689022.3 35, 354508 6689019.4 35, 354503.8 6689028.6 35, 354504 6689028.8 35), (354504 6689038.5 35, 354505.7 6689038.9 35, 354505.6 6689041.7 35, 354502.4 6689041.2 35, 354504 6689038.5 35))
BATIMENT0000000302929034;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;23;19.9;21.5;41.5;43.5;23.0;Cadastre;A 1.0;POLYGON Z ((354521.5 6689043.3 41.5, 354534.2 6689047 41.5, 354534.5 6689046.9 41.5, 354535.1 6689044.6 41.5, 354538.5 6689032.1 41.5, 354523.1 6689025.5 41.5, 354521.1 6689026.9 41.5, 354521.5 6689043.3 41.5), (354532.7 6689037.3 41.5, 354533.1 6689039.6 41.5, 354531.7 6689042 41.5, 354528.7 6689040.7 41.5, 354528.6 6689038.8 41.5, 354529 6689038.9 41.5, 354530.6 6689038.1 41.5, 354531.7 6689038.2 41.5, 354532.7 6689037.3 41.5))
BATIMENT0000000302929030;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;20;20;14.5;22.5;37.0;39.9;23.2;Cadastre;A 1.0;POLYGON Z ((354536.3 6689045.2 37, 354537.9 6689045.6 37, 354538.4 6689047.2 37, 354538 6689048.4 37, 354539.9 6689049.2 37, 354538.2 6689053.5 37, 354553 6689057.8 37, 354559.8 6689041.5 37, 354538.5 6689032.1 37, 354535.1 6689044.6 37, 354536.3 6689045.2 37), (354551.1 6689049.5 37, 354552.3 6689050.6 37, 354551.6 6689050.8 37, 354551.1 6689052.1 37, 354547.9 6689050.8 37, 354548.7 6689048.7 37, 354551.1 6689049.5 37), (354544.7 6689049.3 37, 354541.8 6689048.3 37, 354542.7 6689046.1 37, 354545.5 6689047.2 37, 354544.7 6689049.3 37))
BATIMENT0000000302929033;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.5;22.0;37.6;38.5;23.0;Cadastre;;POLYGON Z ((354535.1 6689044.6 37.6, 354534.5 6689046.9 37.6, 354535.7 6689047.5 37.6, 354536.3 6689045.2 37.6, 354535.1 6689044.6 37.6))
BATIMENT0000000302928853;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;00;00;14.1;21.1;35.2;37.9;22.2;Cadastre;A 1.0;POLYGON Z ((354466.7 6689053.3 35.2, 354472.2 6689055.7 35.2, 354471.8 6689056.2 35.2, 354475.3 6689058 35.2, 354475.6 6689057.3 35.2, 354481 6689059.8 35.2, 354487.4 6689044.6 35.2, 354482 6689042.6 35.2, 354482.3 6689041.8 35.2, 354478.6 6689040.2 35.2, 354478.4 6689040.9 35.2, 354473 6689038.8 35.2, 354466.7 6689053.3 35.2))
BATIMENT0000000302929031;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;17.4;22.1;39.6;42.5;23.2;Cadastre;A 1.0;POLYGON Z ((354522 6689054.9 39.6, 354532.3 6689055.4 39.6, 354533.8 6689055.4 39.6, 354534.2 6689053.6 39.6, 354534.5 6689051.4 39.6, 354535 6689051.4 39.6, 354535.4 6689049.8 39.6, 354534.1 6689048 39.6, 354534.5 6689046.9 39.6, 354534.2 6689047 39.6, 354521.5 6689043.3 39.6, 354522 6689054.9 39.6))
BATIMENT0000000302928983;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;5.0;10;20;16.8;21.8;38.7;40.9;23.0;Cadastre;A 1.0;POLYGON Z ((354493.9 6689062.9 38.7, 354499.4 6689063.7 38.7, 354504.5 6689064.3 38.7, 354514.3 6689065.6 38.7, 354514.3 6689046.5 38.7, 354496.9 6689045 38.7, 354489.7 6689062.3 38.7, 354493.9 6689062.9 38.7), (354503.3 6689048.1 38.7, 354503.2 6689062.2 38.7, 354500.5 6689061.7 38.7, 354500.7 6689052 38.7, 354502.5 6689048.4 38.7, 354503.3 6689048.1 38.7))
BATIMENT0000000302927423;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;20.2;24.0;25.0;20.4;Cadastre;;POLYGON Z ((354420.1 6689005.7 24, 354418.7 6689012.1 24, 354424.4 6689013.8 24, 354425.4 6689006.9 24, 354420.1 6689005.7 24))
BATIMENT0000000302927421;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;19.3;21.0;23.1;20.0;Cadastre;;POLYGON Z ((354415.9 6689014.2 21, 354416.7 6689011.5 21, 354410.8 6689009.9 21, 354410.1 6689012.6 21, 354415.9 6689014.2 21))
BATIMENT0000000302927422;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;19.8;24.6;27.7;21.7;Cadastre;;POLYGON Z ((354446.7 6689030 24.6, 354443.7 6689029.5 24.6, 354446.1 6689012.4 24.6, 354443.6 6689011.9 24.6, 354444.5 6689005.5 24.6, 354439.6 6689005.1 24.6, 354428.9 6689001.2 24.6, 354428.7 6689003.2 24.6, 354426 6689002.3 24.6, 354425.4 6689006.9 24.6, 354424.4 6689013.8 24.6, 354424.2 6689015.3 24.6, 354430 6689016.1 24.6, 354428.5 6689026.4 24.6, 354428.2 6689028.3 24.6, 354422.6 6689027.6 24.6, 354421.9 6689033 24.6, 354446.3 6689036.5 24.6, 354446.7 6689032.3 24.6, 354446.7 6689030 24.6))
BATIMENT0000000302923491;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;4.0;20;20;12.9;20.5;33.4;37.7;22.1;Cadastre;A 1.0;POLYGON Z ((354446.7 6689032.3 33.4, 354446.3 6689036.5 33.4, 354461.6 6689038.8 33.4, 354461 6689042.5 33.4, 354463 6689043.1 33.4, 354479.1 6689005.8 33.4, 354455.4 6688995.8 33.4, 354452.9 6689032.9 33.4, 354446.7 6689032.3 33.4), (354459.8 6689010.5 33.4, 354462.7 6689011.4 33.4, 354462.2 6689012.2 33.4, 354462 6689012.6 33.4, 354461.9 6689013.6 33.4, 354462 6689014.9 33.4, 354462.3 6689016.2 33.4, 354462.6 6689018 33.4, 354461.6 6689019.6 33.4, 354461.4 6689021.3 33.4, 354458.8 6689020.9 33.4, 354459.4 6689016.8 33.4, 354460.5 6689016.9 33.4, 354460.7 6689015.3 33.4, 354459.4 6689015 33.4, 354459.8 6689010.5 33.4))
BATIMENT0000000302927426;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;19.7;23.0;23.5;20.4;Cadastre;;POLYGON Z ((354418.1 6689024.7 23, 354418 6689025.3 23, 354417.8 6689026.5 23, 354419.2 6689028.2 23, 354420.3 6689027.3 23, 354422.6 6689027.6 23, 354422.8 6689026 23, 354422.8 6689025.5 23, 354418.1 6689024.7 23))
BATIMENT0000000302927425;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;20.0;23.4;24.2;20.6;Cadastre;;POLYGON Z ((354422.8 6689025.5 23.4, 354422.8 6689026 23.4, 354422.6 6689027.6 23.4, 354428.2 6689028.3 23.4, 354428.5 6689026.4 23.4, 354422.8 6689025.5 23.4))
BATIMENT0000000302927428;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;20.2;23.4;23.9;20.2;Cadastre;;POLYGON Z ((354410 6689023.9 23.4, 354408.9 6689029.7 23.4, 354417.9 6689031.9 23.4, 354418.5 6689028.8 23.4, 354419.2 6689028.2 23.4, 354417.8 6689026.5 23.4, 354418 6689025.3 23.4, 354410 6689023.9 23.4))
BATIMENT0000000302927424;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;34.0;7.0;30;40;13.1;19.9;33.0;45.0;22.7;Cadastre;C 0.6;POLYGON Z ((354420 6689032.9 33, 354417.2 6689043.9 33, 354419.2 6689044.3 33, 354417.9 6689048.6 33, 354409.5 6689046.7 33, 354408.4 6689049.5 33, 354380.1 6689042.6 33, 354377.7 6689051.4 33, 354402.7 6689057.7 33, 354438 6689066.6 33, 354439.2 6689061.7 33, 354449.6 6689064.5 33, 354458.6 6689042.8 33, 354461 6689042.5 33, 354461.6 6689038.8 33, 354446.3 6689036.5 33, 354421.9 6689033 33, 354420 6689032.9 33))
BATIMENT0000002011295677;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;2.0;;;19.8;17.8;;38.3;22.9;Imagerie aérienne;C 0.2;POLYGON Z ((354382 6689072.6 30.4, 354381.4 6689075.6 30, 354436.1 6689088 37.6, 354438.7 6689078.4 37.6, 354435.1 6689077 35.8, 354391.1 6689066.6 35.8, 354385.1 6689064.7 30.4, 354383.6 6689073 30.4, 354382 6689072.6 30.4))
BATIMENT0000002275363168;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;14.8;22.8;;42.2;24.3;Imagerie aérienne;;POLYGON Z ((354438.7 6689078.4 37.6, 354436.1 6689088 37.6, 354435.8 6689088.8 37.6, 354447.1 6689091.6 37.4, 354468.2 6689096.9 37.1, 354468.3 6689096.4 37.5, 354476.4 6689098.5 37.6, 354478.9 6689087.9 37.5, 354438.7 6689078.4 37.6))
BATIMENT0000000302923493;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;6.0;00;00;11.9;15.2;27.2;32.8;19.2;Cadastre;A 1.0;POLYGON Z ((354378.4 6688962.4 27.2, 354369.4 6688994.6 27.2, 354371.4 6688995.1 27.2, 354370.4 6688998.9 27.2, 354374.6 6689000.1 27.2, 354386.5 6689003.6 27.2, 354386.6 6689003.1 27.2, 354386 6689002.9 27.2, 354389 6688992.7 27.2, 354383.3 6688991.2 27.2, 354382.9 6688990.4 27.2, 354385.9 6688979.6 27.2, 354386.4 6688977.9 27.2, 354389.8 6688979.3 27.2, 354389.1 6688980.9 27.2, 354407.8 6688988.2 27.2, 354412.6 6688977.2 27.2, 354409.6 6688976 27.2, 354394.5 6688969.5 27.2, 354389.9 6688968.4 27.2, 354390.1 6688967.6 27.2, 354389.7 6688967.4 27.2, 354378.4 6688962.4 27.2))
BATIMENT0000000302923499;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;10;20;11.9;14.0;26.0;31.7;15.5;Cadastre;A 1.0;POLYGON Z ((354362 6688984.2 26, 354356.7 6688982.7 26, 354351.1 6688981.2 26, 354349.3 6688988.4 26, 354343.6 6688986.8 26, 354342.8 6688989.6 26, 354344.3 6688990 26, 354359.1 6688994.2 26, 354362 6688984.2 26))
BATIMENT0000000302923494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:43:00;2018-09-18 13:36:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.9;15.0;28.0;29.6;15.6;Cadastre;;POLYGON Z ((354371.4 6688995.1 28, 354369.4 6688994.6 28, 354368.4 6688997.9 28, 354368.3 6688998.3 28, 354370.4 6688998.9 28, 354371.4 6688995.1 28))
BATIMENT0000000302923522;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:43:00;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;7.0;00;00;6.6;15.7;22.3;36.3;19.7;Cadastre;A 1.0;POLYGON Z ((354369.6 6689037.7 22.3, 354369.1 6689039.8 22.3, 354380.1 6689042.6 22.3, 354382.7 6689031.7 22.3, 354386.4 6689018 22.3, 354392.3 6689019.7 22.3, 354396.3 6689005.8 22.3, 354386.6 6689003.1 22.3, 354386.5 6689003.6 22.3, 354374.6 6689000.1 22.3, 354371 6689012.6 22.3, 354364.7 6689010.8 22.3, 354357.4 6689036.1 22.3, 354364.3 6689038 22.3, 354364.6 6689036.3 22.3, 354369.6 6689037.7 22.3))
BATIMENT0000000302927429;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;19.0;23.7;23.7;19.5;Cadastre;;POLYGON Z ((354386.4 6689018 23.7, 354382.7 6689031.7 23.7, 354388.8 6689033.1 23.7, 354392.3 6689019.7 23.7, 354386.4 6689018 23.7))
BATIMENT0000000302927427;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;15.7;15.9;31.7;34.1;19.7;Cadastre;A 1.0;POLYGON Z ((354369.1 6689039.8 31.7, 354369.6 6689037.7 31.7, 354364.6 6689036.3 31.7, 354364.3 6689038 31.7, 354357.4 6689036.1 31.7, 354354.6 6689046.2 31.7, 354355.5 6689048.2 31.7, 354377.3 6689053.5 31.7, 354377.7 6689051.4 31.7, 354380.1 6689042.6 31.7, 354369.1 6689039.8 31.7))
BATIMENT0000000302928684;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;;;15.9;15.8;31.7;36.5;20.0;Cadastre;A 1.0;POLYGON Z ((354356.3 6689057.6 31.7, 354350.6 6689060.9 31.7, 354348.4 6689067.8 31.7, 354348.9 6689067.9 31.7, 354340.2 6689098.9 31.7, 354351.9 6689101.5 31.7, 354359.9 6689070.9 31.7, 354360.3 6689070.8 31.7, 354361 6689067.9 31.7, 354383.6 6689073 31.7, 354385.1 6689064.7 31.7, 354356.3 6689057.6 31.7))
BATIMENT0000002275362961;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;7.9;17.2;;28.2;21.1;Imagerie aérienne;;POLYGON Z ((354381.4 6689075.6 25.1, 354382 6689072.6 25.1, 354378.8 6689071.9 25.1, 354374.3 6689095.8 25.1, 354380.5 6689096.7 25.1, 354383.9 6689076.2 25.1, 354381.4 6689075.6 25.1))
BATIMENT0000002275362897;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;16.5;22.9;;41.0;23.8;Imagerie aérienne;;POLYGON Z ((354447.1 6689091.6 39, 354435.8 6689088.8 39, 354434.7 6689093 39.1, 354432.1 6689104.1 39.1, 354404 6689100.4 39.4, 354400.4 6689099.8 39, 354380.5 6689096.7 35.2, 354374.3 6689095.8 34, 354371.7 6689110.7 34, 354371 6689114.3 34.3, 354366.5 6689140.2 36.3, 354352.1 6689139 36.3, 354340.5 6689137.9 31.5, 354348.4 6689109.9 31.6, 354350.9 6689101.3 31.7, 354340.2 6689098.9 31.7, 354339.4 6689098.6 31.4, 354325.3 6689147.8 31.4, 354351.1 6689150.6 36.3, 354375.7 6689152.8 35.7, 354383.8 6689108.9 34.5, 354398.7 6689111.1 39, 354402.4 6689111.7 39.4, 354440.7 6689117.2 38.9, 354447.1 6689091.6 39))
BATIMENT0000002275362743;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.6;16.3;;30.5;20.0;Imagerie aérienne;;POLYGON Z ((354349.6 6689110.2 20.9, 354348.4 6689109.9 20.9, 354340.5 6689137.9 20.9, 354352.1 6689139 20.9, 354366.5 6689140.2 20.9, 354371 6689114.3 20.9, 354349.6 6689110.2 20.9))
BATIMENT0000000302929032;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;22.9;28.2;35.5;23.3;Cadastre;;POLYGON Z ((354532.3 6689055.4 28.2, 354532.5 6689058.3 28.2, 354541.1 6689059 28.2, 354541.3 6689057.2 28.2, 354536.9 6689056.4 28.2, 354533.8 6689055.4 28.2, 354532.3 6689055.4 28.2))
BATIMENT0000000302929029;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;5.0;20;20;13.3;23.1;36.4;39.1;25.0;Cadastre;A 1.0;POLYGON Z ((354522.5 6689068.4 36.4, 354522.7 6689068.4 36.4, 354525.2 6689068.4 36.4, 354533.9 6689068.6 36.4, 354534.1 6689068.2 36.4, 354549.8 6689068.4 36.4, 354550.8 6689062.7 36.4, 354551.5 6689059.8 36.4, 354552.1 6689059.9 36.4, 354553 6689057.8 36.4, 354538.2 6689053.5 36.4, 354536.9 6689056.4 36.4, 354541.3 6689057.2 36.4, 354541.1 6689059 36.4, 354544.3 6689059.3 36.4, 354543.9 6689062.9 36.4, 354535.4 6689063.1 36.4, 354530.2 6689062.4 36.4, 354529.8 6689061.8 36.4, 354532.5 6689061.6 36.4, 354532.5 6689058.3 36.4, 354532.3 6689055.4 36.4, 354522 6689054.9 36.4, 354522.5 6689068.4 36.4))
BATIMENT0000000302929199;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.4;22.7;38.2;39.9;26.4;Cadastre;;POLYGON Z ((354525.7 6689077.7 38.2, 354525.7 6689080.7 38.2, 354543.3 6689079.7 38.2, 354557.7 6689078.8 38.2, 354563.2 6689078.4 38.2, 354562.5 6689064 38.2, 354564.1 6689063.9 38.2, 354565 6689043.7 38.2, 354559.8 6689041.5 38.2, 354553 6689057.8 38.2, 354552.1 6689059.9 38.2, 354551.5 6689059.8 38.2, 354550.8 6689062.7 38.2, 354549.8 6689068.4 38.2, 354534.1 6689068.2 38.2, 354533.9 6689068.6 38.2, 354525.2 6689068.4 38.2, 354525.1 6689070 38.2, 354525.2 6689071.5 38.2, 354524.2 6689071.6 38.2, 354524.2 6689077.8 38.2, 354525.7 6689077.7 38.2))
BATIMENT0000000302928986;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;22.1;28.2;35.5;22.7;Cadastre;;POLYGON Z ((354489.7 6689062.3 28.2, 354487.4 6689067.3 28.2, 354492.6 6689068.5 28.2, 354493.9 6689062.9 28.2, 354489.7 6689062.3 28.2))
BATIMENT0000000302928985;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1904-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;13.2;22.4;35.6;40.5;23.4;Cadastre;A 1.0;POLYGON Z ((354492.6 6689068.5 35.6, 354491.7 6689071.9 35.6, 354486.2 6689070.1 35.6, 354482.3 6689078.2 35.6, 354483.6 6689080.3 35.6, 354492.9 6689082.6 35.6, 354495.3 6689073.4 35.6, 354499.4 6689063.7 35.6, 354493.9 6689062.9 35.6, 354492.6 6689068.5 35.6))
BATIMENT0000000302928987;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;16.9;22.7;39.7;41.5;24.1;Cadastre;A 1.0;POLYGON Z ((354495.3 6689073.4 39.7, 354492.9 6689082.6 39.7, 354512.1 6689087.5 39.7, 354514.2 6689085.6 39.7, 354514.1 6689081.8 39.7, 354514.1 6689077 39.7, 354514.3 6689065.6 39.7, 354504.5 6689064.3 39.7, 354499.4 6689063.7 39.7, 354495.3 6689073.4 39.7))
BATIMENT0000000302928702;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;12.1;24.1;36.2;38.3;25.2;Cadastre;A 1.0;POLYGON Z ((354513.7 6689097.2 36.2, 354501.8 6689094.4 36.2, 354498.3 6689109.5 36.2, 354513.7 6689112.1 36.2, 354513.7 6689097.2 36.2))
BATIMENT0000000302928701;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;7.2;26.0;33.2;34.7;26.1;Cadastre;A 1.0;POLYGON Z ((354494.5 6689125.7 33.2, 354513.7 6689128.4 33.2, 354513.7 6689112.1 33.2, 354498.3 6689109.5 33.2, 354494.5 6689125.7 33.2))
BATIMENT0000002011294448;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;1872-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;19;20;8.2;25.0;;39.7;26.1;Imagerie aérienne;A 1.0;POLYGON Z ((354506 6689127.3 33.2, 354494.5 6689125.7 33.2, 354494.9 6689129.6 33.2, 354499.2 6689130 31.9, 354499.1 6689128.5 31.9, 354506 6689129.1 33.2, 354505.6 6689141.9 33.2, 354507.3 6689142 33.2, 354512.8 6689142 33.2, 354514 6689142.1 33.2, 354513.7 6689128.4 33.2, 354506 6689127.3 33.2))
BATIMENT0000002011295068;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;1973-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;20.0;6.0;30;49;19.2;25.6;;45.4;27.1;Imagerie aérienne;A 1.0;POLYGON Z ((354512.8 6689143.7 42, 354512.8 6689142 42, 354507.3 6689142 44.8, 354505.6 6689141.9 44.8, 354499.4 6689141.7 44.8, 354499.4 6689142.7 44.8, 354494.6 6689142.7 44.8, 354494.6 6689146.3 44.8, 354492.6 6689146.3 44.8, 354492.6 6689155.6 44.8, 354491.4 6689159 41.1, 354492.8 6689159 41.1, 354492.7 6689163.2 41.1, 354495.3 6689163.4 43.1, 354502.5 6689164.3 43.1, 354513 6689164.3 43.1, 354514.3 6689164 39.8, 354514.6 6689158.6 39.8, 354513.4 6689158.6 39.8, 354513.7 6689148.2 39.8, 354514.4 6689148.2 39.8, 354514 6689143.4 39.8, 354512.8 6689143.7 42))
BATIMENT0000002011295691;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;14.2;23.4;;;;Imagerie aérienne;;POLYGON Z ((354465.7 6689107.3 28.2, 354469.7 6689108.2 28.3, 354469.4 6689110.2 30.9, 354452.2 6689107.9 31, 354448.5 6689111 31.3, 354447.8 6689118 31.6, 354469.5 6689121 31.1, 354473 6689121.6 28.1, 354476.9 6689104.7 28.1, 354479.8 6689105.4 28.3, 354481 6689102.7 28.3, 354482.5 6689099.8 31.9, 354485.7 6689088.7 31.7, 354478.9 6689087.9 37.6, 354476.4 6689098.5 37.6, 354468.3 6689096.4 37.5, 354465.7 6689107.3 28.2))
BATIMENT0000002275362527;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;5.9;23.5;;;;Imagerie aérienne;;POLYGON Z ((354451.1 6689128.2 29.4, 354452.8 6689118.7 29.4, 354447.8 6689118 29.4, 354441.9 6689132.2 29.4, 354442.5 6689142.4 29.4, 354451.5 6689142 29.4, 354451.1 6689128.2 29.4))
BATIMENT0000000302929099;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.1;24.3;29.4;39.1;24.7;Cadastre;;POLYGON Z ((354423.9 6689154.1 29.4, 354432.9 6689155.4 29.4, 354433.6 6689150.3 29.4, 354424.6 6689149 29.4, 354423.9 6689154.1 29.4))
BATIMENT0000000302929003;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;02;6.3;24.1;30.4;30.9;25.4;Cadastre;B 0.5;POLYGON Z ((354427.4 6689161.6 30.4, 354433.1 6689162.4 30.4, 354433.9 6689157 30.4, 354428.2 6689156.3 30.4, 354427.4 6689161.6 30.4))
BATIMENT0000000302929101;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;2.9;25.2;28.1;28.9;26.4;Cadastre;C 0.3;POLYGON Z ((354453.9 6689165.3 28.1, 354457.6 6689160.4 28.1, 354457.6 6689160.3 28.1, 354455.5 6689160 28.1, 354451.2 6689159.4 28.1, 354451.2 6689160.5 28.1, 354450.5 6689164.8 28.1, 354453.9 6689165.3 28.1))
BATIMENT0000000302928711;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;5.6;26.0;31.6;35.4;27.1;Cadastre;A 1.0;POLYGON Z ((354466.7 6689177.3 31.6, 354471 6689177.8 31.6, 354472.1 6689169.5 31.6, 354474.4 6689169.9 31.6, 354475.5 6689162.5 31.6, 354468.8 6689161.6 31.6, 354466.6 6689177.3 31.6, 354466.7 6689177.3 31.6))
BATIMENT0000000302928713;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;5.7;26.0;31.7;36.2;27.1;Cadastre;C 0.7;POLYGON Z ((354466.4 6689179.5 31.7, 354466.7 6689177.3 31.7, 354466.6 6689177.3 31.7, 354468.8 6689161.6 31.7, 354461 6689160.7 31.7, 354459.9 6689167.9 31.7, 354463.5 6689168.4 31.7, 354462.7 6689172.4 31.7, 354459.4 6689172 31.7, 354458.7 6689178.7 31.7, 354466.4 6689179.5 31.7))
BATIMENT0000000302928876;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;02;4.2;24.5;28.7;35.0;25.5;Cadastre;B 0.4;POLYGON Z ((354414.8 6689183.6 28.7, 354413.7 6689191.2 28.7, 354423.9 6689192.7 28.7, 354424.8 6689183.9 28.7, 354423.9 6689183.8 28.7, 354423 6689181.7 28.7, 354421.1 6689181.3 28.7, 354414.8 6689183.6 28.7))
BATIMENT0000000302928671;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.4;25.2;31.6;35.9;26.2;Cadastre;B 0.4;POLYGON Z ((354430.8 6689193.5 31.6, 354445.7 6689195.6 31.6, 354445.7 6689194.5 31.6, 354442.7 6689194 31.6, 354443 6689191.7 31.6, 354448 6689192.3 31.6, 354448.7 6689185.9 31.6, 354443.6 6689185.5 31.6, 354443.6 6689184.9 31.6, 354431.8 6689183.8 31.6, 354430.8 6689193.5 31.6))
BATIMENT0000000302928736;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;24.2;25.8;30.7;24.3;Cadastre;;POLYGON Z ((354425.1 6689200.7 25.8, 354421.6 6689200.6 25.8, 354421.5 6689201.6 25.8, 354425 6689201.7 25.8, 354425.1 6689200.7 25.8))
BATIMENT0000000302928253;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.8;26.7;33.5;34.4;27.5;Cadastre;;POLYGON Z ((354525.1 6689164.5 33.5, 354522.1 6689164.4 33.5, 354522.2 6689171.3 33.5, 354529.6 6689171.8 33.5, 354530 6689164.9 33.5, 354527.7 6689164.7 33.5, 354527.8 6689163.2 33.5, 354525.2 6689163.1 33.5, 354525.1 6689164.5 33.5))
BATIMENT0000000302928712;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;12;12;5.1;26.0;31.1;32.8;27.4;Cadastre;A 1.0;POLYGON Z ((354488.2 6689181.6 31.1, 354488.5 6689179.3 31.1, 354487.6 6689179.4 31.1, 354487.6 6689178.6 31.1, 354485.7 6689178.4 31.1, 354485.7 6689178.9 31.1, 354484.7 6689178.8 31.1, 354485.5 6689172.7 31.1, 354486.1 6689172.6 31.1, 354487.4 6689170.7 31.1, 354489.2 6689170.8 31.1, 354490 6689164.6 31.1, 354475.5 6689162.5 31.1, 354474.4 6689169.9 31.1, 354472.1 6689169.5 31.1, 354471 6689177.8 31.1, 354470.7 6689180 31.1, 354488.2 6689181.6 31.1))
BATIMENT0000000302928998;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;13;20;9.5;27.0;36.5;39.2;27.6;Cadastre;A 1.0;POLYGON Z ((354514.8 6689167.9 36.5, 354501.2 6689166.1 36.5, 354501.2 6689167.8 36.5, 354502.6 6689168.5 36.5, 354504.9 6689168.8 36.5, 354503.7 6689183.1 36.5, 354513.6 6689184.3 36.5, 354514.8 6689167.9 36.5))
BATIMENT0000002011295363;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.6;27.2;;34.5;27.8;Imagerie aérienne;;POLYGON Z ((354470.5 6689194.9 30.8, 354471.8 6689195.2 30.8, 354471.6 6689197.9 30.8, 354486.2 6689200.2 30.8, 354486.6 6689197.3 30.8, 354481.2 6689196.5 30.8, 354481.5 6689192.7 30.8, 354492.1 6689193.7 30.8, 354492.2 6689191.3 30.8, 354501.1 6689192.2 30.8, 354501.8 6689183 30.8, 354488.2 6689181.6 30.8, 354471.9 6689180.1 30.8, 354470.5 6689194.9 30.8))
BATIMENT0000000302929000;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;11.2;27.0;38.2;44.4;28.2;Cadastre;C 0.6;POLYGON Z ((354500.9 6689194.2 38.2, 354501.4 6689194.3 38.2, 354501.2 6689196.2 38.2, 354498.9 6689196.1 38.2, 354498.7 6689199.3 38.2, 354499.6 6689199.3 38.2, 354499.3 6689202.2 38.2, 354512.2 6689203.2 38.2, 354512.4 6689200.7 38.2, 354511.9 6689200.6 38.2, 354512.3 6689195.4 38.2, 354512.7 6689195.3 38.2, 354513.6 6689184.3 38.2, 354503.7 6689183.1 38.2, 354501.8 6689183 38.2, 354500.9 6689194.2 38.2))
BATIMENT0000000302928320;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1889-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.5;27.0;37.5;40.8;29.2;Cadastre;A 1.0;POLYGON Z ((354533.4 6689203 37.5, 354533.4 6689185.6 37.5, 354521.5 6689184.9 37.5, 354521.1 6689185.4 37.5, 354520.8 6689202.9 37.5, 354532.5 6689203 37.5, 354533.4 6689203 37.5))
BATIMENT0000000302928319;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.6;27.8;37.4;41.0;29.1;Cadastre;A 1.0;POLYGON Z ((354519.5 6689220.3 37.4, 354531.6 6689220.1 37.4, 354532.1 6689212.3 37.4, 354532.1 6689209.6 37.4, 354532.5 6689203 37.4, 354520.8 6689202.9 37.4, 354519.5 6689220.3 37.4))
BATIMENT0000000302928999;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;50;20;16.0;27.9;44.0;46.2;28.5;Cadastre;A 1.0;POLYGON Z ((354512.2 6689203.2 44, 354499.3 6689202.2 44, 354499.1 6689202.2 44, 354497.4 6689222.3 44, 354501.7 6689222.8 44, 354510.9 6689222.6 44, 354512.2 6689203.2 44))
BATIMENT0000000302928309;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;29.0;36.7;40.2;29.5;Cadastre;;POLYGON Z ((354545.2 6689219.3 36.7, 354543.1 6689219.4 36.7, 354542.9 6689226.2 36.7, 354545.2 6689226.2 36.7, 354546.8 6689226.1 36.7, 354546.7 6689224.8 36.7, 354546.7 6689219.1 36.7, 354545.2 6689219.3 36.7))
BATIMENT0000000302928312;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;29;9.0;27.8;36.8;38.0;29.3;Cadastre;C 0.9;POLYGON Z ((354519.1 6689228.1 36.8, 354531.7 6689227.2 36.8, 354532.7 6689227.1 36.8, 354532.6 6689225 36.8, 354534.3 6689224.9 36.8, 354534.1 6689220 36.8, 354531.6 6689220.1 36.8, 354519.5 6689220.3 36.8, 354519.1 6689228.1 36.8))
BATIMENT0000000302927313;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.6;8.9;13.5;;;Cadastre;C 0.5;POLYGON Z ((354047.9 6689092.1 13.5, 354044.1 6689091.4 13.5, 354043.1 6689096.5 13.5, 354046.9 6689097.4 13.5, 354047.6 6689093.7 13.5, 354047.9 6689092.1 13.5))
BATIMENT0000000302927310;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;8.9;11.5;;;Cadastre;;POLYGON Z ((354070.7 6689094.6 11.5, 354074.4 6689096.6 11.5, 354075.5 6689094.5 11.5, 354071.8 6689092.4 11.5, 354070.7 6689094.6 11.5))
BATIMENT0000000302927297;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;12;20;11.5;10.2;21.7;24.4;10.8;Cadastre;B 0.9;POLYGON Z ((354036.2 6689106.8 21.7, 354038.6 6689098.1 21.7, 354029.3 6689095.1 21.7, 354026.2 6689103.7 21.7, 354036.2 6689106.8 21.7))
BATIMENT0000000302927300;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;9.3;12.9;16.0;9.7;Cadastre;;POLYGON Z ((354058.9 6689102.3 12.9, 354055.8 6689101.2 12.9, 354055.7 6689102.3 12.9, 354055.5 6689104.3 12.9, 354058.1 6689104.9 12.9, 354058.9 6689102.3 12.9))
BATIMENT0000000302927299;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;9.4;9.5;19.0;23.4;10.4;Cadastre;C 0.9;POLYGON Z ((354053.7 6689112.4 19, 354055.5 6689104.3 19, 354055.7 6689102.3 19, 354055.8 6689101.2 19, 354056.2 6689099.3 19, 354053.5 6689098.7 19, 354053 6689100.8 19, 354051 6689100.3 19, 354050.8 6689101.2 19, 354048.5 6689100.6 19, 354049.6 6689094.2 19, 354047.6 6689093.7 19, 354046.9 6689097.4 19, 354046.2 6689100.8 19, 354044.7 6689109.5 19, 354053.7 6689112.4 19))
BATIMENT0000000302927298;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1868-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;9.7;9.8;19.5;22.0;10.6;Cadastre;C 0.7;POLYGON Z ((354044.7 6689109.5 19.5, 354046.2 6689100.8 19.5, 354041.3 6689099.4 19.5, 354041.7 6689097.8 19.5, 354038.9 6689096.9 19.5, 354038.6 6689098.1 19.5, 354036.2 6689106.8 19.5, 354044.7 6689109.5 19.5))
BATIMENT0000000302927307;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;8.9;12.0;12.0;9.1;Cadastre;;POLYGON Z ((354070.9 6689110.6 12, 354076.4 6689098.6 12, 354074.9 6689098 12, 354070.9 6689106 12, 354069.6 6689110.1 12, 354070.9 6689110.6 12))
BATIMENT0000000302927308;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1886-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;7.2;7.9;15.1;23.0;9.0;Cadastre;C 0.7;POLYGON Z ((354076.1 6689091.9 15.1, 354080.6 6689100.5 15.1, 354081.7 6689100.1 15.1, 354084.1 6689104.8 15.1, 354074.7 6689109.2 15.1, 354073.4 6689113.6 15.1, 354068.8 6689112.2 15.1, 354067.4 6689116.6 15.1, 354082.4 6689121.5 15.1, 354082.9 6689121.5 15.1, 354083.4 6689120.8 15.1, 354083.9 6689119.9 15.1, 354084.5 6689119 15.1, 354085.2 6689118.2 15.1, 354086.4 6689116.7 15.1, 354087.2 6689116.1 15.1, 354087.6 6689115.7 15.1, 354088.4 6689115.1 15.1, 354089 6689114.7 15.1, 354089.7 6689114.2 15.1, 354090.5 6689113.7 15.1, 354091.1 6689113.4 15.1, 354092.1 6689112.9 15.1, 354092.8 6689112.7 15.1, 354093.2 6689112.5 15.1, 354082 6689089.2 15.1, 354076.1 6689091.9 15.1))
BATIMENT0000000302927302;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;6.0;10.0;16.0;;;Cadastre;B 0.8;POLYGON Z ((354067.4 6689116.6 16, 354068.8 6689112.2 16, 354069.6 6689110.1 16, 354070.9 6689106 16, 354067.1 6689104.8 16, 354067.8 6689103.4 16, 354066.4 6689103.1 16, 354065.4 6689106.9 16, 354065.1 6689106.8 16, 354064.5 6689108.1 16, 354063.6 6689107.8 16, 354064.2 6689106 16, 354062.3 6689105.4 16, 354061.9 6689106.3 16, 354058.1 6689104.9 16, 354055.5 6689104.3 16, 354053.7 6689112.4 16, 354067.4 6689116.6 16))
BATIMENT0000000302927346;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;14.3;9.7;24.0;28.1;11.8;Cadastre;C 0.7;POLYGON Z ((354048.7 6689131.4 24, 354050.4 6689125.8 24, 354051.5 6689122.1 24, 354026.9 6689114.4 24, 354024.1 6689124 24, 354048.7 6689131.4 24))
BATIMENT0000000302927295;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;25;10;18.0;10.6;28.7;30.9;11.6;Cadastre;C 0.5;POLYGON Z ((354016.2 6689100.6 28.7, 354019 6689090.7 28.7, 354016.4 6689089.9 28.7, 354016.6 6689088.9 28.7, 354011.9 6689087.5 28.7, 354011.5 6689088.6 28.7, 354008.8 6689087.8 28.7, 354006.2 6689097.5 28.7, 354016.2 6689100.6 28.7))
BATIMENT0000000302927296;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;25;10;16.1;10.6;26.7;30.8;11.1;Cadastre;C 0.8;POLYGON Z ((354026.2 6689103.7 26.7, 354029.3 6689095.1 26.7, 354029.5 6689093.9 26.7, 354026 6689092.9 26.7, 354026.1 6689091.7 26.7, 354021.7 6689090.5 26.7, 354021.4 6689091.2 26.7, 354019 6689090.7 26.7, 354016.2 6689100.6 26.7, 354026.2 6689103.7 26.7))
BATIMENT0000000302903592;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;10;20;8.4;12.5;21.0;22.9;14.7;Cadastre;C 0.8;POLYGON Z ((353949.7 6689118.4 21, 353951.3 6689119.1 21, 353966.2 6689123.2 21, 353965.3 6689126.1 21, 353967.6 6689126.8 21, 353967.8 6689125.9 21, 353976.5 6689098.5 21, 353957.9 6689092.6 21, 353954.2 6689104.5 21, 353949.7 6689118.4 21), (353959.2 6689102.3 21, 353970.3 6689105.9 21, 353969.8 6689107.2 21, 353967.5 6689106.6 21, 353964.7 6689115.8 21, 353957.6 6689113.3 21, 353960.5 6689104.7 21, 353958.8 6689104.1 21, 353959.2 6689102.3 21))
BATIMENT0000000302903591;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;3.0;00;00;6.8;13.6;20.4;22.9;14.5;Cadastre;A 1.0;POLYGON Z ((353972.6 6689127.3 20.4, 353976.4 6689115 20.4, 353973.5 6689114.1 20.4, 353975.4 6689108.1 20.4, 353982.5 6689110.2 20.4, 353981.3 6689114 20.4, 353979.2 6689113.3 20.4, 353977.9 6689117.4 20.4, 353979.8 6689118 20.4, 353976.5 6689128.6 20.4, 353978.6 6689129.2 20.4, 353983.9 6689112 20.4, 353984.2 6689110.7 20.4, 353987.1 6689101.9 20.4, 353976.5 6689098.5 20.4, 353967.8 6689125.9 20.4, 353972.6 6689127.3 20.4))
BATIMENT0000000302903599;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;14.1;;;;Cadastre;;POLYGON Z ((353950.8 6689121.5 -1000, 353955.9 6689122.9 -1000, 353956.3 6689121.4 -1000, 353951.3 6689120.1 -1000, 353950.8 6689121.5 -1000))
BATIMENT0000000302903589;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;12;5.8;12.1;18.0;26.2;14.0;Cadastre;A 1.0;POLYGON Z ((353974.8 6689140.8 18, 353984.1 6689143.6 18, 353996.6 6689104.9 18, 353987.1 6689101.9 18, 353984.2 6689110.7 18, 353992.6 6689113.3 18, 353990.7 6689117.1 18, 353985 6689135.1 18, 353980.3 6689133.5 18, 353986.6 6689113.9 18, 353985 6689113.4 18, 353985.2 6689112.2 18, 353983.9 6689112 18, 353978.6 6689129.2 18, 353974.8 6689140.8 18))
BATIMENT0000000302903602;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;13.1;19.9;20.5;14.4;Cadastre;;POLYGON Z ((353958 6689123.6 19.9, 353959.6 6689124.3 19.9, 353960 6689123.1 19.9, 353958.4 6689122.6 19.9, 353958 6689123.6 19.9))
BATIMENT0000000302903590;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;11.1;13.1;25.2;14.0;Cadastre;;POLYGON Z ((353983.9 6689144.5 13.1, 353983.3 6689144.4 13.1, 353983.9 6689146.1 13.1, 353989 6689155.5 13.1, 353996.9 6689150.9 13.1, 354002.9 6689148.1 13.1, 354002 6689147 13.1, 354003.8 6689142.4 13.1, 354004.9 6689138.5 13.1, 354006.4 6689133.8 13.1, 354019.9 6689137.9 13.1, 354021 6689134.4 13.1, 354024.1 6689124 13.1, 354026.9 6689114.4 13.1, 354012.2 6689109.7 13.1, 353996.6 6689104.9 13.1, 353984.1 6689143.6 13.1, 353983.9 6689144.5 13.1))
BATIMENT0000000302927356;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.2;11.8;14.0;19.0;12.5;Cadastre;B 0.4;POLYGON Z ((354014.3 6689140.9 14, 354014.7 6689142.1 14, 354015.4 6689143.5 14, 354026.5 6689142.2 14, 354025.3 6689139.9 14, 354019.2 6689140.4 14, 354014.3 6689140.9 14))
BATIMENT0000000302905940;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;10.2;15.0;25.2;31.0;15.5;Cadastre;;POLYGON Z ((353950.5 6689148.4 25.2, 353950.7 6689150.7 25.2, 353956.8 6689150 25.2, 353955.8 6689147.7 25.2, 353950.5 6689148.4 25.2))
BATIMENT0000000302927347;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;25;20;10.1;8.8;18.9;23.2;10.6;Cadastre;A 1.0;POLYGON Z ((354048.7 6689131.4 18.9, 354048.6 6689132.1 18.9, 354053.6 6689133.6 18.9, 354061.5 6689136.1 18.9, 354062.9 6689135.2 18.9, 354064 6689131.6 18.9, 354067.8 6689132.8 18.9, 354069.6 6689127.8 18.9, 354051.5 6689122.1 18.9, 354050.4 6689125.8 18.9, 354048.7 6689131.4 18.9), (354050.8 6689128.9 18.9, 354059.4 6689131.5 18.9, 354059.7 6689131 18.9, 354062 6689131.8 18.9, 354061.2 6689134 18.9, 354050.2 6689130.6 18.9, 354050.8 6689128.9 18.9))
BATIMENT0000000302927351;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;10.5;13.7;22.7;12.6;Cadastre;;POLYGON Z ((354019.2 6689140.4 13.7, 354025.3 6689139.9 13.7, 354033.8 6689139 13.7, 354038.8 6689138.3 13.7, 354046.7 6689137.5 13.7, 354047.5 6689135.2 13.7, 354040 6689134.6 13.7, 354040.2 6689133.8 13.7, 354036.6 6689133.4 13.7, 354036.5 6689132.8 13.7, 354021 6689134.4 13.7, 354019.9 6689137.9 13.7, 354019.2 6689140.4 13.7))
BATIMENT0000000302927348;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;90;90;3.1;9.5;12.6;19.2;10.8;Cadastre;A 1.0;POLYGON Z ((354047.6 6689139.3 12.6, 354048.8 6689141.4 12.6, 354051.6 6689140 12.6, 354053.6 6689133.6 12.6, 354048.6 6689132.1 12.6, 354047.5 6689135.2 12.6, 354046.7 6689137.5 12.6, 354047.6 6689139.3 12.6))
BATIMENT0000000302927352;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;35;20;16.4;8.3;24.7;26.7;9.5;Cadastre;A 1.0;POLYGON Z ((354067.8 6689132.8 24.7, 354064 6689131.6 24.7, 354062.9 6689135.2 24.7, 354061.5 6689136.1 24.7, 354067 6689145.9 24.7, 354071.2 6689143.5 24.7, 354071.5 6689144.1 24.7, 354078.3 6689140.6 24.7, 354078.1 6689139.9 24.7, 354081.1 6689138.5 24.7, 354080.7 6689137.1 24.7, 354080.4 6689135.7 24.7, 354080.2 6689134.3 24.7, 354080.1 6689132.8 24.7, 354080.1 6689131.4 24.7, 354076.6 6689130.5 24.7, 354076.6 6689130.1 24.7, 354069.6 6689127.8 24.7, 354067.8 6689132.8 24.7))
BATIMENT0000000302927349;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.9;10.3;20.2;24.4;11.4;Cadastre;;POLYGON Z ((354035.5 6689142.1 20.2, 354039.8 6689140.4 20.2, 354047.6 6689139.3 20.2, 354046.7 6689137.5 20.2, 354038.8 6689138.3 20.2, 354033.8 6689139 20.2, 354035.5 6689142.1 20.2))
BATIMENT0000000302927350;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.6;9.4;14.1;18.7;11.0;Cadastre;C 0.7;POLYGON Z ((354054.7 6689152.4 14.1, 354052.2 6689147.7 14.1, 354049.6 6689143 14.1, 354046.8 6689144.5 14.1, 354046 6689146.2 14.1, 354039.6 6689149.9 14.1, 354040 6689150.7 14.1, 354040.6 6689151.8 14.1, 354043.9 6689158.1 14.1, 354054.7 6689152.4 14.1))
BATIMENT0000000302927353;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;01;02;6.0;10.1;16.1;20.1;11.6;Cadastre;A 1.0;POLYGON Z ((354043.9 6689158.1 16.1, 354040.6 6689151.8 16.1, 354040 6689150.7 16.1, 354036.4 6689152.6 16.1, 354035.5 6689150.9 16.1, 354032.2 6689152.6 16.1, 354036.9 6689161.8 16.1, 354043.9 6689158.1 16.1))
BATIMENT0000000302929035;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;10;20;13.3;8.9;22.2;25.6;9.3;Cadastre;A 1.0;POLYGON Z ((354067.6 6689155.6 22.2, 354081.4 6689169.8 22.2, 354093.6 6689150.8 22.2, 354092.1 6689150.2 22.2, 354090.6 6689149.6 22.2, 354089.2 6689148.8 22.2, 354087.8 6689147.9 22.2, 354086.5 6689147 22.2, 354085.3 6689145.9 22.2, 354067.6 6689155.6 22.2))
BATIMENT0000000302927357;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;5.6;10.0;15.6;18.7;11.9;Cadastre;B 0.8;POLYGON Z ((354036.9 6689161.8 15.6, 354032.2 6689152.6 15.6, 354026 6689156 15.6, 354026.5 6689156.9 15.6, 354023.3 6689158.4 15.6, 354023.5 6689158.7 15.6, 354027.6 6689166.6 15.6, 354036.9 6689161.8 15.6))
BATIMENT0000000302928942;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.5;7.1;20.7;22.9;8.3;Cadastre;C 0.4;POLYGON Z ((354084.7 6689174.5 20.7, 354098.4 6689188.1 20.7, 354100.2 6689186.2 20.7, 354100.9 6689186.8 20.7, 354102.8 6689184.8 20.7, 354102.2 6689184.3 20.7, 354104.4 6689181.9 20.7, 354089.6 6689167.2 20.7, 354084.7 6689174.5 20.7))
BATIMENT0000000302927355;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;7.7;12.1;19.8;23.3;12.2;Cadastre;A 1.0;POLYGON Z ((354010.6 6689144 19.8, 354016.9 6689156.8 19.8, 354018.2 6689156.1 19.8, 354016 6689152 19.8, 354019.2 6689150.4 19.8, 354015.4 6689143.5 19.8, 354014.7 6689142.1 19.8, 354010.6 6689144 19.8))
BATIMENT0000000302927361;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.8;11.7;13.6;14.3;12.1;Cadastre;;POLYGON Z ((354020 6689151.6 13.6, 354018.9 6689152.3 13.6, 354020.2 6689155.1 13.6, 354021.4 6689154.6 13.6, 354020 6689151.6 13.6))
BATIMENT0000000302903585;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;12;20;8.6;13.2;21.8;24.4;14.7;Cadastre;A 1.0;POLYGON Z ((353980.5 6689148 21.8, 353980.2 6689147.4 21.8, 353977.4 6689149.2 21.8, 353977.6 6689150.1 21.8, 353975.4 6689151.1 21.8, 353973.6 6689147.8 21.8, 353982.1 6689146.4 21.8, 353981.9 6689144.8 21.8, 353973.4 6689145.6 21.8, 353971.2 6689145.9 21.8, 353980.5 6689163.5 21.8, 353982.1 6689162.6 21.8, 353980.7 6689160.2 21.8, 353989 6689155.5 21.8, 353983.9 6689146.1 21.8, 353980.5 6689148 21.8))
BATIMENT0000000302903587;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;11.2;16.0;17.2;13.8;Cadastre;;POLYGON Z ((353990.4 6689158.2 16, 353998.1 6689153.4 16, 353996.9 6689150.9 16, 353989 6689155.5 16, 353990.4 6689158.2 16))
BATIMENT0000000302927360;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;11.7;13.9;14.1;12.0;Cadastre;;POLYGON Z ((354020.9 6689156.5 13.9, 354022.2 6689156.1 13.9, 354021.4 6689154.6 13.9, 354020.2 6689155.1 13.9, 354020.9 6689156.5 13.9))
BATIMENT0000000302927358;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;11.6;14.3;14.8;12.0;Cadastre;;POLYGON Z ((354025 6689155 14.3, 354022.3 6689156.4 14.3, 354022.5 6689156.7 14.3, 354023.3 6689158.4 14.3, 354026.5 6689156.9 14.3, 354026 6689156 14.3, 354025 6689155 14.3))
BATIMENT0000000302903593;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;10.5;15.8;16.2;13.6;Cadastre;;POLYGON Z ((353996.3 6689156.6 15.8, 353998.5 6689160.8 15.8, 354001.1 6689159.3 15.8, 353998.8 6689155.1 15.8, 353996.3 6689156.6 15.8))
BATIMENT0000000302927359;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;7.5;10.9;18.5;22.6;12.0;Cadastre;A 0.5;POLYGON Z ((354017.3 6689157.6 18.5, 354023.2 6689169 18.5, 354027.6 6689166.6 18.5, 354023.5 6689158.7 18.5, 354023.3 6689158.4 18.5, 354021.2 6689159.5 18.5, 354019.8 6689156.8 18.5, 354018.8 6689157.2 18.5, 354018.2 6689156.1 18.5, 354016.9 6689156.8 18.5, 354017.3 6689157.6 18.5))
BATIMENT0000000302903586;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;13.6;16.1;16.6;14.2;Cadastre;;POLYGON Z ((353982.7 6689167.6 16.1, 353986.5 6689165.4 16.1, 353984.2 6689161.4 16.1, 353982.1 6689162.6 16.1, 353980.5 6689163.5 16.1, 353982.7 6689167.6 16.1))
BATIMENT0000000302927354;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;10;11.0;10.9;22.0;25.0;12.3;Cadastre;C 0.6;POLYGON Z ((354013.4 6689159.9 22, 354012.4 6689157.8 22, 354006.7 6689160.8 22, 354007.8 6689163 22, 354003.9 6689164.5 22, 354004.5 6689165.4 22, 354010.1 6689175.9 22, 354023.2 6689169 22, 354017.3 6689157.6 22, 354013.4 6689159.9 22))
BATIMENT0000000302903601;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;9.6;12.8;22.5;25.8;13.9;Cadastre;A 1.0;POLYGON Z ((353930.9 6689096.9 22.5, 353954.2 6689104.5 22.5, 353957.9 6689092.6 22.5, 353936.2 6689085.8 22.5, 353932.4 6689093.9 22.5, 353930.9 6689096.9 22.5))
BATIMENT0000000302904613;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;5.5;14.2;19.7;23.5;15.4;Cadastre;C 0.5;POLYGON Z ((353904.9 6689098.4 19.7, 353905.4 6689101.6 19.7, 353908.8 6689102.8 19.7, 353909.7 6689108 19.7, 353907.8 6689111.9 19.7, 353909.9 6689112.9 19.7, 353912.8 6689112 19.7, 353919.5 6689098.7 19.7, 353914.7 6689096.5 19.7, 353904.9 6689098.4 19.7))
BATIMENT0000000302905465;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;1987-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;35;20;10.3;15.9;26.3;35.2;17.2;Cadastre;C 0.3;POLYGON Z ((353899.5 6689128.9 26.3, 353901.1 6689137.3 26.3, 353905.1 6689140 26.3, 353908.6 6689133.2 26.3, 353899.5 6689128.9 26.3))
BATIMENT0000000302905464;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;15.7;21.7;29.5;17.2;Cadastre;;POLYGON Z ((353906 6689141.9 21.7, 353906.9 6689141.7 21.7, 353912.7 6689130 21.7, 353910.6 6689129 21.7, 353909.3 6689131.7 21.7, 353908.6 6689133.2 21.7, 353905.1 6689140 21.7, 353906 6689141.9 21.7))
BATIMENT0000000302903604;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1887-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;01;02;10.1;14.9;25.0;26.8;16.5;Cadastre;A 1.0;POLYGON Z ((353948.8 6689148.7 25, 353952 6689138.3 25, 353944.2 6689135.8 25, 353940 6689149.7 25, 353946.9 6689148.9 25, 353948.8 6689148.7 25))
BATIMENT0000000302903600;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;3.0;00;00;10.5;14.9;25.4;28.7;16.6;Cadastre;C 0.2;POLYGON Z ((353958.9 6689152.1 25.4, 353954.5 6689154.8 25.4, 353959.5 6689163.8 25.4, 353959.1 6689165.7 25.4, 353947.8 6689171.6 25.4, 353946.3 6689171.1 25.4, 353941.4 6689161.7 25.4, 353941.9 6689159.6 25.4, 353947.9 6689156.5 25.4, 353948.4 6689155.5 25.4, 353947.9 6689154.1 25.4, 353947.4 6689152.8 25.4, 353947 6689151.4 25.4, 353946.7 6689150.3 25.4, 353946.9 6689148.9 25.4, 353940 6689149.7 25.4, 353939.4 6689149.7 25.4, 353940.9 6689152.9 25.4, 353936 6689155.5 25.4, 353933.5 6689150.6 25.4, 353931.2 6689150.8 25.4, 353929.2 6689151 25.4, 353940.3 6689172.6 25.4, 353944.7 6689180.9 25.4, 353953.4 6689176.1 25.4, 353956 6689181 25.4, 353961.9 6689178.1 25.4, 353964.5 6689176.8 25.4, 353970.2 6689173.6 25.4, 353958.9 6689152.1 25.4))
BATIMENT0000000302904473;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;30;90;19.3;14.5;33.8;34.3;17.3;Cadastre;A 1.0;POLYGON Z ((353894.4 6689160.1 33.8, 353892.0022898072 6689161.3107249485 33.8, 353892.0022898072 6689180.883648085 33.8, 353898.1 6689193.3 33.8, 353908.5 6689188.1 33.8, 353894.4 6689160.1 33.8))
BATIMENT0000000302904470;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;8.7;13.3;22.0;24.5;16.3;Cadastre;A 1.0;POLYGON Z ((353955.8 6689204.4 22, 353951.6 6689195.9 22, 353941.3 6689201.3 22, 353945.6 6689209.7 22, 353955.8 6689204.4 22))
BATIMENT0000000302904472;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;6.0;30;40;11.2;13.4;24.6;33.9;15.9;Cadastre;A 1.0;POLYGON Z ((353912.6 6689222 24.6, 353918.3 6689224.1 24.6, 353945.6 6689209.7 24.6, 353941.3 6689201.3 24.6, 353940.4 6689199.5 24.6, 353919.8 6689210.2 24.6, 353908.5 6689188.1 24.6, 353898.1 6689193.3 24.6, 353912.6 6689222 24.6))
BATIMENT0000000302903432;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;7.3;13.1;20.5;23.5;15.3;Cadastre;A 1.0;POLYGON Z ((353952.9 6689228.5 20.5, 353948 6689219.4 20.5, 353938.9 6689224.1 20.5, 353943.8 6689233 20.5, 353944 6689233.5 20.5, 353952.9 6689228.5 20.5))
BATIMENT0000000302903596;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;13.7;17.5;18.2;14.9;Cadastre;;POLYGON Z ((353973.6 6689163.6 17.5, 353971.6 6689164.6 17.5, 353978.7 6689177.9 17.5, 353980.6 6689176.9 17.5, 353975.1 6689166.4 17.5, 353973.6 6689163.6 17.5))
BATIMENT0000000302903603;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;11.2;11.2;22.5;24.4;13.3;Cadastre;C 0.9;POLYGON Z ((353996.3 6689169.8 22.5, 354001.9 6689180.4 22.5, 354010.1 6689175.9 22.5, 354004.5 6689165.4 22.5, 353996.3 6689169.8 22.5))
BATIMENT0000000302903588;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;00;00;7.7;13.0;20.7;28.4;14.8;Cadastre;A 1.0;POLYGON Z ((353975.1 6689166.4 20.7, 353980.6 6689176.9 20.7, 353981.4 6689178.7 20.7, 353986.5 6689188.5 20.7, 353992.2 6689185.5 20.7, 353987 6689175.7 20.7, 353983.8 6689177.6 20.7, 353980.9 6689172.2 20.7, 353984.2 6689170.4 20.7, 353982.7 6689167.6 20.7, 353980.5 6689163.5 20.7, 353975.1 6689166.4 20.7))
BATIMENT0000000302903598;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.2;15.1;19.3;;;Cadastre;C 0.4;POLYGON Z ((353970.2 6689173.6 19.3, 353964.5 6689176.8 19.3, 353967.1 6689179.8 19.3, 353972.2 6689177.2 19.3, 353970.2 6689173.6 19.3))
BATIMENT0000000302903594;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;12;20;9.4;12.4;21.8;24.7;13.7;Cadastre;C 1.0;POLYGON Z ((354000.5 6689181.2 21.8, 353995.4 6689171.6 21.8, 353990.7 6689174 21.8, 353989.9 6689172.2 21.8, 353986.3 6689174.2 21.8, 353987 6689175.7 21.8, 353992.2 6689185.5 21.8, 354000.5 6689181.2 21.8))
BATIMENT0000000302903595;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;11.9;12.8;24.7;28.0;14.9;Cadastre;C 0.7;POLYGON Z ((353977.4 6689181 24.7, 353976.6 6689179.4 24.7, 353977.3 6689179.2 24.7, 353975.2 6689175.9 24.7, 353972.2 6689177.2 24.7, 353974.7 6689182.3 24.7, 353979.9 6689192 24.7, 353986.5 6689188.5 24.7, 353981.4 6689178.7 24.7, 353977.4 6689181 24.7))
BATIMENT0000000302903597;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;39;11.4;13.1;24.5;26.9;14.3;Cadastre;C 0.6;POLYGON Z ((353968.9 6689185.4 24.5, 353974.1 6689195.2 24.5, 353979.9 6689192 24.5, 353974.7 6689182.3 24.5, 353968.9 6689185.4 24.5))
BATIMENT0000000302904471;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.8;14.2;23.0;27.8;16.1;Cadastre;A 1.0;POLYGON Z ((353969.2 6689197.1 23, 353965.9 6689190.6 23, 353961.3 6689192.9 23, 353959.4 6689190 23, 353950.9 6689194.6 23, 353951.6 6689195.9 23, 353955.8 6689204.4 23, 353969.2 6689197.1 23))
BATIMENT0000000302927338;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;12.5;12.3;24.8;25.7;13.1;Cadastre;C 0.1;POLYGON Z ((354005.3 6689191.5 24.8, 354000.9 6689194 24.8, 354005.4 6689202.3 24.8, 354003.9 6689203.2 24.8, 354005 6689205.3 24.8, 354010.5 6689202.5 24.8, 354008.2 6689198.2 24.8, 354008.9 6689197.8 24.8, 354005.3 6689191.5 24.8))
BATIMENT0000000302927336;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;00;00;17.1;9.0;26.1;27.6;13.1;Cadastre;C 0.7;POLYGON Z ((354021.5 6689182.2 26.1, 354025.4 6689188.8 26.1, 354022.1 6689190.5 26.1, 354022.5 6689191.5 26.1, 354012.1 6689197.1 26.1, 354011.8 6689196.3 26.1, 354010.1 6689197.1 26.1, 354008.9 6689197.8 26.1, 354008.2 6689198.2 26.1, 354010.5 6689202.5 26.1, 354017 6689213.9 26.1, 354019 6689217.6 26.1, 354036.2 6689208.6 26.1, 354031.5 6689200 26.1, 354027.2 6689192.1 26.1, 354029.1 6689190.9 26.1, 354024 6689180.9 26.1, 354021.5 6689182.2 26.1))
BATIMENT0000000302903429;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;30;40;12.5;12.3;24.9;26.6;14.1;Cadastre;C 0.1;POLYGON Z ((353991.1 6689199.3 24.9, 353996.8 6689209.8 24.9, 354005 6689205.3 24.9, 354003.9 6689203.2 24.9, 354005.4 6689202.3 24.9, 354000.9 6689194 24.9, 353991.1 6689199.3 24.9))
BATIMENT0000000302906108;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;30;40;16.0;13.0;29.1;30.1;14.3;Cadastre;C 0.5;POLYGON Z ((353967.5 6689224.6 29.1, 353968.3 6689226.1 29.1, 353997.7 6689211.4 29.1, 353996.8 6689209.8 29.1, 353991.1 6689199.3 29.1, 353962.1 6689214.6 29.1, 353965.2 6689220.4 29.1, 353967.5 6689224.6 29.1))
BATIMENT0000000302903431;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;00;00;7.1;13.1;20.2;25.0;15.3;Cadastre;C 0.9;POLYGON Z ((353961.2 6689212.6 20.2, 353949.5 6689218.7 20.2, 353953.6 6689226.6 20.2, 353955.4 6689225.6 20.2, 353963.5 6689221.3 20.2, 353965.2 6689220.4 20.2, 353962.1 6689214.6 20.2, 353961.2 6689212.6 20.2))
BATIMENT0000000302903435;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;13.3;27.0;29.1;13.9;Cadastre;;POLYGON Z ((353965.8 6689225.5 27, 353967.5 6689224.6 27, 353965.2 6689220.4 27, 353963.5 6689221.3 27, 353965.8 6689225.5 27))
BATIMENT0000000302906074;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;30;40;3.8;10.7;14.5;26.0;14.3;Cadastre;C 0.3;POLYGON Z ((353972 6689233.2 14.5, 353976.6 6689241.6 14.5, 353978.7 6689245.7 14.5, 353979.2 6689246.5 14.5, 353984.3 6689243.6 14.5, 353983.1 6689241 14.5, 353987.9 6689238.4 14.5, 353984.5 6689232.1 14.5, 354003.4 6689222.2 14.5, 353997.7 6689211.4 14.5, 353968.3 6689226.1 14.5, 353968.6 6689226.7 14.5, 353972 6689233.2 14.5))
BATIMENT0000000302903433;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;13.4;16.6;18.7;15.3;Cadastre;;POLYGON Z ((353956.8 6689232.9 16.6, 353958.6 6689232.1 16.6, 353955.4 6689225.6 16.6, 353953.6 6689226.6 16.6, 353956.8 6689232.9 16.6))
BATIMENT0000000302903430;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;3.7;13.3;17.0;19.7;14.5;Cadastre;C 0.5;POLYGON Z ((353960 6689231.4 17, 353962.1 6689235.5 17, 353965 6689233.9 17, 353966.2 6689236.2 17, 353972 6689233.2 17, 353968.6 6689226.7 17, 353960 6689231.4 17))
BATIMENT0000000302903436;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;13.6;17.0;17.1;15.0;Cadastre;;POLYGON Z ((353959.3 6689237.6 17, 353961 6689236.6 17, 353958.6 6689232.1 17, 353956.8 6689232.9 17, 353959.3 6689237.6 17))
BATIMENT0000000302903434;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;12.7;16.3;16.9;14.2;Cadastre;;POLYGON Z ((353973.6 6689243.2 16.3, 353975.8 6689247 16.3, 353978.7 6689245.7 16.3, 353976.6 6689241.6 16.3, 353973.6 6689243.2 16.3))
BATIMENT0000000302905941;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;11.0;;;;Cadastre;;POLYGON Z ((353978.9 6689253.1 -1000, 353980.5 6689256.5 -1000, 353983.7 6689254.9 -1000, 353981.7 6689251.4 -1000, 353978.9 6689253.1 -1000))
BATIMENT0000000302927339;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;13.7;9.0;22.7;25.0;10.5;Cadastre;C 0.8;POLYGON Z ((354044.3 6689182.8 22.7, 354046.5 6689186.5 22.7, 354056.8 6689181 22.7, 354063.6 6689187.8 22.7, 354064.9 6689186.7 22.7, 354066 6689187.5 22.7, 354072.6 6689180.8 22.7, 354060.8 6689169.1 22.7, 354058.8 6689170.4 22.7, 354057.7 6689169 22.7, 354055.4 6689170.3 22.7, 354054.6 6689169.2 22.7, 354043.1 6689175.2 22.7, 354040.4 6689177 22.7, 354043.9 6689183 22.7, 354044.3 6689182.8 22.7))
BATIMENT0000000302927337;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;13.6;9.0;22.6;24.9;12.0;Cadastre;C 0.1;POLYGON Z ((354040.9 6689171.8 22.6, 354024.5 6689180.5 22.6, 354024 6689180.9 22.6, 354029.1 6689190.9 22.6, 354029.8 6689190.7 22.6, 354034.5 6689188 22.6, 354031.1 6689181.6 22.6, 354035.3 6689179.6 22.6, 354038.9 6689185.9 22.6, 354043.9 6689183 22.6, 354040.4 6689177 22.6, 354043.1 6689175.2 22.6, 354040.9 6689171.8 22.6))
BATIMENT0000000302927340;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.8;9.0;22.8;24.9;11.0;Cadastre;;POLYGON Z ((354035.1 6689187.7 22.8, 354035.9 6689189 22.8, 354038.6 6689187.2 22.8, 354038.1 6689186.3 22.8, 354038.9 6689185.9 22.8, 354035.3 6689179.6 22.8, 354031.1 6689181.6 22.8, 354034.5 6689188 22.8, 354035.1 6689187.7 22.8))
BATIMENT0000000302927341;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;12.9;8.9;21.8;22.2;10.5;Cadastre;C 0.4;POLYGON Z ((354068.4 6689192.6 21.8, 354076.4 6689184.5 21.8, 354072.6 6689180.8 21.8, 354066 6689187.5 21.8, 354064.9 6689186.7 21.8, 354063.6 6689187.8 21.8, 354068.4 6689192.6 21.8))
BATIMENT0000000302927342;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;00;00;12.5;7.6;20.1;23.7;10.6;Cadastre;C 0.1;POLYGON Z ((354081 6689205.4 20.1, 354082.3 6689204.1 20.1, 354083.1 6689203.2 20.1, 354091.6 6689194.8 20.1, 354093 6689193.4 20.1, 354085.6 6689185.5 20.1, 354081.4 6689189.5 20.1, 354076.4 6689184.5 20.1, 354068.4 6689192.6 20.1, 354081 6689205.4 20.1))
BATIMENT0000000302927343;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;34.0;6.0;00;00;16.6;6.9;23.6;25.5;10.5;Cadastre;A 1.0;POLYGON Z ((354087.2 6689208.9 23.6, 354087.6 6689208.5 23.6, 354093 6689213.8 23.6, 354094 6689212.5 23.6, 354098.5 6689216.8 23.6, 354081.7 6689233.6 23.6, 354088 6689239.9 23.6, 354089.9 6689241.9 23.6, 354094.4 6689237.2 23.6, 354094.8 6689237.6 23.6, 354095.2 6689237.6 23.6, 354095.7 6689237.4 23.6, 354115 6689218.3 23.6, 354114.9 6689215.2 23.6, 354094.4 6689194.8 23.6, 354093.1 6689196.2 23.6, 354091.6 6689194.8 23.6, 354083.1 6689203.2 23.6, 354082.3 6689204.1 23.6, 354087.2 6689208.9 23.6))
BATIMENT0000000302927345;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;7.2;24.1;26.0;8.6;Cadastre;;POLYGON Z ((354089.9 6689241.9 24.1, 354088 6689239.9 24.1, 354084 6689243.8 24.1, 354085.9 6689245.8 24.1, 354089.9 6689241.9 24.1))
BATIMENT0000000302928763;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;8.9;7.0;16.0;18.4;7.6;Cadastre;A 1.0;POLYGON Z ((354108.5 6689260.6 16, 354102.6 6689254.5 16, 354097.9 6689259.1 16, 354104.3 6689265.4 16, 354108.9 6689260.9 16, 354108.5 6689260.6 16))
BATIMENT0000000302927344;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;69.0;6.0;00;00;18.2;7.7;26.0;29.0;10.3;Cadastre;A 1.0;POLYGON Z ((354044.9 6689286.1 26, 354045.6 6689286.8 26, 354062.1 6689270.5 26, 354061.5 6689269.8 26, 354069.5 6689261.7 26, 354070.3 6689262.5 26, 354086.5 6689246.4 26, 354085.9 6689245.8 26, 354084 6689243.8 26, 354088 6689239.9 26, 354081.7 6689233.6 26, 354080.6 6689232.5 26, 354076.7 6689236.3 26, 354076.1 6689235.9 26, 354059.7 6689252.3 26, 354060.4 6689252.9 26, 354052.2 6689260.8 26, 354051.7 6689260.2 26, 354035.4 6689276.4 26, 354036.1 6689277.1 26, 354034 6689279.2 26, 354040.1 6689290.8 26, 354044.9 6689286.1 26))
BATIMENT0000000302928761;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.0;7.1;16.2;18.6;7.7;Cadastre;A 1.0;POLYGON Z ((354104.3 6689265.4 16.2, 354097.9 6689259.1 16.2, 354093.3 6689263.6 16.2, 354099.7 6689270 16.2, 354104.3 6689265.4 16.2))
BATIMENT0000000302903495;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;23;7.9;15.1;23.0;25.2;18.3;Cadastre;A 1.0;POLYGON Z ((353896.3 6689231.3 23, 353892.0022898072 6689222.53604196 23, 353892.0022898072 6689233.376421778 23, 353896.3 6689231.3 23))
BATIMENT0000000302903438;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;40;30;15.4;13.0;28.5;31.6;15.2;Cadastre;A 1.0;POLYGON Z ((353922.4 6689232.8 28.5, 353920.6 6689238.6 28.5, 353922.6 6689242.6 28.5, 353932 6689237.5 28.5, 353933 6689239.3 28.5, 353939.1 6689235.6 28.5, 353943.8 6689233 28.5, 353938.9 6689224.1 28.5, 353922.4 6689232.8 28.5))
BATIMENT0000000302903487;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.7;14.6;22.3;25.3;17.9;Cadastre;A 1.0;POLYGON Z ((353901.2 6689241.2 22.3, 353896.3 6689231.3 22.3, 353892.0022898072 6689233.376421778 22.3, 353892.0022898072 6689245.607236134 22.3, 353901.2 6689241.2 22.3))
BATIMENT0000000302903437;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;11.5;16.1;23.5;15.3;Cadastre;;POLYGON Z ((353944.1 6689245.4 16.1, 353949.1 6689242.7 16.1, 353944 6689233.5 16.1, 353943.8 6689233 16.1, 353939.1 6689235.6 16.1, 353944.1 6689245.4 16.1))
BATIMENT0000000302903440;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;30;40;18.1;12.9;31.1;31.4;13.6;Cadastre;C 0.7;POLYGON Z ((353928.2 6689253.9 31.1, 353936.6 6689249.4 31.1, 353935 6689246.2 31.1, 353936.1 6689245.5 31.1, 353933 6689239.3 31.1, 353932 6689237.5 31.1, 353922.6 6689242.6 31.1, 353928.2 6689253.9 31.1))
BATIMENT0000000302903483;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;16;20;7.9;14.4;22.3;25.9;16.4;Cadastre;A 1.0;POLYGON Z ((353894.1 6689252 22.3, 353897.9 6689250.3 22.3, 353904.2 6689247.2 22.3, 353901.2 6689241.2 22.3, 353892.0022898072 6689245.607236134 22.3, 353892.0022898072 6689247.579824951 22.3, 353894.1 6689252 22.3))
BATIMENT0000000302903481;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;10.9;13.0;24.0;24.8;16.3;Cadastre;A 1.0;POLYGON Z ((353899.6 6689253.9 24, 353896.7 6689255.4 24, 353897.1 6689256.6 24, 353896.2 6689257.2 24, 353897.9 6689260.3 24, 353898.7 6689259.8 24, 353901 6689264.1 24, 353898.5 6689265.2 24, 353899 6689266.2 24, 353902.2 6689265 24, 353910.9 6689260.5 24, 353904.2 6689247.2 24, 353897.9 6689250.3 24, 353899.6 6689253.9 24))
BATIMENT0000000302903444;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.5;12.6;23.2;28.0;14.7;Cadastre;A 1.0;POLYGON Z ((353935.3 6689267.9 23.2, 353945.3 6689262.8 23.2, 353946.7 6689262 23.2, 353939.7 6689247.9 23.2, 353936.6 6689249.4 23.2, 353928.2 6689253.9 23.2, 353935.3 6689267.9 23.2))
BATIMENT0000000302903478;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;23;10.4;12.8;23.2;25.1;16.3;Cadastre;A 1.0;POLYGON Z ((353910.9 6689260.5 23.2, 353902.2 6689265 23.2, 353904.9 6689271.1 23.2, 353913.8 6689266.9 23.2, 353910.9 6689260.5 23.2))
BATIMENT0000000302903447;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.8;12.3;21.1;23.4;13.7;Cadastre;A 1.0;POLYGON Z ((353938.2 6689274 21.1, 353946.7 6689269.6 21.1, 353948.3 6689268.7 21.1, 353945.3 6689262.8 21.1, 353935.3 6689267.9 21.1, 353938.2 6689274 21.1))
BATIMENT0000000302903479;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;13.9;19.4;23.2;16.6;Cadastre;;POLYGON Z ((353897.8 6689265.6 19.4, 353900.2 6689270.5 19.4, 353901.9 6689269.9 19.4, 353903 6689272 19.4, 353904.9 6689271.1 19.4, 353902.2 6689265 19.4, 353899 6689266.2 19.4, 353898.5 6689265.2 19.4, 353897.8 6689265.6 19.4))
BATIMENT0000000302903477;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.7;12.6;23.4;28.5;16.9;Cadastre;A 1.0;POLYGON Z ((353917.9 6689274.9 23.4, 353913.8 6689266.9 23.4, 353904.9 6689271.1 23.4, 353903 6689272 23.4, 353903.4 6689272.9 23.4, 353904.3 6689275 23.4, 353905.8 6689275.4 23.4, 353907.9 6689280 23.4, 353908.9 6689279.4 23.4, 353917.9 6689274.9 23.4))
BATIMENT0000000302903448;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;6.2;11.9;18.2;24.2;13.6;Cadastre;A 1.0;POLYGON Z ((353942.6 6689282.9 18.2, 353951.1 6689278.4 18.2, 353954.8 6689276.5 18.2, 353953.5 6689273.9 18.2, 353954.7 6689273.3 18.2, 353953.4 6689270.4 18.2, 353952.1 6689271.1 18.2, 353950.3 6689267.6 18.2, 353948.3 6689268.7 18.2, 353946.7 6689269.6 18.2, 353938.2 6689274 18.2, 353942.6 6689282.9 18.2))
BATIMENT0000000302903480;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;15;23;16.8;12.3;29.2;32.1;16.1;Cadastre;A 1.0;POLYGON Z ((353907.9 6689280 29.2, 353906.9 6689280.5 29.2, 353913.1 6689292.6 29.2, 353913.5 6689292.5 29.2, 353924 6689287.2 29.2, 353917.9 6689274.9 29.2, 353908.9 6689279.4 29.2, 353907.9 6689280 29.2))
BATIMENT0000000302905967;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.9;16.2;26.2;34.1;17.1;Cadastre;;POLYGON Z ((353896.1 6689289.9 26.2, 353900.3 6689298.3 26.2, 353900.6 6689298.2 26.2, 353903 6689297 26.2, 353898.8 6689288.7 26.2, 353896.1 6689289.9 26.2))
BATIMENT0000000302903482;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.6;12.0;22.7;26.2;15.1;Cadastre;A 1.0;POLYGON Z ((353915.6 6689296.8 22.7, 353916 6689296.7 22.7, 353918.5 6689301.7 22.7, 353920.5 6689300.8 22.7, 353923.6 6689307 22.7, 353931.9 6689303.4 22.7, 353924 6689287.2 22.7, 353913.5 6689292.5 22.7, 353915.6 6689296.8 22.7))
BATIMENT0000000302903485;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.2;11.7;22.0;24.1;14.6;Cadastre;A 1.0;POLYGON Z ((353923.1 6689307.2 22, 353923.4 6689307.6 22, 353926.1 6689313.5 22, 353927 6689313.3 22, 353935 6689309.8 22, 353931.9 6689303.4 22, 353923.6 6689307 22, 353923.1 6689307.2 22))
BATIMENT0000000302903484;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;13.1;17.5;21.0;14.6;Cadastre;;POLYGON Z ((353920.3 6689309 17.5, 353923.4 6689314.9 17.5, 353926.1 6689313.5 17.5, 353923.4 6689307.6 17.5, 353920.3 6689309 17.5))
BATIMENT0000000302903471;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;14.5;18.1;20.5;16.4;Cadastre;;POLYGON Z ((353909.9 6689312.5 18.1, 353911 6689311.8 18.1, 353910 6689310.3 18.1, 353908.8 6689309.4 18.1, 353906.6 6689310.1 18.1, 353908.1 6689313.4 18.1, 353909.9 6689312.5 18.1))
BATIMENT0000000302903469;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;15.7;18.6;20.9;16.4;Cadastre;;POLYGON Z ((353906 6689309.2 18.6, 353902.5 6689312.9 18.6, 353909.5 6689322 18.6, 353911.1 6689319.8 18.6, 353911.1 6689319.6 18.6, 353909.2 6689315.7 18.6, 353908.1 6689313.4 18.6, 353906.6 6689310.1 18.6, 353906 6689309.2 18.6))
BATIMENT0000000302928980;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;10;20;7.9;7.3;15.2;17.7;8.7;Cadastre;A 1.0;POLYGON Z ((354146.7 6689062.7 15.2, 354144.2 6689066.4 15.2, 354145 6689066.9 15.2, 354148.4 6689069.3 15.2, 354161.3 6689050.3 15.2, 354157 6689047.5 15.2, 354146.7 6689062.7 15.2))
BATIMENT0000000302929202;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1973-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;8.0;;;23.7;6.8;30.6;31.7;8.8;Cadastre;C 0.4;POLYGON Z ((354139.5 6689060.5 30.6, 354129.9 6689054 30.6, 354113.5 6689078.3 30.6, 354118.7 6689091.3 30.6, 354139.5 6689060.5 30.6))
BATIMENT0000000302929200;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1973-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;8.0;30;40;9.2;7.5;16.7;31.8;8.5;Cadastre;C 0.3;POLYGON Z ((354105.4 6689110.1 16.7, 354106.5 6689110.4 16.7, 354107.7 6689110.8 16.7, 354108.8 6689111.3 16.7, 354109.9 6689111.9 16.7, 354111 6689112.5 16.7, 354111.9 6689113.2 16.7, 354124.3 6689094.9 16.7, 354118.7 6689091.3 16.7, 354113.5 6689078.3 16.7, 354109.4 6689078 16.7, 354098.4 6689081.5 16.7, 354092.7 6689084.4 16.7, 354105.4 6689110.1 16.7))
BATIMENT0000000302929197;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;7.0;35;40;3.1;7.1;10.2;23.2;7.5;Cadastre;C 0.1;POLYGON Z ((354142.1 6689130.3 10.2, 354147.6 6689127.7 10.2, 354147.7 6689127 10.2, 354129.8 6689123.6 10.2, 354131.3 6689115 10.2, 354140.9 6689116.5 10.2, 354144.8 6689090.9 10.2, 354154.4 6689093.4 10.2, 354156.3 6689083.9 10.2, 354146.4 6689082 10.2, 354123.9 6689115.4 10.2, 354125.2 6689121.3 10.2, 354142.1 6689130.3 10.2))
BATIMENT0000000302929196;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;35;40;15.9;7.1;23.0;27.1;7.4;Cadastre;C 0.6;POLYGON Z ((354147.7 6689127 23, 354154.4 6689093.4 23, 354144.8 6689090.9 23, 354140.9 6689116.5 23, 354131.3 6689115 23, 354129.8 6689123.6 23, 354147.7 6689127 23))
BATIMENT0000000302928905;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;15.3;7.0;22.3;22.6;7.6;Cadastre;A 1.0;POLYGON Z ((354167.2 6689090.3 22.3, 354157.5 6689140.8 22.3, 354160.2 6689145.2 22.3, 354173.3 6689148.1 22.3, 354179.9 6689143.6 22.3, 354189.2 6689095 22.3, 354186.1 6689090.4 22.3, 354171.5 6689087.7 22.3, 354167.2 6689090.3 22.3))
BATIMENT0000000302929026;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.9;7.0;23.0;26.2;7.7;Cadastre;C 0.1;POLYGON Z ((354143.8 6689150.1 23, 354136 6689147.7 23, 354119.2 6689142.6 23, 354118.6 6689143.6 23, 354117.5 6689145.1 23, 354116.2 6689146.6 23, 354115.1 6689147.7 23, 354113.9 6689148.7 23, 354112.2 6689149.9 23, 354110.5 6689150.8 23, 354108 6689153.9 23, 354106.5 6689152.4 23, 354104.2 6689152.8 23, 354102.1 6689153 23, 354097.9 6689159.5 23, 354103.1 6689164.7 23, 354102.1 6689165.9 23, 354109.2 6689172.5 23, 354116.1 6689165.6 23, 354122 6689171.6 23, 354122.4 6689171.3 23, 354124.8 6689173.9 23, 354135.3 6689163.8 23, 354145.2 6689174.3 23, 354146 6689175 23, 354153 6689182.2 23, 354161.5 6689173.8 23, 354164.6 6689156.5 23, 354143.8 6689150.1 23))
BATIMENT0000000302929025;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;6.0;30;30;16.1;8.0;24.1;;;Cadastre;A 1.0;POLYGON Z ((354118 6689201.7 24.1, 354125.3 6689209 24.1, 354153 6689182.2 24.1, 354146 6689175 24.1, 354145.2 6689174.3 24.1, 354118 6689201.7 24.1))
BATIMENT0000000302928793;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;5.6;7.4;13.0;15.0;7.4;Cadastre;A 1.0;POLYGON Z ((354171.5 6689190.6 13, 354168.5 6689189.9 13, 354160.6 6689197.7 13, 354164 6689198.6 13, 354169.7 6689199.7 13, 354171.5 6689190.6 13))
BATIMENT0000000302928794;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;6.7;12.7;13.4;7.8;Cadastre;;POLYGON Z ((354158.5 6689199.8 12.7, 354161.3 6689201.5 12.7, 354164 6689198.6 12.7, 354160.6 6689197.7 12.7, 354158.5 6689199.8 12.7))
BATIMENT0000000302928991;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;00;00;11.4;6.3;17.7;21.4;7.8;Cadastre;C 0.8;POLYGON Z ((354261.2 6689095.5 17.7, 354261 6689096.7 17.7, 354264.7 6689097.4 17.7, 354264.7 6689097.3 17.7, 354267.1 6689084.3 17.7, 354264 6689083.6 17.7, 354264.3 6689082.1 17.7, 354261.5 6689081.6 17.7, 354261.8 6689080.6 17.7, 354249.8 6689078.4 17.7, 354249.6 6689079.6 17.7, 354246.7 6689079 17.7, 354246.3 6689080.7 17.7, 354243.8 6689080.2 17.7, 354243.5 6689081.8 17.7, 354242.9 6689085.2 17.7, 354241.7 6689091.8 17.7, 354261.2 6689095.5 17.7))
BATIMENT0000000302928993;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.5;7.1;16.6;;;Cadastre;;POLYGON Z ((354261 6689096.7 16.6, 354261.2 6689095.5 16.6, 354241.7 6689091.8 16.6, 354241.5 6689093.1 16.6, 354261 6689096.7 16.6))
BATIMENT0000000302928719;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;10;20;9.6;6.9;16.5;18.0;8.4;Cadastre;A 1.0;POLYGON Z ((354205.9 6689092.8 16.5, 354203.8 6689104 16.5, 354204.2 6689104 16.5, 354217.8 6689106.6 16.5, 354225.3 6689108.1 16.5, 354227.5 6689096.9 16.5, 354205.9 6689092.8 16.5))
BATIMENT0000000302928718;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;7.8;14.1;14.6;9.6;Cadastre;;POLYGON Z ((354264.8 6689115.1 14.1, 354265.4 6689111.8 14.1, 354236.8 6689106.5 14.1, 354236.2 6689109.7 14.1, 354264.8 6689115.1 14.1))
BATIMENT0000000302928717;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.5;7.6;14.1;16.6;9.6;Cadastre;;POLYGON Z ((354230.6 6689137.6 14.1, 354236.2 6689109.7 14.1, 354236.8 6689106.5 14.1, 354265.4 6689111.8 14.1, 354266.8 6689112 14.1, 354268.2 6689110.5 14.1, 354272.8 6689105.7 14.1, 354227.5 6689096.9 14.1, 354225.3 6689108.1 14.1, 354220.1 6689135.5 14.1, 354230.6 6689137.6 14.1))
BATIMENT0000000302928716;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;7.3;10.8;14.0;8.7;Cadastre;;POLYGON Z ((354212.3 6689137.3 10.8, 354219.4 6689138.7 10.8, 354220.1 6689135.5 10.8, 354225.3 6689108.1 10.8, 354217.8 6689106.6 10.8, 354212.3 6689137.3 10.8))
BATIMENT0000000302928723;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;7.9;15.9;20.4;11.3;Cadastre;;POLYGON Z ((354266 6689122 15.9, 354263.2 6689132.8 15.9, 354263.9 6689133 15.9, 354257.1 6689157 15.9, 354267.5 6689157.7 15.9, 354273.7 6689135.6 15.9, 354274.6 6689135.8 15.9, 354277.4 6689125.2 15.9, 354266.6 6689122.2 15.9, 354266 6689122 15.9))
BATIMENT0000000302928715;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;7.2;16.2;16.6;8.4;Cadastre;;POLYGON Z ((354198.4 6689134.7 16.2, 354196.3 6689145.5 16.2, 354199.6 6689145.8 16.2, 354199.1 6689150.1 16.2, 354199.3 6689151.6 16.2, 354200.7 6689152.3 16.2, 354209.4 6689153.8 16.2, 354216.3 6689154.3 16.2, 354219.4 6689138.7 16.2, 354212.3 6689137.3 16.2, 354198.4 6689134.7 16.2))
BATIMENT0000000302928714;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:20;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;7.9;14.2;15.3;9.6;Cadastre;;POLYGON Z ((354227.3 6689155.1 14.2, 354230.6 6689137.6 14.2, 354220.1 6689135.5 14.2, 354219.4 6689138.7 14.2, 354216.3 6689154.3 14.2, 354227.3 6689155.1 14.2))
BATIMENT0000000302928693;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.8;10.0;22.8;23.6;16.0;Cadastre;C 0.1;POLYGON Z ((354246.7 6689166.5 22.8, 354246 6689178.2 22.8, 354253.6 6689178.7 22.8, 354259.6 6689179.1 22.8, 354259.5 6689180.6 22.8, 354259.3 6689183.9 22.8, 354262.1 6689184.1 22.8, 354262.2 6689181.2 22.8, 354262.3 6689179.2 22.8, 354268.3 6689179.4 22.8, 354268.1 6689180.4 22.8, 354270 6689180.4 22.8, 354270.1 6689179.7 22.8, 354277.6 6689180.2 22.8, 354280.4 6689180.4 22.8, 354280.6 6689178.6 22.8, 354281.5 6689170.8 22.8, 354281.7 6689168.9 22.8, 354246.7 6689166.5 22.8))
BATIMENT0000000302928795;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;50;10;6.0;7.4;13.4;16.6;8.0;Cadastre;A 1.0;POLYGON Z ((354160.6 6689205 13.4, 354165.8 6689206.1 13.4, 354168.6 6689206.4 13.4, 354169.7 6689199.7 13.4, 354164 6689198.6 13.4, 354161.3 6689201.5 13.4, 354160.6 6689205 13.4))
BATIMENT0000000302928797;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.3;7.4;13.7;16.0;8.0;Cadastre;A 1.0;POLYGON Z ((354159.7 6689204.1 13.7, 354156.9 6689201.3 13.7, 354148.6 6689209.4 13.7, 354151.6 6689212 13.7, 354158.1 6689205.7 13.7, 354159.7 6689204.1 13.7))
BATIMENT0000000302928798;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;7.3;13.0;13.6;7.9;Cadastre;;POLYGON Z ((354165.6 6689207.9 13, 354168.3 6689208.4 13, 354168.6 6689206.4 13, 354165.8 6689206.1 13, 354165.6 6689207.9 13))
BATIMENT0000000302928796;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;30;30;8.9;6.8;15.7;17.8;8.0;Cadastre;A 1.0;POLYGON Z ((354158.9 6689206.6 15.7, 354159.1 6689205.6 15.7, 354158.1 6689205.7 15.7, 354151.6 6689212 15.7, 354156.9 6689217.4 15.7, 354159.2 6689215 15.7, 354166.7 6689216.5 15.7, 354168.3 6689208.4 15.7, 354165.6 6689207.9 15.7, 354158.9 6689206.6 15.7))
BATIMENT0000000302928800;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;15;20;10.4;7.0;17.4;19.0;8.2;Cadastre;A 1.0;POLYGON Z ((354166.7 6689216.5 17.4, 354159.2 6689215 17.4, 354156.9 6689217.4 17.4, 354152.4 6689221.9 17.4, 354165.2 6689224 17.4, 354166.7 6689216.5 17.4))
BATIMENT0000000302928799;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;14;20;7.6;7.4;15.0;18.7;7.5;Cadastre;B 0.6;POLYGON Z ((354137.8 6689220 15, 354148.7 6689230.9 15, 354149.3 6689228.1 15, 354147 6689225.8 15, 354151.3 6689221.6 15, 354152.4 6689221.9 15, 354156.9 6689217.4 15, 354151.6 6689212 15, 354148.6 6689209.4 15, 354137.8 6689220 15))
BATIMENT0000000302928801;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;7.9;7.1;15.0;18.8;8.7;Cadastre;B 1.0;POLYGON Z ((354150.2 6689232.3 15, 354153.1 6689235.3 15, 354162.7 6689237.1 15, 354165.2 6689224 15, 354152.4 6689221.9 15, 354150.2 6689232.3 15))
BATIMENT0000000302928768;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.0;6.6;14.7;17.5;7.7;Cadastre;A 1.0;POLYGON Z ((354123 6689246.9 14.7, 354128.3 6689241.7 14.7, 354122.3 6689235.3 14.7, 354116.8 6689240.6 14.7, 354123 6689246.9 14.7))
BATIMENT0000000302928767;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1943-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.8;6.8;14.7;18.0;7.7;Cadastre;A 1.0;POLYGON Z ((354123 6689246.9 14.7, 354116.8 6689240.6 14.7, 354112.3 6689245.1 14.7, 354118.3 6689251.3 14.7, 354119.9 6689249.5 14.7, 354121.4 6689251 14.7, 354124.3 6689248.2 14.7, 354123 6689246.9 14.7))
BATIMENT0000000302928802;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.3;7.0;18.3;20.2;9.6;Cadastre;A 1.0;POLYGON Z ((354162.7 6689237.1 18.3, 354153.1 6689235.3 18.3, 354152 6689240.2 18.3, 354150.4 6689241.4 18.3, 354148.8 6689248.7 18.3, 354150.2 6689250.2 18.3, 354148.7 6689258.2 18.3, 354158.4 6689260.2 18.3, 354159.3 6689255.7 18.3, 354162.7 6689237.1 18.3))
BATIMENT0000000302928692;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.2;10.8;23.0;23.3;11.8;Cadastre;;POLYGON Z ((354255.1 6689179.2 23, 354256.6 6689179.7 23, 354258 6689180.2 23, 354259.5 6689180.6 23, 354259.6 6689179.1 23, 354253.6 6689178.7 23, 354255.1 6689179.2 23))
BATIMENT0000000302928877;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;8.7;7.2;16.0;19.2;7.9;Cadastre;A 1.0;POLYGON Z ((354206.5 6689181.4 16, 354197.8 6689225.7 16, 354212.1 6689228.4 16, 354215.3 6689212.9 16, 354221.2 6689184.1 16, 354206.5 6689181.4 16))
BATIMENT0000000302928878;Industriel, agricole ou commercial;Sportif;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.2;7.5;20.7;25.1;14.4;Cadastre;A 1.0;POLYGON Z ((354221.4 6689182.5 20.7, 354221.6 6689182.5 20.7, 354221.2 6689184.1 20.7, 354215.3 6689212.9 20.7, 354212.1 6689228.4 20.7, 354233.5 6689232.4 20.7, 354237.1 6689214.2 20.7, 354233.9 6689213.6 20.7, 354240 6689182.8 20.7, 354222 6689179.4 20.7, 354221.4 6689182.5 20.7))
BATIMENT0000002275362603;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.5;12.4;;;;Imagerie aérienne;;POLYGON Z ((354273.8 6689219.4 25.4, 354271.4 6689219.3 26.2, 354271.5 6689217.7 23, 354266.4 6689216 23, 354260.9 6689216 23, 354260.4 6689218.3 25.5, 354259.6 6689221.8 25.5, 354257.5 6689221.8 25.5, 354257.9 6689211.8 22.7, 354258.4 6689202.1 22.7, 354259.3 6689189.9 20.5, 354252.1 6689186.3 20.5, 354244.8 6689184.7 20.5, 354244.5 6689189.4 20.5, 354245.9 6689189.5 22.4, 354245.2 6689199.7 22.4, 354243.6 6689199.7 22.4, 354242.8 6689220.6 25.7, 354242.3 6689220.7 25.7, 354241.5 6689231.4 25.7, 354243.1 6689235.8 25.6, 354256.7 6689235.6 25.9, 354256.8 6689233.4 27.9, 354257.3 6689224.9 27.9, 354259.9 6689225 25.7, 354260 6689229.2 25.7, 354265.7 6689230.7 25.1, 354268.5 6689230.5 25.1, 354275 6689230.7 22.6, 354275.9 6689226.8 22.6, 354277.1 6689225.6 22.6, 354276.9 6689219.6 22.6, 354273.8 6689219.4 25.4))
BATIMENT0000000302929194;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;6.3;11.5;14.0;13.1;Cadastre;;POLYGON Z ((354231.2 6689245.5 11.5, 354231.8 6689239.9 11.5, 354190.4 6689232.8 11.5, 354189.6 6689237.8 11.5, 354231.2 6689245.5 11.5))
BATIMENT0000000302929195;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;98.0;6.0;00;00;15.3;8.6;24.0;29.2;13.1;Cadastre;C 0.7;POLYGON Z ((354178.4 6689297.3 24, 354182 6689297.9 24, 354183.1 6689295.2 24, 354181.9 6689292.8 24, 354182.4 6689290.9 24, 354183.6 6689291.1 24, 354184.5 6689283.9 24, 354187.9 6689284.3 24, 354191.4 6689276.3 24, 354186.1 6689275.3 24, 354189.5 6689256.1 24, 354190.1 6689255.7 24, 354201.2 6689257.7 24, 354200.9 6689259.1 24, 354209.7 6689261.8 24, 354210.2 6689259.3 24, 354213 6689259.8 24, 354212.5 6689262.2 24, 354221.6 6689263.2 24, 354221.8 6689261.9 24, 354228.4 6689262.4 24, 354229.4 6689257.1 24, 354229.9 6689257.4 24, 354231.2 6689245.5 24, 354189.6 6689237.8 24, 354178.4 6689235.8 24, 354172.9 6689265.8 24, 354167.6 6689295.2 24, 354178.4 6689297.3 24))
BATIMENT0000000302929104;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;7.5;14.4;22.0;26.2;16.7;Cadastre;A 0.2;POLYGON Z ((354230.4 6689271.8 22, 354231.2 6689275.8 22, 354234.3 6689275 22, 354234.5 6689270.7 22, 354230.4 6689271.8 22))
BATIMENT0000000327814962;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;17.0;2.0;00;00;5.2;18.4;;;;Imagerie aérienne;C 0.5;POLYGON Z ((354263.9 6689295.1 23.6, 354258.3 6689295.1 23.6, 354258.2 6689291 23.6, 354263.8 6689291 23.6, 354263.8 6689283.5 23.6, 354258.3 6689283.5 23.6, 354258.3 6689279.3 23.6, 354263.8 6689279.4 23.6, 354263.9 6689271.7 23.6, 354258.4 6689271.7 23.6, 354258.4 6689267.5 23.6, 354263.6 6689267.5 23.6, 354263.6 6689260.7 23.6, 354252.1 6689260.7 23.6, 354252 6689269.8 23.6, 354246 6689269.8 23.6, 354246 6689304.9 23.6, 354258.4 6689305 23.6, 354258.3 6689302.8 23.6, 354263.6 6689302.7 23.5, 354263.9 6689295.1 23.6))
BATIMENT0000000302928818;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;9.9;24.1;25.5;11.9;Cadastre;;POLYGON Z ((354187.9 6689284.3 24.1, 354184.5 6689283.9 24.1, 354183.6 6689291.1 24.1, 354182.4 6689290.9 24.1, 354181.9 6689292.8 24.1, 354183.1 6689295.2 24.1, 354187.9 6689284.3 24.1))
BATIMENT0000000302928879;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.9;14.7;21.6;28.5;16.2;Cadastre;B 0.2;POLYGON Z ((354209 6689307.9 21.6, 354214.4 6689308.7 21.6, 354215.6 6689296.5 21.6, 354210.4 6689295.9 21.6, 354209 6689307.9 21.6))
BATIMENT0000000302928694;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;11.2;23.1;23.9;16.0;Cadastre;;POLYGON Z ((354263.1 6689181.4 23.1, 354264.3 6689181.7 23.1, 354265 6689181.8 23.1, 354266.4 6689181.9 23.1, 354267.4 6689182 23.1, 354268.3 6689182 23.1, 354269.9 6689181.9 23.1, 354271.1 6689181.8 23.1, 354272 6689181.7 23.1, 354273.4 6689181.5 23.1, 354274.2 6689181.3 23.1, 354275.4 6689180.9 23.1, 354276.3 6689180.7 23.1, 354277.6 6689180.2 23.1, 354270.1 6689179.7 23.1, 354270 6689180.4 23.1, 354268.1 6689180.4 23.1, 354268.3 6689179.4 23.1, 354262.3 6689179.2 23.1, 354262.2 6689181.2 23.1, 354263.1 6689181.4 23.1))
BATIMENT0000000302928697;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.5;14.8;30.3;32.5;15.1;Cadastre;;POLYGON Z ((354290.8 6689185.2 30.3, 354297.2 6689185.7 30.3, 354297.3 6689184.4 30.3, 354290.9 6689183.9 30.3, 354290.8 6689185.2 30.3))
BATIMENT0000002275362793;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;9.8;16.8;;27.3;17.2;Imagerie aérienne;;POLYGON Z ((354287.4 6689229 26.6, 354287.4 6689207.8 24.1, 354297.4 6689207.8 24.1, 354297.2 6689205.3 24.1, 354282.2 6689204.5 24.5, 354282 6689220.8 26.6, 354282 6689229.2 26.6, 354287.4 6689229 26.6))
BATIMENT0000000302929036;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;15.6;23.2;28.6;20.7;Cadastre;;POLYGON Z ((354287.4 6689229 23.2, 354282 6689229.2 23.2, 354282.3 6689234.8 23.2, 354285.1 6689234.9 23.2, 354289 6689234.8 23.2, 354318.3 6689234.4 23.2, 354318 6689224.5 23.2, 354297.6 6689224.8 23.2, 354297.4 6689207.8 23.2, 354287.4 6689207.8 23.2, 354287.4 6689229 23.2))
BATIMENT0000000302929011;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;19.6;30.7;36.4;20.6;Cadastre;;POLYGON Z ((354296.3 6689239.6 30.7, 354296.3 6689246.4 30.7, 354301 6689246.3 30.7, 354300.9 6689239.3 30.7, 354296.3 6689239.6 30.7))
BATIMENT0000000302929096;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.0;19.4;21.5;25.2;19.9;Cadastre;;POLYGON Z ((354283.2 6689245.5 21.5, 354283.2 6689247.9 21.5, 354286.9 6689248.1 21.5, 354287 6689245.4 21.5, 354283.2 6689245.5 21.5))
BATIMENT0000000327814955;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;27.0;6.0;00;00;9.1;17.2;;31.0;19.7;Imagerie aérienne;C 0.1;POLYGON Z ((354268.8 6689257.1 26.3, 354268.8 6689255.8 26.3, 354273.7 6689255.9 26.3, 354273.7 6689256.9 26.3, 354280.4 6689257 26.3, 354280.4 6689252.4 26.3, 354282.1 6689252.5 26.3, 354282 6689241.7 26.3, 354258.2 6689241.8 26.3, 354258 6689252.1 26.3, 354258.8 6689252.1 26.3, 354258.8 6689257.1 26.3, 354268.8 6689257.1 26.3))
BATIMENT0000000302929093;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;12.8;17.4;30.2;33.9;20.8;Cadastre;A 1.0;POLYGON Z ((354287.4 6689302.6 30.2, 354266.4 6689302.3 30.2, 354266.4 6689302.5 30.2, 354266.2 6689312.3 30.2, 354287.3 6689312.6 30.2, 354287.4 6689302.6 30.2))
BATIMENT0000000327814960;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;47.0;6.0;00;00;15.8;19.8;;41.0;21.9;Imagerie aérienne;A 1.0;POLYGON Z ((354292 6689323.1 31.4, 354297.8 6689323.4 35.6, 354352.5 6689323.9 35.6, 354353.9 6689307.4 35.6, 354304 6689307.3 34.1, 354292 6689307.4 31.4, 354292 6689323.1 31.4))
BATIMENT0000000302928882;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;4.0;10;20;10.5;19.1;29.6;33.2;20.2;Cadastre;C 0.5;POLYGON Z ((354299.3 6689361.3 29.6, 354300.9 6689348.7 29.6, 354265.3 6689348.9 29.6, 354263.6 6689362.2 29.6, 354271.2 6689361.9 29.6, 354299.3 6689361.3 29.6))
BATIMENT0000000302928765;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;8.7;6.9;15.6;18.5;7.6;Cadastre;A 1.0;POLYGON Z ((354118.3 6689251.3 15.6, 354112.3 6689245.1 15.6, 354107.6 6689249.6 15.6, 354113.4 6689255.7 15.6, 354113.9 6689256.3 15.6, 354118.6 6689251.6 15.6, 354118.3 6689251.3 15.6))
BATIMENT0000000302928764;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.0;6.9;16.0;18.5;7.6;Cadastre;A 1.0;POLYGON Z ((354113.4 6689255.7 16, 354107.6 6689249.6 16, 354102.6 6689254.5 16, 354108.5 6689260.6 16, 354113.4 6689255.7 16))
BATIMENT0000000302928804;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.8;8.4;20.2;22.0;10.4;Cadastre;A 1.0;POLYGON Z ((354147.8 6689263.1 20.2, 354146.3 6689263 20.2, 354144.1 6689275.3 20.2, 354155.2 6689277 20.2, 354158.4 6689260.2 20.2, 354148.7 6689258.2 20.2, 354147.8 6689263.1 20.2))
BATIMENT0000000302928805;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;9.4;15.2;19.2;10.4;Cadastre;;POLYGON Z ((354143.5 6689278.6 15.2, 354154.6 6689280.5 15.2, 354155.2 6689277 15.2, 354144.1 6689275.3 15.2, 354143.5 6689278.6 15.2))
BATIMENT0000000302928806;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.1;9.2;18.3;23.1;11.2;Cadastre;C 0.3;POLYGON Z ((354142.4 6689284.6 18.3, 354141.7 6689284.8 18.3, 354139.3 6689296.6 18.3, 354123.4 6689293.7 18.3, 354122.4 6689299.8 18.3, 354150 6689304.7 18.3, 354154.6 6689280.5 18.3, 354143.5 6689278.6 18.3, 354142.4 6689284.6 18.3))
BATIMENT0000000302928757;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.6;11.1;22.7;25.5;14.4;Cadastre;B 0.8;POLYGON Z ((354178.6 6689301.3 22.7, 354174.7 6689300.7 22.7, 354175.3 6689297.3 22.7, 354168.1 6689296 22.7, 354165.6 6689309.5 22.7, 354176.8 6689311.7 22.7, 354178.6 6689301.3 22.7))
BATIMENT0000000302928808;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;9.9;13.5;16.0;11.6;Cadastre;;POLYGON Z ((354115 6689299.2 13.5, 354111.8 6689305.8 13.5, 354109.1 6689304.6 13.5, 354109.6 6689303.3 13.5, 354101.3 6689299.5 13.5, 354099.9 6689303 13.5, 354097.1 6689301.8 13.5, 354095.7 6689305 13.5, 354103.2 6689308.5 13.5, 354112.4 6689312.8 13.5, 354118.9 6689301 13.5, 354115 6689299.2 13.5))
BATIMENT0000000302928755;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;8.9;12.3;21.2;24.2;14.8;Cadastre;C 0.8;POLYGON Z ((354163.1 6689322.5 21.2, 354168.7 6689323.5 21.2, 354171.9 6689324.6 21.2, 354174.7 6689325.8 21.2, 354175.1 6689323.9 21.2, 354176.3 6689324 21.2, 354177.5 6689317.7 21.2, 354176.1 6689317.4 21.2, 354177.3 6689311.7 21.2, 354176.8 6689311.7 21.2, 354165.6 6689309.5 21.2, 354163.1 6689322.5 21.2))
BATIMENT0000000302928753;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.0;12.4;22.4;23.8;14.6;Cadastre;;POLYGON Z ((354162.2 6689327.1 22.4, 354171.9 6689329.1 22.4, 354174.1 6689329.4 22.4, 354174.7 6689325.8 22.4, 354171.9 6689324.6 22.4, 354168.7 6689323.5 22.4, 354163.1 6689322.5 22.4, 354162.2 6689327.1 22.4))
BATIMENT0000000302928856;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;12.1;14.5;;;Cadastre;;POLYGON Z ((354118.2 6689332.5 14.5, 354118.1 6689335.2 14.5, 354123.3 6689336.2 14.5, 354125.4 6689325.7 14.5, 354119.7 6689324.6 14.5, 354118.2 6689332.5 14.5))
BATIMENT0000000302928809;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;11.6;14.5;19.0;12.4;Cadastre;C 0.3;POLYGON Z ((354106 6689324.6 14.5, 354101.4 6689333.3 14.5, 354100.3 6689335 14.5, 354101.7 6689340.5 14.5, 354107.9 6689340.5 14.5, 354108.2 6689337.7 14.5, 354113.9 6689325.9 14.5, 354114.1 6689323.4 14.5, 354107.3 6689322.2 14.5, 354106 6689324.6 14.5))
BATIMENT0000000302928754;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.8;12.7;23.5;27.0;14.7;Cadastre;A 1.0;POLYGON Z ((354160.4 6689336.9 23.5, 354168.8 6689339.9 23.5, 354169.9 6689340.1 23.5, 354171.9 6689329.1 23.5, 354162.2 6689327.1 23.5, 354160.4 6689336.9 23.5))
BATIMENT0000000302929005;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;50;20;15.9;13.3;29.2;;;Cadastre;A 1.0;POLYGON Z ((354132.6 6689338.7 29.2, 354143.3 6689340.4 29.2, 354145.5 6689328.8 29.2, 354134.7 6689327 29.2, 354132.6 6689338.7 29.2))
BATIMENT0000000302929103;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.5;11.6;14.2;14.6;12.2;Cadastre;;POLYGON Z ((354112.2 6689338.4 14.2, 354112.2 6689340.5 14.2, 354118.1 6689340.4 14.2, 354118 6689338.1 14.2, 354112.4 6689338.1 14.2, 354112.2 6689338.4 14.2))
BATIMENT0000000302928812;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;2.7;11.9;14.7;20.4;12.5;Cadastre;B 0.3;POLYGON Z ((354102.3 6689343.8 14.7, 354108.4 6689343.8 14.7, 354108.5 6689340.5 14.7, 354107.9 6689340.5 14.7, 354101.7 6689340.5 14.7, 354102.3 6689343.8 14.7))
BATIMENT0000000302928756;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;19.6;12.7;32.4;34.0;15.0;Cadastre;A 1.0;POLYGON Z ((354156.8 6689355.3 32.4, 354161.2 6689359.8 32.4, 354169.9 6689357.8 32.4, 354168.5 6689351.1 32.4, 354170.4 6689347.3 32.4, 354172.5 6689342.8 32.4, 354168.2 6689341.3 32.4, 354168.8 6689339.9 32.4, 354160.4 6689336.9 32.4, 354156.8 6689355.3 32.4))
BATIMENT0000000302928709;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;14.1;12.3;26.5;29.5;13.2;Cadastre;B 0.6;POLYGON Z ((354121.4 6689352.2 26.5, 354119.9 6689351.9 26.5, 354118.4 6689353.2 26.5, 354117.7 6689355 26.5, 354118.9 6689356.6 26.5, 354120.5 6689356.6 26.5, 354120.4 6689357.4 26.5, 354125.3 6689358.5 26.5, 354124.5 6689363.1 26.5, 354132.5 6689361.4 26.5, 354133.2 6689357.1 26.5, 354135.3 6689357.8 26.5, 354136 6689354.8 26.5, 354137.6 6689355.4 26.5, 354139.9 6689343.5 26.5, 354123.4 6689340.3 26.5, 354121.4 6689352.2 26.5))
BATIMENT0000000302928745;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;8.5;13.2;21.7;25.0;14.7;Cadastre;A 1.0;POLYGON Z ((354162.9 6689382.5 21.7, 354162.8 6689386 21.7, 354165.9 6689386 21.7, 354174.2 6689385.9 21.7, 354173.9 6689376.1 21.7, 354174.6 6689375.9 21.7, 354172.6 6689367.6 21.7, 354162.7 6689369.7 21.7, 354162.9 6689382.5 21.7), (354168.7 6689379.6 21.7, 354173 6689379.5 21.7, 354172.9 6689382.9 21.7, 354168.6 6689382.9 21.7, 354168.7 6689379.6 21.7))
BATIMENT0000000302928747;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.2;13.2;22.4;24.7;14.6;Cadastre;A 1.0;POLYGON Z ((354162.7 6689369.7 22.4, 354152.3 6689372.1 22.4, 354154.2 6689380.7 22.4, 354154.3 6689381.2 22.4, 354155 6689384.1 22.4, 354162.9 6689382.5 22.4, 354162.7 6689369.7 22.4))
BATIMENT0000000302928743;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;13.7;16.2;17.6;14.5;Cadastre;;POLYGON Z ((354162.8 6689386 16.2, 354162.8 6689390.5 16.2, 354165.8 6689390.4 16.2, 354165.9 6689386 16.2, 354162.8 6689386 16.2))
BATIMENT0000000327814961;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:22:47;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;13.0;4.0;00;00;11.8;18.1;;38.7;18.7;Imagerie aérienne;C 0.3;POLYGON Z ((354262.4 6689308.9 29.9, 354251.4 6689308.8 29.9, 354251.4 6689308.7 29.9, 354241.6 6689308.8 29.9, 354241.6 6689310.6 29.9, 354236.8 6689310.6 29.9, 354236.7 6689311.9 29.9, 354232.8 6689311.8 29.9, 354232.6 6689321 29.9, 354232.5 6689323.7 29.9, 354256.6 6689323.9 29.9, 354262.3 6689324 29.9, 354262.4 6689308.9 29.9))
BATIMENT0000000302928759;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;16.8;24.8;27.9;18.0;Cadastre;A 0.6;POLYGON Z ((354212.4 6689332.4 24.8, 354232.1 6689334 24.8, 354232.3 6689328.3 24.8, 354232.5 6689323.7 24.8, 354232.6 6689321 24.8, 354213.4 6689319.3 24.8, 354212.4 6689332.4 24.8))
BATIMENT0000000302928758;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;5.0;00;00;13.9;15.0;29.0;32.8;17.2;Cadastre;C 0.7;POLYGON Z ((354178.8 6689350.9 29, 354188 6689348.7 29, 354187.4 6689346.9 29, 354191.1 6689346.2 29, 354191.6 6689347.9 29, 354205.7 6689344.7 29, 354205.4 6689343.3 29, 354208.6 6689342.7 29, 354210.2 6689338.6 29, 354210.9 6689332.3 29, 354208.8 6689332.8 29, 354208.3 6689330.2 29, 354177.9 6689337 29, 354177 6689339.1 29, 354174.7 6689338.3 29, 354173.2 6689341.3 29, 354172.5 6689342.8 29, 354170.4 6689347.3 29, 354178.8 6689350.9 29))
BATIMENT0000000302928885;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;12.8;19.0;31.8;;;Cadastre;A 1.0;POLYGON Z ((354231.8 6689355 31.8, 354232.2 6689359.2 31.8, 354242.2 6689357.6 31.8, 354242.6 6689352.4 31.8, 354231.8 6689355 31.8))
BATIMENT0000000302928883;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;8.0;35;90;10.0;17.8;27.9;42.1;19.1;Cadastre;A 1.0;POLYGON Z ((354242.6 6689352.4 27.9, 354242.2 6689357.6 27.9, 354240.6 6689381.3 27.9, 354256.3 6689379.1 27.9, 354256.5 6689382.1 27.9, 354261.1 6689381.6 27.9, 354261.5 6689378.5 27.9, 354262.7 6689369 27.9, 354263.6 6689362.2 27.9, 354265.3 6689348.9 27.9, 354242.6 6689352.4 27.9))
BATIMENT0000000302928941;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.7;16.4;27.2;29.5;17.7;Cadastre;C 0.8;POLYGON Z ((354198.6 6689365.5 27.2, 354201.3 6689377.6 27.2, 354213.8 6689374.8 27.2, 354211.2 6689362.7 27.2, 354198.6 6689365.5 27.2))
BATIMENT0000000302928710;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;00;00;12.3;16.1;28.4;31.9;17.1;Cadastre;A 1.0;POLYGON Z ((354183.1 6689366.8 28.4, 354183.1 6689376 28.4, 354189.1 6689376.1 28.4, 354189.2 6689387 28.4, 354194.9 6689387.1 28.4, 354194.5 6689364.5 28.4, 354183.1 6689366.8 28.4))
BATIMENT0000000302928888;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;7.0;30;49;9.9;16.5;26.5;37.7;18.3;Cadastre;A 1.0;POLYGON Z ((354214.4 6689359.1 26.5, 354214.3 6689370.5 26.5, 354225 6689367.6 26.5, 354226.1 6689372.7 26.5, 354221.9 6689372.8 26.5, 354221.6 6689376.7 26.5, 354217 6689377 26.5, 354216.7 6689407.6 26.5, 354235.1 6689408.6 26.5, 354235 6689387.6 26.5, 354231.8 6689387.5 26.5, 354231.8 6689372.2 26.5, 354231.1 6689372.3 26.5, 354229.8 6689366.7 26.5, 354233.6 6689365.7 26.5, 354232.2 6689359.2 26.5, 354231.8 6689355 26.5, 354214.4 6689359.1 26.5))
BATIMENT0000000302928886;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;17.4;23.6;32.0;18.9;Cadastre;;POLYGON Z ((354261.1 6689381.6 23.6, 354260.5 6689386.6 23.6, 354264.5 6689387.1 23.6, 354265.4 6689379 23.6, 354261.5 6689378.5 23.6, 354261.1 6689381.6 23.6))
BATIMENT0000000302928960;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;16;13;6.2;13.0;19.2;24.7;15.5;Cadastre;A 1.0;POLYGON Z ((354189.6 6689408.3 19.2, 354189.8 6689403 19.2, 354188.3 6689402.9 19.2, 354188.4 6689401.2 19.2, 354190.2 6689401.1 19.2, 354190.1 6689391.8 19.2, 354180.5 6689391.8 19.2, 354180.5 6689401.4 19.2, 354182.3 6689401.2 19.2, 354182.4 6689404.8 19.2, 354188.6 6689404.8 19.2, 354188.5 6689408.3 19.2, 354189.6 6689408.3 19.2))
BATIMENT0000000302928884;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;15.4;20.0;35.5;40.1;21.7;Cadastre;A 1.0;POLYGON Z ((354299.3 6689361.3 35.5, 354310.1 6689361.2 35.5, 354311.7 6689363.3 35.5, 354335.3 6689363 35.5, 354335.8 6689360.3 35.5, 354336.6 6689352.8 35.5, 354337 6689348.5 35.5, 354315.9 6689348.7 35.5, 354312.9 6689348.7 35.5, 354311.8 6689348.7 35.5, 354300.9 6689348.7 35.5, 354299.3 6689361.3 35.5))
BATIMENT0000000302928881;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;19.0;23.9;27.7;20.2;Cadastre;;POLYGON Z ((354262.7 6689369 23.9, 354296.5 6689369.1 23.9, 354298.5 6689369 23.9, 354299.1 6689364.1 23.9, 354270.9 6689364.6 23.9, 354271.2 6689361.9 23.9, 354263.6 6689362.2 23.9, 354262.7 6689369 23.9))
BATIMENT0000000302929235;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;18.6;26.0;29.5;19.0;Cadastre;;POLYGON Z ((354271 6689375 26, 354271 6689378.7 26, 354276.8 6689378.9 26, 354277.9 6689378.8 26, 354278.6 6689378.2 26, 354278.6 6689377.2 26, 354277.8 6689376.1 26, 354276.9 6689376.2 26, 354276.9 6689375.4 26, 354277.6 6689375.4 26, 354277.7 6689374.4 26, 354277 6689374.4 26, 354277 6689373.6 26, 354276.3 6689373.6 26, 354276.3 6689374.3 26, 354272.1 6689374.2 26, 354272 6689373.3 26, 354271.2 6689373.4 26, 354271.2 6689374 26, 354270.4 6689374 26, 354270.4 6689375 26, 354271 6689375 26))
BATIMENT0000000302928995;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.0;22.0;25.0;35.2;22.3;Cadastre;C 0.6;POLYGON Z ((354332.6 6689400 25, 354339 6689400.2 25, 354342.3 6689368.8 25, 354336.4 6689368.2 25, 354332.6 6689400 25))
BATIMENT0000000302929233;Eglise;Religieux;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.1;17.6;32.7;;;Cadastre;;POLYGON Z ((354270.8 6689386 32.7, 354270.9 6689386.3 32.7, 354272.3 6689387.6 32.7, 354271.7 6689388.4 32.7, 354272.3 6689389 32.7, 354273.1 6689388.1 32.7, 354274.2 6689388.6 32.7, 354274.2 6689389 32.7, 354275.4 6689389.2 32.7, 354275.4 6689390 32.7, 354276.4 6689390 32.7, 354276.4 6689389.2 32.7, 354280.3 6689389.4 32.7, 354280.2 6689390.2 32.7, 354281.1 6689390.3 32.7, 354281.3 6689389.5 32.7, 354284.9 6689389.7 32.7, 354284.9 6689390.5 32.7, 354285.8 6689390.6 32.7, 354286 6689389.8 32.7, 354289.3 6689389.9 32.7, 354289.3 6689390.8 32.7, 354290.3 6689390.7 32.7, 354290.5 6689389.9 32.7, 354293.8 6689390.2 32.7, 354293.8 6689391.1 32.7, 354294.8 6689391.1 32.7, 354294.9 6689390.1 32.7, 354298.2 6689390.4 32.7, 354298.5 6689390.5 32.7, 354298.6 6689391.2 32.7, 354299.7 6689391.4 32.7, 354299.8 6689390.5 32.7, 354300.5 6689390.6 32.7, 354300.6 6689389.6 32.7, 354299.8 6689389.5 32.7, 354300 6689387.4 32.7, 354300.7 6689387.4 32.7, 354300.9 6689384.1 32.7, 354300.1 6689384 32.7, 354300.4 6689381.9 32.7, 354301 6689382 32.7, 354301 6689381.2 32.7, 354300.4 6689381 32.7, 354300.4 6689380 32.7, 354299.4 6689379.9 32.7, 354299.2 6689380.9 32.7, 354295.3 6689380.7 32.7, 354295.4 6689379.6 32.7, 354294.3 6689379.5 32.7, 354294.1 6689380.4 32.7, 354290.7 6689380.4 32.7, 354290.7 6689379.3 32.7, 354289.8 6689379.3 32.7, 354289.7 6689380.2 32.7, 354286.2 6689380.2 32.7, 354286.3 6689379.1 32.7, 354285.3 6689379 32.7, 354285.3 6689380 32.7, 354281.7 6689379.8 32.7, 354281.7 6689378.9 32.7, 354280.8 6689378.8 32.7, 354280.8 6689379.6 32.7, 354276.9 6689379.5 32.7, 354276.8 6689378.9 32.7, 354271 6689378.7 32.7, 354270.1 6689378.8 32.7, 354270 6689380.2 32.7, 354270.8 6689380.3 32.7, 354270.8 6689381.6 32.7, 354269.8 6689382.5 32.7, 354270.7 6689382.6 32.7, 354270.6 6689384.8 32.7, 354269.4 6689385.2 32.7, 354269.6 6689386.2 32.7, 354270.8 6689386 32.7))
BATIMENT0000000302929234;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.1;17.9;26.0;38.5;22.2;Cadastre;C 0.1;POLYGON Z ((354276.8 6689426.4 26, 354276.7 6689427.5 26, 354286.6 6689428.8 26, 354286.7 6689427.6 26, 354293.7 6689428.5 26, 354294.2 6689415 26, 354332.7 6689416.7 26, 354332.6 6689420.5 26, 354332.5 6689421.6 26, 354335.9 6689422 26, 354337.9 6689422.3 26, 354340.8 6689406.5 26, 354298.3 6689404.6 26, 354298.2 6689401.4 26, 354297.2 6689401.3 26, 354298.2 6689390.4 26, 354294.9 6689390.1 26, 354294.8 6689391.1 26, 354294.3 6689400.8 26, 354293.9 6689401 26, 354293.5 6689404.6 26, 354287.2 6689404.5 26, 354287.3 6689404 26, 354267.7 6689403.1 26, 354267.1 6689410 26, 354273.1 6689410.2 26, 354272.6 6689417.5 26, 354266.8 6689417.2 26, 354266.2 6689425.3 26, 354276.8 6689426.4 26))
BATIMENT0000000302928650;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;18.2;25.5;26.0;19.0;Cadastre;;POLYGON Z ((354293.7 6689430.5 25.5, 354293.7 6689428.5 25.5, 354286.7 6689427.6 25.5, 354286.6 6689428.8 25.5, 354286.5 6689429.8 25.5, 354293.7 6689430.5 25.5))
BATIMENT0000000302928656;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;21.2;26.9;28.7;22.5;Cadastre;;POLYGON Z ((354335.9 6689433.2 26.9, 354341.7 6689434 26.9, 354343.1 6689426.5 26.9, 354337.4 6689425.1 26.9, 354335.9 6689433.2 26.9))
BATIMENT0000000302928652;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.9;19.8;23.8;31.1;22.3;Cadastre;C 0.1;POLYGON Z ((354327.6 6689433.7 23.8, 354328.1 6689438.1 23.8, 354333.1 6689438.3 23.8, 354335 6689438.4 23.8, 354335.9 6689433.2 23.8, 354337.4 6689425.1 23.8, 354337.9 6689422.3 23.8, 354335.9 6689422 23.8, 354332.5 6689421.6 23.8, 354328.6 6689421.4 23.8, 354327.6 6689433.7 23.8))
BATIMENT0000000302928658;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1981-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;50;90;6.3;20.8;27.1;28.8;22.5;Cadastre;C 0.1;POLYGON Z ((354335 6689438.4 27.1, 354334.7 6689440 27.1, 354334.5 6689441.5 27.1, 354340.2 6689442.3 27.1, 354340.5 6689440.6 27.1, 354341.7 6689434 27.1, 354335.9 6689433.2 27.1, 354335 6689438.4 27.1))
BATIMENT0000000302928748;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;38.0;6.0;30;20;17.1;10.6;27.7;31.0;13.9;Cadastre;A 1.0;POLYGON Z ((354134.7 6689375.9 27.7, 354133.3 6689378.7 27.7, 354133.9 6689379 27.7, 354133 6689381 27.7, 354130.3 6689381.7 27.7, 354128.6 6689383.4 27.7, 354126.7 6689388 27.7, 354126.9 6689390.8 27.7, 354128.1 6689393.4 27.7, 354127.5 6689394.8 27.7, 354126.9 6689394.6 27.7, 354126.1 6689397 27.7, 354133.4 6689406.5 27.7, 354146.5 6689403.5 27.7, 354143.2 6689398.8 27.7, 354142.2 6689399.5 27.7, 354140.5 6689398.8 27.7, 354144.9 6689387.9 27.7, 354148.1 6689389 27.7, 354148.6 6689388 27.7, 354149.9 6689388.8 27.7, 354154.1 6689387.9 27.7, 354152.7 6689381.7 27.7, 354154.3 6689381.2 27.7, 354154.2 6689380.7 27.7, 354152.3 6689372.1 27.7, 354134.7 6689375.9 27.7))
BATIMENT0000000302928744;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;13.2;20.5;23.2;14.5;Cadastre;A 0.6;POLYGON Z ((354167.4 6689387.1 20.5, 354167.4 6689396 20.5, 354170.4 6689396 20.5, 354175.1 6689396 20.5, 354176.5 6689396.1 20.5, 354176.4 6689386.9 20.5, 354167.4 6689387.1 20.5))
BATIMENT0000000302928746;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1921-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;10;6.0;13.5;19.5;22.0;13.8;Cadastre;A 1.0;POLYGON Z ((354170.4 6689400.4 19.5, 354170.1 6689400.4 19.5, 354170.1 6689403.7 19.5, 354170.8 6689403.8 19.5, 354170.8 6689406 19.5, 354169 6689406 19.5, 354168.9 6689410 19.5, 354172.9 6689409.9 19.5, 354172.8 6689411 19.5, 354171.1 6689411.5 19.5, 354171.2 6689414.7 19.5, 354176.5 6689414.8 19.5, 354176.5 6689414.7 19.5, 354176.5 6689400.2 19.5, 354175 6689400.1 19.5, 354175.1 6689396 19.5, 354170.4 6689396 19.5, 354170.4 6689400.4 19.5))
BATIMENT0000000302928640;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;8.5;16.0;20.4;9.6;Cadastre;;POLYGON Z ((354099.9 6689414.1 16, 354101.9 6689416.8 16, 354102.2 6689416.5 16, 354106.1 6689422.2 16, 354106.9 6689421.6 16, 354107.7 6689422.9 16, 354109.8 6689423.6 16, 354112.7 6689427.7 16, 354112.5 6689429.6 16, 354113.5 6689431 16, 354113 6689431.4 16, 354116 6689435.7 16, 354115.7 6689436 16, 354117.5 6689438.2 16, 354122.1 6689435.1 16, 354129.5 6689429.7 16, 354130.2 6689429.1 16, 354129.6 6689428.5 16, 354128 6689426.1 16, 354127.3 6689426.7 16, 354124.5 6689423.2 16, 354125.4 6689422.6 16, 354123.9 6689420.6 16, 354122.3 6689422.1 16, 354118.8 6689417.2 16, 354120.4 6689415.7 16, 354118.4 6689413 16, 354117.7 6689413.6 16, 354115.2 6689410.1 16, 354115.7 6689409.4 16, 354114 6689407.2 16, 354113.4 6689407.6 16, 354112 6689405.5 16, 354099.9 6689414.1 16))
BATIMENT0000000302928677;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;9.4;19.2;22.4;11.5;Cadastre;A 1.0;POLYGON Z ((354144.9 6689432.1 19.2, 354152.4 6689442.2 19.2, 354161.5 6689435.2 19.2, 354154 6689425.2 19.2, 354144.9 6689432.1 19.2))
BATIMENT0000000302928638;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;01;02;10.2;8.2;18.5;20.6;9.2;Cadastre;A 1.0;POLYGON Z ((354129.5 6689429.7 18.5, 354122.1 6689435.1 18.5, 354126.9 6689441.7 18.5, 354128.9 6689440.3 18.5, 354135.3 6689436 18.5, 354130.2 6689429.1 18.5, 354129.5 6689429.7 18.5))
BATIMENT0000000302928639;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;4.9;9.7;14.6;;;Cadastre;A 1.0;POLYGON Z ((354128.9 6689440.3 14.6, 354130 6689441.9 14.6, 354130 6689444.3 14.6, 354127.9 6689447.8 14.6, 354134 6689452 14.6, 354138.5 6689445.2 14.6, 354138.6 6689440.3 14.6, 354135.3 6689436 14.6, 354128.9 6689440.3 14.6))
BATIMENT0000000302928674;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;8.2;9.8;18.0;21.7;11.3;Cadastre;A 1.0;POLYGON Z ((354162.8 6689440 18, 354162.7 6689439.7 18, 354153.1 6689443.2 18, 354159 6689451.1 18, 354164.6 6689458.5 18, 354172.9 6689459.2 18, 354173.6 6689450.1 18, 354162.7 6689449.3 18, 354162.8 6689440 18))
BATIMENT0000000302928676;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;32;10;8.1;10.0;18.2;24.7;11.5;Cadastre;A 1.0;POLYGON Z ((354183.4 6689452.2 18.2, 354183.9 6689445.2 18.2, 354179.1 6689444.8 18.2, 354178.8 6689447.4 18.2, 354176.5 6689450.4 18.2, 354173.6 6689450.1 18.2, 354172.9 6689459.2 18.2, 354182.7 6689460.2 18.2, 354183.4 6689452.2 18.2))
BATIMENT0000000302928642;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;7.4;12.0;16.2;8.0;Cadastre;;POLYGON Z ((354115.3 6689455.9 12, 354117.7 6689457.5 12, 354118.4 6689457.8 12, 354122.8 6689451 12, 354120 6689449.1 12, 354115.3 6689455.9 12))
BATIMENT0000000302928691;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;21.1;;;;Cadastre;;POLYGON Z ((354393.6 6689152.8 -1000, 354394 6689150.1 -1000, 354385.6 6689148.9 -1000, 354385.2 6689151.7 -1000, 354393.6 6689152.8 -1000))
BATIMENT0000000302928906;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;12;29;7.9;21.7;29.6;34.2;24.2;Cadastre;C 0.2;POLYGON Z ((354366.2 6689170.1 29.6, 354366 6689170.2 29.6, 354365.6 6689170.3 29.6, 354365.4 6689170.4 29.6, 354365.2 6689170.5 29.6, 354365.1 6689170.6 29.6, 354364.8 6689170.9 29.6, 354364.5 6689171.2 29.6, 354364.4 6689171.3 29.6, 354364.3 6689171.5 29.6, 354364.2 6689171.7 29.6, 354364.1 6689171.9 29.6, 354364.1 6689172.1 29.6, 354364.1 6689172.4 29.6, 354364.1 6689172.6 29.6, 354364.1 6689172.8 29.6, 354364.2 6689173.1 29.6, 354364.2 6689173.3 29.6, 354364.4 6689173.7 29.6, 354364.5 6689173.9 29.6, 354364.6 6689174.1 29.6, 354364.8 6689174.3 29.6, 354365.1 6689174.6 29.6, 354365.9 6689174.9 29.6, 354373.7 6689176 29.6, 354373.7 6689177.1 29.6, 354375.6 6689177.3 29.6, 354402.8 6689181.2 29.6, 354403.9 6689174.2 29.6, 354389.2 6689171.7 29.6, 354389.1 6689172.3 29.6, 354374.7 6689170.2 29.6, 354374.5 6689171.3 29.6, 354366.6 6689170.1 29.6, 354366.2 6689170.1 29.6))
BATIMENT0000000302928735;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;22.5;23.7;24.0;23.9;Cadastre;;POLYGON Z ((354381.6 6689188.3 23.7, 354384.6 6689188.4 23.7, 354384.6 6689186.6 23.7, 354381.6 6689186.5 23.7, 354381.6 6689188.3 23.7))
BATIMENT0000000302928734;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.3;23.7;41.1;41.8;24.2;Cadastre;;POLYGON Z ((354370.7 6689210.3 41.1, 354374.7 6689210.4 41.1, 354374.8 6689208.6 41.1, 354369.6 6689208.4 41.1, 354369.5 6689210.2 41.1, 354370.7 6689210.3 41.1))
BATIMENT0000000302928733;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.4;24.1;41.5;41.7;24.6;Cadastre;;POLYGON Z ((354392 6689211 41.5, 354392 6689209.2 41.5, 354387.1 6689209 41.5, 354387 6689210.8 41.5, 354392 6689211 41.5))
BATIMENT0000000302928732;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;42.0;6.0;00;00;17.0;22.3;39.3;41.9;25.1;Cadastre;C 0.9;POLYGON Z ((354351.4 6689209.3 39.3, 354351.3 6689209.6 39.3, 354369.5 6689210.2 39.3, 354369.6 6689208.4 39.3, 354374.8 6689208.6 39.3, 354374.7 6689210.4 39.3, 354375.2 6689210.4 39.3, 354387 6689210.8 39.3, 354387.1 6689209 39.3, 354392 6689209.2 39.3, 354392 6689211 39.3, 354403.7 6689211.4 39.3, 354403.7 6689210.1 39.3, 354411.4 6689210.3 39.3, 354411.2 6689219 39.3, 354410.6 6689219 39.3, 354410 6689235.7 39.3, 354417.5 6689236 39.3, 354417.4 6689239 39.3, 354427.3 6689239.4 39.3, 354427.4 6689236.4 39.3, 354425.5 6689236.3 39.3, 354425.9 6689227.9 39.3, 354424 6689227.8 39.3, 354424.3 6689220.9 39.3, 354424.9 6689207.5 39.3, 354421.3 6689207.3 39.3, 354421.5 6689201.6 39.3, 354412.6 6689201.2 39.3, 354412.8 6689197.8 39.3, 354402.4 6689197.4 39.3, 354402.7 6689190.1 39.3, 354375.9 6689189 39.3, 354376 6689188.1 39.3, 354355.6 6689187.3 39.3, 354355.6 6689186.4 39.3, 354352.2 6689186.3 39.3, 354351.4 6689209.3 39.3))
BATIMENT0000000302928680;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;20.9;23.5;26.1;23.5;Cadastre;;POLYGON Z ((354345.8 6689253.4 23.5, 354347.3 6689253.5 23.5, 354347.5 6689248.7 23.5, 354348.8 6689248.7 23.5, 354348.8 6689247.6 23.5, 354346 6689247.6 23.5, 354345.8 6689253.4 23.5))
BATIMENT0000000302928678;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;20.9;22.5;23.7;22.9;Cadastre;;POLYGON Z ((354345.7 6689257.1 22.5, 354347.2 6689257.1 22.5, 354347.3 6689253.5 22.5, 354345.8 6689253.4 22.5, 354345.7 6689257.1 22.5))
BATIMENT0000000302928682;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;23.0;29.5;36.0;23.7;Cadastre;;POLYGON Z ((354351.6 6689272.2 29.5, 354353.1 6689272.2 29.5, 354353.4 6689264.8 29.5, 354354.9 6689264.8 29.5, 354355.1 6689257.3 29.5, 354356.6 6689257.4 29.5, 354356.9 6689249.4 29.5, 354354.4 6689249.3 29.5, 354354.5 6689247.2 29.5, 354357 6689247.2 29.5, 354357 6689246.7 29.5, 354352.5 6689246.5 29.5, 354351.6 6689272.2 29.5))
BATIMENT0000000302928681;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;80.0;6.0;;;13.9;21.7;35.7;41.1;23.7;Cadastre;A 0.1;POLYGON Z ((354357 6689246.7 35.7, 354357 6689247.2 35.7, 354354.5 6689247.2 35.7, 354354.4 6689249.3 35.7, 354356.9 6689249.4 35.7, 354356.6 6689257.4 35.7, 354355.1 6689257.3 35.7, 354354.9 6689264.8 35.7, 354353.4 6689264.8 35.7, 354353.1 6689272.2 35.7, 354351.6 6689272.2 35.7, 354351.4 6689279.8 35.7, 354344.9 6689279.5 35.7, 354344.2 6689297.4 35.7, 354347.7 6689297.5 35.7, 354357.4 6689297.6 35.7, 354359.2 6689297.6 35.7, 354359.2 6689297.3 35.7, 354359.2 6689297 35.7, 354359.3 6689289.3 35.7, 354359.3 6689287.6 35.7, 354370.7 6689287.8 35.7, 354372.4 6689247.5 35.7, 354370.9 6689247.5 35.7, 354369.7 6689247.4 35.7, 354369.7 6689246.2 35.7, 354370.4 6689246.2 35.7, 354370.7 6689240.9 35.7, 354346.3 6689239.7 35.7, 354346 6689247.6 35.7, 354348.8 6689247.6 35.7, 354348.8 6689246.4 35.7, 354352.5 6689246.5 35.7, 354357 6689246.7 35.7))
BATIMENT0000000302928311;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;28.8;34.0;36.1;29.3;Cadastre;;POLYGON Z ((354534.3 6689224.9 34, 354532.6 6689225 34, 354532.7 6689227.1 34, 354536 6689226.8 34, 354535.8 6689224.8 34, 354534.3 6689224.9 34))
BATIMENT0000000302928314;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;00;00;9.7;27.8;37.5;42.7;29.2;Cadastre;C 0.9;POLYGON Z ((354518.6 6689235.6 37.5, 354530.5 6689236.2 37.5, 354532.1 6689236.6 37.5, 354532 6689232.8 37.5, 354531.7 6689227.2 37.5, 354519.1 6689228.1 37.5, 354518.6 6689235.6 37.5))
BATIMENT0000000302928997;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;14.3;28.3;42.6;46.1;28.8;Cadastre;C 0.7;POLYGON Z ((354509.2 6689245.9 42.6, 354510.9 6689222.6 42.6, 354501.7 6689222.8 42.6, 354497.4 6689222.3 42.6, 354496.7 6689222.2 42.6, 354496.2 6689228.5 42.6, 354493.4 6689228.2 42.6, 354492.4 6689240.7 42.6, 354495.1 6689240.9 42.6, 354494.8 6689244.6 42.6, 354509.1 6689245.9 42.6, 354509.2 6689245.9 42.6))
BATIMENT0000000302928996;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;28.3;40.7;42.6;28.4;Cadastre;;POLYGON Z ((354493.4 6689228.2 40.7, 354490.6 6689228 40.7, 354489.6 6689240.4 40.7, 354492.4 6689240.7 40.7, 354493.4 6689228.2 40.7))
BATIMENT0000000302928310;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;00;00;9.3;29.1;38.5;46.6;29.6;Cadastre;C 0.5;POLYGON Z ((354547.4 6689243.4 38.5, 354548.9 6689240.2 38.5, 354549.9 6689240.6 38.5, 354551.7 6689237.5 38.5, 354552.7 6689237.9 38.5, 354554.5 6689234.1 38.5, 354546.8 6689230.2 38.5, 354546.8 6689226.1 38.5, 354545.2 6689226.2 38.5, 354542.9 6689226.2 38.5, 354539.9 6689226.2 38.5, 354539.3 6689226.6 38.5, 354536 6689226.8 38.5, 354532.7 6689227.1 38.5, 354531.7 6689227.2 38.5, 354532 6689232.8 38.5, 354539.6 6689232.1 38.5, 354539.7 6689234.8 38.5, 354536.9 6689238 38.5, 354544.6 6689246.4 38.5, 354547.4 6689243.4 38.5))
BATIMENT0000000302928318;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;15;20;17.3;27.8;45.1;46.7;29.5;Cadastre;A 0.9;POLYGON Z ((354517.8 6689247.3 45.1, 354527.2 6689248.6 45.1, 354527.3 6689246.8 45.1, 354527.6 6689243.3 45.1, 354528.9 6689242 45.1, 354530.6 6689242.1 45.1, 354531.9 6689242 45.1, 354532.1 6689236.6 45.1, 354530.5 6689236.2 45.1, 354518.6 6689235.6 45.1, 354517.8 6689247.3 45.1))
BATIMENT0000000302928313;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;16.9;27.8;44.7;46.8;29.5;Cadastre;A 1.0;POLYGON Z ((354530.7 6689247 44.7, 354530.3 6689248.4 44.7, 354534.4 6689249.9 44.7, 354537.9 6689253.3 44.7, 354544.6 6689246.4 44.7, 354536.9 6689238 44.7, 354531.8 6689243.7 44.7, 354531.9 6689242 44.7, 354530.6 6689242.1 44.7, 354530.3 6689244.3 44.7, 354531.2 6689244.4 44.7, 354530.7 6689247 44.7))
BATIMENT0000000302928317;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;29.2;41.8;43.2;29.5;Cadastre;;POLYGON Z ((354531.2 6689244.4 41.8, 354530.3 6689244.3 41.8, 354529.9 6689244.4 41.8, 354529.5 6689247 41.8, 354530.7 6689247 41.8, 354531.2 6689244.4 41.8))
BATIMENT0000000302928315;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;29.1;43.5;45.7;29.5;Cadastre;;POLYGON Z ((354527.2 6689248.6 43.5, 354529.2 6689248.8 43.5, 354529.5 6689248.1 43.5, 354530.3 6689248.4 43.5, 354530.7 6689247 43.5, 354529.5 6689247 43.5, 354527.3 6689246.8 43.5, 354527.2 6689248.6 43.5))
BATIMENT0000000302928749;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;12.5;28.7;41.2;43.7;29.5;Cadastre;C 0.8;POLYGON Z ((354493.7 6689264.1 41.2, 354497.5 6689264.4 41.2, 354506.2 6689265.1 41.2, 354507.2 6689251.6 41.2, 354494.9 6689250.3 41.2, 354493.7 6689264.1 41.2))
BATIMENT0000000302929095;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.1;24.2;25.3;25.5;24.4;Cadastre;;POLYGON Z ((354432.2 6689216.9 25.3, 354432.3 6689215.6 25.3, 354431.3 6689215.5 25.3, 354431.2 6689216.8 25.3, 354432.2 6689216.9 25.3))
BATIMENT0000000302929098;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;01;02;3.5;25.2;28.7;29.6;26.7;Cadastre;B 0.3;POLYGON Z ((354440.4 6689222.4 28.7, 354444.2 6689222.7 28.7, 354444.3 6689221.7 28.7, 354446.4 6689221.8 28.7, 354446.8 6689218.3 28.7, 354444.5 6689218.1 28.7, 354444.6 6689217.1 28.7, 354444.7 6689216.3 28.7, 354444.6 6689216 28.7, 354441 6689215.7 28.7, 354440.4 6689222.4 28.7))
BATIMENT0000000302929097;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;26.4;29.5;30.5;26.9;Cadastre;;POLYGON Z ((354455.4 6689219.3 29.5, 354450.1 6689218.8 29.5, 354449.7 6689221.9 29.5, 354454.8 6689222.4 29.5, 354455.4 6689219.3 29.5))
BATIMENT0000000302928731;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.8;24.1;37.0;39.5;24.2;Cadastre;;POLYGON Z ((354425.9 6689227.9 37, 354426.2 6689221 37, 354424.3 6689220.9 37, 354424 6689227.8 37, 354425.9 6689227.9 37))
BATIMENT0000000302928738;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;23.8;35.2;39.2;24.2;Cadastre;;POLYGON Z ((354410.6 6689219 35.2, 354409.6 6689219 35.2, 354409 6689235.7 35.2, 354410 6689235.7 35.2, 354410.6 6689219 35.2))
BATIMENT0000000029198684;Indifférenciée;Annexe;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2002-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;0.0;00;00;5.0;26.2;;36.2;28.6;Imagerie aérienne;C 0.1;POLYGON Z ((354467.4 6689241.3 31, 354473.7 6689242.2 31, 354476.5 6689220.4 31.2, 354470.1 6689219.2 31.2, 354467.4 6689241.3 31))
BATIMENT0000000302928739;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;23.7;38.0;40.0;24.2;Cadastre;;POLYGON Z ((354408.7 6689242.6 38, 354406.2 6689242.5 38, 354406.1 6689244 38, 354411 6689244.2 38, 354411.1 6689242.7 38, 354408.7 6689242.6 38))
BATIMENT0000000302928741;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;24.0;38.1;39.7;24.8;Cadastre;;POLYGON Z ((354418.2 6689252.6 38.1, 354418 6689258.1 38.1, 354419.2 6689258.1 38.1, 354419.8 6689252.6 38.1, 354418.2 6689252.6 38.1))
BATIMENT0000000302928880;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;24;10.9;26.0;37.0;40.4;28.7;Cadastre;B 0.3;POLYGON Z ((354458.8 6689268.8 37, 354459.1 6689264.9 37, 354461.2 6689265 37, 354461.9 6689258.2 37, 354438.8 6689256.3 37, 354438.8 6689259.2 37, 354437.6 6689265.4 37, 354442.3 6689266.1 37, 354458.8 6689268.8 37))
BATIMENT0000000302928737;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;47.0;6.0;00;00;15.7;23.7;39.5;41.5;25.1;Cadastre;A 1.0;POLYGON Z ((354417.4 6689239 39.5, 354417.2 6689243 39.5, 354411.1 6689242.7 39.5, 354411 6689244.2 39.5, 354406.1 6689244 39.5, 354406.2 6689242.5 39.5, 354405.2 6689242.5 39.5, 354405.3 6689251.7 39.5, 354403.8 6689251.7 39.5, 354403.3 6689251.6 39.5, 354403 6689257.2 39.5, 354404.5 6689257.3 39.5, 354403.4 6689283.6 39.5, 354401.9 6689283.5 39.5, 354401.7 6689289.1 39.5, 354401.6 6689289.5 39.5, 354403.1 6689289.5 39.5, 354412.5 6689290 39.5, 354414.8 6689290.1 39.5, 354415.1 6689284.1 39.5, 354416.9 6689284.1 39.5, 354417.3 6689274.1 39.5, 354415.4 6689274 39.5, 354416 6689258 39.5, 354418 6689258.1 39.5, 354418.2 6689252.6 39.5, 354419.8 6689252.6 39.5, 354421.5 6689243.3 39.5, 354427.1 6689243.6 39.5, 354427.3 6689239.4 39.5, 354417.4 6689239 39.5))
BATIMENT0000000302928316;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;16.7;27.8;44.5;46.9;29.5;Cadastre;A 1.0;POLYGON Z ((354516.6 6689266.1 44.5, 354523.1 6689268.9 44.5, 354537.9 6689253.3 44.5, 354534.4 6689249.9 44.5, 354530.3 6689248.4 44.5, 354529.5 6689248.1 44.5, 354529.2 6689248.8 44.5, 354526.9 6689253.9 44.5, 354526 6689253.3 44.5, 354526.5 6689252.6 44.5, 354525.8 6689252 44.5, 354527.2 6689248.6 44.5, 354517.8 6689247.3 44.5, 354516.6 6689266.1 44.5))
BATIMENT0000000302928005;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;8.8;29.2;38.0;42.0;29.3;Cadastre;A 1.0;POLYGON Z ((354536.7 6689269.7 38, 354545.1 6689277.9 38, 354551.2 6689271.5 38, 354548.8 6689269.1 38, 354548.1 6689270 38, 354548.8 6689270.9 38, 354547.6 6689272.4 38, 354544.8 6689269.6 38, 354547 6689267.4 38, 354542.8 6689263.2 38, 354536.7 6689269.7 38))
BATIMENT0000000302928750;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1851-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;10.2;28.7;39.0;43.5;29.3;Cadastre;A 1.0;POLYGON Z ((354496.7 6689275.8 39, 354501.1 6689276.5 39, 354505 6689277.1 39, 354506.9 6689277.4 39, 354507.8 6689265.3 39, 354506.2 6689265.1 39, 354497.5 6689264.4 39, 354496.7 6689275.8 39))
BATIMENT0000000302928006;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;10;20;8.1;29.1;37.2;40.3;29.9;Cadastre;C 0.8;POLYGON Z ((354525.3 6689281.5 37.2, 354533.8 6689289.3 37.2, 354534.5 6689289.9 37.2, 354543 6689280.9 37.2, 354544.6 6689282.4 37.2, 354543.1 6689284.1 37.2, 354545.1 6689286.2 37.2, 354549.1 6689281.9 37.2, 354545.1 6689277.9 37.2, 354536.7 6689269.7 37.2, 354525.3 6689281.5 37.2))
BATIMENT0000000302928751;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;9.0;00;00;23.4;28.2;51.7;55.7;29.3;Cadastre;A 1.0;POLYGON Z ((354500.1 6689287.1 51.7, 354500.8 6689287.2 51.7, 354501 6689285.7 51.7, 354500.7 6689285.7 51.7, 354501.1 6689282.6 51.7, 354500.6 6689282.5 51.7, 354501.1 6689276.5 51.7, 354496.7 6689275.8 51.7, 354493.1 6689275.1 51.7, 354484.6 6689273.7 51.7, 354483.9 6689281.1 51.7, 354484.5 6689281.2 51.7, 354483.9 6689286.4 51.7, 354484.8 6689286.5 51.7, 354484.2 6689293.6 51.7, 354491.2 6689294.9 51.7, 354493 6689295.2 51.7, 354499.7 6689296.4 51.7, 354499.9 6689292.1 51.7, 354498.5 6689292 51.7, 354498.6 6689288.4 51.7, 354499.6 6689287.6 51.7, 354500.1 6689287.7 51.7, 354500.1 6689287.1 51.7))
BATIMENT0000000302928011;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;29.6;37.6;40.9;29.9;Cadastre;A 1.0;POLYGON Z ((354518.7 6689288.6 37.6, 354527.1 6689296.3 37.6, 354533.8 6689289.3 37.6, 354525.3 6689281.5 37.6, 354518.7 6689288.6 37.6))
BATIMENT0000000302928752;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.4;28.5;47.0;49.0;28.8;Cadastre;;POLYGON Z ((354500.1 6689287.7 47, 354499.6 6689287.6 47, 354498.6 6689288.4 47, 354498.5 6689292 47, 354499.9 6689292.1 47, 354500.1 6689287.7 47))
BATIMENT0000000302928017;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;10.7;28.7;39.4;44.0;29.9;Cadastre;A 1.0;POLYGON Z ((354515.5 6689291.9 39.4, 354514.7 6689302.4 39.4, 354522.9 6689301.7 39.4, 354525.3 6689301.4 39.4, 354531.8 6689300.8 39.4, 354527.1 6689296.3 39.4, 354518.7 6689288.6 39.4, 354515.5 6689291.9 39.4))
BATIMENT0000000302928012;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;28.0;;;;Cadastre;;POLYGON Z ((354544 6689299 -1000, 354543.4 6689299.6 -1000, 354544.4 6689303 -1000, 354547.1 6689301.8 -1000, 354549.8 6689300.5 -1000, 354548.5 6689298.6 -1000, 354545.3 6689300 -1000, 354544 6689299 -1000))
BATIMENT0000000302928989;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.1;27.0;39.1;42.7;29.2;Cadastre;;POLYGON Z ((354505 6689302.9 39.1, 354500.1 6689302.4 39.1, 354488.9 6689301.5 39.1, 354488.6 6689305 39.1, 354486.1 6689304.8 39.1, 354485.8 6689311.1 39.1, 354488.4 6689311.4 39.1, 354488.3 6689315 39.1, 354503.9 6689316.5 39.1, 354505 6689302.9 39.1))
BATIMENT0000000302928740;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.5;23.9;37.5;39.7;24.8;Cadastre;;POLYGON Z ((354418 6689258.1 37.5, 354416 6689258 37.5, 354415.4 6689274 37.5, 354417.3 6689274.1 37.5, 354418 6689258.1 37.5))
BATIMENT0000000302929100;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;04;16.0;28.2;44.2;48.5;28.7;Cadastre;C 0.3;POLYGON Z ((354464.9 6689270.6 44.2, 354468.1 6689271.2 44.2, 354469 6689264.4 44.2, 354465.8 6689264.1 44.2, 354464.9 6689270.6 44.2))
BATIMENT0000000302929108;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.2;25.4;31.6;33.1;28.2;Cadastre;;POLYGON Z ((354439.6 6689292.1 31.6, 354440.5 6689286.2 31.6, 354439.7 6689286 31.6, 354432.5 6689285.2 31.6, 354432.2 6689291 31.6, 354439.6 6689292.1 31.6))
BATIMENT0000000302928707;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.3;26.3;33.7;42.1;28.5;Cadastre;C 0.3;POLYGON Z ((354444 6689321.4 33.7, 354446.4 6689323.7 33.7, 354446.6 6689322.8 33.7, 354447.5 6689323 33.7, 354451 6689323.4 33.7, 354448.8 6689348 33.7, 354465.2 6689349.7 33.7, 354466.4 6689335.2 33.7, 354473.6 6689336 33.7, 354475.4 6689320.4 33.7, 354466.2 6689318.8 33.7, 354465.5 6689324.7 33.7, 354453.8 6689323.3 33.7, 354454.6 6689316.6 33.7, 354444.4 6689314.9 33.7, 354444 6689321.4 33.7), (354457.7 6689332.5 33.7, 354463.2 6689332.9 33.7, 354464 6689333.5 33.7, 354463.4 6689338.4 33.7, 354456.2 6689337.6 33.7, 354456.7 6689333.2 33.7, 354457.7 6689332.5 33.7))
BATIMENT0000000302928706;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;11.8;26.4;38.2;39.9;27.3;Cadastre;A 1.0;POLYGON Z ((354431.9 6689346.4 38.2, 354433 6689331.1 38.2, 354433.6 6689323.2 38.2, 354432.1 6689323.1 38.2, 354431.9 6689324.4 38.2, 354428.1 6689324.1 38.2, 354427.6 6689335.3 38.2, 354430.8 6689335.6 38.2, 354429.9 6689346.3 38.2, 354431.9 6689346.4 38.2))
BATIMENT0000000302928704;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;3.0;;;10.7;24.2;35.0;39.2;26.5;Cadastre;A 1.0;POLYGON Z ((354425.9 6689324 35, 354425.4 6689329.5 35, 354413.6 6689329 35, 354411 6689328.8 35, 354411 6689329.4 35, 354410 6689344.4 35, 354429.9 6689346.3 35, 354430.8 6689335.6 35, 354427.6 6689335.3 35, 354428.1 6689324.1 35, 354425.9 6689324 35))
BATIMENT0000000302928705;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;13.1;26.4;39.5;44.7;26.7;Cadastre;A 1.0;POLYGON Z ((354451 6689323.4 39.5, 354447.5 6689323 39.5, 354446.6 6689322.8 39.5, 354446.4 6689323.7 39.5, 354440.4 6689328.8 39.5, 354440 6689331.9 39.5, 354433 6689331.1 39.5, 354431.9 6689346.4 39.5, 354448.8 6689348 39.5, 354451 6689323.4 39.5))
BATIMENT0000000302928708;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;26.6;41.5;43.0;28.6;Cadastre;;POLYGON Z ((354472.2 6689350.3 41.5, 354473.6 6689336 41.5, 354466.4 6689335.2 41.5, 354465.2 6689349.7 41.5, 354472.2 6689350.3 41.5))
BATIMENT0000000302928498;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;00;00;15.9;25.5;41.5;43.4;27.6;Cadastre;C 0.8;POLYGON Z ((354431 6689368.2 41.5, 354447.1 6689370 41.5, 354448.2 6689357.9 41.5, 354432.5 6689356.4 41.5, 354431 6689368.2 41.5))
BATIMENT0000000302928500;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.1;26.1;36.2;39.7;27.7;Cadastre;C 0.9;POLYGON Z ((354460.9 6689371.9 36.2, 354462.2 6689359.3 36.2, 354448.2 6689357.9 36.2, 354447.1 6689370 36.2, 354447 6689370.8 36.2, 354451.2 6689371.1 36.2, 354460.9 6689371.9 36.2))
BATIMENT0000000302928742;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;23.6;36.2;38.2;24.2;Cadastre;;POLYGON Z ((354403.4 6689283.6 36.2, 354404.5 6689257.3 36.2, 354403 6689257.2 36.2, 354401.9 6689283.5 36.2, 354403.4 6689283.6 36.2))
BATIMENT0000000302928918;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.7;23.5;38.2;;;Cadastre;;POLYGON Z ((354363 6689311.3 38.2, 354363.1 6689312.5 38.2, 354367.6 6689313 38.2, 354367.7 6689311.8 38.2, 354363 6689311.3 38.2))
BATIMENT0000000302928919;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;00;00;16.0;21.6;37.6;42.0;23.4;Cadastre;C 0.6;POLYGON Z ((354358.8 6689324 37.6, 354378.4 6689325 37.6, 354378.5 6689323.7 37.6, 354381.5 6689324 37.6, 354382 6689315 37.6, 354378.9 6689315 37.6, 354379 6689313.8 37.6, 354378.3 6689313.8 37.6, 354374 6689313.8 37.6, 354374 6689312.4 37.6, 354367.7 6689311.8 37.6, 354367.6 6689313 37.6, 354363.1 6689312.5 37.6, 354363 6689311.3 37.6, 354357.3 6689310.7 37.6, 354357.2 6689312.4 37.6, 354356.7 6689317.7 37.6, 354356.2 6689323.7 37.6, 354358.8 6689324 37.6))
BATIMENT0000000302928703;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;00;00;13.6;24.8;38.4;42.0;26.0;Cadastre;C 0.5;POLYGON Z ((354399.6 6689315.1 38.4, 354399.5 6689316 38.4, 354392 6689315.6 38.4, 354391.6 6689324.4 38.4, 354393.6 6689324.5 38.4, 354393.4 6689326.9 38.4, 354398.8 6689327.2 38.4, 354398.8 6689328.1 38.4, 354406.4 6689328.9 38.4, 354411 6689329.4 38.4, 354411 6689328.8 38.4, 354411.1 6689327.8 38.4, 354411.3 6689326.7 38.4, 354411.5 6689324.3 38.4, 354411.9 6689316.3 38.4, 354399.6 6689315.1 38.4))
BATIMENT0000000302928887;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;20;14.3;21.3;35.7;38.6;22.1;Cadastre;A 0.8;POLYGON Z ((354348.8 6689360.6 35.7, 354352.5 6689360.7 35.7, 354353.8 6689348.7 35.7, 354349.3 6689348.4 35.7, 354337 6689348.5 35.7, 354336.6 6689352.8 35.7, 354335.8 6689360.3 35.7, 354340 6689360.4 35.7, 354343.2 6689360.5 35.7, 354348.8 6689360.6 35.7))
BATIMENT0000000302928891;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;18.0;21.9;40.0;42.5;23.0;Cadastre;C 0.8;POLYGON Z ((354352.5 6689360.7 40, 354352.4 6689361.2 40, 354359.5 6689362 40, 354359.7 6689362.2 40, 354363.6 6689362.5 40, 354363.5 6689363.5 40, 354366 6689363.8 40, 354366.1 6689362.7 40, 354370.4 6689363.2 40, 354372.1 6689350.6 40, 354353.8 6689348.7 40, 354352.5 6689360.7 40))
BATIMENT0000000302928893;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;90;14.2;23.5;37.7;40.0;24.3;Cadastre;A 1.0;POLYGON Z ((354383.4 6689364.5 37.7, 354383.2 6689365.3 37.7, 354392.4 6689366.5 37.7, 354394.4 6689352.8 37.7, 354384.9 6689352 37.7, 354383.4 6689364.5 37.7))
BATIMENT0000000302928892;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;13.3;22.6;36.0;40.0;24.0;Cadastre;A 1.0;POLYGON Z ((354370.4 6689363.2 36, 354369.2 6689372.1 36, 354373.7 6689373 36, 354374.8 6689363.5 36, 354383.4 6689364.5 36, 354384.9 6689352 36, 354372.1 6689350.6 36, 354370.4 6689363.2 36))
BATIMENT0000000302928889;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;21.6;30.7;34.5;22.0;Cadastre;;POLYGON Z ((354339.9 6689363.2 30.7, 354341 6689363.2 30.7, 354343 6689363.2 30.7, 354343.2 6689360.5 30.7, 354340 6689360.4 30.7, 354339.9 6689363.2 30.7))
BATIMENT0000000302928890;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;21.7;25.7;29.0;22.0;Cadastre;;POLYGON Z ((354340.9 6689365.4 25.7, 354342.9 6689365.5 25.7, 354343 6689363.2 25.7, 354341 6689363.2 25.7, 354340.9 6689365.4 25.7))
BATIMENT0000000302928010;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;19.7;28.4;48.2;51.2;30.0;Cadastre;A 1.0;POLYGON Z ((354512.9 6689326.5 48.2, 354537.4 6689324.1 48.2, 354539.7 6689323.9 48.2, 354546.2 6689323.2 48.2, 354546 6689321.5 48.2, 354549.5 6689321.1 48.2, 354548.3 6689316.6 48.2, 354529.5 6689318.7 48.2, 354528.3 6689307.6 48.2, 354545.3 6689306.2 48.2, 354544.4 6689303 48.2, 354543.4 6689299.6 48.2, 354531.8 6689300.8 48.2, 354525.3 6689301.4 48.2, 354525.6 6689304.9 48.2, 354523.1 6689304.5 48.2, 354522.9 6689301.7 48.2, 354514.7 6689302.4 48.2, 354512.9 6689326.5 48.2))
BATIMENT0000000302928988;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;12.0;27.0;39.0;41.7;29.2;Cadastre;A 1.0;POLYGON Z ((354487.9 6689318.1 39, 354487.7 6689322.9 39, 354490.2 6689323 39, 354503.3 6689324.9 39, 354503.9 6689316.5 39, 354488.3 6689315 39, 354487.9 6689318.1 39))
BATIMENT0000000302928016;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;20;20;20.1;28.5;48.7;51.4;29.6;Cadastre;A 1.0;POLYGON Z ((354558.4 6689352.2 48.7, 354557.8 6689347.4 48.7, 354554.9 6689339.1 48.7, 354543.9 6689340 48.7, 354543.2 6689332.6 48.7, 354552.5 6689331.9 48.7, 354551.9 6689329.7 48.7, 354550.8 6689325.8 48.7, 354548.3 6689326.1 48.7, 354548.2 6689323 48.7, 354546.2 6689323.2 48.7, 354539.7 6689323.9 48.7, 354540 6689328.5 48.7, 354537.6 6689328.6 48.7, 354539.4 6689353.7 48.7, 354558.4 6689352.2 48.7))
BATIMENT0000000302928015;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;19.5;28.2;47.7;50.6;28.8;Cadastre;A 1.0;POLYGON Z ((354512.1 6689339.5 47.7, 354524.5 6689354.7 47.7, 354539.4 6689353.7 47.7, 354537.6 6689328.6 47.7, 354537.4 6689324.1 47.7, 354512.9 6689326.5 47.7, 354512.1 6689339.5 47.7), (354530.3 6689328.3 47.7, 354536.9 6689336.4 47.7, 354536.6 6689337.1 47.7, 354531.4 6689341.2 47.7, 354524.5 6689333 47.7, 354530.3 6689328.3 47.7))
BATIMENT0000000302928855;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;26.8;31.8;32.2;28.1;Cadastre;;POLYGON Z ((354470.6 6689373.3 31.8, 354483.4 6689361.8 31.8, 354483.2 6689361.6 31.8, 354482.3 6689361.7 31.8, 354482 6689361.3 31.8, 354471.5 6689360.2 31.8, 354470.3 6689371.5 31.8, 354469.6 6689372.2 31.8, 354470.6 6689373.3 31.8))
BATIMENT0000000302928186;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;19.4;28.9;48.3;51.4;29.2;Cadastre;A 1.0;POLYGON Z ((354548.1 6689377.3 48.3, 354547.9 6689363.3 48.3, 354524.8 6689365.3 48.3, 354524.5 6689365.2 48.3, 354521 6689368.1 48.3, 354535.8 6689385.5 48.3, 354542.6 6689379.7 48.3, 354540.1 6689376.6 48.3, 354538.5 6689376.7 48.3, 354538.7 6689375.9 48.3, 354537.2 6689374.4 48.3, 354537.4 6689374 48.3, 354542.4 6689374.1 48.3, 354543.2 6689374.5 48.3, 354543.2 6689377.4 48.3, 354548.1 6689377.3 48.3))
BATIMENT0000000302928487;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;27.5;38.5;43.9;28.5;Cadastre;;POLYGON Z ((354474.3 6689374.7 38.5, 354484.6 6689386.7 38.5, 354484.9 6689386.5 38.5, 354487.2 6689389.3 38.5, 354483.3 6689405.4 38.5, 354476.7 6689405 38.5, 354476.4 6689409.5 38.5, 354476.2 6689411.5 38.5, 354478.1 6689411.6 38.5, 354491.3 6689412.6 38.5, 354498.8 6689379.5 38.5, 354496.4 6689376.7 38.5, 354496.9 6689376.3 38.5, 354486.4 6689364.2 38.5, 354485.9 6689364.7 38.5, 354485.7 6689364.4 38.5, 354474.3 6689374.7 38.5))
BATIMENT0000000302928187;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;10;20;19.6;28.8;48.4;51.2;29.3;Cadastre;C 0.3;POLYGON Z ((354543.2 6689377.4 48.4, 354543.4 6689379.6 48.4, 354542.6 6689379.7 48.4, 354535.8 6689385.5 48.4, 354547.8 6689399.6 48.4, 354548.4 6689399.1 48.4, 354548.1 6689377.3 48.4, 354543.2 6689377.4 48.4))
BATIMENT0000000302928535;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;19.2;27.9;47.1;49.2;29.7;Cadastre;A 1.0;POLYGON Z ((354525.4 6689389.7 47.1, 354512.3 6689374.2 47.1, 354509.1 6689377.2 47.1, 354503.2 6689403.9 47.1, 354515.9 6689406.8 47.1, 354519 6689407.6 47.1, 354527.2 6689409.6 47.1, 354523.1 6689405 47.1, 354522.8 6689406.5 47.1, 354517.7 6689405.3 47.1, 354514.5 6689405 47.1, 354516.2 6689398 47.1, 354514.3 6689395.3 47.1, 354514.9 6689394.2 47.1, 354515 6689394.1 47.1, 354515.1 6689394 47.1, 354515.1 6689393.9 47.1, 354515.2 6689393.9 47.1, 354515.2 6689393.8 47.1, 354515.2 6689393.7 47.1, 354515.3 6689393.6 47.1, 354515.3 6689393.5 47.1, 354515.1 6689392.8 47.1, 354514.8 6689392.4 47.1, 354515.4 6689392 47.1, 354516.6 6689393.6 47.1, 354518.5 6689396 47.1, 354525.4 6689389.7 47.1))
BATIMENT0000000302928538;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1848-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;18.8;28.6;47.5;49.4;29.7;Cadastre;A 1.0;POLYGON Z ((354518.5 6689396 47.5, 354518.6 6689396.9 47.5, 354518.6 6689397.5 47.5, 354520.2 6689399.5 47.5, 354520.4 6689401.1 47.5, 354521.9 6689402 47.5, 354521.7 6689403.2 47.5, 354523.1 6689405 47.5, 354527.2 6689409.6 47.5, 354529 6689410.1 47.5, 354532.3 6689410.9 47.5, 354534.9 6689400.5 47.5, 354525.4 6689389.7 47.5, 354518.5 6689396 47.5))
BATIMENT0000000302928854;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;02;5.1;26.8;31.9;32.9;27.9;Cadastre;C 0.4;POLYGON Z ((354466 6689371 31.9, 354470.3 6689371.5 31.9, 354471.5 6689360.2 31.9, 354467 6689359.7 31.9, 354466 6689371 31.9))
BATIMENT0000000302928492;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;20;20;18.5;24.7;43.3;45.9;26.7;Cadastre;C 0.7;POLYGON Z ((354424.3 6689371.9 43.3, 354423.1 6689371.7 43.3, 354423.8 6689367.9 43.3, 354425.4 6689367.4 43.3, 354431 6689368.2 43.3, 354432.5 6689356.4 43.3, 354416.7 6689354.8 43.3, 354411.5 6689380.1 43.3, 354422.1 6689382.1 43.3, 354424.3 6689371.9 43.3))
BATIMENT0000000302928501;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;27.0;32.2;36.0;27.9;Cadastre;;POLYGON Z ((354446.8 6689375.2 32.2, 354450.5 6689375.2 32.2, 354451.2 6689371.1 32.2, 354447 6689370.8 32.2, 354446.8 6689375.2 32.2))
BATIMENT0000000302928496;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;25.6;31.0;32.5;26.5;Cadastre;;POLYGON Z ((354430.5 6689371.9 31, 354429.3 6689371.7 31, 354428.9 6689373.3 31, 354428.2 6689373.2 31, 354427.8 6689375.9 31, 354429.9 6689376.5 31, 354430.5 6689371.9 31))
BATIMENT0000000302928497;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;4.8;26.0;30.8;31.2;27.6;Cadastre;C 0.6;POLYGON Z ((354434.4 6689381.5 30.8, 354435.3 6689371.5 30.8, 354430.5 6689370.9 30.8, 354430.5 6689371.9 30.8, 354429.9 6689376.5 30.8, 354428.9 6689383.4 30.8, 354441.9 6689386.1 30.8, 354442.2 6689383.3 30.8, 354434.4 6689381.5 30.8))
BATIMENT0000000302928491;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;25.6;30.8;32.2;26.5;Cadastre;;POLYGON Z ((354426 6689382.9 30.8, 354428.9 6689383.4 30.8, 354429.9 6689376.5 30.8, 354427.8 6689375.9 30.8, 354426.5 6689375.7 30.8, 354426 6689379.1 30.8, 354425.2 6689382.7 30.8, 354426 6689382.9 30.8))
BATIMENT0000000302928490;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;25.5;33.2;35.0;26.4;Cadastre;;POLYGON Z ((354425.2 6689382.7 33.2, 354426 6689379.1 33.2, 354424.8 6689379 33.2, 354424 6689382.5 33.2, 354425.2 6689382.7 33.2))
BATIMENT0000000302928499;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;27.0;29.8;30.2;28.2;Cadastre;;POLYGON Z ((354445.9 6689387 29.8, 354446.1 6689384.4 29.8, 354442.2 6689383.3 29.8, 354441.9 6689386.1 29.8, 354445.9 6689387 29.8))
BATIMENT0000000302928489;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;26.1;33.4;39.2;26.4;Cadastre;A 1.0;POLYGON Z ((354425.2 6689382.7 33.4, 354424 6689382.5 33.4, 354422.1 6689382.1 33.4, 354411.5 6689380.1 33.4, 354409.5 6689390.1 33.4, 354418 6689391.8 33.4, 354421.6 6689392.6 33.4, 354421.8 6689392.6 33.4, 354422.5 6689389.3 33.4, 354424.9 6689389.8 33.4, 354425.6 6689386.5 33.4, 354425.3 6689386.5 33.4, 354426 6689382.9 33.4, 354425.2 6689382.7 33.4))
BATIMENT0000000302928494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;27.0;29.7;33.2;27.8;Cadastre;;POLYGON Z ((354441.2 6689393.6 29.7, 354441.2 6689396.4 29.7, 354445.1 6689397.2 29.7, 354445.4 6689394.5 29.7, 354441.2 6689393.6 29.7))
BATIMENT0000000302928894;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;20;20;16.2;25.5;41.7;;;Cadastre;A 1.0;POLYGON Z ((354392.4 6689366.5 41.7, 354392.4 6689367.2 41.7, 354390.4 6689376.7 41.7, 354400.3 6689378.9 41.7, 354405.5 6689354.4 41.7, 354405.5 6689353.8 41.7, 354394.4 6689352.8 41.7, 354392.4 6689366.5 41.7))
BATIMENT0000000302929110;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;2.9;21.9;24.8;26.0;22.8;Cadastre;C 0.5;POLYGON Z ((354350.5 6689376.2 24.8, 354354.2 6689376.6 24.8, 354355.2 6689376.6 24.8, 354355.5 6689373.7 24.8, 354354.4 6689373.5 24.8, 354354.6 6689371.9 24.8, 354355.7 6689372 24.8, 354356 6689369 24.8, 354351.5 6689368.5 24.8, 354350.5 6689376.2 24.8))
BATIMENT0000000302928896;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;23.2;25.8;33.7;23.9;Cadastre;;POLYGON Z ((354382.3 6689374.9 25.8, 354381.1 6689380 25.8, 354389.3 6689381.9 25.8, 354390.4 6689376.7 25.8, 354382.3 6689374.9 25.8))
BATIMENT0000000302929109;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;3.5;21.9;25.5;30.2;22.8;Cadastre;C 0.3;POLYGON Z ((354350.5 6689376.2 25.5, 354349.6 6689383.3 25.5, 354353.3 6689383.7 25.5, 354354.2 6689376.6 25.5, 354350.5 6689376.2 25.5))
BATIMENT0000000302929107;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;4.0;22.6;26.7;31.0;23.2;Cadastre;C 0.3;POLYGON Z ((354363.9 6689384.9 26.7, 354367.3 6689385.2 26.7, 354368.3 6689378.2 26.7, 354364.9 6689377.8 26.7, 354363.9 6689384.9 26.7))
BATIMENT0000000302928895;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;11.0;23.2;34.3;36.7;25.5;Cadastre;A 1.0;POLYGON Z ((354386.6 6689395.5 34.3, 354396.4 6689397.5 34.3, 354400.3 6689378.9 34.3, 354390.4 6689376.7 34.3, 354389.3 6689381.9 34.3, 354386.6 6689395.5 34.3))
BATIMENT0000000302928654;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.6;21.6;28.2;32.2;22.4;Cadastre;C 0.3;POLYGON Z ((354345.3 6689396.1 28.2, 354345.1 6689401.4 28.2, 354348.5 6689401.5 28.2, 354349 6689396.4 28.2, 354345.3 6689396.1 28.2))
BATIMENT0000000302928655;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;50;20;9.5;22.6;32.1;34.3;23.3;Cadastre;C 0.3;POLYGON Z ((354348.9 6689403.4 32.1, 354349.8 6689403.9 32.1, 354350.2 6689404.1 32.1, 354350.6 6689404.4 32.1, 354351 6689404.7 32.1, 354351.3 6689405 32.1, 354351.7 6689405.3 32.1, 354351.9 6689405.7 32.1, 354352.2 6689406.1 32.1, 354352.4 6689406.5 32.1, 354352.6 6689407 32.1, 354352.7 6689407.4 32.1, 354352.8 6689407.9 32.1, 354359.6 6689409.2 32.1, 354361.1 6689403 32.1, 354365.7 6689403.3 32.1, 354366.8 6689395.6 32.1, 354361 6689395.3 32.1, 354360.8 6689394.7 32.1, 354355.5 6689394.5 32.1, 354355.4 6689394.9 32.1, 354349.2 6689394.6 32.1, 354349 6689396.4 32.1, 354348.5 6689401.5 32.1, 354348.5 6689403.1 32.1, 354348.9 6689403.4 32.1))
BATIMENT0000000302928651;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;20.5;31.7;33.7;22.1;Cadastre;;POLYGON Z ((354345.1 6689401.4 31.7, 354341.7 6689401.3 31.7, 354340.9 6689405.5 31.7, 354342.6 6689405.9 31.7, 354344.1 6689404.3 31.7, 354344.4 6689404.1 31.7, 354344.8 6689403.7 31.7, 354345.1 6689403.5 31.7, 354345.5 6689403.3 31.7, 354345.6 6689403.2 31.7, 354345.8 6689403.2 31.7, 354346.1 6689403.1 31.7, 354346.8 6689403.1 31.7, 354347 6689403.1 31.7, 354347.4 6689403.1 31.7, 354347.6 6689403.1 31.7, 354348.5 6689403.1 31.7, 354348.5 6689401.5 31.7, 354345.1 6689401.4 31.7))
BATIMENT0000000302928897;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;10.4;23.2;33.7;36.7;25.5;Cadastre;A 1.0;POLYGON Z ((354381.9 6689417.8 33.7, 354392 6689419.8 33.7, 354396.4 6689397.5 33.7, 354386.6 6689395.5 33.7, 354381.9 6689417.8 33.7))
BATIMENT0000000302928534;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;29.0;36.5;39.0;29.7;Cadastre;;POLYGON Z ((354515.9 6689406.8 36.5, 354514.8 6689411 36.5, 354518.1 6689411.8 36.5, 354519 6689407.6 36.5, 354515.9 6689406.8 36.5))
BATIMENT0000000302928533;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;00;00;12.2;28.3;40.5;46.0;29.5;Cadastre;C 0.5;POLYGON Z ((354503.2 6689403.9 40.5, 354500.6 6689415.9 40.5, 354513.2 6689418.9 40.5, 354514.8 6689411 40.5, 354515.9 6689406.8 40.5, 354503.2 6689403.9 40.5))
BATIMENT0000000302928536;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;6.5;28.8;35.3;46.9;29.9;Cadastre;C 0.4;POLYGON Z ((354525.8 6689421.9 35.3, 354527 6689422.2 35.3, 354530.7 6689423 35.3, 354533.5 6689423.6 35.3, 354538.2 6689404.5 35.3, 354534.9 6689400.5 35.3, 354532.3 6689410.9 35.3, 354529 6689410.1 35.3, 354525.8 6689421.9 35.3))
BATIMENT0000000302928486;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;90;14.4;27.1;41.5;43.4;28.5;Cadastre;A 1.0;POLYGON Z ((354476.2 6689419.8 41.5, 354489 6689422.7 41.5, 354491.3 6689412.6 41.5, 354478.1 6689411.6 41.5, 354476.2 6689419.8 41.5))
BATIMENT0000000302928539;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1856-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;18.9;28.7;47.6;49.3;29.7;Cadastre;A 1.0;POLYGON Z ((354533.5 6689423.6 47.6, 354532 6689430.3 47.6, 354541.1 6689432.4 47.6, 354546.1 6689413.9 47.6, 354538.2 6689404.5 47.6, 354533.5 6689423.6 47.6))
BATIMENT0000000302928530;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;20;20;10.1;29.0;39.1;42.9;29.4;Cadastre;A 1.0;POLYGON Z ((354498.2 6689426.3 39.1, 354509.6 6689428.6 39.1, 354511.5 6689420.2 39.1, 354515.2 6689420.9 39.1, 354515.4 6689419.4 39.1, 354513.2 6689418.9 39.1, 354500.6 6689415.9 39.1, 354498.2 6689426.3 39.1))
BATIMENT0000000302928541;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;29.5;33.7;35.5;29.9;Cadastre;;POLYGON Z ((354525.8 6689421.9 33.7, 354525.5 6689421.8 33.7, 354525.2 6689423.1 33.7, 354526.7 6689423.4 33.7, 354527 6689422.2 33.7, 354525.8 6689421.9 33.7))
BATIMENT0000000302928483;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;12.2;28.3;40.5;43.1;28.9;Cadastre;C 0.9;POLYGON Z ((354473.1 6689433.4 40.5, 354486 6689436.4 40.5, 354489 6689422.7 40.5, 354476.2 6689419.8 40.5, 354473.1 6689433.4 40.5))
BATIMENT0000000302928532;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;3.4;29.3;32.7;44.7;30.5;Cadastre;A 0.5;POLYGON Z ((354529.7 6689426.9 32.7, 354518.5 6689424.7 32.7, 354517.4 6689430.4 32.7, 354524.6 6689431.9 32.7, 354540.2 6689435.2 32.7, 354541.1 6689432.4 32.7, 354532 6689430.3 32.7, 354533.5 6689423.6 32.7, 354530.7 6689423 32.7, 354529.7 6689426.9 32.7))
BATIMENT0000000302928529;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;28.8;32.9;37.7;30.5;Cadastre;;POLYGON Z ((354517.4 6689430.4 32.9, 354511.3 6689429 32.9, 354510.6 6689432.5 32.9, 354511.7 6689432.7 32.9, 354511.1 6689434.8 32.9, 354516.2 6689435.8 32.9, 354517.4 6689430.4 32.9))
BATIMENT0000000302929835;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;10;20;7.2;6.6;13.8;17.1;8.1;Cadastre;A 0.3;POLYGON Z ((355693.1 6688319 13.8, 355698.4 6688319.9 13.8, 355702.3 6688320.4 13.8, 355702.1047260761 6688312.003221275 13.8, 355682.0560859007 6688312.003221275 13.8, 355682.2 6688317.4 13.8, 355691.3 6688318.7 13.8, 355693.1 6688319 13.8))
BATIMENT0000000302929832;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.5;6.5;14.0;17.1;7.6;Cadastre;A 0.9;POLYGON Z ((355682.2 6688317.4 14, 355682.0560859007 6688312.003221275 14, 355673.44383341685 6688312.003221275 14, 355672.8 6688319.3 14, 355672.7 6688320.9 14, 355676.8 6688321.1 14, 355680.6 6688321.3 14, 355682.3 6688321.4 14, 355682.2 6688317.4 14))
BATIMENT0000000302929818;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.3;7.1;12.5;16.1;7.5;Cadastre;A 1.0;POLYGON Z ((355673.44383341685 6688312.003221275 12.5, 355666.68685672584 6688312.003221275 12.5, 355666.9 6688320.6 12.5, 355667 6688322.3 12.5, 355667 6688323.4 12.5, 355669.6 6688323.5 12.5, 355669.7 6688321.9 12.5, 355669.9 6688319 12.5, 355672.8 6688319.3 12.5, 355673.44383341685 6688312.003221275 12.5))
BATIMENT0000000302929839;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.7;6.3;14.0;17.0;7.5;Cadastre;C 0.4;POLYGON Z ((355712 6688329.6 14, 355711 6688312.7 14, 355704.10963261215 6688312.003221275 14, 355702.1047260761 6688312.003221275 14, 355702.3 6688320.4 14, 355698.4 6688319.9 14, 355698.4 6688321.4 14, 355701.6 6688322.1 14, 355701.5 6688329.1 14, 355701.4 6688330.7 14, 355712 6688329.6 14))
BATIMENT0000000302929815;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.4;6.3;16.7;19.7;7.4;Cadastre;;POLYGON Z ((355661.7 6688322.6 16.7, 355667 6688322.3 16.7, 355666.9 6688320.6 16.7, 355660.8 6688320.8 16.7, 355659.2 6688320.9 16.7, 355660.8 6688322 16.7, 355661.7 6688322.6 16.7))
BATIMENT0000000302929831;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;7.1;9.9;11.5;7.5;Cadastre;;POLYGON Z ((355672.4 6688323.6 9.9, 355672.6 6688322.1 9.9, 355669.7 6688321.9 9.9, 355669.6 6688323.5 9.9, 355672.4 6688323.6 9.9))
BATIMENT0000000302929833;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;6.7;13.7;16.7;7.4;Cadastre;;POLYGON Z ((355682.3 6688321.4 13.7, 355680.6 6688321.3 13.7, 355680.6 6688326 13.7, 355682.4 6688326 13.7, 355682.3 6688321.4 13.7))
BATIMENT0000000302929838;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;6.3;11.8;13.9;8.1;Cadastre;;POLYGON Z ((355691.3 6688318.7 11.8, 355690.5 6688323.5 11.8, 355691 6688324 11.8, 355691 6688331.8 11.8, 355693.4 6688331.5 11.8, 355695.3 6688331.3 11.8, 355695.3 6688329.6 11.8, 355695.1 6688321.1 11.8, 355693 6688320.9 11.8, 355693.1 6688319 11.8, 355691.3 6688318.7 11.8))
BATIMENT0000000302929834;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;6.3;10.4;14.4;8.1;Cadastre;;POLYGON Z ((355682.3 6688321.4 10.4, 355682.4 6688326 10.4, 355682.6 6688332.7 10.4, 355682.8 6688340.2 10.4, 355686.9 6688340.6 10.4, 355691.1 6688340.9 10.4, 355691 6688339.5 10.4, 355691 6688331.8 10.4, 355691 6688324 10.4, 355690.5 6688323.5 10.4, 355691.3 6688318.7 10.4, 355682.2 6688317.4 10.4, 355682.3 6688321.4 10.4))
BATIMENT0000000302929840;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;6.6;10.2;11.2;7.2;Cadastre;;POLYGON Z ((355698.1 6688331 10.2, 355700.9 6688330.7 10.2, 355701.4 6688330.7 10.2, 355701.5 6688329.1 10.2, 355695.3 6688329.6 10.2, 355695.3 6688331.3 10.2, 355698.1 6688331 10.2))
BATIMENT0000000302929845;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;7.2;21.0;21.6;7.6;Cadastre;;POLYGON Z ((355583.2 6688314 21, 355583 6688316.5 21, 355596.7 6688317.7 21, 355596.7 6688317.5 21, 355597.16704655834 6688312.003221275 21, 355577.2997852483 6688312.003221275 21, 355577.2 6688313.5 21, 355583.2 6688314 21))
BATIMENT0000000302929822;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;5.0;00;00;12.9;6.3;19.2;21.5;7.8;Cadastre;C 0.6;POLYGON Z ((355596.7 6688317.7 19.2, 355601.3 6688318.2 19.2, 355601.4 6688317.7 19.2, 355613.9 6688318.9 19.2, 355613.9 6688319.4 19.2, 355628 6688320.7 19.2, 355628.76096813846 6688312.003221275 19.2, 355597.16704655834 6688312.003221275 19.2, 355596.7 6688317.5 19.2, 355596.7 6688317.7 19.2))
BATIMENT0000000302929821;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.8;6.3;19.1;21.4;7.4;Cadastre;;POLYGON Z ((355631.3 6688321 19.1, 355631.3 6688320.5 19.1, 355637.7 6688321 19.1, 355637.8 6688319.5 19.1, 355638.06966829946 6688312.003221275 19.1, 355628.76096813846 6688312.003221275 19.1, 355628 6688320.7 19.1, 355631.3 6688321 19.1))
BATIMENT0000000302929848;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;7.1;10.2;18.9;7.6;Cadastre;;POLYGON Z ((355582.7 6688321.4 10.2, 355583 6688316.5 10.2, 355583.2 6688314 10.2, 355577.2 6688313.5 10.2, 355576.6 6688320.9 10.2, 355582.7 6688321.4 10.2))
BATIMENT0000000302929817;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;7.1;10.1;13.5;7.5;Cadastre;;POLYGON Z ((355641.9 6688323.1 10.1, 355637.6 6688322.5 10.1, 355637.6 6688323.6 10.1, 355637.5 6688328 10.1, 355635.4 6688342.7 10.1, 355639.2 6688343.2 10.1, 355641.9 6688323.1 10.1))
BATIMENT0000000302929812;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.1;6.3;17.4;19.4;7.4;Cadastre;;POLYGON Z ((355648.6 6688319.8 17.4, 355649.6 6688367.9 17.4, 355650.8 6688367.8 17.4, 355650.8 6688364.5 17.4, 355657.8 6688364.5 17.4, 355657.6 6688357.8 17.4, 355657.1 6688321 17.4, 355659.2 6688320.9 17.4, 355660.8 6688320.8 17.4, 355666.9 6688320.6 17.4, 355666.68685672584 6688312.003221275 17.4, 355638.06966829946 6688312.003221275 17.4, 355637.8 6688319.5 17.4, 355648.6 6688319.8 17.4))
BATIMENT0000000302929853;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;2.0;00;00;5.8;7.3;13.2;15.2;7.9;Cadastre;C 0.5;POLYGON Z ((355569.9 6688351.7 13.2, 355574.3 6688352.2 13.2, 355576.1 6688352.3 13.2, 355575.2 6688362.8 13.2, 355581.6 6688363.4 13.2, 355582.1 6688358.2 13.2, 355588.1 6688358.8 13.2, 355587.6 6688363.9 13.2, 355598 6688364.9 13.2, 355598.5 6688359.7 13.2, 355604.5 6688360.3 13.2, 355604 6688365.5 13.2, 355610.5 6688366.1 13.2, 355611.4 6688355.6 13.2, 355613.2 6688355.8 13.2, 355617.2 6688356.1 13.2, 355618 6688346.9 13.2, 355611.9 6688346.4 13.2, 355611.2 6688354 13.2, 355576.1 6688350.8 13.2, 355576.9 6688343.2 13.2, 355570.7 6688342.6 13.2, 355569.9 6688351.7 13.2))
BATIMENT0000000302929855;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.7;6.1;14.8;15.2;7.8;Cadastre;;POLYGON Z ((355573.4 6688362.6 14.8, 355575.2 6688362.8 14.8, 355576.1 6688352.3 14.8, 355574.3 6688352.2 14.8, 355573.4 6688362.6 14.8))
BATIMENT0000000302929854;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;7.6;12.2;14.9;7.8;Cadastre;;POLYGON Z ((355612.3 6688366.3 12.2, 355613.2 6688355.8 12.2, 355611.4 6688355.6 12.2, 355610.5 6688366.1 12.2, 355612.3 6688366.3 12.2))
BATIMENT0000000302929820;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;6.7;10.0;14.1;7.1;Cadastre;;POLYGON Z ((355650.8 6688367.8 10, 355649.6 6688367.9 10, 355647.6 6688367.8 10, 355647.8 6688372.9 10, 355650.8 6688372.9 10, 355650.8 6688367.8 10))
BATIMENT0000000302929413;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.2;7.3;10.5;11.0;7.7;Cadastre;A 1.0;POLYGON Z ((355778 6688326.2 10.5, 355792.6 6688328 10.5, 355793.5 6688319.9 10.5, 355778.8 6688318.6 10.5, 355778 6688326.2 10.5))
BATIMENT0000000302929414;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;3.0;00;00;7.1;7.0;14.1;15.0;7.6;Cadastre;A 1.0;POLYGON Z ((355792.6 6688328 14.1, 355811.1 6688330.7 14.1, 355811.1 6688329.9 14.1, 355811.8 6688321.6 14.1, 355793.5 6688319.9 14.1, 355792.6 6688328 14.1))
BATIMENT0000000302929417;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;2.0;20;20;7.6;7.0;14.6;16.8;7.9;Cadastre;A 1.0;POLYGON Z ((355811.1 6688329.9 14.6, 355816 6688330.2 14.6, 355816.2 6688328.6 14.6, 355818.2 6688328.9 14.6, 355817.4 6688333.7 14.6, 355827.2 6688335 14.6, 355827.5 6688332.8 14.6, 355828.2 6688328.1 14.6, 355829 6688323.2 14.6, 355811.8 6688321.6 14.6, 355811.1 6688329.9 14.6))
BATIMENT0000000302929921;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;4.0;20;20;14.9;6.0;20.9;24.2;7.5;Cadastre;A 1.0;POLYGON Z ((355733.3 6688338.8 20.9, 355737.3 6688342.3 20.9, 355764.2 6688344.5 20.9, 355766.5 6688317.4 20.9, 355736.1 6688314.6 20.9, 355732.4 6688318.1 20.9, 355733.3 6688338.8 20.9), (355741.8 6688321.2 20.9, 355748.1 6688321.7 20.9, 355751.2 6688321.9 20.9, 355757 6688322.5 20.9, 355755.9 6688334.7 20.9, 355747.7 6688334.1 20.9, 355742.2 6688333.7 20.9, 355741.8 6688321.2 20.9))
BATIMENT0000000302929415;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;3.0;00;00;4.5;7.2;11.8;17.1;7.7;Cadastre;A 1.0;POLYGON Z ((355777.3 6688332.6 11.8, 355792.6 6688334.8 11.8, 355800.4 6688335.9 11.8, 355804.9 6688336.9 11.8, 355804.5 6688342.4 11.8, 355804.2 6688347.7 11.8, 355812.3 6688348.3 11.8, 355813.3 6688341.7 11.8, 355813.4 6688340.9 11.8, 355813.8 6688338 11.8, 355814.5 6688333.4 11.8, 355777.7 6688328.1 11.8, 355777.3 6688332.6 11.8))
BATIMENT0000000302929424;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;2.0;00;00;6.1;7.0;13.1;15.9;7.8;Cadastre;A 1.0;POLYGON Z ((355770.2 6688345 13.1, 355791.6 6688346.7 13.1, 355792.5 6688336.7 13.1, 355792.6 6688334.8 13.1, 355777.3 6688332.6 13.1, 355770 6688331.7 13.1, 355770.2 6688345 13.1))
BATIMENT0000000302929420;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;7.0;9.2;18.2;7.4;Cadastre;;POLYGON Z ((355825 6688339.3 9.2, 355813.8 6688338 9.2, 355813.4 6688340.9 9.2, 355820.5 6688341.5 9.2, 355824.5 6688341.2 9.2, 355825 6688339.3 9.2))
BATIMENT0000000302929423;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;50;10;3.8;7.3;11.1;16.2;7.8;Cadastre;A 1.0;POLYGON Z ((355792.6 6688334.8 11.1, 355792.5 6688336.7 11.1, 355791.6 6688346.7 11.1, 355804.2 6688347.7 11.1, 355804.5 6688342.4 11.1, 355801 6688342.2 11.1, 355800.4 6688335.9 11.1, 355792.6 6688334.8 11.1))
BATIMENT0000000302929422;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;10;7.1;7.0;14.1;14.6;7.7;Cadastre;A 1.0;POLYGON Z ((355812.3 6688348.3 14.1, 355819.7 6688348.9 14.1, 355821.4 6688344 14.1, 355818.5 6688343.5 14.1, 355818.6 6688342 14.1, 355813.3 6688341.7 14.1, 355812.3 6688348.3 14.1))
BATIMENT0000000302929904;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.3;6.0;15.3;20.0;7.6;Cadastre;A 1.0;POLYGON Z ((355781 6688375.4 15.3, 355801.1 6688377.3 15.3, 355802.9 6688357.8 15.3, 355795.7 6688357.2 15.3, 355795.3 6688361.6 15.3, 355788.7 6688361 15.3, 355789.1 6688356.7 15.3, 355782.5 6688356.1 15.3, 355781 6688375.4 15.3))
BATIMENT0000000302929829;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;6.7;9.7;15.4;7.5;Cadastre;;POLYGON Z ((355672.6 6688322.1 9.7, 355672.4 6688323.6 9.7, 355669.6 6688323.5 9.7, 355667 6688323.4 9.7, 355667.2 6688331.9 9.7, 355667.4 6688339 9.7, 355682.8 6688340.2 9.7, 355682.6 6688332.7 9.7, 355673.3 6688331.8 9.7, 355673.1 6688323.4 9.7, 355676.6 6688323.1 9.7, 355676.8 6688321.1 9.7, 355672.7 6688320.9 9.7, 355672.6 6688322.1 9.7))
BATIMENT0000000302929841;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;6.5;10.2;11.1;7.1;Cadastre;;POLYGON Z ((355695.3 6688331.3 10.2, 355693.4 6688331.5 10.2, 355693.5 6688334.2 10.2, 355698.2 6688333.9 10.2, 355698.1 6688331 10.2, 355695.3 6688331.3 10.2))
BATIMENT0000000302929842;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;20;20;8.6;6.4;15.0;20.2;7.3;Cadastre;A 1.0;POLYGON Z ((355701.6 6688339.4 15, 355701.7 6688341.7 15, 355712.7 6688342.6 15, 355712 6688329.6 15, 355701.4 6688330.7 15, 355700.9 6688330.7 15, 355701.6 6688339.4 15))
BATIMENT0000000302929836;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;6.6;12.0;12.1;6.9;Cadastre;;POLYGON Z ((355692.2 6688341 12, 355692.2 6688339.6 12, 355691 6688339.5 12, 355691.1 6688340.9 12, 355692.2 6688341 12))
BATIMENT0000000302929843;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;6.6;17.5;19.5;7.2;Cadastre;;POLYGON Z ((355699.4 6688339.5 17.5, 355699.4 6688341.6 17.5, 355701.7 6688341.7 17.5, 355701.6 6688339.4 17.5, 355699.4 6688339.5 17.5))
BATIMENT0000000302929837;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;39.0;7.0;00;00;7.8;6.8;14.7;30.5;7.3;Cadastre;A 1.0;POLYGON Z ((355687 6688343.8 14.7, 355693.9 6688344.4 14.7, 355695.2 6688369.4 14.7, 355714.1 6688368.7 14.7, 355712.7 6688342.6 14.7, 355701.7 6688341.7 14.7, 355699.4 6688341.6 14.7, 355692.2 6688341 14.7, 355691.1 6688340.9 14.7, 355686.9 6688340.6 14.7, 355687 6688343.8 14.7))
BATIMENT0000000302929827;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;7.0;16.0;17.4;7.6;Cadastre;;POLYGON Z ((355660.7 6688367.6 16, 355660.7 6688371.7 16, 355662.2 6688371.7 16, 355662.4 6688375.6 16, 355668.5 6688375.5 16, 355668.3 6688370.2 16, 355668.2 6688367.5 16, 355660.7 6688367.6 16))
BATIMENT0000000302929826;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;6.3;11.8;13.7;7.4;Cadastre;;POLYGON Z ((355714.2 6688370.5 11.8, 355702.3 6688371.1 11.8, 355704 6688402.4 11.8, 355716 6688402 11.8, 355714.2 6688370.5 11.8))
BATIMENT0000000302929828;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;6.8;16.5;17.6;7.4;Cadastre;;POLYGON Z ((355662.2 6688371.7 16.5, 355660.7 6688371.7 16.5, 355656.5 6688371.9 16.5, 355656.8 6688382.5 16.5, 355657 6688390.7 16.5, 355657.5 6688409.2 16.5, 355659.6 6688409.2 16.5, 355661.8 6688409.2 16.5, 355661.7 6688412.9 16.5, 355663.4 6688412.8 16.5, 355663.3 6688409.6 16.5, 355662.4 6688375.6 16.5, 355662.2 6688371.7 16.5))
BATIMENT0000000302929824;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;MSS;MSS:71963;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;7.0;16.1;17.6;7.6;Cadastre;;POLYGON Z ((355662.4 6688375.6 16.1, 355663.3 6688409.6 16.1, 355669.4 6688409.6 16.1, 355669.2 6688403.6 16.1, 355668.5 6688375.5 16.1, 355662.4 6688375.6 16.1))
BATIMENT0000000302929690;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;29.0;4.0;20;20;13.5;6.2;19.7;22.4;7.5;Cadastre;C 0.8;POLYGON Z ((355734.6 6688355.4 19.7, 355735.5 6688371.3 19.7, 355744.6 6688370.9 19.7, 355744.1 6688361.8 19.7, 355769.8 6688363.8 19.7, 355768.1 6688386 19.7, 355747.4 6688386.6 19.7, 355745.3 6688385.2 19.7, 355744.9 6688378.8 19.7, 355735.9 6688379.2 19.7, 355736.7 6688395.7 19.7, 355776.3 6688395 19.7, 355776.8 6688388.7 19.7, 355779.6 6688354.9 19.7, 355738.1 6688351.5 19.7, 355734.6 6688355.4 19.7))
BATIMENT0000000302929695;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;7.3;10.0;12.4;7.5;Cadastre;;POLYGON Z ((355811.9 6688381.4 10, 355811.4 6688384.9 10, 355813.1 6688385 10, 355813.4 6688381.5 10, 355811.9 6688381.4 10))
BATIMENT0000000302929692;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;7.2;9.9;13.0;7.5;Cadastre;;POLYGON Z ((355811 6688388.6 9.9, 355813.5 6688388.6 9.9, 355823.6 6688388.4 9.9, 355823.9 6688384.8 9.9, 355813.1 6688385 9.9, 355811.4 6688384.9 9.9, 355811 6688388.6 9.9))
BATIMENT0000000302929688;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;20;20;6.2;7.0;13.2;16.0;7.5;Cadastre;A 1.0;POLYGON Z ((355813.5 6688388.6 13.2, 355813.3 6688396.8 13.2, 355816.2 6688396.9 13.2, 355816.1 6688394.4 13.2, 355818.1 6688394.3 13.2, 355818.1 6688395.2 13.2, 355820.2 6688395.1 13.2, 355820.2 6688393 13.2, 355826 6688392.6 13.2, 355826.2 6688391.6 13.2, 355826.5 6688388.6 13.2, 355823.6 6688388.4 13.2, 355813.5 6688388.6 13.2))
BATIMENT0000000302929682;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;9.6;6.5;16.2;19.0;7.4;Cadastre;C 0.2;POLYGON Z ((355736.8 6688397.4 16.2, 355736.9 6688400 16.2, 355746.9 6688399.8 16.2, 355749 6688399.8 16.2, 355764.4 6688399.5 16.2, 355776 6688399.3 16.2, 355776.2 6688396.6 16.2, 355736.8 6688397.4 16.2))
BATIMENT0000000302929684;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;4.7;6.7;11.5;22.5;7.5;Cadastre;A 1.0;POLYGON Z ((355822.2 6688400.1 11.5, 355822.1 6688397.7 11.5, 355825.1 6688397.5 11.5, 355825.3 6688402 11.5, 355826.6 6688402 11.5, 355839.7 6688401.9 11.5, 355840.2 6688396.8 11.5, 355828.9 6688396 11.5, 355826 6688396.2 11.5, 355816.2 6688396.9 11.5, 355813.3 6688396.8 11.5, 355793.1 6688398.4 11.5, 355793.3 6688402 11.5, 355822.2 6688400.1 11.5))
BATIMENT0000000302929680;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;10;10;4.7;6.3;11.1;18.6;7.4;Cadastre;A 1.0;POLYGON Z ((355776 6688399.3 11.1, 355764.4 6688399.5 11.1, 355764.7 6688404.6 11.1, 355749.3 6688405.5 11.1, 355749.4 6688407.1 11.1, 355749.5 6688408.6 11.1, 355759.1 6688408.1 11.1, 355781.2 6688407.1 11.1, 355784.9 6688406.9 11.1, 355793.4 6688406.5 11.1, 355793.4 6688403.8 11.1, 355793.3 6688402 11.1, 355793.1 6688398.4 11.1, 355776 6688399.3 11.1))
BATIMENT0000000302929686;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.3;7.0;15.3;16.6;7.0;Cadastre;A 1.0;POLYGON Z ((355736.9 6688400 15.3, 355737.4 6688409.2 15.3, 355749.5 6688408.6 15.3, 355749.4 6688407.1 15.3, 355747.2 6688407.4 15.3, 355746.9 6688399.8 15.3, 355736.9 6688400 15.3))
BATIMENT0000000302929683;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;7.0;11.7;15.6;7.2;Cadastre;;POLYGON Z ((355793.4 6688406.5 11.7, 355794.4 6688406.4 11.7, 355795.8 6688406.2 11.7, 355795.8 6688403.7 11.7, 355793.4 6688403.8 11.7, 355793.4 6688406.5 11.7))
BATIMENT0000000302929681;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;33.0;6.0;00;00;14.8;6.6;21.5;27.1;7.4;Cadastre;A 1.0;POLYGON Z ((355823.4 6688419.9 21.5, 355823.2 6688416.1 21.5, 355823.1 6688413.5 21.5, 355822.4 6688413.6 21.5, 355821.5 6688405.3 21.5, 355821.3 6688404 21.5, 355810.8 6688404.1 21.5, 355795.8 6688406.2 21.5, 355794.4 6688406.4 21.5, 355794.3 6688408.8 21.5, 355794.3 6688420.3 21.5, 355823.4 6688419.9 21.5))
BATIMENT0000000302929811;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.9;11.2;16.6;7.3;Cadastre;;POLYGON Z ((355650.8 6688367.8 11.2, 355650.8 6688372.9 11.2, 355650.8 6688375.6 11.2, 355650.9 6688382.6 11.2, 355656.8 6688382.5 11.2, 355656.5 6688371.9 11.2, 355660.7 6688371.7 11.2, 355660.7 6688367.6 11.2, 355657.8 6688367.6 11.2, 355657.8 6688364.5 11.2, 355650.8 6688364.5 11.2, 355650.8 6688367.8 11.2))
BATIMENT0000000302929800;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.3;6.9;14.2;15.1;7.6;Cadastre;;POLYGON Z ((355578 6688379.9 14.2, 355578.5 6688374.8 14.2, 355576.7 6688374.6 14.2, 355576.2 6688379.8 14.2, 355578 6688379.9 14.2))
BATIMENT0000000302929809;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:21:06;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.7;6.6;15.3;22.0;8.1;Cadastre;C 0.1;POLYGON Z ((355620.4 6688411.5 15.3, 355619.4 6688422.9 15.3, 355626.1 6688423.5 15.3, 355626.2 6688422.6 15.3, 355643.3 6688423.1 15.3, 355643.3 6688424.1 15.3, 355650.2 6688424 15.3, 355650.1 6688414.6 15.3, 355651.1 6688414.6 15.3, 355651.1 6688409.4 15.3, 355650.8 6688390.8 15.3, 355650.9 6688382.6 15.3, 355650.8 6688375.6 15.3, 355645 6688375.8 15.3, 355645.2 6688408.5 15.3, 355627.6 6688407.5 15.3, 355631.4 6688361.5 15.3, 355631.6 6688360.6 15.3, 355636.3 6688361.2 15.3, 355637.2 6688354.1 15.3, 355637.7 6688354.2 15.3, 355639.2 6688343.2 15.3, 355635.4 6688342.7 15.3, 355634.8 6688346.6 15.3, 355633.6 6688353.6 15.3, 355633.2 6688356.6 15.3, 355622.8 6688357.2 15.3, 355620.6 6688383.2 15.3, 355618.7 6688408.2 15.3, 355618.4 6688411.3 15.3, 355620.4 6688411.5 15.3))
BATIMENT0000000302929810;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;6.3;13.9;17.2;7.2;Cadastre;;POLYGON Z ((355650.9 6688382.6 13.9, 355650.8 6688390.8 13.9, 355657 6688390.7 13.9, 355656.8 6688382.5 13.9, 355650.9 6688382.6 13.9))
BATIMENT0000000302929814;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;6.8;12.7;16.4;7.3;Cadastre;;POLYGON Z ((355650.8 6688390.8 12.7, 355651.1 6688409.4 12.7, 355657.5 6688409.2 12.7, 355657 6688390.7 12.7, 355650.8 6688390.8 12.7))
BATIMENT0000000302929808;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;36.0;6.0;90;90;15.6;6.6;22.3;27.2;7.7;Cadastre;C 0.3;POLYGON Z ((355618.4 6688411.7 22.3, 355618.4 6688411.3 22.3, 355618.7 6688408.2 22.3, 355611.8 6688407.6 22.3, 355611.8 6688408.1 22.3, 355606.7 6688407.6 22.3, 355606.7 6688407.1 22.3, 355591.5 6688405.7 22.3, 355591.4 6688406.2 22.3, 355584.3 6688405.5 22.3, 355584.3 6688405 22.3, 355579.8 6688404.6 22.3, 355578.6 6688419.3 22.3, 355617.4 6688422.7 22.3, 355618.4 6688411.7 22.3))
BATIMENT0000000302929864;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;10;3.8;6.4;10.2;15.3;6.9;Cadastre;A 1.0;POLYGON Z ((355564.1 6688442.5 10.2, 355579 6688443.9 10.2, 355582.3 6688444.2 10.2, 355583.2 6688434.5 10.2, 355576.5 6688433.8 10.2, 355565.1 6688432.8 10.2, 355564.1 6688442.5 10.2))
BATIMENT0000000302929866;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;2.0;00;00;6.6;6.1;12.7;17.0;6.7;Cadastre;A 1.0;POLYGON Z ((355601.1 6688448.9 12.7, 355599.9 6688443.3 12.7, 355603.1 6688442.3 12.7, 355605.5 6688447.9 12.7, 355612.4 6688446.3 12.7, 355617.6 6688445 12.7, 355618.1 6688437.7 12.7, 355583.2 6688434.5 12.7, 355582.3 6688444.2 12.7, 355583.3 6688453 12.7, 355601.1 6688448.9 12.7))
BATIMENT0000000302929865;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.1;6.1;13.2;18.0;6.8;Cadastre;A 0.4;POLYGON Z ((355564.1 6688442.5 13.2, 355564 6688445 13.2, 355563.8 6688448.3 13.2, 355578.9 6688445 13.2, 355579 6688443.9 13.2, 355564.1 6688442.5 13.2))
BATIMENT0000000302929530;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.5;12.7;27.5;7.1;Cadastre;;POLYGON Z ((355570.2 6688687.3 12.7, 355571.5 6688693.2 12.7, 355581.5 6688691 12.7, 355580.2 6688685.1 12.7, 355570.2 6688687.3 12.7))
BATIMENT0000000302929678;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.7;7.0;16.7;20.2;7.1;Cadastre;A 1.0;POLYGON Z ((355781.7 6688420.4 16.7, 355794.3 6688420.3 16.7, 355794.3 6688408.8 16.7, 355784.9 6688409.1 16.7, 355784.9 6688406.9 16.7, 355781.2 6688407.1 16.7, 355781.7 6688420.4 16.7))
BATIMENT0000000302929679;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;10.5;6.9;17.4;17.6;7.2;Cadastre;C 0.5;POLYGON Z ((355759.1 6688408.1 17.4, 355759.6 6688420.7 17.4, 355781.7 6688420.4 17.4, 355781.2 6688407.1 17.4, 355759.1 6688408.1 17.4))
BATIMENT0000000302929687;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;6.4;18.8;21.5;6.9;Cadastre;;POLYGON Z ((355759.2 6688420.7 18.8, 355759.3 6688420.7 18.8, 355759.6 6688420.7 18.8, 355759.1 6688408.1 18.8, 355749.5 6688408.6 18.8, 355737.4 6688409.2 18.8, 355738 6688421 18.8, 355759.2 6688420.7 18.8))
BATIMENT0000000302930007;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.3;5.8;29.1;30.0;7.2;Cadastre;;POLYGON Z ((355813.7 6688661.9 29.1, 355812.5 6688670.1 29.1, 355815.3 6688670.5 29.1, 355816.5 6688662.3 29.1, 355813.7 6688661.9 29.1))
BATIMENT0000000302930012;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;7.1;12.7;28.3;7.7;Cadastre;;POLYGON Z ((355794.5 6688677.9 12.7, 355798.1 6688678.1 12.7, 355798.5 6688675.2 12.7, 355796.9 6688675.1 12.7, 355797.2 6688674.3 12.7, 355799.4 6688669.4 12.7, 355802.2 6688664.9 12.7, 355802.2 6688664.8 12.7, 355805.9 6688660.8 12.7, 355809.6 6688658.3 12.7, 355811.4 6688657.8 12.7, 355809.5 6688658.2 12.7, 355805.7 6688660.5 12.7, 355804 6688662.2 12.7, 355801.7 6688664.5 12.7, 355799 6688669.3 12.7, 355798.7 6688670 12.7, 355796.6 6688673.9 12.7, 355793.3 6688677.8 12.7, 355792.9 6688678.3 12.7, 355791.4 6688679.9 12.7, 355791.8 6688679.9 12.7, 355792.7 6688680.1 12.7, 355794.5 6688677.9 12.7))
BATIMENT0000000302930009;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.3;7.1;24.5;30.3;7.7;Cadastre;C 0.2;POLYGON Z ((355788.4 6688687.8 24.5, 355794.8 6688688.8 24.5, 355794.8 6688689 24.5, 355798.2 6688689.7 24.5, 355798.2 6688689.9 24.5, 355799.3 6688690.1 24.5, 355800.3 6688690.3 24.5, 355801.5 6688684.3 24.5, 355806.7 6688685.4 24.5, 355808.7 6688682.7 24.5, 355811.8 6688674.9 24.5, 355812.5 6688670.1 24.5, 355813.7 6688661.9 24.5, 355813.5 6688659.3 24.5, 355813.2 6688658.3 24.5, 355812.3 6688657.7 24.5, 355811.4 6688657.8 24.5, 355809.6 6688658.3 24.5, 355805.9 6688660.8 24.5, 355802.2 6688664.8 24.5, 355802.2 6688664.9 24.5, 355799.4 6688669.4 24.5, 355797.2 6688674.3 24.5, 355796.9 6688675.1 24.5, 355798.5 6688675.2 24.5, 355798.1 6688678.1 24.5, 355794.5 6688677.9 24.5, 355792.7 6688680.1 24.5, 355791.2 6688682.2 24.5, 355788.4 6688687.7 24.5, 355788.4 6688687.8 24.5))
BATIMENT0000000302930010;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;12;20;14.7;7.3;22.0;24.0;7.6;Cadastre;A 1.0;POLYGON Z ((355778.8 6688704.5 22, 355790 6688708.9 22, 355791.1 6688709.4 22, 355791.8 6688707.2 22, 355792.5 6688707.3 22, 355791.8 6688705.9 22, 355799.3 6688690.1 22, 355798.2 6688689.9 22, 355798.2 6688689.7 22, 355794.8 6688689 22, 355794.8 6688688.8 22, 355788.4 6688687.8 22, 355788.4 6688687.7 22, 355786.6 6688687.4 22, 355778.7 6688704.4 22, 355778.8 6688704.5 22))
BATIMENT0000000302930017;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;6.5;14.2;17.4;7.4;Cadastre;;POLYGON Z ((355804.7 6688707.3 14.2, 355804.2 6688709.7 14.2, 355816.7 6688712.4 14.2, 355818.3 6688709.3 14.2, 355822.3 6688711.1 14.2, 355824.5 6688712 14.2, 355826.4 6688707.7 14.2, 355831.5 6688695.9 14.2, 355807.8 6688691.9 14.2, 355804.7 6688707.3 14.2))
BATIMENT0000000302930018;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;7.1;12.0;16.7;7.4;Cadastre;;POLYGON Z ((355804.7 6688707.3 12, 355798.6 6688706.1 12, 355798.1 6688708.6 12, 355803.4 6688709.6 12, 355804.2 6688709.7 12, 355804.7 6688707.3 12))
BATIMENT0000000302930015;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.1;10.5;14.2;6.6;Cadastre;;POLYGON Z ((355816.7 6688712.4 10.5, 355816.3 6688713 10.5, 355821.4 6688714.8 10.5, 355822.3 6688711.1 10.5, 355818.3 6688709.3 10.5, 355816.7 6688712.4 10.5))
BATIMENT0000000302929825;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.4;6.3;12.7;18.0;7.6;Cadastre;;POLYGON Z ((355669.4 6688410.6 12.7, 355716.4 6688409 12.7, 355716 6688402 12.7, 355704 6688402.4 12.7, 355669.2 6688403.6 12.7, 355669.4 6688409.6 12.7, 355669.4 6688410.6 12.7))
BATIMENT0000000302929823;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.2;6.6;16.9;21.2;7.4;Cadastre;C 0.2;POLYGON Z ((355669.7 6688419.1 16.9, 355687.2 6688418.7 16.9, 355687.4 6688423.3 16.9, 355699.1 6688423.1 16.9, 355699 6688418.6 16.9, 355716.9 6688418.1 16.9, 355716.4 6688409 16.9, 355669.4 6688410.6 16.9, 355669.5 6688412.8 16.9, 355669.7 6688419.1 16.9))
BATIMENT0000000302929819;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;10.2;6.7;17.0;20.9;7.3;Cadastre;A 1.0;POLYGON Z ((355651.2 6688424 17, 355659.6 6688423.8 17, 355669.8 6688423.6 17, 355669.7 6688419.1 17, 355669.5 6688412.8 17, 355663.4 6688412.8 17, 355661.7 6688412.9 17, 355659.6 6688412.9 17, 355657.6 6688413 17, 355657.5 6688409.2 17, 355651.1 6688409.4 17, 355651.1 6688414.6 17, 355651.2 6688424 17))
BATIMENT0000000302929524;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;25.6;6.8;32.4;33.5;8.5;Cadastre;;POLYGON Z ((355682 6688691.8 32.4, 355682.5 6688692.1 32.4, 355682.7 6688692.2 32.4, 355683.3 6688692.6 32.4, 355684.4 6688693.3 32.4, 355684.8 6688693.5 32.4, 355685 6688693.7 32.4, 355685.4 6688693.9 32.4, 355685.9 6688694.1 32.4, 355686.5 6688694.5 32.4, 355686.8 6688694.6 32.4, 355687 6688694.7 32.4, 355687.2 6688694.8 32.4, 355687.7 6688695.1 32.4, 355688.3 6688695.4 32.4, 355689.5 6688695.9 32.4, 355689.7 6688696 32.4, 355690.6 6688696.4 32.4, 355691.1 6688696.5 32.4, 355691.6 6688696.7 32.4, 355693 6688697.2 32.4, 355693.5 6688697.3 32.4, 355693.7 6688697.4 32.4, 355694.9 6688697.8 32.4, 355695.6 6688697.9 32.4, 355695.9 6688698 32.4, 355696.3 6688698.1 32.4, 355697.1 6688698.3 32.4, 355697.3 6688698.4 32.4, 355697.8 6688698.4 32.4, 355698.8 6688698.6 32.4, 355699 6688698.7 32.4, 355699.8 6688698.8 32.4, 355700.3 6688698.9 32.4, 355701 6688699 32.4, 355701.2 6688699 32.4, 355702 6688699.1 32.4, 355702.7 6688699.1 32.4, 355703.1 6688699.2 32.4, 355704.3 6688699.1 32.4, 355705.4 6688699 32.4, 355706.2 6688698.9 32.4, 355706.6 6688698.9 32.4, 355707.7 6688698.7 32.4, 355708.5 6688698.5 32.4, 355709.2 6688698.3 32.4, 355709.9 6688698.1 32.4, 355710.3 6688697.9 32.4, 355711 6688697.7 32.4, 355711.4 6688697.5 32.4, 355711.8 6688697.3 32.4, 355712.4 6688697 32.4, 355713.4 6688696.5 32.4, 355713.8 6688696.3 32.4, 355714.1 6688696.1 32.4, 355714.8 6688695.7 32.4, 355715.7 6688695 32.4, 355716.3 6688694.6 32.4, 355717.2 6688693.8 32.4, 355717.9 6688693.1 32.4, 355718.3 6688692.8 32.4, 355718.6 6688692.5 32.4, 355719.1 6688691.9 32.4, 355719.6 6688691.3 32.4, 355719.8 6688691 32.4, 355720.3 6688690.4 32.4, 355720.5 6688690.1 32.4, 355720.7 6688689.8 32.4, 355721.3 6688688.8 32.4, 355721.9 6688687.8 32.4, 355722.5 6688686.4 32.4, 355722.8 6688685.7 32.4, 355722.9 6688685.3 32.4, 355723.2 6688684.6 32.4, 355723.3 6688684.2 32.4, 355723.6 6688683.1 32.4, 355723.7 6688682.3 32.4, 355723.9 6688681.6 32.4, 355724 6688680.8 32.4, 355724.1 6688680.1 32.4, 355724.1 6688679.7 32.4, 355724.1 6688678.9 32.4, 355724.1 6688678.5 32.4, 355724.1 6688678.1 32.4, 355724.1 6688677.8 32.4, 355724.1 6688677.4 32.4, 355723.8 6688675.8 32.4, 355721.1 6688663.7 32.4, 355734.5 6688660.8 32.4, 355739.2 6688659.8 32.4, 355742.3 6688655 32.4, 355733.7 6688656.9 32.4, 355718.3 6688660.4 32.4, 355698.6 6688664.8 32.4, 355676.7 6688669.7 32.4, 355662.6 6688672.8 32.4, 355655.5 6688674.4 32.4, 355682 6688691.8 32.4))
BATIMENT0000000302929519;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;24.2;6.7;30.9;34.5;8.5;Cadastre;;POLYGON Z ((355658.3 6688693.1 30.9, 355663 6688715 30.9, 355679.1 6688712 30.9, 355693 6688720.9 30.9, 355699.3 6688724.9 30.9, 355716.1 6688735.6 30.9, 355733.4 6688708.1 30.9, 355737.8 6688701 30.9, 355746.9 6688686.6 30.9, 355749.4 6688688.2 30.9, 355763.3 6688666.1 30.9, 355759.7 6688663.8 30.9, 355763.3 6688657.9 30.9, 355762.6 6688657.5 30.9, 355747.6 6688647.7 30.9, 355747.2 6688647.5 30.9, 355747 6688647.8 30.9, 355742.3 6688655 30.9, 355739.2 6688659.8 30.9, 355734.5 6688660.8 30.9, 355721.1 6688663.7 30.9, 355723.8 6688675.8 30.9, 355724.1 6688677.4 30.9, 355724.1 6688677.8 30.9, 355724.1 6688678.1 30.9, 355724.1 6688678.5 30.9, 355724.1 6688678.9 30.9, 355724.1 6688679.7 30.9, 355724.1 6688680.1 30.9, 355724 6688680.8 30.9, 355723.9 6688681.6 30.9, 355723.7 6688682.3 30.9, 355723.6 6688683.1 30.9, 355723.3 6688684.2 30.9, 355723.2 6688684.6 30.9, 355722.9 6688685.3 30.9, 355722.8 6688685.7 30.9, 355722.5 6688686.4 30.9, 355721.9 6688687.8 30.9, 355721.3 6688688.8 30.9, 355720.7 6688689.8 30.9, 355720.5 6688690.1 30.9, 355720.3 6688690.4 30.9, 355719.8 6688691 30.9, 355719.6 6688691.3 30.9, 355719.1 6688691.9 30.9, 355718.6 6688692.5 30.9, 355718.3 6688692.8 30.9, 355717.9 6688693.1 30.9, 355717.2 6688693.8 30.9, 355716.3 6688694.6 30.9, 355715.7 6688695 30.9, 355714.8 6688695.7 30.9, 355714.1 6688696.1 30.9, 355713.8 6688696.3 30.9, 355713.4 6688696.5 30.9, 355712.4 6688697 30.9, 355711.8 6688697.3 30.9, 355711.4 6688697.5 30.9, 355711 6688697.7 30.9, 355710.3 6688697.9 30.9, 355709.9 6688698.1 30.9, 355709.2 6688698.3 30.9, 355708.5 6688698.5 30.9, 355707.7 6688698.7 30.9, 355706.6 6688698.9 30.9, 355706.2 6688698.9 30.9, 355705.4 6688699 30.9, 355704.3 6688699.1 30.9, 355703.1 6688699.2 30.9, 355702.7 6688699.1 30.9, 355702 6688699.1 30.9, 355701.2 6688699 30.9, 355701 6688699 30.9, 355700.3 6688698.9 30.9, 355699.8 6688698.8 30.9, 355699 6688698.7 30.9, 355698.8 6688698.6 30.9, 355697.8 6688698.4 30.9, 355697.3 6688698.4 30.9, 355697.1 6688698.3 30.9, 355696.3 6688698.1 30.9, 355695.9 6688698 30.9, 355695.6 6688697.9 30.9, 355694.9 6688697.8 30.9, 355693.7 6688697.4 30.9, 355693.5 6688697.3 30.9, 355693 6688697.2 30.9, 355691.6 6688696.7 30.9, 355691.1 6688696.5 30.9, 355690.6 6688696.4 30.9, 355689.7 6688696 30.9, 355689.5 6688695.9 30.9, 355688.3 6688695.4 30.9, 355687.7 6688695.1 30.9, 355687.2 6688694.8 30.9, 355687 6688694.7 30.9, 355686.8 6688694.6 30.9, 355686.5 6688694.5 30.9, 355685.9 6688694.1 30.9, 355685.4 6688693.9 30.9, 355685 6688693.7 30.9, 355684.8 6688693.5 30.9, 355684.4 6688693.3 30.9, 355683.3 6688692.6 30.9, 355682.7 6688692.2 30.9, 355682.5 6688692.1 30.9, 355682 6688691.8 30.9, 355655.5 6688674.4 30.9, 355605.2 6688685.6 30.9, 355608.3 6688700.1 30.9, 355609.3 6688699.9 30.9, 355611 6688699.5 30.9, 355613.6 6688711.3 30.9, 355628.7 6688707.9 30.9, 355626.1 6688696.2 30.9, 355629 6688695.5 30.9, 355657.4 6688689.2 30.9, 355658.3 6688693.1 30.9))
BATIMENT0000000302929526;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.8;7.1;25.9;26.4;7.4;Cadastre;;POLYGON Z ((355717.2 6688736.3 25.9, 355718.5 6688737.1 25.9, 355734.6 6688711.6 25.9, 355749.4 6688688.2 25.9, 355746.9 6688686.6 25.9, 355737.8 6688701 25.9, 355733.4 6688708.1 25.9, 355716.1 6688735.6 25.9, 355717.2 6688736.3 25.9))
BATIMENT0000000302929523;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;8.2;10.0;25.7;8.6;Cadastre;;POLYGON Z ((355693 6688720.9 10, 355688.5 6688727.8 10, 355695.3 6688731 10, 355699.3 6688724.9 10, 355693 6688720.9 10))
BATIMENT0000000291499703;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-07-01 11:20:02;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.2;6.8;;10.7;8.5;Imagerie aérienne;;POLYGON Z ((355674.4 6688735.6 10, 355677.3 6688735.5 10, 355679.6 6688735.8 10, 355681.3 6688736.3 10, 355683 6688737.4 10, 355684.7 6688738.8 10, 355686.3 6688735.3 10, 355675.4 6688729.5 10, 355672 6688736.1 10, 355674.4 6688735.6 10))
BATIMENT0000000302929527;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;6.8;12.7;15.2;7.5;Cadastre;;POLYGON Z ((355711.3 6688748.3 12.7, 355718.5 6688737.1 12.7, 355717.2 6688736.3 12.7, 355710 6688747.6 12.7, 355711.3 6688748.3 12.7))
BATIMENT0000000302929536;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;7.5;10.8;17.0;7.9;Cadastre;;POLYGON Z ((355668.3 6688765.9 10.8, 355668.1 6688765.5 10.8, 355667.9 6688765 10.8, 355667.5 6688764.6 10.8, 355666.9 6688764.5 10.8, 355666.5 6688764.3 10.8, 355665.8 6688764.4 10.8, 355665.2 6688764.5 10.8, 355665 6688764.7 10.8, 355664.7 6688765 10.8, 355664.6 6688765.2 10.8, 355664.4 6688765.5 10.8, 355664.3 6688765.8 10.8, 355664.2 6688766.2 10.8, 355664.6 6688769 10.8, 355668.7 6688768.2 10.8, 355668.3 6688765.9 10.8))
BATIMENT0000000302930011;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;4.0;20;20;12.8;6.0;18.8;23.5;7.5;Cadastre;A 1.0;POLYGON Z ((355770.6 6688721.2 18.8, 355771.3 6688722.5 18.8, 355796 6688726.3 18.8, 355798.5 6688720.5 18.8, 355798.3 6688720.4 18.8, 355801.4 6688714 18.8, 355803.4 6688709.6 18.8, 355798.1 6688708.6 18.8, 355797.3 6688708.4 18.8, 355793.6 6688716.6 18.8, 355791.1 6688716.2 18.8, 355791.2 6688714.9 18.8, 355789.3 6688714.7 18.8, 355789.2 6688715.9 18.8, 355786.9 6688715.5 18.8, 355790 6688708.9 18.8, 355778.8 6688704.5 18.8, 355770.6 6688721.2 18.8))
BATIMENT0000000302930014;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;7.6;6.4;14.0;16.9;7.3;Cadastre;A 0.1;POLYGON Z ((355807.3 6688728.1 14, 355813.1 6688729.1 14, 355813.3 6688728.3 14, 355813 6688728.3 14, 355814.9 6688722 14, 355812.4 6688721.3 14, 355814.6 6688715.9 14, 355816.3 6688713 14, 355816.7 6688712.4 14, 355804.2 6688709.7 14, 355803.4 6688709.6 14, 355801.4 6688714 14, 355805.9 6688714.8 14, 355810.7 6688715.6 14, 355809.4 6688720.2 14, 355809.1 6688720.1 14, 355807.9 6688725.2 14, 355807.3 6688728.1 14))
BATIMENT0000000302930020;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;20;20;10.8;5.8;16.6;18.9;7.1;Cadastre;A 1.0;POLYGON Z ((355819.3 6688729.8 16.6, 355826.1 6688731.2 16.6, 355828.8 6688718.5 16.6, 355832.1 6688710.2 16.6, 355826.4 6688707.7 16.6, 355824.5 6688712 16.6, 355827.5 6688713.5 16.6, 355826.5 6688715.8 16.6, 355826.3 6688718.4 16.6, 355821.5 6688717.3 16.6, 355821.7 6688716.5 16.6, 355819.1 6688716 16.6, 355818.9 6688716.8 16.6, 355814.6 6688715.9 16.6, 355812.4 6688721.3 16.6, 355814.9 6688722 16.6, 355813 6688728.3 16.6, 355813.3 6688728.3 16.6, 355819.3 6688729.8 16.6))
BATIMENT0000000302930016;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;6.6;14.9;17.2;7.3;Cadastre;;POLYGON Z ((355807.9 6688725.2 14.9, 355809.1 6688720.1 14.9, 355809.4 6688720.2 14.9, 355810.7 6688715.6 14.9, 355805.9 6688714.8 14.9, 355801.4 6688714 14.9, 355798.3 6688720.4 14.9, 355798.5 6688720.5 14.9, 355807.9 6688725.2 14.9))
BATIMENT0000000302929383;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.4;6.9;16.3;20.5;7.4;Cadastre;;POLYGON Z ((355778.6 6688740 16.3, 355779.9 6688736.9 16.3, 355778.2 6688736.1 16.3, 355780 6688731.9 16.3, 355780.5 6688730.8 16.3, 355767.6 6688728.9 16.3, 355766.9 6688729.3 16.3, 355764.9 6688733.8 16.3, 355776.8 6688739.2 16.3, 355778.6 6688740 16.3))
BATIMENT0000000302929742;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1827-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;;;7.7;6.0;13.7;16.4;7.4;Cadastre;C 0.1;POLYGON Z ((355784 6688732.5 13.7, 355781.1 6688741.1 13.7, 355781.2 6688741.2 13.7, 355791.1 6688745.7 13.7, 355796.2 6688734.5 13.7, 355795.9 6688734.4 13.7, 355784 6688732.5 13.7))
BATIMENT0000000302929353;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;9.0;6.9;15.9;20.6;7.4;Cadastre;A 1.0;POLYGON Z ((355761.8 6688740.5 15.9, 355773.7 6688746.1 15.9, 355773.6 6688746.3 15.9, 355775.9 6688747.5 15.9, 355777.9 6688742.3 15.9, 355777.4 6688742.1 15.9, 355777.9 6688741.1 15.9, 355776.3 6688740.3 15.9, 355776.8 6688739.2 15.9, 355764.9 6688733.8 15.9, 355761.8 6688740.5 15.9))
BATIMENT0000000302929741;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.5;6.9;17.5;18.6;7.5;Cadastre;A 1.0;POLYGON Z ((355804.5 6688734.6 17.5, 355796.4 6688733.4 17.5, 355795.9 6688734.4 17.5, 355796.2 6688734.5 17.5, 355791.1 6688745.7 17.5, 355797.7 6688748.6 17.5, 355799 6688745.9 17.5, 355803.7 6688735.7 17.5, 355804 6688735.8 17.5, 355804.5 6688734.6 17.5))
BATIMENT0000000302929734;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;20;12.7;6.7;19.5;23.3;7.4;Cadastre;A 1.0;POLYGON Z ((355804 6688735.8 19.5, 355803.7 6688735.7 19.5, 355799 6688745.9 19.5, 355817.5 6688748.9 19.5, 355814.2 6688758.3 19.5, 355815 6688759.6 19.5, 355818.9 6688761.4 19.5, 355819.5 6688759.5 19.5, 355821 6688755 19.5, 355821.4 6688754 19.5, 355822.9 6688749.5 19.5, 355823.6 6688749.7 19.5, 355824.2 6688745.7 19.5, 355827.4 6688746.1 19.5, 355827.5 6688745.9 19.5, 355830.1 6688746.3 19.5, 355831 6688740.2 19.5, 355804 6688735.8 19.5))
BATIMENT0000000302929350;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;20;20;9.4;6.9;16.3;20.6;7.3;Cadastre;A 1.0;POLYGON Z ((355756.1 6688752.7 16.3, 355768.2 6688758.2 16.3, 355773.6 6688746.3 16.3, 355773.7 6688746.1 16.3, 355761.8 6688740.5 16.3, 355756.1 6688752.7 16.3))
BATIMENT0000000302929522;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;28.1;7.0;35.1;37.5;7.7;Cadastre;;POLYGON Z ((355596 6688687.7 35.1, 355599.1 6688702.1 35.1, 355608.3 6688700.1 35.1, 355605.2 6688685.6 35.1, 355596 6688687.7 35.1))
BATIMENT0000000302929521;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.6;7.5;25.2;31.7;8.3;Cadastre;;POLYGON Z ((355629 6688695.5 25.2, 355629.9 6688699.5 25.2, 355658.3 6688693.1 25.2, 355657.4 6688689.2 25.2, 355629 6688695.5 25.2))
BATIMENT0000000302929525;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;27.9;7.4;35.3;35.6;7.8;Cadastre;;POLYGON Z ((355610.1 6688703.9 35.3, 355609.3 6688699.9 35.3, 355608.3 6688700.1 35.3, 355609.2 6688704.1 35.3, 355610.1 6688703.9 35.3))
BATIMENT0000000302929520;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.2;7.4;28.7;35.2;7.8;Cadastre;;POLYGON Z ((355599.9 6688705.6 28.7, 355600.8 6688706 28.7, 355609.2 6688704.1 28.7, 355608.3 6688700.1 28.7, 355599.1 6688702.1 28.7, 355599.9 6688705.6 28.7))
BATIMENT0000000302929529;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.9;7.2;26.2;34.7;7.7;Cadastre;;POLYGON Z ((355591.4 6688704 26.2, 355592.2 6688707.9 26.2, 355600.8 6688706 26.2, 355599.9 6688705.6 26.2, 355599.1 6688702.1 26.2, 355591.4 6688704 26.2))
BATIMENT0000000327821847;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.2;7.7;;19.5;8.4;Imagerie aérienne;;POLYGON Z ((355615.3 6688717.2 15.9, 355615.7 6688718.7 15.9, 355620.4 6688717.7 15.9, 355626.2 6688744.7 15.9, 355631.5 6688743.7 15.9, 355625.4 6688715.1 15.9, 355615.3 6688717.2 15.9))
BATIMENT0000000327821884;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.1;7.9;;21.0;8.4;Imagerie aérienne;;POLYGON Z ((355613.7 6688719.2 20, 355626 6688776.1 20, 355628.1 6688775.5 20, 355632.7 6688774.5 20, 355627.2 6688749 20, 355626.2 6688744.7 20, 355620.4 6688717.7 20, 355615.7 6688718.7 20, 355613.7 6688719.2 20))
BATIMENT0000000327821839;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.2;7.3;;19.2;8.4;Imagerie aérienne;;POLYGON Z ((355632.2 6688746.9 15.5, 355627.2 6688749 15.5, 355632.7 6688774.5 15.5, 355628.1 6688775.5 15.5, 355628.4 6688777.5 15.5, 355638.4 6688775.1 15.5, 355632.2 6688746.9 15.5))
BATIMENT0000000327821826;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;7.4;;11.2;8.1;Imagerie aérienne;;POLYGON Z ((355655.5 6688781.6 10.7, 355654.2 6688775.3 10.7, 355655 6688775 10.7, 355656.3 6688774.5 10.7, 355656.9 6688773.8 10.7, 355657.2 6688772.3 10.7, 355656.9 6688771.2 10.7, 355656.3 6688770.2 10.7, 355655.7 6688769.7 10.7, 355654.4 6688769.4 10.7, 355652.9 6688769.6 10.7, 355647 6688743 10.7, 355643.2 6688743.9 10.7, 355651.4 6688782.3 10.7, 355655.5 6688781.6 10.7))
BATIMENT0000000327821911;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;16.3;6.8;;27.0;8.3;Imagerie aérienne;;POLYGON Z ((355567.6 6688827.1 23.1, 355568.6 6688830.2 23.1, 355572.2 6688829.4 23.1, 355570.4 6688822 23.1, 355568.6 6688814.6 23.1, 355569.2 6688806.1 23.1, 355569.4 6688804.6 23.1, 355571.6 6688803.5 23.1, 355572.6 6688802.4 23.1, 355573.5 6688800.8 23.1, 355573.5 6688799.1 23.1, 355573 6688797.5 23.1, 355571.7 6688796.6 23.1, 355569.8 6688796.1 23.1, 355567.9 6688796.3 23.1, 355567.6 6688794.6 23.1, 355577.5 6688792.4 23.1, 355576.9 6688789.1 23.1, 355582.2 6688787.9 23.1, 355626.4 6688778 23.1, 355626 6688776.1 23.1, 355613.7 6688719.2 23.1, 355613.4 6688717.9 23.1, 355550 6688731.8 23.1, 355564.2 6688797.7 23.1, 355563.5 6688799.3 23.1, 355563.3 6688800.5 23.1, 355563.4 6688802.2 23.1, 355564.1 6688803.3 23.1, 355565.2 6688803.9 23.1, 355564.5 6688814.5 23.1, 355567 6688827.2 23, 355567.6 6688827.1 23.1))
BATIMENT0000000302929418;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;10.3;7.0;17.3;20.7;7.9;Cadastre;A 1.0;POLYGON Z ((355828.2 6688328.1 17.3, 355833.8 6688329.5 17.3, 355846.7 6688331.4 17.3, 355847 6688328.6 17.3, 355844.3 6688324.6 17.3, 355829 6688323.2 17.3, 355828.2 6688328.1 17.3))
BATIMENT0000000302929419;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;12.8;7.3;20.2;22.0;7.8;Cadastre;A 1.0;POLYGON Z ((355827.2 6688335 20.2, 355846.3 6688336.9 20.2, 355846.7 6688331.4 20.2, 355833.8 6688329.5 20.2, 355832.5 6688333.5 20.2, 355827.5 6688332.8 20.2, 355827.2 6688335 20.2))
BATIMENT0000000302929416;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;13.5;7.1;20.7;24.3;7.8;Cadastre;A 1.0;POLYGON Z ((355813.8 6688338 20.7, 355825 6688339.3 20.7, 355836.3 6688340.9 20.7, 355837.5 6688340.7 20.7, 355840 6688341 20.7, 355840 6688341.8 20.7, 355842.4 6688342.1 20.7, 355842.7 6688342 20.7, 355845 6688342.5 20.7, 355845.9 6688342.1 20.7, 355846.3 6688336.9 20.7, 355827.2 6688335 20.7, 355817.4 6688333.7 20.7, 355814.5 6688333.4 20.7, 355813.8 6688338 20.7))
BATIMENT0000000302929421;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;7.0;11.2;12.0;7.5;Cadastre;;POLYGON Z ((355823.2 6688342.9 11.2, 355822.7 6688344.3 11.2, 355824.1 6688344.5 11.2, 355824.1 6688343.8 11.2, 355824.2 6688343.1 11.2, 355823.2 6688342.9 11.2))
BATIMENT0000000302929425;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;4.0;10;20;10.1;7.0;17.1;21.2;8.0;Cadastre;A 1.0;POLYGON Z ((355824.5 6688341.2 17.1, 355824.2 6688343.1 17.1, 355824.1 6688343.8 17.1, 355826.5 6688344.2 17.1, 355826.6 6688345.9 17.1, 355829.7 6688346.7 17.1, 355829.4 6688347.8 17.1, 355823.7 6688346.9 17.1, 355823 6688349.1 17.1, 355822.7 6688350.6 17.1, 355844.8 6688355.2 17.1, 355845.7 6688343.3 17.1, 355836.3 6688341.9 17.1, 355836.3 6688340.9 17.1, 355825 6688339.3 17.1, 355824.5 6688341.2 17.1))
BATIMENT0000000302929694;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;4.0;20;20;11.3;7.0;18.3;20.9;8.0;Cadastre;A 1.0;POLYGON Z ((355808.9 6688365.7 18.3, 355813.8 6688366.4 18.3, 355843.3 6688370.3 18.3, 355844.4 6688361 18.3, 355844.2 6688360.2 18.3, 355832.1 6688359.2 18.3, 355821.6 6688358.4 18.3, 355809.7 6688357.4 18.3, 355808.9 6688365.7 18.3), (355833.7 6688364.9 18.3, 355833.6 6688366.1 18.3, 355831.2 6688366 18.3, 355831.3 6688364.7 18.3, 355833.7 6688364.9 18.3), (355824.3 6688364.7 18.3, 355824.2 6688366.1 18.3, 355820.4 6688365.7 18.3, 355820.4 6688364.2 18.3, 355824.3 6688364.7 18.3))
BATIMENT0000000302929747;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;120.0;6.0;30;40;15.8;7.0;22.8;25.2;8.2;Cadastre;A 1.0;POLYGON Z ((355861.9 6688387.4 22.8, 355860.7 6688386.8 22.8, 355859.2 6688389.6 22.8, 355854.1 6688399.4 22.8, 355858.9 6688401.7 22.8, 355858.1 6688402.8 22.8, 355857 6688402.4 22.8, 355854.9 6688406.7 22.8, 355853.6 6688409.1 22.8, 355858.1 6688409.7 22.8, 355858.7 6688409.8 22.8, 355859.4 6688409.8 22.8, 355860 6688409.7 22.8, 355860.7 6688409.7 22.8, 355861.3 6688409.5 22.8, 355861.9 6688409.4 22.8, 355862.5 6688409.1 22.8, 355863.4 6688408.8 22.8, 355864.3 6688408.4 22.8, 355865.1 6688407.9 22.8, 355865.9 6688407.4 22.8, 355866.2 6688407.1 22.8, 355871.8 6688396.4 22.8, 355873.4 6688397.3 22.8, 355893.2 6688359 22.8, 355890.2 6688357.4 22.8, 355894.9 6688348.2 22.8, 355898.3 6688348.6 22.8, 355899.9 6688336.6 22.8, 355898.3 6688336.4 22.8, 355898.9 6688331.6 22.8, 355887.3 6688330.4 22.8, 355887.1 6688329.1 22.8, 355868 6688327 22.8, 355862.2 6688326.4 22.8, 355860.9 6688338.3 22.8, 355866.2 6688338.8 22.8, 355866 6688340.8 22.8, 355887.9 6688343.2 22.8, 355887.3 6688347.3 22.8, 355883.7 6688353.9 22.8, 355882.4 6688356.6 22.8, 355878.8 6688354.6 22.8, 355861.9 6688387.4 22.8))
BATIMENT0000000302929693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;20;20;6.1;7.3;13.4;20.6;7.6;Cadastre;A 1.0;POLYGON Z ((355813.1 6688372 13.4, 355830.9 6688374.6 13.4, 355830.8 6688376 13.4, 355828.7 6688375.8 13.4, 355827.9 6688375.7 13.4, 355827.7 6688376.5 13.4, 355828.3 6688377.5 13.4, 355812.7 6688375.3 13.4, 355811.9 6688381.4 13.4, 355813.4 6688381.5 13.4, 355831.4 6688382.5 13.4, 355841.8 6688383.1 13.4, 355843.3 6688370.3 13.4, 355813.8 6688366.4 13.4, 355813.1 6688372 13.4))
BATIMENT0000000302929691;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;;;11.2;7.3;18.5;21.2;7.5;Cadastre;A 1.0;POLYGON Z ((355826.5 6688388.6 18.5, 355841 6688389.7 18.5, 355841.8 6688383.1 18.5, 355831.4 6688382.5 18.5, 355831.1 6688384 18.5, 355823.9 6688383.8 18.5, 355823.9 6688384.8 18.5, 355823.6 6688388.4 18.5, 355826.5 6688388.6 18.5))
BATIMENT0000000302929689;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;14.9;7.1;22.0;24.1;7.4;Cadastre;A 1.0;POLYGON Z ((355826.2 6688391.6 22, 355829.2 6688391.7 22, 355828.9 6688396 22, 355840.2 6688396.8 22, 355841 6688389.7 22, 355826.5 6688388.6 22, 355826.2 6688391.6 22))
BATIMENT0000000302929565;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;8.0;12.3;20.2;8.2;Cadastre;;POLYGON Z ((355974 6688375 12.3, 355980.2 6688377.2 12.3, 355985.9 6688362 12.3, 355990.1 6688350.8 12.3, 355990.4 6688350 12.3, 355984 6688349.7 12.3, 355983 6688353.2 12.3, 355980.8 6688353.3 12.3, 355979.8 6688359.5 12.3, 355974 6688375 12.3))
BATIMENT0000000302929566;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.6;8.0;25.6;26.5;8.2;Cadastre;C 0.4;POLYGON Z ((355968.1 6688336.7 25.6, 355967.4 6688338.2 25.6, 355965.9 6688338.3 25.6, 355957.8 6688343.3 25.6, 355957 6688343.6 25.6, 355955.2 6688343.1 25.6, 355954.1 6688346.2 25.6, 355953 6688345.9 25.6, 355936.3 6688390.3 25.6, 355937.8 6688390.9 25.6, 355946.9 6688394.4 25.6, 355953.4 6688377.1 25.6, 355956.7 6688378.3 25.6, 355959.1 6688372.3 25.6, 355955.6 6688370.9 25.6, 355959.3 6688359.7 25.6, 355962.7 6688351.6 25.6, 355964.6 6688355.2 25.6, 355970.6 6688351.6 25.6, 355969 6688348.2 25.6, 355971.7 6688348.5 25.6, 355977.2 6688349 25.6, 355976.8 6688352.7 25.6, 355980.8 6688353.3 25.6, 355983 6688353.2 25.6, 355984 6688349.7 25.6, 355990.4 6688350 25.6, 355994.5 6688339.1 25.6, 355968.1 6688336.7 25.6))
BATIMENT0000000302929568;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;8.0;9.7;21.2;8.7;Cadastre;;POLYGON Z ((355958.6 6688398.9 9.7, 355950.3 6688395.7 9.7, 355946.8 6688405 9.7, 355951 6688406.5 9.7, 355951.3 6688405.5 9.7, 355951.8 6688405 9.7, 355952.2 6688404.5 9.7, 355952.8 6688404 9.7, 355953.7 6688403.6 9.7, 355954.4 6688403.6 9.7, 355955.5 6688403.7 9.7, 355956.7 6688404 9.7, 355958.6 6688398.9 9.7))
BATIMENT0000000302929567;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.8;8.0;23.8;25.2;8.4;Cadastre;C 0.2;POLYGON Z ((355926.1 6688417.5 23.8, 355927.7 6688418.2 23.8, 355927.4 6688419.2 23.8, 355929.1 6688423.7 23.8, 355930.6 6688424.1 23.8, 355930 6688425.7 23.8, 355957.9 6688436.1 23.8, 355958.4 6688434.9 23.8, 355962.2 6688424.7 23.8, 355962.8 6688423.1 23.8, 355968.5 6688408.3 23.8, 355956.7 6688404 23.8, 355955.5 6688403.7 23.8, 355954.4 6688403.6 23.8, 355953.7 6688403.6 23.8, 355952.8 6688404 23.8, 355952.2 6688404.5 23.8, 355951.8 6688405 23.8, 355951.3 6688405.5 23.8, 355951 6688406.5 23.8, 355946.8 6688405 23.8, 355950.3 6688395.7 23.8, 355946.9 6688394.4 23.8, 355937.8 6688390.9 23.8, 355936.3 6688390.3 23.8, 355927.5 6688413.8 23.8, 355926.1 6688417.5 23.8))
BATIMENT0000000302929569;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;7.6;12.7;21.0;8.2;Cadastre;;POLYGON Z ((355919.9 6688422.3 12.7, 355921.9 6688426.7 12.7, 355929.1 6688423.7 12.7, 355927.4 6688419.2 12.7, 355919.9 6688422.3 12.7))
BATIMENT0000000302929488;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.9;6.6;19.6;19.9;7.0;Cadastre;;POLYGON Z ((355931.6 6688683.2 19.6, 355931.4 6688683.8 19.6, 355932.8 6688684.4 19.6, 355933 6688683.8 19.6, 355931.6 6688683.2 19.6))
BATIMENT0000000302929489;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.5;6.7;18.2;19.0;6.8;Cadastre;;POLYGON Z ((355921.9 6688692.4 18.2, 355922.5 6688691 18.2, 355918.8 6688689.7 18.2, 355918.9 6688690.3 18.2, 355918.8 6688690.8 18.2, 355919.9 6688691.8 18.2, 355921.9 6688692.4 18.2))
BATIMENT0000000302929490;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;34.0;4.0;20;20;14.2;6.2;20.4;22.5;7.1;Cadastre;B 0.8;POLYGON Z ((355938.3 6688686.1 20.4, 355935.6 6688696.4 20.4, 355953.1 6688703.9 20.4, 355955.8 6688693.6 20.4, 355938.3 6688686.1 20.4))
BATIMENT0000000302929485;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;48.0;5.0;00;00;15.1;5.0;20.1;23.6;7.2;Cadastre;A 1.0;POLYGON Z ((355914.9 6688676.1 20.1, 355913.9 6688676.5 20.1, 355903.6 6688710.5 20.1, 355916.8 6688716.3 20.1, 355918.3 6688710.6 20.1, 355919.6 6688706 20.1, 355920.6 6688702.1 20.1, 355922.2 6688696.2 20.1, 355919 6688695.2 20.1, 355919.9 6688691.8 20.1, 355918.8 6688690.8 20.1, 355918.9 6688690.3 20.1, 355918.8 6688689.7 20.1, 355922.5 6688691 20.1, 355923.5 6688691.3 20.1, 355935.6 6688696.4 20.1, 355938.3 6688686.1 20.1, 355933 6688683.8 20.1, 355932.8 6688684.4 20.1, 355931.4 6688683.8 20.1, 355931.6 6688683.2 20.1, 355914.9 6688676.1 20.1))
BATIMENT0000000302929499;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;11.9;7.2;19.2;22.6;7.5;Cadastre;A 1.0;POLYGON Z ((355988.8 6688714.7 19.2, 355980.2 6688704 19.2, 355978.3 6688703.2 19.2, 355975.7 6688712.9 19.2, 355976.3 6688713.1 19.2, 355977.8 6688714.1 19.2, 355980.5 6688717.1 19.2, 355980.5 6688717.7 19.2, 355974.6 6688716.9 19.2, 355973.8 6688719.8 19.2, 355975.3 6688719.9 19.2, 355977.1 6688719.9 19.2, 355990.1 6688720.3 19.2, 355988.8 6688714.7 19.2))
BATIMENT0000000302929685;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;29;11.5;7.0;18.5;22.3;7.3;Cadastre;A 1.0;POLYGON Z ((355826.6 6688402 18.5, 355826.7 6688405.2 18.5, 355821.5 6688405.3 18.5, 355822.4 6688413.6 18.5, 355823.1 6688413.5 18.5, 355832.1 6688413.2 18.5, 355832.4 6688415.7 18.5, 355838.1 6688415.4 18.5, 355839.7 6688401.9 18.5, 355826.6 6688402 18.5))
BATIMENT0000000302930008;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;22.8;5.8;28.6;30.0;7.5;Cadastre;;POLYGON Z ((355831.1 6688670.5 28.6, 355832.2 6688670.7 28.6, 355839.5 6688671.8 28.6, 355848.2 6688673.1 28.6, 355850.6 6688658.3 28.6, 355844.7 6688657.4 28.6, 355841.4 6688656.8 28.6, 355836.8 6688656.3 28.6, 355831.5 6688656.2 28.6, 355824.3 6688655.9 28.6, 355817.5 6688655.4 28.6, 355816.5 6688662.3 28.6, 355815.3 6688670.5 28.6, 355814.9 6688673 28.6, 355831.1 6688670.5 28.6))
BATIMENT0000000302930013;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;5.0;;;14.7;5.8;20.5;24.5;7.5;Cadastre;A 1.0;POLYGON Z ((355848.2 6688673.1 20.5, 355854.3 6688674 20.5, 355854.5 6688674.8 20.5, 355854.8 6688675.6 20.5, 355855.2 6688676.5 20.5, 355855.8 6688677.2 20.5, 355856.4 6688677.8 20.5, 355857.1 6688678.3 20.5, 355857.9 6688678.8 20.5, 355858.6 6688679 20.5, 355859.4 6688679.2 20.5, 355860.1 6688679.3 20.5, 355861 6688679.3 20.5, 355861.9 6688679.1 20.5, 355862.6 6688678.9 20.5, 355863.5 6688678.5 20.5, 355864.2 6688678 20.5, 355864.9 6688677.3 20.5, 355865.3 6688676.8 20.5, 355865.7 6688676.1 20.5, 355866 6688675.5 20.5, 355866.3 6688674.7 20.5, 355866.4 6688673.9 20.5, 355866.2 6688673.8 20.5, 355866.7 6688670.6 20.5, 355873.7 6688671.6 20.5, 355874.5 6688670.3 20.5, 355876.1 6688668.1 20.5, 355879.6 6688662.7 20.5, 355879.6 6688662.6 20.5, 355850.6 6688658.3 20.5, 355848.2 6688673.1 20.5))
BATIMENT0000000302930019;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;6.0;00;00;15.4;6.2;21.6;25.3;6.9;Cadastre;C 0.4;POLYGON Z ((355884.5 6688674.7 21.6, 355884.5 6688674.8 21.6, 355888 6688676.4 21.6, 355887.4 6688677.5 21.6, 355890.5 6688678.8 21.6, 355893.1 6688678.4 21.6, 355893.4 6688679.1 21.6, 355892.4 6688681.2 21.6, 355893.3 6688683.3 21.6, 355898.5 6688685.5 21.6, 355900.2 6688684.4 21.6, 355901.8 6688679.1 21.6, 355897.1 6688670.1 21.6, 355879.6 6688662.6 21.6, 355879.6 6688662.7 21.6, 355876.1 6688668.1 21.6, 355874.5 6688670.3 21.6, 355884.5 6688674.7 21.6))
BATIMENT0000000302930029;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;00;00;6.0;5.8;11.8;14.0;6.9;Cadastre;C 0.3;POLYGON Z ((355889.7 6688711.3 11.8, 355891.8 6688711.9 11.8, 355896.6 6688696.2 11.8, 355881.4 6688690.8 11.8, 355878.1 6688700.8 11.8, 355877.5 6688702.9 11.8, 355876.2 6688707.2 11.8, 355878.3 6688707.9 11.8, 355886.9 6688710.5 11.8, 355889.7 6688711.3 11.8))
BATIMENT0000000302930021;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;6.8;14.3;15.2;7.5;Cadastre;;POLYGON Z ((355834.5 6688696.3 14.3, 355831.5 6688695.9 14.3, 355826.4 6688707.7 14.3, 355832.1 6688710.2 14.3, 355833.1 6688707.8 14.3, 355837.4 6688696.5 14.3, 355834.5 6688696.3 14.3))
BATIMENT0000000302930026;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;6.5;17.2;18.2;6.9;Cadastre;;POLYGON Z ((355832.2 6688717.5 17.2, 355835.2 6688718.3 17.2, 355836 6688715.5 17.2, 355833.2 6688714.6 17.2, 355832.2 6688717.5 17.2))
BATIMENT0000000302930025;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.5;6.3;20.9;21.4;6.8;Cadastre;;POLYGON Z ((355874.4 6688713 20.9, 355871 6688724.2 20.9, 355870.6 6688725.4 20.9, 355872.8 6688725.8 20.9, 355876.5 6688713.6 20.9, 355878.3 6688707.9 20.9, 355876.2 6688707.2 20.9, 355874.4 6688713 20.9))
BATIMENT0000000302930023;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;6.3;17.5;19.7;6.7;Cadastre;;POLYGON Z ((355852.1 6688722.3 17.5, 355852.3 6688721.1 17.5, 355843.2 6688719.5 17.5, 355842.9 6688720.6 17.5, 355842.9 6688720.8 17.5, 355852.1 6688722.3 17.5))
BATIMENT0000000302930022;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;10;20;9.8;5.8;15.6;18.8;7.3;Cadastre;A 1.0;POLYGON Z ((355839.8 6688734.1 15.6, 355840 6688733.2 15.6, 355840.4 6688731.6 15.6, 355842.9 6688720.8 15.6, 355842.9 6688720.6 15.6, 355843.2 6688719.5 15.6, 355843.7 6688717.1 15.6, 355844.4 6688714.5 15.6, 355840.8 6688713.1 15.6, 355840.6 6688719.4 15.6, 355840.1 6688721.3 15.6, 355831.4 6688719.4 15.6, 355832.2 6688717.5 15.6, 355833.2 6688714.6 15.6, 355836 6688715.5 15.6, 355836.6 6688715.7 15.6, 355838.8 6688710.1 15.6, 355833.1 6688707.8 15.6, 355832.1 6688710.2 15.6, 355828.8 6688718.5 15.6, 355826.1 6688731.2 15.6, 355839.8 6688734.1 15.6))
BATIMENT0000000302923714;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.5;7.6;14.2;28.4;8.6;Cadastre;C 0.2;POLYGON Z ((356027.8 6688411.4 14.2, 356014.8 6688405.9 14.2, 356010.3 6688408.2 14.2, 356005.8 6688406.5 14.2, 356005.2 6688408 14.2, 356003 6688407 14.2, 356000.6 6688412.6 14.2, 355991.2 6688408.9 14.2, 355995.1 6688399.3 14.2, 355997.9 6688400.2 14.2, 356001.6 6688391 14.2, 355998.9 6688389.9 14.2, 356003 6688380 14.2, 356012.7 6688383.7 14.2, 356010.6 6688389.2 14.2, 356012.6 6688390.1 14.2, 356012.1 6688391.9 14.2, 356016.5 6688393.4 14.2, 356018.4 6688397.5 14.2, 356031.4 6688402.6 14.2, 356031 6688403.7 14.2, 356035 6688405.3 14.2, 356035.6 6688404.8 14.2, 356036.2 6688404.4 14.2, 356036.5 6688404.2 14.2, 356037.2 6688403.9 14.2, 356037.5 6688403.7 14.2, 356037.9 6688403.6 14.2, 356038.6 6688403.3 14.2, 356038.9 6688403.2 14.2, 356039.6 6688403.1 14.2, 356040 6688403 14.2, 356040.8 6688403 14.2, 356041.1 6688402.9 14.2, 356041.5 6688402.9 14.2, 356041.9 6688403 14.2, 356042.2 6688403 14.2, 356043 6688403.1 14.2, 356043.3 6688403.2 14.2, 356044 6688403.3 14.2, 356044.4 6688403.4 14.2, 356044.7 6688403.6 14.2, 356045.4 6688403.9 14.2, 356045.7 6688404 14.2, 356046.4 6688404.4 14.2, 356046.7 6688404.6 14.2, 356047 6688404.8 14.2, 356047.3 6688405 14.2, 356047.6 6688405.3 14.2, 356047.8 6688405.5 14.2, 356048.4 6688406.1 14.2, 356051.8 6688405.1 14.2, 356068.7 6688364.7 14.2, 356067.6 6688364 14.2, 356068.6 6688361.6 14.2, 356067.3 6688361 14.2, 356067.4 6688360.4 14.2, 356067.6 6688359.8 14.2, 356067.7 6688359.2 14.2, 356067.8 6688358.5 14.2, 356067.9 6688357.3 14.2, 356067.9 6688356.6 14.2, 356067.8 6688356 14.2, 356067.8 6688355.4 14.2, 356067.7 6688354.8 14.2, 356067.5 6688354.1 14.2, 356067.4 6688353.5 14.2, 356067.2 6688352.9 14.2, 356067 6688352.3 14.2, 356066.7 6688351.8 14.2, 356066.4 6688351.2 14.2, 356066.1 6688350.6 14.2, 356065.8 6688350.1 14.2, 356065.4 6688349.6 14.2, 356064.6 6688348.6 14.2, 356064.2 6688348.1 14.2, 356063.7 6688347.7 14.2, 356063.3 6688347.3 14.2, 356062.8 6688346.9 14.2, 356062.3 6688346.5 14.2, 356061.7 6688346.2 14.2, 356061.2 6688345.8 14.2, 356060.6 6688345.6 14.2, 356060 6688345.3 14.2, 356059.6 6688345.2 14.2, 356014.2 6688340.9 14.2, 356013.6 6688341.2 14.2, 356012.8 6688341.7 14.2, 356012.4 6688341.9 14.2, 356012.2 6688342.1 14.2, 356011.7 6688342.4 14.2, 356011.5 6688342.5 14.2, 356011.4 6688342.7 14.2, 356011.2 6688342.8 14.2, 356010.6 6688343.3 14.2, 356010.1 6688343.8 14.2, 356009.8 6688344.2 14.2, 356009.3 6688344.8 14.2, 356009.1 6688345 14.2, 355994.5 6688339.1 14.2, 355990.4 6688350 14.2, 355990.1 6688350.8 14.2, 356004.3 6688356 14.2, 355974.9 6688429.6 14.2, 355962.2 6688424.7 14.2, 355958.4 6688434.9 14.2, 355957.9 6688436.1 14.2, 355957.8 6688436.3 14.2, 355970.4 6688441 14.2, 355970.6 6688440.2 14.2, 355986 6688445.8 14.2, 355990 6688444.9 14.2, 355992.5 6688445.9 14.2, 355993.8 6688449 14.2, 356025.2 6688460.9 14.2, 356025.4 6688461 14.2, 356025.7 6688461.1 14.2, 356026.2 6688461.1 14.2, 356026.7 6688461.1 14.2, 356026.9 6688461 14.2, 356027.2 6688461 14.2, 356027.4 6688460.9 14.2, 356027.7 6688460.8 14.2, 356027.9 6688460.7 14.2, 356028.1 6688460.5 14.2, 356028.5 6688460.2 14.2, 356028.7 6688460 14.2, 356028.8 6688459.8 14.2, 356029 6688459.6 14.2, 356029.1 6688459.4 14.2, 356029.2 6688459.2 14.2, 356029.3 6688458.9 14.2, 356029.4 6688458.7 14.2, 356029.5 6688458.5 14.2, 356029.5 6688458.2 14.2, 356029.5 6688457.7 14.2, 356029.5 6688457.4 14.2, 356029.5 6688457.2 14.2, 356029.4 6688456.9 14.2, 356029.4 6688456.7 14.2, 356029.3 6688456.5 14.2, 356029.2 6688456.2 14.2, 356029 6688456 14.2, 356028.7 6688455.6 14.2, 356028.6 6688455.4 14.2, 356028.4 6688455.3 14.2, 356028.2 6688455.1 14.2, 356028 6688455 14.2, 356027.7 6688454.8 14.2, 356028.1 6688453.8 14.2, 356029.5 6688454.5 14.2, 356030.2 6688452.5 14.2, 356031.5 6688453 14.2, 356044.6 6688422.1 14.2, 356043.2 6688419 14.2, 356042.9 6688419.1 14.2, 356042.5 6688419.1 14.2, 356041.8 6688419.2 14.2, 356041.5 6688419.2 14.2, 356040.8 6688419.2 14.2, 356040.5 6688419.2 14.2, 356039.8 6688419.1 14.2, 356039.4 6688419 14.2, 356038.8 6688418.8 14.2, 356038.4 6688418.7 14.2, 356038.1 6688418.6 14.2, 356037.8 6688418.5 14.2, 356037.5 6688418.3 14.2, 356037.2 6688418.2 14.2, 356036.6 6688417.8 14.2, 356036 6688417.4 14.2, 356035.7 6688417.2 14.2, 356035 6688416.5 14.2, 356034.8 6688416.2 14.2, 356034.5 6688416 14.2, 356034.1 6688415.4 14.2, 356033.8 6688414.8 14.2, 356033.4 6688414.2 14.2, 356033.2 6688413.5 14.2, 356033.1 6688413.2 14.2, 356032.8 6688412.2 14.2, 356028.2 6688410.3 14.2, 356027.8 6688411.4 14.2))
BATIMENT0000000302923739;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;7.8;11.7;15.0;8.5;Cadastre;;POLYGON Z ((356031 6688403.7 11.7, 356031.4 6688402.6 11.7, 356018.4 6688397.5 11.7, 356017.9 6688398.5 11.7, 356031 6688403.7 11.7))
BATIMENT0000000302923740;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;7.8;18.7;21.1;8.1;Cadastre;;POLYGON Z ((356028.2 6688410.3 18.7, 356032.8 6688412.2 18.7, 356032.6 6688411.6 18.7, 356032.6 6688411 18.7, 356032.6 6688410.6 18.7, 356032.6 6688410.4 18.7, 356032.6 6688410 18.7, 356032.6 6688409.6 18.7, 356032.7 6688409.4 18.7, 356032.7 6688409 18.7, 356032.9 6688408.4 18.7, 356033 6688408.2 18.7, 356033.2 6688407.7 18.7, 356033.5 6688407.1 18.7, 356033.7 6688406.8 18.7, 356034 6688406.3 18.7, 356034.3 6688406 18.7, 356034.6 6688405.7 18.7, 356034.9 6688405.4 18.7, 356035 6688405.3 18.7, 356031 6688403.7 18.7, 356028.2 6688410.3 18.7))
BATIMENT0000000302923741;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;7.8;9.7;15.7;8.1;Cadastre;;POLYGON Z ((356027.8 6688411.4 9.7, 356028.2 6688410.3 9.7, 356015.3 6688404.8 9.7, 356014.8 6688405.9 9.7, 356027.8 6688411.4 9.7))
BATIMENT0000002275362683;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.7;4.1;;;;Imagerie aérienne;;POLYGON Z ((356036.6 6688508.3 12.8, 356009.5 6688497.5 12.2, 356005.4 6688508.2 12.3, 356032.4 6688518.9 12.2, 356036.6 6688508.3 12.8))
BATIMENT0000000302923821;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;74.0;7.0;10;10;16.5;7.1;23.7;26.7;7.8;Cadastre;C 0.6;POLYGON Z ((356007.9 6688715.8 23.7, 356001.9 6688720.9 23.7, 356005.3 6688735.5 23.7, 356005.5 6688736.3 23.7, 356011.6 6688734.7 23.7, 356016.5 6688736.7 23.7, 356017.4 6688734.4 23.7, 356027.1 6688738.2 23.7, 356037.6 6688742.4 23.7, 356036.8 6688744.2 23.7, 356039.8 6688745.4 23.7, 356040.5 6688743.8 23.7, 356048.1 6688746.8 23.7, 356053.4 6688734.2 23.7, 356007.9 6688715.8 23.7))
BATIMENT0000000302923699;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;31.0;6.0;00;00;15.9;5.5;21.4;24.4;7.6;Cadastre;A 1.0;POLYGON Z ((356003 6688778.8 21.4, 355996.7 6688750.5 21.4, 355996 6688750.6 21.4, 355994.7 6688744.8 21.4, 355995.4 6688744.6 21.4, 355990.1 6688720.3 21.4, 355977.1 6688719.9 21.4, 355978.8 6688728 21.4, 355977.2 6688728.4 21.4, 355983.5 6688757.1 21.4, 355986.5 6688756.5 21.4, 355989.5 6688770.3 21.4, 355987.7 6688772 21.4, 355984.8 6688773.2 21.4, 355983.6 6688781.4 21.4, 355987.1 6688781.9 21.4, 355988.2 6688781.7 21.4, 355987.7 6688784.7 21.4, 355995.3 6688785.9 21.4, 356003 6688778.8 21.4))
BATIMENT0000000302923809;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;4.0;00;00;9.8;7.1;17.0;22.2;7.5;Cadastre;C 0.2;POLYGON Z ((356015.3 6688778.2 17, 356016.1 6688782.1 17, 356017.9 6688790.2 17, 356020.8 6688794.2 17, 356029.3 6688798.3 17, 356034.2 6688784.2 17, 356034.8 6688782.5 17, 356035.1 6688782 17, 356033.1 6688781.3 17, 356025.5 6688748.6 17, 356021.2 6688746.3 17, 356008.6 6688749.4 17, 356008.6 6688749.8 17, 356009.4 6688753.2 17, 356015.3 6688778.2 17))
BATIMENT0000000302929508;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;6.0;00;00;14.6;6.7;21.4;24.0;7.2;Cadastre;C 1.0;POLYGON Z ((355987.7 6688784.7 21.4, 355988.2 6688781.7 21.4, 355987.1 6688781.9 21.4, 355983.6 6688781.4 21.4, 355983.2 6688783.9 21.4, 355987.7 6688784.7 21.4))
BATIMENT0000000302923805;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;71.0;5.0;00;00;13.8;7.0;20.8;24.0;7.4;Cadastre;C 0.4;POLYGON Z ((356056.4 6688792.8 20.8, 356066.3 6688781.8 20.8, 356055.8 6688772.3 20.8, 356053.3 6688775.1 20.8, 356052.3 6688774.1 20.8, 356047.1 6688779.9 20.8, 356048.1 6688780.8 20.8, 356041.7 6688787.9 20.8, 356034.2 6688784.2 20.8, 356029.3 6688798.3 20.8, 356037.5 6688802.2 20.8, 356041.5 6688797.8 20.8, 356043.5 6688799.6 20.8, 356042.1 6688801.1 20.8, 356045.2 6688803.7 20.8, 356045.3 6688803.7 20.8, 356045.3 6688803.8 20.8, 356045.5 6688803.8 20.8, 356045.6 6688803.8 20.8, 356045.7 6688803.8 20.8, 356045.9 6688803.8 20.8, 356046 6688803.8 20.8, 356046.1 6688803.8 20.8, 356046.3 6688803.8 20.8, 356046.3 6688803.7 20.8, 356046.4 6688803.7 20.8, 356046.5 6688803.7 20.8, 356047.3 6688802.9 20.8, 356056.4 6688792.8 20.8))
BATIMENT0000000302930041;Industriel, agricole ou commercial;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;3.2;6.6;9.8;10.5;7.3;Cadastre;B 0.2;POLYGON Z ((355928 6688721.6 9.8, 355933.5 6688724 9.8, 355938.2 6688706.3 9.8, 355934.3 6688705.3 9.8, 355934.3 6688705.2 9.8, 355932.4 6688704.8 9.8, 355928 6688721.6 9.8))
BATIMENT0000000302929493;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;00;00;3.7;6.9;10.6;26.7;7.6;Cadastre;A 1.0;POLYGON Z ((355955.8 6688693.6 10.6, 355953.1 6688703.9 10.6, 355950.2 6688714.9 10.6, 355946.3 6688729.2 10.6, 355960.4 6688735.3 10.6, 355963.2 6688736.6 10.6, 355967.7 6688719.6 10.6, 355973.8 6688719.8 10.6, 355974.6 6688716.9 10.6, 355975.7 6688712.9 10.6, 355978.3 6688703.2 10.6, 355955.8 6688693.6 10.6))
BATIMENT0000000302929494;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;5.9;10.5;11.3;7.1;Cadastre;;POLYGON Z ((355950.2 6688714.9 10.5, 355946.5 6688713.9 10.5, 355942.9 6688727.7 10.5, 355946.3 6688729.2 10.5, 355950.2 6688714.9 10.5))
BATIMENT0000000302929500;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;7.4;21.6;23.7;7.5;Cadastre;;POLYGON Z ((355978.8 6688728 21.6, 355977.1 6688719.9 21.6, 355975.3 6688719.9 21.6, 355977.2 6688728.4 21.6, 355978.8 6688728 21.6))
BATIMENT0000000302929487;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;6.8;9.4;10.0;7.2;Cadastre;;POLYGON Z ((355912.4 6688737.6 9.4, 355916.9 6688738.3 9.4, 355917.4 6688735.9 9.4, 355912.9 6688734.6 9.4, 355912.4 6688737.6 9.4))
BATIMENT0000000302929491;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;15;10;9.7;6.5;16.2;18.2;7.0;Cadastre;A 0.7;POLYGON Z ((355915.2 6688738.9 16.2, 355913.8 6688747.1 16.2, 355921.9 6688748.3 16.2, 355924 6688740.6 16.2, 355915.2 6688738.9 16.2))
BATIMENT0000000302929496;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;6.6;22.2;23.4;6.7;Cadastre;;POLYGON Z ((355941 6688747.7 22.2, 355941.6 6688745.2 22.2, 355939.6 6688744.8 22.2, 355939 6688747.2 22.2, 355941 6688747.7 22.2))
BATIMENT0000000302929492;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;5.0;00;00;11.8;6.2;18.0;22.7;7.2;Cadastre;A 1.0;POLYGON Z ((355952.8 6688757.8 18, 355953.8 6688751.3 18, 355955.6 6688751.5 18, 355957.3 6688740.5 18, 355947.3 6688739 18, 355947.6 6688737.1 18, 355934.1 6688735 18, 355933.3 6688740.1 18, 355924.5 6688738.7 18, 355924.4 6688738.7 18, 355924 6688740.6 18, 355921.9 6688748.3 18, 355938.1 6688750.8 18, 355939 6688747.2 18, 355939.6 6688744.8 18, 355941.6 6688745.2 18, 355941 6688747.7 18, 355939.2 6688755.1 18, 355944.2 6688756 18, 355949.9 6688756.9 18, 355949.9 6688757.4 18, 355952.8 6688757.8 18))
BATIMENT0000000302929505;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.3;6.0;10.3;10.9;7.0;Cadastre;A 1.0;POLYGON Z ((355917.5 6688754.4 10.3, 355916.3 6688760.9 10.3, 355919.6 6688761.4 10.3, 355920.9 6688754.9 10.3, 355917.5 6688754.4 10.3))
BATIMENT0000000302929504;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;54;10;5.1;6.0;11.1;15.1;7.1;Cadastre;A 1.0;POLYGON Z ((355920.9 6688754.9 11.1, 355919.6 6688761.4 11.1, 355920.3 6688761.6 11.1, 355920.2 6688762.3 11.1, 355923.1 6688762.7 11.1, 355931.1 6688763.9 11.1, 355931.7 6688760.2 11.1, 355930.7 6688756.9 11.1, 355930.7 6688756.4 11.1, 355920.9 6688754.9 11.1))
BATIMENT0000000302930028;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;15.0;6.4;21.5;23.9;6.8;Cadastre;C 0.7;POLYGON Z ((355869.5 6688729 21.5, 355873.2 6688730.2 21.5, 355872.4 6688732.5 21.5, 355876.8 6688733.9 21.5, 355878.6 6688734.4 21.5, 355878.8 6688733.5 21.5, 355884.6 6688735.3 21.5, 355886.2 6688730.2 21.5, 355891 6688714.5 21.5, 355888.9 6688713.8 21.5, 355889.7 6688711.3 21.5, 355886.9 6688710.5 21.5, 355878.3 6688707.9 21.5, 355876.5 6688713.6 21.5, 355872.8 6688725.8 21.5, 355870.6 6688725.4 21.5, 355870.3 6688726.4 21.5, 355870.1 6688727.2 21.5, 355869.5 6688729 21.5))
BATIMENT0000000302929484;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;5.0;00;00;15.4;6.5;22.0;24.6;7.3;Cadastre;A 1.0;POLYGON Z ((355897.5 6688730.1 22, 355907.1 6688732.9 22, 355912.9 6688734.6 22, 355917.9 6688716.8 22, 355916.8 6688716.3 22, 355903.6 6688710.5 22, 355897.5 6688730.1 22))
BATIMENT0000000302930027;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;5.8;19.9;20.4;6.6;Cadastre;;POLYGON Z ((355863.2 6688724.2 19.9, 355864.1 6688724.3 19.9, 355870.6 6688725.4 19.9, 355871 6688724.2 19.9, 355863.4 6688722.9 19.9, 355863.2 6688724 19.9, 355863.2 6688724.2 19.9))
BATIMENT0000000302930024;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;10;14.1;6.3;20.4;20.9;6.8;Cadastre;C 0.6;POLYGON Z ((355851.4 6688733.4 20.4, 355858 6688734.5 20.4, 355857.7 6688736.2 20.4, 355863.1 6688737.1 20.4, 355866.8 6688737.7 20.4, 355868.5 6688732 20.4, 355869.5 6688729 20.4, 355870.1 6688727.2 20.4, 355870.3 6688726.4 20.4, 355870.6 6688725.4 20.4, 355864.1 6688724.3 20.4, 355863.2 6688724.2 20.4, 355863.2 6688724 20.4, 355863.4 6688722.9 20.4, 355857.2 6688721.9 20.4, 355856.2 6688721.7 20.4, 355852.3 6688721.1 20.4, 355852.1 6688722.3 20.4, 355842.9 6688720.8 20.4, 355840.4 6688731.6 20.4, 355851.4 6688733.4 20.4))
BATIMENT0000000302929486;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;15;20;9.1;6.3;15.5;23.5;7.0;Cadastre;A 1.0;POLYGON Z ((355893.4 6688743.9 15.5, 355910.9 6688746.6 15.5, 355912.3 6688738.2 15.5, 355906.8 6688737.3 15.5, 355906.6 6688738 15.5, 355905.6 6688737.9 15.5, 355907.1 6688732.9 15.5, 355897.5 6688730.1 15.5, 355893.4 6688743.9 15.5))
BATIMENT0000000302929737;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;20;20;15.4;6.5;22.0;23.9;7.2;Cadastre;C 1.0;POLYGON Z ((355831 6688740.2 22, 355830.1 6688746.3 22, 355827.5 6688745.9 22, 355827.4 6688746.1 22, 355827.3 6688747 22, 355826.4 6688746.9 22, 355826 6688748.6 22, 355825.8 6688750 22, 355825.2 6688752.6 22, 355836.5 6688754.5 22, 355842.2 6688742 22, 355831 6688740.2 22))
BATIMENT0000000302929736;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;01;02;7.7;7.0;14.7;15.7;7.2;Cadastre;C 1.0;POLYGON Z ((355826 6688748.6 14.7, 355825 6688748.5 14.7, 355824.7 6688749.8 14.7, 355824.9 6688749.9 14.7, 355825.8 6688750 14.7, 355826 6688748.6 14.7))
BATIMENT0000000302929738;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.3;6.4;11.7;18.2;7.1;Cadastre;A 1.0;POLYGON Z ((355866.7 6688746 11.7, 355861.8 6688745.2 11.7, 355857.6 6688755.8 11.7, 355857.5 6688756.1 11.7, 355864.5 6688757 11.7, 355866.7 6688746 11.7))
BATIMENT0000000302929733;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;7.0;10.2;14.8;7.2;Cadastre;;POLYGON Z ((355823.6 6688749.7 10.2, 355822.9 6688749.5 10.2, 355821.4 6688754 10.2, 355823.9 6688754.4 10.2, 355824.9 6688749.9 10.2, 355824.7 6688749.8 10.2, 355823.6 6688749.7 10.2))
BATIMENT0000000302929740;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;9.8;5.3;15.1;18.5;6.7;Cadastre;A 1.0;POLYGON Z ((355880.5 6688748.8 15.1, 355880.1 6688748.1 15.1, 355871 6688746.6 15.1, 355868.7 6688757.9 15.1, 355877.2 6688759.3 15.1, 355880.5 6688748.8 15.1))
BATIMENT0000000302929730;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;12;20;11.6;6.0;17.6;22.6;7.6;Cadastre;C 0.9;POLYGON Z ((355842.2 6688742 17.6, 355836.5 6688754.5 17.6, 355835.2 6688757.2 17.6, 355832.4 6688763.3 17.6, 355832.2 6688763.7 17.6, 355839.6 6688764.8 17.6, 355844.9 6688753.7 17.6, 355857.6 6688755.8 17.6, 355861.8 6688745.2 17.6, 355842.2 6688742 17.6))
BATIMENT0000000302929512;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;3.0;00;00;9.5;6.0;15.5;19.4;6.8;Cadastre;A 1.0;POLYGON Z ((355901.3 6688757.9 15.5, 355902.3 6688752.2 15.5, 355891.4 6688750.5 15.5, 355890.8 6688755.2 15.5, 355890 6688755 15.5, 355888.3 6688760.3 15.5, 355906.4 6688764.1 15.5, 355907.5 6688758.7 15.5, 355901.3 6688757.9 15.5))
BATIMENT0000000302929732;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;7.0;8.2;11.7;7.3;Cadastre;;POLYGON Z ((355823.2 6688760.6 8.2, 355823.4 6688759.9 8.2, 355826.5 6688760.7 8.2, 355827.4 6688759.3 8.2, 355828.1 6688756.1 8.2, 355821 6688755 8.2, 355819.5 6688759.5 8.2, 355823.2 6688760.6 8.2))
BATIMENT0000000302929728;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;5.1;11.4;15.5;7.5;Cadastre;;POLYGON Z ((355832.4 6688763.3 11.4, 355835.2 6688757.2 11.4, 355828.9 6688756.3 11.4, 355828 6688760.5 11.4, 355827.1 6688761.8 11.4, 355832.4 6688763.3 11.4))
BATIMENT0000000302929731;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;20;20;6.9;6.5;13.5;15.7;7.3;Cadastre;C 0.2;POLYGON Z ((355851.1 6688766.5 13.5, 355854.4 6688763.4 13.5, 355856.3 6688758.4 13.5, 355852 6688757.6 13.5, 355850.6 6688760.8 13.5, 355848.8 6688763.1 13.5, 355848.1 6688762.8 13.5, 355847.6 6688763.9 13.5, 355848 6688764 13.5, 355846.6 6688766 13.5, 355851.4 6688766.8 13.5, 355851.1 6688766.5 13.5))
BATIMENT0000000302929739;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;12;20;10.0;5.1;15.1;18.5;7.1;Cadastre;A 1.0;POLYGON Z ((355856.4 6688765.6 15.1, 355861.9 6688766.6 15.1, 355864.2 6688760.6 15.1, 355867.2 6688761.7 15.1, 355865.5 6688767.2 15.1, 355874.2 6688768.7 15.1, 355877.2 6688759.3 15.1, 355868.7 6688757.9 15.1, 355867.7 6688757.7 15.1, 355865.4 6688757.2 15.1, 355864.5 6688757 15.1, 355857.5 6688756.1 15.1, 355856.6 6688758.3 15.1, 355856.4 6688758.2 15.1, 355856.3 6688758.4 15.1, 355854.4 6688763.4 15.1, 355856.4 6688765.6 15.1))
BATIMENT0000000302929729;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;6.9;10.2;12.2;7.5;Cadastre;;POLYGON Z ((355846.6 6688766 10.2, 355848 6688764 10.2, 355847.6 6688763.9 10.2, 355842.3 6688763 10.2, 355842 6688765.2 10.2, 355846.6 6688766 10.2))
BATIMENT0000000302929511;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.1;6.0;16.1;19.1;6.8;Cadastre;;POLYGON Z ((355887.3 6688763.4 16.1, 355888.3 6688763.7 16.1, 355887.7 6688767.5 16.1, 355899.4 6688769.6 16.1, 355899.9 6688766.8 16.1, 355905.7 6688767.8 16.1, 355906.4 6688764.1 16.1, 355888.3 6688760.3 16.1, 355887.3 6688763.4 16.1))
BATIMENT0000000302929726;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;06;09;4.5;7.0;11.5;15.2;7.6;Cadastre;C 0.3;POLYGON Z ((355845.7 6688770.1 11.5, 355845.7 6688770 11.5, 355846.6 6688766 11.5, 355842 6688765.2 11.5, 355839.6 6688764.8 11.5, 355832.2 6688763.7 11.5, 355830.4 6688767.6 11.5, 355845.7 6688770.1 11.5))
BATIMENT0000000302929727;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;45;90;6.3;5.1;11.4;13.4;7.5;Cadastre;C 0.5;POLYGON Z ((355823.4 6688765.9 11.4, 355830.2 6688768 11.4, 355830.4 6688767.6 11.4, 355832.2 6688763.7 11.4, 355832.4 6688763.3 11.4, 355827.1 6688761.8 11.4, 355823.2 6688760.6 11.4, 355819.5 6688759.5 11.4, 355818.9 6688761.4 11.4, 355814.8 6688774.4 11.4, 355820.3 6688775.8 11.4, 355823.4 6688765.9 11.4))
BATIMENT0000000302929509;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;50;10;3.5;6.4;9.9;15.2;7.1;Cadastre;A 1.0;POLYGON Z ((355905.1 6688770.7 9.9, 355916.1 6688772.6 9.9, 355916.2 6688772.6 9.9, 355916.9 6688768.6 9.9, 355917.2 6688767.2 9.9, 355919.3 6688767.5 9.9, 355920.2 6688762.3 9.9, 355920.3 6688761.6 9.9, 355919.6 6688761.4 9.9, 355916.3 6688760.9 9.9, 355915.3 6688766.6 9.9, 355911.6 6688766 9.9, 355914.1 6688753.9 9.9, 355908.6 6688753.1 9.9, 355908.5 6688753.2 9.9, 355907.5 6688758.7 9.9, 355906.4 6688764.1 9.9, 355905.7 6688767.8 9.9, 355905.1 6688770.7 9.9))
BATIMENT0000000302929503;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;6.7;9.5;12.1;7.1;Cadastre;;POLYGON Z ((355919.3 6688767.5 9.5, 355921.4 6688767.8 9.5, 355922.2 6688767.9 9.5, 355923.1 6688762.7 9.5, 355920.2 6688762.3 9.5, 355919.3 6688767.5 9.5))
BATIMENT0000000302929495;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.4;6.2;10.6;10.7;7.2;Cadastre;C 0.5;POLYGON Z ((355935.7 6688776 10.6, 355936.4 6688771.6 10.6, 355935.4 6688770 10.6, 355937.7 6688755 10.6, 355932.6 6688754.2 10.6, 355930.7 6688756.4 10.6, 355930.7 6688756.9 10.6, 355931.7 6688760.2 10.6, 355931.1 6688763.9 10.6, 355930.3 6688769 10.6, 355929.3 6688774.9 10.6, 355935.7 6688776 10.6))
BATIMENT0000000302929498;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;6.8;10.1;15.5;7.1;Cadastre;;POLYGON Z ((355941.7 6688771.1 10.1, 355940.4 6688772.4 10.1, 355939.7 6688776.6 10.1, 355946.4 6688777.8 10.1, 355949.9 6688757.4 10.1, 355949.9 6688756.9 10.1, 355944.2 6688756 10.1, 355941.7 6688771.1 10.1))
BATIMENT0000000302929497;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;12;20;10.9;5.7;16.6;20.8;7.2;Cadastre;A 1.0;POLYGON Z ((355966.3 6688781.1 16.6, 355969.4 6688760.4 16.6, 355963.4 6688759.4 16.6, 355955.6 6688758.2 16.6, 355952.8 6688757.8 16.6, 355949.9 6688757.4 16.6, 355946.4 6688777.8 16.6, 355966.3 6688781.1 16.6), (355950.1 6688764.2 16.6, 355967.1 6688767.1 16.6, 355966.1 6688773.8 16.6, 355948.9 6688770.8 16.6, 355950.1 6688764.2 16.6))
BATIMENT0000000302929507;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;39;24;7.8;6.6;14.5;15.5;7.7;Cadastre;A 1.0;POLYGON Z ((355972.6 6688782.2 14.5, 355974.7 6688766.1 14.5, 355982.2 6688767.2 14.5, 355983.2 6688762.5 14.5, 355969.4 6688760.4 14.5, 355966.3 6688781.1 14.5, 355972.6 6688782.2 14.5))
BATIMENT0000000302929501;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1777-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;29;6.9;6.8;13.7;16.4;7.1;Cadastre;A 1.0;POLYGON Z ((355926.1 6688776.2 13.7, 355926.4 6688774.4 13.7, 355929.3 6688774.9 13.7, 355930.3 6688769 13.7, 355922.2 6688767.9 13.7, 355921.4 6688767.8 13.7, 355920.7 6688771.7 13.7, 355920.1 6688775.3 13.7, 355926.1 6688776.2 13.7))
BATIMENT0000000302929502;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;6.7;9.6;13.2;7.1;Cadastre;;POLYGON Z ((355918.4 6688775 9.6, 355920.1 6688775.3 9.6, 355920.7 6688771.7 9.6, 355918.5 6688771.3 9.6, 355917.7 6688774.9 9.6, 355918.4 6688775 9.6))
BATIMENT0000000302929506;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;9.8;5.8;15.6;18.2;7.6;Cadastre;A 1.0;POLYGON Z ((355983.2 6688783.9 15.6, 355983.6 6688781.4 15.6, 355984.8 6688773.2 15.6, 355981.1 6688772.8 15.6, 355978.6 6688772.4 15.6, 355977.4 6688781.4 15.6, 355976.6 6688781.2 15.6, 355976.3 6688782.8 15.6, 355977.2 6688783 15.6, 355983.2 6688783.9 15.6))
BATIMENT0000000302929455;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;10;7.5;6.0;13.5;15.3;7.3;Cadastre;A 1.0;POLYGON Z ((355927.5 6688794.4 13.5, 355929.3 6688787 13.5, 355929.9 6688785 13.5, 355921.2 6688783.5 13.5, 355920.8 6688785.5 13.5, 355921 6688785.5 13.5, 355919.4 6688793.2 13.5, 355927.5 6688794.4 13.5))
BATIMENT0000000302929725;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;8.2;6.1;14.3;18.0;6.6;Cadastre;A 1.0;POLYGON Z ((355857 6688778.2 14.3, 355859.8 6688778.7 14.3, 355860.8 6688778.8 14.3, 355870.4 6688780.3 14.3, 355870.3 6688780.6 14.3, 355870.5 6688780.6 14.3, 355873.2 6688772.2 14.3, 355873.2 6688771.9 14.3, 355860.7 6688769.7 14.3, 355860.6 6688770.2 14.3, 355860.5 6688771 14.3, 355859.3 6688770.8 14.3, 355859.4 6688770 14.3, 355859.5 6688769.5 14.3, 355856.8 6688769 14.3, 355856.7 6688769 14.3, 355856.4 6688769 14.3, 355856.3 6688769 14.3, 355856.2 6688769.1 14.3, 355856.1 6688769.1 14.3, 355855.9 6688769.2 14.3, 355855.8 6688769.2 14.3, 355855.7 6688769.3 14.3, 355855.7 6688769.4 14.3, 355855.6 6688769.4 14.3, 355855.6 6688769.5 14.3, 355855.5 6688769.5 14.3, 355855.5 6688769.6 14.3, 355855.4 6688769.7 14.3, 355855.3 6688769.9 14.3, 355855.3 6688770.1 14.3, 355854.1 6688777.8 14.3, 355857 6688778.2 14.3))
BATIMENT0000000302929746;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;7.2;13.2;16.0;7.5;Cadastre;;POLYGON Z ((355836.1 6688779.3 13.2, 355836.9 6688775.1 13.2, 355833.9 6688774.6 13.2, 355833.2 6688778.7 13.2, 355836.1 6688779.3 13.2))
BATIMENT0000000302929722;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;5.1;10.0;12.0;6.4;Cadastre;;POLYGON Z ((355852.7 6688781.3 10, 355856.4 6688781.9 10, 355856.6 6688780.5 10, 355857 6688778.2 10, 355854.1 6688777.8 10, 355853.4 6688777.7 10, 355852.7 6688781.3 10))
BATIMENT0000000302929442;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.3;6.0;11.3;13.5;7.1;Cadastre;;POLYGON Z ((355910.4 6688783.7 11.3, 355910.8 6688783.8 11.3, 355912 6688779.7 11.3, 355901.8 6688778 11.3, 355901.7 6688778.6 11.3, 355901 6688781.5 11.3, 355905 6688782.7 11.3, 355905 6688782.8 11.3, 355910.4 6688783.7 11.3))
BATIMENT0000000302929723;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;5.1;11.2;12.0;6.3;Cadastre;;POLYGON Z ((355858.2 6688782.2 11.2, 355858.4 6688780.7 11.2, 355856.6 6688780.5 11.2, 355856.4 6688781.9 11.2, 355858.2 6688782.2 11.2))
BATIMENT0000000302929745;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;5.1;5.8;10.9;14.0;7.5;Cadastre;C 0.3;POLYGON Z ((355829.8 6688787.8 10.9, 355830.3 6688785.2 10.9, 355838.1 6688786.7 10.9, 355838.5 6688783.5 10.9, 355839.1 6688779.8 10.9, 355836.1 6688779.3 10.9, 355833.2 6688778.7 10.9, 355830.9 6688778.3 10.9, 355831.3 6688776 10.9, 355826.9 6688775.1 10.9, 355825.8 6688777.5 10.9, 355825.6 6688777.5 10.9, 355821.8 6688785.9 10.9, 355821.9 6688786.3 10.9, 355829.8 6688787.8 10.9))
BATIMENT0000000302929446;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;3.5;6.3;9.9;15.6;7.1;Cadastre;C 0.7;POLYGON Z ((355879.7 6688786.8 9.9, 355885.4 6688787.9 9.9, 355886.5 6688784.4 9.9, 355896.8 6688787.5 9.9, 355898.3 6688781.7 9.9, 355889.7 6688780.2 9.9, 355890.2 6688778.4 9.9, 355882.8 6688777.1 9.9, 355879.7 6688786.8 9.9))
BATIMENT0000000302929744;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;7.2;5.8;13.0;16.0;7.6;Cadastre;A 0.6;POLYGON Z ((355844 6688777.7 13, 355839.5 6688776.7 13, 355839.1 6688779.8 13, 355838.5 6688783.5 13, 355838.1 6688786.7 13, 355837.7 6688789.2 13, 355842.7 6688790.2 13, 355844.1 6688782 13, 355844.9 6688777.9 13, 355844.3 6688777.8 13, 355844 6688777.7 13))
BATIMENT0000000302929743;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;5.1;10.2;11.2;7.2;Cadastre;;POLYGON Z ((355846.1 6688790.8 10.2, 355847.6 6688782.5 10.2, 355844.1 6688782 10.2, 355842.7 6688790.2 10.2, 355846.1 6688790.8 10.2))
BATIMENT0000000302929724;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;8.2;5.1;13.3;17.1;6.6;Cadastre;A 1.0;POLYGON Z ((355860.1 6688782.5 13.3, 355859.7 6688784.1 13.3, 355858 6688783.8 13.3, 355856.2 6688792.5 13.3, 355865.9 6688794.5 13.3, 355870.3 6688780.6 13.3, 355870.4 6688780.3 13.3, 355860.8 6688778.8 13.3, 355860.3 6688781 13.3, 355858.4 6688780.7 13.3, 355858.2 6688782.2 13.3, 355860.1 6688782.5 13.3))
BATIMENT0000000302929443;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;12;90;6.7;6.0;12.7;15.2;7.4;Cadastre;C 0.9;POLYGON Z ((355907.1 6688795.1 12.7, 355907.2 6688794.5 12.7, 355910.4 6688783.7 12.7, 355905 6688782.8 12.7, 355901.2 6688795.2 12.7, 355890.7 6688791.9 12.7, 355890.6 6688792.7 12.7, 355883.8 6688791.5 12.7, 355884.1 6688789.5 12.7, 355879.1 6688788.5 12.7, 355876.8 6688795.9 12.7, 355885.8 6688797.4 12.7, 355890.5 6688798.2 12.7, 355905.4 6688800.7 12.7, 355907.1 6688795.1 12.7))
BATIMENT0000000302929329;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;36;20;8.9;7.3;16.2;;;Cadastre;A 1.0;POLYGON Z ((355828.7 6688792.5 16.2, 355825.1 6688791.8 16.2, 355825.4 6688790.3 16.2, 355820.3 6688789.8 16.2, 355819.7 6688791.6 16.2, 355819.6 6688791.9 16.2, 355821.2 6688792.2 16.2, 355819.9 6688798.6 16.2, 355827.4 6688800.1 16.2, 355828.7 6688792.5 16.2))
BATIMENT0000000302929448;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.8;11.2;13.2;7.6;Cadastre;;POLYGON Z ((355908.5 6688801.2 11.2, 355910.1 6688796.1 11.2, 355907.1 6688795.1 11.2, 355905.4 6688800.7 11.2, 355908.1 6688801.1 11.2, 355908.5 6688801.2 11.2))
BATIMENT0000000302929334;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;;;9.1;6.4;15.5;19.1;7.0;Cadastre;A 1.0;POLYGON Z ((355865.1 6688797.1 15.5, 355829 6688790.7 15.5, 355828.7 6688792.5 15.5, 355827.4 6688800.1 15.5, 355843.1 6688803.3 15.5, 355861.9 6688807 15.5, 355865.1 6688797.1 15.5))
BATIMENT0000000302929445;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;6.5;15.7;16.4;6.9;Cadastre;;POLYGON Z ((355890.5 6688798.2 15.7, 355885.8 6688797.4 15.7, 355883.7 6688803.8 15.7, 355889.4 6688804.8 15.7, 355890.5 6688798.2 15.7))
BATIMENT0000000302929447;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;8.6;6.0;14.6;20.5;7.6;Cadastre;A 1.0;POLYGON Z ((355872.9 6688808.2 14.6, 355891.1 6688811.4 14.6, 355891.5 6688811.4 14.6, 355891.7 6688811.5 14.6, 355892.9 6688811.7 14.6, 355896.3 6688812.2 14.6, 355906 6688813.7 14.6, 355908.1 6688801.1 14.6, 355905.4 6688800.7 14.6, 355890.5 6688798.2 14.6, 355889.4 6688804.8 14.6, 355883.7 6688803.8 14.6, 355885.8 6688797.4 14.6, 355876.8 6688795.9 14.6, 355872.9 6688808.2 14.6))
BATIMENT0000000302929332;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;3.0;16;20;9.4;6.0;15.4;17.7;7.1;Cadastre;A 1.0;POLYGON Z ((355850 6688809.5 15.4, 355849.3 6688813.3 15.4, 355849.3 6688813.6 15.4, 355859.2 6688815.5 15.4, 355861.9 6688807 15.4, 355843.1 6688803.3 15.4, 355842.2 6688808 15.4, 355850 6688809.5 15.4))
BATIMENT0000000302929453;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;12;9.3;6.0;15.3;18.9;7.0;Cadastre;A 1.0;POLYGON Z ((355871.5 6688812.5 15.3, 355883.7 6688814.4 15.3, 355891 6688815.5 15.3, 355891.7 6688811.5 15.3, 355891.5 6688811.4 15.3, 355891.1 6688811.4 15.3, 355872.9 6688808.2 15.3, 355871.5 6688812.5 15.3))
BATIMENT0000000302929458;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;8.3;6.0;14.3;17.7;6.9;Cadastre;A 1.0;POLYGON Z ((355868.9 6688820.9 14.3, 355886.5 6688823.8 14.3, 355886.8 6688821.9 14.3, 355882.6 6688821.3 14.3, 355883.2 6688818.2 14.3, 355870.3 6688816.4 14.3, 355868.9 6688820.9 14.3))
BATIMENT0000000302929333;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.1;6.6;14.7;15.7;7.0;Cadastre;;POLYGON Z ((355856.3 6688824.7 14.7, 355857.7 6688820.3 14.7, 355840.4 6688816.8 14.7, 355839.4 6688821.2 14.7, 355846.4 6688822.6 14.7, 355856.3 6688824.7 14.7))
BATIMENT0000000302923776;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.2;9.0;25.2;26.5;9.0;Cadastre;C 0.4;POLYGON Z ((356483 6688313.2 25.2, 356487.8 6688315.5 25.2, 356482.3 6688327.2 25.2, 356493 6688332.5 25.2, 356498.4 6688320.6 25.2, 356504.3 6688323.4 25.2, 356504 6688324.3 25.2, 356503.7 6688324.3 25.2, 356503.6 6688324.3 25.2, 356503.3 6688324.3 25.2, 356503.1 6688324.4 25.2, 356502.9 6688324.5 25.2, 356502.8 6688324.6 25.2, 356502.5 6688324.8 25.2, 356502.4 6688325 25.2, 356502.2 6688325.3 25.2, 356502.2 6688325.4 25.2, 356502.1 6688325.6 25.2, 356502.1 6688325.7 25.2, 356502.1 6688326 25.2, 356502.1 6688326.2 25.2, 356502.1 6688326.5 25.2, 356502.2 6688326.7 25.2, 356502.3 6688327 25.2, 356502.5 6688327.2 25.2, 356502.6 6688327.3 25.2, 356502.7 6688327.3 25.2, 356502.8 6688327.4 25.2, 356503.1 6688327.6 25.2, 356503.3 6688327.7 25.2, 356503.4 6688327.8 25.2, 356503.6 6688327.8 25.2, 356503.9 6688327.9 25.2, 356504.1 6688327.9 25.2, 356504.3 6688327.8 25.2, 356504.6 6688327.8 25.2, 356504.9 6688327.7 25.2, 356505 6688327.5 25.2, 356505.2 6688327.4 25.2, 356505.3 6688327.3 25.2, 356505.4 6688327.2 25.2, 356505.5 6688327 25.2, 356505.5 6688326.9 25.2, 356505.6 6688326.8 25.2, 356505.6 6688326.7 25.2, 356505.7 6688326.5 25.2, 356505.7 6688326.4 25.2, 356505.7 6688326.3 25.2, 356505.7 6688326.1 25.2, 356505.7 6688325.9 25.2, 356505.6 6688325.7 25.2, 356505.6 6688325.5 25.2, 356505.5 6688325.4 25.2, 356505.4 6688325.2 25.2, 356505.8 6688324.2 25.2, 356506.81139568595 6688324.687849684 25.2, 356506.81139568595 6688312.003221275 25.200000000000028, 356483.58025635144 6688312.003221275 25.2, 356483 6688313.2 25.2))
BATIMENT0000000302924021;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.5;7.6;16.1;19.5;8.0;Cadastre;;POLYGON Z ((356314.4 6688325.6 16.1, 356315.7 6688312.9 16.1, 356324.4 6688312.9 16.1, 356324.4763215936 6688312.003221275 16.1, 356280.6733627204 6688312.003221275 16.1, 356279.9 6688321.7 16.1, 356314.4 6688325.6 16.1))
BATIMENT0000000302924003;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;7.0;00;00;15.3;7.9;23.3;29.5;8.5;Cadastre;C 0.6;POLYGON Z ((356373 6688342.6 23.3, 356375.69723669195 6688312.003221275 23.3, 356366.5898922626 6688312.003221275 23.3, 356364.4 6688333.7 23.3, 356363.8 6688339.9 23.3, 356363.6 6688341.6 23.3, 356373 6688342.6 23.3))
BATIMENT0000000302924002;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.7;8.3;16.0;21.8;8.7;Cadastre;;POLYGON Z ((356378.7 6688341.1 16, 356378.9 6688339.9 16, 356379.9 6688340 16, 356380.6 6688332.9 16, 356379.6 6688332.8 16, 356381.67632895475 6688312.003221275 16, 356375.69723669195 6688312.003221275 16, 356373 6688342.6 16, 356378.5 6688343.2 16, 356378.7 6688341.1 16))
BATIMENT0000000302923865;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;9.0;;;28.0;8.8;36.8;38.2;9.4;Cadastre;C 0.1;POLYGON Z ((356391.1 6688320.2 36.8, 356407.7 6688328.3 36.8, 356415.62683194765 6688312.003221275 36.8, 356395.01266174775 6688312.003221275 36.8, 356391.1 6688320.2 36.8))
BATIMENT0000000302924022;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.0;7.7;25.7;30.6;8.0;Cadastre;;POLYGON Z ((356325 6688326.9 25.7, 356325.6 6688325.7 25.7, 356325.9 6688315.3 25.7, 356325.8 6688314.5 25.7, 356325.3 6688313.7 25.7, 356324.4 6688312.9 25.7, 356322.8 6688328.3 25.7, 356324.1 6688327.8 25.7, 356325 6688326.9 25.7))
BATIMENT0000000302923850;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;8.9;11.8;;;Cadastre;;POLYGON Z ((356442.9 6688340 11.8, 356448.9 6688342.7 11.8, 356449.2 6688342.9 11.8, 356451.3 6688338.6 11.8, 356445 6688335.5 11.8, 356442.9 6688340 11.8))
BATIMENT0000002011294636;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;43.6;7.2;;52.0;7.6;Imagerie aérienne;;POLYGON Z ((356316.1 6688390.6 50.8, 356328.2 6688395.7 50.8, 356338.5 6688371.6 50.8, 356324.6 6688370.4 50.8, 356316.1 6688390.6 50.8))
BATIMENT0000002011295301;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;18.9;7.6;;47.7;7.6;Imagerie aérienne;;POLYGON Z ((356315.3 6688393 26.5, 356314.1 6688396.2 25.3, 356331.7 6688403.2 25.3, 356344.4 6688372.2 25.3, 356338.5 6688371.6 25.3, 356328.2 6688395.7 25.3, 356316.1 6688390.6 25.3, 356315.3 6688393 26.5))
BATIMENT0000000302923855;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;11.0;00;00;31.4;8.0;39.4;39.5;10.4;Cadastre;C 0.5;POLYGON Z ((356461.1 6688389.6 39.4, 356456.3 6688399.4 39.4, 356504.7 6688423.2 39.4, 356506.81139568595 6688418.713284167 39.4, 356506.81139568595 6688411.700137584 39.4, 356461.1 6688389.6 39.4))
BATIMENT0000002011295800;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;2013-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;20.0;6.0;00;00;3.7;7.0;;25.1;7.6;Imagerie aérienne;C 0.6;POLYGON Z ((356242.1 6688317.2 10.7, 356267.3 6688319 10.7, 356265 6688315.4 10.7, 356265.495363564 6688312.003221275 10.7, 356243.4674206386 6688312.003221275 10.7, 356243.1 6688313.3 10.7, 356243.9 6688313.7 10.7, 356242.1 6688316.6 10.7, 356242.1 6688317.2 10.7))
BATIMENT0000000302924007;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;58.0;9.0;00;00;8.4;7.3;15.7;20.2;7.8;Cadastre;C 0.4;MULTIPOLYGON Z (((356131.6 6688318.8 15.7, 356145.3 6688320.2 15.7, 356145.9471141099 6688312.003221275 15.7, 356131.9130095465 6688312.003221275 15.7, 356131.6 6688318.8 15.7)), ((356159.5 6688321.5 15.7, 356173.3 6688323.2 15.7, 356174.5 6688313.5 15.7, 356216.1 6688317 15.7, 356216.58805745683 6688312.003221275 15.7, 356160.329412989 6688312.003221275 15.7, 356159.5 6688321.5 15.7)))
BATIMENT0000000302924006;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;32.0;7.0;00;00;21.4;7.3;28.7;30.0;7.6;Cadastre;C 0.1;POLYGON Z ((356178.4 6688323.8 28.7, 356215.2 6688327 28.7, 356215.4 6688325.1 28.7, 356216.1 6688317 28.7, 356174.5 6688313.5 28.7, 356173.3 6688323.2 28.7, 356178.4 6688323.8 28.7))
BATIMENT0000002011294695;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;2013-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;30.0;10.0;00;00;29.5;7.0;;37.1;7.8;Imagerie aérienne;C 0.2;POLYGON Z ((356241.2 6688330.1 36.5, 356266.2 6688332.6 36.5, 356267.2 6688321.3 36.5, 356267.3 6688319 36.2, 356242.1 6688317.2 36, 356241.2 6688330.1 36.5))
BATIMENT0000000302924020;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;81.0;8.0;90;90;17.9;7.6;25.6;31.1;8.1;Cadastre;C 0.6;POLYGON Z ((356285.1 6688334.3 25.6, 356285.3 6688331.8 25.6, 356318.6 6688334.9 25.6, 356318.4 6688337.4 25.6, 356321.9 6688337.7 25.6, 356322.8 6688328.3 25.6, 356324.4 6688312.9 25.6, 356315.7 6688312.9 25.6, 356314.4 6688325.6 25.6, 356279.9 6688321.7 25.6, 356279 6688333.7 25.6, 356285.1 6688334.3 25.6))
BATIMENT0000000302923796;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.4;6.5;10.9;15.7;7.6;Cadastre;C 0.4;POLYGON Z ((356320.5 6688369.7 10.9, 356314.4 6688369.1 10.9, 356313.2 6688371.7 10.9, 356304.7 6688368.1 10.9, 356300.1 6688378.7 10.9, 356307.6 6688381.9 10.9, 356308.6 6688379.9 10.9, 356315.2 6688382.8 10.9, 356320.5 6688369.7 10.9))
BATIMENT0000000302923780;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.1;7.0;16.1;;;Cadastre;;POLYGON Z ((356159.3 6688463.9 16.1, 356158.6 6688465.5 16.1, 356159 6688466.6 16.1, 356162 6688468 16.1, 356163.5 6688467.5 16.1, 356180.9 6688427.2 16.1, 356182.2 6688427.7 16.1, 356182.7 6688428.7 16.1, 356187.2 6688426.8 16.1, 356186.1 6688424 16.1, 356191.9 6688421.5 16.1, 356195.5 6688413.2 16.1, 356192 6688404.8 16.1, 356190.6 6688404.3 16.1, 356207.7 6688365.3 16.1, 356208.8 6688365.7 16.1, 356210 6688365.6 16.1, 356211.6 6688361.9 16.1, 356211.1 6688361 16.1, 356209.6 6688360.4 16.1, 356210.1 6688359.2 16.1, 356193.9 6688357.6 16.1, 356189 6688369.1 16.1, 356150 6688460.2 16.1, 356159.3 6688463.9 16.1))
BATIMENT0000000302923789;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.5;7.0;18.5;20.7;8.0;Cadastre;;POLYGON Z ((356236 6688477.5 18.5, 356242.1 6688475.1 18.5, 356237.4 6688463.9 18.5, 356231.4 6688466.4 18.5, 356236 6688477.5 18.5))
BATIMENT0000000302923785;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.7;7.0;21.7;26.3;8.1;Cadastre;;POLYGON Z ((356182.1 6688489.7 21.7, 356188.1 6688475.3 21.7, 356189.3 6688475.8 21.7, 356191.4 6688470.6 21.7, 356197.1 6688472.9 21.7, 356210.9 6688467.1 21.7, 356217.2 6688451.6 21.7, 356213.9 6688444.4 21.7, 356200.5 6688438.8 21.7, 356199.5 6688441.4 21.7, 356186 6688447.3 21.7, 356183.9 6688446.4 21.7, 356174.2 6688469.8 21.7, 356178 6688471.3 21.7, 356172.4 6688484.6 21.7, 356153 6688493 21.7, 356158 6688504.1 21.7, 356165.9 6688500.5 21.7, 356169.4 6688502 21.7, 356170.6 6688502.5 21.7, 356171.4 6688504.3 21.7, 356169 6688509.7 21.7, 356171 6688514 21.7, 356184.6 6688508.1 21.7, 356199.4 6688514 21.7, 356206.4 6688529.6 21.7, 356213.3 6688532.4 21.7, 356217.4 6688522.8 21.7, 356216.7 6688521.3 21.7, 356218.8 6688520.3 21.7, 356223.7 6688518.2 21.7, 356225.2 6688517.4 21.7, 356228.7 6688525.1 21.7, 356236.8 6688521.6 21.7, 356229.8 6688506.2 21.7, 356237.1 6688488 21.7, 356235.7 6688484.8 21.7, 356233.7 6688485.5 21.7, 356232.4 6688482.3 21.7, 356229.2 6688481.1 21.7, 356219.5 6688505 21.7, 356221 6688507.9 21.7, 356214.6 6688510.7 21.7, 356212.6 6688511.7 21.7, 356211.2 6688509.2 21.7, 356186.2 6688499.2 21.7, 356185.2 6688497 21.7, 356182.1 6688489.7 21.7))
BATIMENT0000000302923786;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2022-10-24 14:11:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.7;7.0;20.7;;;Cadastre;;POLYGON Z ((356185.3 6688444.1 20.7, 356180.6 6688442.2 20.7, 356169.9 6688468 20.7, 356174.2 6688469.8 20.7, 356183.9 6688446.4 20.7, 356186 6688447.3 20.7, 356199.5 6688441.4 20.7, 356200.5 6688438.8 20.7, 356213.9 6688444.4 20.7, 356217.2 6688451.6 20.7, 356210.9 6688467.1 20.7, 356197.1 6688472.9 20.7, 356191.4 6688470.6 20.7, 356189.3 6688475.8 20.7, 356210.3 6688484.2 20.7, 356216.7 6688468.1 20.7, 356230.1 6688473.4 20.7, 356231.9 6688472.7 20.7, 356233.1 6688475.4 20.7, 356231.1 6688476.1 20.7, 356229.2 6688481.1 20.7, 356232.4 6688482.3 20.7, 356233.7 6688485.5 20.7, 356235.7 6688484.8 20.7, 356237.1 6688488 20.7, 356229.8 6688506.2 20.7, 356236.8 6688521.6 20.7, 356228.7 6688525.1 20.7, 356225.2 6688517.4 20.7, 356223.7 6688518.2 20.7, 356235.3 6688544.8 20.7, 356252.2 6688551.6 20.7, 356254.5 6688550.5 20.7, 356253.9 6688549.4 20.7, 356255.8 6688545.4 20.7, 356259.8 6688547 20.7, 356261.7 6688542.4 20.7, 356244.5 6688535.6 20.7, 356231.4 6688505.9 20.7, 356240.2 6688484.2 20.7, 356244.2 6688482.5 20.7, 356257.1 6688487.5 20.7, 356258.8 6688483.2 20.7, 356257.7 6688480.6 20.7, 356259.6 6688475.8 20.7, 356244.7 6688469.7 20.7, 356242.9 6688470.4 20.7, 356241.8 6688467.7 20.7, 356253.2 6688462.8 20.7, 356254 6688461 20.7, 356256.7 6688454.5 20.7, 356258.9 6688448.4 20.7, 356254.5 6688447 20.7, 356251.8 6688448 20.7, 356251.5 6688445.8 20.7, 356246.6 6688443.7 20.7, 356242.3 6688453.6 20.7, 356228.5 6688459.5 20.7, 356221.5 6688456.6 20.7, 356226.4 6688444.1 20.7, 356200.4 6688433.4 20.7, 356198.4 6688438.4 20.7, 356185.3 6688444.1 20.7), (356237.4 6688463.9 20.7, 356242.1 6688475.1 20.7, 356236 6688477.5 20.7, 356231.4 6688466.4 20.7, 356237.4 6688463.9 20.7))
BATIMENT0000002011295915;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-25 12:02:59;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;27.8;7.9;;;;Imagerie aérienne;;POLYGON Z ((356391.4 6688390.6 35.7, 356358.2 6688387.2 35.7, 356339.4 6688432.5 35.7, 356369.4 6688444.5 35.7, 356391.4 6688390.6 35.7))
BATIMENT0000000302923853;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;111.0;14.0;30;40;40.7;8.9;49.6;49.6;9.2;Cadastre;C 0.5;POLYGON Z ((356435.4 6688400.1 49.6, 356422.5 6688393.9 49.6, 356403.2 6688434.1 49.6, 356416.1 6688440.3 49.6, 356435.4 6688400.1 49.6))
BATIMENT0000002011295013;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2021-12-05 17:02:40;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;50.9;8.2;;;;Imagerie aérienne;;POLYGON Z ((356315.6 6688423.9 58.6, 356305.5 6688447.7 59.1, 356318.6 6688453.1 59.1, 356328.8 6688429.2 59.1, 356315.6 6688423.9 58.6))
BATIMENT0000002011295426;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.5;7.1;;34.5;7.9;Imagerie aérienne;;POLYGON Z ((356312.6 6688498.2 22.6, 356325 6688503.4 22.6, 356340.9 6688464.5 22.6, 356329 6688459.2 22.6, 356312.6 6688498.2 22.6))
BATIMENT0000002011295453;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-25 12:02:59;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;30.3;7.8;;;;Imagerie aérienne;;POLYGON Z ((356338.8 6688508.9 38, 356354.3 6688469.7 37.8, 356340.9 6688464.5 38.1, 356325 6688503.4 38, 356338.8 6688508.9 38))
BATIMENT0000002011295109;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;13.7;7.9;;34.0;8.1;Imagerie aérienne;;POLYGON Z ((356341.8 6688510.6 21.6, 356358.1 6688471.2 21.6, 356354.8 6688469.9 21.6, 356354.3 6688469.7 21.6, 356338.8 6688508.9 21.6, 356341.8 6688510.6 21.6))
BATIMENT0000000302923848;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;59.0;14.0;00;00;27.0;10.6;37.7;38.9;11.3;Cadastre;C 0.5;POLYGON Z ((356406.9 6688540.1 37.7, 356416.5 6688544.8 37.7, 356454.9 6688466 37.7, 356445.1 6688461.3 37.7, 356406.9 6688540.1 37.7))
BATIMENT0000002011293198;Indifférenciée;Annexe;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;1969-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;00;00;4.5;8.1;;17.5;8.7;Imagerie aérienne;C 0.6;POLYGON Z ((356374 6688496 12.3, 356366.9 6688511.2 12.6, 356373.3 6688514 12.6, 356380.2 6688499 12.6, 356374 6688496 12.3))
BATIMENT0000000302923852;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;56.0;14.0;30;40;40.5;9.6;50.1;;;Cadastre;C 0.6;POLYGON Z ((356382.1 6688536.1 50.1, 356369.2 6688529.9 50.1, 356350.1 6688570.4 50.1, 356362.8 6688576.5 50.1, 356382.1 6688536.1 50.1))
BATIMENT0000000327821882;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:45:28;2018-09-18 13:52:16;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;32.4;8.1;;43.1;9.6;Imagerie aérienne;;POLYGON Z ((356506.81139568595 6688583.545351687 40.5, 356506.81139568595 6688582.250938302 40.5, 356506.3 6688583.3 40.5, 356506.81139568595 6688583.545351687 40.5))
BATIMENT0000002244337356;Indifférenciée;Indifférencié;;Non;En service;2021-06-09 10:29:25;2023-01-31 17:56:42;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;29.3;7.2;36.6;37.4;8.0;Cadastre;;POLYGON Z ((356088.6 6688313.9 36.6, 356088.74752723414 6688312.003221275 36.6, 356062.2727112958 6688312.003221275 36.6, 356088.6 6688313.9 36.6))
BATIMENT0000000302924005;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.8;7.4;23.2;32.1;7.8;Cadastre;C 0.2;POLYGON Z ((356159.5 6688322.1 23.2, 356159.5 6688321.5 23.2, 356160.329412989 6688312.003221275 23.2, 356145.9471141099 6688312.003221275 23.2, 356145.3 6688320.2 23.2, 356145.3 6688320.9 23.2, 356159.5 6688322.1 23.2))
BATIMENT0000000302924004;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.9;7.3;29.2;37.2;7.6;Cadastre;;POLYGON Z ((356131.6 6688318.8 29.2, 356131.9130095465 6688312.003221275 29.2, 356118.13194632815 6688312.003221275 29.2, 356117.6 6688317.5 29.2, 356131.6 6688318.8 29.2))
BATIMENT0000000302923778;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.1;7.0;28.1;28.5;8.0;Cadastre;;POLYGON Z ((356102.9 6688358.1 28.1, 356104.5 6688362.1 28.1, 356109.1 6688360.1 28.1, 356107.6 6688356.3 28.1, 356102.9 6688358.1 28.1))
BATIMENT0000000302923779;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;5.5;7.7;13.3;28.0;8.5;Cadastre;C 0.5;POLYGON Z ((356147.6 6688354.2 13.3, 356146.8 6688354.6 13.3, 356146.1 6688355 13.3, 356145.4 6688355.7 13.3, 356144.6 6688356.3 13.3, 356144.1 6688357.1 13.3, 356143.4 6688357.8 13.3, 356142.5 6688359.3 13.3, 356141.8 6688360.5 13.3, 356141 6688362.2 13.3, 356140.4 6688363.6 13.3, 356117.4 6688354.4 13.3, 356116.2 6688356.8 13.3, 356113.9 6688355.6 13.3, 356113.5 6688356.6 13.3, 356110.2 6688357.8 13.3, 356110.7 6688359.3 13.3, 356109.1 6688360.1 13.3, 356104.5 6688362.1 13.3, 356103.6 6688362.5 13.3, 356102.6 6688360.6 13.3, 356099 6688362.2 13.3, 356098.4 6688361.9 13.3, 356097.2 6688364.7 13.3, 356094.5 6688363.7 13.3, 356086.2 6688383.7 13.3, 356083.8 6688389.4 13.3, 356077.7 6688405.7 13.3, 356075.6 6688410.5 13.3, 356073.9 6688415 13.3, 356076.1 6688415.7 13.3, 356075.9 6688416.2 13.3, 356075.1 6688418.4 13.3, 356075.7 6688418.7 13.3, 356074.2 6688422.3 13.3, 356071.7 6688428.3 13.3, 356071 6688428.1 13.3, 356070.2 6688430.8 13.3, 356067.3 6688429.5 13.3, 356057.8 6688454 13.3, 356060.2 6688455.1 13.3, 356059 6688457.7 13.3, 356060.3 6688458.1 13.3, 356060.8 6688459.4 13.3, 356065.7 6688471 13.3, 356066.3 6688472.6 13.3, 356066 6688473.6 13.3, 356068.8 6688474.5 13.3, 356067.9 6688477.3 13.3, 356089.3 6688486.2 13.3, 356090.7 6688482.7 13.3, 356092.8 6688483.3 13.3, 356094.1 6688483.6 13.3, 356095.5 6688487.1 13.3, 356122.6 6688498.4 13.3, 356131.5 6688502.4 13.3, 356133.9 6688496.9 13.3, 356135.8 6688492.4 13.3, 356126.5 6688488.6 13.3, 356161.3 6688397.4 13.3, 356154.5 6688394.6 13.3, 356166.1 6688366.6 13.3, 356174 6688367.3 13.3, 356181.4 6688368.1 13.3, 356189 6688369.1 13.3, 356193.9 6688357.6 13.3, 356193.4 6688357.6 13.3, 356186 6688356.9 13.3, 356178.6 6688356.2 13.3, 356149.5 6688353.4 13.3, 356147.6 6688354.2 13.3), (356086.1 6688416.7 13.3, 356104.6 6688424.3 13.3, 356111.5 6688427.2 13.3, 356110.6 6688430 13.3, 356111.3 6688431.6 13.3, 356112.6 6688434.7 13.3, 356112.2 6688434.4 13.3, 356111.8 6688434.1 13.3, 356111.5 6688433.9 13.3, 356111.1 6688433.7 13.3, 356110.6 6688433.6 13.3, 356110.2 6688433.5 13.3, 356109.8 6688433.4 13.3, 356109.3 6688433.4 13.3, 356108.9 6688433.4 13.3, 356108.4 6688433.5 13.3, 356108 6688433.6 13.3, 356107.6 6688433.8 13.3, 356107.2 6688434 13.3, 356106.8 6688434.2 13.3, 356106.5 6688434.5 13.3, 356106.1 6688434.8 13.3, 356105.8 6688435.1 13.3, 356105.6 6688435.5 13.3, 356105.4 6688435.9 13.3, 356105.2 6688436.3 13.3, 356105 6688436.7 13.3, 356104.9 6688437.1 13.3, 356104.8 6688437.5 13.3, 356104.8 6688438 13.3, 356104.8 6688438.4 13.3, 356104.9 6688438.9 13.3, 356105 6688439.3 13.3, 356105.2 6688439.7 13.3, 356105.3 6688440.1 13.3, 356105.6 6688440.5 13.3, 356105.8 6688440.9 13.3, 356106.1 6688441.2 13.3, 356106.5 6688441.5 13.3, 356106.8 6688441.8 13.3, 356107.2 6688442 13.3, 356107.6 6688442.2 13.3, 356108 6688442.3 13.3, 356108.4 6688442.4 13.3, 356108.9 6688442.5 13.3, 356109.3 6688442.5 13.3, 356104.7 6688444.4 13.3, 356103.5 6688447.5 13.3, 356092.9 6688443.1 13.3, 356077.6 6688436.8 13.3, 356078.8 6688434.1 13.3, 356075.9 6688433.3 13.3, 356077.2 6688430.4 13.3, 356076.1 6688430 13.3, 356078.6 6688424 13.3, 356080 6688420.5 13.3, 356081.1 6688421 13.3, 356082.2 6688418.3 13.3, 356083.6 6688418.8 13.3, 356085.1 6688419.4 13.3, 356085.6 6688418 13.3, 356086.1 6688416.7 13.3))
BATIMENT0000000302923781;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.8;7.9;26.7;28.4;8.1;Cadastre;;POLYGON Z ((356056.6 6688461.3 26.7, 356061.2 6688472.9 26.7, 356065.7 6688471 26.7, 356060.8 6688459.4 26.7, 356056.6 6688461.3 26.7))
BATIMENT0000000302923783;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.8;7.0;21.8;22.1;7.8;Cadastre;;POLYGON Z ((356131.5 6688502.4 21.8, 356131.9 6688502.6 21.8, 356134.3 6688497.1 21.8, 356133.9 6688496.9 21.8, 356131.5 6688502.4 21.8))
BATIMENT0000000302923782;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.0;21.5;22.4;7.8;Cadastre;;POLYGON Z ((356134.3 6688497.1 21.5, 356131.9 6688502.6 21.5, 356133.6 6688503.2 21.5, 356134.9 6688502.8 21.5, 356136.5 6688502.2 21.5, 356138.1 6688498.7 21.5, 356136.6 6688498.1 21.5, 356134.3 6688497.1 21.5))
BATIMENT0000000302923784;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.0;21.5;23.4;7.8;Cadastre;;POLYGON Z ((356145.7 6688496.3 21.5, 356138.6 6688493.4 21.5, 356136.6 6688498.1 21.5, 356138.1 6688498.7 21.5, 356136.5 6688502.2 21.5, 356134.9 6688502.8 21.5, 356135.9 6688505.2 21.5, 356146.2 6688509.4 21.5, 356158 6688504.1 21.5, 356153 6688493 21.5, 356145.7 6688496.3 21.5))
BATIMENT0000000302923820;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.6;6.8;21.5;22.5;7.1;Cadastre;;POLYGON Z ((356066.5 6688745 21.5, 356069.9 6688741.1 21.5, 356066.1 6688739.5 21.5, 356066.5 6688745 21.5))
BATIMENT0000000302923787;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;7.8;22.2;24.2;8.0;Cadastre;;POLYGON Z ((356214.6 6688510.7 22.2, 356213.4 6688508.2 22.2, 356185.2 6688497 22.2, 356186.2 6688499.2 22.2, 356211.2 6688509.2 22.2, 356212.6 6688511.7 22.2, 356214.6 6688510.7 22.2))
BATIMENT0000002011295699;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;31.4;5.7;;37.7;7.9;Imagerie aérienne;;POLYGON Z ((356288.8 6688488.7 37.1, 356268.8 6688538.1 36.8, 356282.7 6688543.8 36.8, 356303.3 6688494.8 36.8, 356288.8 6688488.7 37.1))
BATIMENT0000000302923788;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.4;7.0;24.4;26.1;8.1;Cadastre;;POLYGON Z ((356162.9 6688517.9 24.4, 356174.2 6688522.4 24.4, 356178.5 6688512.1 24.4, 356183.2 6688510.3 24.4, 356198.3 6688516.3 24.4, 356203.9 6688528.9 24.4, 356202.2 6688532.8 24.4, 356213.9 6688537.5 24.4, 356220 6688522.8 24.4, 356218.8 6688520.3 24.4, 356216.7 6688521.3 24.4, 356217.4 6688522.8 24.4, 356213.3 6688532.4 24.4, 356206.4 6688529.6 24.4, 356199.4 6688514 24.4, 356184.6 6688508.1 24.4, 356171 6688514 24.4, 356169 6688509.7 24.4, 356171.4 6688504.3 24.4, 356170.6 6688502.5 24.4, 356169.4 6688502 24.4, 356162.9 6688517.9 24.4))
BATIMENT0000000302923790;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-07-01 11:22:43;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.0;21.5;23.3;7.6;Cadastre;;POLYGON Z ((356255.1 6688552 21.5, 356257.3 6688552.9 21.5, 356259.8 6688547 21.5, 356255.8 6688545.4 21.5, 356253.9 6688549.4 21.5, 356254.5 6688550.5 21.5, 356255.1 6688552 21.5))
BATIMENT0000002011294269;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:42;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;26.5;7.2;;35.4;7.7;Imagerie aérienne;;POLYGON Z ((356272.2 6688571.4 33.7, 356284.5 6688576.4 33.7, 356291.8 6688557.9 33.7, 356279.7 6688552.9 33.7, 356272.2 6688571.4 33.7))
BATIMENT0000002011293974;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-07-01 11:22:43;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;55.6;7.5;;;;Imagerie aérienne;;POLYGON Z ((356293.9 6688580.1 62.9, 356301.7 6688561.9 63, 356291.8 6688557.9 63.1, 356284.5 6688576.4 62.9, 356293.9 6688580.1 62.9))
BATIMENT0000002011293384;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-07-01 11:22:43;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;22.5;6.7;;;;Imagerie aérienne;;POLYGON Z ((356298.7 6688582.3 29.2, 356306.2 6688563.9 29.2, 356301.7 6688561.9 29.2, 356293.9 6688580.1 29.2, 356298.7 6688582.3 29.2))
BATIMENT0000000302923811;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;22.0;6.0;00;00;17.5;5.2;22.7;25.9;7.2;Cadastre;A 0.4;POLYGON Z ((356177.3 6688798.2 22.7, 356178.5 6688798.7 22.7, 356178.3 6688799.2 22.7, 356182.6 6688801 22.7, 356182.8 6688800.5 22.7, 356186.4 6688801.9 22.7, 356192.5 6688804.4 22.7, 356197 6688793.7 22.7, 356190.5 6688791.1 22.7, 356168.9 6688782.1 22.7, 356164.5 6688793 22.7, 356177.3 6688798.2 22.7))
BATIMENT0000000302923812;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;6.8;15.2;20.0;7.1;Cadastre;;POLYGON Z ((356175.9 6688801.7 15.2, 356177.3 6688798.2 15.2, 356164.5 6688793 15.2, 356163.1 6688796.5 15.2, 356175.9 6688801.7 15.2))
BATIMENT0000000302923814;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.9;6.8;19.7;22.0;7.1;Cadastre;;POLYGON Z ((356204.1 6688796.7 19.7, 356204.5 6688798.4 19.7, 356206.3 6688799.1 19.7, 356208 6688798.3 19.7, 356204.1 6688796.7 19.7))
BATIMENT0000000327821907;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;52.0;8.0;;;9.1;7.0;;31.0;9.9;Imagerie aérienne;C 0.7;POLYGON Z ((356506.3 6688583.3 16.1, 356496.4 6688604.4 16.1, 356506.81139568595 6688608.760328108 16.1, 356506.81139568595 6688605.757407196 16.1, 356503.8 6688603.8 16.1, 356506.81139568595 6688597.648148813 16.1, 356506.81139568595 6688583.545351687 16.1, 356506.3 6688583.3 16.1))
BATIMENT0000000302923993;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;1.8;8.7;10.5;13.7;10.9;Cadastre;C 0.3;POLYGON Z ((356368.2 6688603.2 10.5, 356372.8 6688593.3 10.5, 356365.9 6688589.9 10.5, 356361.2 6688599.8 10.5, 356368.2 6688603.2 10.5))
BATIMENT0000000327821879;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;41.0;9.0;00;00;26.5;10.6;;;;Imagerie aérienne;C 0.2;POLYGON Z ((356503.8 6688603.8 37.1, 356506.81139568595 6688605.757407196 37.005893884812274, 356506.81139568595 6688597.648148813 37.1, 356503.8 6688603.8 37.1))
BATIMENT0000000302923994;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;39.0;11.0;00;00;30.2;8.9;39.1;;;Cadastre;C 0.4;POLYGON Z ((356414.7 6688625.7 39.1, 356419.4 6688616.1 39.1, 356372.8 6688593.3 39.1, 356368.2 6688603.2 39.1, 356414.7 6688625.7 39.1))
BATIMENT0000000327821886;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2013-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;30.9;5.2;;39.8;9.3;Imagerie aérienne;C 0.2;POLYGON Z ((356499.8 6688641.5 36.1, 356506.81139568595 6688645.198318603 36.1, 356506.81139568595 6688620.158177655 36.1, 356504.9 6688619.3 36.1, 356503.7 6688621.9 36.1, 356491.3 6688615.7 36.1, 356472.3 6688653.8 36.1, 356489.4 6688662.1 36, 356499.8 6688641.5 36.1))
BATIMENT0000000327821825;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;4.8;6.0;;38.3;6.9;Imagerie aérienne;C 0.6;POLYGON Z ((356499.8 6688641.5 10.8, 356489.4 6688662.1 10.8, 356496.4 6688665.7 10.8, 356503.4 6688650.8 10.8, 356506.81139568595 6688652.350634403 10.8, 356506.81139568595 6688645.198318603 10.8, 356499.8 6688641.5 10.8))
BATIMENT0000000327821798;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:45:28;2018-09-18 13:52:16;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;11.4;6.4;;19.3;6.9;Imagerie aérienne;;POLYGON Z ((356505.3 6688670.4 17.8, 356506.81139568595 6688667.046590822 17.8, 356506.81139568595 6688652.350634403 17.8, 356503.4 6688650.8 17.8, 356496.4 6688665.7 17.8, 356505.3 6688670.4 17.8))
BATIMENT0000000302924019;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;7.0;;;21.8;7.0;28.8;29.3;7.8;Cadastre;C 0.1;POLYGON Z ((356299.5 6688866.1 28.8, 356301.1 6688868.7 28.8, 356303.4 6688870.7 28.8, 356306 6688872.2 28.8, 356310.5 6688872.2 28.8, 356313.2 6688871.4 28.8, 356316.7 6688869 28.8, 356319.7 6688865.6 28.8, 356322 6688860.8 28.8, 356322.5 6688859.6 28.8, 356323.2 6688858.1 28.8, 356323.5 6688857.3 28.8, 356323.9 6688855.8 28.8, 356324.1 6688853.4 28.8, 356323.9 6688851 28.8, 356323.1 6688848.8 28.8, 356321.4 6688846.1 28.8, 356319.7 6688844.5 28.8, 356317.7 6688843.2 28.8, 356317.6 6688843.2 28.8, 356315.4 6688842.4 28.8, 356313.1 6688842.1 28.8, 356310.7 6688842.3 28.8, 356308.4 6688843 28.8, 356306.3 6688844.1 28.8, 356304 6688846.3 28.8, 356302.3 6688849 28.8, 356300.8 6688852 28.8, 356298.9 6688856 28.8, 356298.6 6688859.4 28.8, 356298.8 6688863.2 28.8, 356299.5 6688866.1 28.8))
BATIMENT0000000302923893;Indifférenciée;Industriel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.9;6.7;13.6;20.4;7.4;Cadastre;A 1.0;POLYGON Z ((356404.7 6688879.1 13.6, 356400.8 6688877.5 13.6, 356395.6 6688892.6 13.6, 356390.6 6688890.6 13.6, 356395.5 6688875.3 13.6, 356392.2 6688873.9 13.6, 356388.1 6688886.4 13.6, 356382.1 6688905.1 13.6, 356378.2 6688916.4 13.6, 356390.2 6688921.3 13.6, 356399.6 6688893.9 13.6, 356404.7 6688879.1 13.6))
BATIMENT0000000302923879;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;30.0;7.0;00;00;21.0;6.4;27.4;27.6;7.5;Cadastre;A 1.0;POLYGON Z ((356440.9 6688900.6 27.4, 356438.6 6688899.5 27.4, 356439.3 6688898.1 27.4, 356438.5 6688897.7 27.4, 356439.5 6688895.9 27.4, 356417.9 6688887 27.4, 356411.4 6688900.5 27.4, 356421.3 6688904.9 27.4, 356420.6 6688906.7 27.4, 356434.9 6688912.7 27.4, 356440.9 6688900.6 27.4))
BATIMENT0000000302923817;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.6;5.0;20.6;22.6;7.2;Cadastre;;POLYGON Z ((356081 6688745.7 20.6, 356080.3 6688745.4 20.6, 356077.6 6688748.4 20.6, 356085.6 6688747.6 20.6, 356081 6688745.7 20.6))
BATIMENT0000000302923816;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;6.0;00;00;18.4;5.0;23.4;28.4;7.4;Cadastre;C 0.8;POLYGON Z ((356069.7 6688778 23.4, 356084.1 6688761.8 23.4, 356097 6688766.9 23.4, 356097.7 6688765.3 23.4, 356102.1 6688754.4 23.4, 356085.6 6688747.6 23.4, 356077.6 6688748.4 23.4, 356073.3 6688753.1 23.4, 356065.6 6688746 23.4, 356066.5 6688745 23.4, 356066.1 6688739.5 23.4, 356053.4 6688734.2 23.4, 356048.1 6688746.8 23.4, 356057.5 6688750.6 23.4, 356059.2 6688753.1 23.4, 356056.5 6688755.9 23.4, 356064.2 6688762.9 23.4, 356064.6 6688765.9 23.4, 356060.9 6688770 23.4, 356069.7 6688778 23.4))
BATIMENT0000000302923807;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;13;20;15.1;5.0;20.1;23.8;7.3;Cadastre;A 1.0;POLYGON Z ((356102.1 6688754.4 20.1, 356097.7 6688765.3 20.1, 356107.8 6688769.4 20.1, 356112.4 6688771.3 20.1, 356115.2 6688772.4 20.1, 356119.6 6688761.7 20.1, 356102.1 6688754.4 20.1))
BATIMENT0000000302923819;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;7.0;21.2;23.0;7.3;Cadastre;;POLYGON Z ((356064.6 6688765.9 21.2, 356064.2 6688762.9 21.2, 356059.3 6688768.5 21.2, 356060.9 6688770 21.2, 356064.6 6688765.9 21.2))
BATIMENT0000000302923818;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.9;7.0;11.0;14.2;7.2;Cadastre;C 0.3;POLYGON Z ((356093.8 6688774.9 11, 356098.9 6688776.9 11, 356101.5 6688770.2 11, 356096.5 6688768.2 11, 356093.8 6688774.9 11))
BATIMENT0000000302923808;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;6.9;16.0;19.5;7.1;Cadastre;;POLYGON Z ((356112.4 6688771.3 16, 356111.1 6688774.3 16, 356113.9 6688775.4 16, 356114.6 6688773.8 16, 356115.2 6688772.4 16, 356112.4 6688771.3 16))
BATIMENT0000000302923810;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;6.8;17.5;19.5;7.2;Cadastre;;POLYGON Z ((356143 6688777.1 17.5, 356142.5 6688775.5 17.5, 356139.9 6688774.5 17.5, 356138.4 6688775.1 17.5, 356143 6688777.1 17.5))
BATIMENT0000000302923801;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;6.9;21.4;24.0;7.3;Cadastre;;POLYGON Z ((356047.3 6688802.9 21.4, 356050.8 6688806 21.4, 356058.8 6688796.9 21.4, 356060.7 6688797.9 21.4, 356061.3 6688796.4 21.4, 356059.7 6688795.7 21.4, 356056.4 6688792.8 21.4, 356047.3 6688802.9 21.4))
BATIMENT0000000302923806;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;6.9;13.0;14.5;7.4;Cadastre;;POLYGON Z ((356084.1 6688802.4 13, 356084.2 6688802.4 13, 356086.5 6688803.2 13, 356088.8 6688796.4 13, 356086.5 6688795.6 13, 356084.1 6688802.4 13))
BATIMENT0000000302923802;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;;;5.2;6.7;12.0;20.2;7.4;Cadastre;C 0.6;POLYGON Z ((356088.7 6688826.7 12, 356090.8 6688822 12, 356094.4 6688810.7 12, 356100.4 6688812.8 12, 356108.9 6688787.6 12, 356106.5 6688786.7 12, 356095.9 6688783 12, 356096.3 6688782.1 12, 356091.6 6688780.4 12, 356086.5 6688795.6 12, 356088.8 6688796.4 12, 356086.5 6688803.2 12, 356084.2 6688802.4 12, 356084.1 6688802.4 12, 356082.4 6688807.6 12, 356077.7 6688821.5 12, 356088.7 6688826.7 12))
BATIMENT0000000302923815;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;6.8;11.7;19.2;7.0;Cadastre;;POLYGON Z ((356184.9 6688805.5 11.7, 356191 6688808 11.7, 356192.5 6688804.4 11.7, 356186.4 6688801.9 11.7, 356184.9 6688805.5 11.7))
BATIMENT0000000302923813;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.6;5.1;22.7;26.1;7.3;Cadastre;C 0.5;POLYGON Z ((356200.9 6688807.9 22.7, 356199.2 6688811.8 22.7, 356207.7 6688815.4 22.7, 356209.4 6688811.5 22.7, 356223.2 6688817.2 22.7, 356225 6688812.9 22.7, 356220.9 6688803.7 22.7, 356208 6688798.3 22.7, 356206.3 6688799.1 22.7, 356204.5 6688798.4 22.7, 356204.1 6688796.7 22.7, 356197 6688793.7 22.7, 356192.5 6688804.4 22.7, 356200.9 6688807.9 22.7))
BATIMENT0000000302923875;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;7.2;6.9;14.2;18.0;7.2;Cadastre;A 1.0;POLYGON Z ((356246.7 6688813.8 14.2, 356242.2 6688815.8 14.2, 356238.6 6688824.6 14.2, 356243.2 6688826.5 14.2, 356244.3 6688823.6 14.2, 356245.2 6688824.1 14.2, 356245.7 6688822.8 14.2, 356244.8 6688822.5 14.2, 356246.1 6688819.3 14.2, 356254.4 6688822.8 14.2, 356254 6688823.8 14.2, 356254.4 6688824 14.2, 356253.4 6688826.5 14.2, 356252.2 6688826 14.2, 356250.6 6688829.6 14.2, 356253.5 6688830.7 14.2, 356258.4 6688818.7 14.2, 356246.7 6688813.8 14.2))
BATIMENT0000000302923873;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;10.9;7.0;18.0;20.1;7.3;Cadastre;A 1.0;POLYGON Z ((356236.4 6688830.1 18, 356244.8 6688833.7 18, 356246.7 6688829.3 18, 356247.6 6688829.7 18, 356248.1 6688828.5 18, 356243.2 6688826.5 18, 356238.6 6688824.6 18, 356236.4 6688830.1 18))
BATIMENT0000000302923874;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.6;6.2;13.8;19.9;7.3;Cadastre;C 0.6;POLYGON Z ((356257.1 6688837.2 13.8, 356255 6688836.2 13.8, 356256.1 6688833.6 13.8, 356271.9 6688840.1 13.8, 356274.2 6688839.3 13.8, 356274.5 6688838.5 13.8, 356278.8 6688827.1 13.8, 356258.4 6688818.7 13.8, 356253.5 6688830.7 13.8, 356251.2 6688836.3 13.8, 356248.7 6688842.4 13.8, 356254.3 6688844.7 13.8, 356257.1 6688837.2 13.8))
BATIMENT0000000302923872;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;50;90;11.7;7.0;18.7;20.8;7.4;Cadastre;A 1.0;POLYGON Z ((356232.3 6688840.3 18.7, 356241.1 6688844 18.7, 356242.3 6688841.2 18.7, 356245.6 6688842.5 18.7, 356244.5 6688845.4 18.7, 356247 6688846.4 18.7, 356248.7 6688842.4 18.7, 356251.2 6688836.3 18.7, 356244.8 6688833.7 18.7, 356236.4 6688830.1 18.7, 356232.3 6688840.3 18.7))
BATIMENT0000000302923913;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.0;7.1;9.1;9.2;7.3;Cadastre;;POLYGON Z ((356209.6 6688843.5 9.1, 356211.5 6688844.3 9.1, 356212.6 6688841.5 9.1, 356210.8 6688840.7 9.1, 356209.6 6688843.5 9.1))
BATIMENT0000000302923868;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;11.7;7.0;18.7;21.6;7.4;Cadastre;A 0.6;POLYGON Z ((356228.4 6688849.8 18.7, 356238.1 6688853.6 18.7, 356241.9 6688844.3 18.7, 356241.1 6688844 18.7, 356232.3 6688840.3 18.7, 356228.4 6688849.8 18.7))
BATIMENT0000000302923914;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.7;7.1;9.8;10.7;7.4;Cadastre;;POLYGON Z ((356269.6 6688851.9 9.8, 356270.8 6688849 9.8, 356268.2 6688848 9.8, 356267 6688850.9 9.8, 356268 6688851.3 9.8, 356269.6 6688851.9 9.8))
BATIMENT0000000302923869;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;6.9;9.1;9.9;7.3;Cadastre;;POLYGON Z ((356243.8 6688855.8 9.1, 356244.8 6688853.2 9.1, 356242.6 6688852.3 9.1, 356241.4 6688854.9 9.1, 356243.8 6688855.8 9.1))
BATIMENT0000000302923804;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;87.0;7.0;50;20;3.5;6.8;10.3;23.4;7.2;Cadastre;A 1.0;POLYGON Z ((356124.1 6688813.6 10.3, 356123.3 6688814 10.3, 356126 6688820.2 10.3, 356126.8 6688819.8 10.3, 356129 6688825 10.3, 356123.4 6688827.3 10.3, 356122.2 6688827.8 10.3, 356121.7 6688826.7 10.3, 356118.4 6688828.1 10.3, 356118.9 6688829.3 10.3, 356117.7 6688829.8 10.3, 356117 6688827.9 10.3, 356098.2 6688819.2 10.3, 356094.7 6688829.6 10.3, 356098.3 6688831.3 10.3, 356120.5 6688842 10.3, 356122.2 6688841.3 10.3, 356127.9 6688839.1 10.3, 356128.4 6688840.3 10.3, 356129.6 6688840.6 10.3, 356129 6688841.9 10.3, 356131 6688847.1 10.3, 356136 6688849.5 10.3, 356142.2 6688848 10.3, 356155.1 6688816.3 10.3, 356163.1 6688796.5 10.3, 356164.5 6688793 10.3, 356168.9 6688782.1 10.3, 356146.6 6688773.2 10.3, 356144.7 6688777.8 10.3, 356143 6688777.1 10.3, 356138.4 6688775.1 10.3, 356135.8 6688774.1 10.3, 356136.1 6688773.6 10.3, 356136.2 6688773.2 10.3, 356136.3 6688772.8 10.3, 356136.4 6688772.3 10.3, 356136.4 6688772.1 10.3, 356136.4 6688771.9 10.3, 356136.4 6688771.5 10.3, 356136.4 6688771.3 10.3, 356136.4 6688771.1 10.3, 356136.3 6688770.9 10.3, 356136.2 6688770.3 10.3, 356136 6688769.9 10.3, 356135.9 6688769.8 10.3, 356135.8 6688769.6 10.3, 356135.6 6688769.2 10.3, 356135.4 6688769.1 10.3, 356135.3 6688768.9 10.3, 356135.2 6688768.7 10.3, 356134.9 6688768.6 10.3, 356134 6688767.9 10.3, 356133.2 6688767.4 10.3, 356123.1 6688763.2 10.3, 356119.6 6688761.7 10.3, 356115.2 6688772.4 10.3, 356114.6 6688773.8 10.3, 356118.3 6688775.3 10.3, 356112.8 6688788.6 10.3, 356113.1 6688789.3 10.3, 356114.5 6688789.9 10.3, 356110.6 6688799.3 10.3, 356119.4 6688802.9 10.3, 356120.5 6688805.5 10.3, 356119.7 6688805.9 10.3, 356121 6688808.7 10.3, 356121.7 6688808.3 10.3, 356124.1 6688813.6 10.3))
BATIMENT0000000302923800;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;68.0;5.0;00;00;15.5;6.8;22.3;24.1;7.3;Cadastre;C 0.5;POLYGON Z ((356073.2 6688803.5 22.3, 356074 6688801.9 22.3, 356061.3 6688796.4 22.3, 356060.7 6688797.9 22.3, 356058.8 6688796.9 22.3, 356050.8 6688806 22.3, 356056.9 6688811.5 22.3, 356077.7 6688821.5 22.3, 356082.4 6688807.6 22.3, 356073.2 6688803.5 22.3))
BATIMENT0000000302923803;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;6.9;6.7;13.6;17.7;7.2;Cadastre;A 1.0;POLYGON Z ((356094.7 6688829.6 13.6, 356098.2 6688819.2 13.6, 356100.4 6688812.8 13.6, 356094.4 6688810.7 13.6, 356090.8 6688822 13.6, 356088.7 6688826.7 13.6, 356094.7 6688829.6 13.6))
BATIMENT0000000302923888;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;;;13.0;6.6;19.6;21.6;7.1;Cadastre;C 0.2;POLYGON Z ((356039.2 6688857.9 19.6, 356053.2 6688864.6 19.6, 356063.1 6688843.9 19.6, 356080.8 6688852.5 19.6, 356085.3 6688854.7 19.6, 356090.9 6688843.1 19.6, 356048.3 6688822.6 19.6, 356032.9 6688854.8 19.6, 356039.2 6688857.9 19.6))
BATIMENT0000000302923890;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2022-10-20 15:46:45;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;8.9;6.6;15.5;16.0;7.0;Cadastre;C 0.6;POLYGON Z ((356090.9 6688843.1 15.5, 356085.3 6688854.7 15.5, 356080.9 6688863.7 15.5, 356086.2 6688866.3 15.5, 356090.8 6688868.5 15.5, 356097.1 6688855.3 15.5, 356100.8 6688857.1 15.5, 356104.6 6688849.3 15.5, 356090.9 6688843.1 15.5))
BATIMENT0000000302923891;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;6.6;10.4;14.4;7.0;Cadastre;;POLYGON Z ((356079.7 6688879.1 10.4, 356079.9 6688879.2 10.4, 356086.2 6688866.3 10.4, 356080.9 6688863.7 10.4, 356079.4 6688866.8 10.4, 356079.3 6688867 10.4, 356074.5 6688877.2 10.4, 356079.7 6688879.1 10.4))
BATIMENT0000002011292597;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.8;6.7;;;;Imagerie aérienne;;POLYGON Z ((356084.7 6688880.9 10.1, 356090.8 6688868.5 15.5, 356086.2 6688866.3 15.5, 356079.9 6688879.2 10.4, 356084.7 6688880.9 10.1))
BATIMENT0000002275362553;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;24.3;7.5;;;;Imagerie aérienne;;POLYGON Z ((356155.2 6688900.8 23.3, 356158.3 6688894.4 31.8, 356162.3 6688895.3 29.1, 356164.5 6688887.6 29.1, 356168.4 6688880.4 29.1, 356136.8 6688865.2 29.2, 356104.6 6688849.3 22.4, 356100.8 6688857.1 22.4, 356098.7 6688861.4 22.4, 356105.8 6688864.8 22.4, 356104.2 6688867.7 21.7, 356129.8 6688880.3 25.2, 356144.9 6688887.6 25.1, 356141.2 6688896.3 23.2, 356138.9 6688895.4 21.5, 356127.7 6688920.1 23.2, 356106.3 6688914.3 23.1, 356105.9 6688915.3 23.1, 356104.2 6688921.6 23.1, 356102.7 6688926.9 23.1, 356137.7 6688936.5 23.1, 356141.9 6688934.9 23.1, 356157.5 6688902.5 22.5, 356155.2 6688900.8 23.3))
BATIMENT0000000302923885;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;12;20;14.4;6.2;20.6;22.7;6.9;Cadastre;A 1.0;POLYGON Z ((356043.9 6688910.8 20.6, 356045.8 6688912.8 20.6, 356064.1 6688917.1 20.6, 356066.8 6688906.7 20.6, 356062.8 6688905.8 20.6, 356058.9 6688904.9 20.6, 356055.5 6688904.2 20.6, 356054.2 6688904.5 20.6, 356051.5 6688892.2 20.6, 356051.2 6688892.1 20.6, 356038.9 6688888.7 20.6, 356043.9 6688910.8 20.6))
BATIMENT0000000302923884;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.0;6.0;19.0;23.9;7.1;Cadastre;A 1.0;POLYGON Z ((356066.8 6688906.7 19, 356064.1 6688917.1 19, 356089.1 6688923 19, 356102.7 6688926.9 19, 356104.2 6688921.6 19, 356105.9 6688915.3 19, 356100.1 6688913.8 19, 356102.1 6688905.8 19, 356074.7 6688899.2 19, 356072.7 6688906.9 19, 356067.1 6688905.5 19, 356066.8 6688906.7 19))
BATIMENT0000000302923867;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;10;20;8.6;6.0;14.6;19.0;7.4;Cadastre;A 0.9;POLYGON Z ((356224.7 6688859 14.6, 356234.8 6688863.3 14.6, 356238.2 6688855.3 14.6, 356241.5 6688856.5 14.6, 356240.2 6688859.8 14.6, 356241.9 6688860.4 14.6, 356243.8 6688855.8 14.6, 356241.4 6688854.9 14.6, 356238.1 6688853.6 14.6, 356228.4 6688849.8 14.6, 356224.7 6688859 14.6))
BATIMENT0000000302923878;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;7.0;8.8;12.4;7.2;Cadastre;;POLYGON Z ((356239.9 6688865.5 8.8, 356240.5 6688864.2 8.8, 356237.2 6688862.9 8.8, 356236.7 6688864.1 8.8, 356239.9 6688865.5 8.8))
BATIMENT0000000302923871;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;8.8;6.0;14.8;18.7;7.4;Cadastre;A 1.0;POLYGON Z ((356221.1 6688868 14.8, 356236.4 6688874.5 14.8, 356237.1 6688872.7 14.8, 356232.5 6688870.9 14.8, 356233 6688869.7 14.8, 356231.7 6688869 14.8, 356233.5 6688864.6 14.8, 356239.4 6688867 14.8, 356239.9 6688865.5 14.8, 356236.7 6688864.1 14.8, 356234.8 6688863.3 14.8, 356224.7 6688859 14.8, 356221.1 6688868 14.8))
BATIMENT0000000302923876;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.4;7.0;27.4;28.8;7.4;Cadastre;;POLYGON Z ((356257.8 6688907.7 27.4, 356259.4 6688908.5 27.4, 356281.6 6688862.1 27.4, 356283.5 6688858.2 27.4, 356295.1 6688833.9 27.4, 356284.9 6688829.7 27.4, 356282.6 6688828.7 27.4, 356278.8 6688827.1 27.4, 356274.5 6688838.5 27.4, 356278.2 6688839.9 27.4, 356279.8 6688840.5 27.4, 356273.7 6688852.7 27.4, 356254.6 6688891.4 27.4, 356243 6688886.8 27.4, 356238.4 6688898.3 27.4, 356257.8 6688907.7 27.4))
BATIMENT0000000302923870;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;3.0;7.1;10.1;22.0;7.5;Cadastre;A 1.0;POLYGON Z ((356232.9 6688883.5 10.1, 356228.8 6688893.7 10.1, 356238.4 6688898.3 10.1, 356243 6688886.8 10.1, 356258.9 6688846.6 10.1, 356254.3 6688844.7 10.1, 356248.7 6688842.4 10.1, 356247 6688846.4 10.1, 356247.4 6688846.6 10.1, 356244.8 6688853.2 10.1, 356243.8 6688855.8 10.1, 356241.9 6688860.4 10.1, 356240.5 6688864.2 10.1, 356239.9 6688865.5 10.1, 356239.4 6688867 10.1, 356237.1 6688872.7 10.1, 356236.4 6688874.5 10.1, 356232.9 6688883.5 10.1))
BATIMENT0000000302924017;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.8;7.0;10.8;24.5;8.0;Cadastre;C 0.4;POLYGON Z ((356300.8 6688904.5 10.8, 356319.7 6688865.6 10.8, 356316.7 6688869 10.8, 356313.2 6688871.4 10.8, 356310.5 6688872.2 10.8, 356306 6688872.2 10.8, 356303.4 6688870.7 10.8, 356301.1 6688868.7 10.8, 356299.5 6688866.1 10.8, 356298.8 6688863.2 10.8, 356298.6 6688859.4 10.8, 356298.9 6688856 10.8, 356289.5 6688875.8 10.8, 356280.4 6688894.6 10.8, 356300.8 6688904.5 10.8))
BATIMENT0000000302923877;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.8;7.1;22.0;25.7;7.8;Cadastre;A 1.0;POLYGON Z ((356217.3 6688887.3 22, 356217 6688888 22, 356228.8 6688893.7 22, 356232.9 6688883.5 22, 356236.4 6688874.5 22, 356221.1 6688868 22, 356217.7 6688876.4 22, 356215.1 6688882.9 22, 356217.3 6688887.3 22))
BATIMENT0000000302924018;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;7.0;00;00;21.8;7.0;28.8;29.4;7.7;Cadastre;C 0.4;POLYGON Z ((356291.4 6688923.8 28.8, 356294.1 6688918.4 28.8, 356300.8 6688904.5 28.8, 356280.4 6688894.6 28.8, 356271.1 6688914.1 28.8, 356275.2 6688916.1 28.8, 356291.4 6688923.8 28.8))
BATIMENT0000002011296193;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;24.5;6.7;;;;Imagerie aérienne;A 1.0;POLYGON Z ((356266.5 6688958.7 30.9, 356249.3 6688960.4 30.9, 356247.2 6688965.6 30.9, 356236.3 6688960.2 30.9, 356251.2 6688930.3 31.2, 356186.1 6688899.1 31.2, 356174.2 6688923.7 31.2, 356170.2 6688932.1 27.8, 356174.9 6688934.6 30.9, 356214.6 6688953.7 30.9, 356218.5 6688945.7 30.9, 356229.3 6688951 30.9, 356228.1 6688953.9 28.8, 356234.3 6688956.2 30.9, 356232.2 6688960.9 30.9, 356246.2 6688967.4 30.9, 356242.4 6688975.6 30.9, 356260.9 6688984.6 30.9, 356263.8 6688978.7 30.9, 356261.7 6688977.8 30.9, 356263.6 6688973.7 30.9, 356266.9 6688975 30.9, 356272.6 6688961.8 30.9, 356266.5 6688958.7 30.9))
BATIMENT0000000302923953;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;7.2;16.1;20.0;7.4;Cadastre;;POLYGON Z ((356175.5 6688955.3 16.1, 356180 6688957.5 16.1, 356180.7 6688956.1 16.1, 356180.9 6688955.8 16.1, 356176.3 6688953.6 16.1, 356175.4 6688955.3 16.1, 356175.5 6688955.3 16.1))
BATIMENT0000000302929627;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;6.5;13.2;16.1;7.3;Cadastre;A 1.0;POLYGON Z ((355438.8 6688452.8 13.2, 355442.4 6688453.2 13.2, 355448 6688453.7 13.2, 355460.3 6688454.9 13.2, 355461.3 6688444.2 13.2, 355461.4 6688442.4 13.2, 355446.2 6688440.9 13.2, 355439.9 6688440.3 13.2, 355438.8 6688452.8 13.2))
BATIMENT0000000327821799;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2013-09-26 18:45:28;2018-09-18 13:45:21;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.7;6.5;;13.5;7.0;Imagerie aérienne;;POLYGON Z ((355424.6 6688447 11.2, 355422.8 6688465.6 10.9, 355434.7 6688466.4 11, 355436.1 6688452.5 11.2, 355438.8 6688452.8 11.2, 355439.9 6688440.3 11.2, 355440.2 6688436.3 11.2, 355425.7 6688435 11.2, 355424.6 6688447 11.2))
BATIMENT0000000302929620;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.9;5.3;11.2;13.5;6.7;Cadastre;;POLYGON Z ((355442.3 6688454.7 11.2, 355447.7 6688455.1 11.2, 355448 6688453.7 11.2, 355442.4 6688453.2 11.2, 355442.3 6688454.7 11.2))
BATIMENT0000000302929628;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;11.7;6.8;18.6;21.5;7.3;Cadastre;A 1.0;POLYGON Z ((355408.4 6688465.5 18.6, 355422.7 6688466.7 18.6, 355422.8 6688465.6 18.6, 355424.6 6688447 18.6, 355410.1 6688445.9 18.6, 355408.4 6688465.5 18.6))
BATIMENT0000000302929618;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.3;5.3;11.6;13.6;7.3;Cadastre;A 1.0;POLYGON Z ((355447.7 6688455.1 11.6, 355445.4 6688471.2 11.6, 355444.7 6688472.5 11.6, 355443.3 6688477.6 11.6, 355442.7 6688482.7 11.6, 355442.1 6688482.8 11.6, 355442.5 6688484.9 11.6, 355457.8 6688481.5 11.6, 355459.4 6688463.6 11.6, 355460.3 6688454.9 11.6, 355448 6688453.7 11.6, 355447.7 6688455.1 11.6))
BATIMENT0000000302929619;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.9;5.3;11.2;14.2;6.8;Cadastre;A 1.0;POLYGON Z ((355442.5 6688484.9 11.2, 355442.1 6688482.8 11.2, 355442.7 6688482.7 11.2, 355443.3 6688477.6 11.2, 355444.7 6688472.5 11.2, 355445.4 6688471.2 11.2, 355447.7 6688455.1 11.2, 355442.3 6688454.7 11.2, 355442.4 6688453.2 11.2, 355438.8 6688452.8 11.2, 355436.1 6688452.5 11.2, 355434.7 6688466.4 11.2, 355433.4 6688487 11.2, 355435.3 6688486.5 11.2, 355442.5 6688484.9 11.2))
BATIMENT0000000302930196;Industriel, agricole ou commercial;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;;;6.0;5.4;11.4;15.2;7.5;Cadastre;C 0.9;POLYGON Z ((355471.4 6688478.4 11.4, 355472.5 6688469.6 11.4, 355473.2 6688462.5 11.4, 355465.5 6688461.5 11.4, 355465.3 6688464 11.4, 355459.4 6688463.6 11.4, 355457.8 6688481.5 11.4, 355471.4 6688478.4 11.4))
BATIMENT0000000302929624;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;40;40;9.1;6.8;16.0;24.0;7.3;Cadastre;A 1.0;POLYGON Z ((355407.4 6688476.7 16, 355416.6 6688477.5 16, 355421.9 6688478 16, 355422.7 6688466.7 16, 355408.4 6688465.5 16, 355407.4 6688476.7 16))
BATIMENT0000000302930195;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;6.0;5.4;11.4;18.0;7.4;Cadastre;C 0.5;POLYGON Z ((355477.2 6688477.1 11.4, 355477.7 6688470 11.4, 355472.5 6688469.6 11.4, 355471.4 6688478.4 11.4, 355477.2 6688477.1 11.4))
BATIMENT0000000302929622;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.6;5.3;10.9;13.5;7.0;Cadastre;A 1.0;POLYGON Z ((355422.7 6688466.7 10.9, 355421.9 6688478 10.9, 355421.6 6688481.4 10.9, 355420.8 6688489.8 10.9, 355433.4 6688487 10.9, 355434.7 6688466.4 10.9, 355422.8 6688465.6 10.9, 355422.7 6688466.7 10.9))
BATIMENT0000000302930052;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;23;16.0;6.9;23.0;24.6;7.5;Cadastre;A 1.0;POLYGON Z ((355386.4 6688486.9 23, 355387.6 6688473.9 23, 355379.1 6688473 23, 355373.9 6688472.3 23, 355372.9 6688484.2 23, 355372.8 6688485.6 23, 355386.4 6688486.9 23), (355378 6688477.7 23, 355380 6688477.8 23, 355379.8 6688479.3 23, 355379 6688479.2 23, 355378.9 6688480.2 23, 355379.9 6688480.4 23, 355379.7 6688482 23, 355377.6 6688481.9 23, 355378 6688477.7 23))
BATIMENT0000000302929707;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;6.4;12.7;19.8;6.9;Cadastre;;POLYGON Z ((355343.2 6688470.5 12.7, 355340.1 6688508.7 12.7, 355340.4 6688508.7 12.7, 355341.1 6688508.5 12.7, 355344.2 6688470.2 12.7, 355345 6688460.2 12.7, 355344.3 6688460.1 12.7, 355344 6688460.1 12.7, 355343.2 6688470.5 12.7))
BATIMENT0000000302929704;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;6.4;12.5;25.5;7.2;Cadastre;;POLYGON Z ((355305.7 6688517 12.5, 355339.1 6688509 12.5, 355340.1 6688508.7 12.5, 355343.2 6688470.5 12.5, 355344 6688460.1 12.5, 355332.1 6688458.8 12.5, 355329.3 6688485.1 12.5, 355295.3 6688481.5 12.5, 355293.7 6688497.9 12.5, 355293.3 6688502.6 12.5, 355292.3 6688512.4 12.5, 355305.7 6688517 12.5))
BATIMENT0000000302930053;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;13;20;12.0;6.8;18.8;24.4;7.9;Cadastre;A 1.0;POLYGON Z ((355371.9 6688497.3 18.8, 355371.6 6688500.2 18.8, 355381.7 6688497.8 18.8, 355385.9 6688492.8 18.8, 355386.4 6688486.9 18.8, 355372.8 6688485.6 18.8, 355372.6 6688487.9 18.8, 355376.1 6688488 18.8, 355375.8 6688490.1 18.8, 355372.5 6688489.7 18.8, 355371.9 6688497.3 18.8))
BATIMENT0000000302929895;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;7.0;19.5;23.2;7.6;Cadastre;;POLYGON Z ((355348.1 6688747 19.5, 355346.4 6688745.3 19.5, 355339.2 6688746.6 19.5, 355338.6 6688748.4 19.5, 355348.1 6688747 19.5))
BATIMENT0000000302929896;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;7.0;21.4;24.6;8.2;Cadastre;;POLYGON Z ((355347.3 6688747.9 21.4, 355347.4 6688748.8 21.4, 355349.5 6688751.2 21.4, 355350.6 6688751.1 21.4, 355350.9 6688750.8 21.4, 355350.6 6688755.4 21.4, 355350.5 6688757 21.4, 355350.2 6688756.9 21.4, 355349.9 6688756.9 21.4, 355349.6 6688756.9 21.4, 355349.3 6688756.9 21.4, 355349.1 6688756.9 21.4, 355348.7 6688757 21.4, 355348.5 6688757.1 21.4, 355348.2 6688757.2 21.4, 355348.1 6688757.2 21.4, 355347.7 6688757.4 21.4, 355347.5 6688757.6 21.4, 355347.3 6688757.7 21.4, 355347.1 6688757.9 21.4, 355346.9 6688758.1 21.4, 355346.8 6688758.2 21.4, 355346.6 6688758.5 21.4, 355346.4 6688758.9 21.4, 355346.2 6688759.3 21.4, 355346.1 6688759.6 21.4, 355346 6688759.9 21.4, 355346 6688760 21.4, 355344.5 6688760 21.4, 355344.4 6688762.6 21.4, 355356.2 6688763.1 21.4, 355360.2 6688763.3 21.4, 355362.3 6688739.8 21.4, 355356.8 6688734.4 21.4, 355342.6 6688737.5 21.4, 355342.3 6688737.8 21.4, 355337.5 6688738.8 21.4, 355339.2 6688746.6 21.4, 355346.4 6688745.3 21.4, 355348.1 6688747 21.4, 355347.3 6688747.9 21.4))
BATIMENT0000000302929898;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.9;7.0;12.9;14.2;7.3;Cadastre;;POLYGON Z ((355315.7 6688766.9 12.9, 355318.6 6688766.9 12.9, 355318.7 6688761.5 12.9, 355318.7 6688761.4 12.9, 355315.1 6688761.3 12.9, 355315.7 6688766.9 12.9))
BATIMENT0000000302930172;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.5;7.8;11.3;14.5;8.1;Cadastre;C 0.3;POLYGON Z ((355383.7 6688761.2 11.3, 355387.1 6688775.3 11.3, 355385.9 6688775.7 11.3, 355388.8 6688789.9 11.3, 355405.6 6688786 11.3, 355405.4 6688785.2 11.3, 355402.7 6688772.3 11.3, 355404.8 6688771.9 11.3, 355403.6 6688766.5 11.3, 355399.2 6688746.4 11.3, 355383.2 6688749.8 11.3, 355385.5 6688760.8 11.3, 355383.7 6688761.2 11.3))
BATIMENT0000000302929897;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;7.0;12.7;27.6;8.2;Cadastre;;POLYGON Z ((355356.2 6688763.1 12.7, 355344.4 6688762.6 12.7, 355338.6 6688762.3 12.7, 355318.7 6688761.4 12.7, 355318.7 6688761.5 12.7, 355318.6 6688766.9 12.7, 355315.7 6688766.9 12.7, 355315.8 6688767.9 12.7, 355316.5 6688773 12.7, 355319.6 6688772.1 12.7, 355319.9 6688776.9 12.7, 355317 6688777.6 12.7, 355317.5 6688781.9 12.7, 355317.6 6688782.6 12.7, 355320.5 6688782.8 12.7, 355320.5 6688781.3 12.7, 355323.4 6688781.4 12.7, 355323.6 6688777.7 12.7, 355358.7 6688779.5 12.7, 355360.2 6688763.3 12.7, 355356.2 6688763.1 12.7))
BATIMENT0000000302929899;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;7.0;12.6;14.3;7.2;Cadastre;;POLYGON Z ((355319.6 6688772.1 12.6, 355316.5 6688773 12.6, 355316.6 6688773.8 12.6, 355317 6688777.6 12.6, 355319.9 6688776.9 12.6, 355319.6 6688772.1 12.6))
BATIMENT0000000302929623;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;12;20;18.8;5.6;24.4;29.1;7.4;Cadastre;A 1.0;POLYGON Z ((355407.4 6688476.7 24.4, 355406.4 6688488.1 24.4, 355410.9 6688492 24.4, 355420.8 6688489.8 24.4, 355421.6 6688481.4 24.4, 355417.8 6688481 24.4, 355416.3 6688480 24.4, 355416.6 6688477.5 24.4, 355407.4 6688476.7 24.4))
BATIMENT0000000302929986;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.0;3.6;23.6;24.0;7.4;Cadastre;;POLYGON Z ((355422.7 6688691 23.6, 355448 6688685.4 23.6, 355448 6688685.1 23.6, 355447.8 6688684.5 23.6, 355447.6 6688684 23.6, 355447.3 6688683.1 23.6, 355447.2 6688682.8 23.6, 355447.1 6688682.5 23.6, 355446.8 6688681.8 23.6, 355446.3 6688680.9 23.6, 355445.9 6688680.4 23.6, 355445.7 6688680 23.6, 355445.3 6688679.5 23.6, 355444.9 6688679.1 23.6, 355444.4 6688678.5 23.6, 355444.1 6688678.2 23.6, 355443.6 6688677.6 23.6, 355443.1 6688677.2 23.6, 355442.3 6688676.6 23.6, 355441.8 6688676.2 23.6, 355441.4 6688676 23.6, 355441 6688675.8 23.6, 355440.4 6688675.4 23.6, 355439.7 6688675.1 23.6, 355438.7 6688674.8 23.6, 355438.4 6688674.7 23.6, 355437.6 6688674.5 23.6, 355437 6688674.3 23.6, 355436.7 6688674.3 23.6, 355436.1 6688674.2 23.6, 355435.5 6688674.1 23.6, 355435.1 6688674.1 23.6, 355434.3 6688674.1 23.6, 355433.7 6688674.1 23.6, 355432.9 6688674.2 23.6, 355432.4 6688674.3 23.6, 355431.8 6688674.4 23.6, 355431 6688674.6 23.6, 355430.3 6688674.8 23.6, 355429.7 6688675 23.6, 355429.2 6688675.2 23.6, 355428.6 6688675.5 23.6, 355427.9 6688675.8 23.6, 355427.1 6688676.3 23.6, 355426 6688677.1 23.6, 355425.4 6688677.7 23.6, 355425 6688678.1 23.6, 355424.6 6688678.5 23.6, 355424.1 6688679 23.6, 355423.8 6688679.4 23.6, 355423.5 6688679.8 23.6, 355423.1 6688680.3 23.6, 355422.7 6688681 23.6, 355422.4 6688681.5 23.6, 355422 6688682.3 23.6, 355421.8 6688682.9 23.6, 355421.6 6688683.3 23.6, 355421.4 6688683.8 23.6, 355421.2 6688684.5 23.6, 355421.1 6688685.1 23.6, 355421 6688685.6 23.6, 355420.9 6688686.3 23.6, 355420.8 6688687.3 23.6, 355420.7 6688688.5 23.6, 355420.8 6688689.2 23.6, 355420.9 6688689.8 23.6, 355421 6688690.9 23.6, 355421.1 6688691.3 23.6, 355421.1 6688691.4 23.6, 355422.7 6688691 23.6))
BATIMENT0000000302929981;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;5.4;12.2;23.9;7.5;Cadastre;;POLYGON Z ((355420.4 6688691.9 12.2, 355423.9 6688707.7 12.2, 355422.5 6688708 12.2, 355422.5 6688708.4 12.2, 355427.2 6688707.4 12.2, 355449.3 6688702.5 12.2, 355489 6688693.7 12.2, 355488.9 6688693.3 12.2, 355487.5 6688693.6 12.2, 355484 6688677.9 12.2, 355485.4 6688677.5 12.2, 355485.4 6688677.1 12.2, 355450.7 6688684.8 12.2, 355448 6688685.4 12.2, 355422.7 6688691 12.2, 355421.1 6688691.4 12.2, 355421.1 6688691.3 12.2, 355418.9 6688691.8 12.2, 355419 6688692.2 12.2, 355420.4 6688691.9 12.2))
BATIMENT0000000302929984;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;5.8;21.2;23.5;7.5;Cadastre;;POLYGON Z ((355422.5 6688708 21.2, 355423.9 6688707.7 21.2, 355420.4 6688691.9 21.2, 355419 6688692.2 21.2, 355422.5 6688708 21.2))
BATIMENT0000000302929979;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.4;5.5;22.9;24.9;7.5;Cadastre;;POLYGON Z ((355449.3 6688702.5 22.9, 355427.2 6688707.4 22.9, 355431.7 6688718.9 22.9, 355434 6688725.2 22.9, 355434.2 6688725.6 22.9, 355434.6 6688726.4 22.9, 355434.9 6688726.8 22.9, 355435.3 6688727.4 22.9, 355435.5 6688727.7 22.9, 355435.9 6688728.1 22.9, 355436.3 6688728.5 22.9, 355436.7 6688728.9 22.9, 355437.1 6688729.2 22.9, 355437.7 6688729.6 22.9, 355438.1 6688729.8 22.9, 355438.7 6688730.1 22.9, 355439.3 6688730.3 22.9, 355439.9 6688730.5 22.9, 355440.4 6688730.6 22.9, 355440.9 6688730.7 22.9, 355441.4 6688730.8 22.9, 355442.7 6688736.5 22.9, 355447.5 6688735.4 22.9, 355446.3 6688729.7 22.9, 355446.6 6688729.5 22.9, 355446.8 6688729.4 22.9, 355447.2 6688729.1 22.9, 355447.9 6688728.6 22.9, 355448.3 6688728.1 22.9, 355448.8 6688727.6 22.9, 355449.1 6688727.2 22.9, 355449.6 6688726.4 22.9, 355449.8 6688726 22.9, 355450 6688725.4 22.9, 355450.2 6688724.9 22.9, 355450.3 6688724.5 22.9, 355450.5 6688723.6 22.9, 355450.6 6688722.7 22.9, 355450.7 6688722.4 22.9, 355450.7 6688722.2 22.9, 355450.1 6688714.6 22.9, 355449.3 6688702.5 22.9), (355438.7 6688720.1 22.9, 355444.1 6688718.8 22.9, 355444.4 6688722.4 22.9, 355440.1 6688723.4 22.9, 355438.7 6688720.1 22.9))
BATIMENT0000000302929983;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.4;7.0;25.5;26.7;7.4;Cadastre;;POLYGON Z ((355444.4 6688722.4 25.5, 355444.1 6688718.8 25.5, 355438.7 6688720.1 25.5, 355440.1 6688723.4 25.5, 355444.4 6688722.4 25.5))
BATIMENT0000000302929982;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;22.3;5.5;27.8;28.2;7.6;Cadastre;;POLYGON Z ((355448.8 6688741.1 27.8, 355447.5 6688735.4 27.8, 355442.7 6688736.5 27.8, 355444 6688742.2 27.8, 355448.8 6688741.1 27.8))
BATIMENT0000000302930174;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.5;7.8;11.3;;;Cadastre;C 0.3;POLYGON Z ((355436.9 6688763.8 11.3, 355434 6688750.2 11.3, 355407.1 6688756.1 11.3, 355409.1 6688765.3 11.3, 355403.6 6688766.5 11.3, 355404.8 6688771.9 11.3, 355436.9 6688763.8 11.3))
BATIMENT0000000302930173;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;7.4;19.7;30.2;7.8;Cadastre;;POLYGON Z ((355416.7 6688783.2 19.7, 355439.5 6688776.9 19.7, 355436.9 6688763.8 19.7, 355404.8 6688771.9 19.7, 355402.7 6688772.3 19.7, 355405.6 6688786 19.7, 355416.7 6688783.2 19.7))
BATIMENT0000000302930175;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;7.5;17.2;23.5;7.8;Cadastre;;POLYGON Z ((355418.2 6688788.7 17.2, 355416.7 6688783.2 17.2, 355405.6 6688786 17.2, 355406.9 6688792 17.2, 355418.2 6688788.7 17.2))
BATIMENT0000000302929985;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;5.3;11.6;12.2;6.6;Cadastre;;POLYGON Z ((355484 6688677.9 11.6, 355487.5 6688693.6 11.6, 355488.9 6688693.3 11.6, 355485.4 6688677.5 11.6, 355484 6688677.9 11.6))
BATIMENT0000000302929528;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.8;7.0;30.8;35.5;7.6;Cadastre;;POLYGON Z ((355592.3 6688716 30.8, 355589.6 6688704.4 30.8, 355591.4 6688704 30.8, 355599.1 6688702.1 30.8, 355596 6688687.7 30.8, 355581.5 6688691 30.8, 355571.5 6688693.2 30.8, 355544.8 6688699.3 30.8, 355543.7 6688694.8 30.8, 355536.6 6688696.3 30.8, 355532.5 6688697.2 30.8, 355520.6 6688699.9 30.8, 355461.1 6688713.1 30.8, 355463.3 6688723.3 30.8, 355466.1 6688735.9 30.8, 355548.7 6688717.7 30.8, 355547.9 6688713.9 30.8, 355572.9 6688708.2 30.8, 355575.4 6688719.9 30.8, 355592.3 6688716 30.8))
BATIMENT0000000302929535;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.3;7.5;22.8;24.8;8.0;Cadastre;;POLYGON Z ((355538.2 6688728.8 22.8, 355468 6688744.1 22.8, 355486.5 6688826.4 22.8, 355495.9 6688824.2 22.8, 355501.6 6688822.9 22.8, 355509.5 6688821 22.8, 355509.8 6688822.6 22.8, 355515.4 6688819.6 22.8, 355556.5 6688810.2 22.8, 355545.7 6688761.9 22.8, 355545.8 6688754.2 22.8, 355543.8 6688754.5 22.8, 355543.2 6688751.8 22.8, 355542.8 6688750.2 22.8, 355542.6 6688748.9 22.8, 355538.2 6688728.8 22.8))
BATIMENT0000000302929540;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;6.9;14.7;42.5;8.4;Cadastre;;POLYGON Z ((355500.2 6688842.1 14.7, 355505.6 6688840.9 14.7, 355501.6 6688822.9 14.7, 355495.9 6688824.2 14.7, 355500.2 6688842.1 14.7))
BATIMENT0000000302930178;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;41.6;8.1;49.7;56.3;8.5;Cadastre;;POLYGON Z ((355485.1 6688850.5 49.7, 355484.2 6688845.7 49.7, 355483.4 6688842.4 49.7, 355471.4 6688845.2 49.7, 355472.8 6688853.5 49.7, 355485.1 6688850.5 49.7))
BATIMENT0000000302930176;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;44.0;7.8;51.8;56.2;11.4;Cadastre;;POLYGON Z ((355413.8 6688885.9 51.8, 355414.5 6688889 51.8, 355472.7 6688876 51.8, 355491.7 6688961.2 51.8, 355494.4 6688960.7 51.8, 355507.7 6688957.6 51.8, 355503.4 6688938.2 51.8, 355502 6688931.5 51.8, 355495.7 6688903 51.8, 355494.2 6688896.3 51.8, 355501.9 6688894.6 51.8, 355510.3 6688892.8 51.8, 355519.1 6688890.2 51.8, 355516.4 6688875.3 51.8, 355490 6688881.4 51.8, 355486.9 6688866.5 51.8, 355481.2 6688868.4 51.8, 355480.4 6688863.1 51.8, 355570.8 6688842.9 51.8, 355572.1 6688846.8 51.8, 355576.4 6688845.8 51.8, 355575 6688830.9 51.8, 355572.2 6688829.4 51.8, 355568.6 6688830.2 51.8, 355567.6 6688827.1 51.8, 355567 6688827.2 51.8, 355505.6 6688840.9 51.8, 355500.2 6688842.1 51.8, 355484.2 6688845.7 51.8, 355485.1 6688850.5 51.8, 355472.8 6688853.5 51.8, 355471.4 6688845.2 51.8, 355449.6 6688746.6 51.8, 355434 6688750.2 51.8, 355436.9 6688763.8 51.8, 355439.5 6688776.9 51.8, 355452.9 6688837.2 51.8, 355456.8 6688855.1 51.8, 355457.4 6688857.7 51.8, 355462.5 6688856.8 51.8, 355463.7 6688861.6 51.8, 355422.8 6688869.9 51.8, 355410.8 6688872.4 51.8, 355412.3 6688879.4 51.8, 355413.8 6688885.9 51.8))
BATIMENT0000000302929549;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;8.0;23.2;43.2;10.1;Cadastre;;POLYGON Z ((355572.1 6688846.8 23.2, 355537.2 6688854.6 23.2, 355514.5 6688859.7 23.2, 355515.1 6688862.7 23.2, 355577.1 6688849 23.2, 355576.7 6688847.2 23.2, 355576.4 6688845.8 23.2, 355572.1 6688846.8 23.2))
BATIMENT0000000302929545;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;10.6;14.7;17.0;11.8;Cadastre;;POLYGON Z ((355549.2 6688894 14.7, 355556.1 6688892.4 14.7, 355553.9 6688883.1 14.7, 355547.1 6688884.6 14.7, 355549.2 6688894 14.7))
BATIMENT0000000327821899;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;5.4;10.4;;24.7;11.6;Imagerie aérienne;;POLYGON Z ((355536.5 6688895.2 15.8, 355534.7 6688887.4 15.8, 355525.4 6688889.4 15.8, 355525.9 6688891.8 15.8, 355523.5 6688892.4 15.8, 355524.7 6688898.1 15.8, 355536.5 6688895.2 15.8))
BATIMENT0000000302929544;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;10.9;15.3;41.9;11.4;Cadastre;;POLYGON Z ((355510.3 6688892.8 15.3, 355510.7 6688894.7 15.3, 355510.6 6688895.3 15.3, 355511.3 6688896.2 15.3, 355512.2 6688897.1 15.3, 355513.2 6688897.9 15.3, 355514.4 6688898.6 15.3, 355515.7 6688899.3 15.3, 355516.8 6688899.7 15.3, 355517.7 6688899.9 15.3, 355518.5 6688900.1 15.3, 355519.2 6688900.2 15.3, 355519.2 6688899.6 15.3, 355523.1 6688898.7 15.3, 355521.3 6688890.3 15.3, 355510.3 6688892.8 15.3))
BATIMENT0000000327821779;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;1968-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;17.0;2.0;35;40;7.2;6.8;;22.5;7.1;Imagerie aérienne;C 0.2;POLYGON Z ((355295.5 6688767.5 14, 355295.7 6688769.3 14, 355300.2 6688815.4 14, 355310.9 6688814.2 14, 355306.2 6688766.4 14, 355295.5 6688767.5 14))
BATIMENT0000000302929874;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;7.5;22.4;22.7;7.9;Cadastre;;POLYGON Z ((355355 6688798.4 22.4, 355326.3 6688796 22.4, 355324.7 6688816.3 22.4, 355326.4 6688816.1 22.4, 355352.7 6688817.3 22.4, 355353.4 6688817.3 22.4, 355355 6688798.4 22.4))
BATIMENT0000000302929875;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.5;6.8;22.3;22.7;7.8;Cadastre;;POLYGON Z ((355326.4 6688816.1 22.3, 355324.7 6688816.3 22.3, 355324.1 6688824.3 22.3, 355320.5 6688824.1 22.3, 355321 6688829.2 22.3, 355343 6688830.4 22.3, 355343.1 6688831.3 22.3, 355351.5 6688831.8 22.3, 355352.7 6688817.3 22.3, 355326.4 6688816.1 22.3))
BATIMENT0000000302929876;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.2;6.7;22.0;22.5;7.5;Cadastre;;POLYGON Z ((355321 6688829.2 22, 355343.1 6688831.3 22, 355343 6688830.4 22, 355321 6688829.2 22))
BATIMENT0000000302929879;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;24.2;6.0;30.2;32.6;7.6;Cadastre;A 1.0;POLYGON Z ((355297.2 6688901 30.2, 355311.3 6688906.7 30.2, 355312.3 6688907.2 30.2, 355316.9 6688909.9 30.2, 355337 6688866.4 30.2, 355305.9 6688852 30.2, 355299.7 6688863.7 30.2, 355308.6 6688867.4 30.2, 355307.6 6688869.4 30.2, 355312 6688871.2 30.2, 355305.6 6688884 30.2, 355304.5 6688883.4 30.2, 355306.1 6688880.2 30.2, 355302.9 6688878.8 30.2, 355300.5 6688884.1 30.2, 355304.6 6688886.1 30.2, 355297.2 6688901 30.2))
BATIMENT0000000302930181;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;7.4;19.5;45.2;7.7;Cadastre;;POLYGON Z ((355383.1 6688917.4 19.5, 355376.6 6688886.4 19.5, 355364.9 6688889.2 19.5, 355371.7 6688920 19.5, 355383.1 6688917.4 19.5))
BATIMENT0000000302929883;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1888-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;10;20;7.5;6.9;14.4;21.5;7.6;Cadastre;B 0.9;POLYGON Z ((355323.8 6688914 14.4, 355321.1 6688912.4 14.4, 355316.9 6688909.9 14.4, 355312.3 6688907.2 14.4, 355311.3 6688906.7 14.4, 355311 6688907.5 14.4, 355312.1 6688908.1 14.4, 355309.7 6688912.1 14.4, 355306.9 6688910.7 14.4, 355306.9 6688909.9 14.4, 355298.5 6688910.2 14.4, 355298.4 6688909.8 14.4, 355290.1 6688906 14.4, 355288.3 6688915 14.4, 355295.8 6688915.6 14.4, 355304.8 6688916 14.4, 355319 6688923 14.4, 355323.8 6688914 14.4))
BATIMENT0000000302930182;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;38.2;8.0;46.2;48.0;8.2;Cadastre;C 0.1;POLYGON Z ((355404.7 6688958.2 46.2, 355396.9 6688924.8 46.2, 355409.9 6688921.7 46.2, 355409.3 6688916.5 46.2, 355402.8 6688888.3 46.2, 355413.8 6688885.9 46.2, 355412.3 6688879.4 46.2, 355401.3 6688881.9 46.2, 355400.3 6688877 46.2, 355375.8 6688882.3 46.2, 355376.6 6688886.4 46.2, 355383.1 6688917.4 46.2, 355371.7 6688920 46.2, 355379.3 6688953.9 46.2, 355383 6688971 46.2, 355383.2 6688971.5 46.2, 355383.7 6688973.9 46.2, 355384.1 6688976 46.2, 355407.5 6688970.4 46.2, 355404.5 6688958.2 46.2, 355404.7 6688958.2 46.2))
BATIMENT0000000302929886;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;20;20;18.3;6.9;25.2;28.5;7.9;Cadastre;A 1.0;POLYGON Z ((355300.4 6688942.5 25.2, 355300.8 6688942.5 25.2, 355301 6688942.3 25.2, 355308.4 6688943.5 25.2, 355319 6688923 25.2, 355304.8 6688916 25.2, 355304 6688919.6 25.2, 355300.4 6688942.5 25.2), (355304.4 6688925.4 25.2, 355306.3 6688925.7 25.2, 355306 6688927.4 25.2, 355304.2 6688927.2 25.2, 355304.4 6688925.4 25.2))
BATIMENT0000000302930100;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.6;7.8;29.5;45.6;8.3;Cadastre;;POLYGON Z ((355383.2 6688971.5 29.5, 355383 6688971 29.5, 355377.6 6688972.2 29.5, 355379.4 6688980.4 29.5, 355383.3 6688979.5 29.5, 355382.1 6688974.2 29.5, 355383.7 6688973.9 29.5, 355383.2 6688971.5 29.5))
BATIMENT0000000302930198;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;7.7;15.6;33.2;8.6;Cadastre;;POLYGON Z ((355415.9 6688840.7 15.6, 355416.2 6688840.6 15.6, 355418 6688847.7 15.6, 355452.9 6688837.2 15.6, 355439.5 6688776.9 15.6, 355416.7 6688783.2 15.6, 355418.2 6688788.7 15.6, 355406.9 6688792 15.6, 355405.2 6688792.6 15.6, 355415.9 6688840.7 15.6))
BATIMENT0000000302930197;Chapelle;Religieux;;Non;En service;2012-06-19 19:05:58;2012-10-24 11:04:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.7;7.8;26.5;;;Cadastre;;POLYGON Z ((355416.6 6688859.6 26.5, 355418.1 6688859.1 26.5, 355418.9 6688863.2 26.5, 355421.4 6688862.7 26.5, 355456.8 6688855.1 26.5, 355452.9 6688837.2 26.5, 355418 6688847.7 26.5, 355415.9 6688848.4 26.5, 355416.6 6688852.3 26.5, 355415.1 6688852.8 26.5, 355416.6 6688859.6 26.5))
BATIMENT0000000302930199;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.4;8.0;30.5;53.2;8.8;Cadastre;;POLYGON Z ((355463.7 6688861.6 30.5, 355462.5 6688856.8 30.5, 355457.4 6688857.7 30.5, 355456.8 6688855.1 30.5, 355421.4 6688862.7 30.5, 355422.8 6688869.9 30.5, 355463.7 6688861.6 30.5))
BATIMENT0000000302930083;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;32.2;8.5;40.7;49.7;8.7;Cadastre;;POLYGON Z ((355470.7 6688886.4 40.7, 355469.3 6688879.7 40.7, 355458.4 6688882.1 40.7, 355458.7 6688883.5 40.7, 355458.9 6688884.2 40.7, 355459 6688884.3 40.7, 355459.1 6688884.3 40.7, 355459.2 6688884.3 40.7, 355459.3 6688884.4 40.7, 355459.5 6688884.4 40.7, 355459.6 6688884.5 40.7, 355459.7 6688884.5 40.7, 355459.8 6688884.6 40.7, 355459.9 6688884.6 40.7, 355460 6688884.7 40.7, 355460.1 6688884.7 40.7, 355460.2 6688884.7 40.7, 355460.3 6688884.8 40.7, 355460.4 6688884.8 40.7, 355460.5 6688884.8 40.7, 355460.6 6688884.9 40.7, 355460.7 6688885 40.7, 355460.8 6688885 40.7, 355461.1 6688885.2 40.7, 355461.2 6688885.2 40.7, 355461.3 6688885.2 40.7, 355461.5 6688885.4 40.7, 355461.6 6688885.4 40.7, 355461.8 6688885.5 40.7, 355461.9 6688885.6 40.7, 355462 6688885.6 40.7, 355462.1 6688885.6 40.7, 355462.1 6688885.7 40.7, 355462.2 6688885.7 40.7, 355462.2 6688885.8 40.7, 355462.3 6688885.8 40.7, 355462.4 6688885.8 40.7, 355462.5 6688885.9 40.7, 355462.6 6688886 40.7, 355462.7 6688886 40.7, 355462.7 6688886.1 40.7, 355462.8 6688886.1 40.7, 355462.9 6688886.2 40.7, 355463 6688886.2 40.7, 355463.2 6688886.3 40.7, 355463.2 6688886.4 40.7, 355463.3 6688886.4 40.7, 355463.3 6688886.5 40.7, 355463.4 6688886.6 40.7, 355463.5 6688886.6 40.7, 355463.6 6688886.8 40.7, 355463.6 6688886.9 40.7, 355463.7 6688887 40.7, 355463.8 6688887.1 40.7, 355463.9 6688887.2 40.7, 355464.1 6688887.3 40.7, 355464.4 6688887.6 40.7, 355464.5 6688887.6 40.7, 355464.6 6688887.7 40.7, 355464.7 6688887.8 40.7, 355464.8 6688887.7 40.7, 355470.7 6688886.4 40.7))
BATIMENT0000000302930079;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;13.9;;;;Cadastre;;POLYGON Z ((355428.9 6688906.4 -1000, 355430.9 6688915.3 -1000, 355435.1 6688914.4 -1000, 355436.4 6688914.1 -1000, 355435.6 6688910.7 -1000, 355434.7 6688906.6 -1000, 355434.4 6688905.3 -1000, 355432.5 6688905.7 -1000, 355428.9 6688906.4 -1000))
BATIMENT0000000302930080;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;13.2;;;;Cadastre;;POLYGON Z ((355430.9 6688915.3 -1000, 355435.5 6688935.7 -1000, 355441 6688934.6 -1000, 355437.9 6688920.7 -1000, 355436.4 6688914.1 -1000, 355435.1 6688914.4 -1000, 355430.9 6688915.3 -1000))
BATIMENT0000002011294921;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-07-01 11:20:02;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;2.0;;;5.7;13.4;;;;Imagerie aérienne;C 0.3;POLYGON Z ((355450 6688923.3 19.1, 355455.2 6688947 19.1, 355472.9 6688943.3 19.1, 355467.3 6688919.4 19.1, 355450 6688923.3 19.1))
BATIMENT0000002011294518;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-07-01 11:20:02;1991-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;6.0;10.8;;;;Imagerie aérienne;A 1.0;POLYGON Z ((355468.5 6688947.1 16.8, 355469.7 6688953.4 16.8, 355462 6688954.9 16.8, 355460.7 6688948.8 16.6, 355455.9 6688949.9 16.6, 355458.5 6688961.9 16.6, 355475.9 6688958.1 16.6, 355473.2 6688946.1 16.6, 355468.5 6688947.1 16.8))
BATIMENT0000000302930190;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;7.8;15.5;22.7;9.2;Cadastre;;POLYGON Z ((355416.4 6688914.9 15.5, 355409.3 6688916.5 15.5, 355409.9 6688921.7 15.5, 355396.9 6688924.8 15.5, 355404.7 6688958.2 15.5, 355404.5 6688958.2 15.5, 355407.5 6688970.4 15.5, 355384.1 6688976 15.5, 355386.4 6688986.2 15.5, 355401.5 6688982.7 15.5, 355402 6688984.1 15.5, 355408.9 6688991.5 15.5, 355406.5 6688994.1 15.5, 355410.9 6688999.2 15.5, 355413.1 6689000.7 15.5, 355416.3 6689002.7 15.5, 355417.1 6689003.2 15.5, 355417.9 6689003.6 15.5, 355418.5 6689003.9 15.5, 355418.9 6689004.1 15.5, 355419.1 6689004.2 15.5, 355419.6 6689004.3 15.5, 355419.8 6689004.4 15.5, 355420 6689004.5 15.5, 355420.8 6689004.8 15.5, 355421.1 6689004.8 15.5, 355421.5 6689004.9 15.5, 355421.9 6689005 15.5, 355423.1 6689005.3 15.5, 355423.3 6689005.3 15.5, 355423.8 6689005.3 15.5, 355424.3 6689005.4 15.5, 355424.7 6689005.4 15.5, 355425.2 6689005.4 15.5, 355426 6689005.5 15.5, 355426.4 6689005.5 15.5, 355426.7 6689005.5 15.5, 355426.9 6689005.4 15.5, 355427.1 6689005.4 15.5, 355427.7 6689005.2 15.5, 355428.1 6689005.1 15.5, 355428.3 6689005 15.5, 355428.5 6689004.8 15.5, 355428.6 6689004.7 15.5, 355428.7 6689004.5 15.5, 355429.3 6689003 15.5, 355429.6 6689002.9 15.5, 355430.2 6688999.7 15.5, 355434.9 6688998.4 15.5, 355426.4 6688960.4 15.5, 355416.4 6688914.9 15.5))
BATIMENT0000000302931549;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;19.2;6.5;25.7;28.9;7.2;Cadastre;A 1.0;POLYGON Z ((355393.2 6689089.6 25.7, 355396.8 6689091.5 25.7, 355398.2 6689088.7 25.7, 355399.9 6689088.2 25.7, 355401.8 6689089 25.7, 355401.7 6689089.1 25.7, 355401.7 6689089.4 25.7, 355401.7 6689089.7 25.7, 355401.8 6689089.9 25.7, 355401.9 6689090.1 25.7, 355402.2 6689090.4 25.7, 355402.5 6689090.5 25.7, 355402.8 6689090.5 25.7, 355403.1 6689090.5 25.7, 355403.3 6689090.3 25.7, 355403.5 6689090.2 25.7, 355403.6 6689090 25.7, 355404.9 6689090.7 25.7, 355405.7 6689092.2 25.7, 355403.9 6689095.3 25.7, 355407.7 6689097.3 25.7, 355416.3 6689081 25.7, 355411.9 6689078.7 25.7, 355412.2 6689078.5 25.7, 355405.9 6689075.2 25.7, 355405.8 6689075.4 25.7, 355401.7 6689073.5 25.7, 355393.2 6689089.6 25.7))
BATIMENT0000000302929543;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;10.4;14.6;41.6;11.1;Cadastre;;POLYGON Z ((355498.4 6688902.2 14.6, 355508.7 6688910.2 14.6, 355512.4 6688905.1 14.6, 355502.3 6688897.7 14.6, 355501.9 6688894.6 14.6, 355494.2 6688896.3 14.6, 355495.7 6688903 14.6, 355498.4 6688902.2 14.6))
BATIMENT0000000327821780;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;9.1;9.1;;18.4;10.9;Imagerie aérienne;;POLYGON Z ((355558.5 6688917.3 18.2, 355555 6688901.4 18.2, 355524.8 6688908.1 18.2, 355528.2 6688923.7 18.2, 355558.5 6688917.3 18.2))
BATIMENT0000000302930094;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;10.3;14.3;14.7;11.0;Cadastre;;POLYGON Z ((355513.1 6688935.8 14.3, 355511.7 6688929.5 14.3, 355502 6688931.5 14.3, 355503.4 6688938.2 14.3, 355513.1 6688935.8 14.3))
BATIMENT0000000302930093;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.7;8.0;19.7;23.4;10.6;Cadastre;;POLYGON Z ((355516.9 6688975 19.7, 355527.1 6688972.8 19.7, 355545.4 6688968.9 19.7, 355547.5 6688971.8 19.7, 355552 6688969.4 19.7, 355551.6 6688967.4 19.7, 355553.2 6688967.1 19.7, 355556.4 6688966.2 19.7, 355556.3 6688964.7 19.7, 355555.2 6688959.7 19.7, 355553.5 6688952 19.7, 355552.7 6688947.7 19.7, 355565.5 6688944.9 19.7, 355561.2 6688925.5 19.7, 355531.6 6688931.8 19.7, 355535.8 6688951.4 19.7, 355534.1 6688951.9 19.7, 355511.5 6688956.9 19.7, 355510.1 6688957.1 19.7, 355507.7 6688957.6 19.7, 355494.4 6688960.7 19.7, 355496.1 6688968.6 19.7, 355493.3 6688969.2 19.7, 355495 6688976.5 19.7, 355495.7 6688979.7 19.7, 355497.3 6688986.8 19.7, 355504.6 6688985.2 19.7, 355503.7 6688980.9 19.7, 355503.1 6688978 19.7, 355516.9 6688975 19.7))
BATIMENT0000000302930092;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;9.9;24.7;32.7;10.3;Cadastre;;POLYGON Z ((355491.7 6688961.2 24.7, 355493.3 6688969.2 24.7, 355496.1 6688968.6 24.7, 355494.4 6688960.7 24.7, 355491.7 6688961.2 24.7))
BATIMENT0000000302930099;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;9.3;23.5;26.9;10.4;Cadastre;;POLYGON Z ((355507.3 6688993.2 23.5, 355506.5 6688993.4 23.5, 355506 6688991.5 23.5, 355504.6 6688985.2 23.5, 355497.3 6688986.8 23.5, 355499 6688993.1 23.5, 355500.3 6688998.4 23.5, 355487.7 6689001.3 23.5, 355489.9 6689012.6 23.5, 355494.6 6689011.5 23.5, 355495 6689014.1 23.5, 355535.3 6689005.2 23.5, 355538 6689001.3 23.5, 355559.8 6688968.8 23.5, 355552.3 6688970.7 23.5, 355552 6688969.4 23.5, 355547.5 6688971.8 23.5, 355545.4 6688968.9 23.5, 355527.1 6688972.8 23.5, 355530.5 6688988.3 23.5, 355520.3 6688990.5 23.5, 355507.3 6688993.2 23.5))
BATIMENT0000000302930267;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.2;8.0;26.2;27.1;10.0;Cadastre;;POLYGON Z ((355495 6689014.1 26.2, 355494.6 6689011.5 26.2, 355489.9 6689012.6 26.2, 355490.5 6689015.1 26.2, 355495 6689014.1 26.2))
BATIMENT0000000302931027;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;14.3;7.2;21.5;24.9;7.6;Cadastre;A 1.0;POLYGON Z ((355521.8 6689159.2 21.5, 355530.3 6689140.2 21.5, 355521.5 6689135.6 21.5, 355516.5 6689146.6 21.5, 355513.8 6689152.5 21.5, 355514.3 6689152.7 21.5, 355513 6689156.3 21.5, 355521.8 6689159.2 21.5))
BATIMENT0000000302931026;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.9;7.0;24.9;28.8;7.9;Cadastre;C 0.2;POLYGON Z ((355515.7 6689132.6 24.9, 355515 6689133.8 24.9, 355506.3 6689129.4 24.9, 355490.5 6689160.3 24.9, 355507.2 6689168.6 24.9, 355509 6689163.7 24.9, 355512 6689164.8 24.9, 355514.1 6689158.7 24.9, 355513 6689156.3 24.9, 355514.3 6689152.7 24.9, 355513.8 6689152.5 24.9, 355516.5 6689146.6 24.9, 355521.5 6689135.6 24.9, 355521.3 6689135.5 24.9, 355515.7 6689132.6 24.9))
BATIMENT0000000302931031;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;13.4;7.2;20.6;23.6;7.9;Cadastre;A 1.0;POLYGON Z ((355533 6689162.7 20.6, 355538.9 6689144.8 20.6, 355530.3 6689140.2 20.6, 355521.8 6689159.2 20.6, 355533 6689162.7 20.6))
BATIMENT0000000302931575;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.9;6.0;25.0;28.6;6.9;Cadastre;A 1.0;POLYGON Z ((355312.3 6689027.2 25, 355306.3 6689038.3 25, 355309.7 6689040 25, 355307 6689045 25, 355313.3 6689048.2 25, 355321.7 6689032 25, 355312.3 6689027.2 25))
BATIMENT0000000302931577;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;15.4;6.8;22.2;;;Cadastre;A 1.0;POLYGON Z ((355318.8 6689051.1 22.2, 355324.6 6689054 22.2, 355327.7 6689055.6 22.2, 355336 6689039.4 22.2, 355321.7 6689032 22.2, 355313.3 6689048.2 22.2, 355318.8 6689051.1 22.2), (355317.7 6689046.1 22.2, 355319.3 6689046.9 22.2, 355320.3 6689048.2 22.2, 355320.7 6689048.6 22.2, 355321.1 6689048.9 22.2, 355321.5 6689049.1 22.2, 355321.9 6689049.4 22.2, 355322.4 6689049.6 22.2, 355322.9 6689049.7 22.2, 355323.4 6689049.8 22.2, 355323.9 6689049.9 22.2, 355324.4 6689049.9 22.2, 355324.9 6689049.9 22.2, 355325.4 6689049.9 22.2, 355326.4 6689050.4 22.2, 355325.5 6689052.3 22.2, 355316.7 6689047.9 22.2, 355317.7 6689046.1 22.2))
BATIMENT0000000302931578;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1649-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;18.0;5.2;23.2;25.0;6.6;Cadastre;A 1.0;POLYGON Z ((355336 6689039.4 23.2, 355327.7 6689055.6 23.2, 355333.3 6689058.3 23.2, 355333.7 6689057.5 23.2, 355331 6689056.1 23.2, 355331.8 6689054.3 23.2, 355332.3 6689053.5 23.2, 355333.2 6689053.3 23.2, 355334.2 6689053.8 23.2, 355334.6 6689054.7 23.2, 355337.6 6689056.5 23.2, 355338.6 6689056.3 23.2, 355339.8 6689056.6 23.2, 355340.2 6689057.8 23.2, 355338.9 6689060.1 23.2, 355338.5 6689061 23.2, 355342.4 6689063 23.2, 355350.6 6689046.9 23.2, 355336 6689039.4 23.2))
BATIMENT0000000302931580;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;18.2;5.6;23.9;26.4;6.5;Cadastre;A 1.0;POLYGON Z ((355350.6 6689046.9 23.9, 355342.4 6689063 23.9, 355345.2 6689064.5 23.9, 355345.2 6689064.6 23.9, 355346.6 6689061.8 23.9, 355347.1 6689061.5 23.9, 355348.4 6689061.9 23.9, 355348.4 6689062.6 23.9, 355349 6689063.3 23.9, 355352 6689064.8 23.9, 355352.7 6689064.9 23.9, 355353.2 6689064.3 23.9, 355354.8 6689065.2 23.9, 355355.1 6689066.1 23.9, 355354.2 6689068.3 23.9, 355351.2 6689067 23.9, 355351 6689067.6 23.9, 355353.5 6689069 23.9, 355356.8 6689070.7 23.9, 355358.3 6689067.9 23.9, 355359.2 6689066.2 23.9, 355365.2 6689054.3 23.9, 355350.6 6689046.9 23.9))
BATIMENT0000000302931576;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;12;20;15.5;6.9;22.4;;;Cadastre;A 1.0;POLYGON Z ((355319.1 6689071.8 22.4, 355327.7 6689055.6 22.4, 355324.6 6689054 22.4, 355322.8 6689057.5 22.4, 355321.3 6689056.8 22.4, 355320.5 6689055.8 22.4, 355319 6689054.6 22.4, 355319.5 6689053.6 22.4, 355318.6 6689053.2 22.4, 355318.1 6689054.3 22.4, 355316.9 6689054.1 22.4, 355315.6 6689054.1 22.4, 355314.2 6689053.3 22.4, 355315.2 6689051.4 22.4, 355317.8 6689052.6 22.4, 355318.8 6689051.1 22.4, 355313.3 6689048.2 22.4, 355304.7 6689064.3 22.4, 355319.1 6689071.8 22.4))
BATIMENT0000000302931582;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;15;20;17.6;5.8;23.5;25.3;6.6;Cadastre;A 1.0;POLYGON Z ((355381 6689062.6 23.5, 355365.2 6689054.3 23.5, 355359.2 6689066.2 23.5, 355362.2 6689067.7 23.5, 355361.6 6689068.7 23.5, 355360.5 6689069.1 23.5, 355358.3 6689067.9 23.5, 355356.8 6689070.7 23.5, 355372.4 6689078.7 23.5, 355381 6689062.6 23.5))
BATIMENT0000000302931579;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;17.8;5.1;23.0;25.1;6.1;Cadastre;A 1.0;POLYGON Z ((355333.9 6689079.3 23, 355342.4 6689063 23, 355338.5 6689061 23, 355338.9 6689060.1 23, 355336.8 6689059.1 23, 355336.3 6689059.9 23, 355335.8 6689061.1 23, 355337.8 6689062.3 23, 355336.4 6689064.7 23, 355335.5 6689065.2 23, 355334.5 6689064.7 23, 355334 6689063.4 23, 355331.6 6689062 23, 355330.6 6689061.8 23, 355330.1 6689062.3 23, 355328.9 6689061.9 23, 355328.7 6689060.3 23, 355329.9 6689058.3 23, 355334.6 6689060.5 23, 355335.3 6689059.4 23, 355333.3 6689058.3 23, 355327.7 6689055.6 23, 355319.1 6689071.8 23, 355333.9 6689079.3 23))
BATIMENT0000000302931581;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;10;20;18.2;5.4;23.7;26.6;6.3;Cadastre;A 1.0;POLYGON Z ((355348.1 6689086.7 23.7, 355351.5 6689080.7 23.7, 355355.4 6689073.3 23.7, 355356.8 6689070.7 23.7, 355353.5 6689069 23.7, 355352 6689071.7 23.7, 355351.3 6689072.2 23.7, 355350.1 6689071.7 23.7, 355345 6689069.5 23.7, 355343.9 6689068.7 23.7, 355343.9 6689067.4 23.7, 355345.2 6689064.6 23.7, 355345.2 6689064.5 23.7, 355342.4 6689063 23.7, 355333.9 6689079.3 23.7, 355348.1 6689086.7 23.7))
BATIMENT0000000302931547;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;20;17.6;6.4;24.0;27.5;6.9;Cadastre;A 1.0;POLYGON Z ((355385.5 6689085.6 24, 355388.2 6689087 24, 355393.2 6689089.6 24, 355401.7 6689073.5 24, 355386.8 6689065.7 24, 355378.3 6689081.8 24, 355385.5 6689085.6 24), (355388.3 6689080.5 24, 355391.3 6689081.9 24, 355390.3 6689083.4 24, 355387.7 6689081.5 24, 355388.3 6689080.5 24))
BATIMENT0000000302931583;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;17.4;5.5;23.0;25.4;7.0;Cadastre;A 1.0;POLYGON Z ((355363.8 6689094.9 23, 355372.4 6689078.7 23, 355356.8 6689070.7 23, 355355.4 6689073.3 23, 355357.6 6689074.6 23, 355358 6689076.1 23, 355357.3 6689077.1 23, 355356.4 6689077.2 23, 355355.7 6689077.8 23, 355354.4 6689080.5 23, 355354.1 6689081.3 23, 355354.6 6689082 23, 355354.3 6689082.4 23, 355351.5 6689080.7 23, 355348.1 6689086.7 23, 355363.8 6689094.9 23))
BATIMENT0000000302931587;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;50;20;18.0;7.0;25.0;;;Cadastre;A 1.0;POLYGON Z ((355315.1 6689078.6 25, 355306.6 6689094.5 25, 355309.8 6689096.3 25, 355311.8 6689092.9 25, 355314.3 6689094.1 25, 355314.3 6689094.2 25, 355314.2 6689094.3 25, 355314.1 6689094.5 25, 355314 6689094.6 25, 355314 6689094.9 25, 355314 6689095 25, 355314 6689095.1 25, 355314 6689095.4 25, 355314.1 6689095.6 25, 355314.1 6689095.7 25, 355314.3 6689095.9 25, 355314.4 6689096 25, 355314.5 6689096.1 25, 355314.7 6689096.3 25, 355314.8 6689096.4 25, 355314.9 6689096.4 25, 355315 6689096.5 25, 355315.1 6689096.5 25, 355315.4 6689096.5 25, 355315.5 6689096.5 25, 355315.8 6689096.5 25, 355316 6689096.4 25, 355316.1 6689096.4 25, 355316.2 6689096.3 25, 355316.4 6689096.1 25, 355316.6 6689096 25, 355316.7 6689095.8 25, 355316.8 6689095.5 25, 355320.2 6689097.3 25, 355318.1 6689100.8 25, 355321.5 6689102.5 25, 355330.1 6689086.6 25, 355315.1 6689078.6 25))
BATIMENT0000000302931546;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;00;00;16.2;6.4;22.7;27.4;7.5;Cadastre;A 1.0;POLYGON Z ((355369.9 6689097.8 22.7, 355374.6 6689100.2 22.7, 355381.2 6689088.1 22.7, 355382.4 6689088.7 22.7, 355383.5 6689089.1 22.7, 355385.5 6689085.6 22.7, 355378.3 6689081.8 22.7, 355369.9 6689097.8 22.7))
BATIMENT0000000302931545;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;6.0;20;20;20.8;6.5;27.4;29.4;7.3;Cadastre;A 1.0;POLYGON Z ((355384.8 6689105.4 27.4, 355393.2 6689089.6 27.4, 355388.2 6689087 27.4, 355385.6 6689092 27.4, 355381.6 6689090.2 27.4, 355382.4 6689088.7 27.4, 355381.2 6689088.1 27.4, 355374.6 6689100.2 27.4, 355384.8 6689105.4 27.4))
BATIMENT0000000302931589;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;13.2;5.3;18.5;28.0;6.4;Cadastre;A 1.0;POLYGON Z ((355330.1 6689086.6 18.5, 355321.5 6689102.5 18.5, 355328.7 6689106.5 18.5, 355337.2 6689090.4 18.5, 355330.1 6689086.6 18.5))
BATIMENT0000000302931548;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;19.6;6.8;26.4;29.5;7.4;Cadastre;A 1.0;POLYGON Z ((355389.3 6689107.8 26.4, 355389.3 6689108.1 26.4, 355394.8 6689111 26.4, 355395 6689110.9 26.4, 355399.4 6689113 26.4, 355407.7 6689097.3 26.4, 355403.9 6689095.3 26.4, 355402.4 6689098 26.4, 355401 6689098.2 26.4, 355400.1 6689097.6 26.4, 355400.1 6689097.4 26.4, 355400 6689097.2 26.4, 355399.9 6689097 26.4, 355399.7 6689096.8 26.4, 355399.4 6689096.6 26.4, 355399.2 6689096.5 26.4, 355398.8 6689096.4 26.4, 355398.5 6689096.5 26.4, 355398.2 6689096.6 26.4, 355398.1 6689096.7 26.4, 355396.3 6689095.8 26.4, 355395.6 6689094 26.4, 355396.8 6689091.5 26.4, 355393.2 6689089.6 26.4, 355384.8 6689105.4 26.4, 355389.3 6689107.8 26.4))
BATIMENT0000000302931590;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;22.2;5.2;27.5;30.1;7.3;Cadastre;A 1.0;POLYGON Z ((355359.5 6689102.1 27.5, 355337.2 6689090.4 27.5, 355328.7 6689106.5 27.5, 355332.2 6689108.5 27.5, 355335.7 6689110.3 27.5, 355336 6689110.4 27.5, 355337.5 6689107.7 27.5, 355337.6 6689107.7 27.5, 355337.7 6689107.5 27.5, 355337.8 6689107.4 27.5, 355338 6689107.3 27.5, 355338.4 6689107.1 27.5, 355338.6 6689107.1 27.5, 355338.8 6689107.1 27.5, 355338.9 6689107.2 27.5, 355339 6689107.2 27.5, 355339.2 6689107.3 27.5, 355339.3 6689107.3 27.5, 355339.5 6689107.5 27.5, 355339.6 6689107.6 27.5, 355339.7 6689108.6 27.5, 355344.8 6689111.5 27.5, 355343.8 6689113.5 27.5, 355351.5 6689117.7 27.5, 355359.5 6689102.1 27.5))
BATIMENT0000000302931588;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;19.7;5.6;25.4;27.5;6.3;Cadastre;A 1.0;POLYGON Z ((355312.7 6689118.9 25.4, 355321.5 6689102.5 25.4, 355318.1 6689100.8 25.4, 355316.2 6689104.6 25.4, 355312.8 6689102.8 25.4, 355312.9 6689102.6 25.4, 355312.9 6689102.5 25.4, 355312.9 6689102.4 25.4, 355312.9 6689102.2 25.4, 355312.9 6689102 25.4, 355312.8 6689101.8 25.4, 355312.8 6689101.7 25.4, 355312.7 6689101.6 25.4, 355312.6 6689101.4 25.4, 355312.5 6689101.3 25.4, 355312.4 6689101.2 25.4, 355312.2 6689101.1 25.4, 355312.1 6689101 25.4, 355311.8 6689100.9 25.4, 355311.7 6689100.9 25.4, 355311.5 6689100.9 25.4, 355311.4 6689100.9 25.4, 355311.2 6689100.9 25.4, 355311 6689100.9 25.4, 355310.9 6689101 25.4, 355310.8 6689101 25.4, 355310.6 6689101.2 25.4, 355310.5 6689101.3 25.4, 355310.4 6689101.3 25.4, 355307.8 6689100 25.4, 355309.8 6689096.3 25.4, 355306.6 6689094.5 25.4, 355297.9 6689111.1 25.4, 355312.7 6689118.9 25.4))
BATIMENT0000000302931592;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;5.1;22.0;25.5;5.4;Cadastre;;POLYGON Z ((355332.2 6689108.5 22, 355328.7 6689106.5 22, 355327.3 6689108.6 22, 355331 6689110.6 22, 355332.2 6689108.5 22))
BATIMENT0000000302931591;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;17.8;5.1;23.0;26.4;6.2;Cadastre;A 1.0;POLYGON Z ((355327.3 6689126.6 23, 355331.7 6689118.3 23, 355335.7 6689110.3 23, 355332.2 6689108.5 23, 355331 6689110.6 23, 355330.2 6689111.8 23, 355328.6 6689112.5 23, 355327.4 6689111.8 23, 355328 6689110.8 23, 355326 6689109.7 23, 355325.3 6689110.8 23, 355323.5 6689109.7 23, 355323.3 6689108.5 23, 355324.1 6689107 23, 355327.3 6689108.6 23, 355328.7 6689106.5 23, 355321.5 6689102.5 23, 355312.7 6689118.9 23, 355327.3 6689126.6 23))
BATIMENT0000000302931593;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;22.3;5.1;27.5;30.1;7.3;Cadastre;A 1.0;POLYGON Z ((355342.8 6689134.8 27.5, 355351.5 6689117.7 27.5, 355343.8 6689113.5 27.5, 355340.3 6689111.7 27.5, 355339.4 6689111.6 27.5, 355338.4 6689111.6 27.5, 355337.7 6689111.5 27.5, 355335.9 6689115.2 27.5, 355336.7 6689115.9 27.5, 355336 6689117 27.5, 355335.2 6689116.7 27.5, 355333.6 6689119.4 27.5, 355331.7 6689118.3 27.5, 355327.3 6689126.6 27.5, 355342.8 6689134.8 27.5))
BATIMENT0000000302931550;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;00;00;15.0;7.2;22.2;27.0;7.4;Cadastre;A 1.0;POLYGON Z ((355413.8 6689120.4 22.2, 355420.5 6689107.9 22.2, 355411.6 6689103.1 22.2, 355410.8 6689101.7 22.2, 355410.9 6689101.4 22.2, 355411.6 6689101.6 22.2, 355412.3 6689100.6 22.2, 355412 6689100.5 22.2, 355412.9 6689098.7 22.2, 355413.2 6689098.8 22.2, 355413.8 6689097.5 22.2, 355413.1 6689097.2 22.2, 355415.1 6689096.4 22.2, 355424.1 6689101 22.2, 355430.7 6689088.4 22.2, 355426.3 6689086.1 22.2, 355426.3 6689085.8 22.2, 355420.8 6689083 22.2, 355420.5 6689083.2 22.2, 355416.3 6689081 22.2, 355407.7 6689097.3 22.2, 355399.4 6689113 22.2, 355413.8 6689120.4 22.2))
BATIMENT0000000302931552;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;00;00;18.7;6.2;25.0;27.7;6.7;Cadastre;A 1.0;POLYGON Z ((355454.9 6689101 25, 355455.1 6689100.8 25, 355449.2 6689097.7 25, 355449.1 6689097.9 25, 355445.2 6689095.8 25, 355436.9 6689111.7 25, 355439.6 6689113.3 25, 355441.2 6689109.9 25, 355444.8 6689111.7 25, 355444.7 6689111.8 25, 355444.6 6689111.9 25, 355444.5 6689112.1 25, 355444.5 6689112.3 25, 355444.5 6689112.5 25, 355444.5 6689112.6 25, 355444.6 6689112.8 25, 355444.6 6689112.9 25, 355444.7 6689113 25, 355444.8 6689113.1 25, 355444.8 6689113.2 25, 355445.1 6689113.4 25, 355445.2 6689113.4 25, 355445.4 6689113.5 25, 355445.6 6689113.5 25, 355445.7 6689113.5 25, 355445.9 6689113.5 25, 355446 6689113.5 25, 355446.2 6689113.4 25, 355446.2 6689113.3 25, 355446.5 6689113.2 25, 355446.5 6689113.1 25, 355446.7 6689112.8 25, 355449.8 6689114.4 25, 355448.2 6689117.9 25, 355451.2 6689119.5 25, 355454.6 6689113.1 25, 355459.6 6689103.3 25, 355454.9 6689101 25))
BATIMENT0000000302931551;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;;;16.6;6.5;23.1;27.4;7.3;Cadastre;A 1.0;POLYGON Z ((355428.2 6689127.9 23.1, 355436.9 6689111.7 23.1, 355445.2 6689095.8 23.1, 355441.1 6689094 23.1, 355441.1 6689093.7 23.1, 355434.9 6689090.3 23.1, 355434.7 6689090.4 23.1, 355430.7 6689088.4 23.1, 355424.1 6689101 23.1, 355433.3 6689106 23.1, 355433.5 6689107.7 23.1, 355432.8 6689107.3 23.1, 355432 6689108.6 23.1, 355432.3 6689108.8 23.1, 355431.6 6689110.1 23.1, 355431.2 6689110 23.1, 355430.4 6689111.5 23.1, 355431.2 6689111.9 23.1, 355430.8 6689112.5 23.1, 355429 6689112.4 23.1, 355420.5 6689107.9 23.1, 355413.8 6689120.4 23.1, 355428.2 6689127.9 23.1))
BATIMENT0000000302931556;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;00;00;17.6;6.3;23.9;27.7;7.4;Cadastre;C 0.7;POLYGON Z ((355474.1 6689112.3 23.9, 355474.4 6689112.3 23.9, 355474.9 6689111.2 23.9, 355473.3 6689110.3 23.9, 355473.2 6689110.6 23.9, 355470.4 6689109.2 23.9, 355470.3 6689108.9 23.9, 355463.6 6689105.2 23.9, 355463.3 6689105.2 23.9, 355459.6 6689103.3 23.9, 355454.6 6689113.1 23.9, 355456.6 6689114.1 23.9, 355454.1 6689118.6 23.9, 355456.2 6689119.6 23.9, 355455.3 6689121.6 23.9, 355453.4 6689125.5 23.9, 355458.7 6689128.4 23.9, 355458.5 6689129.1 23.9, 355463.7 6689131.9 23.9, 355474.1 6689112.3 23.9))
BATIMENT0000000302931554;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;6.2;21.1;23.5;6.7;Cadastre;;POLYGON Z ((355443.1 6689119 21.1, 355443.1 6689119.1 21.1, 355443.1 6689119.2 21.1, 355443 6689119.3 21.1, 355443 6689119.4 21.1, 355443 6689119.5 21.1, 355442.9 6689119.6 21.1, 355443 6689119.7 21.1, 355446.1 6689121.4 21.1, 355448.2 6689117.9 21.1, 355444.3 6689116 21.1, 355443 6689118.5 21.1, 355443.1 6689119 21.1))
BATIMENT0000000302931553;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;19;20;19.0;6.4;25.5;28.2;7.1;Cadastre;A 1.0;POLYGON Z ((355433.1 6689130.5 25.5, 355433.1 6689130.7 25.5, 355438.1 6689133.4 25.5, 355438.6 6689133.4 25.5, 355442.7 6689135.6 25.5, 355447.8 6689126.1 25.5, 355451.2 6689119.5 25.5, 355448.2 6689117.9 25.5, 355446.1 6689121.4 25.5, 355443 6689119.7 25.5, 355442.9 6689119.6 25.5, 355443 6689119.5 25.5, 355443 6689119.4 25.5, 355443 6689119.3 25.5, 355443.1 6689119.2 25.5, 355443.1 6689119.1 25.5, 355443.1 6689119 25.5, 355443 6689118.5 25.5, 355442.9 6689118.4 25.5, 355442.8 6689118.3 25.5, 355442.7 6689118.2 25.5, 355442.6 6689118.2 25.5, 355442.4 6689118.1 25.5, 355442.3 6689118.1 25.5, 355442.2 6689118 25.5, 355442 6689118 25.5, 355441.9 6689118 25.5, 355441.7 6689118.1 25.5, 355441.5 6689118.1 25.5, 355441.3 6689118.3 25.5, 355441.1 6689118.4 25.5, 355441 6689118.5 25.5, 355441 6689118.6 25.5, 355438.9 6689117.7 25.5, 355440.4 6689115 25.5, 355439.2 6689114.2 25.5, 355439.6 6689113.3 25.5, 355436.9 6689111.7 25.5, 355428.2 6689127.9 25.5, 355433.1 6689130.5 25.5))
BATIMENT0000000302931555;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;16.8;7.0;23.8;27.9;7.3;Cadastre;A 1.0;POLYGON Z ((355446.8 6689137.7 23.8, 355446.8 6689137.9 23.8, 355452.8 6689141.2 23.8, 355453.1 6689141.1 23.8, 355456.8 6689142.9 23.8, 355457.8 6689143.5 23.8, 355458.2 6689142.7 23.8, 355458.1 6689142.6 23.8, 355463.7 6689131.9 23.8, 355458.5 6689129.1 23.8, 355458.7 6689128.4 23.8, 355453.4 6689125.5 23.8, 355451.7 6689128.3 23.8, 355447.8 6689126.1 23.8, 355442.7 6689135.6 23.8, 355446.8 6689137.7 23.8))
BATIMENT0000000302931560;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;5.0;12;20;17.0;7.2;24.2;26.9;7.5;Cadastre;A 1.0;POLYGON Z ((355399.1 6689164.2 24.2, 355406 6689151 24.2, 355408.1 6689146.9 24.2, 355406.7 6689146.4 24.2, 355405.8 6689147.9 24.2, 355404.5 6689148.5 24.2, 355403.5 6689150.5 24.2, 355401.8 6689149.7 24.2, 355403.2 6689147.1 24.2, 355404.3 6689147.5 24.2, 355405.5 6689145.5 24.2, 355404.5 6689144.9 24.2, 355405.6 6689142.8 24.2, 355406.1 6689140.9 24.2, 355410.4 6689142.8 24.2, 355416 6689131.7 24.2, 355408.9 6689128 24.2, 355391.8 6689160.5 24.2, 355399.1 6689164.2 24.2))
BATIMENT0000000302931562;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1760-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;5.0;00;00;17.2;7.3;24.5;27.3;8.3;Cadastre;A 1.0;POLYGON Z ((355430.5 6689139.3 24.5, 355423.3 6689135.5 24.5, 355414.1 6689153.3 24.5, 355417.9 6689155.2 24.5, 355418 6689154.8 24.5, 355419.9 6689151.2 24.5, 355420.2 6689149 24.5, 355423.2 6689150.3 24.5, 355422.8 6689150.9 24.5, 355422.9 6689151.6 24.5, 355423.9 6689152.1 24.5, 355424.7 6689152.5 24.5, 355425.3 6689151.6 24.5, 355428.7 6689153.2 24.5, 355427 6689154.7 24.5, 355425.1 6689158.4 24.5, 355425.1 6689158.8 24.5, 355428.6 6689160.9 24.5, 355429.4 6689159.3 24.5, 355433 6689152.6 24.5, 355434.9 6689149 24.5, 355437.7 6689142.9 24.5, 355430.5 6689139.3 24.5))
BATIMENT0000000302931561;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;00;00;16.9;7.2;24.1;26.0;8.0;Cadastre;A 1.0;POLYGON Z ((355406.6 6689167.9 24.1, 355414.1 6689153.3 24.1, 355423.3 6689135.5 24.1, 355416 6689131.7 24.1, 355410.4 6689142.8 24.1, 355409.4 6689144.6 24.1, 355411.1 6689145.7 24.1, 355412 6689143.9 24.1, 355414.5 6689145.1 24.1, 355413.6 6689146.3 24.1, 355412.3 6689148.4 24.1, 355409.6 6689153.5 24.1, 355409.2 6689155.2 24.1, 355406.7 6689154.1 24.1, 355407.6 6689152.3 24.1, 355406 6689151 24.1, 355399.1 6689164.2 24.1, 355406.6 6689167.9 24.1))
BATIMENT0000000302929335;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;20;20;5.4;6.3;11.7;20.4;7.3;Cadastre;A 1.0;POLYGON Z ((355769.5 6688773 11.7, 355776.9 6688776.7 11.7, 355783.3 6688779.8 11.7, 355783.9 6688778.5 11.7, 355783.7 6688778.3 11.7, 355784.2 6688777.4 11.7, 355786.3 6688772.9 11.7, 355787.3 6688770.6 11.7, 355788.8 6688767.6 11.7, 355783 6688764.9 11.7, 355783 6688765 11.7, 355780.1 6688771.3 11.7, 355773.6 6688768.3 11.7, 355775 6688765.1 11.7, 355780 6688767.4 11.7, 355781.5 6688764.2 11.7, 355779.1 6688763.2 11.7, 355774.2 6688760.9 11.7, 355773.6 6688760.6 11.7, 355768.2 6688758.2 11.7, 355756.1 6688752.7 11.7, 355750.9 6688763.9 11.7, 355769.5 6688773 11.7))
BATIMENT0000000302929345;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;4.9;6.0;10.9;11.5;7.2;Cadastre;A 1.0;POLYGON Z ((355798.7 6688769.8 10.9, 355800.4 6688764.6 10.9, 355791.6 6688761.9 10.9, 355788.8 6688767.6 10.9, 355787.3 6688770.6 10.9, 355786.3 6688772.9 10.9, 355784.2 6688777.4 10.9, 355786.5 6688778.5 10.9, 355790.5 6688780.4 10.9, 355793.2 6688774 10.9, 355794.3 6688771.5 10.9, 355797.8 6688769.5 10.9, 355798.7 6688769.8 10.9))
BATIMENT0000000302929339;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;7.2;16.5;18.0;7.6;Cadastre;;POLYGON Z ((355747.4 6688771.2 16.5, 355748 6688769.9 16.5, 355747.3 6688769.5 16.5, 355746.2 6688770 16.5, 355745 6688772.5 16.5, 355745.3 6688773.6 16.5, 355746.1 6688774 16.5, 355747.4 6688771.2 16.5))
BATIMENT0000000302929338;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.4;6.9;18.3;20.6;7.3;Cadastre;;POLYGON Z ((355764.6 6688774.2 18.3, 355762.7 6688773.3 18.3, 355762.1 6688774.6 18.3, 355761 6688777 18.3, 355762.9 6688777.9 18.3, 355763.4 6688776.7 18.3, 355764.6 6688774.2 18.3))
BATIMENT0000000302929352;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;6.0;9.1;9.6;6.5;Cadastre;;POLYGON Z ((355791.9 6688781 9.1, 355794.6 6688774.6 9.1, 355793.2 6688774 9.1, 355790.5 6688780.4 9.1, 355791.9 6688781 9.1))
BATIMENT0000000302929330;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;4.0;20;20;8.4;6.3;14.7;21.4;7.5;Cadastre;A 1.0;POLYGON Z ((355750.9 6688763.9 14.7, 355748.8 6688768.1 14.7, 355748.1 6688769.7 14.7, 355748 6688769.9 14.7, 355747.4 6688771.2 14.7, 355746.1 6688774 14.7, 355745.8 6688774.5 14.7, 355761 6688781 14.7, 355779 6688789.3 14.7, 355788.8 6688791.6 14.7, 355790.7 6688785.3 14.7, 355775.2 6688780.5 14.7, 355769.5 6688778.7 14.7, 355768.8 6688780.8 14.7, 355762.9 6688777.9 14.7, 355761 6688777 14.7, 355762.1 6688774.6 14.7, 355762.7 6688773.3 14.7, 355764.6 6688774.2 14.7, 355775.8 6688779.2 14.7, 355776.9 6688776.7 14.7, 355769.5 6688773 14.7, 355750.9 6688763.9 14.7))
BATIMENT0000000302929735;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;5.9;5.8;11.7;15.6;7.2;Cadastre;A 1.0;POLYGON Z ((355805.1 6688779 11.7, 355804.4 6688778.9 11.7, 355803.6 6688783.5 11.7, 355814.5 6688785.5 11.7, 355815.4 6688780.6 11.7, 355807.7 6688779.2 11.7, 355808.2 6688776.2 11.7, 355821.6 6688779.1 11.7, 355822.8 6688776.5 11.7, 355820.3 6688775.8 11.7, 355814.8 6688774.4 11.7, 355810.3 6688773.2 11.7, 355810.2 6688773.4 11.7, 355806.7 6688772.3 11.7, 355805.2 6688778.7 11.7, 355805.1 6688779 11.7))
BATIMENT0000000302930078;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.4;5.8;8.2;9.7;6.2;Cadastre;;POLYGON Z ((355817 6688785.9 8.2, 355818.2 6688786.2 8.2, 355818.9 6688784.6 8.2, 355817.9 6688784.1 8.2, 355817 6688785.9 8.2))
BATIMENT0000000302929327;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;7.2;6.9;14.2;25.4;7.7;Cadastre;A 1.0;POLYGON Z ((355738 6688791.6 14.2, 355764 6688804.1 14.2, 355768.4 6688794.9 14.2, 355761.1 6688792.4 14.2, 355755.5 6688791.3 14.2, 355756.1 6688790.1 14.2, 355757.5 6688790.7 14.2, 355760 6688785.1 14.2, 355758.7 6688784.5 14.2, 355759.2 6688783.2 14.2, 355762.1 6688784.6 14.2, 355761.1 6688787 14.2, 355775.6 6688793.9 14.2, 355776.7 6688794.4 14.2, 355779 6688789.3 14.2, 355761 6688781 14.2, 355745.8 6688774.5 14.2, 355738 6688791.6 14.2))
BATIMENT0000000302929324;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.5;6.6;16.1;16.6;6.8;Cadastre;A 1.0;POLYGON Z ((355790.7 6688785.3 16.1, 355788.8 6688791.6 16.1, 355790.8 6688792.1 16.1, 355799.2 6688794.1 16.1, 355800.9 6688788.5 16.1, 355790.7 6688785.3 16.1))
BATIMENT0000000302929322;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.8;5.7;11.5;14.9;6.8;Cadastre;A 1.0;POLYGON Z ((355800.9 6688788.5 11.5, 355799.2 6688794.1 11.5, 355804.4 6688795.3 11.5, 355806.6 6688795.8 11.5, 355808 6688790.3 11.5, 355807.7 6688790.2 11.5, 355800.9 6688788.5 11.5))
BATIMENT0000000302929323;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;20;12.2;5.8;18.0;20.6;6.8;Cadastre;A 1.0;POLYGON Z ((355808.1 6688788.9 18, 355807.7 6688790.2 18, 355808 6688790.3 18, 355806.6 6688795.8 18, 355819.9 6688798.6 18, 355821.2 6688792.2 18, 355819.6 6688791.9 18, 355819.7 6688791.6 18, 355808.1 6688788.9 18))
BATIMENT0000000302929340;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;8.5;6.7;15.2;18.8;7.5;Cadastre;B 0.3;POLYGON Z ((355773.9 6688808.8 15.2, 355778.3 6688799.6 15.2, 355773.9 6688797.5 15.2, 355768.4 6688794.9 15.2, 355764 6688804.1 15.2, 355773.9 6688808.8 15.2))
BATIMENT0000000302929325;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;8.2;7.3;15.5;;;Cadastre;B 0.5;POLYGON Z ((355787 6688815 15.5, 355790.2 6688808.2 15.5, 355799.4 6688812.2 15.5, 355801.2 6688806.1 15.5, 355794.5 6688802.9 15.5, 355796.1 6688799.5 15.5, 355802.3 6688802.5 15.5, 355804.4 6688795.3 15.5, 355799.2 6688794.1 15.5, 355790.8 6688792.1 15.5, 355788.8 6688791.6 15.5, 355779 6688789.3 15.5, 355776.7 6688794.4 15.5, 355788 6688799.8 15.5, 355781.9 6688812.6 15.5, 355786 6688814.6 15.5, 355787 6688815 15.5))
BATIMENT0000000302929341;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;20;20;4.7;6.7;11.4;24.2;7.8;Cadastre;A 1.0;POLYGON Z ((355733.8 6688800.6 11.4, 355739.5 6688803.3 11.4, 355740 6688802.3 11.4, 355745.9 6688804.8 11.4, 355745.5 6688805.9 11.4, 355754.4 6688810.2 11.4, 355755.1 6688811.1 11.4, 355768.5 6688817.4 11.4, 355772.9 6688819.4 11.4, 355776.9 6688810.5 11.4, 355777 6688810.3 11.4, 355773.9 6688808.8 11.4, 355764 6688804.1 11.4, 355738 6688791.6 11.4, 355733.8 6688800.6 11.4))
BATIMENT0000000302929326;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2013-09-26 18:45:28;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;7.3;14.4;;;Cadastre;;POLYGON Z ((355833.1 6688819.9 14.4, 355839.4 6688821.2 14.4, 355840.4 6688816.8 14.4, 355841.7 6688811.7 14.4, 355841.5 6688811.6 14.4, 355842.2 6688808 14.4, 355843.1 6688803.3 14.4, 355827.4 6688800.1 14.4, 355819.9 6688798.6 14.4, 355806.6 6688795.8 14.4, 355804.4 6688795.3 14.4, 355802.3 6688802.5 14.4, 355801.2 6688806.1 14.4, 355799.4 6688812.2 14.4, 355804.2 6688813.3 14.4, 355814.4 6688815.7 14.4, 355822.4 6688817.5 14.4, 355823.6 6688817.8 14.4, 355823.6 6688818 14.4, 355827.2 6688818.7 14.4, 355833.1 6688819.9 14.4))
BATIMENT0000000302929347;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;20;20;6.6;6.7;13.4;24.5;7.8;Cadastre;A 1.0;POLYGON Z ((355729.1 6688810.9 13.4, 355755.9 6688823 13.4, 355757.2 6688823.6 13.4, 355759.4 6688824.6 13.4, 355764.2 6688826.8 13.4, 355768.5 6688817.4 13.4, 355755.1 6688811.1 13.4, 355755.3 6688811.4 13.4, 355754.4 6688811.7 13.4, 355744.8 6688807.4 13.4, 355745 6688806.9 13.4, 355733.2 6688802 13.4, 355729.1 6688810.9 13.4))
BATIMENT0000000327821880;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;1902-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;2.0;30;20;5.9;6.5;;16.2;7.0;Imagerie aérienne;B 0.7;POLYGON Z ((355802.3 6688820.5 12.1, 355804.2 6688813.3 12.2, 355799.4 6688812.2 12.4, 355790.2 6688808.2 12.4, 355787 6688815 12.4, 355786 6688814.6 12.4, 355783.8 6688819.6 12.4, 355786.1 6688820.7 12.4, 355788.6 6688820.3 11.4, 355788.9 6688820.2 12.4, 355795.5 6688820.9 11.4, 355802.3 6688820.5 12.1))
BATIMENT0000000327821797;Indifférenciée;Annexe;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.8;6.6;;13.6;7.2;Imagerie aérienne;B 0.2;POLYGON Z ((355811.7 6688826.4 12.4, 355817.5 6688829.1 12.4, 355818.9 6688825.8 12.4, 355822.4 6688817.5 12.4, 355814.4 6688815.7 12.4, 355810.2 6688825.7 11.2, 355811.7 6688826.4 12.4))
BATIMENT0000000302929346;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;6.5;12.9;18.4;7.2;Cadastre;;POLYGON Z ((355772.9 6688819.4 12.9, 355768.5 6688817.4 12.9, 355764.2 6688826.8 12.9, 355768.6 6688828.8 12.9, 355772.9 6688819.4 12.9))
BATIMENT0000000302929534;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.5;7.7;20.2;22.8;8.5;Cadastre;C 0.1;POLYGON Z ((355704.3 6688744.7 20.2, 355693 6688738.9 20.2, 355694.4 6688746.6 20.2, 355688 6688747.8 20.2, 355687.4 6688744.6 20.2, 355671.2 6688747.6 20.2, 355671.8 6688750.8 20.2, 355666.4 6688751.8 20.2, 355669.3 6688768 20.2, 355669.9 6688771.1 20.2, 355667.6 6688771.6 20.2, 355671.4 6688793 20.2, 355672.3 6688792.9 20.2, 355673.1 6688796.1 20.2, 355676.8 6688795.5 20.2, 355676.8 6688798.8 20.2, 355694.5 6688772.9 20.2, 355689.6 6688773.9 20.2, 355688.7 6688769.3 20.2, 355689.8 6688768.9 20.2, 355690.2 6688769.3 20.2, 355690.5 6688769.4 20.2, 355690.8 6688769.5 20.2, 355691.4 6688769.7 20.2, 355691.9 6688769.6 20.2, 355692.5 6688769.3 20.2, 355692.9 6688769 20.2, 355693.2 6688768.3 20.2, 355693.2 6688767.6 20.2, 355693.1 6688766.9 20.2, 355692.7 6688766.3 20.2, 355691.8 6688765.9 20.2, 355691.2 6688765.8 20.2, 355690.8 6688765.9 20.2, 355690.5 6688766 20.2, 355690 6688766.2 20.2, 355689.9 6688766.4 20.2, 355689.8 6688766.6 20.2, 355689.6 6688766.9 20.2, 355689.4 6688767.2 20.2, 355685.3 6688768.1 20.2, 355684.6 6688765 20.2, 355697.3 6688762.4 20.2, 355698.3 6688767.4 20.2, 355711.3 6688748.3 20.2, 355710 6688747.6 20.2, 355704.9 6688745 20.2, 355704.3 6688744.7 20.2))
BATIMENT0000000302929537;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;7.5;12.5;19.5;7.9;Cadastre;;POLYGON Z ((355665.2 6688772.1 12.5, 355667.6 6688771.6 12.5, 355669.9 6688771.1 12.5, 355669.3 6688768 12.5, 355668.7 6688768.2 12.5, 355664.6 6688769 12.5, 355665.2 6688772.1 12.5))
BATIMENT0000000302929349;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;7.6;22.4;24.5;7.8;Cadastre;;POLYGON Z ((355733.2 6688802 22.4, 355745 6688806.9 22.4, 355745.5 6688805.9 22.4, 355745.9 6688804.8 22.4, 355740 6688802.3 22.4, 355739.5 6688803.3 22.4, 355733.8 6688800.6 22.4, 355733.2 6688802 22.4))
BATIMENT0000000302929348;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;20;20;7.7;6.5;14.2;20.6;7.8;Cadastre;C 0.6;POLYGON Z ((355722.5 6688825.3 14.2, 355742.9 6688834.4 14.2, 355749 6688837.1 14.2, 355750.1 6688834.9 14.2, 355751.6 6688831.7 14.2, 355740.7 6688826.9 14.2, 355740.2 6688828 14.2, 355738.3 6688827.2 14.2, 355736.8 6688828.1 14.2, 355735.4 6688827.7 14.2, 355736.3 6688825.7 14.2, 355736.7 6688825.9 14.2, 355737.3 6688824.6 14.2, 355736.9 6688824.4 14.2, 355739.7 6688818.6 14.2, 355740.8 6688821.5 14.2, 355741.8 6688822.1 14.2, 355741.5 6688822.9 14.2, 355753.3 6688828.2 14.2, 355755.9 6688823 14.2, 355729.1 6688810.9 14.2, 355722.5 6688825.3 14.2))
BATIMENT0000000302929975;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.3;7.0;12.3;12.8;7.8;Cadastre;;POLYGON Z ((355689.2 6688850.9 12.3, 355695.8 6688836 12.3, 355691.8 6688833.3 12.3, 355683.3 6688846.8 12.3, 355689.2 6688850.9 12.3))
BATIMENT0000000302929365;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;10;20;11.7;6.6;18.3;21.1;8.0;Cadastre;A 1.0;POLYGON Z ((355712 6688848.1 18.3, 355717.8 6688850.8 18.3, 355717.6 6688851.2 18.3, 355723.3 6688853.8 18.3, 355723.8 6688852.9 18.3, 355725.1 6688853.5 18.3, 355725.3 6688853.2 18.3, 355725.8 6688852.1 18.3, 355726.6 6688852.5 18.3, 355726.7 6688852.3 18.3, 355727.4 6688850.8 18.3, 355726.8 6688850.4 18.3, 355729.3 6688845.1 18.3, 355734.5 6688847.5 18.3, 355734.7 6688847.5 18.3, 355736.1 6688844.4 18.3, 355717.4 6688836.4 18.3, 355712 6688848.1 18.3))
BATIMENT0000000302929384;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;13;20;11.2;6.9;18.1;23.5;8.0;Cadastre;A 1.0;POLYGON Z ((355723.8 6688852.9 18.1, 355723.3 6688853.8 18.1, 355717.6 6688851.2 18.1, 355717.8 6688850.8 18.1, 355712 6688848.1 18.1, 355707.1 6688858.5 18.1, 355719 6688863.8 18.1, 355720.1 6688861.6 18.1, 355722.7 6688860.3 18.1, 355724.4 6688861 18.1, 355726.1 6688857.1 18.1, 355722.8 6688855.5 18.1, 355723.3 6688854.5 18.1, 355724.4 6688855 18.1, 355725.1 6688853.5 18.1, 355723.8 6688852.9 18.1))
BATIMENT0000000302929370;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;;;15.4;7.5;22.9;25.0;8.0;Cadastre;A 1.0;POLYGON Z ((355707.1 6688858.5 22.9, 355701.4 6688870.3 22.9, 355713.6 6688875.5 22.9, 355717.2 6688877 22.9, 355718.9 6688873.3 22.9, 355715.4 6688871.6 22.9, 355716.5 6688869.1 22.9, 355717.4 6688869.5 22.9, 355718.2 6688868.9 22.9, 355719.6 6688865.9 22.9, 355718.3 6688865.3 22.9, 355719 6688863.8 22.9, 355707.1 6688858.5 22.9))
BATIMENT0000000302929368;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;6.7;17.8;21.0;7.9;Cadastre;;POLYGON Z ((355741.9 6688887.5 17.8, 355742.1 6688887.6 17.8, 355747.4 6688875.3 17.8, 355739.3 6688871.8 17.8, 355741.8 6688867 17.8, 355744.3 6688862.1 17.8, 355727.4 6688854.2 17.8, 355726.1 6688857.1 17.8, 355724.4 6688861 17.8, 355722.7 6688860.3 17.8, 355720.1 6688861.6 17.8, 355719 6688863.8 17.8, 355722.6 6688865.4 17.8, 355719.4 6688872.5 17.8, 355719.3 6688872.5 17.8, 355718.9 6688873.3 17.8, 355717.2 6688877 17.8, 355741.9 6688887.5 17.8))
BATIMENT0000000302929372;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;13;20;15.3;7.4;22.7;24.3;7.7;Cadastre;A 1.0;POLYGON Z ((355709.1 6688885.7 22.7, 355710.2 6688883.1 22.7, 355711.6 6688883.7 22.7, 355712.8 6688881 22.7, 355711.4 6688880.4 22.7, 355713.6 6688875.5 22.7, 355701.4 6688870.3 22.7, 355696.7 6688880.4 22.7, 355709.1 6688885.7 22.7))
BATIMENT0000000302929367;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;6.5;15.0;15.7;6.9;Cadastre;;POLYGON Z ((355757.2 6688823.6 15, 355756.3 6688825.5 15, 355758.5 6688826.6 15, 355759.4 6688824.6 15, 355757.2 6688823.6 15))
BATIMENT0000000302929356;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;6.0;10.9;15.0;6.9;Cadastre;;POLYGON Z ((355755.9 6688823 10.9, 355753.3 6688828.2 10.9, 355754.7 6688828.9 10.9, 355756.3 6688825.5 10.9, 355757.2 6688823.6 10.9, 355755.9 6688823 10.9))
BATIMENT0000000302929343;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.2;7.3;11.5;;;Cadastre;A 1.0;POLYGON Z ((355821.8 6688831.1 11.5, 355823.3 6688827.7 11.5, 355818.9 6688825.8 11.5, 355817.5 6688829.1 11.5, 355820.3 6688830.4 11.5, 355821.8 6688831.1 11.5))
BATIMENT0000000327821800;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;2.0;40;40;6.0;6.5;;14.3;7.4;Imagerie aérienne;A 1.0;POLYGON Z ((355777.9 6688831.8 12.5, 355803.6 6688843.6 12.5, 355806.3 6688837.7 12.5, 355789.9 6688830.5 12.5, 355791.4 6688827.3 12.5, 355782 6688822.9 12.5, 355777.9 6688831.8 12.5))
BATIMENT0000000302929351;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;20;20;10.2;6.9;17.1;;;Cadastre;C 0.4;POLYGON Z ((355768.6 6688828.8 17.1, 355764.2 6688826.8 17.1, 355759.4 6688824.6 17.1, 355758.5 6688826.6 17.1, 355753.6 6688836.5 17.1, 355752.5 6688838.7 17.1, 355762.1 6688843.1 17.1, 355768.6 6688828.8 17.1))
BATIMENT0000000302929366;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;6.4;13.2;18.2;6.6;Cadastre;;POLYGON Z ((355749 6688837.1 13.2, 355750.9 6688838 13.2, 355752.5 6688838.7 13.2, 355753.6 6688836.5 13.2, 355750.1 6688834.9 13.2, 355749 6688837.1 13.2))
BATIMENT0000000302929364;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;34.0;4.0;25;20;11.3;6.9;18.2;20.9;8.0;Cadastre;A 1.0;POLYGON Z ((355717.4 6688836.4 18.2, 355736.1 6688844.4 18.2, 355745.4 6688848.4 18.2, 355750.4 6688850.5 18.2, 355750.6 6688850 18.2, 355757.5 6688853.3 18.2, 355762.1 6688843.1 18.2, 355752.5 6688838.7 18.2, 355750.9 6688838 18.2, 355748 6688843.6 18.2, 355739.8 6688839.9 18.2, 355740.4 6688839.1 18.2, 355740.8 6688838.9 18.2, 355742.9 6688834.4 18.2, 355722.5 6688825.3 18.2, 355717.4 6688836.4 18.2))
BATIMENT0000000327821895;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:45:28;2018-09-18 13:45:21;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.1;6.6;;13.0;7.4;Imagerie aérienne;;POLYGON Z ((355815.1 6688841 12.5, 355809.7 6688838.5 12.5, 355807.8 6688843.5 12.5, 355820.1 6688850.1 12.5, 355824.8 6688837.8 12.5, 355825.5 6688838.1 12.5, 355827.4 6688833.8 10.5, 355824.7 6688832.5 10.5, 355821.8 6688831.1 11.9, 355820.3 6688830.4 12.7, 355815.1 6688841 12.5))
BATIMENT0000000302929342;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;7.3;12.5;14.5;7.4;Cadastre;;POLYGON Z ((355834.5 6688848.5 12.5, 355834.7 6688848.5 12.5, 355836.6 6688842.9 12.5, 355825.5 6688838.1 12.5, 355824.8 6688837.8 12.5, 355820.1 6688850.1 12.5, 355807.8 6688843.5 12.5, 355809.7 6688838.5 12.5, 355815.1 6688841 12.5, 355820.3 6688830.4 12.5, 355817.5 6688829.1 12.5, 355811.7 6688826.4 12.5, 355806.3 6688837.7 12.5, 355803.6 6688843.6 12.5, 355801.6 6688847.7 12.5, 355817.6 6688855.7 12.5, 355819.4 6688851.9 12.5, 355832.2 6688855.9 12.5, 355834.5 6688848.5 12.5))
BATIMENT0000000302929363;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.9;7.3;13.2;;;Cadastre;A 1.0;POLYGON Z ((355771.3 6688847.2 13.2, 355771 6688847.7 13.2, 355766.3 6688858.2 13.2, 355774.1 6688861.8 13.2, 355776.1 6688862.7 13.2, 355779.9 6688864.4 13.2, 355787.4 6688848 13.2, 355783.5 6688846.2 13.2, 355773.7 6688841.9 13.2, 355771.3 6688847.2 13.2))
BATIMENT0000000327821891;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;3.0;4.0;;;12.2;6.0;;21.1;7.1;Imagerie aérienne;A 1.0;POLYGON Z ((355757.5 6688853.3 18.2, 355750.6 6688850 18.2, 355750.4 6688850.5 18.2, 355745.4 6688848.4 18.2, 355740.6 6688858.2 17.5, 355752.6 6688864.1 17.5, 355757.5 6688853.3 18.2))
BATIMENT0000000302929355;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;7.3;12.4;14.1;7.6;Cadastre;;POLYGON Z ((355796.5 6688858.7 12.4, 355803.9 6688862.1 12.4, 355799.5 6688873.3 12.4, 355804.2 6688875.5 12.4, 355815.1 6688880.5 12.4, 355820.2 6688869.6 12.4, 355823.5 6688871 12.4, 355827 6688872 12.4, 355829 6688864.9 12.4, 355815.8 6688859.7 12.4, 355817.6 6688855.7 12.4, 355801.6 6688847.7 12.4, 355799 6688853.2 12.4, 355796.5 6688858.7 12.4))
BATIMENT0000000302929375;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;54;10;8.1;6.3;14.4;17.0;6.8;Cadastre;A 1.0;POLYGON Z ((355766.3 6688858.2 14.4, 355762 6688867.7 14.4, 355769.8 6688871.2 14.4, 355770.5 6688869.7 14.4, 355774.1 6688861.8 14.4, 355766.3 6688858.2 14.4))
BATIMENT0000000302929369;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;20;20;9.9;5.2;15.1;19.2;7.2;Cadastre;A 1.0;POLYGON Z ((355751.9 6688865.7 15.1, 355745.9 6688862.9 15.1, 355743.6 6688867.8 15.1, 355741.8 6688867 15.1, 355739.3 6688871.8 15.1, 355747.4 6688875.3 15.1, 355751.9 6688865.7 15.1))
BATIMENT0000000302929360;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.1;7.3;12.4;14.7;7.5;Cadastre;C 0.1;POLYGON Z ((355776.1 6688862.7 12.4, 355774.1 6688861.8 12.4, 355770.5 6688869.7 12.4, 355801.1 6688882.6 12.4, 355804.2 6688875.5 12.4, 355799.5 6688873.3 12.4, 355791.7 6688869.9 12.4, 355791.5 6688869.5 12.4, 355783.9 6688866.2 12.4, 355779.9 6688864.4 12.4, 355776.1 6688862.7 12.4))
BATIMENT0000000302929362;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;6.9;12.7;13.1;7.2;Cadastre;;POLYGON Z ((355821.3 6688883.3 12.7, 355822.6 6688883.9 12.7, 355824.4 6688879.8 12.7, 355817.8 6688876.9 12.7, 355816 6688880.9 12.7, 355819.5 6688882.5 12.7, 355821.3 6688883.3 12.7))
BATIMENT0000000302929361;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;5.5;6.9;12.4;14.7;7.4;Cadastre;A 1.0;POLYGON Z ((355812.7 6688887.5 12.4, 355815.6 6688880.7 12.4, 355815.1 6688880.5 12.4, 355804.2 6688875.5 12.4, 355801.1 6688882.6 12.4, 355812.7 6688887.5 12.4))
BATIMENT0000000302929390;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;3.9;6.3;10.3;18.2;7.1;Cadastre;C 0.4;POLYGON Z ((355790 6688894.9 10.3, 355793.2 6688887.7 10.3, 355771.6 6688878.4 10.3, 355770.9 6688880 10.3, 355758.9 6688874.5 10.3, 355756.5 6688879.7 10.3, 355767.4 6688884.6 10.3, 355790 6688894.9 10.3))
BATIMENT0000000302929359;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;00;00;5.4;7.1;12.5;14.6;7.2;Cadastre;C 0.2;POLYGON Z ((355816.7 6688889.2 12.5, 355819.5 6688882.5 12.5, 355816 6688880.9 12.5, 355815.6 6688880.7 12.5, 355812.7 6688887.5 12.5, 355816.7 6688889.2 12.5))
BATIMENT0000000302929388;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.5;6.2;17.8;20.3;6.9;Cadastre;A 1.0;POLYGON Z ((355763.1 6688888.1 17.8, 355765.3 6688889.1 17.8, 355767.4 6688884.6 17.8, 355756.5 6688879.7 17.8, 355751.2 6688891.3 17.8, 355759.9 6688895 17.8, 355763.1 6688888.1 17.8))
BATIMENT0000000327821908;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:45:28;2019-07-01 11:20:02;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;10.6;8.7;;;;Imagerie aérienne;;POLYGON Z ((355572.4 6688806.5 19.3, 355575.7 6688806.4 19.3, 355579.3 6688805.7 19.3, 355582 6688804.8 19.3, 355585.7 6688802.8 19.3, 355587.8 6688800.9 19.3, 355589.1 6688799.1 19.3, 355589.6 6688797.5 19.3, 355589.4 6688795.8 19.3, 355588.9 6688794.3 19.3, 355587.5 6688792.9 19.3, 355585.8 6688791.9 19.3, 355582.6 6688791.4 19.3, 355582.2 6688787.9 19.3, 355576.9 6688789.1 19.3, 355577.5 6688792.4 19.3, 355567.6 6688794.6 19.3, 355567.9 6688796.3 19.3, 355569.8 6688796.1 19.3, 355571.7 6688796.6 19.3, 355573 6688797.5 19.3, 355573.5 6688799.1 19.3, 355573.5 6688800.8 19.3, 355572.6 6688802.4 19.3, 355571.6 6688803.5 19.3, 355569.4 6688804.6 19.3, 355569.2 6688806.1 19.3, 355572.4 6688806.5 19.3))
BATIMENT0000000302929541;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;7.8;16.7;26.8;8.3;Cadastre;;POLYGON Z ((355646.4 6688807.8 16.7, 355646.8 6688809.8 16.7, 355646.9 6688810.6 16.7, 355650.1 6688810 16.7, 355649.4 6688807.1 16.7, 355647.3 6688796.3 16.7, 355644.3 6688796.9 16.7, 355646.4 6688807.8 16.7))
BATIMENT0000000302929546;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.0;7.5;24.5;26.5;8.3;Cadastre;;POLYGON Z ((355574.3 6688823.4 24.5, 355574.9 6688825.6 24.5, 355646.8 6688809.8 24.5, 355646.4 6688807.8 24.5, 355574.3 6688823.4 24.5))
BATIMENT0000000302929542;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.0;7.9;25.9;28.8;8.4;Cadastre;;POLYGON Z ((355652 6688809.5 25.9, 355662.5 6688816.5 25.9, 355646.3 6688840 25.9, 355642.7 6688837.4 25.9, 355642.8 6688837.8 25.9, 355643.1 6688838.5 25.9, 355643.3 6688838.9 25.9, 355643.3 6688839.3 25.9, 355643.4 6688839.6 25.9, 355643.5 6688840 25.9, 355643.5 6688840.8 25.9, 355643.5 6688841.2 25.9, 355643.4 6688842 25.9, 355643.4 6688842.4 25.9, 355643.2 6688843.1 25.9, 355643 6688843.5 25.9, 355642.9 6688843.9 25.9, 355642.5 6688844.6 25.9, 355642.3 6688844.9 25.9, 355641.8 6688845.5 25.9, 355641.3 6688846.1 25.9, 355641 6688846.4 25.9, 355640.7 6688846.6 25.9, 355640.4 6688846.8 25.9, 355640.1 6688847 25.9, 355639.7 6688847.2 25.9, 355639.4 6688847.4 25.9, 355639 6688847.6 25.9, 355638.6 6688847.7 25.9, 355638.3 6688847.8 25.9, 355637.9 6688847.9 25.9, 355637.5 6688848 25.9, 355637.1 6688848.1 25.9, 355636.7 6688848.1 25.9, 355636.3 6688848.1 25.9, 355635.9 6688848.1 25.9, 355635.5 6688848.1 25.9, 355630.6 6688855.2 25.9, 355634 6688857.6 25.9, 355622.8 6688874.1 25.9, 355624.7 6688875.4 25.9, 355642 6688850.1 25.9, 355655.6 6688829.9 25.9, 355665.3 6688815.6 25.9, 355654.8 6688808.3 25.9, 355654.5 6688808.2 25.9, 355654.4 6688808.1 25.9, 355654.2 6688807.9 25.9, 355653.9 6688807.8 25.9, 355653.7 6688807.7 25.9, 355653.3 6688807.5 25.9, 355652.8 6688807.3 25.9, 355652.7 6688807.2 25.9, 355652.4 6688807.2 25.9, 355652 6688807.1 25.9, 355651.3 6688807 25.9, 355651.1 6688807 25.9, 355650.4 6688807 25.9, 355650.1 6688807 25.9, 355649.9 6688807 25.9, 355649.4 6688807.1 25.9, 355650.1 6688810 25.9, 355652 6688809.5 25.9))
BATIMENT0000000302929547;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2023-01-31 17:48:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.3;8.0;27.3;27.3;8.2;Cadastre;;POLYGON Z ((355585.1 6688839.4 27.3, 355586.3 6688845.1 27.3, 355592.6 6688843.7 27.3, 355591 6688837.8 27.3, 355585.1 6688839.4 27.3))
BATIMENT0000000302929548;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.7;8.0;27.7;31.4;8.2;Cadastre;;POLYGON Z ((355616.9 6688854.3 27.7, 355616.6 6688853.3 27.7, 355618.8 6688852.7 27.7, 355618.4 6688850.4 27.7, 355618 6688848.5 27.7, 355615.7 6688849.2 27.7, 355615.1 6688846.5 27.7, 355594.8 6688851 27.7, 355595.1 6688852.6 27.7, 355596.5 6688858.9 27.7, 355616.9 6688854.3 27.7))
BATIMENT0000000302930179;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;7.9;20.2;39.0;11.9;Cadastre;;POLYGON Z ((355486.9 6688866.5 20.2, 355490 6688881.4 20.2, 355516.4 6688875.3 20.2, 355519.1 6688890.2 20.2, 355510.3 6688892.8 20.2, 355521.3 6688890.3 20.2, 355525.4 6688889.4 20.2, 355534.7 6688887.4 20.2, 355536.4 6688887 20.2, 355547.1 6688884.6 20.2, 355553.9 6688883.1 20.2, 355583.3 6688876.6 20.2, 355588.3 6688899.1 20.2, 355604.2 6688894.7 20.2, 355596.5 6688858.9 20.2, 355595.1 6688852.6 20.2, 355594.8 6688851 20.2, 355615.1 6688846.5 20.2, 355615.7 6688849.2 20.2, 355618 6688848.5 20.2, 355618.4 6688850.4 20.2, 355624.4 6688849.2 20.2, 355612.2 6688867.1 20.2, 355622.8 6688874.1 20.2, 355634 6688857.6 20.2, 355630.6 6688855.2 20.2, 355635.5 6688848.1 20.2, 355635.9 6688848.1 20.2, 355636.3 6688848.1 20.2, 355636.7 6688848.1 20.2, 355637.1 6688848.1 20.2, 355637.5 6688848 20.2, 355637.9 6688847.9 20.2, 355638.3 6688847.8 20.2, 355638.6 6688847.7 20.2, 355639 6688847.6 20.2, 355639.4 6688847.4 20.2, 355639.7 6688847.2 20.2, 355640.1 6688847 20.2, 355640.4 6688846.8 20.2, 355640.7 6688846.6 20.2, 355641 6688846.4 20.2, 355641.3 6688846.1 20.2, 355641.8 6688845.5 20.2, 355642.3 6688844.9 20.2, 355642.5 6688844.6 20.2, 355642.9 6688843.9 20.2, 355643 6688843.5 20.2, 355643.2 6688843.1 20.2, 355643.4 6688842.4 20.2, 355643.4 6688842 20.2, 355643.5 6688841.2 20.2, 355643.5 6688840.8 20.2, 355643.5 6688840 20.2, 355643.4 6688839.6 20.2, 355643.3 6688839.3 20.2, 355643.3 6688838.9 20.2, 355643.1 6688838.5 20.2, 355642.8 6688837.8 20.2, 355642.7 6688837.4 20.2, 355646.3 6688840 20.2, 355662.5 6688816.5 20.2, 355652 6688809.5 20.2, 355650.1 6688810 20.2, 355646.9 6688810.6 20.2, 355646.8 6688809.8 20.2, 355574.9 6688825.6 20.2, 355574.3 6688823.4 20.2, 355573.8 6688821.2 20.2, 355570.4 6688822 20.2, 355572.2 6688829.4 20.2, 355575 6688830.9 20.2, 355576.4 6688845.8 20.2, 355576.7 6688847.2 20.2, 355577.1 6688849 20.2, 355515.1 6688862.7 20.2, 355514.5 6688859.7 20.2, 355537.2 6688854.6 20.2, 355572.1 6688846.8 20.2, 355570.8 6688842.9 20.2, 355480.4 6688863.1 20.2, 355481.2 6688868.4 20.2, 355486.9 6688866.5 20.2), (355585.1 6688839.4 20.2, 355591 6688837.8 20.2, 355592.6 6688843.7 20.2, 355586.3 6688845.1 20.2, 355585.1 6688839.4 20.2))
BATIMENT0000000302930177;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:20:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;7.8;12.8;17.7;8.2;Cadastre;;POLYGON Z ((355606 6688902.8 12.8, 355604.2 6688894.7 12.8, 355588.3 6688899.1 12.8, 355593.3 6688921 12.8, 355606 6688902.8 12.8))
BATIMENT0000000302930147;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.4;8.7;18.2;19.5;9.2;Cadastre;;POLYGON Z ((355588.3 6688996.2 18.2, 355589.4 6688994 18.2, 355585.4 6688992.1 18.2, 355585.3 6688992.1 18.2, 355584.3 6688994.3 18.2, 355588.3 6688996.2 18.2))
BATIMENT0000000302930144;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.0;8.0;19.0;19.6;9.2;Cadastre;;POLYGON Z ((355589.4 6688994 19, 355588.3 6688996.2 19, 355591 6688997.6 19, 355591.8 6688998 19, 355592.8 6688995.7 19, 355589.4 6688994 19))
BATIMENT0000000302929376;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.7;6.2;14.9;17.7;7.0;Cadastre;C 0.3;POLYGON Z ((355819.7 6688898.9 14.9, 355804 6688892.2 14.9, 355800.8 6688899.8 14.9, 355808.8 6688903.4 14.9, 355814.2 6688905.8 14.9, 355816.2 6688906.7 14.9, 355819.7 6688898.9 14.9))
BATIMENT0000000302929381;Industriel, agricole ou commercial;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;20;20;11.1;6.6;17.7;24.2;7.3;Cadastre;A 1.0;POLYGON Z ((355745.9 6688908.4 17.7, 355768.6 6688917.7 17.7, 355768.9 6688917.8 17.7, 355770.2 6688914.4 17.7, 355772.8 6688908.3 17.7, 355775.5 6688901.9 17.7, 355759.9 6688895 17.7, 355751.2 6688891.3 17.7, 355744.6 6688905.6 17.7, 355745.9 6688908.4 17.7), (355754.8 6688897.2 17.7, 355772.7 6688904.6 17.7, 355772 6688906.4 17.7, 355754 6688898.9 17.7, 355754.8 6688897.2 17.7))
BATIMENT0000000302929377;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;6.0;12.7;15.2;7.3;Cadastre;;POLYGON Z ((355793.1 6688896.3 12.7, 355787.8 6688907.6 12.7, 355795.6 6688911.3 12.7, 355804.6 6688915.4 12.7, 355807.3 6688906.4 12.7, 355808.8 6688903.4 12.7, 355800.8 6688899.8 12.7, 355793.1 6688896.3 12.7))
BATIMENT0000000302929379;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;50;20;6.9;6.2;13.1;14.5;7.2;Cadastre;A 1.0;POLYGON Z ((355791 6688916.4 13.1, 355790.9 6688916.6 13.1, 355791.1 6688916.7 13.1, 355792.9 6688917.5 13.1, 355795.6 6688911.3 13.1, 355787.8 6688907.6 13.1, 355775.5 6688901.9 13.1, 355772.8 6688908.3 13.1, 355791 6688916.4 13.1))
BATIMENT0000000302929378;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;9.2;6.7;16.0;27.0;7.0;Cadastre;C 0.6;POLYGON Z ((355812.6 6688908.9 16, 355807.3 6688906.4 16, 355804.6 6688915.4 16, 355811.2 6688918.5 16, 355825.4 6688924.9 16, 355829.1 6688912.8 16, 355818.5 6688907.8 16, 355816.2 6688906.7 16, 355814.2 6688905.8 16, 355812.7 6688908.8 16, 355812.6 6688908.9 16), (355812.6 6688909.8 16, 355812.8 6688909.9 16, 355816.3 6688911.6 16, 355815.1 6688914.2 16, 355817.6 6688915.4 16, 355817.9 6688916 16, 355818.5 6688916.4 16, 355818.2 6688916.9 16, 355814.7 6688915.3 16, 355812.7 6688916.1 16, 355814.3 6688912.8 16, 355812.1 6688911.7 16, 355812.6 6688909.8 16))
BATIMENT0000000302929382;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;90;90;9.0;6.6;15.7;24.1;7.3;Cadastre;A 1.0;POLYGON Z ((355786.6 6688922.4 15.7, 355786 6688921.1 15.7, 355781.8 6688919.4 15.7, 355782.1 6688918.5 15.7, 355781 6688918 15.7, 355780.7 6688918.9 15.7, 355780.2 6688918.6 15.7, 355770.2 6688914.4 15.7, 355768.9 6688917.8 15.7, 355768.6 6688917.7 15.7, 355767.3 6688920.8 15.7, 355777.4 6688925 15.7, 355784.4 6688927.9 15.7, 355785.6 6688924.9 15.7, 355786.6 6688922.4 15.7))
BATIMENT0000000302929387;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;7.3;6.6;14.0;16.2;7.0;Cadastre;A 1.0;POLYGON Z ((355792.9 6688917.5 14, 355791.1 6688916.7 14, 355793.6 6688922.4 14, 355794 6688923.2 14, 355790.8 6688930.7 14, 355802.9 6688935.7 14, 355806.6 6688927.9 14, 355794.5 6688922.7 14, 355794.8 6688921.9 14, 355794 6688921.5 14, 355795.2 6688918.9 14, 355808.2 6688924.7 14, 355811.2 6688918.5 14, 355804.6 6688915.4 14, 355795.6 6688911.3 14, 355792.9 6688917.5 14))
BATIMENT0000000302930090;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;6.6;12.5;16.7;7.0;Cadastre;;POLYGON Z ((355791.8 6688922 12.5, 355789.6 6688930.1 12.5, 355790.8 6688930.7 12.5, 355794 6688923.2 12.5, 355793.6 6688922.4 12.5, 355791.8 6688922 12.5))
BATIMENT0000000302930089;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;6.8;13.2;16.6;7.1;Cadastre;;POLYGON Z ((355786.5 6688928.8 13.2, 355786.8 6688927.1 13.2, 355786.6 6688925.4 13.2, 355785.6 6688924.9 13.2, 355784.4 6688927.9 13.2, 355786.5 6688928.8 13.2))
BATIMENT0000000302929552;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;01;02;11.4;6.3;17.7;20.5;7.0;Cadastre;A 1.0;POLYGON Z ((355744.8 6688936.4 17.7, 355746.9 6688931.6 17.7, 355747.2 6688931.7 17.7, 355749.2 6688927.2 17.7, 355748.9 6688927.1 17.7, 355751.2 6688922.1 17.7, 355744.7 6688919.4 17.7, 355742.8 6688924.1 17.7, 355740.4 6688929.4 17.7, 355731.9 6688925.8 17.7, 355730.2 6688929.6 17.7, 355744.6 6688936.3 17.7, 355744.8 6688936.4 17.7))
BATIMENT0000000302929373;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;12.7;6.7;19.4;23.9;7.7;Cadastre;A 1.0;POLYGON Z ((355693.6 6688886.9 19.4, 355708.3 6688893 19.4, 355710.3 6688888 19.4, 355710.9 6688886.4 19.4, 355709.1 6688885.7 19.4, 355696.7 6688880.4 19.4, 355693.6 6688886.9 19.4))
BATIMENT0000000302929371;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;13;20;6.1;6.9;13.0;19.4;7.7;Cadastre;A 1.0;POLYGON Z ((355737.3 6688897.6 13, 355737.2 6688897.9 13, 355737.4 6688898 13, 355742.1 6688887.6 13, 355741.9 6688887.5 13, 355717.2 6688877 13, 355713.6 6688875.5 13, 355711.4 6688880.4 13, 355712.8 6688881 13, 355711.6 6688883.7 13, 355710.2 6688883.1 13, 355709.1 6688885.7 13, 355710.9 6688886.4 13, 355737.3 6688897.6 13))
BATIMENT0000000327821801;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;25.0;5.0;10;20;13.1;6.3;;21.8;7.6;Imagerie aérienne;A 1.0;POLYGON Z ((355737.4 6688898 17, 355737.2 6688897.9 17, 355737.3 6688897.6 17, 355710.9 6688886.4 19.4, 355708.3 6688893 19.4, 355734.8 6688904.1 19, 355737.4 6688898 17))
BATIMENT0000000302929391;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.7;6.5;17.2;18.9;7.4;Cadastre;;POLYGON Z ((355686.8 6688907.4 17.2, 355685.6 6688910.4 17.2, 355695 6688914.7 17.2, 355701.2 6688917.5 17.2, 355702.7 6688914 17.2, 355696.6 6688911.4 17.2, 355686.8 6688907.4 17.2))
BATIMENT0000000302929392;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.2;6.5;16.7;19.7;7.5;Cadastre;A 1.0;POLYGON Z ((355696.6 6688911.4 16.7, 355702.7 6688914 16.7, 355715.9 6688919.5 16.7, 355714.5 6688922.7 16.7, 355710.3 6688932.7 16.7, 355721.4 6688937.5 16.7, 355726 6688927.3 16.7, 355731.9 6688913.9 16.7, 355732 6688913.7 16.7, 355718 6688907.8 16.7, 355690.2 6688896.2 16.7, 355686.4 6688905.1 16.7, 355687.6 6688905.6 16.7, 355687.3 6688906.3 16.7, 355686.8 6688907.4 16.7, 355696.6 6688911.4 16.7))
BATIMENT0000000302929393;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;10;20;11.6;6.8;18.4;21.1;7.4;Cadastre;A 1.0;POLYGON Z ((355679.3 6688916.9 18.4, 355674.4 6688927.5 18.4, 355684.3 6688931.9 18.4, 355686.5 6688932.9 18.4, 355688.5 6688928.5 18.4, 355689.8 6688925.7 18.4, 355692.9 6688927 18.4, 355694.2 6688924.8 18.4, 355694.4 6688924 18.4, 355691.3 6688922.6 18.4, 355692.1 6688920.9 18.4, 355693 6688921.3 18.4, 355693.5 6688920.3 18.4, 355692.5 6688919.8 18.4, 355693.9 6688916.8 18.4, 355700.2 6688919.6 18.4, 355701.2 6688917.5 18.4, 355695 6688914.7 18.4, 355685.6 6688910.4 18.4, 355683 6688909.2 18.4, 355679.3 6688916.9 18.4))
BATIMENT0000000302930107;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;10.1;6.0;16.2;20.7;7.0;Cadastre;A 1.0;POLYGON Z ((355723 6688938.8 16.2, 355740.1 6688946.2 16.2, 355744.6 6688936.3 16.2, 355730.2 6688929.6 16.2, 355727.7 6688928.5 16.2, 355723 6688938.8 16.2))
BATIMENT0000000302930152;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.9;5.3;12.2;14.7;7.3;Cadastre;A 1.0;POLYGON Z ((355707.2 6688944.9 12.2, 355706.6 6688944.6 12.2, 355709.9 6688936.9 12.2, 355705.4 6688934.9 12.2, 355701.3 6688943 12.2, 355701.7 6688943.1 12.2, 355700.9 6688944.7 12.2, 355703.9 6688946.1 12.2, 355706.2 6688947.2 12.2, 355707.2 6688944.9 12.2))
BATIMENT0000000302930151;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;4.2;5.7;10.0;13.6;7.4;Cadastre;C 0.3;POLYGON Z ((355691.3 6688928.7 10, 355689.3 6688933.1 10, 355688.8 6688934 10, 355696.9 6688937.6 10, 355691.7 6688948.3 10, 355697.9 6688951.3 10, 355698.2 6688950.6 10, 355701.1 6688951.9 10, 355703.8 6688953.2 10, 355712 6688956.9 10, 355714.6 6688951.1 10, 355712 6688949.9 10, 355709.3 6688948.6 10, 355706.6 6688947.4 10, 355706.2 6688947.2 10, 355703.9 6688946.1 10, 355700.9 6688944.7 10, 355701.7 6688943.1 10, 355701.3 6688943 10, 355705.4 6688934.9 10, 355691.3 6688928.7 10))
BATIMENT0000000302930153;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;6.3;5.5;11.8;14.7;7.0;Cadastre;A 1.0;POLYGON Z ((355719.3 6688941.1 11.8, 355709.9 6688936.9 11.8, 355706.6 6688944.6 11.8, 355707.2 6688944.9 11.8, 355706.2 6688947.2 11.8, 355706.6 6688947.4 11.8, 355709.3 6688948.6 11.8, 355712 6688949.9 11.8, 355714.6 6688951.1 11.8, 355719.3 6688941.1 11.8))
BATIMENT0000000302929380;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;3.0;10;20;10.0;6.0;16.0;21.2;7.0;Cadastre;A 1.0;POLYGON Z ((355808.9 6688938.1 16, 355815.5 6688924.4 16, 355818.4 6688925.9 16, 355815 6688932.3 16, 355816.2 6688933 16, 355815.6 6688933.9 16, 355812.4 6688932.8 16, 355810.3 6688938.7 16, 355819.9 6688942.6 16, 355825.4 6688924.9 16, 355811.2 6688918.5 16, 355808.2 6688924.7 16, 355806.6 6688927.9 16, 355802.9 6688935.7 16, 355808.9 6688938.1 16))
BATIMENT0000000302930104;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;4.0;20;20;8.9;6.7;15.6;19.0;7.4;Cadastre;A 1.0;POLYGON Z ((355759.1 6688942.6 15.6, 355759.3 6688942.7 15.6, 355761.5 6688937.6 15.6, 355775.6 6688943.7 15.6, 355773.5 6688948.9 15.6, 355775.4 6688949.8 15.6, 355776.1 6688950.1 15.6, 355780.5 6688952 15.6, 355781.3 6688952.4 15.6, 355782.7 6688949.3 15.6, 355782.7 6688949.4 15.6, 355786.7 6688940.5 15.6, 355786.7 6688940.4 15.6, 355786.8 6688940.4 15.6, 355785.4 6688939.8 15.6, 355761.5 6688929.7 15.6, 355761 6688929.5 15.6, 355755.7 6688941.2 15.6, 355756.5 6688941.5 15.6, 355759.1 6688942.6 15.6))
BATIMENT0000000302930103;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;6.7;14.7;16.2;7.0;Cadastre;;POLYGON Z ((355742.8 6688947.3 14.7, 355747.1 6688937.4 14.7, 355744.8 6688936.4 14.7, 355744.6 6688936.3 14.7, 355740.1 6688946.2 14.7, 355742.8 6688947.3 14.7))
BATIMENT0000000302930101;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;10;20;7.4;6.8;14.2;15.8;7.2;Cadastre;A 1.0;POLYGON Z ((355754.7 6688952.1 14.2, 355759.1 6688942.6 14.2, 355756.5 6688941.5 14.2, 355755.7 6688941.2 14.2, 355751.4 6688939.3 14.2, 355747.1 6688937.4 14.2, 355742.8 6688947.3 14.2, 355754.7 6688952.1 14.2))
BATIMENT0000000302930102;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.0;6.8;13.8;15.7;7.2;Cadastre;A 1.0;POLYGON Z ((355764.2 6688956.3 13.8, 355768.4 6688946.7 13.8, 355760.8 6688943.4 13.8, 355756.8 6688953 13.8, 355764.2 6688956.3 13.8))
BATIMENT0000000302930108;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;6.8;12.2;15.5;7.0;Cadastre;;POLYGON Z ((355782.5 6688952.9 12.2, 355787.1 6688954.9 12.2, 355788 6688953 12.2, 355784.4 6688950.1 12.2, 355782.7 6688949.4 12.2, 355782.7 6688949.3 12.2, 355781.3 6688952.4 12.2, 355782.5 6688952.9 12.2))
BATIMENT0000000302930105;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;20;7.1;6.8;13.9;15.1;7.1;Cadastre;A 1.0;POLYGON Z ((355771.2 6688959.4 13.9, 355775.4 6688949.8 13.9, 355773.5 6688948.9 13.9, 355768.4 6688946.7 13.9, 355764.2 6688956.3 13.9, 355771.2 6688959.4 13.9))
BATIMENT0000000302930106;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.7;6.8;14.5;15.1;7.1;Cadastre;A 1.0;POLYGON Z ((355778.3 6688962.5 14.5, 355782.5 6688952.9 14.5, 355781.3 6688952.4 14.5, 355780.5 6688952 14.5, 355776.1 6688950.1 14.5, 355775.4 6688949.8 14.5, 355771.2 6688959.4 14.5, 355778.3 6688962.5 14.5))
BATIMENT0000000302930110;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.7;6.7;14.4;16.9;7.3;Cadastre;;POLYGON Z ((355793.9 6688943.6 14.4, 355792.9 6688944.8 14.4, 355794.4 6688946.1 14.4, 355793.5 6688947.1 14.4, 355792.5 6688946.4 14.4, 355791 6688950.1 14.4, 355790.6 6688949.9 14.4, 355789.2 6688955.9 14.4, 355799.8 6688960.5 14.4, 355796.5 6688968.8 14.4, 355798.8 6688969.8 14.4, 355803.5 6688971.9 14.4, 355803.8 6688972.1 14.4, 355806.1 6688973.1 14.4, 355807.1 6688969.5 14.4, 355806.2 6688969.2 14.4, 355807.7 6688964.1 14.4, 355808.7 6688964.4 14.4, 355809.6 6688961.6 14.4, 355807.8 6688961.1 14.4, 355807.2 6688959 14.4, 355808.5 6688958 14.4, 355810.7 6688957.8 14.4, 355810.5 6688954.7 14.4, 355810.4 6688954.7 14.4, 355810.5 6688953.2 14.4, 355810.6 6688953.2 14.4, 355810.9 6688949.8 14.4, 355808 6688949.5 14.4, 355807.4 6688950 14.4, 355805.3 6688949.1 14.4, 355805.8 6688948.1 14.4, 355800.8 6688946 14.4, 355800.7 6688946.4 14.4, 355793.9 6688943.6 14.4))
BATIMENT0000000302930112;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.4;6.7;15.1;16.9;7.0;Cadastre;;POLYGON Z ((355807.2 6688959 15.1, 355807.8 6688961.1 15.1, 355808.5 6688958 15.1, 355807.2 6688959 15.1))
BATIMENT0000000302930091;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;35;20;19.7;7.3;27.0;32.8;7.4;Cadastre;C 0.7;POLYGON Z ((355663.7 6688950.4 27, 355654.4 6688970.5 27, 355670.5 6688978 27, 355672.4 6688973.9 27, 355666.4 6688971 27, 355668.3 6688966.9 27, 355668.4 6688966.8 27, 355668.6 6688966.7 27, 355668.7 6688966.6 27, 355668.9 6688966.5 27, 355669.2 6688966.3 27, 355669.4 6688966.1 27, 355669.5 6688966 27, 355669.6 6688965.8 27, 355669.7 6688965.6 27, 355669.9 6688965.3 27, 355670 6688964.9 27, 355670 6688964.7 27, 355670 6688964.4 27, 355670 6688964.2 27, 355669.9 6688964 27, 355669.8 6688963.7 27, 355669.8 6688963.6 27, 355673.8 6688954.9 27, 355678.5 6688944.6 27, 355678.7 6688944.5 27, 355679 6688944.3 27, 355679.2 6688944.3 27, 355679.3 6688944.2 27, 355679.4 6688944 27, 355679.5 6688943.9 27, 355679.6 6688943.8 27, 355679.7 6688943.6 27, 355679.8 6688943.5 27, 355679.9 6688943.3 27, 355680 6688943 27, 355680 6688942.8 27, 355680 6688942.6 27, 355680 6688942.5 27, 355679.9 6688942.1 27, 355679.8 6688941.8 27, 355679.9 6688941.7 27, 355684.3 6688931.9 27, 355674.4 6688927.5 27, 355663.7 6688950.4 27))
BATIMENT0000000302930134;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;8.9;6.9;15.8;;;Cadastre;A 1.0;POLYGON Z ((355727.1 6688957.8 15.8, 355729.8 6688959.2 15.8, 355731.7 6688960.2 15.8, 355731.5 6688960.7 15.8, 355743 6688966.1 15.8, 355748 6688955 15.8, 355725.3 6688945.2 15.8, 355721.1 6688954.5 15.8, 355726.7 6688957.4 15.8, 355726.5 6688957.8 15.8, 355727.1 6688957.8 15.8))
BATIMENT0000000302930128;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;35;40;6.2;7.0;13.2;14.1;7.4;Cadastre;C 0.1;POLYGON Z ((355696.2 6688959.3 13.2, 355695.9 6688959.1 13.2, 355695.8 6688959.3 13.2, 355695.4 6688959.1 13.2, 355696.3 6688957.5 13.2, 355690.1 6688954.5 13.2, 355684 6688967.1 13.2, 355689.4 6688969.7 13.2, 355692 6688964.3 13.2, 355693.4 6688965 13.2, 355696.2 6688959.3 13.2))
BATIMENT0000000302930129;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;6.5;7.0;13.5;15.2;7.3;Cadastre;A 1.0;POLYGON Z ((355709.2 6688965.6 13.5, 355696.2 6688959.3 13.5, 355693.4 6688965 13.5, 355700 6688968.2 13.5, 355702.3 6688969.3 13.5, 355706.5 6688971.4 13.5, 355709.2 6688965.6 13.5))
BATIMENT0000000302930132;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;20;20;10.1;5.6;15.7;18.2;6.6;Cadastre;A 1.0;POLYGON Z ((355719.3 6688953.7 15.7, 355710.1 6688973.2 15.7, 355721 6688978.5 15.7, 355723.8 6688973.2 15.7, 355723.6 6688973.1 15.7, 355718.8 6688970.8 15.7, 355722.9 6688962.2 15.7, 355723 6688962.2 15.7, 355723.2 6688962.3 15.7, 355723.5 6688962.4 15.7, 355723.8 6688962.5 15.7, 355724.1 6688962.5 15.7, 355724.4 6688962.5 15.7, 355724.7 6688962.5 15.7, 355725 6688962.5 15.7, 355725.3 6688962.4 15.7, 355725.6 6688962.3 15.7, 355725.9 6688962.2 15.7, 355726.1 6688962.1 15.7, 355726.1 6688962 15.7, 355726.2 6688961.9 15.7, 355726.3 6688961.7 15.7, 355726.3 6688961.6 15.7, 355726.4 6688961.4 15.7, 355726.4 6688961.3 15.7, 355727.1 6688961.6 15.7, 355727.6 6688960.3 15.7, 355725.7 6688959.3 15.7, 355726.5 6688957.8 15.7, 355726.7 6688957.4 15.7, 355721.1 6688954.5 15.7, 355719.3 6688953.7 15.7))
BATIMENT0000000302930130;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;5.8;12.2;14.2;6.6;Cadastre;;POLYGON Z ((355697.7 6688972.9 12.2, 355700.1 6688974.1 12.2, 355702.3 6688969.3 12.2, 355700 6688968.2 12.2, 355697.7 6688972.9 12.2))
BATIMENT0000000302930133;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.6;7.0;12.6;;;Cadastre;A 1.0;POLYGON Z ((355730.1 6688989.6 12.6, 355735.9 6688975.8 12.6, 355731.4 6688973.7 12.6, 355732.4 6688971.8 12.6, 355737.1 6688974 12.6, 355740.6 6688966.6 12.6, 355737.5 6688965.1 12.6, 355729 6688961.2 12.6, 355723.6 6688973.1 12.6, 355723.8 6688973.2 12.6, 355721 6688978.5 12.6, 355726 6688981 12.6, 355723.3 6688986.4 12.6, 355730.1 6688989.6 12.6))
BATIMENT0000000302930131;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;35;40;6.6;6.6;13.2;;;Cadastre;A 1.0;POLYGON Z ((355706.5 6688971.4 13.2, 355702.3 6688969.3 13.2, 355700.1 6688974.1 13.2, 355699.6 6688975.1 13.2, 355723.3 6688986.4 13.2, 355726 6688981 13.2, 355721 6688978.5 13.2, 355710.1 6688973.2 13.2, 355706.5 6688971.4 13.2))
BATIMENT0000000302930127;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;90;90;8.5;5.2;13.7;17.1;6.9;Cadastre;A 1.0;POLYGON Z ((355689.4 6688980.2 13.7, 355683.5 6688977.8 13.7, 355680.1 6688985.6 13.7, 355686.4 6688987.4 13.7, 355707.3 6688996 13.7, 355710.3 6688989.1 13.7, 355689.4 6688980.2 13.7))
BATIMENT0000000302930125;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;24;20;10.9;5.7;16.6;18.3;6.7;Cadastre;A 1.0;POLYGON Z ((355710.3 6688989.1 16.6, 355707.3 6688996 16.6, 355713.4 6688998.5 16.6, 355716.3 6688991.6 16.6, 355710.3 6688989.1 16.6))
BATIMENT0000000302929444;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;6.6;6.0;12.6;14.8;7.0;Cadastre;A 1.0;POLYGON Z ((355915.1 6688796 12.6, 355915.4 6688794.1 12.6, 355918.8 6688794.8 12.6, 355919.1 6688793.2 12.6, 355919.4 6688793.2 12.6, 355921 6688785.5 12.6, 355920.8 6688785.5 12.6, 355910.8 6688783.8 12.6, 355910.4 6688783.7 12.6, 355907.2 6688794.5 12.6, 355915.1 6688796 12.6))
BATIMENT0000000302929461;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.9;6.8;19.7;20.8;7.0;Cadastre;;POLYGON Z ((355957.1 6688793.5 19.7, 355963.4 6688794.6 19.7, 355963.7 6688792.8 19.7, 355957.8 6688791.8 19.7, 355957.1 6688793.5 19.7))
BATIMENT0000000302929454;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;6.0;11.8;12.9;7.0;Cadastre;;POLYGON Z ((355918.5 6688796.6 11.8, 355918.8 6688794.8 11.8, 355915.4 6688794.1 11.8, 355915.1 6688796 11.8, 355918.5 6688796.6 11.8))
BATIMENT0000000302929463;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;7.1;12.2;;;Cadastre;;POLYGON Z ((355975 6688794.8 12.2, 355974.7 6688796.5 12.2, 355980.8 6688797.6 12.2, 355981.1 6688795.8 12.2, 355975 6688794.7 12.2, 355975 6688794.8 12.2))
BATIMENT0000000302929457;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;90;90;7.0;6.7;13.7;21.5;7.1;Cadastre;C 0.5;POLYGON Z ((355952.7 6688804.6 13.7, 355959.5 6688805.8 13.7, 355959.5 6688806.1 13.7, 355970.1 6688807.9 13.7, 355971 6688803 13.7, 355973.4 6688803.4 13.7, 355973.6 6688802.4 13.7, 355978.5 6688803.4 13.7, 355981.1 6688803.9 13.7, 355989 6688807.6 13.7, 355991.5 6688802.5 13.7, 355988 6688800.5 13.7, 355986.3 6688799.7 13.7, 355987.1 6688798 13.7, 355985.2 6688797.1 13.7, 355982.9 6688796.3 13.7, 355981.1 6688795.8 13.7, 355980.8 6688797.6 13.7, 355974.7 6688796.5 13.7, 355975 6688794.8 13.7, 355975 6688794.7 13.7, 355966.9 6688793.4 13.7, 355963.7 6688792.8 13.7, 355963.4 6688794.6 13.7, 355957.1 6688793.5 13.7, 355952.6 6688804.6 13.7, 355952.7 6688804.6 13.7))
BATIMENT0000000302929456;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;4.0;00;00;3.0;6.9;9.9;20.6;7.6;Cadastre;A 1.0;POLYGON Z ((355934.5 6688815.4 9.9, 355934.9 6688812.8 9.9, 355950.4 6688815.6 9.9, 355951.7 6688807 9.9, 355952.7 6688804.6 9.9, 355952.6 6688804.6 9.9, 355957.1 6688793.5 9.9, 355957.8 6688791.8 9.9, 355929.3 6688787 9.9, 355927.5 6688794.4 9.9, 355926.5 6688798.4 9.9, 355925.2 6688804 9.9, 355919.7 6688803 9.9, 355918.2 6688812.8 9.9, 355934.5 6688815.4 9.9))
BATIMENT0000000302929478;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;6.9;12.7;19.0;6.9;Cadastre;;POLYGON Z ((355979.3 6688807.4 12.7, 355977 6688806.4 12.7, 355975.5 6688809.4 12.7, 355975.2 6688811.4 12.7, 355976.4 6688811.6 12.7, 355977 6688811.9 12.7, 355979.2 6688807.7 12.7, 355979.3 6688807.4 12.7))
BATIMENT0000000302929464;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;9.2;6.7;16.0;18.7;7.0;Cadastre;A 1.0;POLYGON Z ((355977.3 6688812 16, 355985.2 6688815.8 16, 355989 6688807.6 16, 355981.1 6688803.9 16, 355979.3 6688807.4 16, 355979.2 6688807.7 16, 355977 6688811.9 16, 355977.3 6688812 16))
BATIMENT0000000302929476;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;01;01;13.8;6.8;20.7;21.7;7.0;Cadastre;C 0.1;POLYGON Z ((355971.5 6688824.3 20.7, 355980.4 6688825.7 20.7, 355981.4 6688820.3 20.7, 355982.9 6688820.5 20.7, 355985.2 6688815.8 20.7, 355977.3 6688812 20.7, 355977 6688811.9 20.7, 355976.4 6688811.6 20.7, 355974.7 6688814.9 20.7, 355969.2 6688814.1 20.7, 355968.7 6688817.1 20.7, 355967.9 6688817 20.7, 355966.9 6688823.6 20.7, 355971.5 6688824.3 20.7))
BATIMENT0000000302929449;Indifférenciée;Résidentiel;Commercial et services;Oui;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;8.7;6.8;15.6;19.1;7.4;Cadastre;C 1.0;POLYGON Z ((355895.6 6688816.5 15.6, 355895 6688819.9 15.6, 355894.2 6688825.1 15.6, 355911.8 6688828 15.6, 355916.9 6688828.8 15.6, 355921.6 6688829.6 15.6, 355924.2 6688816.6 15.6, 355906 6688813.7 15.6, 355896.3 6688812.2 15.6, 355895.6 6688816.5 15.6))
BATIMENT0000000302929462;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;6.8;12.2;13.3;7.0;Cadastre;;POLYGON Z ((355986.3 6688799.7 12.2, 355988 6688800.5 12.2, 355988.8 6688798.9 12.2, 355987.1 6688798 12.2, 355986.3 6688799.7 12.2))
BATIMENT0000000302923735;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;6.7;10.7;15.8;7.3;Cadastre;;POLYGON Z ((356008 6688801.4 10.7, 356007.4 6688798.7 10.7, 356005.1 6688797.6 10.7, 356002.7 6688802.7 10.7, 356008 6688801.4 10.7))
BATIMENT0000000302923708;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;9.4;6.0;15.4;19.3;7.3;Cadastre;A 1.0;POLYGON Z ((356008 6688801.4 15.4, 356002.7 6688802.7 15.4, 355997.4 6688813.3 15.4, 356001 6688815 15.4, 356001.6 6688813.7 15.4, 356001.9 6688813.7 15.4, 356010.2 6688811.3 15.4, 356008 6688801.4 15.4))
BATIMENT0000000302923710;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;6.7;10.3;13.5;7.1;Cadastre;;POLYGON Z ((355995.7 6688816.9 10.3, 355999.4 6688818.5 10.3, 355999.6 6688819.4 10.3, 356000.8 6688819.5 10.3, 356001.4 6688816.4 10.3, 356001 6688815 10.3, 355997.4 6688813.3 10.3, 355995.7 6688816.9 10.3))
BATIMENT0000000302923732;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;30;20;8.0;6.0;14.0;16.5;7.3;Cadastre;B 0.7;POLYGON Z ((356010.2 6688811.3 14, 356001.9 6688813.7 14, 356002.1 6688817.2 14, 356003.3 6688822.8 14, 356012.2 6688820.4 14, 356010.2 6688811.3 14))
BATIMENT0000000302923706;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;4.9;6.4;11.3;13.7;7.1;Cadastre;A 1.0;POLYGON Z ((355992 6688824.5 11.3, 355997.7 6688827.2 11.3, 355998.3 6688826.1 11.3, 356000.2 6688822.4 11.3, 355999.6 6688819.4 11.3, 355999.4 6688818.5 11.3, 355995.7 6688816.9 11.3, 355992 6688824.5 11.3))
BATIMENT0000000302923707;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;6.9;8.7;10.5;7.3;Cadastre;;POLYGON Z ((355998.3 6688826.1 8.7, 355999.7 6688826.7 8.7, 356001.3 6688827.5 8.7, 356000.4 6688823.4 8.7, 356000.2 6688822.4 8.7, 355998.3 6688826.1 8.7))
BATIMENT0000000302923730;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;10;4.8;7.0;11.8;16.0;7.4;Cadastre;A 0.9;POLYGON Z ((356012.2 6688820.4 11.8, 356003.3 6688822.8 11.8, 356005.2 6688831.5 11.8, 356005.4 6688832.3 11.8, 356005.6 6688832.3 11.8, 356014.2 6688830 11.8, 356012.2 6688820.4 11.8))
BATIMENT0000000302923705;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;7.0;8.2;10.0;7.3;Cadastre;;POLYGON Z ((356001.9 6688830.1 8.2, 356001.3 6688827.5 8.2, 355999.7 6688826.7 8.2, 355998.8 6688828.8 8.2, 356001.9 6688830.1 8.2))
BATIMENT0000000302923704;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;00;00;4.8;6.4;11.2;13.4;7.3;Cadastre;A 1.0;POLYGON Z ((355987.3 6688834.3 11.2, 355993 6688837 11.2, 355997.1 6688835.9 11.2, 355998.3 6688833.1 11.2, 355999 6688831.7 11.2, 356000.8 6688832.5 11.2, 356001.9 6688830.1 11.2, 355998.8 6688828.8 11.2, 355999.7 6688826.7 11.2, 355998.3 6688826.1 11.2, 355997.7 6688827.2 11.2, 355992 6688824.5 11.2, 355987.3 6688834.3 11.2))
BATIMENT0000000302929480;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;20;20;10.6;6.8;17.5;19.4;7.0;Cadastre;C 0.9;POLYGON Z ((355971.5 6688824.3 17.5, 355966.9 6688823.6 17.5, 355966.5 6688823.5 17.5, 355965.6 6688829.2 17.5, 355970.7 6688830.3 17.5, 355970.5 6688831.2 17.5, 355969.4 6688831 17.5, 355968 6688837.5 17.5, 355974.2 6688838.8 17.5, 355980.4 6688825.7 17.5, 355971.5 6688824.3 17.5))
BATIMENT0000000302929482;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;3.3;6.6;10.0;12.5;7.0;Cadastre;C 0.5;POLYGON Z ((355960.7 6688836.1 10, 355961.5 6688831.1 10, 355951 6688829.4 10, 355950.2 6688834.4 10, 355953.1 6688834.8 10, 355960.7 6688836.1 10))
BATIMENT0000000302929451;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;3.2;6.8;10.0;10.6;7.1;Cadastre;C 0.1;POLYGON Z ((355921.5 6688834.7 10, 355932.2 6688836.3 10, 355932.9 6688831.5 10, 355922.3 6688829.7 10, 355921.5 6688834.7 10))
BATIMENT0000000302929450;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.4;6.0;10.4;14.5;7.1;Cadastre;;POLYGON Z ((355916.9 6688828.8 10.4, 355911.8 6688828 10.4, 355909.4 6688841.1 10.4, 355914.6 6688842 10.4, 355916.9 6688828.8 10.4))
BATIMENT0000000302929483;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;4.6;6.1;10.7;11.5;7.1;Cadastre;C 0.6;POLYGON Z ((355937.1 6688832.2 10.7, 355936.4 6688836.9 10.7, 355952.3 6688839.6 10.7, 355953.1 6688834.8 10.7, 355950.2 6688834.4 10.7, 355937.1 6688832.2 10.7))
BATIMENT0000000302929481;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;9.5;6.7;16.2;17.1;7.0;Cadastre;A 1.0;POLYGON Z ((355962.6 6688836.4 16.2, 355961.8 6688842 16.2, 355971.8 6688843.6 16.2, 355974.2 6688838.8 16.2, 355968 6688837.5 16.2, 355962.6 6688836.4 16.2))
BATIMENT0000000302929477;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;6.8;12.4;13.8;7.2;Cadastre;;POLYGON Z ((355935.8 6688840.2 12.4, 355930.6 6688839 12.4, 355929.5 6688844.6 12.4, 355934.9 6688845.5 12.4, 355935.8 6688840.4 12.4, 355935.8 6688840.2 12.4))
BATIMENT0000000302929475;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;6.2;6.7;13.0;14.0;7.2;Cadastre;A 1.0;POLYGON Z ((355935.8 6688840.4 13, 355934.9 6688845.5 13, 355934.8 6688845.9 13, 355943.7 6688847.6 13, 355943.8 6688847.4 13, 355944.8 6688847.6 13, 355945.8 6688842.1 13, 355935.8 6688840.4 13))
BATIMENT0000000302929459;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.1;6.0;10.1;13.1;7.0;Cadastre;C 0.3;POLYGON Z ((355910.5 6688847.9 10.1, 355910.6 6688847 10.1, 355926 6688850.6 10.1, 355927.3 6688844.2 10.1, 355914.6 6688842 10.1, 355909.4 6688841.1 10.1, 355901.1 6688839.7 10.1, 355900 6688845.4 10.1, 355900.2 6688845.5 10.1, 355910.5 6688847.9 10.1))
BATIMENT0000000302929473;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;90;5.5;6.1;11.6;15.3;7.0;Cadastre;A 1.0;POLYGON Z ((355948 6688842.4 11.6, 355945.8 6688842.1 11.6, 355944.8 6688847.6 11.6, 355948.6 6688848.4 11.6, 355955.1 6688849.8 11.6, 355956.2 6688844.4 11.6, 355948 6688842.4 11.6))
BATIMENT0000000302929328;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;6.8;11.7;14.5;7.0;Cadastre;;POLYGON Z ((355832.3 6688821.6 11.7, 355846 6688824.5 11.7, 355846.4 6688822.6 11.7, 355839.4 6688821.2 11.7, 355833.1 6688819.9 11.7, 355832.3 6688821.6 11.7))
BATIMENT0000000302929331;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;50;10;4.8;7.3;12.1;;;Cadastre;C 0.3;POLYGON Z ((355827.2 6688818.7 12.1, 355823.6 6688818 12.1, 355823.6 6688817.8 12.1, 355822.4 6688817.5 12.1, 355818.9 6688825.8 12.1, 355823.3 6688827.7 12.1, 355827.2 6688818.7 12.1))
BATIMENT0000000302929452;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;5.8;6.0;11.8;16.7;7.1;Cadastre;A 1.0;POLYGON Z ((355864.9 6688833.5 11.8, 355868.2 6688834 11.8, 355883 6688836.6 11.8, 355898.7 6688839.3 11.8, 355901.1 6688839.7 11.8, 355909.4 6688841.1 11.8, 355911.8 6688828 11.8, 355894.2 6688825.1 11.8, 355886.5 6688823.8 11.8, 355868.9 6688820.9 11.8, 355864.9 6688833.5 11.8))
BATIMENT0000000302929389;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.4;7.1;10.5;15.4;7.2;Cadastre;C 0.8;POLYGON Z ((355854.2 6688831.5 10.5, 355847.1 6688829.9 10.5, 355843.2 6688828 10.5, 355841.8 6688830.9 10.5, 355830.4 6688825.7 10.5, 355827.8 6688830.8 10.5, 355825.9 6688829.9 10.5, 355824.7 6688832.5 10.5, 355827.4 6688833.8 10.5, 355838.1 6688838.8 10.5, 355848.5 6688843.6 10.5, 355850.3 6688844.4 10.5, 355854.2 6688831.5 10.5))
BATIMENT0000000302929460;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;12;20;10.1;6.4;16.5;23.2;7.0;Cadastre;A 1.0;POLYGON Z ((355873.8 6688849 16.5, 355877 6688837.9 16.5, 355882.4 6688838.9 16.5, 355881.7 6688842.1 16.5, 355885.9 6688842.9 16.5, 355900 6688845.4 16.5, 355901.1 6688839.7 16.5, 355898.7 6688839.3 16.5, 355883 6688836.6 16.5, 355868.2 6688834 16.5, 355864.9 6688833.5 16.5, 355860.9 6688846.2 16.5, 355860.2 6688846 16.5, 355858.4 6688852 16.5, 355871.8 6688855.1 16.5, 355873.7 6688855.6 16.5, 355882.9 6688857.7 16.5, 355883.8 6688853.9 16.5, 355884.6 6688848.9 16.5, 355882 6688848.4 16.5, 355880.9 6688853 16.5, 355879.6 6688852.7 16.5, 355880.1 6688850.5 16.5, 355876.9 6688849.7 16.5, 355876.1 6688852.6 16.5, 355874.5 6688852.3 16.5, 355875.3 6688849.4 16.5, 355873.8 6688849 16.5))
BATIMENT0000000302929385;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;6.7;14.9;17.1;7.2;Cadastre;;POLYGON Z ((355850.3 6688844.4 14.9, 355848.5 6688843.6 14.9, 355847.2 6688846.2 14.9, 355845.7 6688847 14.9, 355849 6688848.5 14.9, 355850.3 6688844.4 14.9))
BATIMENT0000000302929465;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;6.4;10.7;13.6;6.5;Cadastre;;POLYGON Z ((355876.9 6688849.7 10.7, 355875.3 6688849.4 10.7, 355874.5 6688852.3 10.7, 355876.1 6688852.6 10.7, 355876.9 6688849.7 10.7))
BATIMENT0000000302929357;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;;;9.5;6.4;15.9;17.7;7.3;Cadastre;A 1.0;POLYGON Z ((355849 6688848.5 15.9, 355845.7 6688847 15.9, 355839.5 6688844.2 15.9, 355835.4 6688857 15.9, 355845.4 6688860.2 15.9, 355849 6688848.5 15.9))
BATIMENT0000000302929468;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.4;6.1;12.5;18.2;6.8;Cadastre;C 0.1;POLYGON Z ((355885.1 6688847.2 12.5, 355884.6 6688848.9 12.5, 355883.8 6688853.9 12.5, 355894 6688856.3 12.5, 355923 6688863.1 12.5, 355924.6 6688856.4 12.5, 355909.3 6688852.9 12.5, 355885.1 6688847.2 12.5))
BATIMENT0000000302929466;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;7.9;6.5;14.5;18.0;7.0;Cadastre;A 1.0;POLYGON Z ((355855.4 6688861.9 14.5, 355856 6688862 14.5, 355856.1 6688861.6 14.5, 355869.3 6688864.6 14.5, 355870.5 6688860.1 14.5, 355871.8 6688855.1 14.5, 355858.4 6688852 14.5, 355855.4 6688861.9 14.5))
BATIMENT0000000302923702;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.5;6.0;10.5;11.9;7.3;Cadastre;;POLYGON Z ((355999 6688831.7 10.5, 355998.3 6688833.1 10.5, 356000.2 6688833.9 10.5, 356000.8 6688832.5 10.5, 355999 6688831.7 10.5))
BATIMENT0000000302923731;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;7.1;12.7;15.5;7.4;Cadastre;;POLYGON Z ((356005.6 6688832.3 12.7, 356005.4 6688832.3 12.7, 356005.2 6688831.5 12.7, 356002.1 6688832.2 12.7, 356001.1 6688834.7 12.7, 356005.9 6688833.4 12.7, 356005.6 6688832.3 12.7))
BATIMENT0000000302923701;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;4.8;6.0;10.8;13.5;7.3;Cadastre;A 0.1;POLYGON Z ((355997.1 6688835.9 10.8, 355999.6 6688835.1 10.8, 356000.2 6688833.9 10.8, 355998.3 6688833.1 10.8, 355997.1 6688835.9 10.8))
BATIMENT0000000302923700;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;;;5.9;6.0;11.9;16.7;7.4;Cadastre;A 1.0;POLYGON Z ((356017.6 6688845.1 11.9, 356014.2 6688830 11.9, 356005.6 6688832.3 11.9, 356005.9 6688833.4 11.9, 356001.1 6688834.7 11.9, 355999.6 6688835.1 11.9, 355997.1 6688835.9 11.9, 355993 6688837 11.9, 355987.3 6688848.7 11.9, 355999.1 6688847.3 11.9, 356007.2 6688846.4 11.9, 356017.6 6688845.1 11.9))
BATIMENT0000000302929513;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;4.7;6.9;11.6;13.8;7.3;Cadastre;A 1.0;POLYGON Z ((355980.2 6688849.1 11.6, 355984.6 6688849 11.6, 355987.3 6688848.7 11.6, 355993 6688837 11.6, 355987.3 6688834.3 11.6, 355980.2 6688849.1 11.6))
BATIMENT0000000302923703;Indifférenciée;Annexe;;Oui;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.0;6.3;11.3;11.8;7.2;Cadastre;A 0.4;POLYGON Z ((356000.3 6688853.3 11.3, 355999.1 6688847.3 11.3, 355987.3 6688848.7 11.3, 355984.6 6688849 11.3, 355986.2 6688856.5 11.3, 356000.3 6688853.3 11.3))
BATIMENT0000000302923734;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;12.3;6.0;18.3;21.7;7.0;Cadastre;A 0.2;POLYGON Z ((356015.4 6688850.4 18.3, 356005.6 6688852.6 18.3, 356007.5 6688861.5 18.3, 356007.7 6688862.3 18.3, 356009.5 6688861.9 18.3, 356017.5 6688860 18.3, 356015.4 6688850.4 18.3))
BATIMENT0000000302923889;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.6;6.8;18.4;21.4;7.2;Cadastre;;POLYGON Z ((356032.9 6688854.8 18.4, 356031.7 6688857.2 18.4, 356038 6688860.2 18.4, 356039.2 6688857.9 18.4, 356032.9 6688854.8 18.4))
BATIMENT0000000302923709;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;6.8;9.9;10.9;7.2;Cadastre;;POLYGON Z ((355988.2 6688866 9.9, 355988.3 6688866.5 9.9, 356002.3 6688863.1 9.9, 356002.2 6688862.6 9.9, 356001.1 6688857.2 9.9, 355987 6688860.4 9.9, 355987.6 6688863.1 9.9, 355988.2 6688866 9.9))
BATIMENT0000000302923733;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;29;9.4;6.0;15.4;17.7;7.3;Cadastre;A 1.0;POLYGON Z ((356021.9 6688864.6 15.4, 356020.8 6688859.2 15.4, 356017.5 6688860 15.4, 356009.5 6688861.9 15.4, 356007.7 6688862.3 15.4, 356007.5 6688861.5 15.4, 356002.2 6688862.6 15.4, 356002.3 6688863.1 15.4, 356003.4 6688868.6 15.4, 356021.9 6688864.6 15.4))
BATIMENT0000000302929472;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;24;6.3;6.0;12.3;15.6;7.0;Cadastre;A 1.0;POLYGON Z ((355970.1 6688847.4 12.3, 355956.2 6688844.4 12.3, 355955.1 6688849.8 12.3, 355967.6 6688852.4 12.3, 355970.1 6688847.4 12.3))
BATIMENT0000000302929471;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;6.7;12.0;13.9;6.9;Cadastre;;POLYGON Z ((355943.2 6688849.6 12, 355948.2 6688850.6 12, 355948.6 6688848.4 12, 355944.8 6688847.6 12, 355943.8 6688847.4 12, 355943.7 6688847.6 12, 355943.2 6688849.6 12))
BATIMENT0000000302929514;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.3;6.2;11.5;13.5;7.2;Cadastre;A 1.0;POLYGON Z ((355980.2 6688849.1 11.5, 355976.1 6688857.7 11.5, 355974.5 6688861 11.5, 355976.1 6688861.8 11.5, 355977.7 6688858.4 11.5, 355987.6 6688863.1 11.5, 355987 6688860.4 11.5, 355986.2 6688856.5 11.5, 355984.6 6688849 11.5, 355980.2 6688849.1 11.5))
BATIMENT0000000302929469;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;50;20;7.8;6.0;13.8;18.3;7.0;Cadastre;A 1.0;POLYGON Z ((355948.2 6688850.6 13.8, 355947.8 6688852.1 13.8, 355946.9 6688857.1 13.8, 355945.9 6688861.5 13.8, 355924.6 6688856.4 13.8, 355923 6688863.1 13.8, 355926.1 6688863.9 13.8, 355958.5 6688871.5 13.8, 355967.6 6688852.4 13.8, 355955.1 6688849.8 13.8, 355948.6 6688848.4 13.8, 355948.2 6688850.6 13.8))
BATIMENT0000000302929479;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;10;20;9.2;6.1;15.3;18.6;6.9;Cadastre;A 1.0;POLYGON Z ((355919 6688868.7 15.3, 355919.7 6688865.5 15.3, 355925.4 6688866.8 15.3, 355926.1 6688863.9 15.3, 355923 6688863.1 15.3, 355894 6688856.3 15.3, 355892.5 6688862.6 15.3, 355919 6688868.7 15.3))
BATIMENT0000000302929474;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;4.0;50;20;12.2;6.0;18.2;21.9;7.3;Cadastre;A 1.0;POLYGON Z ((355931.4 6688868.3 18.2, 355930.6 6688871.4 18.2, 355950.5 6688877.2 18.2, 355955.2 6688878.6 18.2, 355958.5 6688871.5 18.2, 355926.1 6688863.9 18.2, 355925.4 6688866.8 18.2, 355931.4 6688868.3 18.2))
BATIMENT0000000302929516;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.7;6.8;14.5;23.7;7.3;Cadastre;A 1.0;POLYGON Z ((355972.4 6688865.3 14.5, 355967.5 6688875.6 14.5, 355981.7 6688882.5 14.5, 355984.6 6688876.3 14.5, 355990.2 6688875.2 14.5, 355990 6688874.3 14.5, 355972.4 6688865.3 14.5))
BATIMENT0000000302929907;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.9;6.0;14.9;17.3;7.3;Cadastre;A 1.0;POLYGON Z ((355927.5 6688885.7 14.9, 355946.5 6688890.1 14.9, 355952 6688887.3 14.9, 355953.8 6688883.5 14.9, 355942.1 6688878.1 14.9, 355929.9 6688875.1 14.9, 355927.5 6688885.7 14.9))
BATIMENT0000000302929518;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;;;10.2;6.5;16.7;20.9;7.1;Cadastre;A 1.0;POLYGON Z ((355961.2 6688888.8 16.7, 355963.8 6688894.2 16.7, 355975.2 6688896.8 16.7, 355981.7 6688882.5 16.7, 355967.5 6688875.6 16.7, 355961.2 6688888.8 16.7))
BATIMENT0000000302929515;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;7.5;6.4;14.0;17.2;7.2;Cadastre;A 1.0;POLYGON Z ((355984.6 6688876.3 14, 355981.7 6688882.5 14, 355975.2 6688896.8 14, 355984.9 6688899 14, 355985.9 6688892 14, 355988.2 6688892.5 14, 355988.8 6688886.7 14, 355988.6 6688886.8 14, 355988 6688882.3 14, 355991.6 6688881.5 14, 355990.2 6688875.2 14, 355984.6 6688876.3 14))
BATIMENT0000000302929470;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;12;20;11.0;6.4;17.4;19.9;6.7;Cadastre;A 1.0;POLYGON Z ((355872.5 6688860.7 17.4, 355881.9 6688862.7 17.4, 355882.6 6688860.2 17.4, 355892.5 6688862.6 17.4, 355894 6688856.3 17.4, 355883.8 6688853.9 17.4, 355882.9 6688857.7 17.4, 355873.7 6688855.6 17.4, 355872.5 6688860.5 17.4, 355872.5 6688860.7 17.4))
BATIMENT0000000302929354;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;6.7;6.9;13.7;21.8;7.3;Cadastre;A 1.0;POLYGON Z ((355845.4 6688860.2 13.7, 355835.4 6688857 13.7, 355832.2 6688855.9 13.7, 355819.4 6688851.9 13.7, 355817.6 6688855.7 13.7, 355815.8 6688859.7 13.7, 355829 6688864.9 13.7, 355829.3 6688865 13.7, 355830.8 6688860.3 13.7, 355834 6688861.4 13.7, 355832.6 6688866.1 13.7, 355842.7 6688869.3 13.7, 355845.4 6688860.2 13.7))
BATIMENT0000000302929467;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;12;20;11.0;6.7;17.7;20.4;7.1;Cadastre;A 1.0;POLYGON Z ((355853.7 6688868.9 17.7, 355873.5 6688873.5 17.7, 355874.5 6688869.3 17.7, 355868.4 6688867.8 17.7, 355869.3 6688864.6 17.7, 355856.1 6688861.6 17.7, 355856 6688862 17.7, 355853.7 6688868.9 17.7))
BATIMENT0000000302929906;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.9;6.1;13.0;17.5;7.4;Cadastre;A 1.0;POLYGON Z ((355878.5 6688866.5 13, 355877.2 6688874.1 13, 355927.5 6688885.7 13, 355929.9 6688875.1 13, 355892.9 6688866.2 13, 355878.5 6688866.5 13))
BATIMENT0000000302929358;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;5.0;10;20;14.0;6.9;21.0;23.7;7.2;Cadastre;C 0.7;POLYGON Z ((355842.7 6688869.3 21, 355832.6 6688866.1 21, 355831.1 6688865.6 21, 355825.1 6688885 21, 355836.2 6688890.1 21, 355842.7 6688869.3 21))
BATIMENT0000000302929434;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;12.0;6.0;18.0;21.4;7.1;Cadastre;A 1.0;POLYGON Z ((355848.5 6688886.2 18, 355855.3 6688887.7 18, 355854.8 6688889.3 18, 355855 6688889.4 18, 355859.4 6688890.4 18, 355859.8 6688888.6 18, 355865.9 6688890 18, 355866.1 6688890 18, 355867.8 6688882.4 18, 355850.8 6688878.5 18, 355848.5 6688886.2 18))
BATIMENT0000000302929433;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.9;6.0;12.9;17.1;7.1;Cadastre;A 1.0;POLYGON Z ((355866.1 6688890 12.9, 355865.9 6688890 12.9, 355865.3 6688893.3 12.9, 355872.1 6688894.7 12.9, 355872.1 6688894.5 12.9, 355872.7 6688894.7 12.9, 355874.8 6688884 12.9, 355867.8 6688882.4 12.9, 355866.1 6688890 12.9))
BATIMENT0000000302929435;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;11.5;6.0;17.5;20.1;7.3;Cadastre;A 1.0;POLYGON Z ((355884.3 6688899.1 17.5, 355888.4 6688899.8 17.5, 355888.8 6688897.6 17.5, 355894 6688898.6 17.5, 355896.1 6688888.9 17.5, 355886.9 6688886.8 17.5, 355884.3 6688899.1 17.5))
BATIMENT0000000302929430;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;12;20;9.0;6.7;15.8;20.5;7.0;Cadastre;A 1.0;POLYGON Z ((355844.4 6688900.1 15.8, 355862.4 6688903.4 15.8, 355863.2 6688898.9 15.8, 355863.3 6688898.8 15.8, 355860.2 6688898.2 15.8, 355855.2 6688897.2 15.8, 355855.1 6688897.6 15.8, 355852.7 6688897.1 15.8, 355852.9 6688896.4 15.8, 355853.9 6688896.6 15.8, 355855 6688893.1 15.8, 355853.9 6688892.9 15.8, 355855 6688889.4 15.8, 355854.8 6688889.3 15.8, 355855.3 6688887.7 15.8, 355848.5 6688886.2 15.8, 355844.4 6688900.1 15.8))
BATIMENT0000000302929429;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;6.7;10.1;11.5;7.0;Cadastre;;POLYGON Z ((355863.9 6688895.9 10.1, 355863 6688894.7 10.1, 355860.9 6688894.3 10.1, 355860.2 6688898.2 10.1, 355863.3 6688898.8 10.1, 355863.7 6688897 10.1, 355863.9 6688895.9 10.1))
BATIMENT0000000302923897;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.8;7.7;18.5;;;Cadastre;A 1.0;POLYGON Z ((356051.8 6688876.9 18.5, 356050.7 6688871.8 18.5, 356049.3 6688865.8 18.5, 356041.3 6688865.4 18.5, 356034.2 6688867.2 18.5, 356036.3 6688876.2 18.5, 356051.8 6688876.9 18.5))
BATIMENT0000000302923711;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;;;8.1;6.8;14.9;19.2;7.6;Cadastre;A 1.0;POLYGON Z ((355991.6 6688881.5 14.9, 356000.5 6688879.5 14.9, 356011 6688877.2 14.9, 356014.9 6688876.3 14.9, 356024.1 6688874.3 14.9, 356021.9 6688864.6 14.9, 356003.4 6688868.6 14.9, 355989.4 6688871.6 14.9, 355990 6688874.3 14.9, 355990.2 6688875.2 14.9, 355991.6 6688881.5 14.9))
BATIMENT0000000302923738;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;13;24;9.4;6.0;15.4;17.3;7.5;Cadastre;A 1.0;POLYGON Z ((356014.9 6688876.3 15.4, 356017.4 6688887.7 15.4, 356026.6 6688885.7 15.4, 356024.1 6688874.3 15.4, 356014.9 6688876.3 15.4))
BATIMENT0000000302923712;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;6.7;6.7;13.4;18.7;7.3;Cadastre;C 0.6;POLYGON Z ((355991.6 6688881.5 13.4, 355988 6688882.3 13.4, 355988.6 6688886.8 13.4, 355988.8 6688886.7 13.4, 355999.4 6688884.3 13.4, 356000.5 6688879.5 13.4, 355991.6 6688881.5 13.4))
BATIMENT0000000302923886;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.9;6.0;14.9;20.2;7.0;Cadastre;A 1.0;POLYGON Z ((356037.2 6688881.2 14.9, 356038.9 6688888.7 14.9, 356051.2 6688892.1 14.9, 356051.8 6688889.9 14.9, 356048 6688888.9 14.9, 356049.5 6688883.1 14.9, 356049.6 6688882.7 14.9, 356039.6 6688880.1 14.9, 356037.2 6688881.2 14.9))
BATIMENT0000000302923713;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;4.0;13;24;14.3;6.5;20.8;22.2;7.6;Cadastre;A 1.0;POLYGON Z ((355999.4 6688884.3 20.8, 355998.8 6688887.2 20.8, 355995.8 6688901.4 20.8, 356018 6688906.4 20.8, 356016.7 6688900.2 20.8, 356015.7 6688895.7 20.8, 356014 6688888 20.8, 356013.4 6688888.2 20.8, 356011 6688877.2 20.8, 356000.5 6688879.5 20.8, 355999.4 6688884.3 20.8))
BATIMENT0000000302929517;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;8.2;6.5;14.7;19.7;7.1;Cadastre;C 0.7;POLYGON Z ((355994.3 6688886.3 14.7, 355992.7 6688893.8 14.7, 355988.1 6688892.7 14.7, 355988.2 6688892.5 14.7, 355985.9 6688892 14.7, 355984.9 6688899 14.7, 355995.8 6688901.4 14.7, 355998.8 6688887.2 14.7, 355994.3 6688886.3 14.7))
BATIMENT0000000302923736;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;6.7;18.0;19.1;7.0;Cadastre;;POLYGON Z ((356017.5 6688895.3 18, 356015.7 6688895.7 18, 356016.7 6688900.2 18, 356018.5 6688899.8 18, 356017.5 6688895.3 18))
BATIMENT0000000302923737;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;20;20;13.0;6.0;19.0;21.8;7.0;Cadastre;A 1.0;POLYGON Z ((356028 6688908.6 19, 356031 6688905.7 19, 356028.2 6688893 19, 356018.8 6688895 19, 356019.7 6688899.5 19, 356018.5 6688899.8 19, 356016.7 6688900.2 19, 356018 6688906.4 19, 356028 6688908.6 19))
BATIMENT0000000302924024;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.3;6.3;18.6;19.9;7.5;Cadastre;C 0.7;POLYGON Z ((356002.6 6688931.6 18.6, 356005.6 6688926.5 18.6, 356005.9 6688926.1 18.6, 356008.5 6688913.8 18.6, 355984 6688908.2 18.6, 355981.3 6688920.4 18.6, 355981.1 6688921.5 18.6, 355979.9 6688926.5 18.6, 356002.6 6688931.6 18.6))
BATIMENT0000000302929426;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;6.9;10.9;13.3;7.0;Cadastre;;POLYGON Z ((355869.9 6688896.1 10.9, 355865.7 6688895.2 10.9, 355865.3 6688897.3 10.9, 355864.9 6688899.4 10.9, 355869.1 6688900.2 10.9, 355869.5 6688898 10.9, 355869.9 6688896.1 10.9))
BATIMENT0000000302929374;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;4.0;15;20;15.4;6.7;22.2;24.9;7.2;Cadastre;A 1.0;POLYGON Z ((355818.9 6688888.8 22.2, 355824 6688891 22.2, 355819.9 6688903.4 22.2, 355819.6 6688903.4 22.2, 355819.2 6688904.6 22.2, 355819.5 6688904.7 22.2, 355818.5 6688907.8 22.2, 355829.1 6688912.8 22.2, 355836.2 6688890.1 22.2, 355825.1 6688885 22.2, 355822.6 6688883.9 22.2, 355821.3 6688883.3 22.2, 355818.9 6688888.8 22.2))
BATIMENT0000000302929428;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;6.9;11.4;11.6;7.0;Cadastre;;POLYGON Z ((355863.7 6688897 11.4, 355863.3 6688898.8 11.4, 355863.2 6688898.9 11.4, 355864.3 6688899.1 11.4, 355864.3 6688899.3 11.4, 355864.9 6688899.4 11.4, 355865.3 6688897.3 11.4, 355863.7 6688897 11.4))
BATIMENT0000000302929431;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.0;6.0;13.0;18.5;7.3;Cadastre;A 1.0;POLYGON Z ((355863.3 6688904 13, 355872.5 6688905.9 13, 355871.1 6688913.5 13, 355871.7 6688913.6 13, 355880.8 6688915.5 13, 355884.3 6688899.1 13, 355886.9 6688886.8 13, 355874.8 6688884 13, 355872.7 6688894.7 13, 355872.1 6688894.5 13, 355872.1 6688894.7 13, 355871.7 6688896.3 13, 355869.9 6688896.1 13, 355869.5 6688898 13, 355869.1 6688900.2 13, 355864.9 6688899.4 13, 355864.3 6688899.3 13, 355863.3 6688904 13))
BATIMENT0000000302929437;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;8.9;6.7;15.6;22.0;7.0;Cadastre;A 1.0;POLYGON Z ((355862.4 6688903.4 15.6, 355844.4 6688900.1 15.6, 355842.2 6688907.4 15.6, 355852 6688909.5 15.6, 355854.2 6688909.9 15.6, 355857.1 6688910.5 15.6, 355857.6 6688908.6 15.6, 355855.3 6688908 15.6, 355856.2 6688904.8 15.6, 355859.3 6688905.4 15.6, 355857.8 6688910.7 15.6, 355859.5 6688911.1 15.6, 355860.5 6688911.3 15.6, 355862.4 6688903.4 15.6))
BATIMENT0000000302929440;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.9;6.0;12.9;17.7;6.8;Cadastre;;POLYGON Z ((355853.4 6688912.9 12.9, 355854.2 6688909.9 12.9, 355852 6688909.5 12.9, 355851.2 6688912.3 12.9, 355852.3 6688912.6 12.9, 355853.4 6688912.9 12.9))
BATIMENT0000000302929441;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;20;20;12.1;6.6;18.8;21.4;6.9;Cadastre;C 0.8;POLYGON Z ((355839.1 6688917.9 18.8, 355848.4 6688921.7 18.8, 355850 6688916.4 18.8, 355851.2 6688916.9 18.8, 355852.3 6688916.4 18.8, 355852.8 6688914.5 18.8, 355852.4 6688913.5 18.8, 355852 6688913.4 18.8, 355852.3 6688912.6 18.8, 355851.2 6688912.3 18.8, 355852 6688909.5 18.8, 355842.2 6688907.4 18.8, 355839.1 6688917.9 18.8))
BATIMENT0000000302929438;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;3.8;6.6;10.5;13.0;6.9;Cadastre;C 0.4;POLYGON Z ((355853.9 6688914.6 10.5, 355855.1 6688914.9 10.5, 355854.6 6688917.1 10.5, 355853.3 6688916.8 10.5, 355852.5 6688917.8 10.5, 355851.1 6688922.7 10.5, 355856 6688924.6 10.5, 355859.5 6688911.1 10.5, 355857.8 6688910.7 10.5, 355857.1 6688910.5 10.5, 355854.2 6688909.9 10.5, 355853.4 6688912.9 10.5, 355853.9 6688914.6 10.5))
BATIMENT0000000302929432;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;50;09;4.0;6.7;10.7;13.3;7.3;Cadastre;A 1.0;POLYGON Z ((355871.1 6688913.5 10.7, 355860.5 6688911.3 10.7, 355859.5 6688911.1 10.7, 355856 6688924.6 10.7, 355865.7 6688928.7 10.7, 355866.9 6688925.1 10.7, 355868.2 6688925.6 10.7, 355869.6 6688918.3 10.7, 355870.7 6688918.6 10.7, 355871.7 6688913.6 10.7, 355871.1 6688913.5 10.7))
BATIMENT0000000302929436;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1942-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;12;5.6;6.0;11.6;15.7;7.3;Cadastre;A 1.0;POLYGON Z ((355877.5 6688933.5 11.6, 355879.6 6688921.1 11.6, 355880.8 6688915.5 11.6, 355871.7 6688913.6 11.6, 355870.7 6688918.6 11.6, 355869.6 6688918.3 11.6, 355868.2 6688925.6 11.6, 355866.9 6688925.1 11.6, 355865.7 6688928.7 11.6, 355877.5 6688933.5 11.6))
BATIMENT0000000302929987;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;41.0;4.0;00;00;11.4;6.5;18.0;21.9;7.0;Cadastre;C 0.6;POLYGON Z ((355943.7 6688903.1 18, 355943.8 6688903.1 18, 355944.7 6688903.3 18, 355944.2 6688905.4 18, 355944.1 6688905.5 18, 355943.8 6688905.5 18, 355943.6 6688905.7 18, 355943.4 6688905.9 18, 355943.2 6688906 18, 355943.1 6688906.2 18, 355943.1 6688906.3 18, 355942.9 6688906.5 18, 355942.9 6688906.6 18, 355942.8 6688907 18, 355942.8 6688907.3 18, 355942.9 6688907.4 18, 355942.9 6688907.5 18, 355943 6688907.7 18, 355943 6688907.8 18, 355943.1 6688908 18, 355943.2 6688908.2 18, 355943.3 6688908.3 18, 355943.5 6688908.4 18, 355943 6688910.1 18, 355942 6688909.9 18, 355941.4 6688912.6 18, 355940.6 6688915.5 18, 355960.9 6688919.9 18, 355961.6 6688917 18, 355961.9 6688915.8 18, 355964.6 6688903.8 18, 355944.7 6688899.3 18, 355943.7 6688903.1 18))
BATIMENT0000000302929988;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1600-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;14;20;10.9;6.3;17.3;19.2;6.7;Cadastre;C 0.8;POLYGON Z ((355964.6 6688903.8 17.3, 355961.9 6688915.8 17.3, 355963.2 6688916.2 17.3, 355963.4 6688915.2 17.3, 355980.1 6688919.1 17.3, 355979.9 6688920.1 17.3, 355981.3 6688920.4 17.3, 355984 6688908.2 17.3, 355964.6 6688903.8 17.3))
BATIMENT0000000302929439;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;46.0;5.0;30;90;14.8;6.0;20.8;23.8;7.1;Cadastre;A 1.0;POLYGON Z ((355894 6688898.6 20.8, 355928.5 6688906.4 20.8, 355915 6688934.9 20.8, 355901.4 6688929.1 20.8, 355898.6 6688938.6 20.8, 355899 6688938.8 20.8, 355913 6688944.7 20.8, 355915.8 6688938.1 20.8, 355922.7 6688941.3 20.8, 355922.9 6688941.4 20.8, 355938.7 6688908.3 20.8, 355930.6 6688904.6 20.8, 355932.3 6688897.2 20.8, 355896.1 6688888.9 20.8, 355894 6688898.6 20.8))
BATIMENT0000000302929989;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1600-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;00;00;7.1;6.0;13.1;14.0;7.0;Cadastre;C 0.6;POLYGON Z ((355960.9 6688919.9 13.1, 355959.5 6688926.1 13.1, 355962.2 6688926.7 13.1, 355962.6 6688925 13.1, 355966.5 6688925.9 13.1, 355968.3 6688918.5 13.1, 355961.6 6688917 13.1, 355960.9 6688919.9 13.1))
BATIMENT0000000302929990;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;6.0;11.0;13.7;6.8;Cadastre;;POLYGON Z ((355979.9 6688926.5 11, 355981.1 6688921.5 11, 355972.9 6688919.6 11, 355972.3 6688922.1 11, 355973.5 6688922.5 11, 355972.4 6688926.8 11, 355972.9 6688927.5 11, 355976.4 6688928.4 11, 355976 6688930 11, 355979 6688930.7 11, 355979.9 6688926.5 11))
BATIMENT0000000302930155;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;27.0;4.0;00;00;10.8;6.6;17.4;22.4;7.1;Cadastre;C 0.1;POLYGON Z ((355933.8 6688941.8 17.4, 355944.7 6688944.6 17.4, 355948.6 6688945.6 17.4, 355953.1 6688927.3 17.4, 355938.3 6688923.8 17.4, 355933.8 6688941.8 17.4))
BATIMENT0000000302930116;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1600-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;3.0;;;7.4;6.0;13.4;16.4;7.1;Cadastre;C 0.1;POLYGON Z ((355976.3 6688942.4 13.4, 355978.4 6688933.2 13.4, 355958.9 6688928.5 13.4, 355958.6 6688929.7 13.4, 355956.7 6688937.9 13.4, 355976.3 6688942.4 13.4))
BATIMENT0000000302930154;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;27.0;4.0;00;00;10.6;6.5;17.1;22.5;7.0;Cadastre;A 1.0;POLYGON Z ((355940.8 6688961.1 17.1, 355945.2 6688963.9 17.1, 355947.3 6688955.5 17.1, 355946 6688955.2 17.1, 355948.6 6688945.6 17.1, 355944.7 6688944.6 17.1, 355933.8 6688941.8 17.1, 355930.6 6688954.6 17.1, 355931.9 6688955.4 17.1, 355940.8 6688961.1 17.1))
BATIMENT0000000302930148;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.7;6.0;14.7;18.2;6.9;Cadastre;;POLYGON Z ((355929.8 6688961.3 14.7, 355921.5 6688957.9 14.7, 355917.9 6688966.3 14.7, 355922.6 6688968.3 14.7, 355927.4 6688969.7 14.7, 355927.8 6688968.1 14.7, 355929.5 6688961.7 14.7, 355929.6 6688961.8 14.7, 355929.8 6688961.3 14.7))
BATIMENT0000000302930117;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.8;6.5;11.3;14.4;6.9;Cadastre;A 1.0;POLYGON Z ((355949.7 6688968 11.3, 355969.6 6688979.9 11.3, 355973.2 6688973.4 11.3, 355973 6688973.3 11.3, 355976.2 6688967.5 11.3, 355981.9 6688970 11.3, 355984.6 6688964.2 11.3, 355981.9 6688963.3 11.3, 355953.1 6688953.4 11.3, 355949.8 6688967.8 11.3, 355949.7 6688968 11.3))
BATIMENT0000000302923892;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;6.5;11.9;12.9;7.4;Cadastre;;POLYGON Z ((356398.1 6688924.5 11.9, 356405.9 6688902.8 11.9, 356408 6688897.1 11.9, 356410.9 6688888.5 11.9, 356412.9 6688882.5 11.9, 356410 6688881.3 11.9, 356408 6688891.7 11.9, 356406.5 6688896.7 11.9, 356399.6 6688893.9 11.9, 356390.2 6688921.3 11.9, 356398.1 6688924.5 11.9))
BATIMENT0000000302923844;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;7.0;21.2;22.5;7.4;Cadastre;;POLYGON Z ((356456.2 6688900.9 21.2, 356455.6 6688902.2 21.2, 356466.4 6688907.1 21.2, 356467.2 6688905.5 21.2, 356456.2 6688900.9 21.2))
BATIMENT0000000302923843;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;38.0;6.0;90;90;19.0;6.7;25.7;26.9;7.4;Cadastre;C 0.1;POLYGON Z ((356439.6 6688928.8 25.7, 356452.8 6688935.2 25.7, 356460.2 6688919.5 25.7, 356463.5 6688917.5 25.7, 356462.2 6688915.5 25.7, 356466.4 6688907.1 25.7, 356455.6 6688902.2 25.7, 356453.2 6688901.1 25.7, 356444.2 6688919.4 25.7, 356439.6 6688928.8 25.7))
BATIMENT0000000302923842;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.0;7.0;15.0;16.7;7.8;Cadastre;A 1.0;POLYGON Z ((356321.1 6688933.5 15, 356323.5 6688939.9 15, 356332.5 6688944.3 15, 356344.3 6688914 15, 356352.8 6688896.5 15, 356341 6688892.6 15, 356321.1 6688933.5 15))
BATIMENT0000000302923756;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;6.0;00;00;19.5;6.9;26.4;26.9;7.3;Cadastre;C 0.3;POLYGON Z ((356486.1 6688914.5 26.4, 356480.6 6688912.2 26.4, 356472.1 6688908.7 26.4, 356468.2 6688919.2 26.4, 356467 6688922.1 26.4, 356479.1 6688927.1 26.4, 356478.4 6688928.8 26.4, 356483.6 6688931 26.4, 356484.3 6688929.2 26.4, 356494.8 6688933.6 26.4, 356495.8 6688931.1 26.4, 356496 6688930.7 26.4, 356496.1 6688930.8 26.4, 356500.3 6688920.4 26.4, 356486.1 6688914.5 26.4))
BATIMENT0000000302923939;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;7.0;21.5;26.0;7.2;Cadastre;;POLYGON Z ((356478.4 6688928.8 21.5, 356479.1 6688927.1 21.5, 356467 6688922.1 21.5, 356466.4 6688923.7 21.5, 356478.4 6688928.8 21.5))
BATIMENT0000000302923934;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;6.6;22.2;23.7;7.1;Cadastre;;POLYGON Z ((356504.6 6688922.2 22.2, 356503.9 6688923.8 22.2, 356506.81139568595 6688925.020907868 22.2, 356506.81139568595 6688923.116920163 22.2, 356504.6 6688922.2 22.2))
BATIMENT0000000302923935;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;17.0;6.6;23.7;25.7;7.5;Cadastre;C 0.3;POLYGON Z ((356495.8 6688931.1 23.7, 356498.1 6688932.3 23.7, 356497.3 6688934.4 23.7, 356503.2 6688937 23.7, 356503.9 6688935.5 23.7, 356506.81139568595 6688936.768330794 23.7, 356506.81139568595 6688925.020907868 23.7, 356503.9 6688923.8 23.7, 356504.6 6688922.2 23.7, 356500.3 6688920.4 23.7, 356496.1 6688930.8 23.7, 356496 6688930.7 23.7, 356495.8 6688931.1 23.7))
BATIMENT0000000302923937;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.3;6.6;16.0;23.7;7.3;Cadastre;;POLYGON Z ((356484.3 6688929.2 16, 356483.6 6688931 16, 356494.1 6688935.4 16, 356494.8 6688933.6 16, 356484.3 6688929.2 16))
BATIMENT0000000302923941;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;13.0;6.0;19.0;21.7;7.7;Cadastre;A 1.0;POLYGON Z ((356398.1 6688924.5 19, 356393.1 6688938.1 19, 356407.3 6688945.5 19, 356407.6 6688945.2 19, 356416.6 6688949.8 19, 356423 6688936.8 19, 356409.6 6688930.1 19, 356409.9 6688929.4 19, 356399.7 6688925.3 19, 356398.1 6688924.5 19))
BATIMENT0000000302923979;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;12.7;6.0;18.7;21.3;6.7;Cadastre;A 0.9;POLYGON Z ((356061.2 6688931.3 18.7, 356061.3 6688931 18.7, 356068.9 6688932.9 18.7, 356069.9 6688928.5 18.7, 356049.9 6688923.8 18.7, 356048.1 6688925.7 18.7, 356051.2 6688939.7 18.7, 356062.9 6688939.4 18.7, 356061.2 6688931.3 18.7))
BATIMENT0000000302923981;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;;;9.7;6.0;15.7;17.5;6.9;Cadastre;A 1.0;POLYGON Z ((356071.2 6688928.8 15.7, 356069.4 6688936.7 15.7, 356068.6 6688940.3 15.7, 356083.8 6688942.8 15.7, 356086.6 6688932.5 15.7, 356071.2 6688928.8 15.7))
BATIMENT0000000302923980;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;5.7;9.5;13.2;6.1;Cadastre;;POLYGON Z ((356066.6 6688936.1 9.5, 356065.7 6688939.9 9.5, 356068.6 6688940.3 9.5, 356069.4 6688936.7 9.5, 356066.6 6688936.1 9.5))
BATIMENT0000000302923974;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;7.4;6.0;13.5;21.0;7.0;Cadastre;C 0.7;POLYGON Z ((356054.4 6688954.4 13.5, 356065.1 6688953.6 13.5, 356066.1 6688953.6 13.5, 356064 6688943.9 13.5, 356079.5 6688944.4 13.5, 356081.3 6688944.3 13.5, 356083.3 6688944.8 13.5, 356083.8 6688942.8 13.5, 356068.6 6688940.3 13.5, 356065.7 6688939.9 13.5, 356062.9 6688939.4 13.5, 356051.2 6688939.7 13.5, 356054.4 6688954.4 13.5))
BATIMENT0000000302923977;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.7;6.7;20.5;21.0;7.1;Cadastre;;POLYGON Z ((356133.3 6688946.8 20.5, 356134.7 6688949.9 20.5, 356135.6 6688950.3 20.5, 356133.6 6688945.7 20.5, 356133.3 6688946.8 20.5))
BATIMENT0000000302923973;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;6.1;10.0;11.4;7.0;Cadastre;;POLYGON Z ((356081.3 6688954.1 10, 356082.8 6688947 10, 356082.9 6688946.9 10, 356080 6688947 10, 356080.2 6688948.3 10, 356070.4 6688947.9 10, 356070.4 6688946.7 10, 356068.4 6688946.6 10, 356068 6688953.7 10, 356068.4 6688953.7 10, 356071.6 6688953.8 10, 356081.3 6688954.1 10))
BATIMENT0000000302923970;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;00;00;14.8;6.5;21.3;26.1;7.1;Cadastre;A 1.0;POLYGON Z ((356108.6 6688954.2 21.3, 356111.5 6688955.1 21.3, 356111.6 6688954.7 21.3, 356114.4 6688955.5 21.3, 356114.6 6688957.2 21.3, 356116.1 6688972.4 21.3, 356123.2 6688970.8 21.3, 356124.1 6688967.5 21.3, 356124.9 6688967.8 21.3, 356125.2 6688966.6 21.3, 356125.6 6688964.9 21.3, 356128.2 6688965.7 21.3, 356131.7 6688958.5 21.3, 356135.6 6688950.3 21.3, 356134.7 6688949.9 21.3, 356133.3 6688946.8 21.3, 356133.6 6688945.7 21.3, 356112.6 6688939.8 21.3, 356086.6 6688932.5 21.3, 356083.8 6688942.8 21.3, 356083.3 6688944.8 21.3, 356082.9 6688946.9 21.3, 356082.8 6688947 21.3, 356108.6 6688954.2 21.3))
BATIMENT0000000302923978;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;6.1;9.9;14.2;6.2;Cadastre;;POLYGON Z ((356065.1 6688953.6 9.9, 356065.6 6688955.8 9.9, 356068.4 6688955.6 9.9, 356068.4 6688953.7 9.9, 356068 6688953.7 9.9, 356066.1 6688953.6 9.9, 356065.1 6688953.6 9.9))
BATIMENT0000000302923967;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;6.1;11.2;13.2;6.4;Cadastre;;POLYGON Z ((356071.6 6688953.8 11.2, 356068.4 6688953.7 11.2, 356068.4 6688955.6 11.2, 356068.4 6688960.6 11.2, 356071.4 6688959 11.2, 356071.6 6688953.8 11.2))
BATIMENT0000000302923972;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;12.9;6.0;18.9;21.1;6.4;Cadastre;C 0.9;POLYGON Z ((356056.2 6688962.7 18.9, 356063.8 6688961.7 18.9, 356066.8 6688961.4 18.9, 356065.6 6688955.8 18.9, 356065.1 6688953.6 18.9, 356054.4 6688954.4 18.9, 356056.2 6688962.7 18.9))
BATIMENT0000000302923952;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.9;7.0;25.0;27.5;7.7;Cadastre;C 0.2;POLYGON Z ((356159.2 6688988.9 25, 356175.5 6688955.3 25, 356175.4 6688955.3 25, 356176.3 6688953.6 25, 356183.2 6688939.3 25, 356170.3 6688933.3 25, 356161.8 6688951.1 25, 356160.9 6688950.8 25, 356154.1 6688964.5 25, 356145.3 6688982.4 25, 356159.2 6688988.9 25))
BATIMENT0000000302923954;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;7.2;14.7;17.2;8.2;Cadastre;C 0.3;POLYGON Z ((356180 6688957.5 14.7, 356170.3 6688977.7 14.7, 356195.2 6688989.6 14.7, 356194.6 6688983.8 14.7, 356195.1 6688984 14.7, 356195.6 6688984.1 14.7, 356196.1 6688984.2 14.7, 356196.6 6688984.2 14.7, 356196.8 6688984.2 14.7, 356197.1 6688984.2 14.7, 356197.6 6688984.2 14.7, 356198.1 6688984.1 14.7, 356198.5 6688984 14.7, 356199 6688983.9 14.7, 356199.5 6688983.7 14.7, 356199.9 6688983.5 14.7, 356200.4 6688983.3 14.7, 356200.8 6688983 14.7, 356201.2 6688982.7 14.7, 356201.5 6688982.3 14.7, 356201.9 6688982 14.7, 356202.2 6688981.6 14.7, 356202.5 6688981.2 14.7, 356202.8 6688980.8 14.7, 356203.2 6688979.9 14.7, 356203.3 6688979.4 14.7, 356203.4 6688978.9 14.7, 356203.5 6688978.4 14.7, 356203.6 6688978 14.7, 356203.6 6688977.5 14.7, 356203.5 6688977 14.7, 356203.5 6688976.5 14.7, 356203.4 6688976 14.7, 356203.3 6688975.5 14.7, 356203.1 6688975 14.7, 356202.9 6688974.6 14.7, 356202.6 6688974.2 14.7, 356202.4 6688973.7 14.7, 356202.1 6688973.3 14.7, 356201.7 6688973 14.7, 356201.4 6688972.6 14.7, 356201 6688972.3 14.7, 356200.6 6688972 14.7, 356200.2 6688971.8 14.7, 356201.6 6688968.8 14.7, 356207.4 6688971.6 14.7, 356208.4 6688969.6 14.7, 356215.2 6688955.6 14.7, 356187.4 6688942.3 14.7, 356180.9 6688955.8 14.7, 356180.7 6688956.1 14.7, 356180 6688957.5 14.7))
BATIMENT0000000302923958;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;7.9;27.4;28.5;8.1;Cadastre;;POLYGON Z ((356224.3 6688983.7 27.4, 356228.4 6688975 27.4, 356225.8 6688973.8 27.4, 356225.5 6688974.7 27.4, 356223.8 6688973.8 27.4, 356223 6688975.5 27.4, 356219.3 6688973.8 27.4, 356220 6688972.3 27.4, 356213.8 6688969.3 27.4, 356219.1 6688958.1 27.4, 356230.8 6688963.4 27.4, 356226.5 6688972.3 27.4, 356229.1 6688973.6 27.4, 356231.1 6688969.4 27.4, 356229.6 6688968.8 27.4, 356232.4 6688962.5 27.4, 356219.1 6688956.3 27.4, 356211.9 6688971.2 27.4, 356210.9 6688973.2 27.4, 356210.1 6688972.9 27.4, 356208.6 6688976.1 27.4, 356224.3 6688983.7 27.4))
BATIMENT0000000302923960;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;8.0;16.0;27.6;8.1;Cadastre;;POLYGON Z ((356210.1 6688972.9 16, 356210.9 6688973.2 16, 356211.9 6688971.2 16, 356208.4 6688969.6 16, 356207.4 6688971.6 16, 356210.1 6688972.9 16))
BATIMENT0000000302923962;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;7.9;27.4;30.7;8.1;Cadastre;;POLYGON Z ((356224 6688984.4 27.4, 356229.1 6688986.8 27.4, 356236.2 6688972 27.4, 356231.1 6688969.4 27.4, 356229.1 6688973.6 27.4, 356226.5 6688972.3 27.4, 356230.8 6688963.4 27.4, 356219.1 6688958.1 27.4, 356213.8 6688969.3 27.4, 356220 6688972.3 27.4, 356219.3 6688973.8 27.4, 356223 6688975.5 27.4, 356223.8 6688973.8 27.4, 356225.5 6688974.7 27.4, 356225.8 6688973.8 27.4, 356228.4 6688975 27.4, 356224.3 6688983.7 27.4, 356224 6688984.4 27.4))
BATIMENT0000000302923961;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;2.1;7.1;9.2;10.7;8.2;Cadastre;C 0.3;POLYGON Z ((356198.2 6688994.4 9.2, 356196.8 6688984.2 9.2, 356196.6 6688984.2 9.2, 356196.1 6688984.2 9.2, 356195.6 6688984.1 9.2, 356195.1 6688984 9.2, 356194.6 6688983.8 9.2, 356195.2 6688989.6 9.2, 356170.3 6688977.7 9.2, 356168.9 6688980.4 9.2, 356198.2 6688994.4 9.2))
BATIMENT0000000302923957;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.2;7.9;24.2;28.2;8.1;Cadastre;;POLYGON Z ((356221.3 6688990.3 24.2, 356226.4 6688992.6 24.2, 356229.1 6688986.8 24.2, 356224 6688984.4 24.2, 356221.3 6688990.3 24.2))
BATIMENT0000000302923955;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;7.8;27.3;27.9;8.3;Cadastre;;POLYGON Z ((356239.7 6689000.7 27.3, 356239 6689002.2 27.3, 356243.6 6689004.3 27.3, 356244.3 6689002.9 27.3, 356245.1 6689003.3 27.3, 356250.6 6688991.7 27.3, 356239.3 6688986.5 27.3, 356233.7 6688998.1 27.3, 356239.7 6689000.7 27.3))
BATIMENT0000000302923950;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.8;7.8;26.6;27.2;8.3;Cadastre;;POLYGON Z ((356225.3 6688994.9 26.6, 356224.3 6688997 26.6, 356230.8 6689000 26.6, 356231.5 6689000.3 26.6, 356232.5 6688998.1 26.6, 356225.3 6688994.9 26.6))
BATIMENT0000000302923956;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;7.9;27.3;28.7;8.2;Cadastre;;POLYGON Z ((356210.6 6689012 27.3, 356217.4 6688998.4 27.3, 356214.8 6688997.1 27.3, 356212 6689003.2 27.3, 356210.4 6689002.5 27.3, 356209.7 6689004 27.3, 356205.9 6689002.2 27.3, 356206.7 6689000.6 27.3, 356199.9 6688997.4 27.3, 356205.4 6688986 27.3, 356217.3 6688991.7 27.3, 356215.4 6688995.8 27.3, 356218.1 6688996.9 27.3, 356220.6 6688991.6 27.3, 356205.4 6688984.4 27.3, 356198.2 6688999.8 27.3, 356197.3 6688999.3 27.3, 356194.8 6689004.5 27.3, 356210.6 6689012 27.3))
BATIMENT0000000302923969;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;10;10;6.7;6.0;12.7;14.2;7.0;Cadastre;C 0.2;POLYGON Z ((356109 6688963 12.7, 356108.4 6688955.5 12.7, 356108.6 6688955.1 12.7, 356108.7 6688954.9 12.7, 356108.4 6688954.9 12.7, 356093 6688954.2 12.7, 356093 6688954.4 12.7, 356092.6 6688962.3 12.7, 356109 6688963 12.7))
BATIMENT0000000302923968;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;6.0;14.2;14.7;6.6;Cadastre;;POLYGON Z ((356084.6 6688961.7 14.2, 356086.1 6688961.4 14.2, 356086.1 6688960.5 14.2, 356085.4 6688960.5 14.2, 356079.9 6688960.3 14.2, 356079.6 6688959.7 14.2, 356072.7 6688959.5 14.2, 356071.4 6688959.4 14.2, 356071.6 6688964.1 14.2, 356073 6688963.8 14.2, 356084.6 6688961.7 14.2))
BATIMENT0000000302923964;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;7.8;6.0;13.8;17.2;6.9;Cadastre;A 1.0;POLYGON Z ((356058 6688970.8 13.8, 356072.4 6688968.3 13.8, 356081.9 6688966.6 13.8, 356081.9 6688966.3 13.8, 356092.5 6688964 13.8, 356092.6 6688962.3 13.8, 356093 6688954.4 13.8, 356085.8 6688954.2 13.8, 356081.3 6688954.1 13.8, 356071.6 6688953.8 13.8, 356071.4 6688959 13.8, 356071.4 6688959.4 13.8, 356072.7 6688959.5 13.8, 356079.6 6688959.7 13.8, 356079.9 6688960.3 13.8, 356085.4 6688960.5 13.8, 356086.1 6688960.5 13.8, 356086.1 6688961.4 13.8, 356084.6 6688961.7 13.8, 356073 6688963.8 13.8, 356071.6 6688964.1 13.8, 356065.4 6688965.2 13.8, 356064.1 6688964.4 13.8, 356063.8 6688961.7 13.8, 356056.2 6688962.7 13.8, 356058 6688970.8 13.8))
BATIMENT0000000302923976;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;6.8;21.6;22.2;7.1;Cadastre;;POLYGON Z ((356125.6 6688964.9 21.6, 356125.2 6688966.6 21.6, 356127.4 6688967.3 21.6, 356128.2 6688965.7 21.6, 356125.6 6688964.9 21.6))
BATIMENT0000000302923971;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.3;6.0;14.3;17.9;7.0;Cadastre;C 0.6;POLYGON Z ((356110.2 6688973.8 14.3, 356109.4 6688967.3 14.3, 356094.1 6688970.8 14.3, 356092.8 6688964 14.3, 356092.5 6688964 14.3, 356081.9 6688966.3 14.3, 356081.9 6688966.6 14.3, 356084.8 6688979.6 14.3, 356110.2 6688973.8 14.3))
BATIMENT0000000302923963;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;8.4;6.0;14.4;17.0;6.7;Cadastre;A 1.0;POLYGON Z ((356065.3 6688974.9 14.4, 356064.8 6688972 14.4, 356068.2 6688971.1 14.4, 356068.8 6688974.2 14.4, 356073.4 6688973.3 14.4, 356072.4 6688968.3 14.4, 356058 6688970.8 14.4, 356059.2 6688976.2 14.4, 356065.3 6688974.9 14.4))
BATIMENT0000000302923965;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;10;10.1;6.3;16.5;20.4;6.6;Cadastre;A 1.0;POLYGON Z ((356084.8 6688979.6 16.5, 356081.9 6688966.6 16.5, 356072.4 6688968.3 16.5, 356073.4 6688973.3 16.5, 356074.2 6688977.2 16.5, 356075.1 6688981.8 16.5, 356084.8 6688979.6 16.5))
BATIMENT0000000302923966;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;8.4;6.0;14.4;16.5;6.9;Cadastre;A 1.0;POLYGON Z ((356061.1 6688985 14.4, 356075.1 6688981.8 14.4, 356074.2 6688977.2 14.4, 356073.4 6688973.3 14.4, 356068.8 6688974.2 14.4, 356065.3 6688974.9 14.4, 356059.2 6688976.2 14.4, 356061.1 6688985 14.4))
BATIMENT0000000302923946;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;8.8;6.6;15.5;21.4;7.0;Cadastre;A 1.0;POLYGON Z ((356118 6688986.9 15.5, 356114.7 6688982.9 15.5, 356101.5 6688985.9 15.5, 356103.4 6688994.3 15.5, 356113.8 6688995.4 15.5, 356118 6688986.9 15.5))
BATIMENT0000000302923951;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.5;7.0;24.5;27.7;8.0;Cadastre;;POLYGON Z ((356144 6688984.9 24.5, 356141.5 6688990 24.5, 356155.4 6688996.8 24.5, 356159.2 6688988.9 24.5, 356145.3 6688982.4 24.5, 356144 6688984.9 24.5))
BATIMENT0000000302923940;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;41.0;7.0;00;00;21.5;5.3;26.8;26.9;7.3;Cadastre;A 1.0;POLYGON Z ((356448.9 6688943.8 26.8, 356448.6 6688943.7 26.8, 356452.8 6688935.2 26.8, 356439.6 6688928.8 26.8, 356434.4 6688939.3 26.8, 356429.3 6688949.6 26.8, 356430.2 6688950.1 26.8, 356428.2 6688953.7 26.8, 356440.1 6688959.4 26.8, 356441.9 6688955.7 26.8, 356442.9 6688956.2 26.8, 356448.9 6688943.8 26.8))
BATIMENT0000000302923986;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.3;7.1;8.4;9.7;7.7;Cadastre;;POLYGON Z ((356481.9 6688957.2 8.4, 356496.2 6688964.7 8.4, 356506.5 6688951.3 8.4, 356506.7 6688951.1 8.4, 356500 6688945.9 8.4, 356499.9 6688945.8 8.4, 356499.6 6688945.7 8.4, 356499.5 6688945.6 8.4, 356499.3 6688945.6 8.4, 356499.2 6688945.6 8.4, 356499.1 6688945.5 8.4, 356498.7 6688945.5 8.4, 356498.4 6688945.5 8.4, 356498.1 6688945.5 8.4, 356497.7 6688945.7 8.4, 356497.4 6688945.8 8.4, 356497.2 6688945.8 8.4, 356497.1 6688945.9 8.4, 356491.7 6688941.7 8.4, 356491.6 6688941.9 8.4, 356489.7 6688946.5 8.4, 356481.9 6688957.2 8.4))
BATIMENT0000000302923982;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.2;7.2;24.5;27.7;7.6;Cadastre;;POLYGON Z ((356502.2 6688958.3 24.5, 356484 6688982.2 24.5, 356481.5 6688985.6 24.5, 356482.1 6688985.9 24.5, 356482.5 6688986.1 24.5, 356503 6688959 24.5, 356502.2 6688958.3 24.5))
BATIMENT0000000302923983;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.7;6.7;21.5;27.5;7.4;Cadastre;C 0.1;MULTIPOLYGON Z (((356504 6688957.7 21.5, 356503 6688959 21.5, 356506.81139568595 6688961.976518536 21.5, 356506.81139568595 6688959.871403173 21.5, 356504 6688957.7 21.5)), ((356494.5 6688991.9 21.5, 356496.5 6688992.8 21.5, 356506.81139568595 6688979.604297829 21.5, 356506.81139568595 6688975.895185608 21.5, 356494.5 6688991.9 21.5)))
BATIMENT0000000302923985;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;37.0;7.0;50;20;19.5;6.9;26.5;30.3;7.5;Cadastre;C 0.6;POLYGON Z ((356482.5 6688986.1 26.5, 356494.5 6688991.9 26.5, 356506.81139568595 6688975.895185608 26.5, 356506.81139568595 6688961.976518536 26.5, 356503 6688959 26.5, 356482.5 6688986.1 26.5))
BATIMENT0000000302923984;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.3;7.1;8.5;11.0;7.6;Cadastre;;POLYGON Z ((356477.1 6688979.2 8.5, 356475.4 6688982.7 8.5, 356481.5 6688985.6 8.5, 356484 6688982.2 8.5, 356477.1 6688979.2 8.5))
BATIMENT0000000302923944;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;7.1;22.5;24.5;7.3;Cadastre;;POLYGON Z ((356454.1 6688989.1 22.5, 356455 6688987.1 22.5, 356448.6 6688984.1 22.5, 356447.6 6688986.1 22.5, 356454.1 6688989.1 22.5))
BATIMENT0000000302923945;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;88.0;7.0;00;00;21.5;6.0;27.5;28.6;7.5;Cadastre;A 1.0;POLYGON Z ((356439.7 6688979.8 27.5, 356438.7 6688981.9 27.5, 356428.6 6688976.9 27.5, 356430.1 6688973.7 27.5, 356432.4 6688974.9 27.5, 356435.6 6688968 27.5, 356424.5 6688962.5 27.5, 356414.6 6688982.4 27.5, 356418.1 6688984.1 27.5, 356417.6 6688985.4 27.5, 356438.2 6688995.4 27.5, 356473.7 6689012.5 27.5, 356478.9 6689011.5 27.5, 356483.4 6689005.7 27.5, 356491.9 6688994.8 27.5, 356480.8 6688989.6 27.5, 356479.5 6688992.2 27.5, 356477.8 6688991.4 27.5, 356475.2 6688997.4 27.5, 356473.8 6688996.8 27.5, 356473 6688998.3 27.5, 356462.4 6688993.3 27.5, 356463.6 6688991.3 27.5, 356455 6688987.1 27.5, 356454.1 6688989.1 27.5, 356447.6 6688986.1 27.5, 356448.6 6688984.1 27.5, 356439.7 6688979.8 27.5))
BATIMENT0000000302932609;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.6;11.0;13.7;7.1;Cadastre;;POLYGON Z ((356501.1 6689024.8 11, 356502 6689025.2 11, 356502.7 6689025.3 11, 356504.8 6689022.5 11, 356504.5 6689021.4 11, 356506.81139568595 6689018.382344522 11, 356506.81139568595 6689009.908863312 11, 356505.9 6689009.2 11, 356504.2 6689011.4 11, 356502.3 6689010 11, 356496.3 6689017.3 11, 356498.3 6689018.9 11, 356494.3 6689024.3 11, 356498.5 6689027.8 11, 356501.1 6689024.8 11))
BATIMENT0000000302932608;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;7.0;13.5;17.4;7.3;Cadastre;;POLYGON Z ((356491.3 6689039.3 13.5, 356496 6689033.5 13.5, 356489.8 6689028.4 13.5, 356485.2 6689034.4 13.5, 356491.3 6689039.3 13.5))
BATIMENT0000000302923959;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.6;7.7;27.3;28.1;8.3;Cadastre;;POLYGON Z ((356231.5 6689000.3 27.3, 356230.8 6689000 27.3, 356228.3 6689005.2 27.3, 356249.6 6689015.1 27.3, 356256.9 6689000.2 27.3, 356249.7 6688997 27.3, 356252.4 6688991.4 27.3, 356245.8 6688988.2 27.3, 356238.8 6688984.9 27.3, 356232.5 6688998.1 27.3, 356231.5 6689000.3 27.3), (356239.3 6688986.5 27.3, 356250.6 6688991.7 27.3, 356245.1 6689003.3 27.3, 356244.3 6689002.9 27.3, 356243.6 6689004.3 27.3, 356239 6689002.2 27.3, 356239.7 6689000.7 27.3, 356233.7 6688998.1 27.3, 356239.3 6688986.5 27.3))
BATIMENT0000000302923949;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;8.0;27.3;30.4;8.3;Cadastre;;POLYGON Z ((356210.3 6689012.7 27.3, 356215.6 6689015.2 27.3, 356224.3 6688997 27.3, 356225.3 6688994.9 27.3, 356226.4 6688992.6 27.3, 356221.3 6688990.3 27.3, 356220.6 6688991.6 27.3, 356218.1 6688996.9 27.3, 356215.4 6688995.8 27.3, 356217.3 6688991.7 27.3, 356205.4 6688986 27.3, 356199.9 6688997.4 27.3, 356206.7 6689000.6 27.3, 356205.9 6689002.2 27.3, 356209.7 6689004 27.3, 356210.4 6689002.5 27.3, 356212 6689003.2 27.3, 356214.8 6688997.1 27.3, 356217.4 6688998.4 27.3, 356210.6 6689012 27.3, 356210.3 6689012.7 27.3))
BATIMENT0000000302932595;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.7;8.0;26.7;28.3;8.2;Cadastre;;POLYGON Z ((356212.6 6689021.1 26.7, 356213 6689021.3 26.7, 356215.6 6689015.2 26.7, 356210.3 6689012.7 26.7, 356207.6 6689018.7 26.7, 356212.6 6689021.1 26.7))
BATIMENT0000000302932593;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;7.8;27.2;28.1;8.3;Cadastre;;POLYGON Z ((356185.1 6689026.3 27.2, 356184 6689028.8 27.2, 356186.7 6689030 27.2, 356188.2 6689026.6 27.2, 356190.1 6689027.4 27.2, 356193.4 6689020.1 27.2, 356204.4 6689025.3 27.2, 356206.7 6689020.4 27.2, 356191.6 6689013 27.2, 356185.1 6689026.3 27.2))
BATIMENT0000000302932602;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;7.8;27.4;28.0;8.0;Cadastre;;POLYGON Z ((356225.6 6689029.1 27.4, 356225.1 6689030.5 27.4, 356229.8 6689032.7 27.4, 356230.5 6689031.3 27.4, 356231.3 6689031.6 27.4, 356236.7 6689020 27.4, 356225.6 6689014.7 27.4, 356219.9 6689026.6 27.4, 356225.6 6689029.1 27.4))
BATIMENT0000000302932597;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.7;7.8;26.6;27.2;8.2;Cadastre;;POLYGON Z ((356211.7 6689023 26.6, 356210.5 6689025.4 26.6, 356217 6689028.4 26.6, 356217.7 6689028.7 26.6, 356218.8 6689026.4 26.6, 356211.7 6689023 26.6))
BATIMENT0000000302932585;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.8;7.9;25.7;27.2;8.4;Cadastre;;POLYGON Z ((356177.6 6689022.7 25.7, 356176.2 6689025.6 25.7, 356182.8 6689029.1 25.7, 356183.7 6689029.5 25.7, 356184 6689028.8 25.7, 356185.1 6689026.3 25.7, 356177.6 6689022.7 25.7))
BATIMENT0000000302932598;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.7;7.7;27.4;28.2;8.0;Cadastre;;POLYGON Z ((356218.8 6689026.4 27.4, 356217.7 6689028.7 27.4, 356217 6689028.4 27.4, 356214.3 6689033.8 27.4, 356235.7 6689043.8 27.4, 356242.9 6689028.9 27.4, 356235.8 6689025.7 27.4, 356238.6 6689020 27.4, 356224.9 6689013.6 27.4, 356218.9 6689026.1 27.4, 356218.8 6689026.4 27.4), (356225.6 6689014.7 27.4, 356236.7 6689020 27.4, 356231.3 6689031.6 27.4, 356230.5 6689031.3 27.4, 356229.8 6689032.7 27.4, 356225.1 6689030.5 27.4, 356225.6 6689029.1 27.4, 356219.9 6689026.6 27.4, 356225.6 6689014.7 27.4))
BATIMENT0000000302932594;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;21.8;6.0;27.8;30.2;8.4;Cadastre;C 0.2;POLYGON Z ((356212.6 6689021.1 27.8, 356207.6 6689018.7 27.8, 356206.7 6689020.4 27.8, 356204.4 6689025.3 27.8, 356193.4 6689020.1 27.8, 356190.1 6689027.4 27.8, 356188.2 6689026.6 27.8, 356186.7 6689030 27.8, 356184 6689028.8 27.8, 356183.7 6689029.5 27.8, 356182.8 6689029.1 27.8, 356180.8 6689032.7 27.8, 356194.1 6689039.1 27.8, 356196.3 6689034.6 27.8, 356199.4 6689036.1 27.8, 356198.3 6689038.1 27.8, 356203.4 6689040.4 27.8, 356210.5 6689025.4 27.8, 356211.7 6689023 27.8, 356212.6 6689021.1 27.8))
BATIMENT0000000302932584;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.9;8.2;27.1;28.0;8.5;Cadastre;;POLYGON Z ((356176.2 6689025.6 27.1, 356171.9 6689023.5 27.1, 356171.4 6689024.9 27.1, 356170.1 6689024.2 27.1, 356162.3 6689040.4 27.1, 356168 6689043.2 27.1, 356176.2 6689025.6 27.1))
BATIMENT0000000302923947;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;3.0;;;9.1;6.0;15.1;17.0;7.3;Cadastre;A 1.0;POLYGON Z ((356063.1 6688994.7 15.1, 356067.1 6689012.6 15.1, 356080.6 6689012.5 15.1, 356078.8 6689004.4 15.1, 356073.2 6689005.7 15.1, 356073 6689004.7 15.1, 356071 6689004 15.1, 356070.8 6689004.1 15.1, 356070.4 6689001.9 15.1, 356071.9 6689001.4 15.1, 356072.3 6689003 15.1, 356075.6 6689002.2 15.1, 356075.3 6689000.7 15.1, 356080.1 6688999.6 15.1, 356081.6 6689006 15.1, 356083.3 6689005.6 15.1, 356083.8 6689008 15.1, 356081.5 6689008.5 15.1, 356082.4 6689012.5 15.1, 356105.7 6689012.3 15.1, 356113.8 6688995.4 15.1, 356103.4 6688994.3 15.1, 356101.5 6688985.9 15.1, 356063.1 6688994.7 15.1))
BATIMENT0000000302923948;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.8;7.1;25.0;27.6;8.6;Cadastre;C 0.2;POLYGON Z ((356141.3 6688990.4 25, 356141.6 6688990.5 25, 356133.9 6689006 25, 356135.1 6689006.6 25, 356134.5 6689007.9 25, 356133.2 6689007.5 25, 356126.7 6689020.5 25, 356128 6689021.2 25, 356126.8 6689023.4 25, 356125.6 6689022.9 25, 356118.9 6689036.3 25, 356120.4 6689036.9 25, 356119.5 6689038.7 25, 356120.6 6689039.2 25, 356119.5 6689041.5 25, 356126 6689044.7 25, 356126.5 6689044.9 25, 356125.7 6689046.5 25, 356129.5 6689048.3 25, 356129.3 6689048.6 25, 356129.2 6689048.7 25, 356129.2 6689048.9 25, 356129.1 6689049 25, 356129 6689049.3 25, 356129 6689049.5 25, 356129 6689049.8 25, 356129.1 6689050.1 25, 356129.2 6689050.4 25, 356129.3 6689050.7 25, 356129.6 6689050.9 25, 356129.7 6689051 25, 356129.8 6689051.1 25, 356129.9 6689051.2 25, 356130.1 6689051.3 25, 356130.4 6689051.4 25, 356130.5 6689051.4 25, 356130.7 6689051.4 25, 356130.8 6689051.4 25, 356131 6689051.4 25, 356131.2 6689051.4 25, 356131.3 6689051.4 25, 356131.6 6689051.3 25, 356131.9 6689051.1 25, 356132 6689051 25, 356132.1 6689050.9 25, 356132.2 6689050.8 25, 356132.3 6689050.7 25, 356132.5 6689050.4 25, 356136.9 6689040.9 25, 356134.4 6689039.9 25, 356135.7 6689037.2 25, 356138 6689038.5 25, 356141.8 6689030.5 25, 356143.8 6689023.8 25, 356144.7 6689024.2 25, 356147.3 6689018.9 25, 356145.7 6689018.2 25, 356146.5 6689016.8 25, 356145.2 6689016 25, 356145.7 6689014.7 25, 356146.3 6689014.9 25, 356154 6688999.8 25, 356154.4 6689000.1 25, 356155.9 6688997.1 25, 356155.4 6688996.8 25, 356141.5 6688990 25, 356141.3 6688990.4 25))
BATIMENT0000000302932599;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;8.2;19.2;25.0;8.5;Cadastre;;POLYGON Z ((356149.4 6689019.8 19.2, 356147.3 6689018.9 19.2, 356144.7 6689024.2 19.2, 356146.7 6689025.2 19.2, 356149.4 6689019.8 19.2))
BATIMENT0000000302932582;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;8.2;27.5;30.6;8.5;Cadastre;;POLYGON Z ((356155.8 6689027.7 27.5, 356154.5 6689030.5 27.5, 356161.6 6689033.9 27.5, 356162.9 6689031.3 27.5, 356163.9 6689031.7 27.5, 356166.4 6689026.5 27.5, 356163.9 6689025.4 27.5, 356165 6689022.9 27.5, 356162.5 6689021.6 27.5, 356164.6 6689017.4 27.5, 356161.6 6689016 27.5, 356158.5 6689014.6 27.5, 356152.7 6689026.4 27.5, 356155.8 6689027.7 27.5))
BATIMENT0000000302932581;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;;20;7.6;6.1;13.8;24.5;6.8;Cadastre;A 1.0;POLYGON Z ((356067.1 6689012.6 13.8, 356070.9 6689029.9 13.8, 356070.9 6689030.2 13.8, 356071 6689030.5 13.8, 356071.1 6689030.8 13.8, 356071.2 6689031 13.8, 356071.4 6689031.3 13.8, 356071.5 6689031.5 13.8, 356071.7 6689031.8 13.8, 356071.9 6689032 13.8, 356072.1 6689032.2 13.8, 356072.4 6689032.4 13.8, 356072.6 6689032.6 13.8, 356073.1 6689032.9 13.8, 356073.4 6689033 13.8, 356088.5 6689037 13.8, 356088.5 6689036.9 13.8, 356092 6689037.9 13.8, 356093.8 6689036.9 13.8, 356095.3 6689033.9 13.8, 356095.4 6689033.9 13.8, 356099.1 6689026.3 13.8, 356099 6689026.2 13.8, 356105.7 6689012.3 13.8, 356082.4 6689012.5 13.8, 356080.6 6689012.5 13.8, 356067.1 6689012.6 13.8), (356090.4 6689017.8 13.8, 356090.5 6689018.8 13.8, 356092 6689019.6 13.8, 356090.9 6689022 13.8, 356089.7 6689021.5 13.8, 356089.7 6689020.2 13.8, 356086.6 6689020.2 13.8, 356086.5 6689017.9 13.8, 356090.4 6689017.8 13.8))
BATIMENT0000000302932583;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.2;8.2;27.4;28.6;8.5;Cadastre;;POLYGON Z ((356149.9 6689028.3 27.4, 356147.4 6689033.4 27.4, 356160.4 6689039.5 27.4, 356162.3 6689040.4 27.4, 356170.1 6689024.2 27.4, 356171.4 6689024.9 27.4, 356171.9 6689023.5 27.4, 356176.2 6689025.6 27.4, 356177.6 6689022.7 27.4, 356178.2 6689021.4 27.4, 356174 6689019.4 27.4, 356173.5 6689020.3 27.4, 356158.3 6689013 27.4, 356150.8 6689028.6 27.4, 356149.9 6689028.3 27.4), (356158.5 6689014.6 27.4, 356161.6 6689016 27.4, 356164.6 6689017.4 27.4, 356162.5 6689021.6 27.4, 356165 6689022.9 27.4, 356163.9 6689025.4 27.4, 356166.4 6689026.5 27.4, 356163.9 6689031.7 27.4, 356162.9 6689031.3 27.4, 356161.6 6689033.9 27.4, 356154.5 6689030.5 27.4, 356155.8 6689027.7 27.4, 356152.7 6689026.4 27.4, 356158.5 6689014.6 27.4))
BATIMENT0000000302932624;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;20;20;18.3;6.1;24.5;26.8;6.5;Cadastre;A 1.0;POLYGON Z ((356057.1 6689023.3 24.5, 356053.1 6689022.6 24.5, 356043.2 6689039.1 24.5, 356044.3 6689039.7 24.5, 356050.8 6689038.2 24.5, 356060 6689036.2 24.5, 356057.1 6689023.3 24.5))
BATIMENT0000000302932591;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;8.1;15.2;24.5;8.6;Cadastre;;POLYGON Z ((356143.4 6689044.1 15.2, 356144.4 6689041.9 15.2, 356137.9 6689038.8 15.2, 356138 6689038.5 15.2, 356135.7 6689037.2 15.2, 356134.4 6689039.9 15.2, 356136.9 6689040.9 15.2, 356143.4 6689044.1 15.2))
BATIMENT0000000302932625;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.9;6.0;15.9;21.2;6.9;Cadastre;A 1.0;POLYGON Z ((356052.5 6689046.1 15.9, 356061.7 6689044 15.9, 356060 6689036.2 15.9, 356050.8 6689038.2 15.9, 356052.5 6689046.1 15.9))
BATIMENT0000000302932592;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.8;6.8;24.7;27.1;8.4;Cadastre;;POLYGON Z ((356117.9 6689038.2 24.7, 356116.2 6689041.8 24.7, 356125.7 6689046.5 24.7, 356126.5 6689044.9 24.7, 356126 6689044.7 24.7, 356119.5 6689041.5 24.7, 356120.6 6689039.2 24.7, 356119.5 6689038.7 24.7, 356120.4 6689036.9 24.7, 356118.9 6689036.3 24.7, 356117.9 6689038.2 24.7))
BATIMENT0000000302932596;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;7.8;27.2;27.9;8.4;Cadastre;;POLYGON Z ((356203.4 6689040.4 27.2, 356198.3 6689038.1 27.2, 356190.8 6689053.7 27.2, 356195.7 6689056.2 27.2, 356196.9 6689053.8 27.2, 356197.9 6689051.7 27.2, 356203.4 6689040.4 27.2))
BATIMENT0000000302932604;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.4;7.9;27.3;28.0;8.0;Cadastre;;POLYGON Z ((356222.8 6689048.9 27.3, 356211.8 6689043.5 27.3, 356206.1 6689055.1 27.3, 356211.8 6689057.7 27.3, 356211.1 6689059.1 27.3, 356215.8 6689061.4 27.3, 356216.6 6689059.8 27.3, 356217.3 6689060.2 27.3, 356222.8 6689048.9 27.3))
BATIMENT0000000302923943;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.3;7.7;24.0;27.0;9.0;Cadastre;C 0.1;POLYGON Z ((356312.5 6689078.1 24, 356314.4 6689079 24, 356313.2 6689081.4 24, 356327.8 6689075.1 24, 356353.8 6689022.2 24, 356343.8 6689017.4 24, 356343 6689019.2 24, 356341.5 6689018.5 24, 356343.9 6689013.4 24, 356340.2 6689011.6 24, 356334.9 6689022.6 24, 356310.7 6689010.8 24, 356319.7 6688992.3 24, 356315.9 6688990.5 24, 356315.6 6688991.2 24, 356303.2 6688983.2 24, 356288 6689014.3 24, 356289.2 6689015 24, 356288.3 6689016.7 24, 356287.2 6689016.1 24, 356261.2 6689069.5 24, 356274.5 6689075.9 24, 356272 6689081 24, 356270.4 6689080.2 24, 356270.6 6689079.9 24, 356266.5 6689078 24, 356243.8 6689107.3 24, 356254.7 6689112.6 24, 356255.6 6689110.8 24, 356257.1 6689111.5 24, 356254.2 6689117.6 24, 356257.9 6689119.4 24, 356262 6689111 24, 356286.1 6689122.6 24, 356298.9 6689096.4 24, 356301.5 6689097.7 24, 356302.7 6689098.3 24, 356312.5 6689078.1 24))
BATIMENT0000000302932603;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.5;7.9;26.5;27.2;8.4;Cadastre;;POLYGON Z ((356203.2 6689056.8 26.5, 356203.8 6689057.1 26.5, 356204.8 6689055 26.5, 356197.9 6689051.7 26.5, 356196.9 6689053.8 26.5, 356203.2 6689056.8 26.5))
BATIMENT0000000302932605;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.7;7.7;27.5;28.0;8.1;Cadastre;;POLYGON Z ((356203.8 6689057.1 27.5, 356203.2 6689056.8 27.5, 356200.7 6689062 27.5, 356221.9 6689072.2 27.5, 356229 6689057.6 27.5, 356221.7 6689054.1 27.5, 356224.6 6689048.5 27.5, 356211.1 6689042.1 27.5, 356204.8 6689055 27.5, 356203.8 6689057.1 27.5), (356216.6 6689059.8 27.5, 356215.8 6689061.4 27.5, 356211.1 6689059.1 27.5, 356211.8 6689057.7 27.5, 356206.1 6689055.1 27.5, 356211.8 6689043.5 27.5, 356222.8 6689048.9 27.5, 356217.3 6689060.2 27.5, 356216.6 6689059.8 27.5))
BATIMENT0000000302932601;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.3;7.9;22.2;27.7;8.5;Cadastre;C 0.2;POLYGON Z ((356185.7 6689060.8 22.2, 356171.8 6689054.3 22.2, 356164.4 6689069.6 22.2, 356167.1 6689071 22.2, 356169.2 6689066.6 22.2, 356169.1 6689066.1 22.2, 356169 6689065.5 22.2, 356168.9 6689065 22.2, 356168.9 6689064.5 22.2, 356169 6689063.9 22.2, 356169 6689063.4 22.2, 356169.1 6689062.9 22.2, 356169.3 6689062.4 22.2, 356169.5 6689061.9 22.2, 356169.7 6689061.4 22.2, 356170 6689061 22.2, 356170.3 6689060.5 22.2, 356170.7 6689060.1 22.2, 356171 6689059.8 22.2, 356171.4 6689059.4 22.2, 356171.9 6689059.1 22.2, 356172.3 6689058.8 22.2, 356172.8 6689058.6 22.2, 356173.3 6689058.4 22.2, 356173.8 6689058.2 22.2, 356174.3 6689058.1 22.2, 356174.8 6689058 22.2, 356175.3 6689057.9 22.2, 356175.9 6689057.9 22.2, 356176.4 6689058 22.2, 356176.9 6689058.1 22.2, 356177.4 6689058.2 22.2, 356177.9 6689058.4 22.2, 356178.4 6689058.6 22.2, 356178.9 6689058.8 22.2, 356179.4 6689059.1 22.2, 356179.8 6689059.4 22.2, 356180.2 6689059.8 22.2, 356180.5 6689060.1 22.2, 356180.9 6689060.6 22.2, 356181.2 6689061 22.2, 356181.5 6689061.5 22.2, 356181.7 6689061.9 22.2, 356181.9 6689062.4 22.2, 356182 6689062.9 22.2, 356181.2 6689064.4 22.2, 356186.3 6689066.7 22.2, 356185.5 6689068.5 22.2, 356187.7 6689069.4 22.2, 356189.1 6689066.3 22.2, 356184.2 6689064 22.2, 356185.7 6689060.8 22.2))
BATIMENT0000000302932600;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;22.2;6.0;28.2;30.4;8.5;Cadastre;C 0.1;POLYGON Z ((356189.4 6689070.2 28.2, 356187.7 6689069.4 28.2, 356185.5 6689068.5 28.2, 356186.3 6689066.7 28.2, 356181.2 6689064.4 28.2, 356182 6689062.9 28.2, 356181.9 6689062.4 28.2, 356181.7 6689061.9 28.2, 356181.5 6689061.5 28.2, 356181.2 6689061 28.2, 356180.9 6689060.6 28.2, 356180.5 6689060.1 28.2, 356180.2 6689059.8 28.2, 356179.8 6689059.4 28.2, 356179.4 6689059.1 28.2, 356178.9 6689058.8 28.2, 356178.4 6689058.6 28.2, 356177.9 6689058.4 28.2, 356177.4 6689058.2 28.2, 356176.9 6689058.1 28.2, 356176.4 6689058 28.2, 356175.9 6689057.9 28.2, 356175.3 6689057.9 28.2, 356174.8 6689058 28.2, 356174.3 6689058.1 28.2, 356173.8 6689058.2 28.2, 356173.3 6689058.4 28.2, 356172.8 6689058.6 28.2, 356172.3 6689058.8 28.2, 356171.9 6689059.1 28.2, 356171.4 6689059.4 28.2, 356171 6689059.8 28.2, 356170.7 6689060.1 28.2, 356170.3 6689060.5 28.2, 356170 6689061 28.2, 356169.7 6689061.4 28.2, 356169.5 6689061.9 28.2, 356169.3 6689062.4 28.2, 356169.1 6689062.9 28.2, 356169 6689063.4 28.2, 356169 6689063.9 28.2, 356168.9 6689064.5 28.2, 356168.9 6689065 28.2, 356169 6689065.5 28.2, 356169.1 6689066.1 28.2, 356169.2 6689066.6 28.2, 356167.1 6689071 28.2, 356164.4 6689069.6 28.2, 356163.9 6689069.3 28.2, 356163 6689071.1 28.2, 356161.3 6689074.7 28.2, 356175.4 6689081.5 28.2, 356182.3 6689084.9 28.2, 356189.4 6689070.2 28.2))
BATIMENT0000000302932579;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.4;7.3;23.7;25.7;8.8;Cadastre;;POLYGON Z ((356310.3 6689107.8 23.7, 356299.7 6689130 23.7, 356301.6 6689131 23.7, 356310.6 6689112.1 23.7, 356312.3 6689108.7 23.7, 356311.7 6689108.4 23.7, 356310.3 6689107.8 23.7))
BATIMENT0000000302932662;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;35;20;15.3;6.7;22.0;24.9;7.6;Cadastre;C 0.5;POLYGON Z ((356162.7 6689110.6 22, 356162.6 6689110.8 22, 356157.4 6689120.8 22, 356176 6689130.6 22, 356181.3 6689120.4 22, 356162.7 6689110.6 22))
BATIMENT0000000302932577;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.4;7.4;24.9;27.6;8.8;Cadastre;C 0.3;POLYGON Z ((356281.7 6689134.1 24.9, 356279 6689139.7 24.9, 356278.1 6689139.3 24.9, 356276.3 6689142.9 24.9, 356279 6689144.3 24.9, 356279.8 6689142.7 24.9, 356281.4 6689143.5 24.9, 356280.7 6689145.1 24.9, 356287.9 6689148.6 24.9, 356290.2 6689149.8 24.9, 356299.7 6689130 24.9, 356310.3 6689107.8 24.9, 356312.6 6689103 24.9, 356303.3 6689098.5 24.9, 356302.5 6689100.2 24.9, 356300.6 6689099.3 24.9, 356301.5 6689097.7 24.9, 356298.9 6689096.4 24.9, 356286.1 6689122.6 24.9, 356280.8 6689133.7 24.9, 356281.7 6689134.1 24.9))
BATIMENT0000000302932586;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.5;8.2;24.7;28.1;8.7;Cadastre;C 0.2;POLYGON Z ((356156.4 6689047.7 24.7, 356164 6689051.4 24.7, 356168 6689043.2 24.7, 356162.3 6689040.4 24.7, 356160.4 6689039.5 24.7, 356156.4 6689047.7 24.7))
BATIMENT0000000302932626;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1908-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;;;11.2;7.0;18.2;;;Cadastre;A 1.0;POLYGON Z ((356050.9 6689046.4 18.2, 356049.6 6689052.1 18.2, 356053.7 6689051.2 18.2, 356053.9 6689052.2 18.2, 356052.2 6689052.5 18.2, 356052.5 6689053.8 18.2, 356063.4 6689051.3 18.2, 356061.7 6689044 18.2, 356052.5 6689046.1 18.2, 356050.9 6689046.4 18.2))
BATIMENT0000000302932588;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.6;7.3;27.0;27.8;8.7;Cadastre;;POLYGON Z ((356140.3 6689057.8 27, 356141.5 6689058.5 27, 356142.5 6689056.4 27, 356139.1 6689054.9 27, 356144.8 6689043.3 27, 356155.9 6689048.6 27, 356156.4 6689047.7 27, 356144.4 6689041.9 27, 356143.4 6689044.1 27, 356137.3 6689056.4 27, 356136.5 6689056 27, 356133.9 6689061.5 27, 356137.7 6689063.3 27, 356140.3 6689057.8 27))
BATIMENT0000000302932589;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.0;7.9;26.9;28.6;8.7;Cadastre;;POLYGON Z ((356150.5 6689060 26.9, 356149.7 6689059.6 26.9, 356149.1 6689060.9 26.9, 356147.6 6689060.1 26.9, 356147.1 6689061.1 26.9, 356157 6689065.9 26.9, 356164 6689051.4 26.9, 356156.4 6689047.7 26.9, 356155.9 6689048.6 26.9, 356150.5 6689060 26.9))
BATIMENT0000000302932628;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.8;6.1;13.0;20.0;6.8;Cadastre;A 1.0;POLYGON Z ((356048.6 6689056.6 13, 356047.3 6689062.7 13, 356053.6 6689061.3 13, 356055.3 6689060.9 13, 356065 6689058.7 13, 356063.4 6689051.3 13, 356052.5 6689053.8 13, 356049.1 6689054.5 13, 356048.6 6689056.6 13))
BATIMENT0000000302932587;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;22.1;6.0;28.1;30.6;8.7;Cadastre;;POLYGON Z ((356157 6689065.9 28.1, 356147.1 6689061.1 28.1, 356147.6 6689060.1 28.1, 356149.1 6689060.9 28.1, 356149.7 6689059.6 28.1, 356150.5 6689060 28.1, 356155.9 6689048.6 28.1, 356144.8 6689043.3 28.1, 356139.1 6689054.9 28.1, 356142.5 6689056.4 28.1, 356141.5 6689058.5 28.1, 356140.3 6689057.8 28.1, 356137.7 6689063.3 28.1, 356139.2 6689064 28.1, 356155.1 6689071.7 28.1, 356156.8 6689068.1 28.1, 356157.7 6689066.3 28.1, 356157 6689065.9 28.1))
BATIMENT0000000302932590;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;7.5;26.8;27.5;8.3;Cadastre;;POLYGON Z ((356163 6689071.1 26.8, 356163.9 6689069.3 26.8, 356157.7 6689066.3 26.8, 356156.8 6689068.1 26.8, 356163 6689071.1 26.8))
BATIMENT0000000302932653;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;;;8.7;5.4;14.1;16.6;7.0;Cadastre;A 1.0;POLYGON Z ((356086.6 6689078.8 14.1, 356091.9 6689077.6 14.1, 356093.6 6689074.3 14.1, 356081.8 6689068.1 14.1, 356079.3 6689070 14.1, 356081.5 6689079.9 14.1, 356086.6 6689078.8 14.1))
BATIMENT0000000302932629;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;133.0;6.0;01;04;16.5;6.2;22.7;25.3;6.7;Cadastre;C 0.8;POLYGON Z ((356060.4 6689091.9 22.7, 356071.9 6689089.2 22.7, 356069.8 6689079.7 22.7, 356067.7 6689070.8 22.7, 356066.1 6689063.3 22.7, 356065 6689058.7 22.7, 356055.3 6689060.9 22.7, 356053.6 6689061.3 22.7, 356058.2 6689084 22.7, 356058.1 6689084.1 22.7, 356058 6689084.2 22.7, 356057.8 6689084.2 22.7, 356057.2 6689084.6 22.7, 356056.9 6689084.8 22.7, 356056.6 6689085 22.7, 356056.3 6689085.2 22.7, 356056.1 6689085.4 22.7, 356056 6689085.4 22.7, 356055.7 6689085.7 22.7, 356055.4 6689085.9 22.7, 356055.3 6689086 22.7, 356055.1 6689086.2 22.7, 356055 6689086.3 22.7, 356054.8 6689086.5 22.7, 356054.7 6689086.6 22.7, 356054.5 6689086.8 22.7, 356054.4 6689087 22.7, 356054.3 6689087.1 22.7, 356053.9 6689087.6 22.7, 356047.2 6689083.9 22.7, 356046.1 6689083.3 22.7, 356045.4 6689081.7 22.7, 356037.6 6689083.7 22.7, 356033.1 6689090.8 22.7, 356054 6689102.9 22.7, 356059.5 6689093.5 22.7, 356060.4 6689091.9 22.7))
BATIMENT0000000302932652;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;35.0;6.0;00;00;15.9;5.4;21.3;24.0;7.1;Cadastre;A 1.0;POLYGON Z ((356095.9 6689093.5 21.3, 356098.2 6689089 21.3, 356105.4 6689092.8 21.3, 356110.6 6689083.2 21.3, 356093.6 6689074.3 21.3, 356091.9 6689077.6 21.3, 356086.6 6689078.8 21.3, 356081.5 6689079.9 21.3, 356083.8 6689090.5 21.3, 356085.7 6689098.9 21.3, 356086.8 6689104.1 21.3, 356090.3 6689103.2 21.3, 356097.6 6689101.5 21.3, 356095.9 6689093.5 21.3))
BATIMENT0000000302932654;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;35;20;16.5;5.4;21.9;24.9;7.2;Cadastre;C 0.8;POLYGON Z ((356110.6 6689083.2 21.9, 356105.4 6689092.8 21.9, 356122.9 6689101.8 21.9, 356127.8 6689093.5 21.9, 356128.3 6689092.5 21.9, 356110.6 6689083.2 21.9))
BATIMENT0000000302932632;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;7.1;6.3;13.5;20.0;6.6;Cadastre;C 0.4;POLYGON Z ((356057.8 6689105.2 13.5, 356062.1 6689097.9 13.5, 356066.6 6689096.9 13.5, 356073.3 6689095.3 13.5, 356071.9 6689089.2 13.5, 356060.4 6689091.9 13.5, 356059.5 6689093.5 13.5, 356054 6689102.9 13.5, 356057.8 6689105.2 13.5))
BATIMENT0000000302932634;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;7.0;11.8;;;Cadastre;;POLYGON Z ((356060.8 6689106.9 11.8, 356066.6 6689096.9 11.8, 356062.1 6689097.9 11.8, 356057.8 6689105.2 11.8, 356060.8 6689106.9 11.8))
BATIMENT0000000302932656;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.5;6.5;10.1;13.5;7.1;Cadastre;C 0.4;POLYGON Z ((356099.8 6689103.1 10.1, 356107.6 6689107.7 10.1, 356116.4 6689112.8 10.1, 356118.3 6689109.7 10.1, 356119.2 6689108.1 10.1, 356102.4 6689098.2 10.1, 356099.8 6689103.1 10.1))
BATIMENT0000000302932657;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.6;6.8;19.5;25.6;7.2;Cadastre;A 1.0;POLYGON Z ((356134 6689118.2 19.5, 356138.4 6689110.9 19.5, 356144.1 6689101.2 19.5, 356139.2 6689098.2 19.5, 356138.7 6689099.2 19.5, 356127.8 6689093.5 19.5, 356122.9 6689101.8 19.5, 356122.6 6689102.2 19.5, 356119.2 6689108.1 19.5, 356118.3 6689109.7 19.5, 356134 6689118.2 19.5))
BATIMENT0000000302932647;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;7.0;15.2;;;Cadastre;;POLYGON Z ((356071.1 6689102.6 15.2, 356070.7 6689103.1 15.2, 356069.1 6689102.4 15.2, 356067.2 6689103.9 15.2, 356067.3 6689105.6 15.2, 356066.7 6689105.8 15.2, 356064.8 6689109.2 15.2, 356073.8 6689114.4 15.2, 356077 6689112 15.2, 356074.7 6689101.8 15.2, 356071.1 6689102.6 15.2))
BATIMENT0000000302932663;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.6;6.1;9.7;11.1;6.9;Cadastre;C 0.4;POLYGON Z ((356115.2 6689115 9.7, 356116.4 6689112.8 9.7, 356107.6 6689107.7 9.7, 356105.1 6689112.2 9.7, 356110.5 6689115.3 9.7, 356108.9 6689118.1 9.7, 356112.3 6689120 9.7, 356115.2 6689115 9.7))
BATIMENT0000000302932655;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1888-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;13.6;7.0;20.6;;;Cadastre;C 0.8;POLYGON Z ((356091.2 6689124.1 20.6, 356105.1 6689132.2 20.6, 356110.8 6689122.5 20.6, 356101.3 6689117.3 20.6, 356101.2 6689116.6 20.6, 356101.7 6689116.1 20.6, 356100.9 6689113.2 20.6, 356100.3 6689112.9 20.6, 356097.7 6689101.9 20.6, 356097.6 6689101.5 20.6, 356090.3 6689103.2 20.6, 356086.8 6689104.1 20.6, 356091.2 6689124.1 20.6))
BATIMENT0000000302932660;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;00;00;4.4;6.7;11.2;26.0;7.6;Cadastre;A 1.0;POLYGON Z ((356144.7 6689142.5 11.2, 356150.1 6689133.2 11.2, 356154 6689126.7 11.2, 356157.4 6689120.8 11.2, 356162.6 6689110.8 11.2, 356155.5 6689107.3 11.2, 356155.7 6689106.9 11.2, 356155.9 6689106.7 11.2, 356155 6689106.2 11.2, 356154.9 6689106.4 11.2, 356154.7 6689106.8 11.2, 356151.4 6689105.1 11.2, 356151.7 6689104.7 11.2, 356151.8 6689104.5 11.2, 356150.8 6689104 11.2, 356150.7 6689104.2 11.2, 356150.5 6689104.6 11.2, 356144.1 6689101.2 11.2, 356138.4 6689110.9 11.2, 356134 6689118.2 11.2, 356130.7 6689123.9 11.2, 356126.3 6689131.4 11.2, 356120.5 6689141.1 11.2, 356138.9 6689152 11.2, 356139.2 6689152.2 11.2, 356144.7 6689142.5 11.2))
BATIMENT0000000302932658;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;6.0;00;00;4.4;6.5;10.9;25.1;7.2;Cadastre;A 1.0;POLYGON Z ((356110.4 6689135.3 10.9, 356110.7 6689134.7 10.9, 356112.2 6689135.6 10.9, 356115.4 6689137.5 10.9, 356120.5 6689141.1 10.9, 356126.3 6689131.4 10.9, 356130.7 6689123.9 10.9, 356115.2 6689115 10.9, 356112.3 6689120 10.9, 356110.8 6689122.5 10.9, 356105.1 6689132.2 10.9, 356110.4 6689135.3 10.9))
BATIMENT0000000302923716;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;33.0;4.0;20;20;9.8;6.5;16.3;20.4;7.6;Cadastre;C 0.3;POLYGON Z ((356025.1 6688920.3 16.3, 356024 6688917.3 16.3, 356013.4 6688914.9 16.3, 356011 6688925.2 16.3, 356015.7 6688926.3 16.3, 356015 6688929.1 16.3, 356007.7 6688927.6 16.3, 356005.6 6688926.5 16.3, 356002.6 6688931.6 16.3, 356005.9 6688933.5 16.3, 356001.5 6688941.1 16.3, 355998.1 6688939.1 16.3, 355997.4 6688940.3 16.3, 355995.8 6688946.8 16.3, 356007.1 6688949.4 16.3, 356008 6688949.6 16.3, 356011.5 6688943.6 16.3, 356007.3 6688942.7 16.3, 356008.2 6688938.7 16.3, 356013.5 6688940.1 16.3, 356025.1 6688920.3 16.3))
BATIMENT0000000302924023;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.2;6.3;14.5;17.4;7.5;Cadastre;C 0.1;POLYGON Z ((355992 6688946 14.5, 355992 6688945.9 14.5, 355995.8 6688946.8 14.5, 355997.4 6688940.3 14.5, 355998.1 6688939.1 14.5, 356002.6 6688931.6 14.5, 355979.9 6688926.5 14.5, 355979 6688930.7 14.5, 355978.4 6688933.2 14.5, 355976.3 6688942.4 14.5, 355992 6688946 14.5))
BATIMENT0000000302923933;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;15.5;6.0;21.5;24.4;7.0;Cadastre;A 1.0;POLYGON Z ((356036 6688928.5 21.5, 356033.4 6688928.1 21.5, 356027.7 6688938.1 21.5, 356029 6688943.8 21.5, 356025.4 6688942.3 21.5, 356023.5 6688945.6 21.5, 356028.9 6688948.6 21.5, 356030.6 6688949.5 21.5, 356040.2 6688947.2 21.5, 356036 6688928.5 21.5))
BATIMENT0000000302923919;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;6.6;18.7;20.9;7.5;Cadastre;;POLYGON Z ((356008.2 6688938.7 18.7, 356007.3 6688942.7 18.7, 356011.5 6688943.6 18.7, 356013.5 6688940.1 18.7, 356008.2 6688938.7 18.7))
BATIMENT0000000302923927;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;6.5;14.0;19.2;7.1;Cadastre;;POLYGON Z ((356027.1 6688951.7 14, 356028.8 6688952.7 14, 356030.6 6688949.5 14, 356028.9 6688948.6 14, 356027.1 6688951.7 14))
BATIMENT0000000302923932;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.2;6.4;14.7;21.0;7.2;Cadastre;A 1.0;POLYGON Z ((356040.2 6688947.2 14.7, 356030.6 6688949.5 14.7, 356028.8 6688952.7 14.7, 356028.2 6688953.7 14.7, 356030.8 6688953.1 14.7, 356031.6 6688956.6 14.7, 356032.8 6688956.3 14.7, 356041.7 6688954.2 14.7, 356040.2 6688947.2 14.7))
BATIMENT0000000302923926;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;6.2;6.0;12.2;13.1;7.2;Cadastre;A 1.0;POLYGON Z ((356021.7 6688948.7 12.2, 356015.2 6688960.1 12.2, 356019.4 6688962.3 12.2, 356022.3 6688963.9 12.2, 356025.6 6688958.1 12.2, 356028.2 6688953.7 12.2, 356028.8 6688952.7 12.2, 356027.1 6688951.7 12.2, 356021.7 6688948.7 12.2))
BATIMENT0000000302923916;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;40.0;4.0;00;00;12.4;5.5;18.0;22.2;7.4;Cadastre;A 1.0;POLYGON Z ((356006.5 6688952.1 18, 356005.8 6688951.8 18, 356007.1 6688949.4 18, 355995.8 6688946.8 18, 355992 6688945.9 18, 355992 6688946 18, 355981.9 6688963.3 18, 355984.6 6688964.2 18, 355988.2 6688965.5 18, 355996.3 6688968.2 18, 355997.4 6688966.1 18, 355998.1 6688966.5 18, 356000.5 6688962.4 18, 356006.5 6688952.1 18))
BATIMENT0000000302923925;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.9;6.0;10.9;16.7;6.8;Cadastre;A 1.0;POLYGON Z ((356041.7 6688954.2 10.9, 356032.8 6688956.3 10.9, 356033.7 6688960.7 10.9, 356033 6688960.9 10.9, 356033.1 6688961.2 10.9, 356024 6688963.3 10.9, 356025.1 6688968.2 10.9, 356031.1 6688966.8 10.9, 356032.6 6688966.5 10.9, 356033.4 6688966.3 10.9, 356043.8 6688963.9 10.9, 356041.7 6688954.2 10.9))
BATIMENT0000000302930119;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;5.3;13.5;19.1;5.9;Cadastre;;POLYGON Z ((355981.9 6688970 13.5, 355984.9 6688971.2 13.5, 355988.2 6688965.5 13.5, 355984.6 6688964.2 13.5, 355981.9 6688970 13.5))
BATIMENT0000000302930142;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.2;6.0;11.2;12.0;6.9;Cadastre;A 1.0;POLYGON Z ((355855.4 6688929.7 11.2, 355851.1 6688928.1 11.2, 355847.1 6688938.2 11.2, 355849.7 6688939.2 11.2, 355855.4 6688929.7 11.2))
BATIMENT0000000302930141;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;20;20;14.1;6.5;20.7;24.5;6.9;Cadastre;A 1.0;POLYGON Z ((355843.2 6688940.3 20.7, 355848 6688942.2 20.7, 355849.7 6688939.2 20.7, 355847.1 6688938.2 20.7, 355851.1 6688928.1 20.7, 355848.9 6688927.1 20.7, 355845.8 6688936 20.7, 355846.4 6688936.3 20.7, 355846 6688937.4 20.7, 355844.2 6688936.8 20.7, 355847.5 6688926.6 20.7, 355838.6 6688922.9 20.7, 355837.1 6688923.5 20.7, 355829.6 6688948 20.7, 355829.7 6688948.1 20.7, 355832 6688949.1 20.7, 355839.5 6688952.1 20.7, 355843.2 6688940.3 20.7))
BATIMENT0000000327821894;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;1930-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;4.0;3.0;10;20;4.1;7.1;;;;Imagerie aérienne;C 0.6;POLYGON Z ((355898.4 6688947.8 11.2, 355871.8 6688936.4 11.2, 355869.4 6688940.6 11.2, 355874.3 6688943.8 11.2, 355871.7 6688948.2 11.2, 355885.9 6688956.7 11.2, 355889 6688951.3 11.2, 355891.7 6688952.7 11.2, 355893.4 6688950.1 11.2, 355897.4 6688952.5 11.2, 355898.4 6688947.8 11.2))
BATIMENT0000000302930140;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;6.2;13.4;17.8;6.8;Cadastre;;POLYGON Z ((355826.1 6688959.9 13.4, 355824.7 6688964.2 13.4, 355829.9 6688967.2 13.4, 355827.7 6688970.8 13.4, 355872.3 6688996.7 13.4, 355877.2 6688988.4 13.4, 355834.7 6688963.8 13.4, 355840.8 6688952.6 13.4, 355839.5 6688952.1 13.4, 355832 6688949.1 13.4, 355826.1 6688959.9 13.4))
BATIMENT0000000302930150;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;6.0;11.2;17.4;7.1;Cadastre;;POLYGON Z ((355904.9 6689015.7 11.2, 355904.8 6689015.9 11.2, 355915.9 6689022.4 11.2, 355916 6689022.2 11.2, 355917.2 6689022.9 11.2, 355917.1 6689023.1 11.2, 355917.3 6689023.3 11.2, 355918.7 6689017.9 11.2, 355913.8 6689015.1 11.2, 355919.9 6689004.7 11.2, 355921.9 6689005.4 11.2, 355926.4 6688987.8 11.2, 355925.9 6688987.5 11.2, 355925.8 6688987.5 11.2, 355924.2 6688986.5 11.2, 355926.2 6688978.9 11.2, 355926.9 6688975.7 11.2, 355923.2 6688973.6 11.2, 355921.7 6688976.2 11.2, 355906.8 6688967.6 11.2, 355907.7 6688966.2 11.2, 355895.1 6688958.8 11.2, 355897.4 6688952.5 11.2, 355893.4 6688950.1 11.2, 355891.7 6688952.7 11.2, 355889 6688951.3 11.2, 355885.9 6688956.7 11.2, 355881.8 6688963.8 11.2, 355897.9 6688973.3 11.2, 355881.4 6689002 11.2, 355904.9 6689015.7 11.2), (355902.5 6688981.7 11.2, 355904.6 6688982.9 11.2, 355907.2 6688978.6 11.2, 355921.8 6688987.2 11.2, 355911.1 6689005.5 11.2, 355909.8 6689007.6 11.2, 355893.1 6688997.8 11.2, 355902.5 6688981.7 11.2))
BATIMENT0000000302930149;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:05:58;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;6.2;8.5;10.2;6.8;Cadastre;;POLYGON Z ((355902.5 6688981.7 8.5, 355893.1 6688997.8 8.5, 355909.8 6689007.6 8.5, 355911.1 6689005.5 8.5, 355896.4 6688997 8.5, 355904.6 6688982.9 8.5, 355902.5 6688981.7 8.5))
BATIMENT0000000302930156;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.0;6.4;15.4;20.2;7.3;Cadastre;A 1.0;POLYGON Z ((355851.1 6689002.3 15.4, 355853.1 6689003.2 15.4, 355854.7 6688998.2 15.4, 355843.4 6688991.6 15.4, 355831.7 6689013.5 15.4, 355847.7 6689021 15.4, 355849.4 6689015.6 15.4, 355845.4 6689013.5 15.4, 355851.1 6689002.3 15.4))
BATIMENT0000000327821888;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2013-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;3.0;3.0;00;00;12.6;6.2;;19.5;6.8;Imagerie aérienne;A 1.0;POLYGON Z ((355854.7 6688998.2 18.8, 355853.1 6689003.2 18.8, 355850.6 6689009.4 18.8, 355869.3 6689020.6 18.8, 355873.1 6689008.9 18.8, 355854.7 6688998.2 18.8))
BATIMENT0000000302930310;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.5;12.7;13.7;7.0;Cadastre;;POLYGON Z ((355825 6689010.3 12.7, 355824.3 6689012.2 12.7, 355826.1 6689012.8 12.7, 355826.8 6689011.2 12.7, 355825 6689010.3 12.7))
BATIMENT0000000302930311;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.8;6.4;13.2;15.5;7.3;Cadastre;;POLYGON Z ((355826.8 6689011.2 13.2, 355826.1 6689012.8 13.2, 355824.5 6689017.3 13.2, 355828.9 6689019 13.2, 355831.5 6689013.4 13.2, 355826.8 6689011.2 13.2))
BATIMENT0000000302923928;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;8.7;6.0;14.7;16.6;6.8;Cadastre;A 1.0;POLYGON Z ((356008.1 6688972.1 14.7, 356015.1 6688976.2 14.7, 356018.9 6688969.7 14.7, 356021.3 6688965.6 14.7, 356018.4 6688964 14.7, 356019.4 6688962.3 14.7, 356015.2 6688960.1 14.7, 356008.1 6688972.1 14.7))
BATIMENT0000000302923929;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;6.4;13.7;17.0;6.7;Cadastre;;POLYGON Z ((356032.2 6688972 13.7, 356033.7 6688971.6 13.7, 356032.6 6688966.5 13.7, 356031.1 6688966.8 13.7, 356032.2 6688972 13.7))
BATIMENT0000000302923924;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:45:35;2018-09-18 13:52:16;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.8;6.0;17.8;20.9;6.7;Cadastre;;POLYGON Z ((356048 6688982.8 17.8, 356043.8 6688963.9 17.8, 356033.4 6688966.3 17.8, 356034.9 6688973.4 17.8, 356035.7 6688976.7 17.8, 356037.5 6688985.1 17.8, 356037.5 6688985.3 17.8, 356048 6688982.8 17.8))
BATIMENT0000000302930118;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;34;20;10.5;5.6;16.2;20.1;6.3;Cadastre;A 1.0;POLYGON Z ((355978 6688985.1 16.2, 355978.2 6688984.8 16.2, 355984.2 6688988.5 16.2, 355984.1 6688988.7 16.2, 355984.9 6688989.2 16.2, 355997 6688968.5 16.2, 355996.3 6688968.2 16.2, 355988.2 6688965.5 16.2, 355984.9 6688971.2 16.2, 355977.2 6688984.6 16.2, 355978 6688985.1 16.2))
BATIMENT0000000302923921;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2023-01-31 17:56:42;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;10;7.3;6.0;13.3;13.4;6.7;Cadastre;C 0.2;POLYGON Z ((356015.1 6688976.2 13.3, 356014.9 6688976.6 13.3, 356015 6688976.8 13.3, 356018.3 6688978.7 13.3, 356016.5 6688981.8 13.3, 356013.4 6688987 13.3, 356011.1 6688991 13.3, 356020.9 6688988.8 13.3, 356020.2 6688985.8 13.3, 356031.1 6688983.3 13.3, 356030.3 6688979.7 13.3, 356026.4 6688980.6 13.3, 356024.9 6688974.2 13.3, 356032.3 6688972.5 13.3, 356032.2 6688972 13.3, 356031.1 6688966.8 13.3, 356025.1 6688968.2 13.3, 356018.9 6688969.7 13.3, 356015.1 6688976.2 13.3))
BATIMENT0000000302923923;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;6.1;5.8;12.0;15.8;6.2;Cadastre;A 1.0;POLYGON Z ((356002.9 6688980.8 12, 356013.4 6688987 12, 356016.5 6688981.8 12, 356013.9 6688980.3 12, 356012.6 6688982.6 12, 356009 6688980.5 12, 356010.5 6688978 12, 356013.3 6688979.6 12, 356015 6688976.8 12, 356014.9 6688976.6 12, 356015.1 6688976.2 12, 356008.1 6688972.1 12, 356002.9 6688980.8 12))
BATIMENT0000000302923920;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:45:35;2018-09-18 13:52:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;6.0;10.2;12.4;6.4;Cadastre;;POLYGON Z ((356031.7 6688986.4 10.2, 356031.1 6688983.3 10.2, 356020.2 6688985.8 10.2, 356020.9 6688988.8 10.2, 356031.7 6688986.4 10.2))
BATIMENT0000000302923917;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;10.3;6.0;16.3;20.0;6.3;Cadastre;A 1.0;POLYGON Z ((355998.3 6688989.5 16.3, 356005.8 6688994 16.3, 356007.1 6688991.8 16.3, 356008.2 6688992.4 16.3, 356009.2 6688992.1 16.3, 356009.9 6688991.1 16.3, 356010.7 6688991.6 16.3, 356011.1 6688991 16.3, 356013.4 6688987 16.3, 356002.9 6688980.8 16.3, 355997.9 6688989.3 16.3, 355998.3 6688989.5 16.3))
BATIMENT0000000302923922;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;;;5.5;5.9;11.5;19.3;6.5;Cadastre;A 1.0;POLYGON Z ((356013.9 6688998.8 11.5, 356049.7 6688990.7 11.5, 356048 6688982.8 11.5, 356037.5 6688985.3 11.5, 356037.5 6688985.1 11.5, 356031.7 6688986.4 11.5, 356020.9 6688988.8 11.5, 356011.1 6688991 11.5, 356010.7 6688991.6 11.5, 356008.4 6688995.5 11.5, 356009.2 6688996 11.5, 356011.4 6688997.3 11.5, 356013.8 6688998.8 11.5, 356013.9 6688998.8 11.5))
BATIMENT0000000302923930;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.6;6.0;13.6;16.7;6.9;Cadastre;A 1.0;POLYGON Z ((356013.9 6688998.8 13.6, 356013.8 6688998.8 13.6, 356027.2 6689006.8 13.6, 356029 6689003.6 13.6, 356030.1 6689003.4 13.6, 356051.7 6688999.1 13.6, 356049.7 6688990.7 13.6, 356013.9 6688998.8 13.6))
BATIMENT0000000302930120;Indifférenciée;Commercial et services;Résidentiel;Oui;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;;;5.1;5.5;10.7;13.7;6.2;Cadastre;B 1.0;POLYGON Z ((355977.2 6688984.6 10.7, 355984.9 6688971.2 10.7, 355981.9 6688970 10.7, 355976.2 6688967.5 10.7, 355973 6688973.3 10.7, 355973.2 6688973.4 10.7, 355969.6 6688979.9 10.7, 355977.2 6688984.6 10.7))
BATIMENT0000000302930158;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;6.3;9.1;10.0;6.9;Cadastre;;POLYGON Z ((355955.5 6688997.2 9.1, 355953.8 6688996.2 9.1, 355951.7 6688999.6 9.1, 355953.4 6689000.7 9.1, 355955.5 6688997.2 9.1))
BATIMENT0000000302930157;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;90;90;14.3;5.9;20.3;22.5;6.9;Cadastre;A 1.0;POLYGON Z ((355970.7 6689014.3 20.3, 355982.4 6688994.3 20.3, 355971.1 6688987.6 20.3, 355968 6688985.8 20.3, 355963.8 6688983.2 20.3, 355962.1 6688986.2 20.3, 355956.2 6688996.1 20.3, 355964.3 6689000.8 20.3, 355967 6688996.2 20.3, 355969.1 6688997.4 20.3, 355966.4 6689002.1 20.3, 355962.1 6689009.3 20.3, 355970.7 6689014.3 20.3))
BATIMENT0000000302930339;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;6.4;13.1;17.7;6.8;Cadastre;;POLYGON Z ((355954.8 6689006.5 13.1, 355955.6 6689006.9 13.1, 355956.2 6689005.9 13.1, 355951.8 6689003.3 13.1, 355950.7 6689002.7 13.1, 355947.6 6689008.3 13.1, 355952.2 6689010.9 13.1, 355954.8 6689006.5 13.1))
BATIMENT0000000302930338;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;11.4;6.0;17.5;19.0;6.5;Cadastre;C 0.5;POLYGON Z ((355951.9 6689019.4 17.5, 355953.1 6689017.3 17.5, 355950.7 6689016 17.5, 355950.3 6689014.1 17.5, 355952.2 6689010.9 17.5, 355947.6 6689008.3 17.5, 355943.9 6689014.9 17.5, 355951.2 6689019.1 17.5, 355951.9 6689019.4 17.5))
BATIMENT0000000302930330;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;10.2;6.3;16.5;19.7;6.9;Cadastre;C 0.2;POLYGON Z ((355970.7 6689014.3 16.5, 355962.1 6689009.3 16.5, 355961.4 6689008.9 16.5, 355961 6689008.6 16.5, 355960.5 6689009.6 16.5, 355962.7 6689010.9 16.5, 355960.1 6689015.5 16.5, 355967.5 6689019.8 16.5, 355970.7 6689014.3 16.5))
BATIMENT0000000302931786;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.3;5.8;9.1;9.5;6.3;Cadastre;;POLYGON Z ((355955.3 6689014.6 9.1, 355957.2 6689015.6 9.1, 355958 6689014.3 9.1, 355956.1 6689013.2 9.1, 355955.3 6689014.6 9.1))
BATIMENT0000000302930337;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;6.0;10.5;14.7;6.3;Cadastre;;POLYGON Z ((355939.6 6689022.2 10.5, 355946.7 6689026.4 10.5, 355950.7 6689019.8 10.5, 355951.2 6689019.1 10.5, 355943.9 6689014.9 10.5, 355942.3 6689017.5 10.5, 355939.6 6689022.2 10.5))
BATIMENT0000000302930331;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;9.6;6.3;15.9;17.7;6.3;Cadastre;C 0.8;POLYGON Z ((355967.5 6689019.8 15.9, 355960.1 6689015.5 15.9, 355956.2 6689022 15.9, 355963.6 6689026.5 15.9, 355967.5 6689019.8 15.9))
BATIMENT0000000302930336;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;6.4;12.2;;;Cadastre;;POLYGON Z ((355950.7 6689019.8 12.2, 355946.7 6689026.4 12.2, 355947.6 6689026.8 12.2, 355950.2 6689022.3 12.2, 355951.9 6689019.4 12.2, 355951.2 6689019.1 12.2, 355950.7 6689019.8 12.2))
BATIMENT0000000302923918;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;13.5;5.9;19.5;22.4;7.4;Cadastre;C 0.6;POLYGON Z ((355986.9 6689009.5 19.5, 355994 6689013.6 19.5, 355997.2 6689015.5 19.5, 355997.6 6689015.7 19.5, 356005.4 6689002.3 19.5, 356008.1 6689003.6 19.5, 356009.2 6689001.8 19.5, 356006.6 6689000.3 19.5, 356009.2 6688996 19.5, 356008.4 6688995.5 19.5, 356005.8 6688994 19.5, 355998.3 6688989.5 19.5, 355986.7 6689009.4 19.5, 355986.9 6689009.5 19.5))
BATIMENT0000000302923931;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:45:35;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;30;20;7.0;6.1;13.2;19.8;7.1;Cadastre;A 1.0;POLYGON Z ((356030.4 6689004.9 13.2, 356033.8 6689004.2 13.2, 356034.2 6689006 13.2, 356032 6689006.5 13.2, 356030.6 6689008.8 13.2, 356033.9 6689010.8 13.2, 356037.2 6689012.8 13.2, 356044.8 6689017.3 13.2, 356045.2 6689017.6 13.2, 356053 6689005 13.2, 356051.7 6688999.1 13.2, 356030.1 6689003.4 13.2, 356030.4 6689004.9 13.2))
BATIMENT0000000302930281;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;5.9;10.8;16.7;7.4;Cadastre;;POLYGON Z ((356001.8 6689018.2 10.8, 355997.6 6689015.7 10.8, 355997.2 6689015.5 10.8, 355994 6689013.6 10.8, 355991.9 6689017.3 10.8, 355992.8 6689017.9 10.8, 355991.8 6689019.6 10.8, 355998.6 6689023.6 10.8, 356001.8 6689018.2 10.8))
BATIMENT0000000302930282;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;10;20;5.2;6.0;11.2;12.9;6.4;Cadastre;A 1.0;POLYGON Z ((355980.1 6689019.5 11.2, 355988.8 6689024.6 11.2, 355991.8 6689019.6 11.2, 355992.8 6689017.9 11.2, 355991.9 6689017.3 11.2, 355984.1 6689012.8 11.2, 355980.1 6689019.5 11.2))
BATIMENT0000000302932557;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;13.3;6.1;19.5;22.6;7.3;Cadastre;C 0.2;POLYGON Z ((356044.8 6689017.3 19.5, 356037.2 6689012.8 19.5, 356033.9 6689010.8 19.5, 356031.3 6689015.1 19.5, 356028.6 6689013.4 19.5, 356027.5 6689015.2 19.5, 356030 6689017.3 19.5, 356022.1 6689030.3 19.5, 356033 6689036.8 19.5, 356044.8 6689017.3 19.5))
BATIMENT0000000302930285;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;6.0;10.8;13.5;6.3;Cadastre;;POLYGON Z ((355991 6689030.6 10.8, 355993.5 6689032.1 10.8, 355995.6 6689028.6 10.8, 355988.8 6689024.6 10.8, 355980.1 6689019.5 10.8, 355978.1 6689023 10.8, 355991 6689030.6 10.8))
BATIMENT0000000302930284;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;6.0;10.3;11.0;6.1;Cadastre;;POLYGON Z ((355998.5 6689030.4 10.3, 355999 6689029.6 10.3, 355996 6689027.9 10.3, 355996 6689027.8 10.3, 355995.6 6689028.6 10.3, 355998.5 6689030.4 10.3))
BATIMENT0000000302931816;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;5.9;14.0;16.9;6.5;Cadastre;;POLYGON Z ((356001.5 6689034.2 14, 356003.7 6689030.6 14, 356002.1 6689029.7 14, 356001.3 6689031 14, 356000 6689033.3 14, 356001.5 6689034.2 14))
BATIMENT0000000302930283;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;9.7;6.0;15.7;18.9;7.4;Cadastre;A 0.1;POLYGON Z ((355991.9 6689039.9 15.7, 355998.8 6689043.8 15.7, 356003.5 6689046.6 15.7, 356015.6 6689026.4 15.7, 356001.8 6689018.2 15.7, 355998.6 6689023.6 15.7, 355996 6689027.8 15.7, 355996 6689027.9 15.7, 355999 6689029.6 15.7, 356001.3 6689031 15.7, 356002.1 6689029.7 15.7, 356003.7 6689030.6 15.7, 356001.5 6689034.2 15.7, 356000 6689033.3 15.7, 355999.8 6689033.2 15.7, 355998.4 6689035.4 15.7, 355993.7 6689032.7 15.7, 355993.9 6689032.3 15.7, 355993.5 6689032.1 15.7, 355991 6689030.6 15.7, 355987.2 6689037 15.7, 355991.9 6689039.9 15.7))
BATIMENT0000000302932558;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.6;5.8;13.5;16.5;7.3;Cadastre;A 1.0;POLYGON Z ((356033.4 6689037.1 13.5, 356033 6689036.8 13.5, 356022.1 6689030.3 13.5, 356015.6 6689026.4 13.5, 356003.5 6689046.6 13.5, 356010.6 6689050.6 13.5, 356012.8 6689051.9 13.5, 356017.7 6689043.7 13.5, 356026.3 6689048.8 13.5, 356033.4 6689037.1 13.5))
BATIMENT0000000302930309;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.4;6.4;13.8;17.3;7.3;Cadastre;A 1.0;POLYGON Z ((355848.8 6689021.5 13.8, 355847.7 6689021 13.8, 355831.7 6689013.5 13.8, 355831.5 6689013.4 13.8, 355828.9 6689019 13.8, 355846.3 6689026.9 13.8, 355848.8 6689021.5 13.8))
BATIMENT0000000302930319;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;6.6;17.4;17.9;7.0;Cadastre;;POLYGON Z ((355870.9 6689024.2 17.4, 355873.3 6689025.5 17.4, 355874 6689024.3 17.4, 355871.6 6689023 17.4, 355870.9 6689024.2 17.4))
BATIMENT0000000302930320;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;6.4;17.5;18.5;6.9;Cadastre;;POLYGON Z ((355881.4 6689030.2 17.5, 355883.8 6689031.6 17.5, 355884.5 6689030.5 17.5, 355882.1 6689029.1 17.5, 355881.4 6689030.2 17.5))
BATIMENT0000000302930302;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.8;6.1;15.0;17.0;6.9;Cadastre;A 1.0;POLYGON Z ((355823.6 6689033 15, 355828.9 6689035.5 15, 355829.6 6689035.8 15, 355838.9 6689040.1 15, 355839 6689039.8 15, 355839.4 6689040 15, 355840.8 6689037.1 15, 355841.7 6689037.6 15, 355842.6 6689035.5 15, 355825.1 6689027.3 15, 355822.7 6689032.6 15, 355823.6 6689033 15))
BATIMENT0000000302930303;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.2;6.4;13.6;17.2;7.0;Cadastre;A 1.0;POLYGON Z ((355850.4 6689028.8 13.6, 355846.6 6689037.3 13.6, 355842.6 6689035.5 13.6, 355841.7 6689037.6 13.6, 355840.8 6689037.1 13.6, 355839.4 6689040 13.6, 355839 6689039.8 13.6, 355838.9 6689040.1 13.6, 355865.5 6689052.4 13.6, 355877 6689034.9 13.6, 355866.2 6689029.8 13.6, 355854.9 6689024.4 13.6, 355848.8 6689021.5 13.6, 355846.3 6689026.9 13.6, 355850.4 6689028.8 13.6))
BATIMENT0000000302930307;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.3;6.4;13.7;16.9;6.4;Cadastre;;POLYGON Z ((355827.3 6689040.9 13.7, 355829.6 6689035.8 13.7, 355828.9 6689035.5 13.7, 355823.6 6689033 13.7, 355821 6689038 13.7, 355827.3 6689040.9 13.7))
BATIMENT0000000302930308;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.1;6.1;12.2;16.9;7.2;Cadastre;A 1.0;POLYGON Z ((355865.5 6689052.4 12.2, 355838.9 6689040.1 12.2, 355829.6 6689035.8 12.2, 355827.3 6689040.9 12.2, 355837.4 6689045.4 12.2, 355836.9 6689046.5 12.2, 355861.9 6689057.7 12.2, 355865.5 6689052.4 12.2))
BATIMENT0000000302930321;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.8;6.6;18.4;20.0;7.8;Cadastre;;POLYGON Z ((355883.1 6689055.2 18.4, 355881.5 6689057.3 18.4, 355882.6 6689058.1 18.4, 355884.1 6689056 18.4, 355883.1 6689055.2 18.4))
BATIMENT0000000302930295;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.7;5.6;13.3;15.9;6.4;Cadastre;A 1.0;POLYGON Z ((355827.6 6689058.6 13.3, 355840.2 6689064.2 13.3, 355843.3 6689059.1 13.3, 355843.9 6689058 13.3, 355829.4 6689051.2 13.3, 355826.3 6689058 13.3, 355827.6 6689058.6 13.3))
BATIMENT0000000302930318;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;7.4;17.2;19.2;7.7;Cadastre;;POLYGON Z ((355897.4 6689057.5 17.2, 355895.7 6689056.3 17.2, 355892.7 6689060.2 17.2, 355894.4 6689061.5 17.2, 355897.4 6689057.5 17.2))
BATIMENT0000000302930332;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;12;20;9.3;6.2;15.5;19.0;6.3;Cadastre;A 1.0;POLYGON Z ((355963.6 6689026.5 15.5, 355956.2 6689022 15.5, 355955.9 6689021.8 15.5, 355954.5 6689024.2 15.5, 355954.1 6689023.8 15.5, 355952.9 6689025.7 15.5, 355953.4 6689026.1 15.5, 355951.6 6689029.2 15.5, 355953.5 6689030.4 15.5, 355959.4 6689033.8 15.5, 355963.6 6689026.5 15.5))
BATIMENT0000000302930289;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;8.5;5.9;14.5;16.4;6.4;Cadastre;A 1.0;POLYGON Z ((355991 6689030.6 14.5, 355978.1 6689023 14.5, 355974.3 6689029.4 14.5, 355987.2 6689037 14.5, 355991 6689030.6 14.5))
BATIMENT0000000302930333;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.5;5.9;17.5;19.6;6.1;Cadastre;;POLYGON Z ((355950.4 6689031.2 17.5, 355952.3 6689032.3 17.5, 355953.5 6689030.4 17.5, 355951.6 6689029.2 17.5, 355950.4 6689031.2 17.5))
BATIMENT0000000302930335;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;16;29;7.0;6.4;13.4;;;Cadastre;A 1.0;POLYGON Z ((355933.1 6689033.1 13.4, 355945.1 6689040.2 13.4, 355950.4 6689031.2 13.4, 355951.6 6689029.2 13.4, 355947.6 6689026.8 13.4, 355946.7 6689026.4 13.4, 355939.6 6689022.2 13.4, 355933.1 6689033.1 13.4))
BATIMENT0000000302930334;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.1;5.9;18.0;20.4;6.2;Cadastre;A 1.0;POLYGON Z ((355952.9 6689044.9 18, 355959.4 6689033.8 18, 355953.5 6689030.4 18, 355952.3 6689032.3 18, 355950.4 6689031.2 18, 355945.1 6689040.2 18, 355952.9 6689044.9 18))
BATIMENT0000000302930288;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;2.0;10;20;6.5;5.9;12.5;14.1;6.6;Cadastre;A 1.0;POLYGON Z ((355970 6689036.7 12.5, 355981.9 6689043.6 12.5, 355980.8 6689045.4 12.5, 355986.7 6689048.9 12.5, 355991.9 6689039.9 12.5, 355987.2 6689037 12.5, 355974.3 6689029.4 12.5, 355970 6689036.7 12.5))
BATIMENT0000000302930291;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.8;5.9;10.7;18.0;6.7;Cadastre;A 1.0;POLYGON Z ((355975.6 6689053.9 10.7, 355977.2 6689051.2 10.7, 355974.6 6689049.7 10.7, 355975.7 6689047.8 10.7, 355974.9 6689047.3 10.7, 355976.2 6689045 10.7, 355967.9 6689040.3 10.7, 355963 6689048.6 10.7, 355963.5 6689050.4 10.7, 355980.2 6689060.1 10.7, 355981.7 6689057.5 10.7, 355975.6 6689053.9 10.7))
BATIMENT0000000302931709;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;6.9;12.5;;;Cadastre;;POLYGON Z ((355931.5 6689106.4 12.5, 355934.3 6689101.3 12.5, 355937.2 6689095.6 12.5, 355949.8 6689072.2 12.5, 355954 6689064.6 12.5, 355955.6 6689061.5 12.5, 355929.5 6689046.1 12.5, 355931.4 6689043.1 12.5, 355915.5 6689033.8 12.5, 355908.2 6689046 12.5, 355911.5 6689047.9 12.5, 355916 6689050.7 12.5, 355941.7 6689065.7 12.5, 355924.1 6689098.8 12.5, 355922.7 6689101.3 12.5, 355931.5 6689106.4 12.5))
BATIMENT0000000302931708;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:22:11;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;6.8;10.8;12.7;7.0;Cadastre;;POLYGON Z ((355910.8 6689050.5 10.8, 355900.9 6689088.8 10.8, 355905.5 6689091.3 10.8, 355913.1 6689095.7 10.8, 355914.9 6689096.8 10.8, 355922.7 6689101.3 10.8, 355924.1 6689098.8 10.8, 355906.3 6689088.6 10.8, 355916 6689050.7 10.8, 355911.5 6689047.9 10.8, 355910.8 6689050.5 10.8))
BATIMENT0000000302931234;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.9;6.0;12.0;13.7;6.5;Cadastre;A 1.0;POLYGON Z ((355977.1 6689084.3 12, 355975.7 6689086.4 12, 355975.9 6689087.6 12, 355978.7 6689089.4 12, 355984.7 6689079.5 12, 355976.9 6689074.9 12, 355973.5 6689080.5 12, 355972.8 6689081.6 12, 355977.1 6689084.3 12))
BATIMENT0000000302932559;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.3;5.8;17.1;17.4;6.3;Cadastre;A 1.0;POLYGON Z ((356021.4 6689056.8 17.1, 356021.6 6689056.6 17.1, 356026.3 6689048.8 17.1, 356017.7 6689043.7 17.1, 356012.8 6689051.9 17.1, 356019 6689055.4 17.1, 356021.4 6689056.8 17.1))
BATIMENT0000000302932560;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;5.6;6.0;11.6;15.7;6.5;Cadastre;C 0.1;POLYGON Z ((356016.5 6689060.1 11.6, 356019 6689055.4 11.6, 356012.8 6689051.9 11.6, 356010.6 6689050.6 11.6, 356007.8 6689055.2 11.6, 356016.5 6689060.1 11.6))
BATIMENT0000000302930286;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;35;20;4.5;6.0;10.5;21.4;6.5;Cadastre;A 1.0;POLYGON Z ((355992.2 6689055.2 10.5, 355987.1 6689064 10.5, 355998.4 6689070.6 10.5, 356003 6689063.2 10.5, 356007.8 6689055.2 10.5, 356010.6 6689050.6 10.5, 356003.5 6689046.6 10.5, 355998.8 6689043.8 10.5, 355992.2 6689055.2 10.5))
BATIMENT0000000302930290;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;15.4;5.9;21.3;22.3;6.5;Cadastre;A 1.0;POLYGON Z ((355985.3 6689051.3 21.3, 355981.7 6689057.5 21.3, 355980.2 6689060.1 21.3, 355987.1 6689064 21.3, 355992.2 6689055.2 21.3, 355985.3 6689051.3 21.3))
BATIMENT0000000302932630;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;6.2;8.5;11.7;6.4;Cadastre;;POLYGON Z ((356042.6 6689064 8.5, 356043 6689064.3 8.5, 356044.1 6689068.8 8.5, 356044.6 6689068.6 8.5, 356045 6689068.4 8.5, 356045.3 6689068.2 8.5, 356045.7 6689068 8.5, 356045.8 6689067.9 8.5, 356046 6689067.7 8.5, 356046.3 6689067.4 8.5, 356046.7 6689066.9 8.5, 356046.9 6689066.6 8.5, 356047.2 6689066 8.5, 356047.3 6689065.8 8.5, 356047.3 6689065.6 8.5, 356047.4 6689065.4 8.5, 356047.4 6689065.2 8.5, 356047.5 6689065 8.5, 356047.5 6689064.8 8.5, 356047.6 6689064.4 8.5, 356047.6 6689064.2 8.5, 356047.5 6689063.7 8.5, 356047.5 6689063.3 8.5, 356047.4 6689062.9 8.5, 356047.3 6689062.7 8.5, 356046.3 6689063 8.5, 356042.6 6689064 8.5))
BATIMENT0000000302932631;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.3;6.0;17.4;21.0;6.9;Cadastre;A 1.0;POLYGON Z ((356046.3 6689063 17.4, 356049.8 6689046.5 17.4, 356047.2 6689044.8 17.4, 356047.5 6689044.4 17.4, 356041.9 6689041.1 17.4, 356037.1 6689049.2 17.4, 356026.9 6689066.1 17.4, 356017.5 6689081.7 17.4, 356033.1 6689090.8 17.4, 356037.6 6689083.7 17.4, 356045.4 6689081.7 17.4, 356046.6 6689079.7 17.4, 356045.1 6689073 17.4, 356044.6 6689070.9 17.4, 356044.1 6689068.8 17.4, 356043 6689064.3 17.4, 356042.6 6689064 17.4, 356046.3 6689063 17.4))
BATIMENT0000000302930287;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;20;7.7;6.0;13.7;17.3;6.5;Cadastre;C 0.7;POLYGON Z ((356011.5 6689078.2 13.7, 356018.7 6689066.2 13.7, 356016.1 6689064.8 13.7, 356014.7 6689067 13.7, 356013.1 6689066.1 13.7, 356011.7 6689068.4 13.7, 356003 6689063.2 13.7, 355998.4 6689070.6 13.7, 356011.5 6689078.2 13.7))
BATIMENT0000000302932633;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.1;10.5;13.7;6.4;Cadastre;;POLYGON Z ((356045.1 6689073 10.5, 356047.4 6689072.4 10.5, 356046.9 6689070.3 10.5, 356044.6 6689070.9 10.5, 356045.1 6689073 10.5))
BATIMENT0000000302931230;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;10;5.8;5.7;11.5;15.9;6.4;Cadastre;A 1.0;POLYGON Z ((355988.1 6689076.5 11.5, 355979.6 6689090.7 11.5, 355982.8 6689092.7 11.5, 355982.4 6689093.2 11.5, 355982 6689092.9 11.5, 355981.1 6689094.5 11.5, 355983 6689095.6 11.5, 355983.5 6689094.8 11.5, 355993 6689079.4 11.5, 355988.1 6689076.5 11.5))
BATIMENT0000000302931233;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;4.0;10;20;6.9;5.8;12.7;20.2;6.4;Cadastre;A 1.0;POLYGON Z ((355995.7 6689102.3 12.7, 356005.4 6689086.7 12.7, 355993 6689079.4 12.7, 355983.5 6689094.8 12.7, 355995.7 6689102.3 12.7), (355989.4 6689089.4 12.7, 355996.1 6689093.3 12.7, 355995.4 6689094.5 12.7, 355994.7 6689094.2 12.7, 355994.1 6689095.2 12.7, 355988.1 6689091.7 12.7, 355989.4 6689089.4 12.7))
BATIMENT0000000302930293;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;5.6;10.8;11.0;7.1;Cadastre;;POLYGON Z ((355848.1 6689067.6 10.8, 355853.7 6689070 10.8, 355856.8 6689065.3 10.8, 355843.3 6689059.1 10.8, 355840.2 6689064.2 10.8, 355848.1 6689067.6 10.8))
BATIMENT0000000302930315;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.1;7.3;18.4;19.2;7.8;Cadastre;;POLYGON Z ((355874.2 6689067.1 18.4, 355872.7 6689069.2 18.4, 355873.6 6689070 18.4, 355875.2 6689067.8 18.4, 355874.2 6689067.1 18.4))
BATIMENT0000000302930296;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;7.0;5.6;12.6;14.2;6.3;Cadastre;C 0.3;POLYGON Z ((355840.2 6689064.2 12.6, 355830 6689081.8 12.6, 355831.5 6689082.7 12.6, 355835.1 6689084.8 12.6, 355835.8 6689084.2 12.6, 355838 6689082 12.6, 355845.9 6689069 12.6, 355847 6689069.5 12.6, 355848.1 6689067.6 12.6, 355840.2 6689064.2 12.6))
BATIMENT0000000302930294;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;8.0;5.6;13.6;16.1;6.5;Cadastre;C 0.4;POLYGON Z ((355827.6 6689058.6 13.6, 355815.8 6689086.7 13.6, 355824.6 6689091.4 13.6, 355830 6689081.8 13.6, 355840.2 6689064.2 13.6, 355827.6 6689058.6 13.6))
BATIMENT0000000302930325;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.0;6.2;18.2;20.6;8.0;Cadastre;;POLYGON Z ((355878.3 6689079.6 18.2, 355879.9 6689080.8 18.2, 355883 6689076.6 18.2, 355881.5 6689075.5 18.2, 355878.3 6689079.6 18.2))
BATIMENT0000000302930297;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;50;20;6.5;6.8;13.3;15.8;7.7;Cadastre;C 0.3;POLYGON Z ((355853.3 6689084.3 13.3, 355862.1 6689073.4 13.3, 355854.4 6689070.3 13.3, 355841.9 6689085.6 13.3, 355843.9 6689087.1 13.3, 355848.3 6689090.5 13.3, 355853.3 6689084.3 13.3))
BATIMENT0000000302930312;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;136.0;4.0;00;00;12.6;5.7;18.3;21.6;8.0;Cadastre;A 1.0;POLYGON Z ((355869.3 6689020.6 18.3, 355868.5 6689022.9 18.3, 355870.9 6689024.2 18.3, 355871.6 6689023 18.3, 355874 6689024.3 18.3, 355873.3 6689025.5 18.3, 355873.2 6689025.6 18.3, 355881.3 6689030.3 18.3, 355881.4 6689030.2 18.3, 355882.1 6689029.1 18.3, 355884.5 6689030.5 18.3, 355883.8 6689031.6 18.3, 355895.4 6689038.4 18.3, 355889.7 6689048 18.3, 355888.6 6689047.3 18.3, 355883.1 6689055.2 18.3, 355884.1 6689056 18.3, 355882.6 6689058.1 18.3, 355881.5 6689057.3 18.3, 355874.2 6689067.1 18.3, 355875.2 6689067.8 18.3, 355873.6 6689070 18.3, 355872.7 6689069.2 18.3, 355868.8 6689074.6 18.3, 355869.1 6689074.9 18.3, 355867.6 6689077.1 18.3, 355868.4 6689077.7 18.3, 355859.8 6689089.2 18.3, 355859.6 6689089 18.3, 355858.4 6689090.6 18.3, 355864.6 6689095.3 18.3, 355865.5 6689094.2 18.3, 355868.4 6689096.4 18.3, 355867.5 6689097.5 18.3, 355871.7 6689100.5 18.3, 355870 6689102.8 18.3, 355869 6689102.1 18.3, 355858.4 6689116.7 18.3, 355859.3 6689117.3 18.3, 355857.7 6689119.4 18.3, 355840.7 6689106.4 18.3, 355837.6 6689104 18.3, 355835.4 6689106.7 18.3, 355828.8 6689114.9 18.3, 355831.4 6689116.9 18.3, 355832.1 6689115.9 18.3, 355832.7 6689116.3 18.3, 355834.7 6689117.8 18.3, 355834 6689118.8 18.3, 355843.3 6689125.7 18.3, 355844 6689124.9 18.3, 355846.5 6689126.8 18.3, 355845.8 6689127.6 18.3, 355850.6 6689131.2 18.3, 355853.8 6689130.7 18.3, 355859.5 6689135 18.3, 355860 6689138.3 18.3, 355865 6689142 18.3, 355865.6 6689141.1 18.3, 355867.8 6689142.8 18.3, 355867.2 6689143.6 18.3, 355876.8 6689150.9 18.3, 355877.5 6689150.1 18.3, 355879.9 6689151.9 18.3, 355879.2 6689152.7 18.3, 355884.9 6689156.9 18.3, 355890 6689146.7 18.3, 355891.1 6689144.6 18.3, 355868.2 6689127.3 18.3, 355869.7 6689125.3 18.3, 355870.4 6689125.7 18.3, 355881.3 6689111.1 18.3, 355880.4 6689110.5 18.3, 355882 6689108.3 18.3, 355887 6689112 18.3, 355887.8 6689110.9 18.3, 355889.9 6689112.4 18.3, 355889.1 6689113.6 18.3, 355894.2 6689117.3 18.3, 355901.2 6689107.8 18.3, 355899.3 6689106.3 18.3, 355900.4 6689104.7 18.3, 355892.4 6689098.8 18.3, 355890.7 6689101 18.3, 355888.6 6689099.5 18.3, 355878.9 6689092.2 18.3, 355878 6689086.5 18.3, 355877.9 6689084 18.3, 355879.9 6689080.8 18.3, 355878.3 6689079.6 18.3, 355881.5 6689075.5 18.3, 355883 6689076.6 18.3, 355894.4 6689061.5 18.3, 355892.7 6689060.2 18.3, 355895.7 6689056.3 18.3, 355897.4 6689057.5 18.3, 355899.9 6689054.2 18.3, 355897.9 6689052.9 18.3, 355902 6689046.4 18.3, 355903.9 6689043.4 18.3, 355904.9 6689044 18.3, 355912.1 6689031.8 18.3, 355912.1 6689031.7 18.3, 355896.3 6689022.6 18.3, 355891 6689019.5 18.3, 355873.1 6689008.9 18.3, 355869.3 6689020.6 18.3))
BATIMENT0000000302930304;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;14;90;3.5;5.9;9.4;12.9;6.3;Cadastre;C 0.6;POLYGON Z ((355821.8 6689096.4 9.4, 355823.2 6689097.5 9.4, 355829.4 6689090.3 9.4, 355835.1 6689084.8 9.4, 355831.5 6689082.7 9.4, 355830 6689081.8 9.4, 355824.6 6689091.4 9.4, 355822.8 6689094.3 9.4, 355821.8 6689096.4 9.4))
BATIMENT0000000302930305;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;10;6.1;7.0;13.1;14.6;7.7;Cadastre;C 0.5;POLYGON Z ((355836 6689096.7 13.1, 355840.6 6689100.3 13.1, 355848.4 6689090.6 13.1, 355848.3 6689090.5 13.1, 355843.9 6689087.1 13.1, 355836 6689096.7 13.1))
BATIMENT0000000302930326;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;7.5;17.2;17.9;7.9;Cadastre;;POLYGON Z ((355864.6 6689095.3 17.2, 355867.5 6689097.5 17.2, 355868.4 6689096.4 17.2, 355865.5 6689094.2 17.2, 355864.6 6689095.3 17.2))
BATIMENT0000000302931235;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;6.0;7.7;9.2;6.5;Cadastre;;POLYGON Z ((355975.1 6689087.5 7.7, 355970.8 6689084.9 7.7, 355970 6689086.3 7.7, 355969.4 6689087.4 7.7, 355973.7 6689090 7.7, 355975.1 6689087.5 7.7))
BATIMENT0000000302931232;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.3;5.9;11.2;13.5;6.9;Cadastre;A 1.0;POLYGON Z ((355955.9 6689070.4 11.2, 355960.2 6689072.9 11.2, 355955 6689081.8 11.2, 355953.6 6689081 11.2, 355948.4 6689089.9 11.2, 355951.2 6689091.5 11.2, 355948.9 6689095.4 11.2, 355944.7 6689092.9 11.2, 355935.1 6689109.2 11.2, 355934.9 6689109.4 11.2, 355946.1 6689115.9 11.2, 355946.2 6689115.9 11.2, 355955.8 6689099.7 11.2, 355960.3 6689102.3 11.2, 355961.2 6689100.8 11.2, 355962.3 6689099 11.2, 355966.4 6689092.4 11.2, 355969.4 6689087.4 11.2, 355970 6689086.3 11.2, 355967.7 6689084.9 11.2, 355971.1 6689079.2 11.2, 355971.5 6689079.5 11.2, 355974.9 6689073.7 11.2, 355959.4 6689064.6 11.2, 355955.9 6689070.4 11.2))
BATIMENT0000000302931236;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;90;3.3;5.9;9.2;9.4;6.5;Cadastre;A 0.5;POLYGON Z ((355969.8 6689094.4 9.2, 355971.3 6689092.2 9.2, 355972 6689092.5 9.2, 355973.7 6689090 9.2, 355969.4 6689087.4 9.2, 355966.4 6689092.4 9.2, 355969.8 6689094.4 9.2))
BATIMENT0000000302931231;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;5.9;7.7;7.7;6.1;Cadastre;;POLYGON Z ((355976 6689091.4 7.7, 355975.9 6689091.7 7.7, 355977 6689092.3 7.7, 355977.2 6689092.1 7.7, 355977.5 6689091.4 7.7, 355976.4 6689090.7 7.7, 355976 6689091.4 7.7))
BATIMENT0000000302931227;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.1;5.9;12.0;14.1;6.7;Cadastre;A 1.0;POLYGON Z ((355984 6689111.7 12, 355983.9 6689112 12, 355988.2 6689114.5 12, 355995.7 6689102.3 12, 355983.5 6689094.8 12, 355983 6689095.6 12, 355981.1 6689094.5 12, 355978.6 6689093 12, 355977.3 6689095 12, 355974 6689100.4 12, 355971.5 6689104.4 12, 355975.9 6689107 12, 355976 6689106.9 12, 355984 6689111.7 12), (355982.4 6689099.8 12, 355987.6 6689102.8 12, 355986.6 6689104.3 12, 355987.3 6689104.8 12, 355985.6 6689107.6 12, 355979.6 6689104 12, 355980.4 6689103 12, 355982.4 6689099.8 12))
BATIMENT0000000302931226;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;25;20;5.2;5.9;11.1;12.7;6.7;Cadastre;A 1.0;POLYGON Z ((355964.5 6689108.2 11.1, 355966.3 6689109.3 11.1, 355972.3 6689112.9 11.1, 355975.9 6689107 11.1, 355971.5 6689104.4 11.1, 355969.5 6689107.8 11.1, 355967.8 6689106.7 11.1, 355968 6689106.3 11.1, 355962.1 6689102.7 11.1, 355962.7 6689101.7 11.1, 355961.2 6689100.8 11.1, 355960.3 6689102.3 11.1, 355958.8 6689104.8 11.1, 355962.7 6689107.1 11.1, 355964.5 6689108.2 11.1))
BATIMENT0000000302931229;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;5.9;10.6;11.2;6.7;Cadastre;;POLYGON Z ((355958.5 6689114.1 10.6, 355962.7 6689107.1 10.6, 355958.8 6689104.8 10.6, 355957.1 6689107.8 10.6, 355954.6 6689111.8 10.6, 355958.5 6689114.1 10.6))
BATIMENT0000000302931224;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;6.9;5.9;12.8;17.0;6.6;Cadastre;A 1.0;POLYGON Z ((355985.7 6689118.4 12.8, 355983.6 6689117.2 12.8, 355983.3 6689117.8 12.8, 355981.1 6689116.6 12.8, 355983.9 6689112 12.8, 355984 6689111.7 12.8, 355976 6689106.9 12.8, 355975.9 6689107 12.8, 355972.3 6689112.9 12.8, 355984.6 6689120.3 12.8, 355985.7 6689118.4 12.8))
BATIMENT0000000302931223;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;6.2;14.4;20.6;6.7;Cadastre;;POLYGON Z ((355964.3 6689112.5 14.4, 355971.8 6689117 14.4, 355971.3 6689117.8 14.4, 355971.5 6689118.8 14.4, 355974.7 6689120.8 14.4, 355973.2 6689123 14.4, 355980.3 6689127.3 14.4, 355984.6 6689120.3 14.4, 355972.3 6689112.9 14.4, 355966.3 6689109.3 14.4, 355964.3 6689112.5 14.4), (355975.7 6689116.2 14.4, 355976.9 6689116.9 14.4, 355976.5 6689117.7 14.4, 355975.2 6689116.9 14.4, 355975.7 6689116.2 14.4))
BATIMENT0000000302931225;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;20;20;11.6;5.9;17.5;21.7;6.7;Cadastre;A 1.0;POLYGON Z ((355972 6689122.2 17.5, 355967.8 6689129 17.5, 355976.1 6689134 17.5, 355980.3 6689127.3 17.5, 355973.2 6689123 17.5, 355972 6689122.2 17.5))
BATIMENT0000000302930109;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;01;02;6.5;6.7;13.2;15.2;7.0;Cadastre;A 1.0;POLYGON Z ((355795.9 6688970.3 13.2, 355796.5 6688968.8 13.2, 355799.8 6688960.5 13.2, 355789.2 6688955.9 13.2, 355787.1 6688954.9 13.2, 355782.5 6688952.9 13.2, 355778.3 6688962.5 13.2, 355795.9 6688970.3 13.2))
BATIMENT0000000302930113;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;6.6;16.7;17.4;6.9;Cadastre;;POLYGON Z ((355807.1 6688969.5 16.7, 355808.7 6688964.4 16.7, 355807.7 6688964.1 16.7, 355806.2 6688969.2 16.7, 355807.1 6688969.5 16.7))
BATIMENT0000000302930135;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;42.0;3.0;12;20;12.4;6.4;18.8;20.9;6.9;Cadastre;A 1.0;POLYGON Z ((355742.6 6688967.1 18.8, 355744 6688967.7 18.8, 355757 6688973 18.8, 355767.3 6688977.3 18.8, 355783.2 6688984 18.8, 355783.1 6688984.2 18.8, 355783.4 6688984.3 18.8, 355785.6 6688978.1 18.8, 355787.9 6688971.8 18.8, 355748 6688955 18.8, 355743 6688966.1 18.8, 355742.6 6688967.1 18.8))
BATIMENT0000000302930111;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;6.7;13.0;14.6;6.9;Cadastre;;POLYGON Z ((355803.1 6688973.5 13, 355803.8 6688972.1 13, 355803.5 6688971.9 13, 355798.8 6688969.8 13, 355798.1 6688971.3 13, 355803.1 6688973.5 13))
BATIMENT0000000302930137;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;10.1;6.9;17.0;22.5;6.9;Cadastre;A 1.0;POLYGON Z ((355793.6 6688981.5 17, 355795.9 6688975.3 17, 355787.9 6688971.8 17, 355785.6 6688978.1 17, 355793.6 6688981.5 17))
BATIMENT0000000302930136;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;10.0;7.0;17.0;23.0;7.1;Cadastre;A 1.0;POLYGON Z ((355785.6 6688978.1 17, 355783.4 6688984.3 17, 355791.4 6688987.7 17, 355793.6 6688981.5 17, 355785.6 6688978.1 17))
BATIMENT0000000302930138;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;20;16.3;6.6;23.0;25.4;7.1;Cadastre;A 1.0;POLYGON Z ((355799.3 6688991.2 23, 355799.5 6688991.3 23, 355803.9 6688978.7 23, 355795.9 6688975.3 23, 355793.6 6688981.5 23, 355791.4 6688987.7 23, 355799.3 6688991.2 23))
BATIMENT0000000302930139;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;20;20;9.8;6.3;16.2;19.9;6.8;Cadastre;A 1.0;POLYGON Z ((355798 6688995.1 16.2, 355804 6688997.1 16.2, 355809.1 6688981 16.2, 355803.9 6688978.7 16.2, 355799.5 6688991.3 16.2, 355799.3 6688991.2 16.2, 355798 6688995.1 16.2))
BATIMENT0000000302930159;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.1;7.0;19.1;;;Cadastre;A 1.0;POLYGON Z ((355737 6688995.8 19.1, 355740.4 6688997.2 19.1, 355746.1 6688999.6 19.1, 355746.7 6688999.5 19.1, 355753.2 6688982.9 19.1, 355752.9 6688982.8 19.1, 355753 6688982.6 19.1, 355744 6688978.9 19.1, 355737 6688995.8 19.1))
BATIMENT0000000302930160;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;;;8.9;7.0;15.9;;;Cadastre;A 1.0;POLYGON Z ((355773 6688989.6 15.9, 355773.3 6688988.8 15.9, 355757.5 6688982 15.9, 355750.4 6688998.8 15.9, 355753 6689002.5 15.9, 355757.4 6689004.4 15.9, 355756.6 6689006.2 15.9, 355764.7 6689009.4 15.9, 355768 6689001.4 15.9, 355773 6688989.6 15.9))
BATIMENT0000000302930122;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;5.0;14;20;11.0;6.7;17.7;25.0;7.4;Cadastre;A 1.0;POLYGON Z ((355660.8 6689004.5 17.7, 355665.3 6689006.7 17.7, 355665.5 6689006.5 17.7, 355667.1 6689007.2 17.7, 355677.2 6689011.8 17.7, 355677 6689012.2 17.7, 355680.2 6689013.6 17.7, 355680.3 6689013.3 17.7, 355682.2 6689009.2 17.7, 355683.4 6689006.9 17.7, 355679 6689004.8 17.7, 355679 6689004.6 17.7, 355668.6 6688999.7 17.7, 355668.2 6689000.5 17.7, 355661.9 6688998.2 17.7, 355661.8 6688998.2 17.7, 355661.8 6688998.3 17.7, 355659.1 6688997.1 17.7, 355666.7 6688981.6 17.7, 355653.3 6688975.1 17.7, 355643.3 6688996.4 17.7, 355651 6689000 17.7, 355660.8 6689004.5 17.7))
BATIMENT0000000302930126;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;23;90;6.4;5.8;12.2;14.7;6.8;Cadastre;A 1.0;POLYGON Z ((355719.9 6688993.1 12.2, 355716.3 6688991.6 12.2, 355713.4 6688998.5 12.2, 355719.6 6689001 12.2, 355722.2 6688994.1 12.2, 355719.9 6688993.1 12.2))
BATIMENT0000000302930124;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.8;5.4;12.2;14.6;7.0;Cadastre;A 1.0;POLYGON Z ((355733.4 6688999.4 12.2, 355722.2 6688994.1 12.2, 355719.6 6689001 12.2, 355730.5 6689005.4 12.2, 355733.4 6688999.4 12.2))
BATIMENT0000000302930123;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;3.3;6.1;9.5;15.1;7.2;Cadastre;C 0.5;POLYGON Z ((355684.9 6689010.4 9.5, 355690.5 6689013 9.5, 355690.8 6689012.4 9.5, 355692.7 6689013.2 9.5, 355692.4 6689013.9 9.5, 355720.1 6689026.4 9.5, 355721.5 6689023.1 9.5, 355735.3 6689029.3 9.5, 355737 6689024.7 9.5, 355742.3 6689010.8 9.5, 355736.1 6689008 9.5, 355730.5 6689005.4 9.5, 355719.6 6689001 9.5, 355713.4 6688998.5 9.5, 355707.3 6688996 9.5, 355686.4 6688987.4 9.5, 355679 6689004.6 9.5, 355679 6689004.8 9.5, 355683.4 6689006.9 9.5, 355682.2 6689009.2 9.5, 355684.9 6689010.4 9.5))
BATIMENT0000000302930273;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.4;6.8;15.2;16.7;7.4;Cadastre;C 0.2;POLYGON Z ((355680.3 6689013.3 15.2, 355681.6 6689013.9 15.2, 355683.1 6689014.5 15.2, 355684.9 6689010.4 15.2, 355682.2 6689009.2 15.2, 355680.3 6689013.3 15.2))
BATIMENT0000000302930270;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;9.5;6.5;16.0;25.2;7.4;Cadastre;A 1.0;POLYGON Z ((355678.1 6689028.5 16, 355676.8 6689033.6 16, 355677.8 6689033.9 16, 355683.6 6689035.7 16, 355700.8 6689040.4 16, 355702.2 6689035.6 16, 355682.7 6689030.1 16, 355684.8 6689023.8 16, 355703.2 6689032.3 16, 355705.4 6689024.5 16, 355692.4 6689018.6 16, 355684.6 6689015.1 16, 355681.6 6689021.7 16, 355678.1 6689020.1 16, 355674.6 6689028 16, 355678.1 6689028.5 16))
BATIMENT0000000302930272;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;8.5;6.6;15.1;16.3;6.9;Cadastre;A 1.0;POLYGON Z ((355676.8 6689033.6 15.1, 355678.1 6689028.5 15.1, 355674.6 6689028 15.1, 355672.5 6689032.5 15.1, 355676.8 6689033.6 15.1))
BATIMENT0000000302930271;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.8;6.5;16.4;18.2;7.1;Cadastre;A 1.0;POLYGON Z ((355714.1 6689044.1 16.4, 355716.9 6689029.7 16.4, 355705.4 6689024.5 16.4, 355703.2 6689032.3 16.4, 355702.2 6689035.6 16.4, 355700.8 6689040.4 16.4, 355714.1 6689044.1 16.4))
BATIMENT0000000302930275;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.6;5.6;18.2;21.5;7.1;Cadastre;A 1.0;POLYGON Z ((355728.7 6689048.2 18.2, 355732.5 6689036.8 18.2, 355716.9 6689029.7 18.2, 355714.1 6689044.1 18.2, 355728.7 6689048.2 18.2))
BATIMENT0000000302930276;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;00;00;12.2;5.8;18.0;20.0;6.7;Cadastre;A 1.0;POLYGON Z ((355679.2 6689053.1 18, 355682.7 6689040 18, 355680.1 6689039.3 18, 355676.5 6689038.4 18, 355675.8 6689038.2 18, 355671.9 6689050.1 18, 355679.2 6689053.1 18))
BATIMENT0000000302930161;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.1;7.0;12.1;;;Cadastre;A 1.0;POLYGON Z ((355780 6688992.6 12.1, 355773 6688989.6 12.1, 355768 6689001.4 12.1, 355776 6689005.2 12.1, 355780 6688992.6 12.1))
BATIMENT0000000302930162;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2023-01-31 17:48:51;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;10;20;9.2;6.2;15.5;22.1;6.8;Cadastre;A 1.0;POLYGON Z ((355798.4 6689016.4 15.5, 355803.6 6689000.2 15.5, 355803.1 6689000 15.5, 355790.7 6688996.1 15.5, 355788 6689004.4 15.5, 355785.1 6689003.5 15.5, 355788.1 6688994.3 15.5, 355782.2 6688991.5 15.5, 355777.6 6689006 15.5, 355783.3 6689008.7 15.5, 355797.9 6689015.8 15.5, 355797.8 6689016.2 15.5, 355798.4 6689016.4 15.5))
BATIMENT0000000327821804;Indifférenciée;Annexe;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;00;00;8.7;6.7;;15.6;6.8;Imagerie aérienne;C 0.1;POLYGON Z ((355781 6689016.2 15.4, 355783.3 6689008.7 15.4, 355777.6 6689006 15.4, 355776 6689005.2 15.4, 355768 6689001.4 15.4, 355764.7 6689009.4 15.4, 355764.2 6689010.8 15.4, 355781 6689016.2 15.4))
BATIMENT0000000302930301;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;10;20;16.6;6.1;22.7;26.2;7.0;Cadastre;C 0.9;POLYGON Z ((355812.3 6689004.4 22.7, 355805.9 6689024.6 22.7, 355805.8 6689024.8 22.7, 355822.7 6689032.6 22.7, 355825.1 6689027.3 22.7, 355824.9 6689027.3 22.7, 355824.8 6689027.5 22.7, 355820.1 6689025.5 22.7, 355818.8 6689028.4 22.7, 355817.7 6689028.1 22.7, 355823.5 6689009.7 22.7, 355812.3 6689004.4 22.7))
BATIMENT0000000327821893;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2010-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;37.0;5.0;00;00;14.0;6.4;;21.1;6.6;Imagerie aérienne;C 0.7;POLYGON Z ((355797.8 6689016.2 20.4, 355797.9 6689015.8 20.4, 355783.3 6689008.7 20.4, 355781 6689016.2 20.4, 355772.2 6689045.7 20.4, 355778.2 6689048.2 20.4, 355787.1 6689051.6 20.4, 355797.8 6689016.2 20.4))
BATIMENT0000000327821802;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;18.0;4.0;00;00;10.4;5.8;;20.6;6.7;Imagerie aérienne;A 1.0;POLYGON Z ((355760.5 6689050.3 16.2, 355763.8 6689042.6 16.2, 355757.4 6689039.8 16.2, 355761.3 6689025.2 16.2, 355756.8 6689023.8 16.2, 355756.3 6689025.4 16.2, 355749.1 6689023.1 16.2, 355740.5 6689051.4 16.2, 355749.4 6689054.2 16.2, 355750.3 6689052.1 16.2, 355758.6 6689054.7 16.2, 355760.5 6689050.3 16.2))
BATIMENT0000000302930299;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.3;6.5;18.8;23.6;6.5;Cadastre;A 1.0;POLYGON Z ((355829.4 6689051.2 18.8, 355819.4 6689046.5 18.8, 355817.8 6689045.8 18.8, 355815.5 6689050.7 18.8, 355813.3 6689049.7 18.8, 355815.7 6689044.6 18.8, 355817.8 6689040 18.8, 355815.4 6689038.9 18.8, 355816.7 6689036.1 18.8, 355821 6689038 18.8, 355823.6 6689033 18.8, 355822.7 6689032.6 18.8, 355805.8 6689024.8 18.8, 355805.9 6689024.6 18.8, 355805.4 6689024.4 18.8, 355798.9 6689045.7 18.8, 355799.2 6689045.8 18.8, 355799.2 6689045.7 18.8, 355812 6689051.5 18.8, 355826.3 6689058 18.8, 355829.4 6689051.2 18.8))
BATIMENT0000000302930340;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;7.0;13.2;;;Cadastre;;POLYGON Z ((355775.4 6689047.9 13.2, 355763.8 6689042.6 13.2, 355760.5 6689050.3 13.2, 355775.6 6689056.8 13.2, 355777.9 6689049 13.2, 355775.4 6689047.9 13.2))
BATIMENT0000000302930342;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;20;20;10.3;5.9;16.2;19.7;6.5;Cadastre;C 0.1;POLYGON Z ((355778.2 6689048.2 16.2, 355777.9 6689049 16.2, 355775.6 6689056.8 16.2, 355784.5 6689060.2 16.2, 355785.3 6689057.4 16.2, 355787.1 6689051.6 16.2, 355778.2 6689048.2 16.2))
BATIMENT0000000302930341;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;7.8;7.0;14.8;;;Cadastre;C 0.5;POLYGON Z ((355758.6 6689054.7 14.8, 355757.5 6689057.3 14.8, 355764.7 6689060 14.8, 355782.1 6689068 14.8, 355784.5 6689060.2 14.8, 355775.6 6689056.8 14.8, 355760.5 6689050.3 14.8, 355758.6 6689054.7 14.8))
BATIMENT0000000302930274;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;;;9.4;6.3;15.7;24.5;7.4;Cadastre;A 1.0;POLYGON Z ((355666.4 6689058.7 15.7, 355666.2 6689058.6 15.7, 355667.5 6689055.5 15.7, 355669.7 6689056.3 15.7, 355671.9 6689050.1 15.7, 355675.8 6689038.2 15.7, 355676.5 6689038.4 15.7, 355677.8 6689033.9 15.7, 355676.8 6689033.6 15.7, 355672.5 6689032.5 15.7, 355669.1 6689031.6 15.7, 355658.6 6689045.6 15.7, 355651.4 6689043.4 15.7, 355650 6689048 15.7, 355651.7 6689048.4 15.7, 355656.7 6689049.8 15.7, 355655.1 6689054.8 15.7, 355652.8 6689054 15.7, 355649.4 6689066.2 15.7, 355662.2 6689070.7 15.7, 355666.4 6689058.7 15.7))
BATIMENT0000000302930278;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.3;6.5;11.9;16.5;7.1;Cadastre;A 1.0;POLYGON Z ((355709.5 6689057.1 11.9, 355701.8 6689054.9 11.9, 355703.2 6689049.6 11.9, 355700.2 6689044.7 11.9, 355699.1 6689044.4 11.9, 355693.8 6689063.7 11.9, 355707.5 6689066.7 11.9, 355709.5 6689057.1 11.9))
BATIMENT0000000302931536;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1856-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;10;20;8.4;7.0;15.4;15.7;7.1;Cadastre;A 1.0;POLYGON Z ((355718.8 6689060.7 15.4, 355719.4 6689058.3 15.4, 355721.1 6689058.7 15.4, 355721.6 6689056 15.4, 355724.3 6689056.9 15.4, 355726.9 6689051.3 15.4, 355716.9 6689048.4 15.4, 355713.7 6689050.4 15.4, 355711.9 6689059.1 15.4, 355711.4 6689061.5 15.4, 355717.7 6689063.7 15.4, 355718.8 6689060.7 15.4))
BATIMENT0000000302931535;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1600-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;24;10;13.6;6.4;20.0;21.7;7.1;Cadastre;C 0.6;POLYGON Z ((355742.5 6689055.8 20, 355726.9 6689051.3 20, 355724.3 6689056.9 20, 355722.3 6689061.3 20, 355738.6 6689067.1 20, 355738.9 6689067.1 20, 355740.4 6689062.2 20, 355740.2 6689062.1 20, 355742.1 6689055.9 20, 355742.4 6689056 20, 355742.5 6689055.8 20))
BATIMENT0000000302930277;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;5.0;12;20;12.3;6.4;18.7;25.6;6.9;Cadastre;A 1.0;POLYGON Z ((355673.4 6689074.5 18.7, 355686.9 6689079 18.7, 355689.9 6689071.6 18.7, 355691.5 6689072.1 18.7, 355693.8 6689063.7 18.7, 355699.1 6689044.4 18.7, 355682.7 6689040 18.7, 355679.2 6689053.1 18.7, 355673.4 6689074.5 18.7), (355686.4 6689047.7 18.7, 355689.3 6689048.5 18.7, 355689.3 6689048.6 18.7, 355689.4 6689048.8 18.7, 355689.5 6689049 18.7, 355689.6 6689049.1 18.7, 355689.7 6689049.2 18.7, 355689.9 6689049.3 18.7, 355690 6689049.3 18.7, 355691.1 6689049.6 18.7, 355687.3 6689063.6 18.7, 355685.7 6689064.8 18.7, 355682.8 6689063.7 18.7, 355682.5 6689062 18.7, 355686.4 6689047.7 18.7))
BATIMENT0000000302930280;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;00;00;13.3;6.4;19.7;24.6;6.9;Cadastre;A 1.0;POLYGON Z ((355673.4 6689074.5 19.7, 355679.2 6689053.1 19.7, 355671.9 6689050.1 19.7, 355669.7 6689056.3 19.7, 355667.5 6689055.5 19.7, 355666.2 6689058.6 19.7, 355666.4 6689058.7 19.7, 355662.2 6689070.7 19.7, 355673.4 6689074.5 19.7))
BATIMENT0000000302931538;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;11.9;7.0;18.9;20.6;7.1;Cadastre;A 1.0;POLYGON Z ((355711.4 6689061.5 18.9, 355706.7 6689082.3 18.9, 355712.2 6689083.5 18.9, 355717.1 6689072.8 18.9, 355720.7 6689064.7 18.9, 355719.3 6689064.2 18.9, 355717.7 6689063.7 18.9, 355711.4 6689061.5 18.9))
BATIMENT0000000302930279;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;12;10;16.6;6.1;22.7;25.9;7.0;Cadastre;A 1.0;POLYGON Z ((355691.7 6689080.5 22.7, 355704.3 6689082.9 22.7, 355707.5 6689066.7 22.7, 355693.8 6689063.7 22.7, 355691.5 6689072.1 22.7, 355689.9 6689071.6 22.7, 355686.9 6689079 22.7, 355691.7 6689080.5 22.7))
BATIMENT0000000302931537;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;3.0;00;00;9.0;7.0;16.0;;;Cadastre;A 1.0;POLYGON Z ((355746.7 6689063.8 16, 355740.4 6689062.2 16, 355738.9 6689067.1 16, 355738.6 6689067.1 16, 355738.3 6689068.2 16, 355738.5 6689068.3 16, 355736.8 6689074.1 16, 355734.6 6689073.4 16, 355733.7 6689076.3 16, 355733.3 6689077.9 16, 355735.3 6689078.5 16, 355734.8 6689080 16, 355734.7 6689080 16, 355734.3 6689081.3 16, 355732.6 6689087.8 16, 355738.4 6689089.1 16, 355746.7 6689063.8 16))
BATIMENT0000000302931541;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;9.7;7.0;16.7;;;Cadastre;C 0.5;POLYGON Z ((355727.7 6689086.7 16.7, 355730 6689079 16.7, 355727.7 6689077.1 16.7, 355724.1 6689076.4 16.7, 355724.5 6689075.5 16.7, 355717.1 6689072.8 16.7, 355712.2 6689083.5 16.7, 355727.7 6689086.7 16.7))
BATIMENT0000000302930146;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;8.5;14.7;18.2;9.1;Cadastre;;POLYGON Z ((355597.4 6688998.8 14.7, 355599.6 6688994.1 14.7, 355593.7 6688995.5 14.7, 355594.7 6688997.5 14.7, 355597.4 6688998.8 14.7))
BATIMENT0000000302930145;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.7;8.0;18.7;19.9;9.1;Cadastre;;POLYGON Z ((355591 6688997.6 18.7, 355588.3 6688996.2 18.7, 355584.3 6688994.3 18.7, 355580.5 6689002.4 18.7, 355587.2 6689005.7 18.7, 355591 6688997.6 18.7))
BATIMENT0000000302930143;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:05:58;2018-09-18 13:45:21;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.0;8.0;18.0;19.2;9.2;Cadastre;;POLYGON Z ((355591.4 6688990.1 18, 355599.6 6688994.1 18, 355597.4 6688998.8 18, 355594.7 6688997.5 18, 355593.8 6688999.3 18, 355591.5 6688998.3 18, 355591.8 6688998 18, 355591 6688997.6 18, 355587.2 6689005.7 18, 355588 6689006.1 18, 355588.3 6689005.5 18, 355589.7 6689006.3 18, 355593.2 6689008 18, 355589.1 6689016.6 18, 355610.4 6689026.6 18, 355629.1 6688987.1 18, 355599.1 6688973.4 18, 355591.4 6688990.1 18))
BATIMENT0000000302930292;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.3;8.0;19.3;19.7;8.9;Cadastre;;POLYGON Z ((355579.6 6689004.2 19.3, 355588.6 6689008.6 19.3, 355589.7 6689006.3 19.3, 355588.3 6689005.5 19.3, 355588 6689006.1 19.3, 355587.2 6689005.7 19.3, 355580.5 6689002.4 19.3, 355579.6 6689004.2 19.3))
BATIMENT0000000302930121;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:05:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;4.0;00;00;13.5;7.1;20.6;25.5;7.4;Cadastre;A 1.0;POLYGON Z ((355630.6 6689023.6 20.6, 355641 6689027.1 20.6, 355657.9 6689033.9 20.6, 355667.1 6689007.2 20.6, 355665.5 6689006.5 20.6, 355665.3 6689006.7 20.6, 355660.8 6689004.5 20.6, 355660.2 6689006 20.6, 355661.4 6689006.5 20.6, 355655.2 6689024.7 20.6, 355643.5 6689019.9 20.6, 355650.1 6689005.7 20.6, 355648.7 6689005.1 20.6, 355651 6689000 20.6, 355643.3 6688996.4 20.6, 355630.6 6689023.6 20.6))
BATIMENT0000000302930268;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;;;7.9;6.6;14.5;28.2;8.2;Cadastre;A 1.0;POLYGON Z ((355617.4 6689051.7 14.5, 355619.1 6689055.3 14.5, 355633.8 6689060.8 14.5, 355638.3 6689045.9 14.5, 355640.7 6689040 14.5, 355651.4 6689043.4 14.5, 355658.6 6689045.6 14.5, 355669.1 6689031.6 14.5, 355672.5 6689032.5 14.5, 355674.6 6689028 14.5, 355678.1 6689020.1 14.5, 355674.5 6689018.5 14.5, 355676.6 6689013.3 14.5, 355677 6689012.2 14.5, 355677.2 6689011.8 14.5, 355667.1 6689007.2 14.5, 355657.9 6689033.9 14.5, 355641 6689027.1 14.5, 355630.6 6689023.6 14.5, 355617.4 6689051.7 14.5))
BATIMENT0000000302930269;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;00;00;13.7;6.5;20.2;23.2;7.6;Cadastre;A 1.0;POLYGON Z ((355649.4 6689066.2 20.2, 355652.8 6689054 20.2, 355655.1 6689054.8 20.2, 355656.7 6689049.8 20.2, 355651.7 6689048.4 20.2, 355650.3 6689052.9 20.2, 355645.2 6689051.1 20.2, 355643.3 6689051.2 20.2, 355644.7 6689046.2 20.2, 355646.4 6689046.6 20.2, 355646.3 6689047 20.2, 355650 6689048 20.2, 355651.4 6689043.4 20.2, 355640.7 6689040 20.2, 355638.3 6689045.9 20.2, 355633.8 6689060.8 20.2, 355649.4 6689066.2 20.2))
BATIMENT0000000302930954;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.8;8.0;12.8;16.2;8.4;Cadastre;C 0.2;POLYGON Z ((355612.5 6689102.5 12.8, 355617.7 6689093.7 12.8, 355600.7 6689084.7 12.8, 355595.7 6689094.2 12.8, 355612.5 6689102.5 12.8))
BATIMENT0000000302930908;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;14.7;7.7;22.4;26.4;7.7;Cadastre;A 1.0;POLYGON Z ((355598.5 6689181.7 22.4, 355586 6689168.3 22.4, 355569.5 6689159.9 22.4, 355568.7 6689160.2 22.4, 355563.1 6689172.3 22.4, 355580.5 6689178.5 22.4, 355580.3 6689179.1 22.4, 355585.6 6689181.1 22.4, 355596.9 6689185 22.4, 355598.5 6689181.7 22.4))
BATIMENT0000000302930907;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.0;7.4;20.5;21.5;7.7;Cadastre;;POLYGON Z ((355572.3 6689188.5 20.5, 355573.2 6689186.2 20.5, 355572 6689185.8 20.5, 355571.2 6689188.1 20.5, 355572.3 6689188.5 20.5))
BATIMENT0000000302931544;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;5.5;9.9;12.2;6.4;Cadastre;;POLYGON Z ((355763.9 6689063 9.9, 355762 6689069.2 9.9, 355767.8 6689071.2 9.9, 355770 6689066 9.9, 355763.9 6689063 9.9))
BATIMENT0000000327821901;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:45:28;2018-09-18 13:45:40;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.3;5.9;;19.0;6.6;Imagerie aérienne;;POLYGON Z ((355814.1 6689063.9 10.2, 355814.2 6689062.5 10.2, 355814.2 6689062.2 10.2, 355814.1 6689061.2 10.2, 355813.5 6689059.9 10.2, 355811.9 6689059 10.2, 355809.9 6689059 10.2, 355804.9 6689076.5 10.2, 355813.4 6689065.8 10.2, 355814.1 6689063.9 10.2))
BATIMENT0000000327821897;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;27.0;6.0;00;00;14.9;6.6;;27.0;6.9;Imagerie aérienne;C 0.7;POLYGON Z ((355787.6 6689082.2 21.5, 355782.6 6689099.8 21.5, 355806.4 6689105.1 21.5, 355813.6 6689091.4 21.5, 355793.2 6689087.1 21.5, 355794 6689084.3 21.5, 355799.8 6689086 21.5, 355803 6689083.2 21.5, 355804.9 6689076.5 21.5, 355809.9 6689059 21.5, 355812 6689051.5 21.5, 355799.2 6689045.7 21.5, 355799.2 6689045.8 21.5, 355798.9 6689045.7 21.5, 355787.6 6689082.2 21.5))
BATIMENT0000000302931539;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;3.0;16;20;10.4;7.0;17.4;19.3;7.0;Cadastre;A 1.0;POLYGON Z ((355749.9 6689091.6 17.4, 355753.4 6689081.2 17.4, 355754.3 6689078.2 17.4, 355757.8 6689067.7 17.4, 355746.7 6689063.8 17.4, 355738.4 6689089.1 17.4, 355749.9 6689091.6 17.4), (355746.6 6689075.4 17.4, 355750.7 6689076.7 17.4, 355749.7 6689079.7 17.4, 355745.7 6689078.4 17.4, 355746.6 6689075.4 17.4))
BATIMENT0000000302931542;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;12;20;10.4;7.0;17.4;20.7;7.0;Cadastre;A 1.0;POLYGON Z ((355754.9 6689092.7 17.4, 355756.2 6689086.7 17.4, 355758.7 6689080.6 17.4, 355760.3 6689073.9 17.4, 355762 6689069.2 17.4, 355758.8 6689068.1 17.4, 355759.3 6689066.7 17.4, 355758.3 6689066.2 17.4, 355757.8 6689067.7 17.4, 355754.3 6689078.2 17.4, 355756.4 6689078.8 17.4, 355755.4 6689081.9 17.4, 355753.4 6689081.2 17.4, 355749.9 6689091.6 17.4, 355754.9 6689092.7 17.4))
BATIMENT0000000302931543;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;12;20;8.0;5.4;13.5;21.0;7.3;Cadastre;A 1.0;POLYGON Z ((355767.8 6689071.2 13.5, 355762 6689069.2 13.5, 355760.3 6689073.9 13.5, 355758.7 6689080.6 13.5, 355756.2 6689086.7 13.5, 355754.9 6689092.7 13.5, 355772.9 6689096.7 13.5, 355778 6689080.2 13.5, 355778.6 6689074.7 13.5, 355775.4 6689073.6 13.5, 355775.7 6689069.2 13.5, 355773.5 6689068.1 13.5, 355773.6 6689067.9 13.5, 355770 6689066 13.5, 355767.8 6689071.2 13.5), (355763.1 6689081.2 13.5, 355769.1 6689082.8 13.5, 355768.8 6689089.3 13.5, 355761.8 6689087.7 13.5, 355763.1 6689081.2 13.5))
BATIMENT0000000327821883;Indifférenciée;Annexe;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2012-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;0.0;00;00;15.7;6.3;;27.9;6.7;Imagerie aérienne;C 0.1;POLYGON Z ((355815.4 6689107 22, 355816 6689105.9 22, 355816.2 6689106.1 22, 355821.8 6689096.4 22, 355813.6 6689091.4 22, 355806.4 6689105.1 22, 355815.4 6689107 22))
BATIMENT0000000302931114;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;10;7.8;7.0;14.8;17.2;7.0;Cadastre;A 1.0;POLYGON Z ((355785.2 6689110.7 14.8, 355785.2 6689110.5 14.8, 355780 6689109 14.8, 355776.8 6689119.2 14.8, 355783.2 6689121.1 14.8, 355786.1 6689112 14.8, 355785.5 6689110.8 14.8, 355785.2 6689110.7 14.8))
BATIMENT0000000302931115;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.5;7.0;11.5;;;Cadastre;A 1.0;POLYGON Z ((355788.2 6689122.6 11.5, 355791.7 6689117.2 11.5, 355792.8 6689117.5 11.5, 355795.6 6689113 11.5, 355785.5 6689110.8 11.5, 355786.1 6689112 11.5, 355783.2 6689121.1 11.5, 355787 6689122.2 11.5, 355788.2 6689122.6 11.5))
BATIMENT0000000302931119;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.5;7.0;10.5;;;Cadastre;C 0.3;POLYGON Z ((355802.7 6689114.5 10.5, 355797.1 6689122.9 10.5, 355799.1 6689124.1 10.5, 355797.5 6689126.5 10.5, 355802.6 6689130 10.5, 355804.3 6689127.5 10.5, 355801.4 6689125.7 10.5, 355808 6689115.7 10.5, 355802.7 6689114.5 10.5))
BATIMENT0000000302931540;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.3;7.0;16.3;;;Cadastre;;POLYGON Z ((355732.6 6689087.8 16.3, 355734.3 6689081.3 16.3, 355733.2 6689081 16.3, 355733.6 6689079.7 16.3, 355732.1 6689079.2 16.3, 355730 6689079 16.3, 355727.7 6689086.7 16.3, 355732.6 6689087.8 16.3))
BATIMENT0000000302930354;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;;;7.2;6.2;13.5;18.0;6.9;Cadastre;A 1.0;POLYGON Z ((355718.8 6689097.2 13.5, 355717.4 6689096.6 13.5, 355715.7 6689100.5 13.5, 355717.1 6689101.1 13.5, 355716.7 6689102 13.5, 355749.9 6689124.5 13.5, 355754.1 6689119.2 13.5, 355757.2 6689111.6 13.5, 355758.5 6689104.9 13.5, 355719.2 6689096.2 13.5, 355718.8 6689097.2 13.5))
BATIMENT0000000302931647;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;126.0;7.0;10;10;20.0;7.1;27.1;29.6;7.6;Cadastre;B 0.1;POLYGON Z ((355670.1 6689322.1 27.1, 355669.2 6689322.7 27.1, 355667.8 6689328.2 27.1, 355665.4 6689340.3 27.1, 355661.6 6689347 27.1, 355662.2 6689347.2 27.1, 355669.5 6689349.3 27.1, 355672.5 6689337.7 27.1, 355678.1 6689339.1 27.1, 355679.4 6689336.1 27.1, 355683.7 6689325.6 27.1, 355670.1 6689322.1 27.1))
BATIMENT0000000302931648;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.9;8.3;24.2;;;Cadastre;;POLYGON Z ((355681.7 6689340.1 24.2, 355682.8 6689337.3 24.2, 355679.4 6689336.1 24.2, 355678.1 6689339.1 24.2, 355681.7 6689340.1 24.2))
BATIMENT0000000302931652;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;17.9;7.3;25.3;29.3;7.8;Cadastre;A 1.0;POLYGON Z ((355711.5 6689332.9 25.3, 355707.9 6689347.5 25.3, 355709.2 6689348 25.3, 355710.1 6689344.1 25.3, 355714.3 6689345.1 25.3, 355714.1 6689345.7 25.3, 355718.8 6689347.9 25.3, 355718.9 6689347.5 25.3, 355720.4 6689335.1 25.3, 355711.5 6689332.9 25.3))
BATIMENT0000000302931649;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;10;20;14.8;8.3;23.1;;;Cadastre;A 1.0;POLYGON Z ((355682.8 6689337.3 23.1, 355681.7 6689340.1 23.1, 355678.2 6689348.7 23.1, 355697 6689356.4 23.1, 355703.7 6689330.8 23.1, 355683.7 6689325.6 23.1, 355679.4 6689336.1 23.1, 355682.8 6689337.3 23.1), (355684.6 6689340.9 23.1, 355687.9 6689341.7 23.1, 355698.3 6689344.4 23.1, 355697 6689349.3 23.1, 355688.3 6689346.1 23.1, 355683.4 6689344.3 23.1, 355684.6 6689340.9 23.1))
BATIMENT0000000302931650;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;7.2;18.1;21.3;7.5;Cadastre;;POLYGON Z ((355684.6 6689340.9 18.1, 355683.4 6689344.3 18.1, 355688.3 6689346.1 18.1, 355687.5 6689342.9 18.1, 355687.9 6689341.7 18.1, 355684.6 6689340.9 18.1))
BATIMENT0000000302931651;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;13.9;8.3;22.2;;;Cadastre;A 1.0;POLYGON Z ((355697 6689356.4 22.2, 355704.6 6689359.5 22.2, 355705.9 6689354 22.2, 355701.9 6689353 22.2, 355703.3 6689347.2 22.2, 355707.4 6689348.2 22.2, 355707.7 6689348.3 22.2, 355707.9 6689347.5 22.2, 355711.5 6689332.9 22.2, 355703.7 6689330.8 22.2, 355697 6689356.4 22.2))
BATIMENT0000000302931654;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.9;22.4;;;Cadastre;;POLYGON Z ((355718.9 6689347.5 22.4, 355718.8 6689347.9 22.4, 355718.5 6689350.5 22.4, 355720 6689350.7 22.4, 355720.6 6689348.1 22.4, 355718.9 6689347.5 22.4))
BATIMENT0000000302931655;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;17.1;7.3;24.5;27.0;7.9;Cadastre;A 1.0;POLYGON Z ((355727 6689368.8 24.5, 355727.4 6689368.4 24.5, 355727.5 6689336.9 24.5, 355720.4 6689334.9 24.5, 355720.4 6689335.1 24.5, 355718.9 6689347.5 24.5, 355720.6 6689348.1 24.5, 355721.3 6689348.3 24.5, 355719.8 6689354.8 24.5, 355718 6689354.5 24.5, 355717.7 6689354.5 24.5, 355716.5 6689364.5 24.5, 355727 6689368.8 24.5))
BATIMENT0000000302931120;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.4;6.4;14.8;17.1;6.8;Cadastre;A 1.0;POLYGON Z ((355815.5 6689117.4 14.8, 355808 6689115.7 14.8, 355801.4 6689125.7 14.8, 355804.3 6689127.5 14.8, 355814.4 6689134.1 14.8, 355822.6 6689122.8 14.8, 355815.5 6689117.4 14.8))
BATIMENT0000000302931110;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1873-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;12.5;6.1;18.7;21.5;7.0;Cadastre;A 1.0;POLYGON Z ((355771.1 6689137.6 18.7, 355771.9 6689139.4 18.7, 355776.1 6689142.2 18.7, 355783.4 6689130.6 18.7, 355784.1 6689131.1 18.7, 355785.1 6689127.9 18.7, 355786.3 6689124.3 18.7, 355787 6689122.2 18.7, 355783.2 6689121.1 18.7, 355776.8 6689119.2 18.7, 355771.1 6689137.6 18.7))
BATIMENT0000000302931116;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;7.0;13.7;;;Cadastre;;POLYGON Z ((355822.6 6689122.8 13.7, 355814.4 6689134.1 13.7, 355804.3 6689127.5 13.7, 355802.6 6689130 13.7, 355801.1 6689132.2 13.7, 355814.4 6689141.1 13.7, 355825.7 6689125.1 13.7, 355822.6 6689122.8 13.7))
BATIMENT0000000302931112;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;00;00;3.9;7.0;10.9;16.2;7.1;Cadastre;C 0.2;POLYGON Z ((355791.2 6689135.9 10.9, 355791 6689136.1 10.9, 355796.2 6689139.6 10.9, 355801.1 6689132.2 10.9, 355802.6 6689130 10.9, 355797.5 6689126.5 10.9, 355791.2 6689135.9 10.9))
BATIMENT0000000302931113;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;7.0;13.2;15.0;7.0;Cadastre;;POLYGON Z ((355803.8 6689144.7 13.2, 355809.1 6689148.5 13.2, 355814.4 6689141.1 13.2, 355801.1 6689132.2 13.2, 355796.2 6689139.6 13.2, 355803.8 6689144.7 13.2))
BATIMENT0000000302931109;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.4;6.2;21.7;24.7;7.0;Cadastre;C 0.7;POLYGON Z ((355796.2 6689155.9 21.7, 355803.8 6689144.7 21.7, 355796.2 6689139.6 21.7, 355791 6689136.1 21.7, 355791.2 6689135.9 21.7, 355784.1 6689131.1 21.7, 355783.4 6689130.6 21.7, 355776.1 6689142.2 21.7, 355796.2 6689155.9 21.7))
BATIMENT0000000302931107;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.6;6.4;14.0;15.8;6.9;Cadastre;A 1.0;POLYGON Z ((355821.4 6689173 14, 355828 6689163 14, 355837.3 6689148.9 14, 355844 6689138.8 14, 355825.7 6689125.1 14, 355814.4 6689141.1 14, 355809.1 6689148.5 14, 355801.4 6689159.4 14, 355821.4 6689173 14))
BATIMENT0000000302931108;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.0;7.0;16.0;;;Cadastre;A 1.0;POLYGON Z ((355801.4 6689159.4 16, 355809.1 6689148.5 16, 355803.8 6689144.7 16, 355796.2 6689155.9 16, 355801.4 6689159.4 16))
BATIMENT0000000302931025;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;18.9;7.4;26.4;28.5;8.0;Cadastre;A 1.0;POLYGON Z ((355735.5 6689338.5 26.4, 355735.4 6689358.8 26.4, 355741.2 6689360.3 26.4, 355742.5 6689353.4 26.4, 355741.7 6689352.5 26.4, 355740.7 6689352.6 26.4, 355740.8 6689351.1 26.4, 355743.1 6689350.3 26.4, 355744.8 6689341 26.4, 355735.5 6689338.5 26.4))
BATIMENT0000000302931020;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;18.7;7.4;26.1;29.1;7.8;Cadastre;A 1.0;POLYGON Z ((355750.6 6689342.9 26.1, 355750.7 6689342.5 26.1, 355744.8 6689341 26.1, 355743.1 6689350.3 26.1, 355742.8 6689351.7 26.1, 355744.3 6689352.2 26.1, 355744 6689353.4 26.1, 355743.7 6689353.7 26.1, 355742.5 6689353.4 26.1, 355741.2 6689360.3 26.1, 355744.8 6689361.2 26.1, 355747.9 6689362 26.1, 355749.7 6689355.9 26.1, 355747.7 6689355.3 26.1, 355748.3 6689353 26.1, 355750.4 6689353.6 26.1, 355753.3 6689343.6 26.1, 355750.6 6689342.9 26.1))
BATIMENT0000000302930904;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;30;20;18.1;7.4;25.5;27.0;7.8;Cadastre;A 1.0;POLYGON Z ((355591.5 6689196.1 25.5, 355596.9 6689185 25.5, 355585.6 6689181.1 25.5, 355583.3 6689187.4 25.5, 355582.6 6689189.1 25.5, 355582.2 6689190 25.5, 355579.7 6689189 25.5, 355578.9 6689191.1 25.5, 355582.6 6689192.6 25.5, 355591.5 6689196.1 25.5))
BATIMENT0000000302930905;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;7.4;19.4;22.0;7.8;Cadastre;;POLYGON Z ((355579.7 6689189 19.4, 355582.2 6689190 19.4, 355582.6 6689189.1 19.4, 355573.2 6689186.2 19.4, 355572.3 6689188.5 19.4, 355574.5 6689189.4 19.4, 355578.9 6689191.1 19.4, 355579.7 6689189 19.4))
BATIMENT0000000302930906;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;00;00;15.2;7.7;22.9;26.7;8.3;Cadastre;A 1.0;POLYGON Z ((355553.5 6689192.7 22.9, 355585.1 6689209.2 22.9, 355591.5 6689196.1 22.9, 355582.6 6689192.6 22.9, 355578.9 6689191.1 22.9, 355574.5 6689189.4 22.9, 355572.3 6689188.5 22.9, 355571.2 6689188.1 22.9, 355558 6689183.2 22.9, 355553.5 6689192.7 22.9))
BATIMENT0000002011296172;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:59;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;73.0;5.0;00;00;19.3;7.1;;27.0;7.9;Imagerie aérienne;A 1.0;POLYGON Z ((355665.2 6689260.8 23.1, 355663.5 6689259.4 26.4, 355664.4 6689257.5 26.4, 355666.5 6689258.8 23.3, 355669.9 6689251.8 23.3, 355667.9 6689250.3 26.3, 355668.7 6689248.7 26.3, 355671.1 6689250 23.3, 355675.2 6689241.8 23.3, 355665.1 6689233.1 23.3, 355664.3 6689234.8 23.4, 355662.4 6689233.4 23.4, 355662.9 6689231.4 23.4, 355653.2 6689223.4 23.6, 355652.5 6689225 23.6, 355650.7 6689223.7 23.6, 355651.3 6689222 23.6, 355641.5 6689214 23.6, 355641 6689215.1 23.6, 355639.2 6689213.9 23.6, 355639.7 6689212.5 23.5, 355630.3 6689204.4 23.4, 355629.6 6689205.5 23.4, 355626.7 6689204.3 23.4, 355627.5 6689202.6 23.1, 355613.4 6689195.5 23.8, 355609.8 6689202.3 23.8, 355612.1 6689203.6 26, 355611.1 6689205.7 26, 355609 6689204.4 23.8, 355603.2 6689215.5 24, 355605.7 6689216.5 26.3, 355604.6 6689218.8 26.2, 355602.2 6689217.6 23.8, 355599 6689223.8 24, 355601.4 6689225 26.2, 355600.3 6689227.2 26.2, 355598 6689225.9 23.9, 355592.4 6689237 23.9, 355595 6689237.9 25.9, 355593.8 6689240.3 26.1, 355591.4 6689238.7 23.5, 355588 6689245.6 23.5, 355602.3 6689252.8 23.5, 355602.6 6689251.9 23.5, 355605.3 6689252.5 23.5, 355604.9 6689254 23.4, 355617.1 6689257.3 23.4, 355617.7 6689255.9 23.4, 355619.6 6689256.2 23.4, 355619.4 6689257.8 23.4, 355631.7 6689260.9 23.4, 355632.3 6689259.5 23.4, 355634.4 6689260.1 23.4, 355633.9 6689261.5 23.4, 355646 6689264.5 23.4, 355647 6689262.5 25.9, 355649.4 6689263.1 25.9, 355648.3 6689265.7 23.6, 355661.4 6689269 23.6, 355665.2 6689260.8 23.1))
BATIMENT0000000302931167;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;20;20;15.6;7.0;22.7;27.8;7.9;Cadastre;A 1.0;POLYGON Z ((355624.5 6689309.7 22.7, 355624.6 6689309.4 22.7, 355613.4 6689306.5 22.7, 355611.4 6689314.5 22.7, 355625.4 6689318.1 22.7, 355646.2 6689330.2 22.7, 355649.8 6689316.3 22.7, 355624.5 6689309.7 22.7))
BATIMENT0000000302931168;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;18.4;7.0;25.4;29.1;7.5;Cadastre;A 1.0;POLYGON Z ((355656.2 6689336 25.4, 355657.9 6689336.3 25.4, 355659.9 6689325.4 25.4, 355661.4 6689319.6 25.4, 355661 6689318.8 25.4, 355649.9 6689316 25.4, 355649.8 6689316.3 25.4, 355646.2 6689330.2 25.4, 355656.2 6689336 25.4))
BATIMENT0000000302930923;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;20;17.5;6.9;24.5;26.8;8.0;Cadastre;A 1.0;POLYGON Z ((355609.9 6689331.1 24.5, 355622.8 6689338.7 24.5, 355622.2 6689339.7 24.5, 355627.2 6689342.8 24.5, 355629.7 6689344.4 24.5, 355631.5 6689341.2 24.5, 355632.3 6689340 24.5, 355637.4 6689331.2 24.5, 355638 6689330.2 24.5, 355629.5 6689325.6 24.5, 355617.4 6689319.7 24.5, 355616.8 6689320.6 24.5, 355609.9 6689331.1 24.5), (355625.5 6689334.5 24.5, 355628.4 6689336.3 24.5, 355626.2 6689339.8 24.5, 355623.4 6689338 24.5, 355625.5 6689334.5 24.5))
BATIMENT0000000302930920;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;20;20;19.8;6.8;26.7;28.5;7.3;Cadastre;B 0.4;POLYGON Z ((355640.7 6689345.3 26.7, 355642.1 6689343.3 26.7, 355641.9 6689343.2 26.7, 355646.3 6689336.2 26.7, 355637.4 6689331.2 26.7, 355632.3 6689340 26.7, 355640.7 6689345.3 26.7))
BATIMENT0000000302930926;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;14.9;7.7;22.6;28.2;8.3;Cadastre;A 1.0;POLYGON Z ((355607.8 6689340.4 22.6, 355607.4 6689341 22.6, 355620.9 6689349.7 22.6, 355621.9 6689348.1 22.6, 355623.1 6689348.7 22.6, 355627.2 6689342.8 22.6, 355622.2 6689339.7 22.6, 355622.8 6689338.7 22.6, 355609.9 6689331.1 22.6, 355609.8 6689331.4 22.6, 355607.4 6689330.8 22.6, 355605.4 6689338.8 22.6, 355607.8 6689340.4 22.6), (355619.5 6689341.2 22.6, 355621.8 6689342.7 22.6, 355620.5 6689344.8 22.6, 355618.2 6689343.3 22.6, 355619.5 6689341.2 22.6))
BATIMENT0000000302930922;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;20;20;13.9;7.7;21.6;;;Cadastre;A 1.0;POLYGON Z ((355651 6689348.6 21.6, 355654.8 6689341.1 21.6, 355646.7 6689336.1 21.6, 355646.3 6689336.2 21.6, 355641.9 6689343.2 21.6, 355642.1 6689343.3 21.6, 355651 6689348.6 21.6))
BATIMENT0000000302930924;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.3;7.7;23.0;;;Cadastre;;POLYGON Z ((355631.5 6689341.2 23, 355629.7 6689344.4 23, 355632.7 6689346.3 23, 355637.8 6689349.5 23, 355639.9 6689346.5 23, 355631.5 6689341.2 23))
BATIMENT0000000302931261;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;16.6;8.0;24.6;28.2;8.8;Cadastre;A 1.0;POLYGON Z ((355596.4 6689345.3 24.6, 355595.9 6689343.8 24.6, 355582.6 6689340.4 24.6, 355582.7 6689339.8 24.6, 355572.4 6689337.2 24.6, 355572.2 6689337.8 24.6, 355569.6 6689346.9 24.6, 355576 6689348.4 24.6, 355575 6689351.9 24.6, 355573.5 6689351.6 24.6, 355573.1 6689352.3 24.6, 355578.6 6689355.2 24.6, 355581 6689352.2 24.6, 355587 6689355.6 24.6, 355596.4 6689345.3 24.6))
BATIMENT0000000302930925;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;18.6;7.3;25.9;27.6;7.5;Cadastre;A 1.0;POLYGON Z ((355629.2 6689351.4 25.9, 355632.7 6689346.3 25.9, 355629.7 6689344.4 25.9, 355627.2 6689342.8 25.9, 355623.1 6689348.7 25.9, 355629.2 6689351.4 25.9))
BATIMENT0000000302930921;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;00;00;18.0;6.9;25.0;27.9;7.6;Cadastre;A 1.0;POLYGON Z ((355649.5 6689351.5 25, 355639.9 6689346.5 25, 355637.8 6689349.5 25, 355648.4 6689356.2 25, 355649.5 6689351.5 25))
BATIMENT0000000302930927;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;12;20;15.9;7.8;23.7;;;Cadastre;A 1.0;POLYGON Z ((355647.1 6689359.5 23.7, 355647.7 6689359.3 23.7, 355648.4 6689356.2 23.7, 355637.8 6689349.5 23.7, 355632.7 6689346.3 23.7, 355629.2 6689351.4 23.7, 355647.1 6689359.5 23.7))
BATIMENT0000000302931259;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.8;8.0;21.8;24.2;8.3;Cadastre;;POLYGON Z ((355571.4 6689355.2 21.8, 355573.1 6689352.3 21.8, 355570.6 6689351.1 21.8, 355569.2 6689353.8 21.8, 355571.4 6689355.2 21.8))
BATIMENT0000000302930360;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;35;20;13.2;7.4;20.7;26.3;8.0;Cadastre;A 1.0;POLYGON Z ((355606 6689348.7 20.7, 355600.8 6689354.4 20.7, 355613.2 6689359.9 20.7, 355616.1 6689353.2 20.7, 355606 6689348.7 20.7))
BATIMENT0000000302930361;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;7.3;14.9;17.2;7.7;Cadastre;;POLYGON Z ((355614.4 6689360.4 14.9, 355616.5 6689359.5 14.9, 355616.6 6689359.6 14.9, 355619 6689354.5 14.9, 355616.1 6689353.2 14.9, 355613.2 6689359.9 14.9, 355614.4 6689360.4 14.9))
BATIMENT0000000302931260;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;10;20;15.4;8.0;23.4;27.7;8.7;Cadastre;A 1.0;POLYGON Z ((355587 6689355.6 23.4, 355581 6689352.2 23.4, 355578.6 6689355.2 23.4, 355573.1 6689352.3 23.4, 355571.4 6689355.2 23.4, 355576.2 6689358 23.4, 355574.6 6689360.2 23.4, 355579.5 6689363.9 23.4, 355587 6689355.6 23.4))
BATIMENT0000000302930386;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.7;8.0;22.7;22.7;8.1;Cadastre;;POLYGON Z ((355606.7 6689359.7 22.7, 355605.3 6689362.2 22.7, 355607.7 6689363.5 22.7, 355609.2 6689361 22.7, 355606.7 6689359.7 22.7))
BATIMENT0000000302932566;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.2;7.0;13.2;17.7;8.4;Cadastre;B 0.5;POLYGON Z ((356045 6689141 13.2, 356066 6689152.9 13.2, 356067.7 6689153.9 13.2, 356069.5 6689154.9 13.2, 356071.5 6689147.4 13.2, 356071.4 6689147.4 13.2, 356071.9 6689145.8 13.2, 356063.4 6689140.9 13.2, 356069.9 6689129.5 13.2, 356078.6 6689134.6 13.2, 356081 6689134 13.2, 356079.9 6689129.4 13.2, 356058.9 6689117.1 13.2, 356051.9 6689129.2 13.2, 356050.9 6689130.8 13.2, 356049.6 6689133.1 13.2, 356045 6689141 13.2))
BATIMENT0000000302932659;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.8;6.0;19.8;22.5;7.0;Cadastre;;POLYGON Z ((356116.1 6689138.5 19.8, 356120.5 6689141.1 19.8, 356115.4 6689137.5 19.8, 356112.2 6689135.6 19.8, 356111.9 6689136.1 19.8, 356111.9 6689136.2 19.8, 356116.1 6689138.5 19.8))
BATIMENT0000000302932568;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;6.3;11.0;15.0;7.1;Cadastre;;POLYGON Z ((356082.2 6689139.7 11, 356072.8 6689141.8 11, 356073.8 6689146.9 11, 356083.4 6689144.9 11, 356082.2 6689139.7 11))
BATIMENT0000000302932569;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:15:29;2023-01-31 17:56:48;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.5;6.6;17.2;19.4;8.1;Cadastre;B 0.8;POLYGON Z ((356086 6689156.4 17.2, 356083.4 6689144.9 17.2, 356073.8 6689146.9 17.2, 356073.5 6689147 17.2, 356074.9 6689153.7 17.2, 356069.5 6689154.9 17.2, 356069.7 6689155 17.2, 356074.7 6689157.8 17.2, 356075.2 6689158.1 17.2, 356076.1 6689158.6 17.2, 356086 6689156.4 17.2))
BATIMENT0000000302932661;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;35;20;13.4;6.4;19.8;23.6;7.0;Cadastre;C 0.7;POLYGON Z ((356144.7 6689142.5 19.8, 356139.2 6689152.2 19.8, 356144 6689155.1 19.8, 356157.5 6689163.1 19.8, 356163.2 6689153.4 19.8, 356144.7 6689142.5 19.8))
BATIMENT0000000302932611;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;90;90;15.3;5.2;20.5;20.9;7.0;Cadastre;C 0.5;POLYGON Z ((356094.4 6689141.6 20.5, 356093.8 6689142.1 20.5, 356098.1 6689160.9 20.5, 356121.2 6689175.2 20.5, 356128.8 6689161.9 20.5, 356094.4 6689141.6 20.5))
BATIMENT0000000302932570;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;3.9;6.5;10.5;17.0;7.2;Cadastre;B 0.4;POLYGON Z ((356086.9 6689160.5 10.5, 356082.2 6689158 10.5, 356081.3 6689158.3 10.5, 356079.9 6689160.7 10.5, 356087.9 6689165.4 10.5, 356086.9 6689160.5 10.5))
BATIMENT0000000302932617;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.3;6.4;7.7;9.7;6.8;Cadastre;;POLYGON Z ((356102.7 6689175.9 7.7, 356101.9 6689172.3 7.7, 356100.5 6689171.5 7.7, 356101.5 6689176.2 7.7, 356102.7 6689175.9 7.7))
BATIMENT0000000302932567;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.5;7.4;24.9;26.6;8.2;Cadastre;C 0.4;POLYGON Z ((356053.9 6689177.4 24.9, 356065 6689183.6 24.9, 356069 6689176.5 24.9, 356072 6689178.1 24.9, 356070.6 6689180.6 24.9, 356094.3 6689194 24.9, 356092.3 6689184.9 24.9, 356090.5 6689177.1 24.9, 356089 6689169.9 24.9, 356080.1 6689165 24.9, 356078.5 6689167.7 24.9, 356075.6 6689166 24.9, 356078.9 6689160.2 24.9, 356076.4 6689158.8 24.9, 356076.1 6689158.6 24.9, 356075.2 6689158.1 24.9, 356074.7 6689157.8 24.9, 356069.7 6689155 24.9, 356069.5 6689154.9 24.9, 356067.7 6689153.9 24.9, 356060.9 6689165.6 24.9, 356053.9 6689177.4 24.9))
BATIMENT0000000302932616;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.1;5.3;10.4;10.8;7.4;Cadastre;C 0.8;POLYGON Z ((356121.8 6689193.4 10.4, 356119.4 6689182.8 10.4, 356111.7 6689184.5 10.4, 356110.1 6689177.1 10.4, 356101.9 6689172.3 10.4, 356102.7 6689175.9 10.4, 356101.5 6689176.2 10.4, 356106.2 6689196.9 10.4, 356121.8 6689193.4 10.4))
BATIMENT0000000302932675;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.4;6.0;23.4;31.0;7.5;Cadastre;;POLYGON Z ((356403.6 6689066.8 23.4, 356411 6689051.6 23.4, 356374.3 6689033.7 23.4, 356367.2 6689048.3 23.4, 356367.3 6689048.5 23.4, 356403.6 6689066.8 23.4))
BATIMENT0000000302932676;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;23.0;7.0;30.1;41.3;9.0;Cadastre;B 0.4;POLYGON Z ((356341.7 6689085.2 30.1, 356341.7 6689086 30.1, 356341.8 6689086.7 30.1, 356341.9 6689088.3 30.1, 356342 6689089.1 30.1, 356342.1 6689089.9 30.1, 356342.4 6689091.4 30.1, 356342.6 6689092.1 30.1, 356342.8 6689092.9 30.1, 356343 6689093.6 30.1, 356343.3 6689094.4 30.1, 356343.5 6689095.1 30.1, 356343.8 6689095.9 30.1, 356344.5 6689097.3 30.1, 356345.2 6689098.7 30.1, 356345.5 6689099.4 30.1, 356346.3 6689100.7 30.1, 356347.2 6689102 30.1, 356347.7 6689102.6 30.1, 356348.2 6689103.2 30.1, 356348.7 6689103.8 30.1, 356349.2 6689104.4 30.1, 356349.7 6689105 30.1, 356350.3 6689105.5 30.1, 356350.8 6689106.1 30.1, 356351.4 6689106.6 30.1, 356352 6689107.1 30.1, 356352.6 6689107.6 30.1, 356353.2 6689108.1 30.1, 356353.8 6689108.6 30.1, 356354.5 6689109 30.1, 356355.1 6689109.5 30.1, 356355.8 6689109.9 30.1, 356356.5 6689110.3 30.1, 356357.1 6689110.6 30.1, 356357.8 6689111 30.1, 356358.5 6689111.3 30.1, 356360 6689112 30.1, 356360.6 6689112.3 30.1, 356361.3 6689112.6 30.1, 356362 6689112.9 30.1, 356363.5 6689113.5 30.1, 356364.2 6689113.7 30.1, 356365.6 6689114.1 30.1, 356367.1 6689114.5 30.1, 356367.9 6689114.6 30.1, 356369.4 6689114.9 30.1, 356370.9 6689115 30.1, 356371.7 6689115.1 30.1, 356372.4 6689115.1 30.1, 356373.2 6689115.1 30.1, 356373.9 6689115.1 30.1, 356374.7 6689115.1 30.1, 356376.2 6689114.9 30.1, 356377 6689114.8 30.1, 356378.5 6689114.6 30.1, 356380 6689114.3 30.1, 356380.7 6689114.1 30.1, 356382.2 6689113.7 30.1, 356382.9 6689113.4 30.1, 356384.3 6689112.9 30.1, 356385 6689112.5 30.1, 356385.7 6689112.2 30.1, 356386.4 6689111.9 30.1, 356387.1 6689111.5 30.1, 356387.7 6689111.2 30.1, 356389 6689110.4 30.1, 356389.6 6689109.9 30.1, 356390.3 6689109.5 30.1, 356390.9 6689109 30.1, 356391.5 6689108.5 30.1, 356392 6689108.1 30.1, 356392.6 6689107.6 30.1, 356393.7 6689106.5 30.1, 356394.2 6689105.9 30.1, 356394.7 6689105.4 30.1, 356395.7 6689104.2 30.1, 356396.7 6689103 30.1, 356397.1 6689102.4 30.1, 356397.5 6689101.7 30.1, 356397.9 6689101.1 30.1, 356398.3 6689100.4 30.1, 356398.7 6689099.8 30.1, 356399 6689099.1 30.1, 356399.3 6689098.4 30.1, 356399.6 6689097.7 30.1, 356400.2 6689096.3 30.1, 356400.5 6689095.6 30.1, 356400.7 6689094.9 30.1, 356400.9 6689094.1 30.1, 356401.1 6689093.4 30.1, 356401.3 6689092.7 30.1, 356401.5 6689091.9 30.1, 356401.6 6689091.2 30.1, 356401.8 6689090.4 30.1, 356401.9 6689089.7 30.1, 356401.9 6689088.9 30.1, 356402 6689088.1 30.1, 356402 6689087.4 30.1, 356402.1 6689086.6 30.1, 356402.1 6689085.9 30.1, 356402 6689085.1 30.1, 356402 6689084.3 30.1, 356402 6689083.6 30.1, 356401.8 6689082.1 30.1, 356401.7 6689081.3 30.1, 356401.5 6689080.6 30.1, 356401.4 6689079.8 30.1, 356401.2 6689079.1 30.1, 356401 6689078.3 30.1, 356400.8 6689077.6 30.1, 356399.9 6689079.4 30.1, 356398 6689078.5 30.1, 356403.6 6689066.8 30.1, 356367.3 6689048.5 30.1, 356367.2 6689048.3 30.1, 356361.3 6689060.5 30.1, 356359.3 6689059.6 30.1, 356360.2 6689057.8 30.1, 356358.8 6689058.4 30.1, 356358 6689058.7 30.1, 356356.7 6689059.5 30.1, 356355.3 6689060.3 30.1, 356354 6689061.1 30.1, 356352.8 6689062.1 30.1, 356352.2 6689062.6 30.1, 356351 6689063.6 30.1, 356349.9 6689064.7 30.1, 356349.4 6689065.3 30.1, 356348.8 6689065.8 30.1, 356347.8 6689067 30.1, 356347.4 6689067.7 30.1, 356346.9 6689068.3 30.1, 356346.5 6689068.9 30.1, 356346.1 6689069.6 30.1, 356345.7 6689070.3 30.1, 356345.3 6689071 30.1, 356344.9 6689071.7 30.1, 356344.6 6689072.4 30.1, 356344.2 6689073.1 30.1, 356343.9 6689073.8 30.1, 356343.6 6689074.5 30.1, 356343.4 6689075.2 30.1, 356343.1 6689076 30.1, 356342.7 6689077.5 30.1, 356342.3 6689079 30.1, 356342.2 6689079.8 30.1, 356342 6689080.5 30.1, 356341.9 6689081.3 30.1, 356341.8 6689082.1 30.1, 356341.7 6689083.6 30.1, 356341.7 6689084.4 30.1, 356341.7 6689085.2 30.1))
BATIMENT0000000303962346;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;00;00;18.5;7.5;26.0;27.5;7.6;Cadastre;A 1.0;POLYGON Z ((356502.6 6689250.1 26, 356506.81139568595 6689253.987442171 26, 356506.81139568595 6689245.620231059 26, 356502.6 6689250.1 26))
BATIMENT0000000303962347;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;25;90;18.9;7.3;26.2;27.5;7.7;Cadastre;A 1.0;POLYGON Z ((356482 6689272.1 26.2, 356489.7 6689279.2 26.2, 356496.6 6689272 26.2, 356500 6689268.3 26.2, 356506.81139568595 6689261.08793398 26.2, 356506.81139568595 6689253.987442171 26.2, 356502.6 6689250.1 26.2, 356482 6689272.1 26.2))
BATIMENT0000000303963062;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.8;7.1;9.9;11.2;7.5;Cadastre;A 1.0;POLYGON Z ((356499.9 6689277.2 9.9, 356496.7 6689282.7 9.9, 356499.4 6689284.3 9.9, 356502.6 6689278.8 9.9, 356499.9 6689277.2 9.9))
BATIMENT0000000303963061;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.9;7.1;10.0;10.3;7.9;Cadastre;A 1.0;POLYGON Z ((356502.6 6689278.8 10, 356499.4 6689284.3 10, 356502.3 6689286 10, 356505.5 6689280.5 10, 356502.6 6689278.8 10))
BATIMENT0000000303963060;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.9;7.1;10.0;10.2;8.0;Cadastre;A 1.0;POLYGON Z ((356505.5 6689280.5 10, 356502.3 6689286 10, 356505 6689287.5 10, 356506.81139568595 6689284.386663665 10, 356506.81139568595 6689281.274915633 10, 356505.5 6689280.5 10))
BATIMENT0000000303962419;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;39;90;19.9;6.7;26.6;27.4;7.5;Cadastre;A 1.0;POLYGON Z ((356479 6689275.3 26.6, 356464.9 6689290.5 26.6, 356472.6 6689297.3 26.6, 356479.6 6689289.9 26.6, 356479.9 6689290.3 26.6, 356482.9 6689287 26.6, 356482.6 6689286.8 26.6, 356489.7 6689279.2 26.6, 356482 6689272.1 26.6, 356479 6689275.3 26.6))
BATIMENT0000000303963053;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.9;7.1;10.0;10.6;8.2;Cadastre;A 1.0;POLYGON Z ((356506.81139568595 6689288.561852643 10, 356506.81139568595 6689284.386663665 10, 356505 6689287.5 10, 356506.81139568595 6689288.561852643 10))
BATIMENT0000000303962859;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;6.4;7.3;13.7;19.6;7.7;Cadastre;A 1.0;POLYGON Z ((356496.4 6689291.6 13.7, 356491.8 6689298.9 13.7, 356487.7 6689296.5 13.7, 356482.6 6689304.9 13.7, 356489.7 6689309 13.7, 356499.1 6689293.2 13.7, 356496.4 6689291.6 13.7))
BATIMENT0000000302932664;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;15.0;7.0;22.0;26.3;7.3;Cadastre;A 1.0;POLYGON Z ((356190.3 6689132.7 22, 356187.1 6689123.2 22, 356181.4 6689120.2 22, 356181.3 6689120.4 22, 356176 6689130.6 22, 356172.3 6689138 22, 356184.8 6689143.9 22, 356190.3 6689132.7 22))
BATIMENT0000000302932578;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.4;6.0;27.4;27.7;7.7;Cadastre;;POLYGON Z ((356278.1 6689139.3 27.4, 356279 6689139.7 27.4, 356281.7 6689134.1 27.4, 356280.8 6689133.7 27.4, 356278.1 6689139.3 27.4))
BATIMENT0000000302932665;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.9;6.7;25.6;26.4;7.3;Cadastre;A 1.0;POLYGON Z ((356168.3 6689169.4 25.6, 356169.9 6689166.2 25.6, 356173.2 6689167.7 25.6, 356184.8 6689143.9 25.6, 356172.3 6689138 25.6, 356163.2 6689153.4 25.6, 356157.5 6689163.1 25.6, 356168.3 6689169.4 25.6))
BATIMENT0000000302932648;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;21.2;7.0;28.2;30.2;7.6;Cadastre;A 1.0;POLYGON Z ((356202.8 6689187.8 28.2, 356212.5 6689192.3 28.2, 356212 6689193.3 28.2, 356218.1 6689196.9 28.2, 356238.1 6689155.4 28.2, 356231.9 6689152.4 28.2, 356232.3 6689151.7 28.2, 356222.6 6689147 28.2, 356202.8 6689187.8 28.2))
BATIMENT0000000302932620;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;6.6;10.2;12.7;8.0;Cadastre;;POLYGON Z ((356303.5 6689197.5 10.2, 356308.3 6689187.7 10.2, 356306.7 6689186.9 10.2, 356300.4 6689183.8 10.2, 356299.8 6689185 10.2, 356306.1 6689188 10.2, 356302.8 6689194.8 10.2, 356301.9 6689196.7 10.2, 356303.5 6689197.5 10.2))
BATIMENT0000000302932618;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.0;12.3;12.7;8.3;Cadastre;;POLYGON Z ((356285.7 6689198.9 12.3, 356286.8 6689196.6 12.3, 356283.1 6689194.8 12.3, 356282 6689197.1 12.3, 356285.7 6689198.9 12.3))
BATIMENT0000000302932619;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;21.5;6.8;28.3;32.0;8.6;Cadastre;A 0.4;POLYGON Z ((356246.5 6689212 28.3, 356247.3 6689210.2 28.3, 356248.6 6689210.8 28.3, 356247.7 6689212.6 28.3, 356262.2 6689219.6 28.3, 356263.7 6689220.3 28.3, 356279.2 6689227.9 28.3, 356280.1 6689228.3 28.3, 356280.3 6689227.7 28.3, 356284.9 6689229.9 28.3, 356284.6 6689230.5 28.3, 356288.2 6689232.3 28.3, 356290 6689233.1 28.3, 356299.3 6689237.7 28.3, 356301.3 6689233.5 28.3, 356300.1 6689232.8 28.3, 356300.7 6689231.6 28.3, 356305.1 6689233.8 28.3, 356315 6689220.9 28.3, 356294.9 6689211.1 28.3, 356292.6 6689215.8 28.3, 356291 6689219.2 28.3, 356288.1 6689217.8 28.3, 356289.7 6689214.4 28.3, 356265.2 6689202.8 28.3, 356272.1 6689188.4 28.3, 356287.2 6689195.7 28.3, 356294.3 6689199.2 28.3, 356296.7 6689194.2 28.3, 356301.9 6689196.7 28.3, 356302.8 6689194.8 28.3, 356306.1 6689188 28.3, 356299.8 6689185 28.3, 356300.4 6689183.8 28.3, 356263.8 6689165.9 28.3, 356260.3 6689173 28.3, 356247 6689200.5 28.3, 356242.4 6689210 28.3, 356246.5 6689212 28.3))
BATIMENT0000000302932649;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;7.2;26.6;28.5;7.6;Cadastre;;POLYGON Z ((356207.3 6689215.4 26.6, 356208.6 6689216 26.6, 356212 6689208.6 26.6, 356210.7 6689207.9 26.6, 356207.3 6689215.4 26.6))
BATIMENT0000000302932621;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.9;6.6;26.5;30.9;6.8;Cadastre;;POLYGON Z ((356288.1 6689217.8 26.5, 356291 6689219.2 26.5, 356292.6 6689215.8 26.5, 356289.7 6689214.4 26.5, 356288.1 6689217.8 26.5))
BATIMENT0000000302932623;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;6.3;8.9;20.0;7.0;Cadastre;;POLYGON Z ((356305.1 6689233.8 8.9, 356306.2 6689234.3 8.9, 356316.9 6689220.5 8.9, 356315.8 6689220 8.9, 356295.4 6689210 8.9, 356294.9 6689211.1 8.9, 356315 6689220.9 8.9, 356305.1 6689233.8 8.9))
BATIMENT0000000302932612;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;159.0;6.0;90;90;13.9;6.8;20.8;26.0;7.7;Cadastre;C 0.2;POLYGON Z ((356145.7 6689189.2 20.8, 356137.9 6689204.5 20.8, 356141.5 6689206.3 20.8, 356138.5 6689212.4 20.8, 356148.8 6689217.2 20.8, 356159.1 6689195.6 20.8, 356160.9 6689191.9 20.8, 356164.6 6689184.1 20.8, 356164.2 6689182.6 20.8, 356155.3 6689177.4 20.8, 356132.7 6689164.2 20.8, 356128.8 6689161.9 20.8, 356121.2 6689175.2 20.8, 356145.7 6689189.2 20.8))
BATIMENT0000000302932613;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.6;7.0;25.6;25.7;7.8;Cadastre;;POLYGON Z ((356148.8 6689217.2 25.6, 356138.5 6689212.4 25.6, 356130.5 6689229.1 25.6, 356134.3 6689231 25.6, 356140.7 6689234 25.6, 356142.9 6689229.5 25.6, 356148.8 6689217.2 25.6))
BATIMENT0000000302932610;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;6.8;10.2;15.0;7.3;Cadastre;;POLYGON Z ((356115.3 6689229 10.2, 356115.1 6689229.1 10.2, 356114.9 6689229.2 10.2, 356114.6 6689229.4 10.2, 356114.4 6689229.7 10.2, 356114.1 6689230 10.2, 356113.9 6689230.4 10.2, 356113.8 6689230.6 10.2, 356113.9 6689230.8 10.2, 356114 6689231.2 10.2, 356114.2 6689231.5 10.2, 356114.4 6689231.9 10.2, 356114.5 6689232.1 10.2, 356114.7 6689232.2 10.2, 356114.8 6689232.4 10.2, 356115 6689232.5 10.2, 356115.3 6689232.7 10.2, 356115.5 6689232.8 10.2, 356115.7 6689232.9 10.2, 356115.9 6689233 10.2, 356116.3 6689233.1 10.2, 356116.5 6689233.1 10.2, 356116.9 6689233.2 10.2, 356117.1 6689233.1 10.2, 356117.5 6689233.1 10.2, 356117.7 6689233 10.2, 356117.9 6689233 10.2, 356118.3 6689232.8 10.2, 356118.5 6689232.7 10.2, 356118.8 6689232.5 10.2, 356119.2 6689232.2 10.2, 356119.3 6689232.1 10.2, 356119.4 6689231.9 10.2, 356119.7 6689231.5 10.2, 356119.7 6689231.4 10.2, 356119.8 6689231.2 10.2, 356119.9 6689231 10.2, 356119.8 6689230.8 10.2, 356119.8 6689230.6 10.2, 356119.6 6689230.2 10.2, 356119.4 6689229.9 10.2, 356119.1 6689229.6 10.2, 356119 6689229.4 10.2, 356118.7 6689229.2 10.2, 356118.5 6689229.1 10.2, 356118.2 6689228.9 10.2, 356118 6689228.8 10.2, 356117.8 6689228.7 10.2, 356117.6 6689228.7 10.2, 356117.4 6689228.6 10.2, 356117.2 6689228.6 10.2, 356116.8 6689228.6 10.2, 356116.6 6689228.6 10.2, 356116.2 6689228.6 10.2, 356115.8 6689228.7 10.2, 356115.5 6689228.9 10.2, 356115.3 6689229 10.2))
BATIMENT0000000302932668;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.2;8.2;21.4;;;Cadastre;;POLYGON Z ((356083.6 6689211.5 21.4, 356083.4 6689211.8 21.4, 356063.8 6689200.7 21.4, 356063.2 6689201.8 21.4, 356057.4 6689198.5 21.4, 356052.1 6689207.8 21.4, 356053.4 6689208.5 21.4, 356036.4 6689238.1 21.4, 356035.4 6689237.5 21.4, 356035.1 6689237.3 21.4, 356029.2 6689247.7 21.4, 356034.9 6689250.8 21.4, 356051.7 6689259.8 21.4, 356055.3 6689261.8 21.4, 356070.5 6689269.9 21.4, 356077.5 6689257 21.4, 356073.6 6689254.9 21.4, 356072.9 6689256 21.4, 356059.9 6689249 21.4, 356060.6 6689247.9 21.4, 356049.7 6689242 21.4, 356063.5 6689218 21.4, 356073.1 6689223.2 21.4, 356084.8 6689229.5 21.4, 356085 6689229.2 21.4, 356087.5 6689230.6 21.4, 356090.2 6689242.4 21.4, 356104.4 6689239.7 21.4, 356099.6 6689218.5 21.4, 356097 6689219.1 21.4, 356088.7 6689214.3 21.4, 356083.6 6689211.5 21.4))
BATIMENT0000000302932614;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;7.1;21.2;26.2;7.9;Cadastre;;POLYGON Z ((356130.6 6689236.8 21.2, 356130 6689236.6 21.2, 356129.2 6689236.3 21.2, 356128.8 6689236.2 21.2, 356128.4 6689236.1 21.2, 356127.7 6689235.9 21.2, 356127.5 6689235.9 21.2, 356127.3 6689235.8 21.2, 356127.1 6689235.8 21.2, 356126.8 6689235.8 21.2, 356126 6689235.6 21.2, 356125.5 6689235.6 21.2, 356125.3 6689235.6 21.2, 356124.7 6689235.6 21.2, 356124.4 6689235.6 21.2, 356124.2 6689235.6 21.2, 356124 6689235.6 21.2, 356123.8 6689235.6 21.2, 356123.1 6689235.6 21.2, 356122.7 6689235.7 21.2, 356115.3 6689237.2 21.2, 356115.4 6689237.4 21.2, 356118.9 6689253 21.2, 356121.9 6689266.6 21.2, 356124.7 6689266.9 21.2, 356136.1 6689243.4 21.2, 356140.7 6689234 21.2, 356134.3 6689231 21.2, 356131.2 6689237.1 21.2, 356130.6 6689236.8 21.2), (356125.6 6689237.2 21.2, 356126.2 6689237.2 21.2, 356126.6 6689237.2 21.2, 356126.8 6689237.3 21.2, 356127 6689237.3 21.2, 356127.9 6689237.5 21.2, 356128.5 6689237.6 21.2, 356128.9 6689237.7 21.2, 356129.4 6689237.9 21.2, 356130.2 6689238.2 21.2, 356130.7 6689238.5 21.2, 356131.1 6689237.4 21.2, 356133.2 6689238.4 21.2, 356133.5 6689237.6 21.2, 356136.2 6689239 21.2, 356125.3 6689261.6 21.2, 356122.5 6689261.5 21.2, 356117.3 6689238.6 21.2, 356123.1 6689237.4 21.2, 356123.3 6689237.4 21.2, 356123.7 6689237.3 21.2, 356124.4 6689237.2 21.2, 356124.8 6689237.2 21.2, 356125.2 6689237.2 21.2, 356125.4 6689237.2 21.2, 356125.6 6689237.2 21.2))
BATIMENT0000000302932615;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;7.2;24.5;25.6;7.9;Cadastre;;POLYGON Z ((356125.2 6689237.2 24.5, 356124.8 6689237.2 24.5, 356124.4 6689237.2 24.5, 356123.7 6689237.3 24.5, 356123.3 6689237.4 24.5, 356123.1 6689237.4 24.5, 356117.3 6689238.6 24.5, 356122.5 6689261.5 24.5, 356125.3 6689261.6 24.5, 356136.2 6689239 24.5, 356133.5 6689237.6 24.5, 356133.2 6689238.4 24.5, 356131.1 6689237.4 24.5, 356130.7 6689238.5 24.5, 356130.2 6689238.2 24.5, 356129.4 6689237.9 24.5, 356128.9 6689237.7 24.5, 356128.5 6689237.6 24.5, 356127.9 6689237.5 24.5, 356127 6689237.3 24.5, 356126.8 6689237.3 24.5, 356126.6 6689237.2 24.5, 356126.2 6689237.2 24.5, 356125.6 6689237.2 24.5, 356125.4 6689237.2 24.5, 356125.2 6689237.2 24.5))
BATIMENT0000000302932669;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.3;6.9;19.2;21.2;7.5;Cadastre;;POLYGON Z ((356060.6 6689247.9 19.2, 356059.9 6689249 19.2, 356072.9 6689256 19.2, 356073.6 6689254.9 19.2, 356074 6689254.1 19.2, 356061 6689247.1 19.2, 356060.6 6689247.9 19.2))
BATIMENT0000000302932670;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.6;6.9;17.5;18.1;7.9;Cadastre;A 1.0;POLYGON Z ((356078.6 6689255.2 17.5, 356078.5 6689255.2 17.5, 356077.5 6689257 17.5, 356070.5 6689269.9 17.5, 356070.3 6689270.1 17.5, 356097.2 6689284.6 17.5, 356112.1 6689273.4 17.5, 356104.4 6689239.7 17.5, 356090.2 6689242.4 17.5, 356085.5 6689243.3 17.5, 356078.6 6689255.2 17.5))
BATIMENT0000000302932572;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.2;7.0;24.2;26.4;8.0;Cadastre;;POLYGON Z ((356054.2 6689281.8 24.2, 356044.6 6689299.4 24.2, 356043.5 6689298.8 24.2, 356040.1 6689304.7 24.2, 356043.9 6689313.3 24.2, 356042.4 6689314.2 24.2, 356043.1 6689315.4 24.2, 356043.9 6689316.8 24.2, 356044.8 6689318 24.2, 356045.9 6689319.5 24.2, 356046.9 6689321 24.2, 356048.1 6689322.4 24.2, 356049.2 6689323.8 24.2, 356051.1 6689325.9 24.2, 356052.4 6689327.2 24.2, 356053.7 6689328.7 24.2, 356056.5 6689331.2 24.2, 356057.7 6689332.3 24.2, 356066.2 6689337.9 24.2, 356069.7 6689339.8 24.2, 356070.8 6689337.4 24.2, 356074.6 6689336.5 24.2, 356077.5 6689337.9 24.2, 356095.4 6689304.7 24.2, 356092.6 6689303.2 24.2, 356091.8 6689299.3 24.2, 356093.2 6689296.8 24.2, 356058 6689277.7 24.2, 356055.4 6689282.4 24.2, 356054.2 6689281.8 24.2), (356061.2 6689282.9 24.2, 356089.1 6689298.1 24.2, 356088.5 6689299.2 24.2, 356089.9 6689305.1 24.2, 356091.2 6689306 24.2, 356076.1 6689333.6 24.2, 356074.7 6689332.8 24.2, 356069.1 6689334.2 24.2, 356068.2 6689335.7 24.2, 356067.6 6689335.4 24.2, 356066.4 6689334.5 24.2, 356065.1 6689333.7 24.2, 356063.5 6689332.5 24.2, 356062.2 6689331.5 24.2, 356060.8 6689330.6 24.2, 356059.6 6689329.6 24.2, 356058.5 6689328.6 24.2, 356057.2 6689327.5 24.2, 356055.3 6689325.7 24.2, 356054.3 6689324.6 24.2, 356053.1 6689323.6 24.2, 356052.1 6689322.4 24.2, 356050.6 6689320.9 24.2, 356049.7 6689319.8 24.2, 356048.6 6689318.4 24.2, 356047.5 6689317 24.2, 356046.7 6689316.1 24.2, 356046.2 6689315.2 24.2, 356049.3 6689313.3 24.2, 356047.9 6689311.1 24.2, 356049.5 6689310.1 24.2, 356047.9 6689308.3 24.2, 356050.2 6689304 24.2, 356050.9 6689304.3 24.2, 356051.5 6689303.2 24.2, 356052.4 6689301.6 24.2, 356049.9 6689300.2 24.2, 356052.6 6689295.4 24.2, 356053.4 6689295.8 24.2, 356060.4 6689283 24.2, 356061.2 6689282.9 24.2))
BATIMENT0000000302932573;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.2;7.0;24.2;27.4;7.9;Cadastre;C 0.1;POLYGON Z ((356053.4 6689295.8 24.2, 356052.6 6689295.4 24.2, 356049.9 6689300.2 24.2, 356052.4 6689301.6 24.2, 356051.5 6689303.2 24.2, 356050.9 6689304.3 24.2, 356050.2 6689304 24.2, 356047.9 6689308.3 24.2, 356049.5 6689310.1 24.2, 356047.9 6689311.1 24.2, 356049.3 6689313.3 24.2, 356046.2 6689315.2 24.2, 356046.7 6689316.1 24.2, 356047.5 6689317 24.2, 356048.6 6689318.4 24.2, 356049.7 6689319.8 24.2, 356050.6 6689320.9 24.2, 356052.1 6689322.4 24.2, 356053.1 6689323.6 24.2, 356054.3 6689324.6 24.2, 356055.3 6689325.7 24.2, 356057.2 6689327.5 24.2, 356058.5 6689328.6 24.2, 356059.6 6689329.6 24.2, 356060.8 6689330.6 24.2, 356062.2 6689331.5 24.2, 356063.5 6689332.5 24.2, 356065.1 6689333.7 24.2, 356066.4 6689334.5 24.2, 356067.6 6689335.4 24.2, 356068.2 6689335.7 24.2, 356069.1 6689334.2 24.2, 356074.7 6689332.8 24.2, 356076.1 6689333.6 24.2, 356091.2 6689306 24.2, 356089.9 6689305.1 24.2, 356088.5 6689299.2 24.2, 356089.1 6689298.1 24.2, 356061.2 6689282.9 24.2, 356060.4 6689283 24.2, 356053.4 6689295.8 24.2), (356060.5 6689291.9 24.2, 356080.8 6689302.9 24.2, 356080.5 6689303.1 24.2, 356081.4 6689306.7 24.2, 356081.9 6689307 24.2, 356071.7 6689325.8 24.2, 356071.3 6689325.6 24.2, 356067.9 6689326.4 24.2, 356066 6689324.9 24.2, 356064.9 6689323.9 24.2, 356063.9 6689323.1 24.2, 356062.7 6689322 24.2, 356060.2 6689319.6 24.2, 356059.2 6689318.5 24.2, 356057.6 6689316.8 24.2, 356055.4 6689314.1 24.2, 356054.5 6689313 24.2, 356053.7 6689311.9 24.2, 356053.1 6689311 24.2, 356054.8 6689309.9 24.2, 356052.1 6689305.6 24.2, 356052.3 6689305.2 24.2, 356051.2 6689304.5 24.2, 356051.8 6689303.4 24.2, 356052.8 6689301.8 24.2, 356055.2 6689303.2 24.2, 356058.8 6689302.1 24.2, 356057.8 6689298.8 24.2, 356056.9 6689298.3 24.2, 356060.5 6689291.9 24.2))
BATIMENT0000000302932650;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;21.2;7.2;28.5;30.1;7.6;Cadastre;C 0.1;POLYGON Z ((356205.8 6689218.4 28.5, 356207.3 6689215.4 28.5, 356210.7 6689207.9 28.5, 356196 6689200.8 28.5, 356177.4 6689239.1 28.5, 356182.1 6689241.5 28.5, 356178.1 6689249.7 28.5, 356188.2 6689254.6 28.5, 356188.9 6689253.2 28.5, 356205.8 6689218.4 28.5))
BATIMENT0000000302932622;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.1;7.2;27.3;;;Cadastre;;POLYGON Z ((356284.6 6689230.5 27.3, 356284.9 6689229.9 27.3, 356280.3 6689227.7 27.3, 356280.1 6689228.3 27.3, 356284.6 6689230.5 27.3))
BATIMENT0000000302932651;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.2;7.2;28.5;29.6;7.6;Cadastre;;POLYGON Z ((356188.9 6689253.2 28.5, 356190.2 6689253.8 28.5, 356207.2 6689219.1 28.5, 356205.8 6689218.4 28.5, 356188.9 6689253.2 28.5))
BATIMENT0000000302932635;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.6;6.1;25.7;30.7;6.5;Cadastre;;POLYGON Z ((356289 6689255.4 25.7, 356286.6 6689254 25.7, 356285.1 6689256.6 25.7, 356285.4 6689258 25.7, 356279.9 6689265 25.7, 356281.1 6689265.6 25.7, 356289 6689255.4 25.7))
BATIMENT0000000302932636;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.1;6.4;22.5;32.7;7.5;Cadastre;;POLYGON Z ((356209.9 6689272.4 22.5, 356210 6689272.4 22.5, 356213.5 6689273.9 22.5, 356212.2 6689277.1 22.5, 356243.3 6689292.5 22.5, 356244.4 6689290.3 22.5, 356251.7 6689294 22.5, 356254.4 6689295.3 22.5, 356255.4 6689293.8 22.5, 356256.4 6689294.3 22.5, 356262.4 6689287.1 22.5, 356261.5 6689286.4 22.5, 356263.1 6689283.6 22.5, 356262.3 6689283.3 22.5, 356272.6 6689261.4 22.5, 356279.9 6689265 22.5, 356285.4 6689258 22.5, 356285.1 6689256.6 22.5, 356286.6 6689254 22.5, 356247.8 6689231.2 22.5, 356246.9 6689232.6 22.5, 356242.9 6689230.4 22.5, 356242.4 6689231.1 22.5, 356239 6689229.2 22.5, 356239.4 6689227.9 22.5, 356235.2 6689226 22.5, 356234.3 6689228.1 22.5, 356232.4 6689227 22.5, 356209.9 6689272.4 22.5))
BATIMENT0000000302932645;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.7;7.4;29.1;30.1;8.4;Cadastre;;POLYGON Z ((356162.7 6689305.2 29.1, 356178.9 6689272.5 29.1, 356176.6 6689271.5 29.1, 356179.5 6689265.4 29.1, 356167.6 6689259.7 29.1, 356148.8 6689298.1 29.1, 356162.7 6689305.2 29.1))
BATIMENT0000000302932642;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;7.2;19.2;24.9;7.8;Cadastre;;POLYGON Z ((356216.3 6689290.1 19.2, 356217.2 6689288.2 19.2, 356213.7 6689286.5 19.2, 356207.4 6689281.9 19.2, 356206 6689284.9 19.2, 356216.3 6689290.1 19.2))
BATIMENT0000000302932643;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;7.2;11.0;12.0;7.5;Cadastre;;POLYGON Z ((356201.6 6689289.2 11, 356203.5 6689290.2 11, 356206 6689284.9 11, 356204.2 6689284 11, 356201.6 6689289.2 11))
BATIMENT0000000302932646;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.0;7.3;29.3;29.6;8.0;Cadastre;;POLYGON Z ((356164.1 6689305.9 29.3, 356180.4 6689273.3 29.3, 356178.9 6689272.5 29.3, 356162.7 6689305.2 29.3, 356164.1 6689305.9 29.3))
BATIMENT0000000302932637;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.6;6.0;23.6;31.0;7.0;Cadastre;;POLYGON Z ((356266.1 6689285.1 23.6, 356263.1 6689283.6 23.6, 356261.5 6689286.4 23.6, 356262.4 6689287.1 23.6, 356256.4 6689294.3 23.6, 356258.3 6689295.3 23.6, 356259.7 6689293.4 23.6, 356266.1 6689285.1 23.6))
BATIMENT0000000303962858;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;00;00;6.3;7.4;13.8;19.8;7.7;Cadastre;A 1.0;POLYGON Z ((356496.5 6689313 13.8, 356501.6 6689304.6 13.8, 356497.5 6689302.2 13.8, 356501.9 6689294.8 13.8, 356499.1 6689293.2 13.8, 356489.7 6689309 13.8, 356496.5 6689313 13.8))
BATIMENT0000000303962857;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;13;20;6.3;7.4;13.7;19.9;7.9;Cadastre;A 1.0;POLYGON Z ((356503.4 6689317 13.7, 356506.81139568595 6689311.385411267 13.7, 356506.81139568595 6689305.336815983 13.7, 356505.8 6689307 13.7, 356501.6 6689304.6 13.7, 356496.5 6689313 13.7, 356503.4 6689317 13.7))
BATIMENT0000000303962856;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;13;20;8.1;7.2;15.3;19.9;7.8;Cadastre;A 1.0;POLYGON Z ((356506.81139568595 6689318.949368963 15.3, 356506.81139568595 6689311.385411267 15.3, 356503.4 6689317 15.3, 356506.81139568595 6689318.949368963 15.3))
BATIMENT0000000303962996;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;00;00;20.1;7.0;27.1;27.3;7.6;Cadastre;A 1.0;POLYGON Z ((356469 6689325.1 27.1, 356461.2 6689317.8 27.1, 356445.2 6689336.3 27.1, 356453.1 6689342.8 27.1, 356469 6689325.1 27.1))
BATIMENT0000000303962813;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;13;40;20.0;7.0;27.0;27.6;7.7;Cadastre;A 1.0;POLYGON Z ((356476.8 6689326.2 27, 356471.6 6689335.2 27, 356489.7 6689345.6 27, 356495 6689336.6 27, 356476.8 6689326.2 27))
BATIMENT0000000303963001;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.5;10.2;10.5;7.6;Cadastre;A 1.0;POLYGON Z ((356461.6 6689341.9 10.2, 356457.6 6689346.6 10.2, 356460 6689348.5 10.2, 356464.2 6689344 10.2, 356461.6 6689341.9 10.2))
BATIMENT0000000303962812;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;25;20;20.0;7.0;27.0;27.6;7.8;Cadastre;A 1.0;POLYGON Z ((356506.81139568595 6689355.213143643 27, 356506.81139568595 6689343.378130479 27, 356495 6689336.6 27, 356489.7 6689345.6 27, 356506.81139568595 6689355.213143643 27))
BATIMENT0000000303963002;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.5;10.3;10.5;7.6;Cadastre;A 1.0;POLYGON Z ((356464.2 6689344 10.3, 356460 6689348.5 10.3, 356462.2 6689350.3 10.3, 356466.4 6689345.8 10.3, 356464.2 6689344 10.3))
BATIMENT0000000303963003;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.6;7.5;10.2;10.4;7.7;Cadastre;A 1.0;POLYGON Z ((356466.4 6689345.8 10.2, 356462.2 6689350.3 10.2, 356464.5 6689352.2 10.2, 356468.6 6689347.6 10.2, 356466.4 6689345.8 10.2))
BATIMENT0000000303963004;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.6;7.6;10.2;10.4;7.7;Cadastre;A 1.0;POLYGON Z ((356468.6 6689347.6 10.2, 356464.5 6689352.2 10.2, 356466.7 6689354.1 10.2, 356470.9 6689349.5 10.2, 356468.6 6689347.6 10.2))
BATIMENT0000000303963005;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.6;7.0;11.6;;;Cadastre;A 1.0;POLYGON Z ((356474 6689352.1 11.6, 356470.9 6689349.5 11.6, 356466.7 6689354.1 11.6, 356466.5 6689355 11.6, 356472.9 6689356.6 11.6, 356474 6689352.1 11.6))
BATIMENT0000000303963006;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.6;10.3;10.5;7.8;Cadastre;A 1.0;POLYGON Z ((356472.9 6689356.6 10.3, 356466.5 6689355 10.3, 356465.9 6689357.8 10.3, 356472.3 6689359.3 10.3, 356472.9 6689356.6 10.3))
BATIMENT0000000303963007;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.5;7.6;10.1;10.6;7.9;Cadastre;A 1.0;POLYGON Z ((356472.3 6689359.3 10.1, 356465.9 6689357.8 10.1, 356465.2 6689360.7 10.1, 356471.6 6689362.2 10.1, 356472.3 6689359.3 10.1))
BATIMENT0000000303962998;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.9;7.2;16.1;29.6;8.1;Cadastre;C 0.1;POLYGON Z ((356424.3 6689360.5 16.1, 356424 6689360.1 16.1, 356420.4 6689364.7 16.1, 356420.3 6689365 16.1, 356419.5 6689366 16.1, 356419.1 6689366.7 16.1, 356418.7 6689367.4 16.1, 356418.3 6689368.2 16.1, 356418.1 6689369 16.1, 356417.9 6689369.8 16.1, 356417.7 6689370.7 16.1, 356417.7 6689371.5 16.1, 356417.7 6689372.4 16.1, 356417.8 6689373.2 16.1, 356418 6689374.1 16.1, 356418.2 6689374.9 16.1, 356418.5 6689375.7 16.1, 356418.9 6689376.5 16.1, 356419.4 6689377.2 16.1, 356419.9 6689377.9 16.1, 356420.4 6689378.5 16.1, 356421 6689379.1 16.1, 356421.7 6689379.7 16.1, 356422.4 6689380.1 16.1, 356423.2 6689380.5 16.1, 356423.9 6689380.9 16.1, 356426 6689381.6 16.1, 356425.9 6689382 16.1, 356431.7 6689383.2 16.1, 356431.7 6689383 16.1, 356454.5 6689388 16.1, 356455 6689388.4 16.1, 356455.3 6689388.7 16.1, 356457.9 6689389.2 16.1, 356458.7 6689389.2 16.1, 356460.6 6689380.8 16.1, 356461.2 6689378.2 16.1, 356461.9 6689375.2 16.1, 356462.5 6689372.4 16.1, 356463.2 6689369.4 16.1, 356463.9 6689366.5 16.1, 356464.5 6689363.5 16.1, 356465.2 6689360.7 16.1, 356465.9 6689357.8 16.1, 356466.5 6689355 16.1, 356466.7 6689354.1 16.1, 356464.5 6689352.2 16.1, 356462.2 6689350.3 16.1, 356460 6689348.5 16.1, 356457.6 6689346.6 16.1, 356454.5 6689344 16.1, 356453.1 6689342.8 16.1, 356445.2 6689336.3 16.1, 356424.3 6689360.5 16.1), (356445.8 6689351.6 16.1, 356447.9 6689353.4 16.1, 356448.3 6689353.8 16.1, 356448.7 6689354.3 16.1, 356449.1 6689354.8 16.1, 356449.3 6689355 16.1, 356449.6 6689355.5 16.1, 356449.9 6689355.9 16.1, 356450.2 6689356.2 16.1, 356450.3 6689356.4 16.1, 356450.4 6689356.6 16.1, 356450.5 6689356.8 16.1, 356450.6 6689357 16.1, 356451 6689357.5 16.1, 356451.1 6689357.7 16.1, 356451.2 6689357.9 16.1, 356451.6 6689358.5 16.1, 356452.2 6689359.6 16.1, 356452.6 6689360.5 16.1, 356453.1 6689361.6 16.1, 356453.3 6689362.1 16.1, 356453.4 6689362.3 16.1, 356453.4 6689362.5 16.1, 356453.7 6689363.1 16.1, 356453.7 6689363.3 16.1, 356453.9 6689363.8 16.1, 356454.1 6689364.4 16.1, 356454.2 6689364.6 16.1, 356454.2 6689364.8 16.1, 356454.4 6689365.5 16.1, 356454.4 6689365.9 16.1, 356454.5 6689366.1 16.1, 356454.6 6689366.9 16.1, 356454.6 6689367.1 16.1, 356454.7 6689367.3 16.1, 356454.7 6689367.9 16.1, 356454.7 6689368.1 16.1, 356454.8 6689368.3 16.1, 356454.8 6689368.5 16.1, 356454.8 6689368.7 16.1, 356454.9 6689369.9 16.1, 356454.9 6689370.8 16.1, 356454.9 6689371.8 16.1, 356454.9 6689372.4 16.1, 356454.8 6689373.3 16.1, 356454.7 6689373.5 16.1, 356454.7 6689373.7 16.1, 356454.6 6689374.6 16.1, 356454.5 6689375.1 16.1, 356454.5 6689375.3 16.1, 356454.3 6689376.2 16.1, 356454.3 6689376.6 16.1, 356454.3 6689376.8 16.1, 356454.3 6689377 16.1, 356454.3 6689377.2 16.1, 356454.2 6689377.4 16.1, 356454 6689377.5 16.1, 356434.8 6689373.1 16.1, 356434.9 6689372.6 16.1, 356435 6689372 16.1, 356435 6689371.5 16.1, 356434.9 6689370.9 16.1, 356434.8 6689370.4 16.1, 356434.7 6689369.9 16.1, 356434.5 6689369.3 16.1, 356434.3 6689368.8 16.1, 356434.1 6689368.4 16.1, 356433.8 6689367.9 16.1, 356433.5 6689367.5 16.1, 356433.1 6689367.1 16.1, 356432.7 6689366.7 16.1, 356445.8 6689351.6 16.1))
BATIMENT0000000303963000;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.4;7.5;10.0;13.4;7.9;Cadastre;A 1.0;POLYGON Z ((356471.6 6689362.2 10, 356465.2 6689360.7 10, 356464.5 6689363.5 10, 356470.9 6689365.2 10, 356471.6 6689362.2 10))
BATIMENT0000002275362534;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.0;6.5;;;;Imagerie aérienne;;POLYGON Z ((356350.1 6689352.1 10.5, 356334.7 6689372.1 10.5, 356340.5 6689376.5 10.4, 356355.8 6689356.6 10.2, 356350.1 6689352.1 10.5))
BATIMENT0000000303962863;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;8.4;7.0;15.4;19.7;7.9;Cadastre;A 1.0;POLYGON Z ((356501.5 6689364.3 15.4, 356493.4 6689359.6 15.4, 356490 6689365.5 15.4, 356498.1 6689370.2 15.4, 356501.5 6689364.3 15.4))
BATIMENT0000000303962999;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.6;10.3;12.5;7.9;Cadastre;A 1.0;POLYGON Z ((356470.9 6689365.2 10.3, 356464.5 6689363.5 10.3, 356463.9 6689366.5 10.3, 356470.2 6689368.1 10.3, 356470.9 6689365.2 10.3))
BATIMENT0000000303963008;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.8;7.5;10.4;12.5;8.0;Cadastre;A 1.0;POLYGON Z ((356470.2 6689368.1 10.4, 356463.9 6689366.5 10.4, 356463.2 6689369.4 10.4, 356469.6 6689370.8 10.4, 356470.2 6689368.1 10.4))
BATIMENT0000000303962862;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;10.5;7.6;18.2;20.3;7.9;Cadastre;A 1.0;POLYGON Z ((356486.7 6689371.4 18.2, 356494.8 6689375.9 18.2, 356498.1 6689370.2 18.2, 356490 6689365.5 18.2, 356486.7 6689371.4 18.2))
BATIMENT0000000303963009;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.5;10.3;11.7;8.0;Cadastre;A 1.0;POLYGON Z ((356469.6 6689370.8 10.3, 356463.2 6689369.4 10.3, 356462.5 6689372.4 10.3, 356468.8 6689373.9 10.3, 356469.6 6689370.8 10.3))
BATIMENT0000000303963010;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.6;10.3;11.7;8.0;Cadastre;A 1.0;POLYGON Z ((356468.8 6689373.9 10.3, 356462.5 6689372.4 10.3, 356461.9 6689375.2 10.3, 356468.2 6689376.9 10.3, 356468.8 6689373.9 10.3))
BATIMENT0000000303962861;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;10.4;7.8;18.2;20.4;8.2;Cadastre;A 1.0;POLYGON Z ((356483.4 6689377.2 18.2, 356491.5 6689381.7 18.2, 356494.8 6689375.9 18.2, 356486.7 6689371.4 18.2, 356483.4 6689377.2 18.2))
BATIMENT0000000303963011;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;7.6;10.3;14.5;7.9;Cadastre;A 1.0;POLYGON Z ((356468.2 6689376.9 10.3, 356461.9 6689375.2 10.3, 356461.2 6689378.2 10.3, 356467.5 6689379.8 10.3, 356468.2 6689376.9 10.3))
BATIMENT0000000303963012;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;7.6;12.7;16.2;7.9;Cadastre;;POLYGON Z ((356467.1 6689381.6 12.7, 356467.5 6689379.8 12.7, 356461.2 6689378.2 12.7, 356460.6 6689380.8 12.7, 356466.9 6689382.3 12.7, 356466.9 6689382.1 12.7, 356467.1 6689381.6 12.7))
BATIMENT0000000303962860;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;8.3;7.0;15.3;19.8;8.3;Cadastre;A 1.0;POLYGON Z ((356480 6689383.1 15.3, 356488 6689387.8 15.3, 356491.5 6689381.7 15.3, 356483.4 6689377.2 15.3, 356480 6689383.1 15.3))
BATIMENT0000000303962997;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.9;7.6;13.6;17.7;8.0;Cadastre;A 1.0;POLYGON Z ((356467 6689391.1 13.6, 356469.1 6689382.7 13.6, 356466.9 6689382.1 13.6, 356466.9 6689382.3 13.6, 356460.6 6689380.8 13.6, 356458.7 6689389.2 13.6, 356467 6689391.1 13.6))
BATIMENT0000000303963104;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;7.5;;;;Cadastre;;POLYGON Z ((356318.5 6689409.1 -1000, 356315.8 6689403.3 -1000, 356310.7 6689405.6 -1000, 356313.4 6689411.4 -1000, 356318.5 6689409.1 -1000))
BATIMENT0000000303962745;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;0.0;;;15.3;8.0;23.3;28.3;8.3;Cadastre;C 0.2;POLYGON Z ((356371.5 6689414.4 23.3, 356372.5 6689413.1 23.3, 356371.7 6689412.4 23.3, 356371.4 6689412.7 23.3, 356367.9 6689409.7 23.3, 356368.1 6689409.4 23.3, 356367.2 6689408.5 23.3, 356366.4 6689409.4 23.3, 356364.9 6689408.1 23.3, 356365.7 6689407.3 23.3, 356364.7 6689406.4 23.3, 356364.5 6689406.8 23.3, 356361 6689403.7 23.3, 356361.2 6689403.4 23.3, 356360.3 6689402.6 23.3, 356359.4 6689403.6 23.3, 356359.7 6689403.8 23.3, 356356.7 6689407.4 23.3, 356356.4 6689407.1 23.3, 356355.6 6689408.1 23.3, 356356.4 6689408.8 23.3, 356355.2 6689410.1 23.3, 356354.4 6689409.5 23.3, 356353.6 6689410.4 23.3, 356353.9 6689410.7 23.3, 356350.9 6689414.2 23.3, 356350.6 6689414 23.3, 356349.7 6689414.9 23.3, 356362 6689425.4 23.3, 356371.5 6689414.4 23.3))
BATIMENT0000000303962744;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:23:24;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.8;8.0;14.8;15.2;8.3;Cadastre;A 1.0;POLYGON Z ((356375.9 6689414.3 14.8, 356374.5 6689413.7 14.8, 356373.1 6689414.1 14.8, 356372.4 6689415.2 14.8, 356372.2 6689415 14.8, 356367.6 6689434.8 14.8, 356381.6 6689438 14.8, 356382.7 6689433.5 14.8, 356389.7 6689435.1 14.8, 356391.4 6689427.5 14.8, 356375.9 6689414.3 14.8))
BATIMENT0000000302932638;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.2;7.0;23.2;27.7;7.5;Cadastre;;POLYGON Z ((356250.6 6689296 23.2, 356251.7 6689294 23.2, 356244.4 6689290.3 23.2, 356243.3 6689292.5 23.2, 356250.6 6689296 23.2))
BATIMENT0000000302932640;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;66.0;9.0;00;00;17.1;6.6;23.7;32.9;7.7;Cadastre;C 0.5;POLYGON Z ((356216.3 6689290.1 23.7, 356206 6689284.9 23.7, 356203.5 6689290.2 23.7, 356201.6 6689289.2 23.7, 356188.6 6689315.6 23.7, 356190.4 6689316.6 23.7, 356200 6689321.3 23.7, 356198.6 6689324.2 23.7, 356207.9 6689328.8 23.7, 356208.4 6689327.7 23.7, 356209.3 6689325.8 23.7, 356220.5 6689331.4 23.7, 356219.6 6689333.2 23.7, 356222.8 6689334.8 23.7, 356223.6 6689333 23.7, 356224.7 6689333.7 23.7, 356230.5 6689325.8 23.7, 356229.4 6689325.1 23.7, 356230.8 6689322.5 23.7, 356233.5 6689323.9 23.7, 356234.1 6689322.5 23.7, 356236.1 6689323.5 23.7, 356244 6689313.4 23.7, 356233.9 6689308.5 23.7, 356230.1 6689315.2 23.7, 356231.5 6689315.9 23.7, 356228.7 6689321.6 23.7, 356206.3 6689310.4 23.7, 356216.3 6689290.1 23.7))
BATIMENT0000000302932644;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.2;7.2;24.4;31.0;7.5;Cadastre;;POLYGON Z ((356200 6689321.3 24.4, 356190.4 6689316.6 24.4, 356189 6689319.5 24.4, 356198.6 6689324.2 24.4, 356200 6689321.3 24.4))
BATIMENT0000000302932639;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;22.4;7.0;29.4;32.6;7.0;Cadastre;;POLYGON Z ((356235.1 6689324.7 29.4, 356233.5 6689323.9 29.4, 356230.8 6689322.5 29.4, 356229.4 6689325.1 29.4, 356230.5 6689325.8 29.4, 356224.7 6689333.7 29.4, 356226.8 6689334.7 29.4, 356228.5 6689333.1 29.4, 356231.5 6689329.3 29.4, 356235.1 6689324.7 29.4))
BATIMENT0000000302932641;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.0;7.1;28.1;31.4;7.1;Cadastre;;POLYGON Z ((356219.6 6689333.2 28.1, 356220.5 6689331.4 28.1, 356209.3 6689325.8 28.1, 356208.4 6689327.7 28.1, 356219.6 6689333.2 28.1))
BATIMENT0000000302932607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.1;6.9;25.0;25.4;8.4;Cadastre;;POLYGON Z ((356187.2 6689334.1 25, 356197.1 6689338.9 25, 356198.5 6689336 25, 356187.7 6689330.7 25, 356186.5 6689333.7 25, 356187.2 6689334.1 25))
BATIMENT0000000303962993;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;7.8;12.6;12.6;9.5;Cadastre;;POLYGON Z ((356252.3 6689477.4 12.6, 356241.3 6689470.1 12.6, 356240.5 6689471 12.6, 356232.7 6689464.2 12.6, 356232.4 6689464 12.6, 356232.1 6689463.9 12.6, 356231.8 6689463.8 12.6, 356231.3 6689463.7 12.6, 356231 6689463.7 12.6, 356230.6 6689463.9 12.6, 356230.2 6689464.1 12.6, 356229.8 6689464.4 12.6, 356224.4 6689470.7 12.6, 356224.3 6689470.9 12.6, 356224.1 6689471.1 12.6, 356224 6689471.5 12.6, 356223.9 6689472 12.6, 356223.9 6689472.4 12.6, 356224 6689472.9 12.6, 356224.2 6689473.3 12.6, 356224.4 6689473.5 12.6, 356223.4 6689474.6 12.6, 356241.2 6689490 12.6, 356242.2 6689488.9 12.6, 356245.4 6689491.6 12.6, 356245.9 6689492 12.6, 356246.5 6689492.1 12.6, 356246.9 6689492.1 12.6, 356247.3 6689492 12.6, 356247.8 6689491.8 12.6, 356248.2 6689491.4 12.6, 356249.1 6689490.3 12.6, 356251.1 6689488.1 12.6, 356253.7 6689485.2 12.6, 356253.9 6689484.8 12.6, 356254.1 6689484.2 12.6, 356254.1 6689483.6 12.6, 356253.9 6689483 12.6, 356253.5 6689482.4 12.6, 356250.3 6689479.6 12.6, 356252.3 6689477.4 12.6))
BATIMENT0000000303962992;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.6;8.9;16.6;17.7;10.8;Cadastre;C 0.2;POLYGON Z ((356246.4 6689496.8 16.6, 356242.5 6689495.8 16.6, 356240.9 6689494.8 16.6, 356242.2 6689493.1 16.6, 356242.3 6689492.7 16.6, 356242.4 6689492.3 16.6, 356242.4 6689492 16.6, 356242.3 6689491.6 16.6, 356242.1 6689491.3 16.6, 356241.9 6689491.1 16.6, 356223.2 6689474.9 16.6, 356209 6689462.4 16.6, 356208.6 6689462.1 16.6, 356208.1 6689461.9 16.6, 356207.6 6689461.9 16.6, 356207.1 6689462 16.6, 356206.6 6689462.3 16.6, 356206.3 6689462.7 16.6, 356204.4 6689465 16.6, 356201.2 6689461.9 16.6, 356201.6 6689461.2 16.6, 356201.7 6689460.4 16.6, 356201.6 6689459.7 16.6, 356201.3 6689459 16.6, 356200.7 6689458.5 16.6, 356200 6689458.1 16.6, 356199.3 6689458 16.6, 356198.6 6689458.1 16.6, 356197.9 6689458.5 16.6, 356197.4 6689459 16.6, 356197 6689459.7 16.6, 356196.9 6689460.4 16.6, 356197 6689461.2 16.6, 356197.3 6689461.9 16.6, 356197.7 6689462.2 16.6, 356199.2 6689463.5 16.6, 356187.4 6689477.1 16.6, 356191.1 6689480.3 16.6, 356188.8 6689482.9 16.6, 356188.6 6689483.3 16.6, 356188.5 6689483.7 16.6, 356188.5 6689484.2 16.6, 356188.6 6689484.7 16.6, 356188.9 6689485 16.6, 356222.3 6689514 16.6, 356222.6 6689514.2 16.6, 356223.1 6689514.3 16.6, 356223.6 6689514.3 16.6, 356224 6689514.1 16.6, 356224.4 6689513.8 16.6, 356226.5 6689511.3 16.6, 356228.7 6689513.3 16.6, 356228.3 6689513.8 16.6, 356228.1 6689514 16.6, 356228.1 6689514.4 16.6, 356228.1 6689514.8 16.6, 356228.2 6689515 16.6, 356228.4 6689515.3 16.6, 356228.5 6689515.4 16.6, 356232.4 6689518.7 16.6, 356231.8 6689519.3 16.6, 356231.6 6689519.2 16.6, 356230.9 6689518.9 16.6, 356230.2 6689518.8 16.6, 356229.5 6689519 16.6, 356228.9 6689519.4 16.6, 356228.4 6689519.9 16.6, 356228.1 6689520.6 16.6, 356228 6689521.3 16.6, 356228.2 6689522 16.6, 356228.6 6689522.6 16.6, 356229.1 6689523.1 16.6, 356229.8 6689523.4 16.6, 356230.5 6689523.5 16.6, 356231.2 6689523.3 16.6, 356231.8 6689523 16.6, 356232.3 6689522.4 16.6, 356232.9 6689522.9 16.6, 356232.7 6689523.3 16.6, 356232.6 6689523.5 16.6, 356232.6 6689523.6 16.6, 356232.7 6689523.7 16.6, 356232.8 6689523.8 16.6, 356232.8 6689523.9 16.6, 356234.3 6689524.9 16.6, 356250.4 6689499.6 16.6, 356246.4 6689496.8 16.6))
BATIMENT0000000303962994;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;8.6;12.0;12.6;9.1;Cadastre;;POLYGON Z ((356286.1 6689510.8 12, 356289.6 6689505.6 12, 356282.3 6689500.7 12, 356278.8 6689505.9 12, 356286.1 6689510.8 12))
BATIMENT0000000303962995;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.2;7.9;18.1;18.2;9.7;Cadastre;C 0.1;POLYGON Z ((356300.3 6689522 18.1, 356300.3 6689521.5 18.1, 356300.1 6689521 18.1, 356299.9 6689520.7 18.1, 356299.5 6689520.4 18.1, 356298.5 6689520 18.1, 356259.2 6689502.2 18.1, 356258.8 6689502 18.1, 356258.4 6689502.1 18.1, 356258 6689502.2 18.1, 356257.6 6689502.5 18.1, 356257.4 6689502.9 18.1, 356256.3 6689505.2 18.1, 356255.1 6689504.5 18.1, 356252.7 6689501.1 18.1, 356250.4 6689499.6 18.1, 356234.3 6689524.9 18.1, 356236.7 6689526.5 18.1, 356236.9 6689526.6 18.1, 356237.2 6689526.7 18.1, 356237.4 6689526.7 18.1, 356237.7 6689526.6 18.1, 356238 6689526.6 18.1, 356238.3 6689526.5 18.1, 356240.1 6689527.4 18.1, 356240.3 6689527.8 18.1, 356240.6 6689528.2 18.1, 356241 6689528.4 18.1, 356241.5 6689528.5 18.1, 356241.9 6689528.5 18.1, 356242.4 6689528.3 18.1, 356242.7 6689528 18.1, 356243 6689527.6 18.1, 356243.1 6689527.2 18.1, 356243.1 6689526.7 18.1, 356242.9 6689526.3 18.1, 356242.6 6689525.9 18.1, 356242.3 6689525.7 18.1, 356242.8 6689524.6 18.1, 356243.2 6689524.8 18.1, 356243.3 6689524.8 18.1, 356243.5 6689524.8 18.1, 356243.7 6689524.7 18.1, 356244 6689524.5 18.1, 356244.2 6689524.4 18.1, 356244.4 6689524.2 18.1, 356244.5 6689524 18.1, 356244.7 6689523.4 18.1, 356247.4 6689524.6 18.1, 356246 6689527.7 18.1, 356245.8 6689528.1 18.1, 356245.8 6689528.6 18.1, 356246 6689529 18.1, 356246.3 6689529.4 18.1, 356246.7 6689529.7 18.1, 356278.1 6689544 18.1, 356278.5 6689544.1 18.1, 356279 6689544 18.1, 356279.4 6689543.9 18.1, 356279.8 6689543.6 18.1, 356280 6689543.2 18.1, 356280.5 6689541.9 18.1, 356289.5 6689545.9 18.1, 356290.4 6689544 18.1, 356294.3 6689545.8 18.1, 356294.1 6689546.5 18.1, 356294.1 6689547.3 18.1, 356294.4 6689548 18.1, 356294.9 6689548.6 18.1, 356295.5 6689549 18.1, 356296.2 6689549.3 18.1, 356297 6689549.2 18.1, 356297.7 6689549 18.1, 356298.3 6689548.5 18.1, 356298.8 6689547.9 18.1, 356299 6689547.2 18.1, 356298.9 6689546.4 18.1, 356298.7 6689545.7 18.1, 356298.2 6689545.1 18.1, 356297.6 6689544.6 18.1, 356295.8 6689543.8 18.1, 356303.2 6689527.6 18.1, 356298.7 6689525.6 18.1, 356300.2 6689522.4 18.1, 356300.3 6689522 18.1))
BATIMENT0000000302932606;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;8.1;14.2;18.2;8.8;Cadastre;;POLYGON Z ((356136.2 6689312.7 14.2, 356134.6 6689315.9 14.2, 356141.2 6689319.1 14.2, 356142.7 6689315.9 14.2, 356136.2 6689312.7 14.2))
BATIMENT0000000302932678;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.1;8.0;19.1;25.3;9.0;Cadastre;C 0.2;POLYGON Z ((356117.4 6689360.3 19.1, 356118.9 6689360.6 19.1, 356120.1 6689361.5 19.1, 356121.2 6689363.1 19.1, 356121.5 6689365.5 19.1, 356121.2 6689366.8 19.1, 356120.2 6689368.1 19.1, 356121.1 6689370.5 19.1, 356122.7 6689371 19.1, 356131 6689372.7 19.1, 356134.2 6689373.1 19.1, 356139.9 6689373.5 19.1, 356145.6 6689373.7 19.1, 356150.3 6689373.4 19.1, 356152.1 6689373.2 19.1, 356158.7 6689372.3 19.1, 356162.2 6689371.6 19.1, 356166.7 6689370.5 19.1, 356170.1 6689369.3 19.1, 356174.5 6689367.5 19.1, 356178.5 6689365.9 19.1, 356179.2 6689365.5 19.1, 356179.4 6689365.4 19.1, 356180 6689365.1 19.1, 356182.3 6689363.9 19.1, 356182.5 6689363.9 19.1, 356182.9 6689363.7 19.1, 356183.1 6689363.6 19.1, 356183.3 6689363.5 19.1, 356183.9 6689363.2 19.1, 356184.1 6689363.1 19.1, 356184.3 6689363 19.1, 356184.5 6689362.9 19.1, 356184.9 6689362.7 19.1, 356185.5 6689362.4 19.1, 356186.2 6689362.1 19.1, 356186.5 6689361.9 19.1, 356187.1 6689361.6 19.1, 356187.7 6689361.3 19.1, 356188.3 6689361.1 19.1, 356188.9 6689360.8 19.1, 356189.5 6689360.5 19.1, 356189.8 6689360.3 19.1, 356190.8 6689359.9 19.1, 356191.1 6689359.8 19.1, 356192 6689359.3 19.1, 356192.3 6689359.2 19.1, 356192.9 6689358.9 19.1, 356194.1 6689358.3 19.1, 356194.4 6689358.2 19.1, 356194.7 6689358 19.1, 356196.2 6689357.3 19.1, 356197.4 6689356.6 19.1, 356197.7 6689356.5 19.1, 356198 6689356.3 19.1, 356198.5 6689356 19.1, 356199.1 6689355.7 19.1, 356199.4 6689355.6 19.1, 356200.2 6689355.1 19.1, 356200.5 6689354.9 19.1, 356200.8 6689354.8 19.1, 356201 6689354.6 19.1, 356201.6 6689354.3 19.1, 356202.4 6689353.8 19.1, 356202.7 6689353.7 19.1, 356203.5 6689353.2 19.1, 356203.8 6689353 19.1, 356204.3 6689352.7 19.1, 356205.1 6689352.2 19.1, 356205.4 6689352 19.1, 356205.9 6689351.7 19.1, 356207 6689351 19.1, 356207.3 6689350.8 19.1, 356207.6 6689350.6 19.1, 356209.1 6689349.6 19.1, 356209.6 6689349.3 19.1, 356209.8 6689349.1 19.1, 356210 6689349 19.1, 356210.4 6689348.7 19.1, 356210.8 6689348.4 19.1, 356211.5 6689347.9 19.1, 356211.7 6689347.8 19.1, 356211.9 6689347.6 19.1, 356212.3 6689347.3 19.1, 356212.6 6689347.2 19.1, 356213 6689346.8 19.1, 356213.2 6689346.7 19.1, 356197.1 6689338.9 19.1, 356187.2 6689334.1 19.1, 356186.5 6689333.7 19.1, 356176.6 6689328.9 19.1, 356147.5 6689314.9 19.1, 356146.2 6689317.6 19.1, 356142.7 6689315.9 19.1, 356141.2 6689319.1 19.1, 356134.6 6689315.9 19.1, 356114.3 6689357.6 19.1, 356115.6 6689360.6 19.1, 356117.4 6689360.3 19.1))
BATIMENT0000000302932677;Tour, donjon;Indifférencié;;Non;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.9;5.9;20.8;;;Cadastre;;POLYGON Z ((356113.6 6689364.2 20.8, 356113.6 6689364.8 20.8, 356113.6 6689365.3 20.8, 356113.6 6689365.5 20.8, 356113.7 6689365.7 20.8, 356113.7 6689365.9 20.8, 356113.8 6689366.1 20.8, 356113.9 6689366.3 20.8, 356114 6689366.5 20.8, 356114.2 6689366.9 20.8, 356114.3 6689367 20.8, 356114.4 6689367.2 20.8, 356114.6 6689367.3 20.8, 356114.7 6689367.5 20.8, 356115 6689367.7 20.8, 356115.4 6689368 20.8, 356115.7 6689368.2 20.8, 356116.1 6689368.3 20.8, 356116.3 6689368.4 20.8, 356116.7 6689368.5 20.8, 356116.9 6689368.5 20.8, 356117.3 6689368.6 20.8, 356117.7 6689368.5 20.8, 356120.2 6689368.1 20.8, 356121.2 6689366.8 20.8, 356121.5 6689365.5 20.8, 356121.2 6689363.1 20.8, 356120.1 6689361.5 20.8, 356118.9 6689360.6 20.8, 356117.4 6689360.3 20.8, 356115.6 6689360.6 20.8, 356115.6 6689360.8 20.8, 356115.5 6689361 20.8, 356115.3 6689361.2 20.8, 356115.1 6689361.3 20.8, 356114.6 6689361.6 20.8, 356114.4 6689361.7 20.8, 356114.2 6689361.9 20.8, 356114 6689362.2 20.8, 356113.9 6689362.6 20.8, 356113.7 6689363 20.8, 356113.6 6689363.6 20.8, 356113.6 6689364 20.8, 356113.6 6689364.2 20.8))
BATIMENT0000000302932666;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;10.0;14.0;14.4;11.3;Cadastre;;POLYGON Z ((356060.7 6689444.6 14, 356060.3 6689442.6 14, 356058.8 6689441.3 14, 356056.9 6689441.1 14, 356055.1 6689442 14, 356054.3 6689443.8 14, 356054.7 6689445.8 14, 356056.2 6689447.1 14, 356058.1 6689447.4 14, 356059.8 6689446.4 14, 356060.7 6689444.6 14))
BATIMENT0000000303963103;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.2;6.2;8.4;11.2;9.5;Cadastre;;POLYGON Z ((356105.4 6689449.3 8.4, 356103.6 6689446.9 8.4, 356100.4 6689449.4 8.4, 356102.2 6689451.7 8.4, 356105.4 6689449.3 8.4))
BATIMENT0000000303963157;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;5.1;7.8;12.9;17.2;8.6;Cadastre;C 0.1;POLYGON Z ((356087.6 6689510.5 12.9, 356090.4 6689504.8 12.9, 356076.8 6689497.7 12.9, 356073.2 6689498.4 12.9, 356071.2 6689502.2 12.9, 356087.6 6689510.5 12.9))
BATIMENT0000000303963158;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;12;23;18.2;8.2;26.5;27.9;9.3;Cadastre;C 0.9;POLYGON Z ((356074.9 6689518.9 26.5, 356076.1 6689516.4 26.5, 356080.8 6689518.8 26.5, 356079.9 6689519.1 26.5, 356079.2 6689520.9 26.5, 356082 6689522.3 26.5, 356087.6 6689510.5 26.5, 356071.2 6689502.2 26.5, 356064.9 6689514.8 26.5, 356074.9 6689518.9 26.5))
BATIMENT0000000303963019;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;12;20;13.4;7.2;20.7;28.3;9.3;Cadastre;A 1.0;POLYGON Z ((356103.8 6689513.8 20.7, 356103.1 6689511.2 20.7, 356090.4 6689504.8 20.7, 356087.6 6689510.5 20.7, 356082 6689522.3 20.7, 356081.1 6689524.8 20.7, 356090 6689528.1 20.7, 356097.1 6689529.8 20.7, 356103.8 6689513.8 20.7))
BATIMENT0000000303963018;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;35;20;15.5;8.2;23.7;25.7;9.3;Cadastre;A 1.0;POLYGON Z ((356073.1 6689542.1 23.7, 356080.3 6689528.3 23.7, 356081.1 6689524.8 23.7, 356082 6689522.3 23.7, 356079.2 6689520.9 23.7, 356074.9 6689518.9 23.7, 356064.9 6689514.8 23.7, 356055.7 6689533.2 23.7, 356073.1 6689542.1 23.7), (356072.6 6689522.1 23.7, 356076.1 6689523.8 23.7, 356072.8 6689532.1 23.7, 356069.2 6689530.7 23.7, 356072.6 6689522.1 23.7))
BATIMENT0000000303963065;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;19.2;7.0;26.2;27.2;7.7;Cadastre;A 1.0;POLYGON Z ((356105.6 6689515.1 26.2, 356101.3 6689526.4 26.2, 356123.6 6689537.8 26.2, 356119.6 6689545.5 26.2, 356120.9 6689546.1 26.2, 356120 6689547.9 26.2, 356098.3 6689536.8 26.2, 356093.2 6689550.6 26.2, 356113.5 6689560.6 26.2, 356114.2 6689559.2 26.2, 356114.3 6689559.3 26.2, 356115.4 6689554.2 26.2, 356124.5 6689558.5 26.2, 356127.7 6689559.9 26.2, 356138.3 6689534 26.2, 356136.8 6689533.3 26.2, 356137.5 6689531.5 26.2, 356135.9 6689530.6 26.2, 356136.6 6689528.8 26.2, 356108.2 6689514.2 26.2, 356105.6 6689515.1 26.2))
BATIMENT0000000302930314;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;7.5;16.2;19.2;7.7;Cadastre;;POLYGON Z ((355890.2 6689097.2 16.2, 355888.6 6689099.5 16.2, 355890.7 6689101 16.2, 355892.4 6689098.8 16.2, 355890.2 6689097.2 16.2))
BATIMENT0000000302930317;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.2;12.4;13.7;7.6;Cadastre;;POLYGON Z ((355834.7 6689098.5 12.4, 355834.6 6689098.5 12.4, 355839 6689102.1 12.4, 355840.6 6689100.3 12.4, 355836 6689096.7 12.4, 355834.7 6689098.5 12.4))
BATIMENT0000000302930306;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;12.8;5.7;18.5;22.5;7.3;Cadastre;A 1.0;POLYGON Z ((355815.4 6689107 18.5, 355819.8 6689108 18.5, 355828.8 6689114.9 18.5, 355835.4 6689106.7 18.5, 355827.4 6689100.7 18.5, 355823.2 6689097.5 18.5, 355821.8 6689096.4 18.5, 355816.2 6689106.1 18.5, 355816 6689105.9 18.5, 355815.4 6689107 18.5))
BATIMENT0000000302930327;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.0;7.5;15.5;17.5;7.7;Cadastre;;POLYGON Z ((355902.3 6689106.2 15.5, 355900.4 6689104.7 15.5, 355899.3 6689106.3 15.5, 355901.2 6689107.8 15.5, 355902.3 6689106.2 15.5))
BATIMENT0000000302930328;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.0;7.5;17.6;17.8;7.7;Cadastre;;POLYGON Z ((355889.1 6689113.6 17.6, 355889.9 6689112.4 17.6, 355887.8 6689110.9 17.6, 355887 6689112 17.6, 355889.1 6689113.6 17.6))
BATIMENT0000000302930316;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.5;5.7;18.2;19.0;7.0;Cadastre;;POLYGON Z ((355832.1 6689115.9 18.2, 355831.4 6689116.9 18.2, 355832 6689117.2 18.2, 355834 6689118.8 18.2, 355834.7 6689117.8 18.2, 355832.7 6689116.3 18.2, 355832.1 6689115.9 18.2))
BATIMENT0000000302930322;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.0;5.9;17.9;18.0;7.1;Cadastre;;POLYGON Z ((355845.8 6689127.6 17.9, 355846.5 6689126.8 17.9, 355844 6689124.9 17.9, 355843.3 6689125.7 17.9, 355845.8 6689127.6 17.9))
BATIMENT0000000302930785;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;00;00;6.9;7.0;13.9;16.3;7.6;Cadastre;C 0.4;POLYGON Z ((355898.6 6689129.7 13.9, 355893 6689140.8 13.9, 355898.7 6689144.1 13.9, 355900.6 6689140.9 13.9, 355916.8 6689150.2 13.9, 355921.4 6689142.5 13.9, 355898.6 6689129.7 13.9))
BATIMENT0000000302930323;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.2;5.8;18.0;18.2;7.1;Cadastre;;POLYGON Z ((355867.2 6689143.6 18, 355867.8 6689142.8 18, 355865.6 6689141.1 18, 355865 6689142 18, 355867.2 6689143.6 18))
BATIMENT0000000302931118;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.1;6.9;16.0;;;Cadastre;C 0.3;POLYGON Z ((355844 6689138.8 16, 355837.3 6689148.9 16, 355856.5 6689163.3 16, 355857.3 6689162.1 16, 355863.3 6689153.2 16, 355844 6689138.8 16))
BATIMENT0000000302930789;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.1;6.4;10.6;13.5;6.9;Cadastre;A 1.0;POLYGON Z ((355951.7 6689143.5 10.6, 355953.1 6689141.4 10.6, 355959.1 6689131.2 10.6, 355946.1 6689123.4 10.6, 355943.3 6689128.1 10.6, 355940.1 6689126.2 10.6, 355942.9 6689121.5 10.6, 355940.6 6689120.2 10.6, 355933.3 6689132.5 10.6, 355951.7 6689143.5 10.6))
BATIMENT0000000302930790;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;12;20;6.0;6.9;12.9;15.3;6.9;Cadastre;C 0.3;POLYGON Z ((355933.3 6689132.5 12.9, 355928.9 6689129.9 12.9, 355923.3 6689139.2 12.9, 355928.6 6689142.4 12.9, 355930.9 6689138.4 12.9, 355933.9 6689140.3 12.9, 355932.8 6689142.1 12.9, 355946.9 6689150.8 12.9, 355951.7 6689143.5 12.9, 355933.3 6689132.5 12.9))
BATIMENT0000000302930787;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;6.7;10.2;14.2;6.9;Cadastre;;POLYGON Z ((355914.2 6689149.7 10.2, 355912.3 6689152.9 10.2, 355914.4 6689154.1 10.2, 355916.1 6689151.4 10.2, 355916.4 6689151 10.2, 355914.2 6689149.7 10.2))
BATIMENT0000000302930786;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;;;9.9;6.7;16.6;19.1;6.9;Cadastre;C 0.4;POLYGON Z ((355916.4 6689151 16.6, 355916.1 6689151.4 16.6, 355937 6689165.5 16.6, 355941.5 6689158.8 16.6, 355942.9 6689156.7 16.6, 355921.5 6689142.3 16.6, 355921.4 6689142.5 16.6, 355916.8 6689150.2 16.6, 355916.4 6689151 16.6))
BATIMENT0000000302930788;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.7;7.3;15.0;;;Cadastre;A 1.0;POLYGON Z ((355946.9 6689162.3 15, 355949.3 6689164 15, 355951.4 6689165.4 15, 355951.3 6689165.5 15, 355953.8 6689167.2 15, 355956 6689168.7 15, 355967.5 6689149.8 15, 355953.1 6689141.4 15, 355951.7 6689143.5 15, 355946.9 6689150.8 15, 355942.9 6689156.7 15, 355941.5 6689158.8 15, 355946.9 6689162.3 15))
BATIMENT0000000302931741;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.2;6.2;12.5;17.4;7.4;Cadastre;A 1.0;POLYGON Z ((355964.4 6689165 12.5, 355966.9 6689166.4 12.5, 355966.9 6689166.2 12.5, 355973.8 6689170.5 12.5, 355973.7 6689170.7 12.5, 355976.1 6689172.1 12.5, 355976.2 6689173.1 12.5, 355976.9 6689173.5 12.5, 355977 6689173.5 12.5, 355977.5 6689173.8 12.5, 355985.2 6689178.3 12.5, 355985.3 6689178.1 12.5, 355990.5 6689169.9 12.5, 355990.9 6689169.2 12.5, 355998.8 6689156.8 12.5, 356000 6689154.9 12.5, 356000.2 6689154.6 12.5, 355978.3 6689141.8 12.5, 355964.4 6689165 12.5))
BATIMENT0000000302930784;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.8;7.0;11.8;12.2;7.2;Cadastre;C 0.2;POLYGON Z ((355931.7 6689164.9 11.8, 355930.9 6689166 11.8, 355929.9 6689165.4 11.8, 355927.9 6689168.3 11.8, 355928.9 6689168.9 11.8, 355928.1 6689170 11.8, 355931.7 6689172.5 11.8, 355935.2 6689167.3 11.8, 355931.7 6689164.9 11.8))
BATIMENT0000000302930779;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;6.8;9.6;11.0;7.2;Cadastre;;POLYGON Z ((355923.7 6689171.6 9.6, 355925.4 6689169.1 9.6, 355922.1 6689166.8 9.6, 355920.4 6689169.3 9.6, 355923.7 6689171.6 9.6))
BATIMENT0000000302930780;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;3.0;10;20;6.3;7.0;13.3;15.5;7.2;Cadastre;C 0.6;POLYGON Z ((355914.3 6689177.4 13.3, 355914.1 6689177.7 13.3, 355912.9 6689179.4 13.3, 355922.6 6689186 13.3, 355923.4 6689184.9 13.3, 355929.7 6689175.6 13.3, 355923.7 6689171.6 13.3, 355920.4 6689169.3 13.3, 355912.1 6689163.7 13.3, 355906.6 6689172.2 13.3, 355909.7 6689174.5 13.3, 355912.6 6689170.7 13.3, 355919.5 6689175.5 13.3, 355918 6689177.7 13.3, 355918.5 6689178.1 13.3, 355921.1 6689179.9 13.3, 355920.1 6689181.3 13.3, 355917.5 6689179.5 13.3, 355914.3 6689177.4 13.3))
BATIMENT0000000302931742;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;00;00;14.1;6.7;20.8;24.1;7.4;Cadastre;C 0.8;POLYGON Z ((355956.1 6689183.8 20.8, 355964.3 6689188.4 20.8, 355967.8 6689190.4 20.8, 355968.3 6689190.7 20.8, 355974.2 6689180.9 20.8, 355973.4 6689180.5 20.8, 355977.5 6689173.8 20.8, 355977 6689173.5 20.8, 355976.9 6689173.5 20.8, 355976.2 6689173.1 20.8, 355976.1 6689172.1 20.8, 355973.7 6689170.7 20.8, 355973.8 6689170.5 20.8, 355966.9 6689166.2 20.8, 355966.9 6689166.4 20.8, 355956.1 6689183.8 20.8))
BATIMENT0000000302932562;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;11.1;7.0;18.1;;;Cadastre;A 1.0;POLYGON Z ((356014.8 6689103 18.1, 356015.3 6689102.2 18.1, 356016.6 6689100.4 18.1, 356018.6 6689101.5 18.1, 356019.3 6689101.9 18.1, 356019.4 6689101.8 18.1, 356019.1 6689101.6 18.1, 356022.6 6689095.9 18.1, 356010.7 6689088.9 18.1, 356005.5 6689097.6 18.1, 356014.8 6689103 18.1))
BATIMENT0000000302932563;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;6.3;9.8;15.7;7.7;Cadastre;;POLYGON Z ((356017.5 6689103.4 9.8, 356015.3 6689102.2 9.8, 356014.8 6689103 9.8, 356011.1 6689109 9.8, 356008.2 6689113.8 9.8, 356017.8 6689119.3 9.8, 356023 6689110.6 9.8, 356019.1 6689108.4 9.8, 356020.8 6689105.4 9.8, 356018.1 6689103.8 9.8, 356017.5 6689103.4 9.8))
BATIMENT0000000302931817;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.2;6.3;9.5;22.4;8.5;Cadastre;C 0.6;POLYGON Z ((356018.9 6689138 9.5, 356024 6689129.1 9.5, 356030.2 6689118.5 9.5, 356031.1 6689117 9.5, 356038.1 6689104.9 9.5, 356029.9 6689100.2 9.5, 356022.6 6689095.9 9.5, 356019.1 6689101.6 9.5, 356019.4 6689101.8 9.5, 356019.3 6689101.9 9.5, 356021.9 6689103.4 9.5, 356020.8 6689105.4 9.5, 356019.1 6689108.4 9.5, 356023 6689110.6 9.5, 356017.8 6689119.3 9.5, 356008.2 6689113.8 9.5, 356006.8 6689116.2 9.5, 356000.2 6689127.1 9.5, 356018.9 6689138 9.5))
BATIMENT0000000302932565;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;48.0;4.0;00;00;11.8;6.3;18.1;21.1;8.1;Cadastre;C 0.5;POLYGON Z ((356040.6 6689106.4 18.1, 356038.1 6689104.9 18.1, 356031.1 6689117 18.1, 356045.7 6689125.6 18.1, 356051.9 6689129.2 18.1, 356058.9 6689117.1 18.1, 356040.6 6689106.4 18.1))
BATIMENT0000000302931213;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;8.7;6.3;15.0;17.6;6.8;Cadastre;A 1.0;POLYGON Z ((356006.8 6689116.2 15, 355997.5 6689110.7 15, 355997.4 6689110.6 15, 355990.6 6689121.5 15, 356000.2 6689127.1 15, 356006.8 6689116.2 15))
BATIMENT0000000302932564;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;7.5;9.2;22.4;8.5;Cadastre;;POLYGON Z ((356050.2 6689175.4 9.2, 356053.9 6689177.4 9.2, 356060.9 6689165.6 9.2, 356067.7 6689153.9 9.2, 356066 6689152.9 9.2, 356045 6689141 9.2, 356049.6 6689133.1 9.2, 356050.9 6689130.8 9.2, 356030.2 6689118.5 9.2, 356024 6689129.1 9.2, 356018.9 6689138 9.2, 356010.4 6689152.5 9.2, 356026 6689161.5 9.2, 356026.6 6689161.8 9.2, 356031.3 6689164.5 9.2, 356033.1 6689165.6 9.2, 356050.2 6689175.4 9.2))
BATIMENT0000000302931740;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:56:48;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;6.0;01;02;16.2;7.0;23.2;26.3;7.6;Cadastre;C 0.1;POLYGON Z ((355998.8 6689156.8 23.2, 355990.9 6689169.2 23.2, 355990.5 6689169.9 23.2, 355996.3 6689173.5 23.2, 356001.5 6689178.5 23.2, 356002.3 6689177 23.2, 356003.6 6689174.9 23.2, 356004.5 6689175.4 23.2, 356003.3 6689177.6 23.2, 356003.2 6689177.8 23.2, 356003.2 6689177.9 23.2, 356003.2 6689178.2 23.2, 356003.2 6689178.3 23.2, 356003.2 6689178.6 23.2, 356003.3 6689178.8 23.2, 356003.3 6689178.9 23.2, 356003.4 6689179.2 23.2, 356003.6 6689179.4 23.2, 356003.8 6689179.6 23.2, 356003.8 6689179.7 23.2, 356003.9 6689179.8 23.2, 356004 6689179.8 23.2, 356004.2 6689179.9 23.2, 356004.3 6689180 23.2, 356004.4 6689180 23.2, 356004.6 6689180.1 23.2, 356004.8 6689180.1 23.2, 356005 6689180.2 23.2, 356005.3 6689180.2 23.2, 356005.4 6689180.2 23.2, 356005.8 6689180.1 23.2, 356005.9 6689180 23.2, 356006.2 6689179.9 23.2, 356006.3 6689179.8 23.2, 356006.5 6689179.7 23.2, 356006.6 6689179.6 23.2, 356007.4 6689178.2 23.2, 356009 6689179.1 23.2, 356008.1 6689180.5 23.2, 356013.4 6689183.7 23.2, 356013.8 6689183 23.2, 356014.3 6689182.1 23.2, 356016.6 6689178.4 23.2, 356020.9 6689171.3 23.2, 356021.4 6689170.4 23.2, 355998.8 6689156.8 23.2))
BATIMENT0000000302932576;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.7;22.2;;;Cadastre;;POLYGON Z ((356003.5 6689180.5 22.2, 356004 6689179.8 22.2, 356003.9 6689179.8 22.2, 356003.8 6689179.7 22.2, 356003.8 6689179.6 22.2, 356003.6 6689179.4 22.2, 356003.4 6689179.2 22.2, 356003.3 6689178.9 22.2, 356003.3 6689178.8 22.2, 356003.2 6689178.6 22.2, 356003.2 6689178.3 22.2, 356003.2 6689178.2 22.2, 356003.2 6689177.9 22.2, 356003.2 6689177.8 22.2, 356003.3 6689177.6 22.2, 356004.5 6689175.4 22.2, 356003.6 6689174.9 22.2, 356002.3 6689177 22.2, 356001.5 6689178.5 22.2, 356003.5 6689180.5 22.2))
BATIMENT0000000302931739;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;56.0;5.0;00;00;13.7;7.1;20.8;24.1;7.8;Cadastre;C 0.6;POLYGON Z ((355995.2 6689213.9 20.8, 355991.9 6689219.5 20.8, 355988.9 6689224.5 20.8, 355988.7 6689224.8 20.8, 356008.6 6689235.6 20.8, 356012.6 6689237.8 20.8, 356012.9 6689238 20.8, 356017.9 6689240.6 20.8, 356024.5 6689229.1 20.8, 356023.2 6689228.4 20.8, 356033.8 6689209.8 20.8, 356039.9 6689199.1 20.8, 356041.3 6689199.8 20.8, 356047.7 6689188.7 20.8, 356038.7 6689183.8 20.8, 356039.8 6689182.1 20.8, 356020.9 6689171.3 20.8, 356016.6 6689178.4 20.8, 356014.3 6689182.1 20.8, 356013.8 6689183 20.8, 356019.8 6689186.3 20.8, 356019.3 6689187.3 20.8, 356027.3 6689191.6 20.8, 356027.6 6689191.3 20.8, 356028.9 6689192 20.8, 356027.5 6689194.4 20.8, 356027.2 6689194.3 20.8, 356021.5 6689204.2 20.8, 356017.7 6689210.9 20.8, 356014.4 6689216.5 20.8, 356015.6 6689217.2 20.8, 356013.3 6689221.3 20.8, 355999.8 6689214.1 20.8, 356000.9 6689212.2 20.8, 355997.3 6689210.4 20.8, 355995.2 6689213.9 20.8))
BATIMENT0000000302932575;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;7.2;14.0;16.7;7.6;Cadastre;;POLYGON Z ((356015.9 6689209.9 14, 356017.7 6689210.9 14, 356021.5 6689204.2 14, 356019.7 6689203.2 14, 356015.9 6689209.9 14))
BATIMENT0000000302930782;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.1;7.0;13.1;13.6;7.3;Cadastre;A 0.9;POLYGON Z ((355932.9 6689192 13.1, 355938.7 6689190.9 13.1, 355948.1 6689175.5 13.1, 355935.4 6689167 13.1, 355935.2 6689167.3 13.1, 355931.7 6689172.5 13.1, 355929.7 6689175.6 13.1, 355923.4 6689184.9 13.1, 355923.6 6689185 13.1, 355932.9 6689192 13.1))
BATIMENT0000000302930781;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.6;11.0;13.0;7.0;Cadastre;;POLYGON Z ((355917.5 6689179.5 11, 355920.1 6689181.3 11, 355921.1 6689179.9 11, 355918.5 6689178.1 11, 355917.5 6689179.5 11))
BATIMENT0000000302930783;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.0;7.0;13.0;13.7;7.1;Cadastre;A 0.9;POLYGON Z ((355922.6 6689186 13, 355922.8 6689186.2 13, 355923.6 6689185 13, 355923.4 6689184.9 13, 355922.6 6689186 13))
BATIMENT0000000302931744;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;6.9;13.5;20.7;7.4;Cadastre;;POLYGON Z ((355966.4 6689192.8 13.5, 355969.9 6689194.8 13.5, 355970.4 6689196 13.5, 355968.7 6689198.7 13.5, 355971.3 6689200.2 13.5, 355974.9 6689194.5 13.5, 355968.3 6689190.7 13.5, 355967.8 6689190.4 13.5, 355966.4 6689192.8 13.5))
BATIMENT0000000302931743;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;35;20;14.3;6.8;21.2;23.2;7.4;Cadastre;C 0.9;POLYGON Z ((355947.8 6689197.4 21.2, 355949.3 6689203.3 21.2, 355964.4 6689211.5 21.2, 355969.2 6689203.6 21.2, 355964.9 6689201.4 21.2, 355964.4 6689202.2 21.2, 355957 6689198.1 21.2, 355961.5 6689190.6 21.2, 355962.5 6689191.2 21.2, 355964.3 6689188.4 21.2, 355956.1 6689183.8 21.2, 355947.8 6689197.4 21.2))
BATIMENT0000000302931745;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.0;6.7;14.7;19.0;7.2;Cadastre;A 1.0;POLYGON Z ((355982.2 6689195.2 14.7, 355976.7 6689191.8 14.7, 355976.7 6689191.7 14.7, 355974.9 6689194.5 14.7, 355971.3 6689200.2 14.7, 355970.6 6689201.4 14.7, 355976.3 6689204.4 14.7, 355982.2 6689195.2 14.7))
BATIMENT0000000302931111;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.6;6.8;22.4;23.0;7.9;Cadastre;C 0.2;POLYGON Z ((355909.1 6689232.5 22.4, 355914.9 6689231.2 22.4, 355929.2 6689207.8 22.4, 355928 6689201.8 22.4, 355923.3 6689198.2 22.4, 355917.6 6689207.2 22.4, 355909.9 6689219.6 22.4, 355903.9 6689229 22.4, 355909.1 6689232.5 22.4))
BATIMENT0000000302931613;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;36.0;6.0;00;00;13.7;7.0;20.7;24.9;7.4;Cadastre;A 1.0;POLYGON Z ((355926.2 6689229.1 20.7, 355928.6 6689230.7 20.7, 355928.5 6689231 20.7, 355931.9 6689233.3 20.7, 355932 6689233.1 20.7, 355933.7 6689230.8 20.7, 355934.5 6689229.8 20.7, 355935.5 6689230.5 20.7, 355935.7 6689230.2 20.7, 355936.6 6689228.7 20.7, 355941 6689221.8 20.7, 355944.4 6689220.9 20.7, 355955.3 6689227.5 20.7, 355959.8 6689220.1 20.7, 355949 6689214.1 20.7, 355946.3 6689212.6 20.7, 355944.9 6689211.9 20.7, 355939.1 6689213.4 20.7, 355935 6689214.6 20.7, 355926.2 6689229.1 20.7))
BATIMENT0000000302931609;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;00;00;11.0;7.0;18.0;21.0;7.2;Cadastre;C 0.9;POLYGON Z ((355959.8 6689220.1 18, 355955.3 6689227.5 18, 355955.1 6689227.8 18, 355965.6 6689233.5 18, 355964.9 6689234.9 18, 355968.5 6689236.8 18, 355969.2 6689235.5 18, 355972.8 6689237.4 18, 355977.5 6689229.8 18, 355959.8 6689220.1 18))
BATIMENT0000000302931612;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.3;7.0;18.3;19.2;7.0;Cadastre;;POLYGON Z ((355954.1 6689229.4 18.3, 355955.2 6689230 18.3, 355956 6689228.8 18.3, 355954.9 6689228.2 18.3, 355954.1 6689229.4 18.3))
BATIMENT0000000302931738;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.7;6.7;19.4;22.5;7.8;Cadastre;A 1.0;POLYGON Z ((355976.3 6689218 19.4, 355988.3 6689224.6 19.4, 355988.7 6689224.8 19.4, 355988.9 6689224.5 19.4, 355991.9 6689219.5 19.4, 355995.2 6689213.9 19.4, 355997.3 6689210.4 19.4, 355999.3 6689207.1 19.4, 356002.8 6689201.3 19.4, 355991.5 6689194.3 19.4, 355976.3 6689218 19.4))
BATIMENT0000000302931737;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;7.1;12.0;15.7;7.7;Cadastre;;POLYGON Z ((355997.3 6689210.4 12, 356000.9 6689212.2 12, 356002.7 6689208.9 12, 355999.3 6689207.1 12, 355997.3 6689210.4 12))
BATIMENT0000000302932574;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.4;7.8;19.2;;;Cadastre;;POLYGON Z ((356033.8 6689209.8 19.2, 356023.2 6689228.4 19.2, 356024.5 6689229.1 19.2, 356035.1 6689210.6 19.2, 356041.3 6689199.8 19.2, 356039.9 6689199.1 19.2, 356033.8 6689209.8 19.2))
BATIMENT0000000302932667;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;7.1;15.7;18.2;7.5;Cadastre;;POLYGON Z ((356046.1 6689218.3 15.7, 356035.1 6689237.3 15.7, 356035.4 6689237.5 15.7, 356036.4 6689238.1 15.7, 356053.4 6689208.5 15.7, 356052.1 6689207.8 15.7, 356046.1 6689218.3 15.7))
BATIMENT0000000302931616;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;11.2;7.1;18.3;20.7;7.4;Cadastre;A 1.0;POLYGON Z ((355983.9 6689233.2 18.3, 355976.3 6689245.3 18.3, 355978.8 6689246.6 18.3, 355981 6689243 18.3, 355984.5 6689245 18.3, 355982.4 6689248.6 18.3, 355991.3 6689253.5 18.3, 355992.8 6689251.1 18.3, 355996 6689246 18.3, 355998.8 6689241.3 18.3, 355983.9 6689233.2 18.3))
BATIMENT0000000302931623;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;00;00;11.8;7.2;19.0;22.5;7.5;Cadastre;C 0.2;POLYGON Z ((356015.8 6689265.6 19, 356020.7 6689256.5 19, 356003.4 6689247.4 19, 356002.3 6689249.4 19, 355996 6689246 19, 355992.8 6689251.1 19, 355999.6 6689254.7 19, 355998.6 6689256.5 19, 356014.6 6689265 19, 356015.8 6689265.6 19))
BATIMENT0000000302931624;Indifférenciée;Commercial et services;Annexe;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;;;10.5;6.8;17.4;26.4;7.8;Cadastre;C 0.1;POLYGON Z ((356011.8 6689288.6 17.4, 356014.6 6689283.4 17.4, 356013.1 6689282.6 17.4, 356015.2 6689278.6 17.4, 356014.6 6689278.2 17.4, 356017.3 6689273.6 17.4, 356017.5 6689273.7 17.4, 356022.1 6689265.4 17.4, 356026.9 6689256.4 17.4, 356022.2 6689253.9 17.4, 356006.1 6689245.3 17.4, 356001.1 6689242.6 17.4, 355998.8 6689241.3 17.4, 355996 6689246 17.4, 356002.3 6689249.4 17.4, 356003.4 6689247.4 17.4, 356020.7 6689256.5 17.4, 356015.8 6689265.6 17.4, 356014.6 6689265 17.4, 356006.2 6689279.7 17.4, 356006.7 6689279.8 17.4, 356007.6 6689280.1 17.4, 356007.1 6689283.9 17.4, 356006.1 6689284.7 17.4, 356003.3 6689283.8 17.4, 356003.2 6689284.5 17.4, 356002.8 6689287.7 17.4, 356011.8 6689288.6 17.4))
BATIMENT0000000302931619;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;7.2;9.7;10.1;8.1;Cadastre;;POLYGON Z ((355985.5 6689266.1 9.7, 355986.6 6689270 9.7, 355990.7 6689268.8 9.7, 355989.7 6689265 9.7, 355985.5 6689266.1 9.7))
BATIMENT0000000302931620;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;00;00;16.4;7.0;23.4;26.6;8.1;Cadastre;C 0.2;POLYGON Z ((355977.9 6689275.3 23.4, 355978.8 6689276 23.4, 355980.1 6689276.7 23.4, 355981.3 6689277.6 23.4, 355982.8 6689278.4 23.4, 355984.1 6689279.2 23.4, 355985.4 6689279.9 23.4, 355988.4 6689281.5 23.4, 355989.5 6689281.9 23.4, 355991.1 6689282.7 23.4, 355992.3 6689283.1 23.4, 355993.7 6689283.7 23.4, 355995.2 6689284.4 23.4, 355996.8 6689284.8 23.4, 355998.8 6689285.6 23.4, 355999.4 6689285.8 23.4, 355999.7 6689285.9 23.4, 356000.8 6689286.2 23.4, 356001.3 6689283.6 23.4, 356003.2 6689284.5 23.4, 356003.3 6689283.8 23.4, 356006.1 6689284.7 23.4, 356007.1 6689283.9 23.4, 356007.6 6689280.1 23.4, 356006.7 6689279.8 23.4, 356006.2 6689279.7 23.4, 356004.9 6689279.3 23.4, 356003.7 6689279 23.4, 356002.4 6689278.6 23.4, 356001.1 6689278.1 23.4, 355999.2 6689277.4 23.4, 355995.7 6689276 23.4, 355992 6689274.3 23.4, 355989.8 6689273.3 23.4, 355987.5 6689272 23.4, 355985.8 6689271 23.4, 355984.1 6689269.9 23.4, 355982.8 6689269.1 23.4, 355982.1 6689268.5 23.4, 355977.9 6689275.3 23.4))
BATIMENT0000000302932571;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:15:29;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;4.0;00;00;10.3;7.1;17.5;26.7;7.8;Cadastre;C 0.5;POLYGON Z ((356043.5 6689298.8 17.5, 356044.6 6689299.4 17.5, 356054.2 6689281.8 17.5, 356036.7 6689272.3 17.5, 356035.4 6689267.1 17.5, 356031.3 6689268.2 17.5, 356025.5 6689265 17.5, 356023.1 6689265.9 17.5, 356022.1 6689265.4 17.5, 356017.5 6689273.7 17.5, 356017.3 6689273.6 17.5, 356014.6 6689278.2 17.5, 356015.2 6689278.6 17.5, 356013.1 6689282.6 17.5, 356014.6 6689283.4 17.5, 356043.5 6689298.8 17.5))
BATIMENT0000000302930324;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;6.5;17.2;18.5;7.0;Cadastre;;POLYGON Z ((355879.2 6689152.7 17.2, 355879.9 6689151.9 17.2, 355877.5 6689150.1 17.2, 355876.8 6689150.9 17.2, 355879.2 6689152.7 17.2))
BATIMENT0000000302930329;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;00;00;16.2;5.7;21.9;26.4;7.1;Cadastre;C 0.8;POLYGON Z ((355903.9 6689171.1 21.9, 355910 6689161.7 21.9, 355903.9 6689157.2 21.9, 355905.3 6689155.3 21.9, 355902.7 6689153.5 21.9, 355901.4 6689155.2 21.9, 355890 6689146.7 21.9, 355884.9 6689156.9 21.9, 355903.9 6689171.1 21.9))
BATIMENT0000000302931117;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;15.3;6.4;21.7;23.9;7.7;Cadastre;C 0.7;POLYGON Z ((355857.3 6689162.1 21.7, 355862.9 6689166.2 21.7, 355862.8 6689166.4 21.7, 355887.9 6689185.6 21.7, 355888.2 6689185.3 21.7, 355894.1 6689189.8 21.7, 355896.2 6689186.5 21.7, 355900 6689180.7 21.7, 355863.3 6689153.2 21.7, 355857.3 6689162.1 21.7))
BATIMENT0000000302931103;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;13;90;20.2;6.2;26.4;28.0;6.9;Cadastre;C 0.7;POLYGON Z ((355840.9 6689186.2 26.4, 355847 6689177.2 26.4, 355847.7 6689176.2 26.4, 355828 6689163 26.4, 355821.4 6689173 26.4, 355840.9 6689186.2 26.4))
BATIMENT0000000302931101;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;7.0;00;00;18.5;6.1;24.7;26.6;6.7;Cadastre;A 1.0;POLYGON Z ((355849.8 6689189.9 24.7, 355852 6689191.4 24.7, 355850.8 6689192.9 24.7, 355860.5 6689199.5 24.7, 355866.6 6689190.6 24.7, 355869.9 6689192.7 24.7, 355870 6689192.5 24.7, 355866.4 6689190.1 24.7, 355852.5 6689180.6 24.7, 355852.4 6689180.9 24.7, 355847 6689177.2 24.7, 355840.9 6689186.2 24.7, 355848.7 6689191.5 24.7, 355849.8 6689189.9 24.7))
BATIMENT0000000302931104;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;6.1;25.5;26.3;6.4;Cadastre;;POLYGON Z ((355850.8 6689192.9 25.5, 355852 6689191.4 25.5, 355849.8 6689189.9 25.5, 355848.7 6689191.5 25.5, 355850.8 6689192.9 25.5))
BATIMENT0000000302931102;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;7.0;00;00;18.2;6.2;24.5;26.7;6.8;Cadastre;C 0.7;POLYGON Z ((355870.6 6689206.4 24.5, 355871.7 6689204.8 24.5, 355873.6 6689206.1 24.5, 355872.5 6689207.7 24.5, 355879.6 6689212.5 24.5, 355885.5 6689203.4 24.5, 355880.5 6689200.1 24.5, 355880.8 6689199.8 24.5, 355870 6689192.5 24.5, 355869.9 6689192.7 24.5, 355866.6 6689190.6 24.5, 355860.5 6689199.5 24.5, 355870.6 6689206.4 24.5))
BATIMENT0000000302931106;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;6.0;00;00;8.7;6.5;15.2;26.2;7.9;Cadastre;A 1.0;POLYGON Z ((355889.8 6689219.4 15.2, 355891.4 6689219.3 15.2, 355893.9 6689221 15.2, 355894.7 6689222.7 15.2, 355896.6 6689224 15.2, 355896.8 6689223.8 15.2, 355900.6 6689226.3 15.2, 355900.4 6689226.6 15.2, 355903.9 6689229 15.2, 355909.9 6689219.6 15.2, 355917.6 6689207.2 15.2, 355923.3 6689198.2 15.2, 355913.9 6689191.2 15.2, 355912.2 6689191.1 15.2, 355909.8 6689189.4 15.2, 355909.1 6689187.6 15.2, 355900 6689180.7 15.2, 355896.2 6689186.5 15.2, 355894.1 6689189.8 15.2, 355893.5 6689190.8 15.2, 355886 6689202.5 15.2, 355885.6 6689203.2 15.2, 355885.5 6689203.4 15.2, 355879.6 6689212.5 15.2, 355889.8 6689219.4 15.2))
BATIMENT0000000302931105;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.0;6.2;25.2;26.0;6.4;Cadastre;;POLYGON Z ((355872.5 6689207.7 25.2, 355873.6 6689206.1 25.2, 355871.7 6689204.8 25.2, 355870.6 6689206.4 25.2, 355872.5 6689207.7 25.2))
BATIMENT0000000302931879;Tour, donjon;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355845.7 6689390.4 22.2, 355846.4 6689391.9 22.2, 355847.6 6689393.2 22.2, 355849 6689394.1 22.2, 355850 6689394.5 22.2, 355860.1 6689390.1 22.2, 355859 6689386 22.2, 355858.4 6689384.6 22.2, 355857.2 6689382.9 22.2, 355856 6689382 22.2, 355854.7 6689381.3 22.2, 355851.7 6689380.7 22.2, 355848.7 6689381.5 22.2, 355847.9 6689382 22.2, 355846.2 6689383.6 22.2, 355845.5 6689385 22.2, 355845.1 6689387.1 22.2, 355845.3 6689388.9 22.2, 355845.7 6689390.4 22.2))
BATIMENT0000000302931622;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;6.9;15.2;21.7;7.1;Cadastre;;POLYGON Z ((355940.1 6689231.2 15.2, 355940.3 6689230.9 15.2, 355936.6 6689228.7 15.2, 355935.7 6689230.2 15.2, 355936.7 6689230.8 15.2, 355939.1 6689232.3 15.2, 355939.9 6689231.2 15.2, 355940.1 6689231.2 15.2))
BATIMENT0000000302931615;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;;;9.0;6.7;15.8;25.9;7.2;Cadastre;A 1.0;POLYGON Z ((355953.2 6689230.9 15.8, 355947.8 6689227.7 15.8, 355943.8 6689225.2 15.8, 355940.3 6689230.9 15.8, 355940.1 6689231.2 15.8, 355939.9 6689231.2 15.8, 355939.1 6689232.3 15.8, 355937.6 6689234.9 15.8, 355937.7 6689235.1 15.8, 355937.8 6689237 15.8, 355933.3 6689234 15.8, 355935.5 6689230.5 15.8, 355934.5 6689229.8 15.8, 355933.7 6689230.8 15.8, 355932 6689233.1 15.8, 355931.9 6689233.3 15.8, 355928.5 6689231 15.8, 355928.6 6689230.7 15.8, 355926.2 6689229.1 15.8, 355920.1 6689238.9 15.8, 355939.9 6689252.5 15.8, 355953.2 6689230.9 15.8))
BATIMENT0000000302931611;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;6.9;11.5;15.2;7.6;Cadastre;;POLYGON Z ((355970.8 6689240.8 11.5, 355965 6689236.7 11.5, 355958.7 6689246.9 11.5, 355957.2 6689248.5 11.5, 355963.5 6689252.8 11.5, 355970.8 6689240.8 11.5))
BATIMENT0000000302931614;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;8.8;6.6;15.5;23.7;7.6;Cadastre;C 0.6;POLYGON Z ((355956.6 6689264.1 15.5, 355963.2 6689253.4 15.5, 355949.1 6689244.5 15.5, 355950 6689242.9 15.5, 355951.5 6689243.7 15.5, 355958.4 6689232.8 15.5, 355953.8 6689229.9 15.5, 355953.2 6689230.9 15.5, 355939.9 6689252.5 15.5, 355956.6 6689264.1 15.5))
BATIMENT0000000302931610;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.3;6.7;15.1;18.1;7.6;Cadastre;A 1.0;POLYGON Z ((355962.1 6689267.9 15.1, 355976.3 6689245.3 15.1, 355983.9 6689233.2 15.1, 355977.5 6689229.8 15.1, 355972.8 6689237.4 15.1, 355970.8 6689240.8 15.1, 355963.5 6689252.8 15.1, 355963.2 6689253.4 15.1, 355956.6 6689264.1 15.1, 355962.1 6689267.9 15.1))
BATIMENT0000000302931618;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;5.0;7.0;12.0;16.8;8.3;Cadastre;A 1.0;POLYGON Z ((355976.4 6689277.8 12, 355977.9 6689275.3 12, 355982.1 6689268.5 12, 355991.3 6689253.5 12, 355982.4 6689248.6 12, 355978.8 6689246.6 12, 355976.3 6689245.3 12, 355962.1 6689267.9 12, 355976.4 6689277.8 12))
BATIMENT0000000302931884;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355930.6 6689436.3 22.2, 355935 6689430.8 22.2, 355933.6 6689427.4 22.2, 355910.2 6689415.8 22.2, 355908.1 6689414.7 22.2, 355907 6689416.9 22.2, 355904.2 6689423.3 22.2, 355930.6 6689436.3 22.2))
BATIMENT0000000302931882;Tour, donjon;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355935 6689430.8 22.2, 355940.2 6689434.5 22.2, 355944.4 6689437.9 22.2, 355947.3 6689431.9 22.2, 355947.5 6689430.7 22.2, 355947.5 6689428.2 22.2, 355946.5 6689425.8 22.2, 355945.9 6689425 22.2, 355943.8 6689423.4 22.2, 355942.3 6689422.8 22.2, 355940.5 6689422.5 22.2, 355938.6 6689422.7 22.2, 355937 6689423.4 22.2, 355935.5 6689424.4 22.2, 355934.4 6689425.8 22.2, 355933.6 6689427.4 22.2, 355935 6689430.8 22.2))
BATIMENT0000000302931880;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355939.2 6689435.8 22.2, 355955.1 6689485.7 22.2, 355958.1 6689485.1 22.2, 355959.2 6689484.9 22.2, 355958.7 6689481.6 22.2, 355944.4 6689437.9 22.2, 355940.2 6689434.5 22.2, 355940.4 6689435.3 22.2, 355939.2 6689435.8 22.2))
BATIMENT0000000302930355;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.9;5.8;25.7;;;Cadastre;;POLYGON Z ((355915.2 6689446.6 25.7, 355929 6689490.4 25.7, 355946.4 6689484.8 25.7, 355932.4 6689440.8 25.7, 355915.2 6689446.6 25.7))
BATIMENT0000000302931621;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.6;7.0;23.6;26.0;7.6;Cadastre;;POLYGON Z ((355982.8 6689282.1 23.6, 355984.4 6689283 23.6, 355986.1 6689283.8 23.6, 355988.5 6689284.9 23.6, 355990.5 6689285.7 23.6, 355992.3 6689286.4 23.6, 355994.1 6689287.1 23.6, 355996.4 6689287.8 23.6, 355998.5 6689288.5 23.6, 356000.4 6689289 23.6, 356002.5 6689289.5 23.6, 356002.8 6689287.7 23.6, 356003.2 6689284.5 23.6, 356001.3 6689283.6 23.6, 356000.8 6689286.2 23.6, 355999.7 6689285.9 23.6, 355999.4 6689285.8 23.6, 355998.8 6689285.6 23.6, 355996.8 6689284.8 23.6, 355995.2 6689284.4 23.6, 355993.7 6689283.7 23.6, 355992.3 6689283.1 23.6, 355991.1 6689282.7 23.6, 355989.5 6689281.9 23.6, 355988.4 6689281.5 23.6, 355985.4 6689279.9 23.6, 355984.1 6689279.2 23.6, 355982.8 6689278.4 23.6, 355981.3 6689277.6 23.6, 355980.1 6689276.7 23.6, 355978.8 6689276 23.6, 355977.9 6689275.3 23.6, 355976.4 6689277.8 23.6, 355982.8 6689282.1 23.6))
BATIMENT0000000302932673;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;9.6;12.0;12.4;10.2;Cadastre;;POLYGON Z ((356054 6689459.6 12, 356047.1 6689455.9 12, 356046.3 6689457.4 12, 356053.2 6689461.1 12, 356054 6689459.6 12))
BATIMENT0000000302932674;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:15:29;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.8;9.6;11.5;12.2;10.2;Cadastre;;POLYGON Z ((356042.2 6689465.4 11.5, 356049 6689469.1 11.5, 356049.8 6689467.6 11.5, 356043 6689463.9 11.5, 356042.2 6689465.4 11.5))
BATIMENT0000000303962912;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;5.0;;;7.2;10.1;17.4;27.5;11.3;Cadastre;A 1.0;POLYGON Z ((356029.1 6689587.8 17.4, 356052.7 6689597.3 17.4, 356055.6 6689590.7 17.4, 356053 6689589.9 17.4, 356052.9 6689590.6 17.4, 356053.6 6689591 17.4, 356053.3 6689591.8 17.4, 356043.4 6689587.2 17.4, 356043.7 6689585.7 17.4, 356032.6 6689581 17.4, 356029.1 6689587.8 17.4))
BATIMENT0000000303962911;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;;;9.2;10.9;20.2;31.8;12.5;Cadastre;A 1.0;POLYGON Z ((356019.1 6689608 20.2, 356028.3 6689611.4 20.2, 356035.9 6689614.1 20.2, 356037.4 6689614.7 20.2, 356037.2 6689615.7 20.2, 356046.5 6689619.7 20.2, 356049.6 6689612.6 20.2, 356050.4 6689610.5 20.2, 356054.2 6689602.4 20.2, 356055.7 6689598.5 20.2, 356052.7 6689597.3 20.2, 356029.1 6689587.8 20.2, 356027.4 6689591.2 20.2, 356019.1 6689608 20.2), (356034.8 6689595.8 20.2, 356036.7 6689596.5 20.2, 356036.8 6689595.9 20.2, 356043.5 6689598.9 20.2, 356041.3 6689604.3 20.2, 356041.6 6689604.4 20.2, 356040.9 6689606.6 20.2, 356033.6 6689603.5 20.2, 356032.2 6689606.9 20.2, 356030.3 6689605.9 20.2, 356034.4 6689596.8 20.2, 356034.8 6689595.8 20.2))
BATIMENT0000000303962917;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;11.4;13.4;13.6;11.7;Cadastre;;POLYGON Z ((356051 6689612.9 13.4, 356051.7 6689610.9 13.4, 356050.4 6689610.5 13.4, 356049.6 6689612.6 13.4, 356051 6689612.9 13.4))
BATIMENT0000000303961865;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;14.2;13.3;27.6;28.7;16.1;Cadastre;C 1.0;POLYGON Z ((355998.7 6689616.9 27.6, 356001.8 6689618.5 27.6, 356003.2 6689615.2 27.6, 356000.4 6689613.8 27.6, 355998.7 6689616.9 27.6))
BATIMENT0000000303962908;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.9;11.5;26.4;30.5;13.7;Cadastre;;POLYGON Z ((356017.7 6689607.5 26.4, 356012.2 6689623.5 26.4, 356027 6689630.7 26.4, 356029.6 6689624.1 26.4, 356028.7 6689623.7 26.4, 356024.7 6689621.8 26.4, 356028.3 6689611.4 26.4, 356019.1 6689608 26.4, 356017.7 6689607.5 26.4))
BATIMENT0000000303962914;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;11.4;15.7;18.2;12.1;Cadastre;;POLYGON Z ((356032.6 6689622.1 15.7, 356033.2 6689620.9 15.7, 356030.2 6689619.6 15.7, 356029.4 6689621.7 15.7, 356032.4 6689623 15.7, 356032.6 6689622.1 15.7))
BATIMENT0000000303962909;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;11.5;19.4;23.0;12.5;Cadastre;;POLYGON Z ((356029.6 6689624.1 19.4, 356031.5 6689625.1 19.4, 356031.7 6689624.4 19.4, 356032.4 6689623 19.4, 356029.4 6689621.7 19.4, 356028.7 6689623.7 19.4, 356029.6 6689624.1 19.4))
BATIMENT0000000302931881;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;2013-06-11 17:28:52;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355859 6689407.7 22.2, 355862.3 6689396.8 22.2, 355866 6689397.7 22.2, 355866.4 6689396.9 22.2, 355907 6689416.9 22.2, 355908.1 6689414.7 22.2, 355860.1 6689390.1 22.2, 355850 6689394.5 22.2, 355846.6 6689401.7 22.2, 355847.8 6689402.3 22.2, 355859 6689407.7 22.2))
BATIMENT0000000302931877;Tour, donjon;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;29.7;4.9;34.6;;;Cadastre;;POLYGON Z ((355816.1 6689439.3 34.6, 355817.3 6689441.4 34.6, 355818.9 6689443.3 34.6, 355820.7 6689444.5 34.6, 355822.9 6689445.3 34.6, 355827.7 6689445.7 34.6, 355832.5 6689440.6 34.6, 355833.5 6689435 34.6, 355831.5 6689427.5 34.6, 355826.7 6689426.4 34.6, 355824.2 6689426.4 34.6, 355821.7 6689426.9 34.6, 355819.5 6689428.1 34.6, 355817.8 6689429.7 34.6, 355816.5 6689431.6 34.6, 355815.7 6689433.9 34.6, 355815.5 6689436.9 34.6, 355816.1 6689439.3 34.6))
BATIMENT0000000302931878;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;2012-09-27 15:33:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;29.7;4.9;34.6;;;Cadastre;;POLYGON Z ((355826.7 6689468.2 34.6, 355827.5 6689469.6 34.6, 355829.1 6689471.1 34.6, 355831.5 6689472.1 34.6, 355834.3 6689472.1 34.6, 355836.5 6689471.4 34.6, 355838.9 6689477.4 34.6, 355838 6689477.6 34.6, 355835.9 6689478.6 34.6, 355834.3 6689480.2 34.6, 355833.8 6689481.2 34.6, 355833.2 6689482.7 34.6, 355833.1 6689484.8 34.6, 355833.7 6689486.9 34.6, 355835 6689488.6 34.6, 355837 6689490 34.6, 355839.7 6689490.5 34.6, 355841.8 6689490.2 34.6, 355843.2 6689489.4 34.6, 355845.4 6689488.6 34.6, 355849 6689487 34.6, 355847.1 6689482.3 34.6, 355854.6 6689479.4 34.6, 355855.3 6689480.9 34.6, 355856.3 6689480.5 34.6, 355842.3 6689445.5 34.6, 355844.6 6689443.6 34.6, 355845.2 6689441.2 34.6, 355846.1 6689440.9 34.6, 355847.2 6689441.2 34.6, 355847 6689441.8 34.6, 355847.6 6689442 34.6, 355847.8 6689441.2 34.6, 355849.5 6689440.5 34.6, 355850.2 6689440.7 34.6, 355850.5 6689440.1 34.6, 355850.1 6689440.1 34.6, 355850.7 6689437.6 34.6, 355851.1 6689437.6 34.6, 355851.1 6689437.1 34.6, 355850.4 6689437 34.6, 355859 6689407.7 34.6, 355847.8 6689402.3 34.6, 355846.6 6689401.7 34.6, 355846.2 6689402.6 34.6, 355838 6689429.1 34.6, 355831.5 6689427.5 34.6, 355833.5 6689435 34.6, 355832.5 6689440.6 34.6, 355827.7 6689445.7 34.6, 355831.9 6689458.7 34.6, 355829.8 6689459.9 34.6, 355828 6689461.2 34.6, 355826.6 6689463.5 34.6, 355826.2 6689466.1 34.6, 355826.7 6689468.2 34.6))
BATIMENT0000000302931844;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355852.5 6689494.1 22.2, 355850 6689488.2 22.2, 355849.5 6689488.3 22.2, 355849 6689487 22.2, 355845.4 6689488.6 22.2, 355848.2 6689495.7 22.2, 355852.5 6689494.1 22.2))
BATIMENT0000000302931504;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;15.6;12.4;28.1;31.0;15.3;Cadastre;A 1.0;POLYGON Z ((355842.1 6689566.8 28.1, 355841.7 6689551.2 28.1, 355831.9 6689549.2 28.1, 355831.1 6689552.9 28.1, 355829.8 6689552.6 28.1, 355829 6689563.7 28.1, 355828.8 6689563.7 28.1, 355828.3 6689571.8 28.1, 355828.3 6689571.9 28.1, 355842.4 6689571.7 28.1, 355842.1 6689566.8 28.1))
BATIMENT0000000302931500;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;10;20;19.2;12.3;31.5;34.4;15.3;Cadastre;A 1.0;POLYGON Z ((355851.6 6689572.8 31.5, 355852.4 6689568.1 31.5, 355848.5 6689567.9 31.5, 355847.9 6689567 31.5, 355848 6689565 31.5, 355847.2 6689563.8 31.5, 355847.3 6689562.7 31.5, 355848.3 6689562.6 31.5, 355849.2 6689564.4 31.5, 355852.7 6689565 31.5, 355854.4 6689553.7 31.5, 355842.8 6689551.4 31.5, 355843.5 6689571 31.5, 355843.5 6689571.7 31.5, 355843.6 6689572.1 31.5, 355846.6 6689572.4 31.5, 355851.6 6689572.8 31.5))
BATIMENT0000000302931505;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;15.9;12.5;28.5;30.7;15.2;Cadastre;A 1.0;POLYGON Z ((355857.8 6689573.5 28.5, 355858.5 6689569.2 28.5, 355856.8 6689568.8 28.5, 355857.6 6689564.4 28.5, 355859.3 6689564.7 28.5, 355861.1 6689555.1 28.5, 355854.4 6689553.7 28.5, 355852.7 6689565 28.5, 355852.4 6689568.1 28.5, 355851.6 6689572.8 28.5, 355857.8 6689573.5 28.5))
BATIMENT0000000302931508;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;16.3;12.6;28.9;31.0;15.0;Cadastre;A 1.0;POLYGON Z ((355864.4 6689574.3 28.9, 355867.7 6689556.4 28.9, 355861.1 6689555.1 28.9, 355859.3 6689564.7 28.9, 355860.7 6689565 28.9, 355860 6689569.4 28.9, 355858.5 6689569.2 28.9, 355857.8 6689573.5 28.9, 355864.4 6689574.3 28.9))
BATIMENT0000000302931509;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;18.3;12.6;31.0;35.5;16.0;Cadastre;A 0.8;POLYGON Z ((355875.5 6689575.4 31, 355876.1 6689572 31, 355875.7 6689572 31, 355875.9 6689570.5 31, 355882 6689571.6 31, 355882 6689571.8 31, 355882 6689572.1 31, 355882.1 6689572.3 31, 355882.2 6689572.5 31, 355882.4 6689572.8 31, 355882.5 6689572.9 31, 355882.6 6689573.1 31, 355882.8 6689573.2 31, 355883 6689573.3 31, 355883.2 6689573.4 31, 355883.6 6689573.5 31, 355884 6689573.6 31, 355884.2 6689573.6 31, 355884.4 6689573.6 31, 355884.8 6689573.5 31, 355885.2 6689573.4 31, 355885.4 6689573.4 31, 355885.5 6689573.3 31, 355885.7 6689573.2 31, 355885.8 6689573 31, 355886 6689572.7 31, 355891.2 6689573.6 31, 355890.4 6689577.3 31, 355897.2 6689578.1 31, 355897.7 6689576.2 31, 355899.3 6689562.8 31, 355867.7 6689556.4 31, 355864.4 6689574.3 31, 355875.5 6689575.4 31))
BATIMENT0000000302931510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;12.9;22.0;26.5;16.0;Cadastre;;POLYGON Z ((355901.4 6689576.6 22, 355902.1 6689571.5 22, 355903.2 6689563.6 22, 355899.3 6689562.8 22, 355897.7 6689576.2 22, 355901.4 6689576.6 22))
BATIMENT0000000302931502;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;14.7;25.9;33.6;15.3;Cadastre;;POLYGON Z ((355845.5 6689578.7 25.9, 355845.2 6689575.9 25.9, 355846.9 6689575.8 25.9, 355846.6 6689572.4 25.9, 355843.6 6689572.1 25.9, 355843.5 6689571.7 25.9, 355843.2 6689571.7 25.9, 355843.7 6689576.1 25.9, 355843.9 6689578.8 25.9, 355845.5 6689578.7 25.9))
BATIMENT0000000302931503;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;;;12.3;14.9;27.2;31.4;15.3;Cadastre;A 1.0;POLYGON Z ((355858.8 6689594.5 27.2, 355859.1 6689594.6 27.2, 355859.8 6689585.2 27.2, 355859.4 6689585.1 27.2, 355859.3 6689585.7 27.2, 355855.8 6689585.4 27.2, 355856.1 6689580.7 27.2, 355844.1 6689579.9 27.2, 355844.7 6689586.8 27.2, 355847.8 6689587.1 27.2, 355847.5 6689588.7 27.2, 355844.9 6689588.5 27.2, 355845.3 6689593.2 27.2, 355847 6689593.3 27.2, 355847 6689593.6 27.2, 355858.8 6689594.5 27.2))
BATIMENT0000000302931499;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;12;20;11.6;13.8;25.5;30.4;16.4;Cadastre;A 1.0;POLYGON Z ((355828.3 6689571.9 25.5, 355828.3 6689571.8 25.5, 355821.9 6689571.8 25.5, 355820.2 6689571.8 25.5, 355820.1 6689572.1 25.5, 355814.1 6689572 25.5, 355814.1 6689571.9 25.5, 355810.5 6689571.9 25.5, 355808.9 6689576.6 25.5, 355813.7 6689577.2 25.5, 355813.7 6689577.8 25.5, 355813.8 6689578.2 25.5, 355814.3 6689578.6 25.5, 355814.8 6689578.7 25.5, 355813.9 6689583.8 25.5, 355812.5 6689583.6 25.5, 355812.8 6689582.1 25.5, 355807.4 6689581 25.5, 355805.9 6689585.7 25.5, 355809.1 6689586.4 25.5, 355813.4 6689587.3 25.5, 355812.9 6689589.9 25.5, 355812.8 6689590.1 25.5, 355815.5 6689590.6 25.5, 355814.5 6689599.1 25.5, 355816.6 6689599.1 25.5, 355815.9 6689604.6 25.5, 355813.9 6689604.3 25.5, 355813.6 6689606 25.5, 355820.1 6689607.2 25.5, 355823 6689608 25.5, 355835.7 6689609.7 25.5, 355838.7 6689609.9 25.5, 355839.1 6689608 25.5, 355845.2 6689608.8 25.5, 355847 6689593.6 25.5, 355847 6689593.3 25.5, 355845.3 6689593.2 25.5, 355844.9 6689588.5 25.5, 355844.7 6689586.8 25.5, 355844.1 6689579.9 25.5, 355843.9 6689578.8 25.5, 355843.7 6689576.1 25.5, 355843.2 6689571.7 25.5, 355842.4 6689571.7 25.5, 355828.3 6689571.9 25.5), (355839.6 6689576.4 25.5, 355836.5 6689576.6 25.5, 355836.6 6689576.1 25.5, 355837.8 6689575.8 25.5, 355837.9 6689574.4 25.5, 355839.5 6689574.2 25.5, 355839.6 6689576.4 25.5), (355828.5 6689577.5 25.5, 355829.3 6689578 25.5, 355836 6689578 25.5, 355836.9 6689578.4 25.5, 355837.3 6689585.6 25.5, 355837.8 6689585.6 25.5, 355838 6689588 25.5, 355838.2 6689588 25.5, 355839.2 6689602.1 25.5, 355819.7 6689599.2 25.5, 355823.6 6689576.1 25.5, 355828.4 6689576.1 25.5, 355828.5 6689577.5 25.5))
BATIMENT0000000302931507;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;10;20;17.4;14.6;32.0;34.5;17.1;Cadastre;C 0.2;POLYGON Z ((355858.8 6689594.5 32, 355858.5 6689598.8 32, 355858.2 6689598.8 32, 355857.3 6689612.1 32, 355863.6 6689612.6 32, 355863.8 6689612.4 32, 355868.1 6689612.7 32, 355868.2 6689613.1 32, 355884 6689614.2 32, 355884 6689611.7 32, 355885.9 6689587.1 32, 355882.3 6689586.8 32, 355860.6 6689585.3 32, 355860.5 6689585.2 32, 355859.8 6689585.2 32, 355859.1 6689594.6 32, 355858.8 6689594.5 32), (355872.6 6689597.6 32, 355872.2 6689601.9 32, 355866.9 6689601.5 32, 355867.3 6689597.3 32, 355872.6 6689597.6 32), (355868.3 6689606.2 32, 355868.1 6689608.7 32, 355866.2 6689608.6 32, 355866.5 6689606.2 32, 355868.3 6689606.2 32))
BATIMENT0000000302931506;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;6.8;15.3;22.2;26.7;16.3;Cadastre;C 0.5;POLYGON Z ((355847.9 6689616.9 22.2, 355848.2 6689611.5 22.2, 355848.2 6689610.9 22.2, 355845.2 6689610.7 22.2, 355845.2 6689608.8 22.2, 355839.1 6689608 22.2, 355838.7 6689609.9 22.2, 355835.7 6689609.7 22.2, 355838.4 6689621.9 22.2, 355847.9 6689616.9 22.2))
BATIMENT0000000302931511;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;16.1;23.1;24.5;16.5;Cadastre;;POLYGON Z ((355888.6 6689620.3 23.1, 355888.8 6689616.4 23.1, 355883.4 6689615.9 23.1, 355883.2 6689617.7 23.1, 355883.4 6689619.8 23.1, 355888.6 6689620.3 23.1))
BATIMENT0000000302931498;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;8.6;15.6;24.3;29.5;16.9;Cadastre;A 1.0;POLYGON Z ((355816.8 6689610.5 24.3, 355816.7 6689610.8 24.3, 355816.3 6689612.7 24.3, 355818.4 6689613.1 24.3, 355818 6689614.8 24.3, 355819.1 6689614.6 24.3, 355817.3 6689631.9 24.3, 355817.3 6689633 24.3, 355824.1 6689630.4 24.3, 355824.1 6689629.5 24.3, 355833.5 6689624.6 24.3, 355833.9 6689624.9 24.3, 355838.4 6689621.9 24.3, 355835.7 6689609.7 24.3, 355823 6689608 24.3, 355820.1 6689607.2 24.3, 355819.3 6689611 24.3, 355816.8 6689610.5 24.3), (355825.6 6689612.5 24.3, 355833.2 6689613.3 24.3, 355834.6 6689619.8 24.3, 355827.5 6689621.8 24.3, 355827.8 6689623.3 24.3, 355823.7 6689623.7 24.3, 355825.6 6689612.5 24.3))
BATIMENT0000000302931512;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;20;20;13.2;15.4;28.7;32.6;16.6;Cadastre;A 1.0;POLYGON Z ((355882.6 6689629.8 28.7, 355883.4 6689619.8 28.7, 355883.2 6689617.7 28.7, 355869.5 6689616.6 28.7, 355857 6689615.7 28.7, 355856.4 6689623 28.7, 355866.9 6689623.7 28.7, 355866.5 6689628.6 28.7, 355882.6 6689629.8 28.7))
BATIMENT0000000302931804;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;09;09;3.1;16.2;19.3;21.7;17.8;Cadastre;C 0.4;POLYGON Z ((355828.2 6689632.7 19.3, 355830.4 6689638.4 19.3, 355834 6689636.7 19.3, 355832.5 6689630.5 19.3, 355828.2 6689632.7 19.3))
BATIMENT0000000302930639;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;16.9;30.9;34.7;18.1;Cadastre;;POLYGON Z ((355860.7 6689658.3 30.9, 355849.8 6689656.7 30.9, 355850 6689653.9 30.9, 355847.8 6689653.6 30.9, 355846.2 6689654.3 30.9, 355846.6 6689651.3 30.9, 355847.2 6689651.4 30.9, 355847.4 6689650.4 30.9, 355837.1 6689649.5 30.9, 355836.4 6689656.6 30.9, 355845 6689657.6 30.9, 355843.4 6689665.7 30.9, 355845.7 6689666 30.9, 355845.7 6689665.5 30.9, 355847.8 6689665.2 30.9, 355859 6689666.5 30.9, 355859.6 6689666.5 30.9, 355860.2 6689662.2 30.9, 355860.7 6689658.3 30.9))
BATIMENT0000000302931646;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.8;7.1;26.0;28.6;8.2;Cadastre;B 0.5;POLYGON Z ((355661.6 6689351 26, 355659.6 6689350.5 26, 355659 6689351.6 26, 355658.2 6689353.1 26, 355656.1 6689356.8 26, 355656 6689357.1 26, 355655.9 6689357.3 26, 355655.8 6689357.6 26, 355655.8 6689357.9 26, 355655.7 6689358.2 26, 355655.8 6689358.6 26, 355655.8 6689358.8 26, 355655.9 6689359.1 26, 355656 6689359.3 26, 355656.1 6689359.5 26, 355656.2 6689359.8 26, 355656.4 6689360 26, 355656.7 6689360.3 26, 355657 6689360.5 26, 355657.4 6689360.8 26, 355657.8 6689360.9 26, 355658 6689361 26, 355658.1 6689361 26, 355662.7 6689361.8 26, 355675 6689364.5 26, 355681.1 6689367 26, 355691.3 6689370.9 26, 355699.3 6689373.9 26, 355703.1 6689363.6 26, 355695.5 6689360.3 26, 355697 6689356.4 26, 355678.2 6689348.7 26, 355681.7 6689340.1 26, 355678.1 6689339.1 26, 355672.5 6689337.7 26, 355669.5 6689349.3 26, 355662.2 6689347.2 26, 355661.6 6689351 26))
BATIMENT0000000302931653;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;13.1;8.1;21.2;;;Cadastre;A 1.0;POLYGON Z ((355716.5 6689364.5 21.2, 355717.7 6689354.5 21.2, 355718 6689354.5 21.2, 355718.3 6689352 21.2, 355709.2 6689348 21.2, 355707.9 6689347.5 21.2, 355707.7 6689348.3 21.2, 355707.4 6689348.2 21.2, 355706.5 6689351.7 21.2, 355705.9 6689354 21.2, 355704.6 6689359.5 21.2, 355716.5 6689364.5 21.2))
BATIMENT0000000302931643;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;15.2;7.5;22.7;24.7;7.9;Cadastre;A 1.0;POLYGON Z ((355700.2 6689374.2 22.7, 355708 6689377.3 22.7, 355711.8 6689367.3 22.7, 355703.1 6689363.6 22.7, 355699.3 6689373.9 22.7, 355700.2 6689374.2 22.7))
BATIMENT0000000302931634;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;20;20;15.6;7.0;22.7;24.1;7.7;Cadastre;A 1.0;POLYGON Z ((355652.7 6689367.8 22.7, 355652.3 6689373.8 22.7, 355663.5 6689375.1 22.7, 355669.3 6689376.1 22.7, 355669.4 6689371.5 22.7, 355652.7 6689367.8 22.7))
BATIMENT0000000302931642;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.6;7.5;24.2;26.9;7.8;Cadastre;;POLYGON Z ((355714.4 6689379.9 24.2, 355718.6 6689370.2 24.2, 355711.8 6689367.3 24.2, 355708 6689377.3 24.2, 355714.4 6689379.9 24.2))
BATIMENT0000000302931640;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;16.5;7.5;24.1;27.0;8.0;Cadastre;A 1.0;POLYGON Z ((355725.5 6689384.3 24.1, 355727.5 6689378.3 24.1, 355728.5 6689375.5 24.1, 355722 6689371.9 24.1, 355721.4 6689370.4 24.1, 355720 6689369.7 24.1, 355718.6 6689370.2 24.1, 355714.4 6689379.9 24.1, 355725.5 6689384.3 24.1))
BATIMENT0000000302931632;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1843-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;15.2;7.3;22.5;25.9;8.0;Cadastre;A 1.0;POLYGON Z ((355652.1 6689378.6 22.5, 355660.8 6689379.8 22.5, 355662.7 6689380.1 22.5, 355663.1 6689377.5 22.5, 355669.5 6689378.8 22.5, 355669.5 6689380.7 22.5, 355672.9 6689381.3 22.5, 355673.5 6689376.9 22.5, 355669.3 6689376.1 22.5, 355663.5 6689375.1 22.5, 355652.3 6689373.8 22.5, 355652.1 6689378.6 22.5))
BATIMENT0000000302931633;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;10;20;13.5;7.1;20.7;22.8;8.1;Cadastre;A 1.0;POLYGON Z ((355673.1 6689386.6 20.7, 355673 6689384 20.7, 355673.7 6689384 20.7, 355673.8 6689383 20.7, 355676 6689383.2 20.7, 355676 6689382.2 20.7, 355677.1 6689382.3 20.7, 355682.2 6689382.7 20.7, 355682.6 6689379.2 20.7, 355683 6689379.2 20.7, 355683.5 6689374.7 20.7, 355669.4 6689371.5 20.7, 355669.3 6689376.1 20.7, 355673.5 6689376.9 20.7, 355672.9 6689381.3 20.7, 355669.5 6689380.7 20.7, 355669.2 6689386.7 20.7, 355673.1 6689386.6 20.7))
BATIMENT0000000302931631;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;15;20;14.7;7.6;22.3;26.9;8.3;Cadastre;A 1.0;POLYGON Z ((355651.5 6689388.1 22.3, 355664 6689387.8 22.3, 355664 6689386.9 22.3, 355669.2 6689386.7 22.3, 355669.5 6689380.7 22.3, 355663.5 6689379.7 22.3, 355663.4 6689380.1 22.3, 355663.1 6689382.1 22.3, 355660.6 6689381.8 22.3, 355660.8 6689379.8 22.3, 355652.1 6689378.6 22.3, 355651.5 6689388.1 22.3))
BATIMENT0000000302931641;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;7.8;14.9;21.4;8.1;Cadastre;;POLYGON Z ((355712.4 6689393.9 14.9, 355713.4 6689389.7 14.9, 355702.9 6689387 14.9, 355701.8 6689391.2 14.9, 355712.4 6689393.9 14.9))
BATIMENT0000000302930385;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;15.3;8.0;23.3;26.9;8.5;Cadastre;A 0.4;POLYGON Z ((355595.4 6689354.1 23.3, 355588.6 6689361.8 23.3, 355603 6689370.9 23.3, 355604.2 6689369 23.3, 355601.7 6689367.5 23.3, 355603.5 6689365.4 23.3, 355605.7 6689366.6 23.3, 355607.7 6689363.5 23.3, 355605.3 6689362.2 23.3, 355606.7 6689359.7 23.3, 355595.4 6689354.1 23.3))
BATIMENT0000000302930387;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;50;20;14.6;8.0;22.6;24.2;8.2;Cadastre;A 1.0;POLYGON Z ((355610.9 6689370.5 22.6, 355614.4 6689363.5 22.6, 355609.2 6689361 22.6, 355607.7 6689363.5 22.6, 355605.7 6689366.6 22.6, 355604.8 6689368.1 22.6, 355609.1 6689369.5 22.6, 355609.1 6689369.9 22.6, 355610.9 6689370.5 22.6))
BATIMENT0000000302930363;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;16.0;8.0;24.0;;;Cadastre;A 1.0;POLYGON Z ((355633.7 6689361.2 24, 355622.8 6689356.2 24, 355620.4 6689357.3 24, 355617 6689364.9 24, 355617.2 6689365.1 24, 355624.9 6689367.8 24, 355622.3 6689374.8 24, 355626.7 6689375.5 24, 355628.8 6689375.9 24, 355629.6 6689371.3 24, 355630.7 6689365.9 24, 355632.8 6689366.2 24, 355633.7 6689361.6 24, 355633.7 6689361.2 24))
BATIMENT0000000302930392;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.8;8.0;22.8;25.1;8.6;Cadastre;A 0.1;POLYGON Z ((355588.1 6689362.4 22.8, 355602.6 6689371.6 22.8, 355603 6689370.9 22.8, 355588.6 6689361.8 22.8, 355588.1 6689362.4 22.8))
BATIMENT0000000302930362;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;10.7;7.2;18.0;22.5;7.6;Cadastre;A 1.0;POLYGON Z ((355645 6689373.4 18, 355646 6689368.6 18, 355646.6 6689364 18, 355633.7 6689361.6 18, 355632.8 6689366.2 18, 355631.8 6689371.6 18, 355645 6689373.4 18))
BATIMENT0000000302930384;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;10;14.4;8.0;22.4;24.9;8.8;Cadastre;C 0.4;POLYGON Z ((355584.9 6689366.2 22.4, 355601.5 6689376.3 22.4, 355602 6689374.1 22.4, 355602.6 6689371.6 22.4, 355588.1 6689362.4 22.4, 355584.9 6689366.2 22.4))
BATIMENT0000000302931876;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;00;00;12.2;7.3;19.5;25.7;7.7;Cadastre;A 1.0;POLYGON Z ((355618.6 6689370 19.5, 355617.1 6689374 19.5, 355622.3 6689374.8 19.5, 355624.9 6689367.8 19.5, 355617.2 6689365.1 19.5, 355616.5 6689369.7 19.5, 355618.6 6689370 19.5))
BATIMENT0000000302930364;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;12.6;8.0;20.6;;;Cadastre;A 1.0;POLYGON Z ((355645 6689373.4 20.6, 355631.8 6689371.6 20.6, 355629.6 6689371.3 20.6, 355628.8 6689375.9 20.6, 355630.5 6689376 20.6, 355636.7 6689376.7 20.6, 355644.1 6689377.6 20.6, 355645 6689373.4 20.6))
BATIMENT0000000302930382;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1600-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;8.1;8.3;16.5;18.3;9.1;Cadastre;A 1.0;POLYGON Z ((355577.7 6689374.9 16.5, 355582.8 6689377.7 16.5, 355584.5 6689378.6 16.5, 355586.7 6689374.8 16.5, 355587.2 6689373.9 16.5, 355581.4 6689370.4 16.5, 355577.7 6689374.9 16.5))
BATIMENT0000000302930377;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;13.1;8.0;21.1;23.7;9.1;Cadastre;A 1.0;POLYGON Z ((355587.2 6689373.9 21.1, 355586.7 6689374.8 21.1, 355591.7 6689377.6 21.1, 355591.1 6689380.6 21.1, 355593.5 6689381.9 21.1, 355593 6689383.6 21.1, 355591.8 6689383.2 21.1, 355588.1 6689380 21.1, 355586.9 6689382.6 21.1, 355590.3 6689384.2 21.1, 355591.1 6689384.6 21.1, 355598.9 6689386.6 21.1, 355599.9 6689382.6 21.1, 355601.5 6689376.3 21.1, 355584.9 6689366.2 21.1, 355581.4 6689370.4 21.1, 355587.2 6689373.9 21.1), (355593.8 6689374.2 21.1, 355595.4 6689375.1 21.1, 355594.6 6689378 21.1, 355592.6 6689376.8 21.1, 355592.3 6689376.7 21.1, 355593.8 6689374.2 21.1))
BATIMENT0000000302931018;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;36;20;19.7;7.4;27.2;29.2;7.8;Cadastre;A 1.0;POLYGON Z ((355753.3 6689343.6 27.2, 355750.4 6689353.6 27.2, 355749.7 6689355.9 27.2, 355747.9 6689362 27.2, 355748.9 6689362.3 27.2, 355750.1 6689362.6 27.2, 355756.2 6689364.2 27.2, 355756.7 6689362.8 27.2, 355762.7 6689346.1 27.2, 355753.3 6689343.6 27.2))
BATIMENT0000000302931019;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;10;20;18.3;7.0;25.3;28.8;8.1;Cadastre;A 0.2;POLYGON Z ((355762.7 6689346.1 25.3, 355756.7 6689362.8 25.3, 355759.9 6689364 25.3, 355760.8 6689363.1 25.3, 355761.7 6689359.8 25.3, 355767.4 6689361.5 25.3, 355766.5 6689364.5 25.3, 355769.2 6689365.3 25.3, 355773.8 6689349.1 25.3, 355762.7 6689346.1 25.3))
BATIMENT0000000302931021;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;19.1;7.2;26.3;29.0;8.6;Cadastre;A 1.0;POLYGON Z ((355781.4 6689353.1 26.3, 355780.4 6689350.8 26.3, 355773.8 6689349.1 26.3, 355769.2 6689365.3 26.3, 355766.4 6689375 26.3, 355770 6689376 26.3, 355781.4 6689353.1 26.3))
BATIMENT0000000327821890;Indifférenciée;Résidentiel;Annexe;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;7.0;6.0;00;00;18.2;7.8;;27.9;8.0;Imagerie aérienne;A 1.0;POLYGON Z ((355746.2 6689371.8 26, 355748.9 6689362.3 24.6, 355747.9 6689362 24.6, 355744.8 6689361.2 24, 355741.2 6689360.3 24, 355735.4 6689358.8 23.8, 355735.3 6689369.2 26, 355746.2 6689371.8 26))
BATIMENT0000000302931014;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;7.4;20.1;28.7;8.3;Cadastre;;POLYGON Z ((355753.6 6689371.6 20.1, 355766.4 6689375 20.1, 355769.2 6689365.3 20.1, 355766.5 6689364.5 20.1, 355767.4 6689361.5 20.1, 355761.7 6689359.8 20.1, 355760.8 6689363.1 20.1, 355759.9 6689364 20.1, 355756.7 6689362.8 20.1, 355756.2 6689364.2 20.1, 355753.6 6689371.6 20.1))
BATIMENT0000000302931008;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;20;20;18.7;8.0;26.7;30.2;8.9;Cadastre;A 1.0;POLYGON Z ((355802.1 6689360.4 26.7, 355795.3 6689356.8 26.7, 355779.4 6689388.3 26.7, 355794.1 6689392.6 26.7, 355802.1 6689360.4 26.7))
BATIMENT0000000302931013;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;00;00;16.8;7.3;24.2;26.7;8.0;Cadastre;A 1.0;POLYGON Z ((355746.2 6689371.8 24.2, 355735.3 6689369.2 24.2, 355735.3 6689379.7 24.2, 355749.5 6689383.4 24.2, 355750.4 6689379.7 24.2, 355751.5 6689380 24.2, 355753.1 6689373.4 24.2, 355746.2 6689371.8 24.2))
BATIMENT0000000302931015;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;23;19.6;8.1;27.7;31.0;8.9;Cadastre;A 1.0;POLYGON Z ((355770 6689376 27.7, 355766.4 6689375 27.7, 355753.6 6689371.6 27.7, 355753.1 6689373.4 27.7, 355751.5 6689380 27.7, 355750.4 6689379.7 27.7, 355749.5 6689383.4 27.7, 355750.7 6689383.7 27.7, 355764.3 6689387.2 27.7, 355770 6689376 27.7))
BATIMENT0000000302931017;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;15.7;7.5;23.2;26.5;8.2;Cadastre;A 1.0;POLYGON Z ((355735.2 6689391.1 23.2, 355735.5 6689391.4 23.2, 355745.2 6689394 23.2, 355747.9 6689394.7 23.2, 355750.7 6689383.7 23.2, 355749.5 6689383.4 23.2, 355735.3 6689379.7 23.2, 355735.2 6689391.1 23.2))
BATIMENT0000000302931016;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.0;7.7;17.7;25.5;9.1;Cadastre;A 1.0;POLYGON Z ((355764.3 6689387.2 17.7, 355750.7 6689383.7 17.7, 355747.9 6689394.7 17.7, 355749.2 6689395 17.7, 355759 6689397.7 17.7, 355764.3 6689387.2 17.7))
BATIMENT0000000302930391;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.0;8.4;21.5;26.2;9.1;Cadastre;;POLYGON Z ((355572.5 6689380.8 21.5, 355578.4 6689382.7 21.5, 355579.2 6689381.6 21.5, 355582.2 6689382.3 21.5, 355582.8 6689380.4 21.5, 355581.7 6689379.8 21.5, 355582.8 6689377.7 21.5, 355577.7 6689374.9 21.5, 355572.5 6689380.8 21.5))
BATIMENT0000000302930376;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;11.3;8.0;19.3;22.0;8.5;Cadastre;C 0.3;POLYGON Z ((355601.5 6689376.3 19.3, 355599.9 6689382.6 19.3, 355606 6689384.1 19.3, 355606.3 6689384.1 19.3, 355607.9 6689375.8 19.3, 355606 6689375.4 19.3, 355606.1 6689374.9 19.3, 355602 6689374.1 19.3, 355601.5 6689376.3 19.3))
BATIMENT0000000302930372;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;26;20;12.6;7.9;20.5;23.5;8.1;Cadastre;C 0.7;POLYGON Z ((355644.1 6689377.6 20.5, 355636.7 6689376.7 20.5, 355636.4 6689388.5 20.5, 355644 6689388.5 20.5, 355644.1 6689377.6 20.5))
BATIMENT0000000302930390;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;17.3;8.6;26.0;26.6;9.1;Cadastre;A 1.0;POLYGON Z ((355570.4 6689383.2 26, 355575 6689385.6 26, 355574.5 6689387.8 26, 355577.9 6689389.5 26, 355579.8 6689383.2 26, 355578.4 6689382.7 26, 355572.5 6689380.8 26, 355570.4 6689383.2 26))
BATIMENT0000000302930365;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.9;8.0;11.9;;;Cadastre;C 0.5;POLYGON Z ((355615.1 6689395.8 11.9, 355619.2 6689396.8 11.9, 355621.6 6689397.3 11.9, 355626.7 6689375.5 11.9, 355622.3 6689374.8 11.9, 355617.1 6689374 11.9, 355611.3 6689389.5 11.9, 355613.9 6689390 11.9, 355616.5 6689390.5 11.9, 355615.1 6689395.8 11.9))
BATIMENT0000000302930381;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;10.5;8.7;19.2;22.2;9.2;Cadastre;B 0.1;POLYGON Z ((355586.9 6689382.6 19.2, 355584.6 6689381.4 19.2, 355583.7 6689384.4 19.2, 355579.8 6689383.2 19.2, 355577.9 6689389.5 19.2, 355585.4 6689391.6 19.2, 355586.7 6689387.4 19.2, 355589.1 6689388.1 19.2, 355589.4 6689387.2 19.2, 355590.3 6689384.2 19.2, 355586.9 6689382.6 19.2))
BATIMENT0000000302930389;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.1;8.1;23.2;26.3;9.1;Cadastre;;POLYGON Z ((355569.5 6689384.1 23.2, 355573.9 6689386.3 23.2, 355572.6 6689390.5 23.2, 355572.1 6689392.1 23.2, 355576.5 6689394 23.2, 355577.9 6689389.5 23.2, 355574.5 6689387.8 23.2, 355575 6689385.6 23.2, 355570.4 6689383.2 23.2, 355569.5 6689384.1 23.2))
BATIMENT0000000302930366;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;12;20;6.2;7.6;13.8;22.7;8.6;Cadastre;C 0.7;POLYGON Z ((355643.1 6689394.9 13.8, 355643.1 6689394.7 13.8, 355636.3 6689394.7 13.8, 355636.4 6689388.5 13.8, 355636.7 6689376.7 13.8, 355630.5 6689376 13.8, 355630 6689396.1 13.8, 355636.3 6689397.9 13.8, 355636.3 6689400 13.8, 355636.2 6689404.4 13.8, 355637.3 6689404.4 13.8, 355642.5 6689404.4 13.8, 355643.1 6689394.9 13.8))
BATIMENT0000000302930379;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;10;20;12.7;7.9;20.6;23.4;8.1;Cadastre;C 1.0;POLYGON Z ((355643.9 6689394.9 20.6, 355644 6689388.5 20.6, 355636.4 6689388.5 20.6, 355636.3 6689394.7 20.6, 355643.1 6689394.7 20.6, 355643.1 6689394.9 20.6, 355643.9 6689394.9 20.6))
BATIMENT0000000302931637;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;15.0;7.8;22.8;24.4;8.3;Cadastre;A 1.0;POLYGON Z ((355651.3 6689389.7 22.8, 355650.9 6689395.2 22.8, 355661.2 6689394.8 22.8, 355661 6689389.4 22.8, 355651.3 6689389.7 22.8))
BATIMENT0000000302930383;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;12;20;13.6;8.8;22.4;26.5;9.6;Cadastre;A 1.0;POLYGON Z ((355583.9 6689402.4 22.4, 355586.3 6689394.6 22.4, 355590.6 6689395.8 22.4, 355590.9 6689395 22.4, 355592.7 6689395.5 22.4, 355596.3 6689396.5 22.4, 355598.9 6689386.6 22.4, 355591.1 6689384.6 22.4, 355590.3 6689384.2 22.4, 355589.4 6689387.2 22.4, 355592.8 6689388.2 22.4, 355591.4 6689393.3 22.4, 355589.4 6689392.8 22.4, 355589.5 6689392.4 22.4, 355586.9 6689391.6 22.4, 355586.8 6689392 22.4, 355585.4 6689391.6 22.4, 355577.9 6689389.5 22.4, 355576.5 6689394 22.4, 355574.8 6689399.6 22.4, 355583.9 6689402.4 22.4))
BATIMENT0000000302930374;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;11.7;8.0;19.7;25.2;9.5;Cadastre;A 1.0;POLYGON Z ((355596.3 6689396.5 19.7, 355594 6689405.6 19.7, 355601.7 6689408.1 19.7, 355605.1 6689398.7 19.7, 355606.9 6689399.1 19.7, 355609.3 6689389.6 19.7, 355605 6689388.9 19.7, 355606 6689384.1 19.7, 355599.9 6689382.6 19.7, 355598.9 6689386.6 19.7, 355596.3 6689396.5 19.7), (355601.5 6689389.1 19.7, 355605.8 6689389.7 19.7, 355603.9 6689397.4 19.7, 355599.8 6689396.4 19.7, 355601.5 6689389.1 19.7))
BATIMENT0000000302930388;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;;;17.1;8.8;26.0;27.1;9.3;Cadastre;A 1.0;POLYGON Z ((355574.8 6689399.6 26, 355576.5 6689394 26, 355572.1 6689392.1 26, 355570.3 6689397.8 26, 355574.8 6689399.6 26))
BATIMENT0000000302930375;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;17.0;9.1;26.1;26.9;9.6;Cadastre;A 1.0;POLYGON Z ((355594 6689405.6 26.1, 355596.3 6689396.5 26.1, 355592.7 6689395.5 26.1, 355592.2 6689397.5 26.1, 355591.4 6689397.3 26.1, 355591 6689398.6 26.1, 355590 6689398.3 26.1, 355590.6 6689395.8 26.1, 355586.3 6689394.6 26.1, 355583.9 6689402.4 26.1, 355594 6689405.6 26.1))
BATIMENT0000000302930373;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;8.7;7.7;16.5;23.0;9.3;Cadastre;A 1.0;POLYGON Z ((355613.1 6689403.6 16.5, 355615.1 6689395.8 16.5, 355616.5 6689390.5 16.5, 355613.9 6689390 16.5, 355611.3 6689389.5 16.5, 355609.4 6689389.2 16.5, 355609.3 6689389.6 16.5, 355606.9 6689399.1 16.5, 355605.1 6689398.7 16.5, 355601.7 6689408.1 16.5, 355611.2 6689411.2 16.5, 355613.1 6689403.6 16.5))
BATIMENT0000000302930380;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1873-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;8.0;7.7;15.7;20.2;9.0;Cadastre;A 1.0;POLYGON Z ((355624.6 6689402.9 15.7, 355627.4 6689404.2 15.7, 355630.2 6689405.5 15.7, 355629.9 6689407 15.7, 355631.7 6689407.4 15.7, 355632.3 6689404.3 15.7, 355636.2 6689404.4 15.7, 355636.3 6689400 15.7, 355625.9 6689398.4 15.7, 355625.7 6689398.4 15.7, 355625 6689400.9 15.7, 355624.6 6689402.9 15.7))
BATIMENT0000000302930369;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1450-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;46;20;15.2;8.3;23.5;25.7;9.3;Cadastre;A 1.0;POLYGON Z ((355618.5 6689414.1 23.5, 355622 6689399.1 23.5, 355622.4 6689397.5 23.5, 355621.6 6689397.3 23.5, 355619.2 6689396.8 23.5, 355618.6 6689399.4 23.5, 355619.5 6689399.6 23.5, 355618.9 6689402.2 23.5, 355617.7 6689403 23.5, 355617.2 6689404.7 23.5, 355613.1 6689403.6 23.5, 355611.2 6689411.2 23.5, 355618.5 6689414.1 23.5))
BATIMENT0000000302930368;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;12;20;16.4;8.0;24.4;27.7;9.1;Cadastre;A 1.0;POLYGON Z ((355618.5 6689414.1 24.4, 355621.9 6689415.4 24.4, 355622.2 6689415.5 24.4, 355623.7 6689409.8 24.4, 355625.9 6689410.4 24.4, 355627 6689406.3 24.4, 355624.4 6689405.6 24.4, 355624 6689405.6 24.4, 355624.6 6689402.9 24.4, 355625 6689400.9 24.4, 355625.7 6689398.4 24.4, 355625.9 6689398.4 24.4, 355626.1 6689397.3 24.4, 355622.9 6689396.7 24.4, 355622.7 6689397.6 24.4, 355622.4 6689397.5 24.4, 355622 6689399.1 24.4, 355618.5 6689414.1 24.4))
BATIMENT0000000302931636;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;16.3;8.1;24.5;24.8;8.7;Cadastre;A 1.0;POLYGON Z ((355650 6689410 24.5, 355657.7 6689410.5 24.5, 355657.5 6689403.1 24.5, 355650.4 6689403.5 24.5, 355650 6689410 24.5))
BATIMENT0000000302930371;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;14.8;8.0;22.8;23.3;8.8;Cadastre;A 1.0;POLYGON Z ((355631.2 6689418 22.8, 355634.8 6689419 22.8, 355635.5 6689415 22.8, 355636.6 6689415.1 22.8, 355637.3 6689404.4 22.8, 355636.2 6689404.4 22.8, 355632.3 6689404.3 22.8, 355631.7 6689407.4 22.8, 355629.7 6689417.5 22.8, 355631.2 6689418 22.8))
BATIMENT0000000302931630;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;13;20;14.6;7.8;22.4;25.0;8.2;Cadastre;A 1.0;POLYGON Z ((355661 6689389.4 22.4, 355661.2 6689394.8 22.4, 355670.6 6689394.5 22.4, 355670.5 6689389 22.4, 355661 6689389.4 22.4))
BATIMENT0000000302931638;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;9.8;7.6;17.5;23.5;8.3;Cadastre;A 1.0;POLYGON Z ((355692.3 6689384.8 17.5, 355695.3 6689385.2 17.5, 355695.1 6689393.3 17.5, 355712.1 6689397.7 17.5, 355710.6 6689407.7 17.5, 355717.1 6689408.8 17.5, 355718 6689403 17.5, 355727.2 6689403.5 17.5, 355727.5 6689385.8 17.5, 355694.8 6689377.3 17.5, 355693 6689381.1 17.5, 355692.3 6689384.8 17.5), (355702.9 6689387 17.5, 355713.4 6689389.7 17.5, 355712.4 6689393.9 17.5, 355701.8 6689391.2 17.5, 355702.9 6689387 17.5))
BATIMENT0000000302931626;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;14.6;7.8;22.5;25.9;8.7;Cadastre;A 1.0;POLYGON Z ((355676.4 6689388.7 22.5, 355670.5 6689389 22.5, 355670.6 6689394.5 22.5, 355670.7 6689398.7 22.5, 355673.8 6689398.6 22.5, 355676.7 6689398.5 22.5, 355676.4 6689388.7 22.5))
BATIMENT0000000302931628;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;20;20;15.8;7.9;23.7;25.5;8.8;Cadastre;A 1.0;POLYGON Z ((355669 6689398.7 23.7, 355669.1 6689402.5 23.7, 355670 6689402.5 23.7, 355673.8 6689402.4 23.7, 355673.8 6689398.6 23.7, 355670.7 6689398.7 23.7, 355670.6 6689394.5 23.7, 355661.2 6689394.8 23.7, 355650.9 6689395.2 23.7, 355650.4 6689403.5 23.7, 355657.5 6689403.1 23.7, 355662.8 6689402.9 23.7, 355662.8 6689402.8 23.7, 355666 6689402.6 23.7, 355666 6689398.9 23.7, 355669 6689398.7 23.7), (355662.7 6689398.8 23.7, 355662.7 6689399.3 23.7, 355661.3 6689399.4 23.7, 355661.2 6689396.1 23.7, 355665.8 6689396 23.7, 355665.8 6689398.7 23.7, 355662.7 6689398.8 23.7))
BATIMENT0000000302931629;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;9.7;8.1;17.8;25.7;8.7;Cadastre;A 1.0;POLYGON Z ((355690 6689384.6 17.8, 355689.8 6689388.9 17.8, 355683.7 6689388.9 17.8, 355683.6 6689398.4 17.8, 355683.3 6689423 17.8, 355694.3 6689423 17.8, 355695.1 6689393.3 17.8, 355695.3 6689385.2 17.8, 355692.3 6689384.8 17.8, 355690 6689384.6 17.8))
BATIMENT0000000302931639;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;10;20;11.5;7.9;19.5;24.9;8.5;Cadastre;A 1.0;POLYGON Z ((355694.2 6689423.6 19.5, 355697.3 6689423.9 19.5, 355714.2 6689425.6 19.5, 355715.4 6689418.4 19.5, 355717.1 6689408.8 19.5, 355710.6 6689407.7 19.5, 355712.1 6689397.7 19.5, 355695.1 6689393.3 19.5, 355694.3 6689423 19.5, 355694.2 6689423.6 19.5), (355706 6689412 19.5, 355705.3 6689417.5 19.5, 355699.6 6689417 19.5, 355699.8 6689411.2 19.5, 355706 6689412 19.5), (355705.1 6689399.3 19.5, 355703.8 6689407.7 19.5, 355701.8 6689407.5 19.5, 355699.9 6689408.7 19.5, 355700.4 6689398.2 19.5, 355705.1 6689399.3 19.5))
BATIMENT0000000302931625;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;15.7;8.4;24.2;28.5;8.9;Cadastre;A 1.0;POLYGON Z ((355678.5 6689398.5 24.2, 355680.1 6689400.6 24.2, 355680.3 6689409.7 24.2, 355677 6689409.8 24.2, 355676.9 6689398.5 24.2, 355676.7 6689398.5 24.2, 355673.8 6689398.6 24.2, 355673.8 6689402.4 24.2, 355673.9 6689412.3 24.2, 355674.4 6689412.3 24.2, 355674.6 6689423.4 24.2, 355683.3 6689423.2 24.2, 355683.3 6689423 24.2, 355683.6 6689398.4 24.2, 355678.5 6689398.5 24.2))
BATIMENT0000000302931627;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;4.0;00;00;12.8;8.4;21.2;25.2;9.2;Cadastre;A 1.0;POLYGON Z ((355669.1 6689402.5 21.2, 355666 6689402.6 21.2, 355662.8 6689402.8 21.2, 355662.8 6689402.9 21.2, 355657.5 6689403.1 21.2, 355657.7 6689410.5 21.2, 355658 6689417 21.2, 355658.3 6689423.7 21.2, 355658.1 6689423.7 21.2, 355658.2 6689424.6 21.2, 355666.3 6689424.3 21.2, 355666.4 6689424 21.2, 355674.6 6689423.4 21.2, 355674.4 6689412.3 21.2, 355673.9 6689412.3 21.2, 355673.8 6689402.4 21.2, 355670 6689402.5 21.2, 355669.1 6689402.5 21.2), (355669.2 6689405.5 21.2, 355669.3 6689413.3 21.2, 355668.5 6689413.4 21.2, 355668.5 6689416.6 21.2, 355666.2 6689416.7 21.2, 355666.2 6689405.7 21.2, 355669.2 6689405.5 21.2))
BATIMENT0000000302931644;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.4;8.7;22.1;;;Cadastre;;POLYGON Z ((355699.6 6689417 22.1, 355705.3 6689417.5 22.1, 355706 6689412 22.1, 355699.8 6689411.2 22.1, 355699.6 6689417 22.1))
BATIMENT0000000302931416;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;11.1;8.5;19.6;22.5;9.5;Cadastre;A 1.0;POLYGON Z ((355679.3 6689438.2 19.6, 355679.5 6689439.6 19.6, 355683.4 6689439.8 19.6, 355685.4 6689439.7 19.6, 355684.1 6689429.3 19.6, 355680 6689429.7 19.6, 355679.3 6689438.2 19.6))
BATIMENT0000000302930378;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1873-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;15.7;8.0;23.7;26.5;9.0;Cadastre;A 1.0;POLYGON Z ((355629.7 6689417.8 23.7, 355629.7 6689417.5 23.7, 355631.7 6689407.4 23.7, 355629.9 6689407 23.7, 355627 6689406.3 23.7, 355625.9 6689410.4 23.7, 355623.7 6689409.8 23.7, 355622.2 6689415.5 23.7, 355629.7 6689417.8 23.7))
BATIMENT0000000302930370;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;13.5;8.0;21.5;24.0;8.8;Cadastre;A 1.0;POLYGON Z ((355638.7 6689420.2 21.5, 355641.6 6689418.4 21.5, 355641.9 6689413.1 21.5, 355642.5 6689404.4 21.5, 355637.3 6689404.4 21.5, 355636.6 6689415.1 21.5, 355635.5 6689415 21.5, 355634.8 6689419 21.5, 355638.7 6689420.2 21.5))
BATIMENT0000000302931635;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;12.0;8.3;20.3;24.4;9.2;Cadastre;C 0.4;POLYGON Z ((355649.7 6689415.9 20.3, 355653.4 6689416.2 20.3, 355652.9 6689423.7 20.3, 355658.1 6689423.7 20.3, 355658.3 6689423.7 20.3, 355658 6689417 20.3, 355657.7 6689410.5 20.3, 355650 6689410 20.3, 355649.7 6689415.9 20.3))
BATIMENT0000000302931645;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;00;00;10.8;8.5;19.3;23.1;8.8;Cadastre;A 1.0;POLYGON Z ((355649.1 6689423.8 19.3, 355652.9 6689423.7 19.3, 355653.4 6689416.2 19.3, 355649.7 6689415.9 19.3, 355649.1 6689423.8 19.3))
BATIMENT0000000302931278;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;14.4;9.6;24.0;24.9;10.8;Cadastre;A 1.0;POLYGON Z ((355582.1 6689431.4 24, 355582.5 6689429.1 24, 355583.7 6689422.6 24, 355583.9 6689420.8 24, 355584.3 6689419.3 24, 355586.3 6689410.4 24, 355578.4 6689408.3 24, 355576.8 6689414.7 24, 355577 6689415.6 24, 355576.4 6689418.1 24, 355575.7 6689421.1 24, 355575.1 6689424.3 24, 355574.1 6689428.8 24, 355573.9 6689429.8 24, 355579.4 6689432.2 24, 355580.1 6689430.7 24, 355582.1 6689431.4 24), (355579.4 6689419.2 24, 355581.7 6689419.8 24, 355581 6689424.5 24, 355577.9 6689423.7 24, 355578.7 6689420.2 24, 355579.1 6689420.3 24, 355579.4 6689419.2 24))
BATIMENT0000000302931277;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.2;9.4;21.7;25.5;10.7;Cadastre;A 1.0;POLYGON Z ((355586.3 6689410.4 21.7, 355584.3 6689419.3 21.7, 355589.3 6689420.8 21.7, 355588.3 6689424 21.7, 355583.7 6689422.6 21.7, 355582.5 6689429.1 21.7, 355590 6689430.3 21.7, 355590.4 6689428.4 21.7, 355589.2 6689428 21.7, 355593.8 6689412.5 21.7, 355586.3 6689410.4 21.7))
BATIMENT0000000302931280;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;16.2;8.9;25.1;27.7;10.6;Cadastre;A 1.0;POLYGON Z ((355593.8 6689412.5 25.1, 355589.2 6689428 25.1, 355590.4 6689428.4 25.1, 355594.8 6689429.5 25.1, 355599.5 6689414.4 25.1, 355593.8 6689412.5 25.1))
BATIMENT0000000302931288;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.0;9.7;23.7;;;Cadastre;;POLYGON Z ((355575.7 6689421.1 23.7, 355574 6689420.6 23.7, 355573.2 6689423.8 23.7, 355575.1 6689424.3 23.7, 355575.7 6689421.1 23.7))
BATIMENT0000000302931294;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.5;9.5;28.1;28.7;10.0;Cadastre;;POLYGON Z ((355604 6689425.7 28.1, 355604.9 6689422.9 28.1, 355602.9 6689422.2 28.1, 355602 6689425 28.1, 355604 6689425.7 28.1))
BATIMENT0000000302931292;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;17.3;8.6;25.9;29.2;10.6;Cadastre;A 1.0;POLYGON Z ((355599.5 6689414.4 25.9, 355594.8 6689429.5 25.9, 355593.8 6689432.9 25.9, 355593.3 6689434.5 25.9, 355595.3 6689435.1 25.9, 355596.9 6689430.1 25.9, 355599.8 6689431 25.9, 355604.7 6689416.1 25.9, 355599.5 6689414.4 25.9))
BATIMENT0000000302931007;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;20;20;10.7;7.3;18.0;26.5;9.1;Cadastre;A 1.0;POLYGON Z ((355790.9 6689405.5 18, 355794.1 6689392.6 18, 355779.4 6689388.3 18, 355773.5 6689400 18, 355790.9 6689405.5 18), (355780.5 6689394 18, 355782.4 6689394.6 18, 355781.7 6689397 18, 355779.7 6689396.4 18, 355780.5 6689394 18))
BATIMENT0000000302931022;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;14;20;17.5;7.6;25.2;31.2;9.4;Cadastre;A 1.0;POLYGON Z ((355733.9 6689390.7 25.2, 355733 6689404.8 25.2, 355735 6689405.2 25.2, 355734.9 6689404.9 25.2, 355742.8 6689406.6 25.2, 355743.9 6689400.9 25.2, 355746 6689401.8 25.2, 355743.6 6689406.7 25.2, 355753.3 6689408.8 25.2, 355759 6689397.7 25.2, 355749.2 6689395 25.2, 355747.4 6689398.8 25.2, 355744.5 6689397.7 25.2, 355745.2 6689394 25.2, 355735.5 6689391.4 25.2, 355735.2 6689391.1 25.2, 355733.9 6689390.7 25.2))
BATIMENT0000000302931024;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.3;8.4;29.7;31.5;8.5;Cadastre;;POLYGON Z ((355746 6689401.8 29.7, 355743.9 6689400.9 29.7, 355742.8 6689406.6 29.7, 355743.6 6689406.7 29.7, 355746 6689401.8 29.7))
BATIMENT0000000302931009;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;11.8;8.8;20.6;32.1;9.3;Cadastre;A 1.0;POLYGON Z ((355767.5 6689412 20.6, 355788 6689417.2 20.6, 355790.9 6689405.5 20.6, 355773.5 6689400 20.6, 355767.5 6689412 20.6))
BATIMENT0000000302931023;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;24.4;8.0;32.5;35.0;9.8;Cadastre;A 1.0;POLYGON Z ((355735.1 6689423.6 32.5, 355743.2 6689423.6 32.5, 355747.1 6689421.3 32.5, 355753.3 6689408.8 32.5, 355743.6 6689406.7 32.5, 355742.8 6689406.6 32.5, 355734.9 6689404.9 32.5, 355735 6689405.2 32.5, 355735.1 6689423.6 32.5))
BATIMENT0000000302931010;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;10;20;20.4;8.4;28.8;32.0;9.6;Cadastre;A 1.0;POLYGON Z ((355763 6689420.9 28.8, 355764.4 6689423.7 28.8, 355785.8 6689424.3 28.8, 355786.4 6689424 28.8, 355788 6689417.2 28.8, 355767.5 6689412 28.8, 355763 6689420.9 28.8))
BATIMENT0000000302931204;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;29.0;4.0;00;00;16.6;10.0;26.6;28.5;10.1;Cadastre;A 1.0;POLYGON Z ((355761.3 6689431.6 26.6, 355757.4 6689433.9 26.6, 355751.5 6689445.7 26.6, 355760.5 6689450.3 26.6, 355763.5 6689444.4 26.6, 355764.8 6689446.2 26.6, 355765.2 6689446.2 26.6, 355766.9 6689448.9 26.6, 355770.7 6689446.5 26.6, 355772.3 6689447 26.6, 355773.5 6689443.5 26.6, 355777.3 6689432 26.6, 355761.3 6689431.6 26.6))
BATIMENT0000000302931203;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;17.3;10.0;27.3;31.2;10.0;Cadastre;A 1.0;POLYGON Z ((355785.7 6689434.9 27.3, 355784.8 6689435 27.3, 355777.3 6689432 27.3, 355773.5 6689443.5 27.3, 355775 6689444 27.3, 355774.4 6689447 27.3, 355774.4 6689451.1 27.3, 355786.1 6689451.3 27.3, 355785.7 6689434.9 27.3))
BATIMENT0000000302931206;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;9.3;13.7;27.5;10.1;Cadastre;;POLYGON Z ((355770.7 6689451.6 13.7, 355770.9 6689451.1 13.7, 355772.3 6689447 13.7, 355770.7 6689446.5 13.7, 355766.9 6689448.9 13.7, 355766.2 6689451 13.7, 355770.7 6689451.6 13.7))
BATIMENT0000000302931211;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;8.6;14.2;19.0;10.0;Cadastre;;POLYGON Z ((355766.3 6689453.3 14.2, 355765.2 6689452.9 14.2, 355763.3 6689458.3 14.2, 355764.5 6689458.7 14.2, 355766.3 6689453.3 14.2))
BATIMENT0000000302931298;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;12;20;17.9;8.3;26.2;29.1;10.5;Cadastre;A 1.0;POLYGON Z ((355601.8 6689431.7 26.2, 355600.3 6689436.8 26.2, 355604 6689437.9 26.2, 355605.1 6689433.9 26.2, 355604.6 6689433.7 26.2, 355605 6689432.3 26.2, 355604.5 6689432.1 26.2, 355609.6 6689417.9 26.2, 355609.7 6689417.7 26.2, 355604.7 6689416.1 26.2, 355599.8 6689431 26.2, 355601.8 6689431.7 26.2), (355602.9 6689422.2 26.2, 355604.9 6689422.9 26.2, 355604 6689425.7 26.2, 355602 6689425 26.2, 355602.9 6689422.2 26.2))
BATIMENT0000000302931297;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;17.1;8.4;25.5;29.1;10.4;Cadastre;A 1.0;POLYGON Z ((355604.5 6689432.1 25.5, 355605 6689432.3 25.5, 355604.6 6689433.7 25.5, 355605.1 6689433.9 25.5, 355604 6689437.9 25.5, 355603.7 6689438.9 25.5, 355608.3 6689440.3 25.5, 355609.2 6689437.5 25.5, 355614.2 6689438.6 25.5, 355615.4 6689434.9 25.5, 355616.6 6689431.1 25.5, 355619.5 6689421.3 25.5, 355609.6 6689417.9 25.5, 355604.5 6689432.1 25.5), (355608.5 6689427.9 25.5, 355611.7 6689428.2 25.5, 355609.4 6689435 25.5, 355606.5 6689434.1 25.5, 355608.5 6689427.9 25.5))
BATIMENT0000000302931279;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;10.3;24.6;25.7;10.6;Cadastre;;POLYGON Z ((355589.6 6689431.8 24.6, 355593.8 6689432.9 24.6, 355594.8 6689429.5 24.6, 355590.4 6689428.4 24.6, 355590 6689430.3 24.6, 355589.6 6689431.8 24.6))
BATIMENT0000000302931301;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;16.4;8.5;24.9;28.2;10.1;Cadastre;A 1.0;POLYGON Z ((355619.5 6689421.3 24.9, 355616.6 6689431.1 24.9, 355619.3 6689431.8 24.9, 355618.1 6689435.8 24.9, 355615.4 6689434.9 24.9, 355614.2 6689438.6 24.9, 355618.5 6689439.6 24.9, 355619.2 6689439.8 24.9, 355623.1 6689441 24.9, 355623.3 6689440.5 24.9, 355623.7 6689438.9 24.9, 355621.9 6689438.3 24.9, 355622.9 6689435.1 24.9, 355624.7 6689435.7 24.9, 355628.2 6689424.2 24.9, 355619.5 6689421.3 24.9))
BATIMENT0000000302931299;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.4;8.6;26.0;26.3;10.2;Cadastre;;POLYGON Z ((355609.4 6689435 26, 355611.7 6689428.2 26, 355608.5 6689427.9 26, 355606.5 6689434.1 26, 355609.4 6689435 26))
BATIMENT0000000302931293;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.3;10.1;23.5;24.8;10.5;Cadastre;;POLYGON Z ((355600.3 6689436.8 23.5, 355601.8 6689431.7 23.5, 355599.8 6689431 23.5, 355596.9 6689430.1 23.5, 355595.3 6689435.1 23.5, 355600.3 6689436.8 23.5))
BATIMENT0000000302931304;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;16.1;8.7;24.8;28.3;10.0;Cadastre;A 1.0;POLYGON Z ((355639.8 6689428.1 24.8, 355628.2 6689424.2 24.8, 355624.7 6689435.7 24.8, 355624.6 6689436.2 24.8, 355626.6 6689436.8 24.8, 355625.2 6689441.1 24.8, 355623.3 6689440.5 24.8, 355623.1 6689441 24.8, 355622 6689444.5 24.8, 355627.2 6689446.3 24.8, 355628 6689444 24.8, 355630.5 6689436.7 24.8, 355636.4 6689438.6 24.8, 355639.8 6689428.1 24.8))
BATIMENT0000000302931441;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;8.7;11.5;12.0;9.4;Cadastre;;POLYGON Z ((355655 6689435.3 11.5, 355654.2 6689435.2 11.5, 355654.1 6689436.1 11.5, 355654.9 6689436.1 11.5, 355655 6689435.3 11.5))
BATIMENT0000000302931290;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.2;9.1;29.3;32.5;10.7;Cadastre;;POLYGON Z ((355587.9 6689439.5 29.3, 355591.1 6689440.6 29.3, 355592.4 6689436.4 29.3, 355588.9 6689435.4 29.3, 355587.9 6689439.5 29.3))
BATIMENT0000000302931436;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;;;7.2;8.7;16.0;25.4;10.3;Cadastre;A 1.0;POLYGON Z ((355654.8 6689436.3 16, 355654.9 6689436.1 16, 355654.1 6689436.1 16, 355644.6 6689435 16, 355644.5 6689435.1 16, 355644.2 6689435.2 16, 355642.3 6689441 16, 355653 6689441.1 16, 355655.9 6689442 16, 355656.4 6689442.1 16, 355658.2 6689442.2 16, 355658.3 6689441.4 16, 355658.9 6689436.6 16, 355654.8 6689436.3 16))
BATIMENT0000000302931418;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;13.9;8.4;22.3;26.0;10.8;Cadastre;A 1.0;POLYGON Z ((355693.9 6689429.2 22.3, 355689.7 6689429.3 22.3, 355691.1 6689440.8 22.3, 355693 6689440.7 22.3, 355693.3 6689442.9 22.3, 355695.8 6689442.7 22.3, 355697.3 6689429.3 22.3, 355693.9 6689429.2 22.3))
BATIMENT0000000302931429;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;13.5;8.3;21.9;31.5;11.0;Cadastre;A 1.0;POLYGON Z ((355703.2 6689429.5 21.9, 355697.3 6689429.3 21.9, 355695.8 6689442.7 21.9, 355695.7 6689444.1 21.9, 355702.3 6689444.1 21.9, 355702.4 6689442 21.9, 355699.7 6689441.9 21.9, 355699.7 6689440.6 21.9, 355702.2 6689440.7 21.9, 355702.9 6689431.1 21.9, 355703.2 6689431.1 21.9, 355703.2 6689429.5 21.9))
BATIMENT0000000302931435;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.5;8.9;16.5;23.6;10.6;Cadastre;A 1.0;POLYGON Z ((355658.9 6689436.6 16.5, 355658.3 6689441.4 16.5, 355663.3 6689441.8 16.5, 355663.6 6689437.7 16.5, 355663.6 6689436.9 16.5, 355658.9 6689436.6 16.5))
BATIMENT0000000302931414;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;12.6;8.6;21.2;26.0;10.8;Cadastre;A 1.0;POLYGON Z ((355684.1 6689429.3 21.2, 355685.4 6689439.7 21.2, 355686.1 6689441.6 21.2, 355686.4 6689446.6 21.2, 355683.5 6689446.9 21.2, 355683.4 6689439.8 21.2, 355679.5 6689439.6 21.2, 355679.7 6689449.9 21.2, 355690.2 6689449 21.2, 355692.1 6689448.9 21.2, 355691.1 6689440.8 21.2, 355689.7 6689429.3 21.2, 355684.1 6689429.3 21.2))
BATIMENT0000000302931428;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;9.4;22.0;23.6;10.6;Cadastre;;POLYGON Z ((355663.6 6689437.7 22, 355663.3 6689441.8 22, 355667.6 6689442.2 22, 355668.4 6689442.3 22, 355668.6 6689438 22, 355663.6 6689437.7 22))
BATIMENT0000000302931419;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;10;20;12.7;10.4;23.1;31.2;11.2;Cadastre;C 0.6;POLYGON Z ((355668.6 6689438 23.1, 355670 6689438.1 23.1, 355669.5 6689444.7 23.1, 355668.9 6689444.7 23.1, 355668.7 6689445.8 23.1, 355671.6 6689446.1 23.1, 355670.4 6689456.7 23.1, 355677.2 6689458.2 23.1, 355677.3 6689456.6 23.1, 355677.5 6689454.4 23.1, 355677.8 6689450.1 23.1, 355679.7 6689449.9 23.1, 355679.5 6689439.6 23.1, 355679.3 6689438.2 23.1, 355673.5 6689437.7 23.1, 355673.7 6689435.4 23.1, 355671.4 6689435.1 23.1, 355671.8 6689429.8 23.1, 355664.1 6689429.9 23.1, 355664 6689431 23.1, 355663.6 6689436.9 23.1, 355663.6 6689437.7 23.1, 355668.6 6689438 23.1))
BATIMENT0000000302931417;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.6;9.6;21.2;23.5;11.0;Cadastre;;POLYGON Z ((355692.1 6689448.9 21.2, 355695.3 6689448.7 21.2, 355695.7 6689444.1 21.2, 355695.8 6689442.7 21.2, 355693.3 6689442.9 21.2, 355693 6689440.7 21.2, 355691.1 6689440.8 21.2, 355692.1 6689448.9 21.2))
BATIMENT0000000302931421;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;10.5;19.0;21.5;11.0;Cadastre;;POLYGON Z ((355696 6689448.6 19, 355702.2 6689449 19, 355702.3 6689444.1 19, 355695.7 6689444.1 19, 355695.3 6689448.7 19, 355696 6689448.6 19))
BATIMENT0000000302931425;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;9.8;22.0;29.5;11.2;Cadastre;;POLYGON Z ((355664.3 6689455.4 22, 355670.1 6689456.6 22, 355670.4 6689456.7 22, 355671.6 6689446.1 22, 355668.7 6689445.8 22, 355668.9 6689444.7 22, 355669.5 6689444.7 22, 355670 6689438.1 22, 355668.6 6689438 22, 355668.4 6689442.3 22, 355667.6 6689442.2 22, 355667.1 6689445.6 22, 355666.5 6689445.5 22, 355664.8 6689452.1 22, 355664.6 6689452.7 22, 355664.3 6689455.4 22))
BATIMENT0000000302931424;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;21.4;9.5;30.9;33.0;11.0;Cadastre;C 0.9;POLYGON Z ((355709 6689462.6 30.9, 355708.9 6689459.3 30.9, 355708.8 6689457.3 30.9, 355714.4 6689457.1 30.9, 355721.4 6689457.5 30.9, 355728.2 6689458.2 30.9, 355739.7 6689435.8 30.9, 355737 6689431.5 30.9, 355703.2 6689431.1 30.9, 355702.9 6689431.1 30.9, 355702.2 6689440.7 30.9, 355702.2 6689441.3 30.9, 355702.4 6689441.3 30.9, 355721.1 6689441.5 30.9, 355722.7 6689444.6 30.9, 355719.5 6689451.1 30.9, 355714.7 6689451.1 30.9, 355709.2 6689451.3 30.9, 355705.7 6689451.3 30.9, 355702.3 6689451.6 30.9, 355702.5 6689457.7 30.9, 355703.2 6689457.7 30.9, 355704.4 6689463.9 30.9, 355707.2 6689463.9 30.9, 355709 6689464.6 30.9, 355709 6689462.6 30.9))
BATIMENT0000000302931303;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.5;9.0;25.5;26.8;9.8;Cadastre;;POLYGON Z ((355625.2 6689441.1 25.5, 355626.6 6689436.8 25.5, 355624.6 6689436.2 25.5, 355623.7 6689438.9 25.5, 355623.3 6689440.5 25.5, 355625.2 6689441.1 25.5))
BATIMENT0000000302931305;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;00;00;16.0;9.1;25.1;29.3;9.9;Cadastre;A 1.0;POLYGON Z ((355636.4 6689438.6 25.1, 355630.5 6689436.7 25.1, 355628 6689444 25.1, 355634.1 6689446 25.1, 355636.4 6689438.6 25.1))
BATIMENT0000000302931440;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;9.6;16.2;16.6;10.5;Cadastre;;POLYGON Z ((355655.9 6689442 16.2, 355655.1 6689445.4 16.2, 355658 6689445.9 16.2, 355658.6 6689442.2 16.2, 355658.2 6689442.2 16.2, 355656.4 6689442.1 16.2, 355655.9 6689442 16.2))
BATIMENT0000000302931281;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;10;10;21.6;9.3;30.9;34.1;10.7;Cadastre;A 1.0;POLYGON Z ((355578.5 6689453.7 30.9, 355586 6689455.9 30.9, 355590.7 6689445.1 30.9, 355586.9 6689443.5 30.9, 355587.9 6689439.5 30.9, 355588.9 6689435.4 30.9, 355589.4 6689433.3 30.9, 355587.5 6689432.7 30.9, 355583.6 6689442.1 30.9, 355585.6 6689443 30.9, 355584.9 6689446 30.9, 355582.3 6689444.9 30.9, 355579.4 6689451.6 30.9, 355578.5 6689453.7 30.9))
BATIMENT0000000302931439;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;14.7;10.4;25.1;;;Cadastre;A 1.0;POLYGON Z ((355640.2 6689447.6 25.1, 355652.6 6689448.5 25.1, 355654.1 6689449 25.1, 355654.6 6689446.8 25.1, 355652.3 6689446.2 25.1, 355652.7 6689444.8 25.1, 355655.1 6689445.4 25.1, 355655.9 6689442 25.1, 355653 6689441.1 25.1, 355642.3 6689441 25.1, 355640.2 6689447.6 25.1))
BATIMENT0000000302931291;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;10;20;20.3;9.1;29.4;32.9;10.7;Cadastre;A 1.0;POLYGON Z ((355591.7 6689457.6 29.4, 355594.7 6689448.7 29.4, 355595.7 6689445.3 29.4, 355598.8 6689446.1 29.4, 355601.5 6689446.8 29.4, 355603.7 6689438.9 29.4, 355604 6689437.9 29.4, 355600.3 6689436.8 29.4, 355595.3 6689435.1 29.4, 355593.3 6689434.5 29.4, 355593 6689434.3 29.4, 355592.4 6689436.4 29.4, 355591.1 6689440.6 29.4, 355587.9 6689439.5 29.4, 355586.9 6689443.5 29.4, 355590.7 6689445.1 29.4, 355586 6689455.9 29.4, 355591.7 6689457.6 29.4))
BATIMENT0000000302931295;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;20.4;9.2;29.6;32.4;10.6;Cadastre;;POLYGON Z ((355594.7 6689448.7 29.6, 355597.7 6689449.7 29.6, 355598.8 6689446.1 29.6, 355595.7 6689445.3 29.6, 355594.7 6689448.7 29.6))
BATIMENT0000000302931306;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;16.5;9.6;26.1;29.7;10.1;Cadastre;A 1.0;POLYGON Z ((355634.1 6689446 26.1, 355628 6689444 26.1, 355627.2 6689446.3 26.1, 355625.4 6689451.5 26.1, 355631.7 6689453.7 26.1, 355634.1 6689446 26.1))
BATIMENT0000000302931296;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1732-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;18.1;10.2;28.4;31.7;10.8;Cadastre;A 1.0;POLYGON Z ((355601.5 6689460.6 28.4, 355608.3 6689440.3 28.4, 355603.7 6689438.9 28.4, 355601.5 6689446.8 28.4, 355598.8 6689446.1 28.4, 355597.7 6689449.7 28.4, 355594.7 6689448.7 28.4, 355591.7 6689457.6 28.4, 355601.5 6689460.6 28.4))
BATIMENT0000000302931300;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1744-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;12;20;19.8;8.9;28.7;32.0;10.7;Cadastre;A 1.0;POLYGON Z ((355601.5 6689460.6 28.7, 355611.8 6689463.8 28.7, 355619.2 6689439.8 28.7, 355618.5 6689439.6 28.7, 355614.2 6689438.6 28.7, 355609.2 6689437.5 28.7, 355608.3 6689440.3 28.7, 355601.5 6689460.6 28.7), (355610.6 6689446.3 28.7, 355613.4 6689447.3 28.7, 355611.7 6689452.2 28.7, 355609 6689451.3 28.7, 355610.6 6689446.3 28.7))
BATIMENT0000000302931437;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;10.5;18.2;21.6;11.1;Cadastre;;POLYGON Z ((355665.6 6689445.4 18.2, 355664.6 6689452.7 18.2, 355664.8 6689452.1 18.2, 355666.5 6689445.5 18.2, 355665.6 6689445.4 18.2))
BATIMENT0000000302931427;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;10.8;16.6;28.0;11.2;Cadastre;;POLYGON Z ((355662.4 6689460.4 16.6, 355665.6 6689461.2 16.6, 355669.2 6689462 16.6, 355670.1 6689456.6 16.6, 355664.3 6689455.4 16.6, 355664 6689455.3 16.6, 355662.4 6689460.4 16.6))
BATIMENT0000000302931423;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.7;9.8;28.6;29.7;10.7;Cadastre;;POLYGON Z ((355710.2 6689462.3 28.6, 355710.4 6689459.2 28.6, 355708.9 6689459.3 28.6, 355709 6689462.6 28.6, 355710.2 6689462.3 28.6))
BATIMENT0000000302931420;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1790-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;20.1;10.1;30.3;33.1;11.3;Cadastre;A 1.0;POLYGON Z ((355693.2 6689474.9 30.3, 355694.1 6689464.8 30.3, 355692.1 6689464.6 30.3, 355692 6689462.6 30.3, 355691.2 6689462.5 30.3, 355688.5 6689462.2 30.3, 355687.4 6689461.7 30.3, 355687 6689461.7 30.3, 355686.6 6689461.8 30.3, 355685.8 6689461.5 30.3, 355685.4 6689461.6 30.3, 355684.7 6689461.8 30.3, 355684.2 6689462.2 30.3, 355683.5 6689461.3 30.3, 355683.5 6689461.1 30.3, 355687 6689458.1 30.3, 355687.6 6689452.1 30.3, 355690.4 6689451.8 30.3, 355690.2 6689449 30.3, 355679.7 6689449.9 30.3, 355677.8 6689450.1 30.3, 355677.5 6689454.4 30.3, 355679.9 6689454.6 30.3, 355679.8 6689456.8 30.3, 355677.3 6689456.6 30.3, 355677.2 6689458.2 30.3, 355679.6 6689458.7 30.3, 355678 6689473.4 30.3, 355693.2 6689474.9 30.3))
BATIMENT0000000302931431;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.2;10.4;24.6;26.0;11.0;Cadastre;;POLYGON Z ((355665.2 6689463.2 24.6, 355668.9 6689464 24.6, 355669.2 6689462 24.6, 355665.6 6689461.2 24.6, 355665.2 6689463.2 24.6))
BATIMENT0000000302931415;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;20;15.4;10.6;26.0;31.0;11.2;Cadastre;A 1.0;POLYGON Z ((355701.6 6689475.9 26, 355701.6 6689476.4 26, 355708.4 6689476.8 26, 355708.5 6689476.1 26, 355709.1 6689469.5 26, 355709 6689464.6 26, 355707.2 6689463.9 26, 355704.4 6689463.9 26, 355703.2 6689457.7 26, 355702.5 6689457.7 26, 355702.3 6689451.6 26, 355702.2 6689449 26, 355696 6689448.6 26, 355695.3 6689448.7 26, 355692.1 6689448.9 26, 355690.2 6689449 26, 355690.4 6689451.8 26, 355691.2 6689462.5 26, 355692 6689462.6 26, 355692.1 6689464.6 26, 355694.1 6689464.8 26, 355693.2 6689474.9 26, 355701.6 6689475.9 26))
BATIMENT0000000302931430;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1626-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;;;15.9;10.4;26.3;32.3;11.2;Cadastre;A 1.0;POLYGON Z ((355667.5 6689472.8 26.3, 355677.9 6689473.9 26.3, 355678 6689473.4 26.3, 355679.6 6689458.7 26.3, 355677.2 6689458.2 26.3, 355670.4 6689456.7 26.3, 355670.1 6689456.6 26.3, 355669.2 6689462 26.3, 355668.9 6689464 26.3, 355667.5 6689472.5 26.3, 355667.5 6689472.8 26.3))
BATIMENT0000000302931432;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;14.8;10.4;25.2;27.0;11.0;Cadastre;A 1.0;POLYGON Z ((355667.5 6689472.5 25.2, 355668.9 6689464 25.2, 355665.2 6689463.2 25.2, 355665.6 6689461.2 25.2, 355662.4 6689460.4 25.2, 355660.7 6689471.8 25.2, 355667.5 6689472.5 25.2))
BATIMENT0000000302931422;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;20;20;19.9;10.3;30.2;34.0;11.3;Cadastre;A 0.5;POLYGON Z ((355716.5 6689477 30.2, 355719.7 6689475.1 30.2, 355727.3 6689460 30.2, 355714.4 6689458.9 30.2, 355711.2 6689465.4 30.2, 355709 6689464.6 30.2, 355709.1 6689469.5 30.2, 355708.5 6689476.1 30.2, 355716.5 6689477 30.2))
BATIMENT0000000302931343;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;19;20;9.2;10.7;19.9;25.5;12.3;Cadastre;A 1.0;POLYGON Z ((355667.1 6689494.5 19.9, 355667.6 6689491.7 19.9, 355669.3 6689492 19.9, 355670.6 6689492.3 19.9, 355672.4 6689492.8 19.9, 355676.5 6689494.1 19.9, 355675.9 6689496.5 19.9, 355679.7 6689497.5 19.9, 355680.4 6689491.3 19.9, 355682.3 6689482.1 19.9, 355682.8 6689482.1 19.9, 355683 6689480.7 19.9, 355669 6689478.2 19.9, 355668 6689485.6 19.9, 355665.4 6689485.4 19.9, 355664 6689494.1 19.9, 355664.9 6689494.3 19.9, 355667.1 6689494.5 19.9))
BATIMENT0000000302931434;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1650-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;18.8;9.4;28.3;29.4;10.8;Cadastre;A 1.0;POLYGON Z ((355637.7 6689455 28.3, 355646 6689456.2 28.3, 355647.2 6689456.4 28.3, 355647.7 6689453.4 28.3, 355649.8 6689453.8 28.3, 355650.2 6689451.7 28.3, 355655 6689452.5 28.3, 355657 6689453.1 28.3, 355657.5 6689450.3 28.3, 355657.3 6689450.2 28.3, 355654 6689449.3 28.3, 355654.1 6689449 28.3, 355652.6 6689448.5 28.3, 355640.2 6689447.6 28.3, 355637.7 6689455 28.3))
BATIMENT0000000302931302;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;10;20;15.9;9.8;25.7;29.1;10.5;Cadastre;A 1.0;POLYGON Z ((355620.3 6689466.4 25.7, 355625.4 6689451.5 25.7, 355627.2 6689446.3 25.7, 355622 6689444.5 25.7, 355623.1 6689441 25.7, 355619.2 6689439.8 25.7, 355611.8 6689463.8 25.7, 355620.3 6689466.4 25.7))
BATIMENT0000000302931307;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;17.9;9.8;27.7;30.0;10.5;Cadastre;C 0.9;POLYGON Z ((355625.5 6689468 27.7, 355630 6689458.7 27.7, 355631.7 6689453.7 27.7, 355625.4 6689451.5 27.7, 355620.3 6689466.4 27.7, 355625.5 6689468 27.7))
BATIMENT0000000302931433;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;18.5;9.9;28.5;31.2;10.7;Cadastre;A 1.0;POLYGON Z ((355651.6 6689471.2 28.5, 355651.7 6689471.2 28.5, 355651.8 6689470.9 28.5, 355655 6689452.5 28.5, 355650.2 6689451.7 28.5, 355649.8 6689453.8 28.5, 355649.7 6689454.6 28.5, 355651.2 6689454.8 28.5, 355650.5 6689458.5 28.5, 355648.9 6689458.2 28.5, 355648.7 6689459.7 28.5, 355647.4 6689466 28.5, 355644.4 6689465.7 28.5, 355643.9 6689470.3 28.5, 355651.6 6689471.2 28.5))
BATIMENT0000000302931426;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;14.8;10.4;25.2;28.0;11.1;Cadastre;A 1.0;POLYGON Z ((355660.7 6689471.8 25.2, 355662.4 6689460.4 25.2, 355664 6689455.3 25.2, 355657 6689453.1 25.2, 355655 6689452.5 25.2, 355651.8 6689470.9 25.2, 355660.7 6689471.8 25.2), (355657.2 6689460.4 25.2, 355657.2 6689460.2 25.2, 355658.7 6689460.4 25.2, 355658.2 6689464.2 25.2, 355655.4 6689463.9 25.2, 355655.6 6689462.6 25.2, 355655.9 6689462.6 25.2, 355656.1 6689462.5 25.2, 355656.4 6689462.3 25.2, 355656.5 6689462 25.2, 355656.5 6689461.6 25.2, 355656.5 6689461.4 25.2, 355656.4 6689461 25.2, 355656.7 6689461 25.2, 355656.9 6689461 25.2, 355657.1 6689460.9 25.2, 355657.2 6689460.8 25.2, 355657.2 6689460.6 25.2, 355657.2 6689460.4 25.2))
BATIMENT0000000302931438;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;19.8;9.8;29.7;32.5;10.5;Cadastre;A 1.0;POLYGON Z ((355632.4 6689468.2 29.7, 355632.7 6689469.1 29.7, 355643.9 6689470.3 29.7, 355644.4 6689465.7 29.7, 355647.4 6689466 29.7, 355648.7 6689459.7 29.7, 355645.5 6689459.2 29.7, 355646 6689456.2 29.7, 355637.7 6689455 29.7, 355632.4 6689468.2 29.7))
BATIMENT0000000302931338;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;15.8;10.2;26.0;29.0;10.9;Cadastre;A 1.0;POLYGON Z ((355629 6689473.8 26, 355627 6689480.4 26, 355637.3 6689482.3 26, 355638.2 6689474.8 26, 355629 6689473.8 26))
BATIMENT0000000302931140;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;7.0;00;00;21.7;8.9;30.6;33.8;11.7;Cadastre;C 1.0;POLYGON Z ((355591.7 6689500.5 30.6, 355592.1 6689499.5 30.6, 355592.4 6689499.5 30.6, 355592.8 6689498.9 30.6, 355594 6689496.1 30.6, 355593.8 6689496 30.6, 355595.2 6689493.1 30.6, 355598.1 6689486.7 30.6, 355598.3 6689486.8 30.6, 355601.7 6689479.3 30.6, 355587.8 6689468.9 30.6, 355587.6 6689469.3 30.6, 355587.2 6689470.2 30.6, 355586.9 6689470 30.6, 355578.6 6689487.2 30.6, 355588.9 6689492 30.6, 355585.9 6689498 30.6, 355591.7 6689500.5 30.6))
BATIMENT0000000302931334;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;16;23;17.7;10.5;28.2;30.7;11.0;Cadastre;A 1.0;POLYGON Z ((355624.5 6689488.2 28.2, 355636.3 6689491.1 28.2, 355637.3 6689482.3 28.2, 355627 6689480.4 28.2, 355624.5 6689488.2 28.2))
BATIMENT0000000302931336;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1680-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;4.0;10;20;16.1;10.4;26.6;29.4;12.3;Cadastre;A 1.0;POLYGON Z ((355636.3 6689491.1 26.6, 355637.1 6689491.4 26.6, 355643.8 6689493.1 26.6, 355648 6689493.1 26.6, 355647.6 6689499.2 26.6, 355648 6689499.2 26.6, 355652.5 6689499 26.6, 355652.3 6689499.8 26.6, 355652.8 6689503.8 26.6, 355656.4 6689503.7 26.6, 355657.2 6689499.1 26.6, 355657.6 6689496.6 26.6, 355658.2 6689496.6 26.6, 355658.2 6689496.3 26.6, 355658.7 6689493.2 26.6, 355664 6689494.1 26.6, 355665.4 6689485.4 26.6, 355668 6689485.6 26.6, 355669 6689478.2 26.6, 355658.6 6689477.1 26.6, 355658.6 6689477.2 26.6, 355644.4 6689475.7 26.6, 355644.4 6689475.5 26.6, 355638.2 6689474.8 26.6, 355637.3 6689482.3 26.6, 355636.3 6689491.1 26.6), (355644.7 6689483.2 26.6, 355658.2 6689484.8 26.6, 355657.2 6689492.5 26.6, 355649.4 6689492.7 26.6, 355649.5 6689491.8 26.6, 355648.2 6689491.6 26.6, 355648.2 6689491.1 26.6, 355646.5 6689491.1 26.6, 355643.9 6689491.1 26.6, 355644.7 6689483.2 26.6))
BATIMENT0000000302931205;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;23.2;9.7;33.0;35.1;11.1;Cadastre;A 1.0;POLYGON Z ((355767.3 6689469.7 33, 355770.7 6689469.7 33, 355774.3 6689469.8 33, 355774.5 6689467 33, 355777.8 6689467.2 33, 355777.6 6689469.8 33, 355786.7 6689469.8 33, 355786.1 6689451.3 33, 355774.4 6689451.1 33, 355770.9 6689451.1 33, 355770.7 6689451.6 33, 355769.9 6689454.1 33, 355769.6 6689455.2 33, 355772.7 6689455.2 33, 355772.8 6689455.6 33, 355773 6689456 33, 355773.2 6689456 33, 355773.2 6689459.7 33, 355768 6689459.7 33, 355765.4 6689467.3 33, 355765.8 6689467.5 33, 355767.3 6689469.7 33))
BATIMENT0000000302931207;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;12;20;18.7;10.0;28.7;32.2;11.1;Cadastre;C 0.8;POLYGON Z ((355741.5 6689465.5 28.7, 355746.1 6689467 28.7, 355745.2 6689479.5 28.7, 355752.9 6689480.2 28.7, 355752.2 6689472.2 28.7, 355756 6689472.3 28.7, 355757.4 6689470.8 28.7, 355757.6 6689467.4 28.7, 355765.2 6689468.5 28.7, 355765.5 6689468.5 28.7, 355765.8 6689467.5 28.7, 355765.4 6689467.3 28.7, 355768 6689459.7 28.7, 355769.6 6689455.2 28.7, 355769.9 6689454.1 28.7, 355766.5 6689453 28.7, 355766.3 6689453.3 28.7, 355764.5 6689458.7 28.7, 355764.2 6689459.6 28.7, 355759.7 6689459.2 28.7, 355756 6689459.1 28.7, 355760.5 6689450.3 28.7, 355751.5 6689445.7 28.7, 355741.5 6689465.5 28.7))
BATIMENT0000000302931210;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;7.0;00;00;19.2;10.0;29.2;33.2;11.1;Cadastre;C 0.7;POLYGON Z ((355736.3 6689475.6 29.2, 355738.1 6689479 29.2, 355745.2 6689479.5 29.2, 355746.1 6689467 29.2, 355741.5 6689465.5 29.2, 355736.3 6689475.6 29.2))
BATIMENT0000000302931208;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;17.7;10.4;28.1;30.2;11.4;Cadastre;A 1.0;POLYGON Z ((355765 6689469.6 28.1, 355764.3 6689474.2 28.1, 355763.3 6689481.1 28.1, 355763 6689481.2 28.1, 355762.9 6689482.1 28.1, 355780.6 6689482.9 28.1, 355787.1 6689483.4 28.1, 355786.7 6689469.8 28.1, 355777.6 6689469.8 28.1, 355777.4 6689473.2 28.1, 355771.3 6689473 28.1, 355770.7 6689469.7 28.1, 355767.3 6689469.7 28.1, 355765 6689469.6 28.1))
BATIMENT0000000302931209;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.1;10.8;24.0;29.5;11.4;Cadastre;;POLYGON Z ((355761.3 6689473.7 24, 355760.2 6689480.9 24, 355763 6689481.2 24, 355763.3 6689481.1 24, 355764.3 6689474.2 24, 355761.3 6689473.7 24))
BATIMENT0000000302930602;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;16.3;10.9;27.2;31.1;12.4;Cadastre;A 1.0;POLYGON Z ((355768.9 6689489.9 27.2, 355741.1 6689487.5 27.2, 355740.6 6689487.5 27.2, 355739.9 6689498.3 27.2, 355745.2 6689498.8 27.2, 355745.1 6689499.3 27.2, 355759.1 6689500.5 27.2, 355758.8 6689502.1 27.2, 355754.9 6689501.5 27.2, 355753.9 6689509.1 27.2, 355754.6 6689509.2 27.2, 355754.9 6689510.4 27.2, 355759.4 6689510.9 27.2, 355759.5 6689510 27.2, 355759.3 6689509.9 27.2, 355760.7 6689500.3 27.2, 355764.4 6689500.7 27.2, 355765 6689495.9 27.2, 355768 6689496.4 27.2, 355768.9 6689489.9 27.2))
BATIMENT0000000302930617;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;13;40;14.7;10.7;25.5;30.1;11.3;Cadastre;A 1.0;POLYGON Z ((355792.4 6689500.8 25.5, 355792.4 6689498.8 25.5, 355788.8 6689491.7 25.5, 355781.9 6689491.1 25.5, 355781.2 6689507 25.5, 355792 6689508.1 25.5, 355792.4 6689500.8 25.5))
BATIMENT0000000302930596;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;5.0;10;20;13.6;10.8;24.5;28.5;12.4;Cadastre;A 1.0;POLYGON Z ((355774.6 6689490.4 24.5, 355773.9 6689496.2 24.5, 355774.7 6689497.3 24.5, 355778.4 6689497.6 24.5, 355778.3 6689500.7 24.5, 355767.7 6689499.3 24.5, 355768 6689496.4 24.5, 355765 6689495.9 24.5, 355764.4 6689500.7 24.5, 355760.7 6689500.3 24.5, 355759.3 6689509.9 24.5, 355759.5 6689510 24.5, 355762.7 6689510.6 24.5, 355762.2 6689514.8 24.5, 355759 6689514.5 24.5, 355752.2 6689513.5 24.5, 355751.6 6689516.8 24.5, 355751.9 6689516.8 24.5, 355755 6689517.2 24.5, 355754.5 6689520.4 24.5, 355756.6 6689520.8 24.5, 355755.6 6689527.9 24.5, 355755.6 6689528.2 24.5, 355766.8 6689529.6 24.5, 355767.1 6689524.7 24.5, 355762.6 6689524.3 24.5, 355762.9 6689521.5 24.5, 355767.3 6689522.1 24.5, 355767.9 6689517.5 24.5, 355777.3 6689519.1 24.5, 355777.4 6689517.5 24.5, 355777.5 6689514.5 24.5, 355780.7 6689514.9 24.5, 355781.2 6689507 24.5, 355781.9 6689491.1 24.5, 355774.6 6689490.4 24.5))
BATIMENT0000000302930612;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;00;00;13.4;11.8;25.2;27.8;13.0;Cadastre;A 1.0;POLYGON Z ((355728.2 6689510.2 25.2, 355727.9 6689510.5 25.2, 355727.5 6689517.6 25.2, 355737 6689519.6 25.2, 355742.1 6689520.5 25.2, 355742.5 6689520.6 25.2, 355741.7 6689530.5 25.2, 355749.7 6689532.4 25.2, 355750.3 6689527.3 25.2, 355751.9 6689516.8 25.2, 355751.6 6689516.8 25.2, 355752.2 6689513.5 25.2, 355743.4 6689512.6 25.2, 355743.1 6689512.5 25.2, 355742.8 6689515.7 25.2, 355742.7 6689515.6 25.2, 355734.9 6689512.4 25.2, 355730.9 6689511.4 25.2, 355731 6689510.1 25.2, 355728.5 6689510 25.2, 355728.2 6689510.2 25.2))
BATIMENT0000000302930601;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;11.5;16.4;21.7;11.9;Cadastre;;POLYGON Z ((355777.1 6689524.6 16.4, 355776.8 6689524.6 16.4, 355776.8 6689524.9 16.4, 355779.3 6689525.2 16.4, 355779.6 6689517.8 16.4, 355777.4 6689517.5 16.4, 355777.3 6689519.1 16.4, 355777.1 6689524.6 16.4))
BATIMENT0000000302931353;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;20;20;18.7;10.7;29.5;34.2;11.8;Cadastre;A 1.0;POLYGON Z ((355683.9 6689492 29.5, 355683.6 6689493.5 29.5, 355683.9 6689493.5 29.5, 355683.8 6689494.5 29.5, 355685.3 6689494.8 29.5, 355685.6 6689493.7 29.5, 355687.5 6689493.9 29.5, 355689.6 6689482.6 29.5, 355682.8 6689482.1 29.5, 355682.3 6689482.1 29.5, 355680.4 6689491.3 29.5, 355683.9 6689492 29.5))
BATIMENT0000000302930621;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;20;20;20.0;10.9;31.0;33.5;12.0;Cadastre;A 1.0;POLYGON Z ((355731.6 6689497.4 31, 355731.6 6689497.1 31, 355739.9 6689498.3 31, 355740.6 6689487.5 31, 355741.1 6689487.5 31, 355741.3 6689485.2 31, 355732.2 6689484.6 31, 355730.1 6689497.3 31, 355731.6 6689497.4 31), (355736.9 6689493.6 31, 355739 6689493.9 31, 355738.7 6689495.8 31, 355736.7 6689495.6 31, 355736.9 6689493.6 31))
BATIMENT0000000302931361;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;21.7;10.9;32.7;35.5;12.0;Cadastre;A 1.0;POLYGON Z ((355687.1 6689496.3 32.7, 355695.8 6689498.2 32.7, 355695.8 6689498.4 32.7, 355698.5 6689498.7 32.7, 355699.3 6689499.1 32.7, 355699.1 6689499.5 32.7, 355705.1 6689502.4 32.7, 355712.5 6689488 32.7, 355710.7 6689484.6 32.7, 355689.6 6689482.6 32.7, 355687.5 6689493.9 32.7, 355687.1 6689496.3 32.7))
BATIMENT0000000302931346;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;11.2;17.5;19.3;12.3;Cadastre;;POLYGON Z ((355669.8 6689495.1 17.5, 355670.6 6689492.3 17.5, 355669.3 6689492 17.5, 355667.6 6689491.7 17.5, 355667.1 6689494.5 17.5, 355669.8 6689495.1 17.5))
BATIMENT0000000302931352;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;11.1;17.2;19.5;12.2;Cadastre;;POLYGON Z ((355671.6 6689495.6 17.2, 355673.6 6689496.1 17.2, 355675.9 6689496.5 17.2, 355676.5 6689494.1 17.2, 355672.4 6689492.8 17.2, 355671.6 6689495.6 17.2))
BATIMENT0000000302931337;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.0;11.2;19.2;24.0;12.3;Cadastre;A 1.0;POLYGON Z ((355664.9 6689494.3 19.2, 355664 6689494.1 19.2, 355658.7 6689493.2 19.2, 355658.2 6689496.3 19.2, 355664.1 6689497.7 19.2, 355664.9 6689494.3 19.2))
BATIMENT0000000302931339;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.8;11.3;18.1;23.0;12.5;Cadastre;A 1.0;POLYGON Z ((355664.1 6689497.7 18.1, 355658.2 6689496.3 18.1, 355658.2 6689496.6 18.1, 355657.6 6689496.6 18.1, 355657.2 6689499.1 18.1, 355663.4 6689500.5 18.1, 355664.1 6689497.7 18.1))
BATIMENT0000000302931347;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.3;11.2;15.6;17.0;12.1;Cadastre;A 1.0;POLYGON Z ((355672.3 6689502.4 15.6, 355679.1 6689503.8 15.6, 355679.7 6689497.5 15.6, 355675.9 6689496.5 15.6, 355673.6 6689496.1 15.6, 355672.3 6689502.4 15.6))
BATIMENT0000000302931340;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.3;11.5;17.9;23.5;12.6;Cadastre;A 1.0;POLYGON Z ((355663.4 6689500.5 17.9, 355657.2 6689499.1 17.9, 355656.4 6689503.7 17.9, 355659.4 6689504.6 17.9, 355660.2 6689502.9 17.9, 355662.8 6689503.4 17.9, 355663.4 6689500.5 17.9))
BATIMENT0000000302931358;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.7;13.0;16.7;;;Cadastre;A 1.0;POLYGON Z ((355671.8 6689505.5 16.7, 355678.7 6689506.8 16.7, 355680.2 6689503.9 16.7, 355679.1 6689503.8 16.7, 355672.3 6689502.4 16.7, 355671.8 6689505.5 16.7))
BATIMENT0000000302931341;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.2;10.4;22.7;23.7;11.1;Cadastre;;POLYGON Z ((355648.2 6689491.1 22.7, 355648.2 6689491.6 22.7, 355649.5 6689491.8 22.7, 355649.9 6689488 22.7, 355646.9 6689487.7 22.7, 355646.5 6689491.1 22.7, 355648.2 6689491.1 22.7))
BATIMENT0000000302931333;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;19.5;10.7;30.3;31.8;11.1;Cadastre;A 1.0;POLYGON Z ((355628.2 6689494.7 30.3, 355636.9 6689495.1 30.3, 355637.1 6689491.4 30.3, 355636.3 6689491.1 30.3, 355624.5 6689488.2 30.3, 355628.2 6689494.7 30.3))
BATIMENT0000000302931146;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1794-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;20;20;21.9;8.8;30.7;33.4;11.6;Cadastre;A 1.0;POLYGON Z ((355601.7 6689479.3 30.7, 355598.3 6689486.8 30.7, 355598.1 6689486.7 30.7, 355595.2 6689493.1 30.7, 355597.9 6689494.2 30.7, 355595.2 6689500 30.7, 355592.8 6689498.9 30.7, 355592.4 6689499.5 30.7, 355592.1 6689499.5 30.7, 355591.7 6689500.5 30.7, 355589.5 6689506.3 30.7, 355593.1 6689507.2 30.7, 355604.9 6689481.6 30.7, 355601.7 6689479.3 30.7))
BATIMENT0000000302931335;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;19.6;10.8;30.5;32.1;11.2;Cadastre;A 1.0;POLYGON Z ((355630.7 6689499.2 30.5, 355639.2 6689499 30.5, 355639.2 6689497.6 30.5, 355640.6 6689496.3 30.5, 355644.2 6689496.8 30.5, 355644.2 6689498.9 30.5, 355644.5 6689498.8 30.5, 355644.5 6689499.8 30.5, 355645.2 6689499.7 30.5, 355647.6 6689499.6 30.5, 355647.6 6689499.2 30.5, 355648 6689493.1 30.5, 355643.8 6689493.1 30.5, 355637.1 6689491.4 30.5, 355636.9 6689495.1 30.5, 355628.2 6689494.7 30.5, 355630.7 6689499.2 30.5))
BATIMENT0000000302931144;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;10;20;19.6;10.3;29.9;33.2;11.5;Cadastre;A 1.0;POLYGON Z ((355596.1 6689507.9 29.9, 355596.2 6689507.6 29.9, 355599.9 6689508.8 29.9, 355601 6689507.2 29.9, 355606.5 6689510.2 29.9, 355609.8 6689504.8 29.9, 355604.2 6689502.5 29.9, 355612.9 6689488.8 29.9, 355604.9 6689481.6 29.9, 355593.1 6689507.2 29.9, 355596.1 6689507.9 29.9), (355600.4 6689494.5 29.9, 355604.5 6689496.5 29.9, 355602.1 6689501.5 29.9, 355598 6689499.6 29.9, 355600.4 6689494.5 29.9))
BATIMENT0000000302931150;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;10;23;18.5;10.8;29.3;32.4;11.3;Cadastre;A 1.0;POLYGON Z ((355616.9 6689493.1 29.3, 355616.8 6689492.2 29.3, 355612.9 6689488.8 29.3, 355604.2 6689502.5 29.3, 355609.8 6689504.8 29.3, 355616.9 6689493.1 29.3))
BATIMENT0000000302930561;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;19.7;10.9;30.7;33.0;11.4;Cadastre;A 1.0;POLYGON Z ((355620 6689497.6 30.7, 355619.4 6689497.5 30.7, 355610.9 6689511.7 30.7, 355618.6 6689510 30.7, 355625.8 6689508.2 30.7, 355620 6689497.6 30.7))
BATIMENT0000000302931342;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;17.2;11.1;28.3;32.7;12.4;Cadastre;A 1.0;POLYGON Z ((355642.9 6689520.5 28.3, 355650.8 6689514.7 28.3, 355653.1 6689513 28.3, 355658.5 6689509.1 28.3, 355658.9 6689507.8 28.3, 355658.1 6689507.4 28.3, 355659 6689505.6 28.3, 355659.4 6689504.6 28.3, 355656.4 6689503.7 28.3, 355652.8 6689503.8 28.3, 355652.3 6689499.8 28.3, 355652.5 6689499 28.3, 355648 6689499.2 28.3, 355648.3 6689501.6 28.3, 355648.6 6689501.6 28.3, 355650.2 6689504.7 28.3, 355649.9 6689506 28.3, 355648.3 6689506.9 28.3, 355647 6689506.4 28.3, 355645.8 6689504.2 28.3, 355647.1 6689503.4 28.3, 355645.2 6689499.7 28.3, 355644.5 6689499.8 28.3, 355644.5 6689498.8 28.3, 355644.2 6689498.9 28.3, 355639.2 6689499 28.3, 355630.7 6689499.2 28.3, 355642.9 6689520.5 28.3))
BATIMENT0000000302930562;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.5;13.0;28.5;;;Cadastre;A 1.0;POLYGON Z ((355628.8 6689513.8 28.5, 355625.8 6689508.2 28.5, 355618.6 6689510 28.5, 355619.9 6689514.7 28.5, 355628 6689513.8 28.5, 355628.2 6689514 28.5, 355628.8 6689513.8 28.5))
BATIMENT0000000302930560;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;23;17.4;11.0;28.5;32.5;11.6;Cadastre;A 1.0;POLYGON Z ((355605.7 6689520.5 28.5, 355614.8 6689519.4 28.5, 355614.8 6689517.3 28.5, 355616.5 6689516.9 28.5, 355616.4 6689515 28.5, 355619.9 6689514.7 28.5, 355618.6 6689510 28.5, 355610.9 6689511.7 28.5, 355605.7 6689520.5 28.5))
BATIMENT0000000302930613;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;16.0;11.5;27.5;30.0;12.4;Cadastre;A 1.0;POLYGON Z ((355731 6689510.1 27.5, 355730.9 6689511.4 27.5, 355734.9 6689512.4 27.5, 355742.7 6689515.6 27.5, 355742.8 6689515.7 27.5, 355743.1 6689512.5 27.5, 355743.4 6689512.6 27.5, 355743.8 6689508.7 27.5, 355745.1 6689499.3 27.5, 355745.2 6689498.8 27.5, 355739.9 6689498.3 27.5, 355731.6 6689497.1 27.5, 355731.6 6689497.4 27.5, 355731 6689510.1 27.5))
BATIMENT0000000302931350;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 19:18:06;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.3;13.0;16.3;;;Cadastre;A 1.0;POLYGON Z ((355665.9 6689504 16.3, 355662.8 6689503.4 16.3, 355660.2 6689502.9 16.3, 355659.4 6689504.6 16.3, 355659 6689505.6 16.3, 355658.1 6689507.4 16.3, 355658.9 6689507.8 16.3, 355658.5 6689509.1 16.3, 355663.4 6689510.1 16.3, 355664.4 6689510.3 16.3, 355665.2 6689507.1 16.3, 355665.9 6689504 16.3))
BATIMENT0000000302931359;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.4;13.0;16.4;;;Cadastre;A 1.0;POLYGON Z ((355671.3 6689508.4 16.4, 355674 6689508.9 16.4, 355677.4 6689509.5 16.4, 355678.7 6689506.8 16.4, 355671.8 6689505.5 16.4, 355671.3 6689508.4 16.4))
BATIMENT0000000302931360;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.0;12.0;16.0;17.0;12.2;Cadastre;A 1.0;POLYGON Z ((355671.8 6689513.5 16, 355674.3 6689514.7 16, 355674.6 6689514.8 16, 355677.4 6689509.5 16, 355674 6689508.9 16, 355671.8 6689513.5 16))
BATIMENT0000000302931356;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.7;13.0;14.7;;;Cadastre;A 1.0;POLYGON Z ((355669 6689512.2 14.7, 355664.4 6689510.3 14.7, 355663.4 6689510.1 14.7, 355662.6 6689512 14.7, 355662.3 6689512.8 14.7, 355667.8 6689515 14.7, 355669 6689512.2 14.7))
BATIMENT0000000302931351;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;13.0;19.7;;;Cadastre;;POLYGON Z ((355660.4 6689511.4 19.7, 355659.7 6689513.3 19.7, 355661.3 6689515.3 19.7, 355662.3 6689512.8 19.7, 355662.6 6689512 19.7, 355660.4 6689511.4 19.7))
BATIMENT0000002011295158;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:59;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;21.1;12.2;;35.3;12.6;Imagerie aérienne;A 1.0;POLYGON Z ((355705.1 6689502.4 32.7, 355699.1 6689499.5 32.7, 355699.3 6689499.1 32.7, 355698.5 6689498.7 32.7, 355696.9 6689502.9 33.3, 355690.6 6689501.4 30.7, 355687.5 6689509.3 30.7, 355687.1 6689510.1 32.8, 355685.8 6689509.7 32.8, 355680.5 6689520.4 32.8, 355683.1 6689521.9 33.2, 355680.3 6689527.3 32.8, 355690.1 6689532 32.8, 355705.1 6689502.4 32.7))
BATIMENT0000000302931348;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;10;10;3.1;13.0;16.1;;;Cadastre;A 1.0;POLYGON Z ((355666.6 6689518 16.1, 355667.8 6689515 16.1, 355662.3 6689512.8 16.1, 355661.3 6689515.3 16.1, 355665.4 6689517.2 16.1, 355665.2 6689517.3 16.1, 355666.6 6689518 16.1))
BATIMENT0000000302930611;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;30;20;12.8;12.1;24.9;28.1;13.4;Cadastre;A 1.0;POLYGON Z ((355726.9 6689527.4 24.9, 355734.6 6689528.5 24.9, 355736.5 6689528.8 24.9, 355736.7 6689525.3 24.9, 355737.6 6689524.7 24.9, 355737.7 6689522.9 24.9, 355736.8 6689522 24.9, 355737 6689519.6 24.9, 355727.5 6689517.6 24.9, 355726.9 6689527.4 24.9))
BATIMENT0000000302931345;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;10;20;16.7;13.0;29.7;;;Cadastre;A 1.0;POLYGON Z ((355651.6 6689535.7 29.7, 355654.7 6689541.5 29.7, 355668.9 6689533 29.7, 355675.1 6689538.9 29.7, 355675.3 6689538.8 29.7, 355676.1 6689537.8 29.7, 355676.9 6689536.1 29.7, 355674.3 6689532.8 29.7, 355674.6 6689532.6 29.7, 355672.2 6689529.5 29.7, 355672.5 6689529.3 29.7, 355663.6 6689518.4 29.7, 355665.2 6689517.3 29.7, 355665.4 6689517.2 29.7, 355661.3 6689515.3 29.7, 355659.2 6689518.7 29.7, 355646.4 6689526.9 29.7, 355651.6 6689535.7 29.7))
BATIMENT0000000302930563;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;17.5;11.1;28.7;31.0;11.5;Cadastre;A 1.0;POLYGON Z ((355628.2 6689514 28.7, 355628 6689513.8 28.7, 355619.9 6689514.7 28.7, 355616.4 6689515 28.7, 355616.5 6689516.9 28.7, 355616.7 6689519.1 28.7, 355630 6689517 28.7, 355628.2 6689514 28.7))
BATIMENT0000000302931344;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;12;20;17.5;11.8;29.4;31.4;12.5;Cadastre;A 1.0;POLYGON Z ((355646.4 6689526.9 29.4, 355659.2 6689518.7 29.4, 355661.3 6689515.3 29.4, 355659.7 6689513.3 29.4, 355660.4 6689511.4 29.4, 355662.6 6689512 29.4, 355663.4 6689510.1 29.4, 355658.5 6689509.1 29.4, 355653.1 6689513 29.4, 355654.2 6689514.7 29.4, 355652 6689516.3 29.4, 355650.8 6689514.7 29.4, 355642.9 6689520.5 29.4, 355646.4 6689526.9 29.4))
BATIMENT0000000302930566;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.1;13.0;28.1;;;Cadastre;;POLYGON Z ((355614.8 6689517.3 28.1, 355614.8 6689519.4 28.1, 355615.2 6689519.3 28.1, 355616.7 6689519.1 28.1, 355616.5 6689516.9 28.1, 355614.8 6689517.3 28.1))
BATIMENT0000000302931141;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.0;11.2;26.2;31.9;12.1;Cadastre;;POLYGON Z ((355601.5 6689518.4 26.2, 355591 6689515.2 26.2, 355591.1 6689514.6 26.2, 355585.5 6689513.5 26.2, 355584.5 6689519.7 26.2, 355585.1 6689519.9 26.2, 355585.1 6689519.5 26.2, 355594.3 6689522 26.2, 355594.1 6689522.4 26.2, 355600.2 6689523.8 26.2, 355601.5 6689518.4 26.2))
BATIMENT0000000302931152;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;11.5;22.5;24.5;12.1;Cadastre;;POLYGON Z ((355587.2 6689523.8 22.5, 355587.5 6689521 22.5, 355584.9 6689520.7 22.5, 355584.6 6689523.6 22.5, 355587.2 6689523.8 22.5))
BATIMENT0000000302930564;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;12;20;17.7;11.3;29.1;30.8;11.9;Cadastre;A 1.0;POLYGON Z ((355630.5 6689517 29.1, 355630 6689517 29.1, 355616.7 6689519.1 29.1, 355615.2 6689519.3 29.1, 355615.6 6689521.5 29.1, 355615.9 6689523.2 29.1, 355616.9 6689527.9 29.1, 355621 6689527.3 29.1, 355620.5 6689524.2 29.1, 355624.1 6689523.6 29.1, 355624.5 6689526.8 29.1, 355625.8 6689526.6 29.1, 355625.9 6689526.9 29.1, 355635.1 6689525.2 29.1, 355630.5 6689517 29.1))
BATIMENT0000000302930565;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;12;20;14.9;13.1;28.0;;;Cadastre;A 1.0;POLYGON Z ((355604.5 6689529.3 28, 355604.6 6689529.6 28, 355613 6689528.5 28, 355616.9 6689527.9 28, 355615.9 6689523.2 28, 355613.8 6689523.6 28, 355613.5 6689521.9 28, 355615.6 6689521.5 28, 355615.2 6689519.3 28, 355614.8 6689519.4 28, 355605.7 6689520.5 28, 355604.5 6689529.3 28))
BATIMENT0000000302930572;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;11.5;28.5;29.2;11.7;Cadastre;;POLYGON Z ((355624.1 6689523.6 28.5, 355620.5 6689524.2 28.5, 355621 6689527.3 28.5, 355624.5 6689526.8 28.5, 355624.1 6689523.6 28.5))
BATIMENT0000000302931153;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;90;20;17.2;11.3;28.5;32.3;12.0;Cadastre;A 0.6;POLYGON Z ((355598.1 6689532.5 28.5, 355598.3 6689532.6 28.5, 355600.2 6689523.8 28.5, 355594.1 6689522.4 28.5, 355594.3 6689522 28.5, 355585.1 6689519.5 28.5, 355585.1 6689519.9 28.5, 355592.1 6689521.8 28.5, 355592 6689522.4 28.5, 355592.4 6689523.1 28.5, 355593.7 6689523.8 28.5, 355591.8 6689532.8 28.5, 355597.9 6689533.7 28.5, 355598.1 6689532.5 28.5))
BATIMENT0000000302930569;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.9;13.1;28.0;;;Cadastre;A 1.0;POLYGON Z ((355635.1 6689525.2 28, 355625.9 6689526.9 28, 355626.3 6689528.4 28, 355628.5 6689528.2 28, 355629 6689530.2 28, 355636.9 6689528.7 28, 355635.1 6689525.2 28))
BATIMENT0000000302930595;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;4.0;00;00;11.7;11.2;23.0;28.5;12.7;Cadastre;A 1.0;POLYGON Z ((355812.5 6689513.4 23, 355799.2 6689513.4 23, 355798.6 6689531.9 23, 355791.2 6689531.3 23, 355791.9 6689511 23, 355792 6689508.1 23, 355781.2 6689507 23, 355780.7 6689514.9 23, 355782.4 6689515.2 23, 355781.7 6689526.7 23, 355776.7 6689526.2 23, 355776.8 6689524.9 23, 355776.8 6689524.6 23, 355777.1 6689524.6 23, 355777.3 6689519.1 23, 355767.9 6689517.5 23, 355767.3 6689522.1 23, 355767.1 6689524.7 23, 355766.8 6689529.6 23, 355776.8 6689530.8 23, 355776.4 6689535.8 23, 355800.6 6689537.7 23, 355800.5 6689537.2 23, 355801.1 6689532.4 23, 355813.8 6689533.2 23, 355812.5 6689513.4 23))
BATIMENT0000000302930593;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.8;11.6;18.5;20.0;12.1;Cadastre;A 1.0;POLYGON Z ((355755.6 6689528.2 18.5, 355755.6 6689527.9 18.5, 355754.2 6689527.7 18.5, 355753.4 6689534.2 18.5, 355773.4 6689536.7 18.5, 355773.5 6689536.3 18.5, 355776.1 6689536.5 18.5, 355776.5 6689536.7 18.5, 355776.4 6689535.8 18.5, 355776.8 6689530.8 18.5, 355766.8 6689529.6 18.5, 355755.6 6689528.2 18.5))
BATIMENT0000000302930597;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;13.3;11.8;25.2;27.7;12.5;Cadastre;A 1.0;POLYGON Z ((355813.8 6689534.3 25.2, 355813.8 6689533.2 25.2, 355801.1 6689532.4 25.2, 355800.5 6689537.2 25.2, 355805.2 6689537.3 25.2, 355804.8 6689540.9 25.2, 355800.4 6689540.4 25.2, 355799.9 6689543.6 25.2, 355812 6689545.3 25.2, 355813.8 6689534.3 25.2))
BATIMENT0000000302930594;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;4.0;10;29;12.7;12.0;24.8;27.2;13.5;Cadastre;A 1.0;POLYGON Z ((355776.1 6689536.5 24.8, 355775.7 6689544.1 24.8, 355780.8 6689545.3 24.8, 355786.8 6689546.5 24.8, 355792.7 6689547.7 24.8, 355792.6 6689548.3 24.8, 355810.4 6689551.8 24.8, 355812 6689545.3 24.8, 355799.9 6689543.6 24.8, 355800.4 6689540.4 24.8, 355800.6 6689537.7 24.8, 355776.4 6689535.8 24.8, 355776.5 6689536.7 24.8, 355776.1 6689536.5 24.8), (355788.7 6689539.5 24.8, 355790.7 6689540.4 24.8, 355795.9 6689540.5 24.8, 355795.8 6689541.7 24.8, 355797 6689541.7 24.8, 355796.8 6689542.9 24.8, 355797.2 6689543.1 24.8, 355796.6 6689544.3 24.8, 355788.4 6689543.1 24.8, 355788.7 6689539.5 24.8))
BATIMENT0000000302930603;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;11.6;19.2;21.6;13.9;Cadastre;;POLYGON Z ((355747.2 6689548.8 19.2, 355758 6689550.1 19.2, 355775.2 6689552.4 19.2, 355775.7 6689551.2 19.2, 355775.9 6689545.7 19.2, 355775.6 6689545.6 19.2, 355768.5 6689544.7 19.2, 355768.3 6689545.4 19.2, 355748.1 6689542.9 19.2, 355747.2 6689548.8 19.2))
BATIMENT0000000302930620;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.1;13.1;26.2;26.7;13.5;Cadastre;;POLYGON Z ((355788.6 6689549.5 26.2, 355788.3 6689550.9 26.2, 355789.9 6689551.4 26.2, 355790.3 6689549.9 26.2, 355788.6 6689549.5 26.2))
BATIMENT0000000302930598;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;12;20;13.9;12.6;26.5;28.4;13.8;Cadastre;A 1.0;POLYGON Z ((355809.1 6689557.6 26.5, 355810.4 6689551.8 26.5, 355792.6 6689548.3 26.5, 355792.7 6689547.7 26.5, 355786.8 6689546.5 26.5, 355786.4 6689547.9 26.5, 355787.9 6689548.2 26.5, 355787.8 6689548.7 26.5, 355788.6 6689549.5 26.5, 355790.3 6689549.9 26.5, 355791.9 6689550.2 26.5, 355791.6 6689551.8 26.5, 355789.9 6689551.4 26.5, 355788.3 6689550.9 26.5, 355786.8 6689550.7 26.5, 355786.9 6689549.7 26.5, 355780.4 6689548.6 26.5, 355780.8 6689545.3 26.5, 355775.7 6689544.1 26.5, 355775.6 6689545.6 26.5, 355775.9 6689545.7 26.5, 355775.7 6689551.2 26.5, 355808.5 6689557.2 26.5, 355808.5 6689557.4 26.5, 355809.1 6689557.6 26.5))
BATIMENT0000000302930609;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;13.1;22.7;25.2;13.8;Cadastre;;POLYGON Z ((355739.6 6689553.1 22.7, 355739.2 6689555.7 22.7, 355746 6689556.8 22.7, 355746.4 6689554 22.7, 355739.6 6689553.1 22.7))
BATIMENT0000000302930606;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;12.5;19.7;21.6;14.3;Cadastre;;POLYGON Z ((355746.4 6689554 19.7, 355746 6689556.8 19.7, 355745.7 6689558.9 19.7, 355754.1 6689562.5 19.7, 355754.4 6689562.3 19.7, 355755.6 6689561.4 19.7, 355756.8 6689556.4 19.7, 355756.5 6689556.3 19.7, 355758 6689550.1 19.7, 355747.2 6689548.8 19.7, 355746.4 6689554 19.7))
BATIMENT0000000302931501;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;20.5;12.2;32.8;35.5;13.9;Cadastre;A 1.0;POLYGON Z ((355817.8 6689546.3 32.8, 355814.1 6689571.9 32.8, 355814.1 6689572 32.8, 355820.1 6689572.1 32.8, 355820.2 6689571.8 32.8, 355821.9 6689571.8 32.8, 355821.9 6689570.8 32.8, 355821.1 6689570.8 32.8, 355821.1 6689571 32.8, 355820.3 6689571 32.8, 355821.4 6689562.8 32.8, 355828.8 6689563.7 32.8, 355829 6689563.7 32.8, 355829.8 6689552.6 32.8, 355831.1 6689552.9 32.8, 355831.9 6689549.2 32.8, 355817.8 6689546.3 32.8))
BATIMENT0000000302930568;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;11.6;28.7;31.5;11.9;Cadastre;;POLYGON Z ((355629 6689530.2 28.7, 355628.5 6689528.2 28.7, 355626.3 6689528.4 28.7, 355626.8 6689530.6 28.7, 355629 6689530.2 28.7))
BATIMENT0000000302930567;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;12;20;13.8;11.6;25.5;28.6;11.9;Cadastre;A 1.0;POLYGON Z ((355613 6689528.5 25.5, 355613.6 6689534.2 25.5, 355615.7 6689533.9 25.5, 355616.4 6689535.5 25.5, 355617.3 6689539.2 25.5, 355619 6689538.8 25.5, 355628.3 6689536.6 25.5, 355626.8 6689530.6 25.5, 355626.3 6689528.4 25.5, 355625.9 6689526.9 25.5, 355625.8 6689526.6 25.5, 355624.5 6689526.8 25.5, 355621 6689527.3 25.5, 355616.9 6689527.9 25.5, 355613 6689528.5 25.5))
BATIMENT0000000302930570;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;;;14.9;13.1;28.0;;;Cadastre;A 1.0;POLYGON Z ((355636.9 6689528.7 28, 355629 6689530.2 28, 355626.8 6689530.6 28, 355628.3 6689536.6 28, 355628.9 6689536.5 28, 355629 6689536.7 28, 355629.8 6689539.6 28, 355640.9 6689536 28, 355636.9 6689528.7 28))
BATIMENT0000000302930571;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;30;13.1;13.1;26.2;;;Cadastre;A 1.0;POLYGON Z ((355603.5 6689529.5 26.2, 355603.1 6689542.2 26.2, 355610.5 6689540.9 26.2, 355611.2 6689540.7 26.2, 355617.3 6689539.2 26.2, 355616.4 6689535.5 26.2, 355613.8 6689536.1 26.2, 355613 6689536.3 26.2, 355612.7 6689535.5 26.2, 355612.5 6689534.3 26.2, 355613.6 6689534.2 26.2, 355613 6689528.5 26.2, 355604.6 6689529.6 26.2, 355604.5 6689529.3 26.2, 355603.5 6689529.5 26.2))
BATIMENT0000000302930588;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;12.3;11.8;24.2;28.0;12.3;Cadastre;A 1.0;POLYGON Z ((355630.9 6689543.1 24.2, 355629.8 6689539.6 24.2, 355629 6689536.7 24.2, 355628.9 6689536.5 24.2, 355628.3 6689536.6 24.2, 355619 6689538.8 24.2, 355619.4 6689541.1 24.2, 355622.2 6689540.4 24.2, 355623.6 6689544.7 24.2, 355623.6 6689544.8 24.2, 355630.9 6689543.1 24.2))
BATIMENT0000000302931155;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;30;20;13.4;11.5;25.0;31.5;12.3;Cadastre;A 1.0;POLYGON Z ((355596.8 6689548 25, 355597 6689548 25, 355597 6689547.4 25, 355596.6 6689547.4 25, 355597.9 6689533.7 25, 355583.7 6689532.9 25, 355583.7 6689534 25, 355582.6 6689546.7 25, 355582.4 6689547.5 25, 355596.7 6689548.5 25, 355596.8 6689548 25))
BATIMENT0000000302930581;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;5.7;11.8;17.5;22.5;12.0;Cadastre;C 0.5;POLYGON Z ((355611.2 6689540.7 17.5, 355611.7 6689542.7 17.5, 355611.9 6689543.4 17.5, 355619.5 6689541.2 17.5, 355619.4 6689541.1 17.5, 355619 6689538.8 17.5, 355617.3 6689539.2 17.5, 355611.2 6689540.7 17.5))
BATIMENT0000000302930587;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;14.8;13.1;27.9;;;Cadastre;A 1.0;POLYGON Z ((355640.9 6689536 27.9, 355629.8 6689539.6 27.9, 355630.9 6689543.1 27.9, 355635.2 6689542.1 27.9, 355636.1 6689544.8 27.9, 355639.1 6689544 27.9, 355639.8 6689545.4 27.9, 355639.4 6689545.6 27.9, 355639.9 6689546.3 27.9, 355641.1 6689545.7 27.9, 355640.6 6689544.8 27.9, 355644.6 6689542.8 27.9, 355640.9 6689536 27.9))
BATIMENT0000000302930573;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;11.7;21.0;25.5;12.0;Cadastre;;POLYGON Z ((355610.5 6689540.9 21, 355610.6 6689543 21, 355611.7 6689542.7 21, 355611.2 6689540.7 21, 355610.5 6689540.9 21))
BATIMENT0000000302930574;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;10;24;13.7;12.7;26.4;;;Cadastre;C 0.8;POLYGON Z ((355602.6 6689553.4 26.4, 355618.6 6689551.2 26.4, 355621 6689550.7 26.4, 355621.3 6689553 26.4, 355621.5 6689553.4 26.4, 355623.8 6689552.9 26.4, 355623.3 6689550.4 26.4, 355626.2 6689549.5 26.4, 355636.6 6689546.4 26.4, 355636.1 6689544.8 26.4, 355635.2 6689542.1 26.4, 355630.9 6689543.1 26.4, 355623.6 6689544.8 26.4, 355623.6 6689544.7 26.4, 355610.3 6689547.9 26.4, 355610.6 6689543 26.4, 355610.5 6689540.9 26.4, 355603.1 6689542.2 26.4, 355602.6 6689553.4 26.4))
BATIMENT0000000302931046;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;10;20;13.7;7.7;21.4;;;Cadastre;A 1.0;POLYGON Z ((355311.3 6689421.6 21.4, 355327.7 6689422.4 21.4, 355328.5 6689418.8 21.4, 355311.9 6689417.2 21.4, 355311.3 6689421.6 21.4))
BATIMENT0000000302931047;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;16.4;6.7;23.1;25.9;7.6;Cadastre;A 1.0;POLYGON Z ((355310.7 6689426.4 23.1, 355326.4 6689428.3 23.1, 355327.7 6689422.4 23.1, 355311.3 6689421.6 23.1, 355310.7 6689426.4 23.1))
BATIMENT0000000302931529;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;7.0;20;20;18.2;7.0;25.2;29.6;7.2;Cadastre;C 0.7;POLYGON Z ((355372.7 6689426.6 25.2, 355372.3 6689428.4 25.2, 355371.8 6689431.1 25.2, 355371.8 6689431.6 25.2, 355371.7 6689432.1 25.2, 355371.8 6689432.5 25.2, 355371.8 6689433 25.2, 355371.9 6689433.5 25.2, 355372.1 6689433.9 25.2, 355372.3 6689434.4 25.2, 355372.5 6689434.8 25.2, 355372.7 6689435.2 25.2, 355373 6689435.6 25.2, 355373.4 6689436 25.2, 355373.7 6689436.3 25.2, 355374.1 6689436.6 25.2, 355374.5 6689436.9 25.2, 355374.9 6689437.1 25.2, 355375.4 6689437.3 25.2, 355375.8 6689437.4 25.2, 355376.3 6689437.6 25.2, 355376.8 6689437.6 25.2, 355377.3 6689437.7 25.2, 355377.8 6689437.6 25.2, 355378.2 6689437.6 25.2, 355378.7 6689437.5 25.2, 355379.2 6689437.4 25.2, 355419.5 6689429.4 25.2, 355416.5 6689418.5 25.2, 355414.1 6689419.1 25.2, 355413.8 6689419.1 25.2, 355413.9 6689419.5 25.2, 355414.3 6689421.3 25.2, 355407.9 6689422.6 25.2, 355407.8 6689422.3 25.2, 355404.5 6689422.9 25.2, 355404.6 6689423.2 25.2, 355381.8 6689427.6 25.2, 355384 6689416.9 25.2, 355384.2 6689415.8 25.2, 355383 6689415.6 25.2, 355378.1 6689416.5 25.2, 355377.7 6689417.3 25.2, 355374.3 6689418.2 25.2, 355372.7 6689426.6 25.2))
BATIMENT0000000302931048;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;19.1;6.8;26.0;27.7;7.6;Cadastre;A 1.0;POLYGON Z ((355310 6689432.1 26, 355325.4 6689433.2 26, 355326.4 6689428.3 26, 355310.7 6689426.4 26, 355310 6689432.1 26))
BATIMENT0000000302931534;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;6.7;15.5;25.2;7.1;Cadastre;;POLYGON Z ((355372.7 6689426.6 15.5, 355370.1 6689426.1 15.5, 355369.3 6689429.8 15.5, 355369.1 6689431.3 15.5, 355369.1 6689433 15.5, 355369.6 6689434.4 15.5, 355370.3 6689434.8 15.5, 355371.2 6689434.4 15.5, 355372.1 6689433.9 15.5, 355371.9 6689433.5 15.5, 355371.8 6689433 15.5, 355371.8 6689432.5 15.5, 355371.7 6689432.1 15.5, 355371.8 6689431.6 15.5, 355371.8 6689431.1 15.5, 355372.3 6689428.4 15.5, 355372.7 6689426.6 15.5))
BATIMENT0000000302931672;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;10;20;18.5;7.1;25.6;27.9;9.0;Cadastre;A 1.0;POLYGON Z ((355305.1 6689470.2 25.6, 355315.5 6689472.1 25.6, 355317 6689471 25.6, 355323.4 6689441.4 25.6, 355322.5 6689439.7 25.6, 355309.2 6689439.1 25.6, 355305.1 6689470.2 25.6))
BATIMENT0000000302931451;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;20;22.3;6.3;28.7;31.7;7.4;Cadastre;A 1.0;POLYGON Z ((355366.7 6689455.7 28.7, 355363.5 6689472.2 28.7, 355375.3 6689474.4 28.7, 355374.4 6689478.9 28.7, 355381.9 6689478.8 28.7, 355383.7 6689478.8 28.7, 355383.8 6689481 28.7, 355388.2 6689481.1 28.7, 355394.6 6689481.3 28.7, 355393.8 6689473.3 28.7, 355393.4 6689473.3 28.7, 355393.3 6689472.9 28.7, 355393 6689472.9 28.7, 355392.1 6689463.8 28.7, 355391.6 6689463.7 28.7, 355391.2 6689459 28.7, 355391.7 6689458.8 28.7, 355391.5 6689455.8 28.7, 355389.8 6689456.2 28.7, 355389.6 6689454.9 28.7, 355391.3 6689454.4 28.7, 355390.5 6689447.4 28.7, 355368.1 6689454.3 28.7, 355366.7 6689455.7 28.7), (355378.6 6689462.6 28.7, 355383.4 6689463.5 28.7, 355383.1 6689465 28.7, 355388.2 6689466 28.7, 355388.5 6689464.5 28.7, 355390.4 6689464.7 28.7, 355389.8 6689467.6 28.7, 355389.4 6689469.5 28.7, 355379.7 6689467.5 28.7, 355377.7 6689467.2 28.7, 355378.6 6689462.6 28.7))
BATIMENT0000000302931465;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.1;6.3;27.4;27.7;7.0;Cadastre;;POLYGON Z ((355380.1 6689465.7 27.4, 355379.7 6689467.5 27.4, 355389.4 6689469.5 27.4, 355389.8 6689467.6 27.4, 355380.1 6689465.7 27.4))
BATIMENT0000000302931453;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;6.8;21.0;28.5;7.4;Cadastre;;POLYGON Z ((355383.8 6689481 21, 355383.7 6689478.8 21, 355381.9 6689478.8 21, 355381.4 6689480.2 21, 355383 6689480.6 21, 355382.2 6689484.5 21, 355382.5 6689484.5 21, 355387.4 6689485.4 21, 355387.4 6689485.1 21, 355388.2 6689481.1 21, 355383.8 6689481 21))
BATIMENT0000000302931454;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.8;6.1;12.0;19.7;7.4;Cadastre;B 0.4;POLYGON Z ((355388.2 6689481.1 12, 355387.4 6689485.1 12, 355400.4 6689487.4 12, 355401.3 6689482.3 12, 355399 6689482 12, 355399.1 6689481.8 12, 355394.6 6689481.3 12, 355388.2 6689481.1 12))
BATIMENT0000000302931443;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;7.0;14;24;19.6;6.6;26.2;32.2;8.3;Cadastre;A 1.0;POLYGON Z ((355445.1 6689456.9 26.2, 355446.4 6689451.3 26.2, 355445.5 6689451.2 26.2, 355436.6 6689451.1 26.2, 355436.7 6689450.5 26.2, 355433.4 6689450.4 26.2, 355433.4 6689451.1 26.2, 355419.2 6689451.6 26.2, 355416.8 6689452.3 26.2, 355417.2 6689457 26.2, 355417.4 6689460.3 26.2, 355422.7 6689460.1 26.2, 355435.2 6689460.1 26.2, 355444.5 6689460.7 26.2, 355445.1 6689456.9 26.2))
BATIMENT0000000302931444;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;6.0;10;30;10.1;5.9;16.1;27.3;8.5;Cadastre;A 1.0;POLYGON Z ((355447.5 6689442.4 16.1, 355434.3 6689439 16.1, 355390.5 6689447.4 16.1, 355391.3 6689454.4 16.1, 355391.5 6689455.8 16.1, 355391.7 6689458.8 16.1, 355391.2 6689459 16.1, 355391.6 6689463.7 16.1, 355392.1 6689463.8 16.1, 355393 6689472.9 16.1, 355393.3 6689472.9 16.1, 355393.4 6689473.3 16.1, 355393.8 6689473.3 16.1, 355420 6689473 16.1, 355418.6 6689468.1 16.1, 355417.9 6689464.1 16.1, 355417.6 6689463.1 16.1, 355415.5 6689463 16.1, 355414.4 6689460.3 16.1, 355413.5 6689460.5 16.1, 355414 6689463.1 16.1, 355402.9 6689463 16.1, 355396.9 6689462.8 16.1, 355396.8 6689461 16.1, 355397.1 6689460.9 16.1, 355395.9 6689454.7 16.1, 355399.4 6689453.8 16.1, 355399.4 6689454.1 16.1, 355403.6 6689453.3 16.1, 355403.6 6689453.1 16.1, 355415.2 6689450.8 16.1, 355415.2 6689451 16.1, 355416.3 6689450.9 16.1, 355416.3 6689450.6 16.1, 355417.7 6689450.3 16.1, 355417.8 6689450.5 16.1, 355421.9 6689449.8 16.1, 355421.8 6689449.6 16.1, 355434.1 6689447.1 16.1, 355437.4 6689448.2 16.1, 355436.7 6689450.5 16.1, 355436.6 6689451.1 16.1, 355445.5 6689451.2 16.1, 355445.7 6689450.6 16.1, 355447.5 6689442.4 16.1))
BATIMENT0000000302931682;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;9.0;7.6;16.7;26.0;10.0;Cadastre;A 1.0;POLYGON Z ((355453 6689464.4 16.7, 355464.9 6689467.5 16.7, 355469.7 6689467.4 16.7, 355473.9 6689450.3 16.7, 355457.3 6689447.4 16.7, 355453 6689464.4 16.7))
BATIMENT0000000302931446;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;7.2;14.8;;;Cadastre;;POLYGON Z ((355417.2 6689457 14.8, 355413.1 6689457.9 14.8, 355413.5 6689460.5 14.8, 355414.4 6689460.3 14.8, 355415.5 6689463 14.8, 355417.6 6689463.1 14.8, 355417.4 6689460.3 14.8, 355417.2 6689457 14.8))
BATIMENT0000000302931447;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;20.8;6.4;27.2;30.6;8.2;Cadastre;A 1.0;POLYGON Z ((355444.5 6689460.7 27.2, 355435.2 6689460.1 27.2, 355422.7 6689460.1 27.2, 355422.5 6689464.1 27.2, 355432.2 6689464.3 27.2, 355444.1 6689465.4 27.2, 355444.5 6689460.7 27.2))
BATIMENT0000000302931448;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;10;20;15.8;5.9;21.7;28.0;7.9;Cadastre;A 1.0;POLYGON Z ((355444.1 6689465.4 21.7, 355432.2 6689464.3 21.7, 355422.5 6689464.1 21.7, 355420.3 6689464.1 21.7, 355420.2 6689468.2 21.7, 355418.6 6689468.1 21.7, 355420 6689473 21.7, 355426 6689473.9 21.7, 355426.9 6689468.9 21.7, 355433.8 6689469.5 21.7, 355443.2 6689470.4 21.7, 355444.1 6689465.4 21.7))
BATIMENT0000000302931684;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;20;20;16.1;7.5;23.7;27.0;8.1;Cadastre;C 0.5;POLYGON Z ((355450.2 6689476.2 23.7, 355462.1 6689478.2 23.7, 355464.9 6689467.5 23.7, 355453 6689464.4 23.7, 355450.2 6689476.2 23.7))
BATIMENT0000000302931466;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;30;90;16.4;6.0;22.5;26.5;7.0;Cadastre;A 1.0;POLYGON Z ((355433.8 6689469.5 22.5, 355426.9 6689468.9 22.5, 355426 6689473.9 22.5, 355432.9 6689474.8 22.5, 355433.8 6689469.5 22.5))
BATIMENT0000000302931680;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;6.7;11.6;17.2;8.6;Cadastre;;POLYGON Z ((355477.3 6689478.4 11.6, 355478 6689467.8 11.6, 355472.2 6689467.6 11.6, 355471.6 6689478.1 11.6, 355477.3 6689478.4 11.6))
BATIMENT0000000302931449;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;19.7;6.4;26.2;28.8;7.6;Cadastre;A 1.0;POLYGON Z ((355443.2 6689470.4 26.2, 355433.8 6689469.5 26.2, 355432.9 6689474.8 26.2, 355432.6 6689476.2 26.2, 355441.8 6689477.5 26.2, 355443.2 6689470.4 26.2))
BATIMENT0000000302931681;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;20;20;19.5;7.3;26.8;30.0;9.8;Cadastre;C 0.8;POLYGON Z ((355495.1 6689468.7 26.8, 355483 6689468.1 26.8, 355482 6689486 26.8, 355494.1 6689485.9 26.8, 355494.2 6689485.7 26.8, 355495.1 6689468.7 26.8))
BATIMENT0000000302931139;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;17.1;9.8;26.9;32.1;12.2;Cadastre;A 1.0;POLYGON Z ((355606.5 6689510.2 26.9, 355601 6689507.2 26.9, 355599.9 6689508.8 26.9, 355596.2 6689507.6 26.9, 355596.1 6689507.9 26.9, 355593.1 6689507.2 26.9, 355589.5 6689506.3 26.9, 355591.7 6689500.5 26.9, 355585.9 6689498 26.9, 355588.9 6689492 26.9, 355578.6 6689487.2 26.9, 355586.9 6689470 26.9, 355515.6 6689436.9 26.9, 355515.1 6689436.7 26.9, 355514.6 6689436.4 26.9, 355514.1 6689436.3 26.9, 355513.6 6689436.1 26.9, 355513.1 6689436 26.9, 355512.5 6689436 26.9, 355512 6689436 26.9, 355511.5 6689436.1 26.9, 355510.9 6689436.1 26.9, 355510.4 6689436.3 26.9, 355509.9 6689436.5 26.9, 355509.4 6689436.7 26.9, 355509 6689437 26.9, 355508.5 6689437.3 26.9, 355508.1 6689437.6 26.9, 355507.7 6689438 26.9, 355507.4 6689438.4 26.9, 355507.1 6689438.9 26.9, 355506.8 6689439.3 26.9, 355506.6 6689439.8 26.9, 355506.4 6689440.3 26.9, 355506.3 6689440.8 26.9, 355506.2 6689441.4 26.9, 355503.1 6689490.5 26.9, 355512.4 6689490.9 26.9, 355513.9 6689491 26.9, 355529.5 6689498.2 26.9, 355530.2 6689498.6 26.9, 355530.1 6689503.1 26.9, 355530.1 6689505.5 26.9, 355552.4 6689509.5 26.9, 355553.3 6689504.9 26.9, 355564.4 6689507.7 26.9, 355572.4 6689509.4 26.9, 355572.8 6689509.1 26.9, 355581.9 6689512.4 26.9, 355581.9 6689512.8 26.9, 355585.5 6689513.5 26.9, 355591.1 6689514.6 26.9, 355591 6689515.2 26.9, 355601.5 6689518.4 26.9, 355606.5 6689510.2 26.9))
BATIMENT0000000302931683;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;12;29;9.4;7.0;16.5;29.7;9.6;Cadastre;A 1.0;POLYGON Z ((355497.3 6689495 16.5, 355497 6689494.5 16.5, 355497.8 6689493.6 16.5, 355497.4 6689485.5 16.5, 355494.2 6689485.7 16.5, 355494.1 6689485.9 16.5, 355482 6689486 16.5, 355477.5 6689485.9 16.5, 355477.3 6689478.4 16.5, 355471.6 6689478.1 16.5, 355466.3 6689478.1 16.5, 355466.2 6689478.9 16.5, 355465.3 6689485.9 16.5, 355465.1 6689486.6 16.5, 355474.8 6689486 16.5, 355477.9 6689490.7 16.5, 355481.1 6689495.5 16.5, 355485.9 6689502.6 16.5, 355497.3 6689495 16.5))
BATIMENT0000000302931142;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;13;20;16.0;9.3;25.3;27.9;9.8;Cadastre;A 1.0;POLYGON Z ((355502.7 6689490.5 25.3, 355501.7 6689505.9 25.3, 355505.1 6689506 25.3, 355511.6 6689506 25.3, 355511.9 6689499.8 25.3, 355512.2 6689499.9 25.3, 355512.3 6689497.2 25.3, 355513.2 6689497.3 25.3, 355513.2 6689497.5 25.3, 355513.9 6689497.5 25.3, 355513.9 6689497.3 25.3, 355514.2 6689497.3 25.3, 355514.4 6689494.3 25.3, 355514.2 6689494.3 25.3, 355514.2 6689494 25.3, 355513.8 6689494 25.3, 355513.9 6689493.1 25.3, 355513.9 6689493 25.3, 355512.2 6689492.9 25.3, 355512.4 6689490.9 25.3, 355503.1 6689490.5 25.3, 355502.7 6689490.5 25.3))
BATIMENT0000000302931143;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;9.5;18.3;30.2;10.4;Cadastre;;POLYGON Z ((355511.6 6689506 18.3, 355513.3 6689506 18.3, 355518.1 6689506.1 18.3, 355521.9 6689506.2 18.3, 355524.8 6689506.2 18.3, 355529.7 6689505.8 18.3, 355530.1 6689505.5 18.3, 355530.1 6689503.1 18.3, 355529.3 6689502.8 18.3, 355529.4 6689502.4 18.3, 355527.9 6689502 18.3, 355529.5 6689498.2 18.3, 355513.9 6689491 18.3, 355512.4 6689490.9 18.3, 355512.2 6689492.9 18.3, 355513.9 6689493 18.3, 355513.9 6689493.1 18.3, 355515.8 6689493.3 18.3, 355515.4 6689500 18.3, 355512.2 6689499.9 18.3, 355511.9 6689499.8 18.3, 355511.6 6689506 18.3))
BATIMENT0000000302931056;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;15;20;12.2;7.8;20.0;22.0;9.3;Cadastre;A 1.0;POLYGON Z ((355496.7 6689505.2 20, 355495.1 6689504.3 20, 355480 6689514.7 20, 355483.4 6689519.5 20, 355489.5 6689519.1 20, 355497 6689518.7 20, 355496.7 6689505.2 20))
BATIMENT0000000302931145;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.5;11.1;31.6;35.1;12.3;Cadastre;;POLYGON Z ((355585.5 6689513.5 31.6, 355581.9 6689512.8 31.6, 355581.9 6689512.4 31.6, 355572.8 6689509.1 31.6, 355572.4 6689509.4 31.6, 355564.4 6689507.7 31.6, 355553.3 6689504.9 31.6, 355552.4 6689509.5 31.6, 355558.2 6689510.3 31.6, 355558.8 6689510.9 31.6, 355563.2 6689511.6 31.6, 355562.6 6689513.9 31.6, 355563.2 6689514 31.6, 355563.2 6689514.1 31.6, 355565 6689514.4 31.6, 355571 6689515.2 31.6, 355571 6689515.6 31.6, 355571.8 6689515.7 31.6, 355572.2 6689514.8 31.6, 355572.6 6689514 31.6, 355574.7 6689515 31.6, 355577.3 6689516.1 31.6, 355578.7 6689516.7 31.6, 355578.5 6689517.8 31.6, 355580.7 6689518.6 31.6, 355581.5 6689518.9 31.6, 355584.2 6689519.6 31.6, 355584.5 6689519.7 31.6, 355585.5 6689513.5 31.6))
BATIMENT0000000302931148;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;8.8;23.0;29.3;9.9;Cadastre;;POLYGON Z ((355504.9 6689507.9 23, 355504 6689507.8 23, 355503.2 6689521.3 23, 355502.5 6689529.9 23, 355503.4 6689530 23, 355511.6 6689530.5 23, 355511.7 6689529.4 23, 355512.6 6689529.5 23, 355513.3 6689506 23, 355511.6 6689506 23, 355505.1 6689506 23, 355504.9 6689507.9 23))
BATIMENT0000000302931055;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;50;20;18.4;8.0;26.4;27.4;8.7;Cadastre;A 1.0;POLYGON Z ((355468.8 6689522.5 26.4, 355475.8 6689532.6 26.4, 355483.7 6689527.6 26.4, 355482.5 6689526.2 26.4, 355486.4 6689523.5 26.4, 355483.4 6689519.5 26.4, 355480 6689514.7 26.4, 355468.8 6689522.5 26.4))
BATIMENT0000000302931149;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;18.8;9.1;27.9;33.3;11.3;Cadastre;A 1.0;POLYGON Z ((355531.6 6689542.5 27.9, 355531.4 6689543.9 27.9, 355536.3 6689544.2 27.9, 355536.4 6689542.9 27.9, 355548.6 6689543.6 27.9, 355551.9 6689512.8 27.9, 355551.2 6689512.4 27.9, 355550.4 6689512 27.9, 355549.7 6689511.8 27.9, 355548.9 6689511.6 27.9, 355548.1 6689511.4 27.9, 355547.3 6689511.3 27.9, 355546.5 6689511.3 27.9, 355545.7 6689511.4 27.9, 355544.9 6689511.6 27.9, 355544.1 6689511.8 27.9, 355543.3 6689512 27.9, 355542.6 6689512.4 27.9, 355541.9 6689512.8 27.9, 355521.4 6689510.8 27.9, 355521.9 6689506.2 27.9, 355518.1 6689506.1 27.9, 355513.3 6689506 27.9, 355512.6 6689529.5 27.9, 355513.3 6689529.6 27.9, 355512.5 6689541 27.9, 355531.6 6689542.5 27.9))
BATIMENT0000000302931459;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;11.4;7.2;18.6;;;Cadastre;A 1.0;POLYGON Z ((355421.8 6689480.9 18.6, 355414 6689479.6 18.6, 355412.3 6689477.6 18.6, 355405 6689477 18.6, 355399.2 6689478.3 18.6, 355399.1 6689481.8 18.6, 355399 6689482 18.6, 355401.3 6689482.3 18.6, 355421.3 6689485.1 18.6, 355421.8 6689480.9 18.6))
BATIMENT0000000302931685;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;35;90;19.9;7.0;26.9;27.6;8.0;Cadastre;A 1.0;POLYGON Z ((355448.9 6689481.8 26.9, 355465.3 6689485.9 26.9, 355466.2 6689478.9 26.9, 355462.1 6689478.2 26.9, 355450.2 6689476.2 26.9, 355448.9 6689481.8 26.9))
BATIMENT0000000302931450;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;15.6;6.0;21.6;24.2;7.7;Cadastre;A 1.0;POLYGON Z ((355421.3 6689485.1 21.6, 355426.5 6689486.2 21.6, 355438.9 6689488.6 21.6, 355441.8 6689477.5 21.6, 355432.6 6689476.2 21.6, 355429.4 6689477.1 21.6, 355422.4 6689475.9 21.6, 355421.8 6689480.9 21.6, 355421.3 6689485.1 21.6), (355428.4 6689479.9 21.6, 355431.5 6689480.4 21.6, 355430.6 6689484.2 21.6, 355428 6689483.7 21.6, 355428.4 6689479.9 21.6))
BATIMENT0000000302931686;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;30;16.3;7.4;23.7;27.6;8.0;Cadastre;A 1.0;POLYGON Z ((355447.3 6689488.2 23.7, 355446.3 6689488 23.7, 355446.3 6689488.4 23.7, 355455.6 6689490.7 23.7, 355454.8 6689493.3 23.7, 355453.9 6689496.3 23.7, 355458.1 6689497.2 23.7, 355460.4 6689487.8 23.7, 355464.8 6689488.7 23.7, 355465.1 6689486.6 23.7, 355465.3 6689485.9 23.7, 355448.9 6689481.8 23.7, 355447.3 6689488.2 23.7))
BATIMENT0000000302931460;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;16;20;12.2;6.2;18.4;22.2;7.7;Cadastre;A 1.0;POLYGON Z ((355438.5 6689488.8 18.4, 355438.8 6689488.9 18.4, 355438.9 6689488.6 18.4, 355426.5 6689486.2 18.4, 355425.5 6689490.1 18.4, 355422 6689489.2 18.4, 355422.5 6689486.9 18.4, 355408.7 6689484.7 18.4, 355407.7 6689490.5 18.4, 355417.8 6689491.7 18.4, 355421.8 6689492.5 18.4, 355421.8 6689493.1 18.4, 355423.7 6689493.4 18.4, 355436.8 6689495.8 18.4, 355438.5 6689488.8 18.4))
BATIMENT0000000302931461;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;7.2;15.4;;;Cadastre;;POLYGON Z ((355416.1 6689502.1 15.4, 355417.4 6689496.5 15.4, 355416.7 6689496.4 15.4, 355417.8 6689491.7 15.4, 355407.7 6689490.5 15.4, 355406.8 6689490.5 15.4, 355406.1 6689494.9 15.4, 355405.5 6689494.9 15.4, 355405.4 6689495.9 15.4, 355405.9 6689496 15.4, 355405.2 6689500.2 15.4, 355406 6689500.4 15.4, 355408.8 6689500.9 15.4, 355416.1 6689502.1 15.4))
BATIMENT0000000302931467;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1450-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;12;13.3;6.6;20.0;23.4;7.5;Cadastre;B 0.5;POLYGON Z ((355436.3 6689496.3 20, 355436.7 6689496.3 20, 355436.8 6689495.8 20, 355423.7 6689493.4 20, 355422.2 6689500.9 20, 355427.4 6689502 20, 355431.3 6689502.1 20, 355435 6689502.8 20, 355436.3 6689496.3 20))
BATIMENT0000000302931687;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;7.5;14.5;21.0;8.2;Cadastre;;POLYGON Z ((355466.7 6689491.1 14.5, 355463.4 6689505.4 14.5, 355465.2 6689506.6 14.5, 355481.1 6689495.5 14.5, 355477.9 6689490.7 14.5, 355466.7 6689491.1 14.5))
BATIMENT0000000302931689;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;20;14.5;7.2;21.7;27.3;7.8;Cadastre;A 1.0;POLYGON Z ((355440.8 6689509.9 21.7, 355450.7 6689512.4 21.7, 355454.1 6689513.3 21.7, 355458.1 6689497.2 21.7, 355453.9 6689496.3 21.7, 355454.8 6689493.3 21.7, 355455.6 6689490.7 21.7, 355446.3 6689488.4 21.7, 355440.8 6689509.9 21.7))
BATIMENT0000000302931463;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.1;6.5;19.7;24.2;6.9;Cadastre;;POLYGON Z ((355427.4 6689502 19.7, 355422.2 6689500.9 19.7, 355421.7 6689503.1 19.7, 355426.9 6689504 19.7, 355427.4 6689502 19.7))
BATIMENT0000000302931452;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;22.2;7.2;29.5;33.1;7.7;Cadastre;C 0.6;POLYGON Z ((355371.3 6689494.7 29.5, 355382.7 6689499.4 29.5, 355386.3 6689490.7 29.5, 355386.1 6689490.6 29.5, 355381.6 6689488.8 29.5, 355382.5 6689484.5 29.5, 355382.2 6689484.5 29.5, 355383 6689480.6 29.5, 355381.4 6689480.2 29.5, 355381.9 6689478.8 29.5, 355374.4 6689478.9 29.5, 355371.3 6689494.7 29.5))
BATIMENT0000000302931455;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;18.6;7.2;25.8;30.1;7.4;Cadastre;B 0.9;POLYGON Z ((355393.7 6689504 25.8, 355394 6689504.1 25.8, 355394.6 6689504.3 25.8, 355394.7 6689503.9 25.8, 355395.9 6689504.3 25.8, 355396 6689503.9 25.8, 355397 6689499.2 25.8, 355397.9 6689495.3 25.8, 355389 6689491.7 25.8, 355389.2 6689490.9 25.8, 355386.5 6689489.8 25.8, 355386.1 6689490.6 25.8, 355386.3 6689490.7 25.8, 355382.7 6689499.4 25.8, 355393.7 6689504 25.8))
BATIMENT0000000302931457;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.4;7.2;15.6;;;Cadastre;;POLYGON Z ((355397 6689499.2 15.6, 355404.1 6689500.5 15.6, 355405 6689500.7 15.6, 355405.2 6689500.2 15.6, 355405.9 6689496 15.6, 355405.4 6689495.9 15.6, 355399.1 6689494.8 15.6, 355398.3 6689494.7 15.6, 355397.9 6689495.3 15.6, 355397 6689499.2 15.6))
BATIMENT0000000302931456;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;6.0;13.8;20.0;6.9;Cadastre;;POLYGON Z ((355396 6689503.9 13.8, 355403.3 6689505 13.8, 355404.1 6689500.5 13.8, 355397 6689499.2 13.8, 355396 6689503.9 13.8))
BATIMENT0000000302931458;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;14.9;6.2;21.2;23.2;7.3;Cadastre;B 0.8;POLYGON Z ((355390.9 6689511.5 21.2, 355411.2 6689519.7 21.2, 355415.9 6689507.4 21.2, 355403.2 6689505.3 21.2, 355403.3 6689505 21.2, 355396 6689503.9 21.2, 355395.9 6689504.3 21.2, 355394.7 6689503.9 21.2, 355394.6 6689504.3 21.2, 355394 6689504.1 21.2, 355390.9 6689511.5 21.2))
BATIMENT0000000302930418;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;;;17.8;6.6;24.4;32.5;7.4;Cadastre;A 1.0;POLYGON Z ((355376.2 6689532.2 24.4, 355402.4 6689535 24.4, 355402.6 6689533.7 24.4, 355402.2 6689533.3 24.4, 355401.3 6689532.5 24.4, 355404.9 6689524.7 24.4, 355368.3 6689509.7 24.4, 355364.4 6689530.9 24.4, 355376.2 6689532.2 24.4), (355378.3 6689519.9 24.4, 355378.4 6689519.9 24.4, 355378.7 6689520 24.4, 355378.8 6689520 24.4, 355379.1 6689520.1 24.4, 355379.5 6689520.3 24.4, 355379.7 6689520.4 24.4, 355380 6689520.7 24.4, 355380.2 6689520.9 24.4, 355380.3 6689521 24.4, 355380.5 6689521.2 24.4, 355380.7 6689521.5 24.4, 355380.8 6689521.8 24.4, 355380.9 6689522 24.4, 355380.9 6689522.1 24.4, 355381 6689522.4 24.4, 355381 6689522.7 24.4, 355381 6689523 24.4, 355381 6689523.4 24.4, 355380.9 6689523.6 24.4, 355380.9 6689523.9 24.4, 355380.8 6689524 24.4, 355380.6 6689524.4 24.4, 355380.5 6689524.6 24.4, 355380.4 6689524.8 24.4, 355380.2 6689524.9 24.4, 355380.1 6689525.1 24.4, 355379.8 6689525.3 24.4, 355379.6 6689525.4 24.4, 355379.4 6689525.6 24.4, 355379.2 6689525.6 24.4, 355379 6689525.7 24.4, 355378.8 6689525.8 24.4, 355378.3 6689525.9 24.4, 355377.9 6689525.9 24.4, 355377.6 6689525.9 24.4, 355377.4 6689525.8 24.4, 355377.3 6689525.8 24.4, 355378.3 6689519.9 24.4))
BATIMENT0000000302930417;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;13.4;7.8;21.2;;;Cadastre;C 0.8;POLYGON Z ((355371.5 6689533.3 21.2, 355371.5 6689533.4 21.2, 355363.9 6689532.8 21.2, 355364.5 6689539.6 21.2, 355376.5 6689540.8 21.2, 355382.8 6689542 21.2, 355383.5 6689535.3 21.2, 355371.5 6689533.3 21.2))
BATIMENT0000000302930421;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;6.5;13.5;18.8;6.7;Cadastre;;POLYGON Z ((355383.5 6689535.3 13.5, 355382.8 6689542 13.5, 355386.2 6689542.5 13.5, 355387.4 6689535.6 13.5, 355383.5 6689535.3 13.5))
BATIMENT0000000302930422;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;6.4;14.0;19.2;6.7;Cadastre;;POLYGON Z ((355387.4 6689535.6 14, 355386.2 6689542.5 14, 355386.5 6689542.6 14, 355389.5 6689543.2 14, 355390.3 6689543.3 14, 355391.3 6689536 14, 355387.4 6689535.6 14))
BATIMENT0000000302930414;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;30;20;9.1;7.8;16.9;;;Cadastre;A 1.0;POLYGON Z ((355393.6 6689544 16.9, 355393.7 6689542.1 16.9, 355401.5 6689542.9 16.9, 355401.8 6689540.2 16.9, 355402.1 6689537 16.9, 355391.3 6689536 16.9, 355390.3 6689543.3 16.9, 355393.3 6689544 16.9, 355393.6 6689544 16.9))
BATIMENT0000000302931688;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;10;20;12.0;7.5;19.6;24.2;9.0;Cadastre;A 0.6;POLYGON Z ((355485.9 6689502.6 19.6, 355481.1 6689495.5 19.6, 355465.2 6689506.6 19.6, 355463.4 6689505.4 19.6, 355466.7 6689491.1 19.6, 355477.9 6689490.7 19.6, 355474.8 6689486 19.6, 355465.1 6689486.6 19.6, 355464.8 6689488.7 19.6, 355460.4 6689487.8 19.6, 355458.1 6689497.2 19.6, 355454.1 6689513.3 19.6, 355458.1 6689514.4 19.6, 355461.3 6689519.2 19.6, 355485.9 6689502.6 19.6))
BATIMENT0000000302931462;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;20;20;14.7;6.0;20.8;23.8;7.3;Cadastre;A 1.0;POLYGON Z ((355433.4 6689510.5 20.8, 355435 6689502.8 20.8, 355431.3 6689502.1 20.8, 355427.4 6689502 20.8, 355426.9 6689504 20.8, 355421.7 6689503.1 20.8, 355421.3 6689503 20.8, 355420.6 6689506.5 20.8, 355415.4 6689505.6 20.8, 355416.1 6689502.1 20.8, 355408.8 6689500.9 20.8, 355408 6689504.4 20.8, 355407.2 6689504.2 20.8, 355407.4 6689502.5 20.8, 355405.6 6689502.2 20.8, 355406 6689500.4 20.8, 355405.2 6689500.2 20.8, 355405 6689500.7 20.8, 355404.1 6689500.5 20.8, 355403.3 6689505 20.8, 355403.2 6689505.3 20.8, 355415.9 6689507.4 20.8, 355431.5 6689509.9 20.8, 355431.6 6689510.1 20.8, 355433.4 6689510.5 20.8))
BATIMENT0000000302931690;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;7.4;18.2;25.7;7.7;Cadastre;;POLYGON Z ((355450.7 6689512.4 18.2, 355450.1 6689514 18.2, 355453.6 6689515.1 18.2, 355454.1 6689513.3 18.2, 355450.7 6689512.4 18.2))
BATIMENT0000000302931464;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1858-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;16.9;6.8;23.8;25.5;7.5;Cadastre;A 1.0;POLYGON Z ((355427.9 6689526.5 23.8, 355429.2 6689525.8 23.8, 355431.6 6689510.1 23.8, 355431.5 6689509.9 23.8, 355415.9 6689507.4 23.8, 355411.2 6689519.7 23.8, 355427.9 6689526.5 23.8))
BATIMENT0000000302931691;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;20;20;20.6;7.0;27.6;31.7;8.0;Cadastre;A 1.0;POLYGON Z ((355437.8 6689528.2 27.6, 355438.5 6689529.3 27.6, 355442.9 6689531.2 27.6, 355444 6689530.9 27.6, 355461.3 6689519.2 27.6, 355458.1 6689514.4 27.6, 355454.1 6689513.3 27.6, 355453.6 6689515.1 27.6, 355450.7 6689516.9 27.6, 355449.5 6689515.9 27.6, 355450.1 6689514 27.6, 355450.7 6689512.4 27.6, 355440.8 6689509.9 27.6, 355437.8 6689528.2 27.6))
BATIMENT0000000302930419;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.1;6.6;22.7;26.3;7.2;Cadastre;A 1.0;POLYGON Z ((355401.3 6689532.5 22.7, 355402.2 6689533.3 22.7, 355404.3 6689533.8 22.7, 355404.2 6689535.2 22.7, 355404 6689537.4 22.7, 355403.8 6689538.5 22.7, 355409.1 6689538.9 22.7, 355408.9 6689540.6 22.7, 355415.3 6689541.7 22.7, 355415.9 6689538.1 22.7, 355416.1 6689535 22.7, 355417.3 6689535.1 22.7, 355418.5 6689534.8 22.7, 355418.7 6689534 22.7, 355427.1 6689534.5 22.7, 355426.4 6689533.4 22.7, 355404.9 6689524.7 22.7, 355401.3 6689532.5 22.7))
BATIMENT0000000302931059;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;10;20;20.5;8.1;28.6;31.4;8.2;Cadastre;A 1.0;POLYGON Z ((355453.2 6689533.3 28.6, 355453.8 6689536.9 28.6, 355471 6689544 28.6, 355475.8 6689532.6 28.6, 355468.8 6689522.5 28.6, 355453.2 6689533.3 28.6))
BATIMENT0000000302930413;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;20;30;15.8;6.8;22.7;24.9;7.2;Cadastre;A 1.0;POLYGON Z ((355418.7 6689534 22.7, 355418.5 6689534.8 22.7, 355417.3 6689535.1 22.7, 355416.1 6689535 22.7, 355415.9 6689538.1 22.7, 355415.3 6689541.7 22.7, 355427.3 6689542.9 22.7, 355426.4 6689539 22.7, 355427.1 6689534.5 22.7, 355418.7 6689534 22.7))
BATIMENT0000000302930881;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;20;20;15.0;7.6;22.6;25.4;7.7;Cadastre;A 1.0;POLYGON Z ((355437.7 6689539.1 22.6, 355436.5 6689539.7 22.6, 355435.8 6689545.6 22.6, 355448.8 6689548.3 22.6, 355450.5 6689544.3 22.6, 355437.7 6689539.1 22.6))
BATIMENT0000000302930410;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;12;14.2;6.6;20.9;24.3;7.1;Cadastre;A 1.0;POLYGON Z ((355427.3 6689542.9 20.9, 355415.3 6689541.7 20.9, 355408.9 6689540.6 20.9, 355408.9 6689540.8 20.9, 355403.6 6689540.2 20.9, 355403.6 6689540.5 20.9, 355403.3 6689542.4 20.9, 355408.3 6689542.9 20.9, 355407.6 6689545.3 20.9, 355407.6 6689546 20.9, 355406.3 6689546 20.9, 355406.4 6689545.3 20.9, 355403 6689544.7 20.9, 355402.2 6689544.7 20.9, 355401.9 6689548.4 20.9, 355404.6 6689548.5 20.9, 355406.5 6689548.6 20.9, 355406.4 6689549.3 20.9, 355406.5 6689549.3 20.9, 355414.3 6689550.4 20.9, 355416.8 6689550.7 20.9, 355419 6689551 20.9, 355426 6689551.9 20.9, 355427.3 6689542.9 20.9))
BATIMENT0000000302931060;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;6.6;8.6;15.3;18.5;9.2;Cadastre;A 1.0;POLYGON Z ((355496.6 6689531.5 15.3, 355496.6 6689531.7 15.3, 355497.2 6689531.7 15.3, 355497 6689518.7 15.3, 355489.5 6689519.1 15.3, 355489.8 6689531.6 15.3, 355490.3 6689531.6 15.3, 355496.6 6689531.5 15.3))
BATIMENT0000000302931058;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;8.5;13.7;20.0;8.7;Cadastre;;POLYGON Z ((355482.5 6689526.2 13.7, 355483.7 6689527.6 13.7, 355485.3 6689526.5 13.7, 355486.9 6689524.2 13.7, 355486.4 6689523.5 13.7, 355482.5 6689526.2 13.7))
BATIMENT0000000302931147;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;13.3;10.8;24.1;26.2;12.3;Cadastre;A 1.0;POLYGON Z ((355584.2 6689520.6 24.1, 355581.3 6689520.3 24.1, 355577.2 6689520 24.1, 355577.3 6689518.4 24.1, 355577.5 6689516.8 24.1, 355577.2 6689516.8 24.1, 355577 6689516.8 24.1, 355561.2 6689515.4 24.1, 355561.3 6689514.2 24.1, 355561.2 6689514.1 24.1, 355560.8 6689513.8 24.1, 355557.2 6689510.6 24.1, 355558.8 6689510.9 24.1, 355558.2 6689510.3 24.1, 355552.4 6689509.5 24.1, 355556.2 6689512.9 24.1, 355554.6 6689514.9 24.1, 355553.2 6689513.6 24.1, 355553.1 6689513.6 24.1, 355553 6689513.5 24.1, 355552.9 6689513.4 24.1, 355552.8 6689513.4 24.1, 355552.7 6689513.3 24.1, 355552.6 6689513.2 24.1, 355552.5 6689513.2 24.1, 355552 6689512.9 24.1, 355551.9 6689512.8 24.1, 355548.6 6689543.6 24.1, 355581.9 6689546.6 24.1, 355582.6 6689546.7 24.1, 355583.7 6689534 24.1, 355583.7 6689532.9 24.1, 355584.6 6689523.6 24.1, 355584.9 6689520.7 24.1, 355584.4 6689520.6 24.1, 355584.2 6689520.6 24.1))
BATIMENT0000000302931057;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;13.2;7.8;21.0;27.9;8.8;Cadastre;A 1.0;POLYGON Z ((355487.9 6689550.9 21, 355489 6689550.2 21, 355490.3 6689531.6 21, 355489.8 6689531.6 21, 355489.5 6689519.1 21, 355483.4 6689519.5 21, 355486.4 6689523.5 21, 355486.9 6689524.2 21, 355485.3 6689526.5 21, 355483.7 6689527.6 21, 355475.8 6689532.6 21, 355471 6689544 21, 355487.9 6689550.9 21))
BATIMENT0000000302931162;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.7;9.3;26.0;26.0;9.6;Cadastre;;POLYGON Z ((355520 6689543.6 26, 355518.9 6689557.5 26, 355521.9 6689557.8 26, 355522.2 6689554.7 26, 355521.2 6689554.7 26, 355522.1 6689543.8 26, 355520 6689543.6 26))
BATIMENT0000000302931157;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;5.0;;;18.5;8.4;26.9;29.3;11.5;Cadastre;B 0.2;POLYGON Z ((355528.2 6689557.6 26.9, 355528.5 6689553.7 26.9, 355529.1 6689553.7 26.9, 355529.2 6689553.5 26.9, 355532.3 6689553.9 26.9, 355532.2 6689554.3 26.9, 355532.4 6689554.3 26.9, 355533.6 6689554.4 26.9, 355533.6 6689554.2 26.9, 355544 6689554.9 26.9, 355544 6689555.2 26.9, 355545.5 6689555.3 26.9, 355545.6 6689555.1 26.9, 355554.9 6689555.8 26.9, 355554.9 6689556.1 26.9, 355556.7 6689556.2 26.9, 355556.7 6689555.8 26.9, 355567.1 6689556.4 26.9, 355567.1 6689556.6 26.9, 355567.8 6689556.7 26.9, 355568.2 6689556.6 26.9, 355569.7 6689546.6 26.9, 355548.3 6689545.1 26.9, 355536.3 6689544.2 26.9, 355531.4 6689543.9 26.9, 355525.5 6689543.4 26.9, 355522.9 6689543 26.9, 355522.8 6689543.8 26.9, 355522.1 6689543.8 26.9, 355521.2 6689554.7 26.9, 355522.2 6689554.7 26.9, 355521.9 6689557.8 26.9, 355522.3 6689557.8 26.9, 355522.4 6689557.3 26.9, 355524.7 6689557.6 26.9, 355524.5 6689559.6 26.9, 355528.1 6689559.8 26.9, 355528.2 6689557.6 26.9))
BATIMENT0000000302931160;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;9.8;23.5;26.0;10.6;Cadastre;;POLYGON Z ((355532.1 6689558 23.5, 355532.4 6689554.3 23.5, 355532.2 6689554.3 23.5, 355532.3 6689553.9 23.5, 355529.2 6689553.5 23.5, 355529.1 6689553.7 23.5, 355528.5 6689553.7 23.5, 355528.2 6689557.6 23.5, 355532.1 6689558 23.5))
BATIMENT0000000302930692;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;8.2;22.7;24.3;8.5;Cadastre;;POLYGON Z ((355479.4 6689566.5 22.7, 355477.1 6689565.9 22.7, 355476.5 6689567.5 22.7, 355485 6689569.7 22.7, 355485.4 6689568.2 22.7, 355479.4 6689566.5 22.7))
BATIMENT0000000302930899;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.9;8.7;21.6;25.2;10.2;Cadastre;;POLYGON Z ((355520.5 6689577.8 21.6, 355520.5 6689577.5 21.6, 355522.5 6689577.6 21.6, 355526.2 6689566 21.6, 355523.8 6689565.8 21.6, 355523.3 6689566.3 21.6, 355523.1 6689568.5 21.6, 355521.3 6689568.4 21.6, 355521.3 6689568 21.6, 355520.8 6689568 21.6, 355520.7 6689570 21.6, 355519.7 6689570 21.6, 355519.3 6689575.8 21.6, 355520.3 6689575.9 21.6, 355520.1 6689577.8 21.6, 355520.5 6689577.8 21.6))
BATIMENT0000000302930898;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.6;8.7;19.3;22.2;10.4;Cadastre;;POLYGON Z ((355522.7 6689577.6 19.3, 355522.5 6689578.2 19.3, 355533.8 6689578.9 19.3, 355535.1 6689578.9 19.3, 355535.4 6689578.1 19.3, 355538.4 6689571.4 19.3, 355540.2 6689571.4 19.3, 355540.3 6689571.3 19.3, 355540.4 6689571.2 19.3, 355540.5 6689571 19.3, 355540.6 6689571 19.3, 355540.6 6689570.9 19.3, 355540.7 6689570.8 19.3, 355540.7 6689570.7 19.3, 355540.7 6689570.6 19.3, 355540.7 6689570.4 19.3, 355540.7 6689570.2 19.3, 355540.7 6689570.1 19.3, 355540.7 6689570 19.3, 355540.6 6689569.8 19.3, 355540.5 6689569.7 19.3, 355540.5 6689569.6 19.3, 355540.3 6689569.4 19.3, 355540.2 6689569.4 19.3, 355539.5 6689569.4 19.3, 355539.5 6689569.1 19.3, 355531.8 6689568.6 19.3, 355531.9 6689567 19.3, 355527.7 6689566.6 19.3, 355526.2 6689566 19.3, 355522.5 6689577.6 19.3, 355522.7 6689577.6 19.3))
BATIMENT0000000302930882;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;50;20;15.0;7.7;22.7;25.4;7.8;Cadastre;A 1.0;POLYGON Z ((355435.3 6689549.6 22.7, 355447.5 6689551.2 22.7, 355448.8 6689548.3 22.7, 355435.8 6689545.6 22.7, 355435.3 6689549.6 22.7))
BATIMENT0000000302930406;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;16;23;9.7;7.8;17.5;;;Cadastre;B 0.4;POLYGON Z ((355408.4 6689554.7 17.5, 355413.6 6689555.4 17.5, 355414.3 6689550.4 17.5, 355406.5 6689549.3 17.5, 355406.4 6689549.3 17.5, 355405.7 6689554.4 17.5, 355408.4 6689554.7 17.5))
BATIMENT0000000302930884;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;14.8;7.8;22.6;26.5;7.8;Cadastre;A 1.0;POLYGON Z ((355434.7 6689554.2 22.6, 355447.1 6689555.3 22.6, 355447.3 6689553.1 22.6, 355447.5 6689551.2 22.6, 355435.3 6689549.6 22.6, 355434.7 6689554.2 22.6))
BATIMENT0000000302930409;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;15.2;6.5;21.7;25.5;7.5;Cadastre;B 1.0;POLYGON Z ((355426 6689551.9 21.7, 355419 6689551 21.7, 355418.6 6689552.8 21.7, 355416.6 6689552.5 21.7, 355416.8 6689550.7 21.7, 355414.3 6689550.4 21.7, 355413.6 6689555.4 21.7, 355414.9 6689555.6 21.7, 355425.4 6689556.9 21.7, 355426 6689551.9 21.7))
BATIMENT0000000302930883;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;7.8;22.2;24.0;7.8;Cadastre;;POLYGON Z ((355447.1 6689555.3 22.2, 355448.3 6689555.4 22.2, 355448.5 6689553.3 22.2, 355447.3 6689553.1 22.2, 355447.1 6689555.3 22.2))
BATIMENT0000000302930877;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;14.3;7.8;22.1;24.9;8.1;Cadastre;A 1.0;POLYGON Z ((355456.8 6689546.9 22.1, 355450.5 6689544.3 22.1, 355448.8 6689548.3 22.1, 355447.5 6689551.2 22.1, 355447.3 6689553.1 22.1, 355448.5 6689553.3 22.1, 355448.3 6689555.4 22.1, 355447.1 6689555.3 22.1, 355446.4 6689565.4 22.1, 355448.7 6689565.7 22.1, 355450.4 6689565.9 22.1, 355450.8 6689566 22.1, 355451.3 6689561.3 22.1, 355455.7 6689562.1 22.1, 355456.8 6689546.9 22.1))
BATIMENT0000000302930408;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;20;20;17.2;6.4;23.7;27.2;7.9;Cadastre;C 0.9;POLYGON Z ((355425.4 6689556.9 23.7, 355414.9 6689555.6 23.7, 355414.3 6689557.9 23.7, 355409.5 6689557.2 23.7, 355408.8 6689560.3 23.7, 355424.5 6689563.2 23.7, 355425.4 6689556.9 23.7))
BATIMENT0000000302930880;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;15.0;7.8;22.8;26.9;8.0;Cadastre;A 1.0;POLYGON Z ((355433.5 6689564.3 22.8, 355446.4 6689565.4 22.8, 355447.1 6689555.3 22.8, 355434.7 6689554.2 22.8, 355433.5 6689564.3 22.8))
BATIMENT0000000302930687;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;11.0;7.9;18.9;23.7;8.4;Cadastre;A 1.0;POLYGON Z ((355466.9 6689550 18.9, 355461.7 6689563.7 18.9, 355461.6 6689565.7 18.9, 355464.6 6689566.8 18.9, 355463.2 6689578.6 18.9, 355467.1 6689578.4 18.9, 355467.1 6689574.9 18.9, 355467.2 6689571.9 18.9, 355468 6689571.9 18.9, 355468.2 6689565.6 18.9, 355467.9 6689565.4 18.9, 355470.1 6689559.3 18.9, 355473 6689552.7 18.9, 355466.9 6689550 18.9))
BATIMENT0000000302930688;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;15.3;7.8;23.2;25.6;8.5;Cadastre;A 1.0;POLYGON Z ((355473.4 6689574.5 23.2, 355476.5 6689567.5 23.2, 355477.1 6689565.9 23.2, 355479.8 6689555.7 23.2, 355473 6689552.7 23.2, 355470.1 6689559.3 23.2, 355467.9 6689565.4 23.2, 355468.2 6689565.6 23.2, 355468 6689571.9 23.2, 355467.2 6689571.9 23.2, 355467.1 6689574.9 23.2, 355472.8 6689576 23.2, 355473.4 6689574.5 23.2))
BATIMENT0000000302930416;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;5.0;10;20;10.3;7.8;18.1;;;Cadastre;A 1.0;POLYGON Z ((355364.8 6689543.4 18.1, 355368.8 6689543 18.1, 355376.2 6689545.1 18.1, 355376.2 6689544.8 18.1, 355380.8 6689545.7 18.1, 355379.4 6689551.8 18.1, 355382.3 6689552.1 18.1, 355384 6689552.3 18.1, 355390.4 6689553 18.1, 355390.8 6689548.2 18.1, 355392.9 6689548.4 18.1, 355393 6689547.7 18.1, 355393.3 6689544 18.1, 355390.3 6689543.3 18.1, 355389.5 6689543.2 18.1, 355388.8 6689547.1 18.1, 355382.4 6689545.7 18.1, 355382.7 6689544 18.1, 355386.1 6689544.6 18.1, 355386.5 6689542.6 18.1, 355386.2 6689542.5 18.1, 355382.8 6689542 18.1, 355376.5 6689540.8 18.1, 355364.5 6689539.6 18.1, 355364.8 6689543.4 18.1))
BATIMENT0000000302930420;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;00;00;17.2;6.5;23.7;26.9;7.6;Cadastre;A 1.0;POLYGON Z ((355365.3 6689550.2 23.7, 355379.4 6689551.8 23.7, 355380.8 6689545.7 23.7, 355376.2 6689544.8 23.7, 355376.2 6689545.1 23.7, 355368.8 6689543 23.7, 355364.8 6689543.4 23.7, 355365.3 6689550.2 23.7))
BATIMENT0000000302931198;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;;;19.1;6.9;26.1;28.6;7.5;Cadastre;A 1.0;POLYGON Z ((355357.2 6689560.2 26.1, 355355.4 6689538.3 26.1, 355354.4 6689537.2 26.1, 355350.8 6689536.8 26.1, 355349.8 6689537.7 26.1, 355345.5 6689558.5 26.1, 355346.5 6689559.6 26.1, 355356.3 6689560.8 26.1, 355357.2 6689560.2 26.1))
BATIMENT0000000302930415;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;15.1;6.3;21.4;26.0;7.6;Cadastre;A 1.0;POLYGON Z ((355365.7 6689555.3 21.4, 355381.7 6689556.9 21.4, 355382.3 6689552.1 21.4, 355379.4 6689551.8 21.4, 355365.3 6689550.2 21.4, 355365.7 6689555.3 21.4))
BATIMENT0000000302930407;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;20;20;8.5;6.3;14.8;18.4;7.4;Cadastre;C 0.5;POLYGON Z ((355405.6 6689554.7 14.8, 355392.4 6689553.2 14.8, 355390.4 6689553 14.8, 355384 6689552.3 14.8, 355383.5 6689557.1 14.8, 355399.9 6689558.8 14.8, 355400 6689557.6 14.8, 355402 6689557.7 14.8, 355401.9 6689559 14.8, 355405.1 6689559.3 14.8, 355407.4 6689559.6 14.8, 355408.4 6689554.7 14.8, 355405.7 6689554.4 14.8, 355405.6 6689554.7 14.8))
BATIMENT0000000302930412;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;10;20;14.8;6.6;21.5;27.0;7.7;Cadastre;A 1.0;POLYGON Z ((355367.3 6689575.3 21.5, 355400.4 6689577.6 21.5, 355401 6689567.6 21.5, 355401.5 6689567.3 21.5, 355404.4 6689565 21.5, 355404.7 6689562.7 21.5, 355405.1 6689559.3 21.5, 355401.9 6689559 21.5, 355399.9 6689558.8 21.5, 355383.5 6689557.1 21.5, 355381.7 6689556.9 21.5, 355365.7 6689555.3 21.5, 355367.3 6689575.3 21.5))
BATIMENT0000000302931196;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.5;7.2;27.7;28.7;7.8;Cadastre;;POLYGON Z ((355357.4 6689561.3 27.7, 355356.8 6689561.3 27.7, 355356.3 6689560.8 27.7, 355346.5 6689559.6 27.7, 355346.5 6689560.4 27.7, 355345.8 6689560.3 27.7, 355345.3 6689560.2 27.7, 355342.5 6689575.1 27.7, 355343.9 6689575.2 27.7, 355350.1 6689575.5 27.7, 355358.8 6689575.9 27.7, 355357.8 6689566 27.7, 355357.4 6689561.3 27.7))
BATIMENT0000000302930709;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.1;6.0;14.1;17.0;8.3;Cadastre;A 1.0;POLYGON Z ((355379.9 6689594.8 14.1, 355371.4 6689595.4 14.1, 355372 6689606.3 14.1, 355380.6 6689605.5 14.1, 355379.9 6689594.8 14.1))
BATIMENT0000000302930345;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;16.3;7.7;24.0;26.0;8.3;Cadastre;C 0.9;POLYGON Z ((355338.9 6689599.9 24, 355338.2 6689600.5 24, 355337 6689613 24, 355349 6689614.1 24, 355348.8 6689608.9 24, 355349.9 6689602.5 24, 355338.9 6689599.9 24))
BATIMENT0000000302930708;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.2;7.6;16.9;22.7;8.2;Cadastre;A 1.0;POLYGON Z ((355372.2 6689609.8 16.9, 355372.3 6689610.3 16.9, 355380.7 6689609.6 16.9, 355380.6 6689605.5 16.9, 355372 6689606.3 16.9, 355372.2 6689609.8 16.9))
BATIMENT0000000302930411;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1790-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;20;20;17.1;7.1;24.2;28.0;7.9;Cadastre;A 1.0;POLYGON Z ((355421.6 6689579.9 24.2, 355422.4 6689572.7 24.2, 355423.2 6689572.8 24.2, 355424.5 6689563.2 24.2, 355408.8 6689560.3 24.2, 355408.5 6689562.6 24.2, 355407.2 6689562.4 24.2, 355406.7 6689564.8 24.2, 355408 6689565.1 24.2, 355407.4 6689568.3 24.2, 355401.5 6689567.3 24.2, 355401 6689567.6 24.2, 355400.4 6689577.6 24.2, 355421.6 6689579.9 24.2))
BATIMENT0000000302930689;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;7.9;14.0;19.0;8.3;Cadastre;;POLYGON Z ((355460.4 6689578.8 14, 355463.2 6689578.6 14, 355464.6 6689566.8 14, 355461.6 6689565.7 14, 355460.4 6689578.8 14))
BATIMENT0000000302930868;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;15;20;14.3;7.8;22.1;24.9;8.5;Cadastre;A 1.0;POLYGON Z ((355432.6 6689564.3 22.1, 355432.1 6689568.4 22.1, 355431.6 6689573 22.1, 355432.5 6689573.2 22.1, 355443.1 6689574.5 22.1, 355442.9 6689576 22.1, 355445.9 6689576.3 22.1, 355445.6 6689578.9 22.1, 355442.5 6689578.5 22.1, 355441.6 6689583.7 22.1, 355456.6 6689583.5 22.1, 355456.1 6689577.4 22.1, 355456.5 6689570.3 22.1, 355458.4 6689563 22.1, 355455.7 6689562.1 22.1, 355451.3 6689561.3 22.1, 355450.8 6689566 22.1, 355450.4 6689565.9 22.1, 355449.6 6689570.4 22.1, 355449.1 6689574.9 22.1, 355446.1 6689574.7 22.1, 355446.5 6689569.2 22.1, 355448 6689569.5 22.1, 355448.7 6689565.7 22.1, 355446.4 6689565.4 22.1, 355433.5 6689564.3 22.1, 355432.6 6689564.3 22.1))
BATIMENT0000000302930866;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;15.3;7.6;23.0;25.0;8.3;Cadastre;A 1.0;POLYGON Z ((355431 6689582.9 23, 355441.6 6689584.2 23, 355441.6 6689583.7 23, 355442.5 6689578.5 23, 355442.9 6689576 23, 355443.1 6689574.5 23, 355432.5 6689573.2 23, 355431 6689582.9 23))
BATIMENT0000000302930686;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.5;7.8;15.3;17.5;8.7;Cadastre;;POLYGON Z ((355460.7 6689583.7 15.3, 355463.4 6689583.9 15.3, 355468 6689583.2 15.3, 355472.1 6689583.2 15.3, 355472.4 6689582.8 15.3, 355472.8 6689576 15.3, 355467.1 6689574.9 15.3, 355467.1 6689578.4 15.3, 355463.2 6689578.6 15.3, 355460.4 6689578.8 15.3, 355460.7 6689583.7 15.3))
BATIMENT0000000302930867;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;5.0;20;20;13.2;7.9;21.2;24.7;9.1;Cadastre;A 1.0;POLYGON Z ((355442.2 6689597.3 21.2, 355447.6 6689597.4 21.2, 355447.1 6689590.8 21.2, 355449.7 6689590.6 21.2, 355449.5 6689588 21.2, 355457.1 6689587.6 21.2, 355456.6 6689583.5 21.2, 355441.6 6689583.7 21.2, 355441.6 6689584.2 21.2, 355441.5 6689589.6 21.2, 355441.5 6689592.8 21.2, 355441.5 6689597.3 21.2, 355442.2 6689597.3 21.2))
BATIMENT0000000302930693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.5;8.4;22.0;27.2;9.4;Cadastre;A 1.0;POLYGON Z ((355472.4 6689590 22, 355467.2 6689590.1 22, 355467.5 6689588 22, 355461 6689587.3 22, 355462.6 6689593.3 22, 355465.8 6689599.5 22, 355468.9 6689602.7 22, 355473.6 6689605.5 22, 355474.8 6689603.4 22, 355475.1 6689603.6 22, 355475.5 6689602.8 22, 355475.2 6689602.6 22, 355478.7 6689597.1 22, 355480.5 6689597.9 22, 355482.6 6689594.9 22, 355481.7 6689594.5 22, 355479.1 6689593.3 22, 355479.1 6689592.7 22, 355477.8 6689592.3 22, 355477.9 6689591.4 22, 355477.6 6689591.3 22, 355477.6 6689591 22, 355472.4 6689590 22))
BATIMENT0000000302930869;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;7.0;10;20;22.3;7.4;29.7;31.9;9.1;Cadastre;A 1.0;POLYGON Z ((355429.4 6689582.7 29.7, 355425.7 6689610.4 29.7, 355428.4 6689610.2 29.7, 355437.7 6689609.9 29.7, 355438.1 6689604.8 29.7, 355435.5 6689604.5 29.7, 355435.9 6689601.6 29.7, 355438.3 6689601.7 29.7, 355438.6 6689597.3 29.7, 355441.5 6689597.3 29.7, 355441.5 6689592.8 29.7, 355437.9 6689592.7 29.7, 355438 6689590.7 29.7, 355439.2 6689590.8 29.7, 355439.2 6689589.6 29.7, 355441.5 6689589.6 29.7, 355441.6 6689584.2 29.7, 355431 6689582.9 29.7, 355429.4 6689582.7 29.7))
BATIMENT0000000302930878;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.2;8.6;11.8;22.0;9.1;Cadastre;C 0.5;POLYGON Z ((355441.9 6689603.4 11.8, 355455.9 6689603.8 11.8, 355463.1 6689602.7 11.8, 355460.9 6689597.4 11.8, 355447.6 6689597.4 11.8, 355442.2 6689597.3 11.8, 355441.9 6689603.4 11.8))
BATIMENT0000000302930875;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;8.4;13.0;25.5;9.1;Cadastre;;POLYGON Z ((355458.8 6689609.8 13, 355440.6 6689611.6 13, 355440.5 6689616.4 13, 355440.4 6689618.3 13, 355448.7 6689616.9 13, 355449.1 6689617.2 13, 355455.6 6689615.6 13, 355459.8 6689614 13, 355459.2 6689612.6 13, 355458.8 6689609.8 13))
BATIMENT0000000303962743;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;7.9;15.0;28.6;8.7;Cadastre;A 1.0;POLYGON Z ((356348.9 6689415.9 15, 356349.2 6689416.1 15, 356346.2 6689419.7 15, 356345.9 6689419.4 15, 356345 6689420.4 15, 356345.8 6689421 15, 356343 6689424.3 15, 356342.6 6689423.9 15, 356341.9 6689424.7 15, 356342.4 6689425.1 15, 356340.7 6689427.2 15, 356340.2 6689426.7 15, 356339.5 6689427.5 15, 356339.9 6689427.9 15, 356337.2 6689431.1 15, 356336.4 6689430.5 15, 356335.6 6689431.5 15, 356335.9 6689431.7 15, 356332.9 6689435.3 15, 356332.6 6689435 15, 356331.8 6689436 15, 356332.7 6689436.8 15, 356333.1 6689436.4 15, 356335.8 6689438.7 15, 356334.5 6689440.2 15, 356334.1 6689439.8 15, 356333.3 6689440.8 15, 356334.2 6689441.6 15, 356334.6 6689441.1 15, 356338.5 6689444.4 15, 356338.1 6689444.9 15, 356339 6689445.7 15, 356339.9 6689444.7 15, 356339.4 6689444.4 15, 356340.7 6689442.9 15, 356343.5 6689445.3 15, 356343.1 6689445.6 15, 356344.1 6689446.5 15, 356345 6689445.5 15, 356344.7 6689445.3 15, 356347.7 6689441.7 15, 356348 6689442 15, 356348.8 6689441.1 15, 356352.3 6689444 15, 356352.6 6689444.1 15, 356353 6689444.2 15, 356353.5 6689444.2 15, 356353.9 6689444.2 15, 356354.2 6689444.1 15, 356354.9 6689443.9 15, 356355.2 6689443.8 15, 356355.4 6689443.7 15, 356357.4 6689440.5 15, 356359.2 6689442.2 15, 356359.4 6689442.2 15, 356359.7 6689442.3 15, 356360 6689442.2 15, 356360.2 6689442.1 15, 356360.5 6689442 15, 356360.8 6689441.8 15, 356360.9 6689441.6 15, 356361 6689441.4 15, 356361.1 6689441.2 15, 356361.1 6689440.9 15, 356361.1 6689440.6 15, 356361.1 6689440.5 15, 356361 6689440.2 15, 356358.8 6689438.3 15, 356361.7 6689433.9 15, 356361.9 6689433.7 15, 356362.3 6689433.4 15, 356362.6 6689433.2 15, 356362.9 6689433.1 15, 356363.1 6689433 15, 356363.4 6689432.9 15, 356363.7 6689432.9 15, 356364 6689432.9 15, 356367.6 6689433.7 15, 356367.5 6689434.4 15, 356366.4 6689434.1 15, 356366.3 6689434.5 15, 356367.6 6689434.8 15, 356372.2 6689415 15, 356371.5 6689414.4 15, 356362 6689425.4 15, 356349.7 6689414.9 15, 356348.9 6689415.9 15))
BATIMENT0000000029191987;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2006-10-04 09:41:10;2020-05-13 21:47:09;2012-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;3.6;9.0;;;;Imagerie aérienne;C 0.4;POLYGON Z ((356460.3 6689486.7 12.3, 356459.4 6689491.7 12.4, 356506.81139568595 6689502.431881814 12.547012079646386, 356506.81139568595 6689497.588714339 12.516332072957978, 356460.3 6689486.7 12.3))
BATIMENT0000000327842440;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2013-09-27 10:56:18;2022-11-04 16:09:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;7.9;14.8;23.0;8.4;Cadastre;;POLYGON Z ((356384.6 6689574.7 14.8, 356395.7 6689577.1 14.8, 356408.1 6689579.6 14.8, 356437.2 6689451.7 14.8, 356504 6689466.6 14.8, 356504.5 6689459.4 14.8, 356500.9 6689457.9 14.8, 356503 6689444.4 14.8, 356500.6 6689443.4 14.8, 356499.2 6689442.5 14.8, 356497.6 6689441.6 14.8, 356496.3 6689441.1 14.8, 356495.7 6689443.6 14.8, 356493.5 6689443 14.8, 356493.6 6689442.5 14.8, 356490.3 6689440.5 14.8, 356486.8 6689439.6 14.8, 356483.2 6689439.6 14.8, 356481.1 6689440.1 14.8, 356441.8 6689430.7 14.8, 356443.3 6689424.7 14.8, 356431.9 6689422.5 14.8, 356421.1 6689420.6 14.8, 356419.7 6689419 14.8, 356413.8 6689417.9 14.8, 356412 6689423.5 14.8, 356394.1 6689420.4 14.8, 356384.8 6689418.3 14.8, 356381.1 6689418 14.8, 356376.4 6689414.1 14.8, 356374.9 6689413.6 14.8, 356374.5 6689413.7 14.8, 356375.9 6689414.3 14.8, 356391.4 6689427.5 14.8, 356389.7 6689435.1 14.8, 356382.7 6689433.5 14.8, 356381.6 6689438 14.8, 356388.4 6689439.5 14.8, 356388.4 6689439.7 14.8, 356413.2 6689444.8 14.8, 356384.6 6689574.7 14.8))
BATIMENT0000000291501562;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;1998-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;4.7;8.1;;;;Imagerie aérienne;A 1.0;POLYGON Z ((356506.81139568595 6689488.923320627 12.14181131796881, 356506.81139568595 6689484.262301361 12.5, 356506.1 6689484.1 12.5, 356505.7 6689485.3 12.5, 356494.8 6689482.7 11.8, 356479.8 6689480.3 11.8, 356479.3 6689482.4 12, 356506.81139568595 6689488.923320627 12.14181131796881))
BATIMENT0000000029192284;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2006-10-04 09:41:10;2020-05-13 21:54:56;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.7;8.0;;;;Imagerie aérienne;;POLYGON Z ((356506.81139568595 6689516.850060298 12.289413857735086, 356506.81139568595 6689510.038155795 12.14274849944143, 356458.9 6689499.4 12.5, 356457.5 6689505.6 12.7, 356506.81139568595 6689516.850060298 12.289413857735086))
BATIMENT0000000029192228;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2006-10-04 09:41:10;2020-05-13 21:54:09;2012-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;3.1;9.0;;12.3;9.0;Imagerie aérienne;C 0.4;POLYGON Z ((356447.6 6689510.2 11.3, 356444.7 6689522.5 11.9, 356506.81139568595 6689536.385574843 11.978671812141755, 356506.81139568595 6689523.38305584 11.599614905432244, 356447.6 6689510.2 11.3))
BATIMENT0000000029191988;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2006-10-04 09:41:10;2020-05-13 21:46:54;2012-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;3.1;9.0;;12.3;9.1;Imagerie aérienne;C 0.4;POLYGON Z ((356439.8 6689541.9 12, 356506.81139568595 6689556.997595755 12.042172055183038, 356506.81139568595 6689544.077225444 12.040396605330331, 356442.5 6689530.1 12, 356439.8 6689541.9 12))
BATIMENT0000000303962991;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:05:20;2020-05-13 21:50:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;8.7;14.3;17.4;9.1;Cadastre;;POLYGON Z ((356475.9 6689566.6 14.3, 356476.6 6689563.6 14.3, 356423.4 6689551.2 14.3, 356422.7 6689554.7 14.3, 356475.9 6689566.6 14.3))
BATIMENT0000000303963155;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.1;8.8;18.9;24.2;9.0;Cadastre;C 0.1;POLYGON Z ((356457 6689586.1 18.9, 356487.9 6689593 18.9, 356493.9 6689570.6 18.9, 356475.9 6689566.6 18.9, 356422.7 6689554.7 18.9, 356419.9 6689567.1 18.9, 356417.8 6689577.1 18.9, 356457 6689586.1 18.9))
BATIMENT0000000303963156;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:23:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;8.3;15.5;17.0;8.8;Cadastre;;POLYGON Z ((356506.81139568595 6689592.805243633 15.5, 356506.81139568595 6689580.049563366 15.5, 356503.2 6689592 15.5, 356506.81139568595 6689592.805243633 15.5))
BATIMENT0000000303963020;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;00;00;8.2;7.0;15.2;21.5;9.3;Cadastre;A 1.0;POLYGON Z ((356080.3 6689528.3 15.2, 356073.1 6689542.1 15.2, 356089.9 6689550.7 15.2, 356091.9 6689546.6 15.2, 356094.1 6689540 15.2, 356096.2 6689534.5 15.2, 356097.4 6689530.3 15.2, 356097.1 6689529.8 15.2, 356090 6689528.1 15.2, 356081.1 6689524.8 15.2, 356080.3 6689528.3 15.2), (356081.3 6689533.7 15.2, 356082.6 6689534.5 15.2, 356080.7 6689539.3 15.2, 356079.2 6689538.6 15.2, 356081.3 6689533.7 15.2))
BATIMENT0000000303962943;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;12.0;7.1;19.2;30.7;7.8;Cadastre;A 1.0;POLYGON Z ((356147.4 6689534.3 19.2, 356131.9 6689571.9 19.2, 356134.2 6689573 19.2, 356136.1 6689569.3 19.2, 356138.4 6689570.3 19.2, 356140.7 6689565.4 19.2, 356141 6689565.5 19.2, 356142.9 6689561.2 19.2, 356145.1 6689562.1 19.2, 356142 6689569.4 19.2, 356144.8 6689570.6 19.2, 356146.1 6689568.1 19.2, 356145.7 6689567.6 19.2, 356158.4 6689539.8 19.2, 356147.4 6689534.3 19.2))
BATIMENT0000000303963066;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;17.0;6.5;23.5;26.7;7.4;Cadastre;A 1.0;POLYGON Z ((356114.3 6689559.3 23.5, 356114.2 6689559.2 23.5, 356113.6 6689562.2 23.5, 356124.4 6689567.6 23.5, 356127.7 6689559.9 23.5, 356124.5 6689558.5 23.5, 356115.4 6689554.2 23.5, 356114.3 6689559.3 23.5))
BATIMENT0000000303962944;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;10;20;9.4;7.2;16.7;25.3;7.7;Cadastre;A 1.0;POLYGON Z ((356146.1 6689568.1 16.7, 356144.8 6689570.6 16.7, 356144.8 6689570.8 16.7, 356141.9 6689576.9 16.7, 356157.2 6689584.6 16.7, 356166.1 6689561.2 16.7, 356172.4 6689547 16.7, 356158.4 6689539.8 16.7, 356145.7 6689567.6 16.7, 356146.1 6689568.1 16.7), (356154.7 6689566 16.7, 356155.5 6689567.3 16.7, 356158.4 6689568.1 16.7, 356157.4 6689570.3 16.7, 356158.1 6689571.6 16.7, 356157 6689573.4 16.7, 356151.7 6689570.9 16.7, 356151.8 6689568.8 16.7, 356152.8 6689566.3 16.7, 356154.7 6689566 16.7))
BATIMENT0000000303962942;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;7.0;10.6;23.6;7.4;Cadastre;;POLYGON Z ((356139 6689575.4 10.6, 356141.9 6689576.9 10.6, 356144.8 6689570.8 10.6, 356144.8 6689570.6 10.6, 356142 6689569.4 10.6, 356139 6689575.4 10.6))
BATIMENT0000000303962918;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;4.0;;;12.4;7.1;19.5;23.7;10.7;Cadastre;A 0.6;POLYGON Z ((356059.8 6689581.2 19.5, 356064.2 6689583 19.5, 356064.1 6689583.4 19.5, 356067.6 6689585.5 19.5, 356069.9 6689586.2 19.5, 356070.1 6689585.7 19.5, 356073 6689586.9 19.5, 356073.3 6689586.5 19.5, 356075.9 6689587.7 19.5, 356069.5 6689601.6 19.5, 356070.9 6689602.2 19.5, 356069 6689606.2 19.5, 356079.5 6689611 19.5, 356081.2 6689606.9 19.5, 356082.9 6689607.5 19.5, 356089.2 6689593.9 19.5, 356092.3 6689595.4 19.5, 356102.9 6689575.9 19.5, 356108.2 6689578.8 19.5, 356107 6689580.7 19.5, 356111.8 6689583.5 19.5, 356111.1 6689584.8 19.5, 356113.7 6689586.2 19.5, 356114.5 6689584.8 19.5, 356125.2 6689590.6 19.5, 356124.4 6689591.9 19.5, 356127.4 6689593.5 19.5, 356128.1 6689592.3 19.5, 356133.3 6689595.2 19.5, 356133.8 6689594.3 19.5, 356138.6 6689596.8 19.5, 356138.1 6689598 19.5, 356140 6689599 19.5, 356138.8 6689601.3 19.5, 356135.5 6689599.3 19.5, 356131.9 6689606.1 19.5, 356129.9 6689604.9 19.5, 356126.7 6689610.9 19.5, 356126.9 6689611 19.5, 356127.4 6689610.3 19.5, 356129.9 6689611.4 19.5, 356133.9 6689612.8 19.5, 356135.7 6689613.6 19.5, 356130.1 6689623.5 19.5, 356134.2 6689625.6 19.5, 356134.8 6689624.6 19.5, 356135.7 6689625.1 19.5, 356140 6689616.7 19.5, 356141.7 6689617.7 19.5, 356143.4 6689617 19.5, 356144.1 6689615.7 19.5, 356149 6689606.7 19.5, 356145.6 6689605 19.5, 356146.6 6689602.7 19.5, 356147.4 6689603.2 19.5, 356148 6689602 19.5, 356149.1 6689600 19.5, 356151.8 6689601.4 19.5, 356156 6689592.9 19.5, 356151.1 6689590.3 19.5, 356146 6689587.6 19.5, 356145.5 6689587.7 19.5, 356132.6 6689581.5 19.5, 356128 6689578.9 19.5, 356125.4 6689577.6 19.5, 356125.7 6689576.9 19.5, 356117.1 6689572.9 19.5, 356115.9 6689572.1 19.5, 356110.8 6689568.7 19.5, 356108.3 6689567.1 19.5, 356102.6 6689564 19.5, 356092.1 6689558.7 19.5, 356085.6 6689555.3 19.5, 356085.2 6689556.6 19.5, 356073.3 6689551.2 19.5, 356072.7 6689552.8 19.5, 356067.4 6689564.3 19.5, 356063.3 6689573.9 19.5, 356059.8 6689581.2 19.5))
BATIMENT0000000303962921;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.5;10.1;11.7;14.0;11.0;Cadastre;;POLYGON Z ((356067 6689599.5 11.7, 356065.7 6689598.8 11.7, 356063.7 6689599.1 11.7, 356062.4 6689601.2 11.7, 356065.9 6689602.6 11.7, 356067 6689599.5 11.7))
BATIMENT0000000303962926;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.3;10.3;18.6;;;Cadastre;;POLYGON Z ((356149.1 6689600 18.6, 356148 6689602 18.6, 356150.8 6689603.3 18.6, 356151.8 6689601.4 18.6, 356149.1 6689600 18.6))
BATIMENT0000000303962925;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;30;30;11.2;7.2;18.5;22.6;9.8;Cadastre;C 0.3;POLYGON Z ((356165.6 6689596 18.5, 356165.5 6689596.6 18.5, 356160.5 6689594.8 18.5, 356156.8 6689593.2 18.5, 356153.2 6689601.8 18.5, 356155.5 6689603 18.5, 356154.6 6689605.4 18.5, 356154.2 6689606.3 18.5, 356163.4 6689610.5 18.5, 356164.4 6689608.2 18.5, 356169.9 6689610.7 18.5, 356170.3 6689610 18.5, 356174.7 6689600.8 18.5, 356174.9 6689600.4 18.5, 356165.6 6689596 18.5))
BATIMENT0000000303962916;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.7;11.5;17.2;18.3;11.6;Cadastre;B 0.3;POLYGON Z ((356064 6689606.5 17.2, 356065.9 6689602.6 17.2, 356062.4 6689601.2 17.2, 356055.7 6689598.5 17.2, 356054.2 6689602.4 17.2, 356064 6689606.5 17.2))
BATIMENT0000000303962945;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;10;10.9;7.2;18.1;26.9;8.0;Cadastre;C 0.7;POLYGON Z ((356166.1 6689561.2 18.1, 356157.2 6689584.6 18.1, 356180.6 6689594.6 18.1, 356181.6 6689589.3 18.1, 356171.2 6689584 18.1, 356161.9 6689578.8 18.1, 356165.5 6689571.4 18.1, 356182.3 6689579.6 18.1, 356186.8 6689570 18.1, 356193.1 6689557.9 18.1, 356172.4 6689547 18.1, 356166.1 6689561.2 18.1), (356176 6689563 18.1, 356180.9 6689565.9 18.1, 356177.5 6689571.5 18.1, 356173.1 6689569.3 18.1, 356174.1 6689566.9 18.1, 356174.7 6689566.8 18.1, 356174.6 6689565.6 18.1, 356176 6689563 18.1))
BATIMENT0000000303962949;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;15.5;7.2;22.7;26.5;7.8;Cadastre;A 1.0;POLYGON Z ((356205.1 6689564.1 22.7, 356201.7 6689570.7 22.7, 356199.6 6689576 22.7, 356202.1 6689577.4 22.7, 356200.7 6689581.2 22.7, 356203.8 6689582.2 22.7, 356206.4 6689576.4 22.7, 356206.7 6689575.4 22.7, 356210.3 6689566.8 22.7, 356205.1 6689564.1 22.7))
BATIMENT0000000303962953;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;10;20;19.3;7.4;26.7;28.3;7.8;Cadastre;A 1.0;POLYGON Z ((356213.6 6689577.7 26.7, 356215 6689578.7 26.7, 356214.5 6689580.2 26.7, 356214.7 6689580.8 26.7, 356215.4 6689581.5 26.7, 356216.7 6689582.2 26.7, 356221.6 6689572.8 26.7, 356210.3 6689566.8 26.7, 356206.7 6689575.4 26.7, 356212.5 6689578.4 26.7, 356213.6 6689577.7 26.7))
BATIMENT0000000303962947;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;3.0;10;20;7.5;7.1;14.7;19.2;8.0;Cadastre;A 1.0;POLYGON Z ((356186.8 6689570 14.7, 356182.3 6689579.6 14.7, 356183.5 6689580.2 14.7, 356182.9 6689581.4 14.7, 356182 6689587.8 14.7, 356182.2 6689587.9 14.7, 356181.6 6689589.3 14.7, 356180.6 6689594.6 14.7, 356191.9 6689599.5 14.7, 356197.3 6689583 14.7, 356199.6 6689576 14.7, 356201.7 6689570.7 14.7, 356205.1 6689564.1 14.7, 356193.1 6689557.9 14.7, 356186.8 6689570 14.7), (356191.6 6689578.3 14.7, 356193.2 6689579.2 14.7, 356192.9 6689580.3 14.7, 356191.1 6689579.4 14.7, 356191.6 6689578.3 14.7))
BATIMENT0000000303962946;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;10;10;6.4;7.2;13.7;18.0;8.0;Cadastre;C 0.1;POLYGON Z ((356182.9 6689581.4 13.7, 356175.9 6689578 13.7, 356173.2 6689583.5 13.7, 356182 6689587.8 13.7, 356182.9 6689581.4 13.7))
BATIMENT0000000303962951;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;9.2;7.2;16.4;23.5;7.6;Cadastre;A 1.0;POLYGON Z ((356211 6689584.1 16.4, 356212.5 6689578.4 16.4, 356206.4 6689576.4 16.4, 356203.8 6689582.2 16.4, 356202.9 6689584.5 16.4, 356202.3 6689587.3 16.4, 356206.2 6689588.3 16.4, 356209.3 6689589.4 16.4, 356211 6689584.1 16.4))
BATIMENT0000000303962952;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;7.1;14.5;15.9;7.5;Cadastre;;POLYGON Z ((356209.3 6689589.4 14.5, 356206.2 6689588.3 14.5, 356205.1 6689591.7 14.5, 356208.3 6689593.1 14.5, 356209.3 6689589.4 14.5))
BATIMENT0000000303962948;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;00;00;10.4;7.0;17.5;20.7;7.5;Cadastre;A 1.0;POLYGON Z ((356198 6689602 17.5, 356201.6 6689590 17.5, 356202.3 6689587.3 17.5, 356202.9 6689584.5 17.5, 356197.3 6689583 17.5, 356191.9 6689599.5 17.5, 356198 6689602 17.5))
BATIMENT0000000303962954;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;6.0;6.8;12.8;27.1;7.8;Cadastre;A 1.0;POLYGON Z ((356216 6689583.7 12.8, 356213.5 6689588.1 12.8, 356212.7 6689587.7 12.8, 356207.6 6689605.9 12.8, 356235.9 6689617.6 12.8, 356249.4 6689587.3 12.8, 356221.6 6689572.8 12.8, 356216.7 6689582.2 12.8, 356216 6689583.7 12.8), (356218.8 6689586 12.8, 356224.9 6689588.9 12.8, 356224.5 6689590 12.8, 356225.3 6689590.4 12.8, 356224.6 6689591.8 12.8, 356225.3 6689592.2 12.8, 356225.4 6689594.1 12.8, 356226.8 6689594.9 12.8, 356227.2 6689595.7 12.8, 356234.7 6689599.2 12.8, 356231.7 6689605.7 12.8, 356226.4 6689605.7 12.8, 356224 6689605 12.8, 356220.6 6689603.1 12.8, 356218.1 6689600.9 12.8, 356215.7 6689597.9 12.8, 356218.9 6689590.9 12.8, 356217.7 6689590.1 12.8, 356218.9 6689587.7 12.8, 356218.2 6689587.3 12.8, 356218.8 6689586 12.8))
BATIMENT0000000303962950;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;9.1;6.9;16.0;18.1;7.5;Cadastre;A 1.0;POLYGON Z ((356205.2 6689605 16, 356208.3 6689593.1 16, 356205.1 6689591.7 16, 356201.6 6689590 16, 356198 6689602 16, 356205.2 6689605 16))
BATIMENT0000000303963091;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;19.0;8.9;27.9;;;Cadastre;A 1.0;POLYGON Z ((356255.1 6689590 27.9, 356253 6689590.3 27.9, 356245.4 6689607.3 27.9, 356252.3 6689610.3 27.9, 356255.9 6689602 27.9, 356260.1 6689592.1 27.9, 356255.1 6689590 27.9))
BATIMENT0000000303963092;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;22.1;7.0;29.2;34.0;7.7;Cadastre;A 1.0;POLYGON Z ((356280.1 6689601.7 29.2, 356277.7 6689597.3 29.2, 356269.7 6689595.3 29.2, 356268 6689595 29.2, 356260.1 6689592.1 29.2, 356255.9 6689602 29.2, 356276.5 6689610.1 29.2, 356280.1 6689601.7 29.2))
BATIMENT0000000303962928;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;20;20;5.4;7.3;12.7;21.7;9.8;Cadastre;A 1.0;POLYGON Z ((356177.3 6689604.1 12.7, 356174.7 6689600.8 12.7, 356170.3 6689610 12.7, 356169.9 6689610.7 12.7, 356166.1 6689618.3 12.7, 356170.5 6689620.4 12.7, 356177.3 6689604.1 12.7))
BATIMENT0000000303963089;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;6.8;16.5;27.4;7.4;Cadastre;;POLYGON Z ((356240.3 6689619 16.5, 356246.7 6689621.6 16.5, 356249.8 6689615.6 16.5, 356250.9 6689615.7 16.5, 356252.3 6689610.3 16.5, 356245.4 6689607.3 16.5, 356240.3 6689619 16.5))
BATIMENT0000000303963036;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;16.3;6.4;22.8;26.7;7.6;Cadastre;A 1.0;POLYGON Z ((356306.8 6689605 22.8, 356300.8 6689615 22.8, 356299 6689617.6 22.8, 356295.8 6689622.1 22.8, 356300.3 6689624.4 22.8, 356300.6 6689624.1 22.8, 356302.4 6689620.8 22.8, 356303.6 6689621.4 22.8, 356312.1 6689606.4 22.8, 356306.8 6689605 22.8))
BATIMENT0000000303963090;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;13.2;6.7;20.0;29.2;7.5;Cadastre;A 1.0;POLYGON Z ((356263.9 6689628.7 20, 356269.6 6689626.3 20, 356276.5 6689610.1 20, 356255.9 6689602 20, 356252.3 6689610.3 20, 356250.9 6689615.7 20, 356249.8 6689615.6 20, 356246.7 6689621.6 20, 356263.9 6689628.7 20))
BATIMENT0000000303963034;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;10;20;6.7;6.6;13.4;24.7;7.6;Cadastre;A 1.0;POLYGON Z ((356286.1 6689599.7 13.4, 356284.8 6689600.4 13.4, 356270.9 6689632.5 13.4, 356282.6 6689637.2 13.4, 356286.9 6689627.4 13.4, 356285 6689626.6 13.4, 356286.3 6689622.5 13.4, 356288.5 6689623.5 13.4, 356293.8 6689613.7 13.4, 356289.7 6689611.3 13.4, 356291.1 6689607.6 13.4, 356293.3 6689608.5 13.4, 356292.3 6689610.6 13.4, 356294.7 6689612 13.4, 356299.3 6689603.1 13.4, 356286.1 6689599.7 13.4))
BATIMENT0000000303962884;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;10;20;13.3;7.8;21.1;22.7;9.4;Cadastre;A 1.0;POLYGON Z ((356174.8 6689628.5 21.1, 356186.6 6689635.2 21.1, 356191 6689625.2 21.1, 356197.6 6689611.5 21.1, 356184.5 6689605.9 21.1, 356174.8 6689628.5 21.1), (356187.1 6689617.8 21.1, 356189.5 6689618.7 21.1, 356188.5 6689623.3 21.1, 356186.8 6689623.9 21.1, 356185.5 6689626.3 21.1, 356181.6 6689624.9 21.1, 356182.3 6689622.2 21.1, 356184.6 6689623 21.1, 356185.4 6689621.6 21.1, 356187.1 6689617.8 21.1))
BATIMENT0000000303963033;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.9;6.4;20.3;23.7;7.6;Cadastre;A 1.0;POLYGON Z ((356293.8 6689613.7 20.3, 356288.5 6689623.5 20.3, 356286.9 6689627.4 20.3, 356282.6 6689637.2 20.3, 356287.5 6689639.2 20.3, 356291.4 6689630.7 20.3, 356295.8 6689622.1 20.3, 356299 6689617.6 20.3, 356300.8 6689615 20.3, 356306.8 6689605 20.3, 356299.3 6689603.1 20.3, 356294.7 6689612 20.3, 356293.8 6689613.7 20.3), (356292.4 6689621 20.3, 356294.4 6689622 20.3, 356290.9 6689629.6 20.3, 356289.2 6689628.8 20.3, 356290.9 6689625.4 20.3, 356292.4 6689621 20.3))
BATIMENT0000000303962885;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.7;7.3;20.0;21.7;10.0;Cadastre;A 1.0;POLYGON Z ((356191.3 6689638 20, 356192.7 6689634.8 20, 356191.4 6689634.1 20, 356194.9 6689625.7 20, 356195.6 6689625.9 20, 356198.3 6689620 20, 356199.7 6689617.6 20, 356199.8 6689617.6 20, 356201.9 6689613.4 20, 356197.6 6689611.5 20, 356191 6689625.2 20, 356186.6 6689635.2 20, 356189.5 6689637 20, 356191.3 6689638 20))
BATIMENT0000000303963154;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:23:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;29.6;8.0;37.7;41.2;8.8;Cadastre;;POLYGON Z ((356484 6689613.5 37.7, 356484.6 6689613.5 37.7, 356485.3 6689613.5 37.7, 356486.9 6689613.6 37.7, 356489.5 6689613.9 37.7, 356491.1 6689614.2 37.7, 356494.5 6689615.2 37.7, 356496.2 6689615.9 37.7, 356497.8 6689616.7 37.7, 356498 6689616.3 37.7, 356497.7 6689616.2 37.7, 356499.1 6689610 37.7, 356501.4 6689599.8 37.7, 356503.2 6689592 37.7, 356506.81139568595 6689580.049563366 37.7, 356506.81139568595 6689573.391653121 37.7, 356493.9 6689570.6 37.7, 356487.9 6689593 37.7, 356487.2 6689596.6 37.7, 356483.6 6689612.6 37.7, 356483.6 6689613 37.7, 356483.1 6689613 37.7, 356483.2 6689613.4 37.7, 356484 6689613.5 37.7))
BATIMENT0000000303963039;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;18.0;6.9;25.0;28.1;8.0;Cadastre;A 1.0;POLYGON Z ((356312.1 6689606.4 25, 356303.6 6689621.4 25, 356319.2 6689628.3 25, 356323.5 6689620.9 25, 356329.4 6689610.8 25, 356312.1 6689606.4 25))
BATIMENT0000000303962902;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;16.9;7.5;24.4;26.1;8.2;Cadastre;A 1.0;POLYGON Z ((356374.2 6689632 24.4, 356377 6689632.6 24.4, 356382.5 6689633.7 24.4, 356385.3 6689634.3 24.4, 356385.6 6689632.9 24.4, 356388 6689622.2 24.4, 356377 6689619.8 24.4, 356374.2 6689632 24.4))
BATIMENT0000000303963150;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;14.9;7.1;22.0;25.0;8.2;Cadastre;C 0.4;POLYGON Z ((356390.2 6689633.8 22, 356396.5 6689635.2 22, 356403.6 6689636.8 22, 356405.9 6689626.2 22, 356388 6689622.2 22, 356385.6 6689632.9 22, 356390.2 6689633.8 22))
BATIMENT0000000303962906;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;17.7;7.7;25.4;28.6;8.3;Cadastre;A 1.0;POLYGON Z ((356372.2 6689622.7 25.4, 356358.6 6689649.9 25.4, 356369.8 6689651.6 25.4, 356374.2 6689632 25.4, 356377 6689619.8 25.4, 356372.2 6689622.7 25.4))
BATIMENT0000000303963038;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;;;12.9;7.5;20.5;27.6;8.3;Cadastre;A 1.0;POLYGON Z ((356321.4 6689657.3 20.5, 356332.5 6689662.5 20.5, 356333.4 6689662.9 20.5, 356338.7 6689661.3 20.5, 356339 6689660.4 20.5, 356351.1 6689636.4 20.5, 356358.1 6689622.5 20.5, 356356.2 6689617.6 20.5, 356329.4 6689610.8 20.5, 356323.5 6689620.9 20.5, 356319.2 6689628.3 20.5, 356313.9 6689639.1 20.5, 356313.6 6689639.9 20.5, 356312.7 6689640.4 20.5, 356307.9 6689650.1 20.5, 356321.4 6689657.3 20.5))
BATIMENT0000000303962901;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;7.3;23.3;23.7;7.8;Cadastre;;POLYGON Z ((356406.5 6689638.9 23.3, 356404.5 6689638.5 23.3, 356404.1 6689640.5 23.3, 356406.1 6689640.9 23.3, 356406.5 6689638.9 23.3))
BATIMENT0000000303962903;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;7.2;7.4;14.7;22.0;8.6;Cadastre;A 1.0;POLYGON Z ((356374.2 6689632 14.7, 356369.8 6689651.6 14.7, 356372 6689651.9 14.7, 356379.4 6689653.1 14.7, 356381.1 6689653.4 14.7, 356385.3 6689634.3 14.7, 356382.5 6689633.7 14.7, 356381.6 6689637.7 14.7, 356376.1 6689636.6 14.7, 356377 6689632.6 14.7, 356374.2 6689632 14.7))
BATIMENT0000000303963151;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;4.6;6.6;11.3;20.2;8.4;Cadastre;C 0.2;POLYGON Z ((356388.6 6689654.4 11.3, 356388.5 6689655 11.3, 356389.7 6689655.2 11.3, 356390.6 6689651.1 11.3, 356385.8 6689650.2 11.3, 356390.2 6689633.8 11.3, 356385.6 6689632.9 11.3, 356385.3 6689634.3 11.3, 356381.1 6689653.4 11.3, 356388.6 6689654.4 11.3))
BATIMENT0000000303962899;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;13;20;16.4;7.5;23.9;26.8;8.0;Cadastre;A 1.0;POLYGON Z ((356403.3 6689664.6 23.9, 356415.8 6689659.6 23.9, 356422.3 6689629.8 23.9, 356405.9 6689626.2 23.9, 356403.6 6689636.8 23.9, 356402.9 6689640.3 23.9, 356399.7 6689655.8 23.9, 356402.5 6689656.4 23.9, 356406.1 6689640.9 23.9, 356404.1 6689640.5 23.9, 356404.5 6689638.5 23.9, 356406.5 6689638.9 23.9, 356410.3 6689639.6 23.9, 356410.1 6689640.9 23.9, 356410.6 6689640.9 23.9, 356409.8 6689644.9 23.9, 356407.8 6689644.5 23.9, 356405.2 6689657 23.9, 356403.3 6689664.6 23.9))
BATIMENT0000000303962927;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.7;9.4;19.1;19.7;9.8;Cadastre;;POLYGON Z ((356155.5 6689603 19.1, 356153.2 6689601.8 19.1, 356152.1 6689604.2 19.1, 356154.6 6689605.4 19.1, 356155.5 6689603 19.1))
BATIMENT0000000303962924;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;5.0;9.3;14.4;14.9;10.5;Cadastre;A 0.4;POLYGON Z ((356123.4 6689614.3 14.4, 356126.9 6689611 14.4, 356126.7 6689610.9 14.4, 356121.2 6689609.2 14.4, 356123.4 6689614.3 14.4))
BATIMENT0000000303962923;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.1;9.3;18.5;21.2;10.4;Cadastre;A 0.9;POLYGON Z ((356134.2 6689625.6 18.5, 356130.1 6689623.5 18.5, 356135.7 6689613.6 18.5, 356133.9 6689612.8 18.5, 356129.9 6689611.4 18.5, 356129.4 6689614.1 18.5, 356124.3 6689616.7 18.5, 356127.3 6689624.8 18.5, 356126.6 6689625.5 18.5, 356129.9 6689633 18.5, 356134.2 6689625.6 18.5))
BATIMENT0000000303962930;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;00;00;4.5;11.5;16.0;;;Cadastre;C 0.5;POLYGON Z ((356110.6 6689617.8 16, 356114.7 6689619.6 16, 356117.6 6689620.8 16, 356116.1 6689622.1 16, 356118.7 6689625.8 16, 356122.5 6689630.1 16, 356121.8 6689631.3 16, 356128.1 6689635.9 16, 356129.9 6689633 16, 356126.6 6689625.5 16, 356124.8 6689621.7 16, 356122.4 6689615.8 16, 356116.2 6689613.1 16, 356112.9 6689611.4 16, 356110.6 6689617.8 16))
BATIMENT0000000303962919;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;11.6;14.7;17.0;12.6;Cadastre;;POLYGON Z ((356053.9 6689625.1 14.7, 356053.2 6689626.4 14.7, 356054.6 6689627.1 14.7, 356055.4 6689625.7 14.7, 356053.9 6689625.1 14.7))
BATIMENT0000000303962938;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.3;11.0;14.3;14.5;12.6;Cadastre;C 0.3;POLYGON Z ((356079.4 6689627 14.3, 356087.1 6689630.9 14.3, 356090.9 6689632.6 14.3, 356093.6 6689627.9 14.3, 356080.7 6689621.6 14.3, 356078.4 6689626.5 14.3, 356079.4 6689627 14.3))
BATIMENT0000000303962941;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;11.4;14.9;16.3;12.6;Cadastre;;POLYGON Z ((356072.3 6689628.3 14.9, 356077.9 6689631 14.9, 356079.4 6689627 14.9, 356078.4 6689626.5 14.9, 356073.8 6689624.2 14.9, 356072.3 6689628.3 14.9))
BATIMENT0000000303962929;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;3.0;10;20;10.2;8.8;19.0;21.0;9.8;Cadastre;A 1.0;POLYGON Z ((356163.8 6689617.4 19, 356162.6 6689618.2 19, 356157.7 6689628.9 19, 356152.3 6689639.4 19, 356160.5 6689643.2 19, 356170.5 6689620.4 19, 356166.1 6689618.3 19, 356163.8 6689617.4 19))
BATIMENT0000000303962936;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;9.2;11.5;20.7;22.9;12.5;Cadastre;C 0.1;POLYGON Z ((356099.2 6689627.9 20.7, 356097.9 6689631.5 20.7, 356094.3 6689629.4 20.7, 356092 6689633.2 20.7, 356094.1 6689634.3 20.7, 356102 6689638.2 20.7, 356105 6689630.8 20.7, 356099.2 6689627.9 20.7))
BATIMENT0000000303962932;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.7;10.9;18.6;20.2;10.9;Cadastre;;POLYGON Z ((356128.1 6689635.9 18.6, 356121.8 6689631.3 18.6, 356119.8 6689634 18.6, 356120.4 6689634.4 18.6, 356120.7 6689633.8 18.6, 356122.3 6689634.8 18.6, 356122 6689635.5 18.6, 356126.5 6689638.4 18.6, 356128.1 6689635.9 18.6))
BATIMENT0000000303962887;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;6.8;16.0;19.0;7.4;Cadastre;;POLYGON Z ((356239.7 6689626 16, 356231.9 6689622.5 16, 356231.3 6689624.1 16, 356231.3 6689624.2 16, 356238.8 6689627.2 16, 356239.7 6689626 16))
BATIMENT0000000303962886;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;00;00;12.1;8.1;20.2;22.2;10.1;Cadastre;A 1.0;POLYGON Z ((356211.2 6689630.7 20.2, 356212.6 6689627.9 20.2, 356223.8 6689633.3 20.2, 356223.5 6689634.4 20.2, 356227.7 6689636.4 20.2, 356229.2 6689633.2 20.2, 356234.6 6689635.7 20.2, 356238.8 6689627.2 20.2, 356231.3 6689624.2 20.2, 356231.3 6689624.1 20.2, 356226.7 6689622.7 20.2, 356210.1 6689615.8 20.2, 356205.8 6689614.2 20.2, 356205.5 6689614.9 20.2, 356201.9 6689613.4 20.2, 356199.8 6689617.6 20.2, 356199.7 6689617.6 20.2, 356198.3 6689620 20.2, 356199.7 6689620.7 20.2, 356201.8 6689621.8 20.2, 356201.1 6689623.7 20.2, 356204.3 6689625.3 20.2, 356206.4 6689626.2 20.2, 356205.6 6689628.1 20.2, 356211.2 6689630.7 20.2))
BATIMENT0000000303962895;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;6.8;15.8;19.1;7.0;Cadastre;;POLYGON Z ((356248.5 6689629.7 15.8, 356242.3 6689627 15.8, 356241.7 6689628.1 15.8, 356247.9 6689630.9 15.8, 356248.5 6689629.7 15.8))
BATIMENT0000000303963035;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;12;9.1;6.3;15.5;22.7;7.3;Cadastre;A 1.0;POLYGON Z ((356299.1 6689625.6 15.5, 356300.3 6689624.4 15.5, 356295.8 6689622.1 15.5, 356291.4 6689630.7 15.5, 356287.5 6689639.2 15.5, 356291.6 6689640.9 15.5, 356295.2 6689633.7 15.5, 356299.1 6689625.6 15.5))
BATIMENT0000000303963037;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;6.6;13.8;25.9;7.9;Cadastre;A 1.0;POLYGON Z ((356319.2 6689628.3 13.8, 356303.6 6689621.4 13.8, 356302.4 6689620.8 13.8, 356300.6 6689624.1 13.8, 356300.3 6689624.4 13.8, 356299.1 6689625.6 13.8, 356295.2 6689633.7 13.8, 356291.6 6689640.9 13.8, 356307.9 6689650.1 13.8, 356312.7 6689640.4 13.8, 356313.6 6689639.9 13.8, 356313.9 6689639.1 13.8, 356319.2 6689628.3 13.8))
BATIMENT0000000303962882;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;10;20;14.0;7.2;21.2;24.1;10.0;Cadastre;A 1.0;POLYGON Z ((356169.7 6689640.1 21.2, 356175.9 6689643.7 21.2, 356176.8 6689644.2 21.2, 356177.8 6689643.1 21.2, 356179.6 6689644.1 21.2, 356180.2 6689643.6 21.2, 356183 6689645 21.2, 356184.8 6689646.1 21.2, 356185.4 6689645.1 21.2, 356189.5 6689637 21.2, 356186.6 6689635.2 21.2, 356174.8 6689628.5 21.2, 356169.7 6689640.1 21.2))
BATIMENT0000000303962894;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;35;20;13.5;7.2;20.7;22.4;8.0;Cadastre;A 1.0;POLYGON Z ((356239.1 6689633.8 20.7, 356234.7 6689643.5 20.7, 356243.3 6689647.8 20.7, 356250 6689633.4 20.7, 356247.3 6689632.1 20.7, 356247.9 6689630.9 20.7, 356241.7 6689628.1 20.7, 356239.1 6689633.8 20.7))
BATIMENT0000000303962893;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;35;20;10.9;9.8;20.8;23.5;10.2;Cadastre;C 0.4;POLYGON Z ((356192.1 6689641.9 20.8, 356197 6689644.3 20.8, 356196.4 6689646 20.8, 356199.4 6689647.4 20.8, 356201.9 6689648.6 20.8, 356202.6 6689647.2 20.8, 356207.9 6689649.6 20.8, 356205.2 6689655.1 20.8, 356210.3 6689657.3 20.8, 356215.6 6689646.2 20.8, 356220.3 6689648.3 20.8, 356220.8 6689648.5 20.8, 356221.1 6689647.6 20.8, 356217.8 6689646.1 20.8, 356219.1 6689643.5 20.8, 356196.4 6689632.5 20.8, 356192.1 6689641.9 20.8))
BATIMENT0000000303963171;Chapelle;Indifférencié;;Non;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.8;8.7;28.5;;;Cadastre;;POLYGON Z ((356255.6 6689649.2 28.5, 356275.5 6689659.8 28.5, 356275.8 6689659.3 28.5, 356276.7 6689659.8 28.5, 356277.2 6689659.4 28.5, 356277.6 6689659.6 28.5, 356277.8 6689659 28.5, 356280.8 6689660.3 28.5, 356282.2 6689657.7 28.5, 356283.6 6689654.4 28.5, 356285 6689652 28.5, 356282.6 6689650.9 28.5, 356282.9 6689649.8 28.5, 356260 6689638.4 28.5, 356257.2 6689639.4 28.5, 356254.3 6689645.5 28.5, 356254.5 6689647.7 28.5, 356255.6 6689649.2 28.5))
BATIMENT0000000303962891;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;9.8;20.7;23.1;10.0;Cadastre;;POLYGON Z ((356220.3 6689648.3 20.7, 356215.6 6689646.2 20.7, 356210.3 6689657.3 20.7, 356215 6689659.7 20.7, 356216.6 6689656.6 20.7, 356220.3 6689648.3 20.7))
BATIMENT0000000303962920;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;11.1;12.0;23.2;29.0;13.9;Cadastre;A 1.0;POLYGON Z ((356055.1 6689645.6 23.2, 356061.8 6689633.2 23.2, 356063.3 6689629.4 23.2, 356057 6689626.5 23.2, 356057.5 6689625.3 23.2, 356055.9 6689624.6 23.2, 356055.4 6689625.7 23.2, 356054.6 6689627.1 23.2, 356053.8 6689628.8 23.2, 356047.7 6689641.9 23.2, 356055.1 6689645.6 23.2))
BATIMENT0000000303962935;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.0;11.5;20.5;22.2;11.9;Cadastre;;POLYGON Z ((356107.9 6689641.3 20.5, 356110 6689637.2 20.5, 356111.3 6689637.8 20.5, 356113 6689634.8 20.5, 356107.7 6689632.1 20.5, 356105 6689630.8 20.5, 356102 6689638.2 20.5, 356102.4 6689638.4 20.5, 356107.9 6689641.3 20.5))
BATIMENT0000000303962933;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;10.7;17.9;20.0;11.0;Cadastre;;POLYGON Z ((356147.8 6689639 17.9, 356151 6689631.6 17.9, 356141.6 6689627.2 17.9, 356140.4 6689626.9 17.9, 356137.1 6689632.4 17.9, 356128.8 6689647.8 17.9, 356129.5 6689649.2 17.9, 356135.5 6689650.4 17.9, 356136.3 6689648.2 17.9, 356140.1 6689634.3 17.9, 356147.8 6689639 17.9))
BATIMENT0000000303962939;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.9;12.0;17.0;20.0;12.6;Cadastre;A 1.0;POLYGON Z ((356085 6689635.4 17, 356089.4 6689637.7 17, 356086.1 6689645.2 17, 356089.2 6689646.5 17, 356093.5 6689636 17, 356094.1 6689634.3 17, 356092 6689633.2 17, 356090.9 6689632.6 17, 356087.1 6689630.9 17, 356085 6689635.4 17))
BATIMENT0000000303962940;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.7;12.1;15.9;18.2;12.5;Cadastre;A 1.0;POLYGON Z ((356081.5 6689643 15.9, 356086.1 6689645.2 15.9, 356089.4 6689637.7 15.9, 356085 6689635.4 15.9, 356081.5 6689643 15.9))
BATIMENT0000000303962934;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.6;11.2;19.8;22.2;11.6;Cadastre;;POLYGON Z ((356120.4 6689648.2 19.8, 356126.5 6689638.4 19.8, 356122 6689635.5 19.8, 356122.3 6689634.8 19.8, 356120.7 6689633.8 19.8, 356120.4 6689634.4 19.8, 356119.8 6689634 19.8, 356117.9 6689637.3 19.8, 356113 6689634.8 19.8, 356111.3 6689637.8 19.8, 356110 6689637.2 19.8, 356107.9 6689641.3 19.8, 356120.4 6689648.2 19.8))
BATIMENT0000000303962922;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;13.2;11.5;24.7;26.9;13.8;Cadastre;C 0.6;POLYGON Z ((356069.2 6689652.4 24.7, 356075.5 6689640.1 24.7, 356061.8 6689633.2 24.7, 356055.1 6689645.6 24.7, 356069.2 6689652.4 24.7))
BATIMENT0000000303962931;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;20;20;9.3;9.4;18.7;20.1;10.8;Cadastre;A 1.0;POLYGON Z ((356154.3 6689653.2 18.7, 356156.8 6689651.8 18.7, 356160.5 6689643.2 18.7, 356152.3 6689639.4 18.7, 356152.2 6689639.9 18.7, 356151.6 6689641.4 18.7, 356150.8 6689643.3 18.7, 356146.6 6689642.1 18.7, 356147.8 6689639 18.7, 356140.1 6689634.3 18.7, 356136.3 6689648.2 18.7, 356154.3 6689653.2 18.7))
BATIMENT0000000303962937;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;13.5;11.7;25.3;26.6;13.2;Cadastre;A 1.0;POLYGON Z ((356094.9 6689636.6 25.3, 356089.9 6689647.6 25.3, 356084.5 6689660 25.3, 356090.7 6689662.8 25.3, 356102.4 6689638.4 25.3, 356102 6689638.2 25.3, 356094.1 6689634.3 25.3, 356093.5 6689636 25.3, 356094.9 6689636.6 25.3))
BATIMENT0000000303962406;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;35;10;13.8;13.6;27.5;30.0;14.7;Cadastre;A 1.0;POLYGON Z ((356060 6689670.8 27.5, 356067.1 6689656.3 27.5, 356058.1 6689652.1 27.5, 356051.2 6689666.7 27.5, 356060 6689670.8 27.5))
BATIMENT0000000303962892;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;30;49;15.4;7.3;22.7;25.0;10.0;Cadastre;A 1.0;POLYGON Z ((356230.2 6689653.2 22.7, 356225.9 6689661 22.7, 356233.6 6689664.6 22.7, 356234.8 6689665.2 22.7, 356243.3 6689647.8 22.7, 356234.7 6689643.5 22.7, 356230.2 6689653.2 22.7))
BATIMENT0000000303962878;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;10.7;8.7;19.5;22.2;11.2;Cadastre;A 1.0;POLYGON Z ((356156 6689667.8 19.5, 356158.1 6689668.7 19.5, 356170.8 6689672.9 19.5, 356174.4 6689674.4 19.5, 356175.5 6689674.9 19.5, 356178.1 6689669.2 19.5, 356166.6 6689665 19.5, 356175.9 6689643.7 19.5, 356169.7 6689640.1 19.5, 356159.4 6689663.8 19.5, 356155.7 6689663 19.5, 356156 6689667.8 19.5))
BATIMENT0000000303962889;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;9.8;17.7;19.4;10.0;Cadastre;;POLYGON Z ((356216.6 6689656.6 17.7, 356215 6689659.7 17.7, 356217.6 6689661 17.7, 356219.2 6689657.8 17.7, 356216.6 6689656.6 17.7))
BATIMENT0000000303962888;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.4;9.7;19.2;22.4;10.0;Cadastre;C 0.1;POLYGON Z ((356219.2 6689657.8 19.2, 356217.6 6689661 19.2, 356214 6689668.1 19.2, 356216.6 6689669.2 19.2, 356222.1 6689659.3 19.2, 356219.2 6689657.8 19.2))
BATIMENT0000000303962890;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.5;7.2;21.7;25.2;10.0;Cadastre;;POLYGON Z ((356224.4 6689660.2 21.7, 356222.1 6689659.3 21.7, 356216.6 6689669.2 21.7, 356214 6689668.1 21.7, 356213.4 6689669.3 21.7, 356229.4 6689676.6 21.7, 356229.9 6689675.6 21.7, 356233.5 6689667.8 21.7, 356232.4 6689667.3 21.7, 356233.6 6689664.6 21.7, 356225.9 6689661 21.7, 356224.4 6689660.2 21.7))
BATIMENT0000000303962877;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;14;10;8.5;11.7;20.2;;;Cadastre;C 0.6;POLYGON Z ((356170 6689681.7 20.2, 356176.6 6689685.7 20.2, 356176.9 6689685.4 20.2, 356178.5 6689686.5 20.2, 356179.2 6689686.1 20.2, 356192 6689693.9 20.2, 356195.4 6689687.6 20.2, 356196.9 6689684.8 20.2, 356175.5 6689674.9 20.2, 356174.4 6689674.4 20.2, 356170 6689681.7 20.2))
BATIMENT0000000303962881;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.9;10.2;19.1;20.5;12.3;Cadastre;C 0.6;POLYGON Z ((356183.7 6689693.3 19.1, 356182.8 6689695.2 19.1, 356183.6 6689695.7 19.1, 356176.2 6689709.3 19.1, 356182.3 6689712.4 19.1, 356184.9 6689707.4 19.1, 356190.1 6689697.7 19.1, 356190.5 6689696.8 19.1, 356183.7 6689693.3 19.1))
BATIMENT0000000303962970;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;11.7;15.8;16.5;12.8;Cadastre;;POLYGON Z ((356165.4 6689704.9 15.8, 356171.3 6689707.9 15.8, 356172.7 6689704.9 15.8, 356166.8 6689702.1 15.8, 356165.4 6689704.9 15.8))
BATIMENT0000000303962876;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.1;10.1;19.2;23.6;11.3;Cadastre;;POLYGON Z ((356192.3 6689702.2 19.2, 356220.6 6689716.3 19.2, 356223.8 6689717.9 19.2, 356225.3 6689714.9 19.2, 356190.1 6689697.7 19.2, 356184.9 6689707.4 19.2, 356188.7 6689709.3 19.2, 356192.3 6689702.2 19.2))
BATIMENT0000000303962879;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.4;10.0;19.4;23.8;10.8;Cadastre;;POLYGON Z ((356192.3 6689702.2 19.4, 356188.7 6689709.3 19.4, 356215.4 6689722.5 19.4, 356217.4 6689717.8 19.4, 356219.3 6689718.8 19.4, 356220.6 6689716.3 19.4, 356192.3 6689702.2 19.4))
BATIMENT0000000303963161;Chapelle;Religieux;;Non;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.0;11.1;23.1;;;Cadastre;;POLYGON Z ((356109.9 6689675.3 23.1, 356109.9 6689675.4 23.1, 356110 6689675.2 23.1, 356131.8 6689681.6 23.1, 356136 6689682.6 23.1, 356138.5 6689674.7 23.1, 356143.9 6689673.6 23.1, 356144.7 6689666.8 23.1, 356143.7 6689665.9 23.1, 356142.8 6689663 23.1, 356143.3 6689660.9 23.1, 356134.9 6689659 23.1, 356135.1 6689656.8 23.1, 356108.3 6689649.9 23.1, 356107.2 6689653.8 23.1, 356105.7 6689653.4 23.1, 356105.4 6689654.4 23.1, 356105.9 6689654.6 23.1, 356103.4 6689663.8 23.1, 356102.7 6689663.5 23.1, 356102.5 6689664.5 23.1, 356104 6689664.9 23.1, 356101.8 6689672.7 23.1, 356102.3 6689672.9 23.1, 356109.9 6689675.3 23.1))
BATIMENT0000000303962421;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;9.8;14.5;19.0;12.0;Cadastre;;POLYGON Z ((356152.6 6689663 14.5, 356150.9 6689670.7 14.5, 356155.8 6689672.8 14.5, 356152.6 6689663 14.5))
BATIMENT0000000303962420;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;24;20;8.4;10.0;18.5;21.2;12.4;Cadastre;A 1.0;POLYGON Z ((356148 6689676.5 18.5, 356153.5 6689678.9 18.5, 356154.1 6689677.2 18.5, 356155.8 6689672.8 18.5, 356150.9 6689670.7 18.5, 356152.6 6689663 18.5, 356143.3 6689660.9 18.5, 356142.8 6689663 18.5, 356143.7 6689665.9 18.5, 356144.7 6689666.8 18.5, 356145.2 6689666.1 18.5, 356146.9 6689666.3 18.5, 356145.8 6689668.6 18.5, 356148.2 6689671.4 18.5, 356147.9 6689675.5 18.5, 356148 6689676.5 18.5))
BATIMENT0000000303963063;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;13.3;19.0;22.5;14.8;Cadastre;;POLYGON Z ((356091.3 6689668.5 19, 356074.8 6689660.5 19, 356068.3 6689675 19, 356073 6689677.1 19, 356086.2 6689683.2 19, 356091.3 6689668.5 19))
BATIMENT0000000303962883;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;10.2;18.5;21.7;11.4;Cadastre;;POLYGON Z ((356157.3 6689671.1 18.5, 356169.9 6689675.3 18.5, 356170.8 6689672.9 18.5, 356158.1 6689668.7 18.5, 356157.3 6689671.1 18.5))
BATIMENT0000000303963064;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.0;13.3;18.3;22.5;14.7;Cadastre;A 1.0;POLYGON Z ((356070.4 6689682.4 18.3, 356080.1 6689686.8 18.3, 356080.1 6689686.6 18.3, 356082.6 6689687.6 18.3, 356084.6 6689687.1 18.3, 356086.2 6689683.2 18.3, 356073 6689677.1 18.3, 356070.4 6689682.4 18.3))
BATIMENT0000000303963159;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;13.3;20.5;24.5;14.4;Cadastre;;POLYGON Z ((356098.1 6689695.9 20.5, 356103.8 6689683.1 20.5, 356101.5 6689682.2 20.5, 356102.3 6689680.4 20.5, 356101.5 6689679.5 20.5, 356102.9 6689678.6 20.5, 356108.9 6689679.8 20.5, 356109.9 6689675.4 20.5, 356109.9 6689675.3 20.5, 356102.3 6689672.9 20.5, 356101.9 6689674.9 20.5, 356100.1 6689675.6 20.5, 356096.2 6689674.1 20.5, 356094.1 6689678.9 20.5, 356093.5 6689678.7 20.5, 356089.3 6689689 20.5, 356091.3 6689692.7 20.5, 356098.1 6689695.9 20.5))
BATIMENT0000000303962422;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;5.9;10.8;16.7;22.9;13.5;Cadastre;C 0.7;POLYGON Z ((356150.1 6689686.9 16.7, 356152.9 6689695.1 16.7, 356150.9 6689697.2 16.7, 356155.1 6689699.3 16.7, 356156 6689698.4 16.7, 356162.6 6689684.3 16.7, 356161.5 6689681.1 16.7, 356154.1 6689677.2 16.7, 356153.5 6689678.9 16.7, 356150.1 6689686.9 16.7))
BATIMENT0000000303962989;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.7;13.6;17.3;22.6;15.0;Cadastre;C 0.2;POLYGON Z ((356057.4 6689688.1 17.3, 356079.6 6689698.1 17.3, 356081.9 6689692.6 17.3, 356059.3 6689682.8 17.3, 356057.4 6689688.1 17.3))
BATIMENT0000000303963160;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;10;10;17.9;12.3;30.2;34.7;15.3;Cadastre;C 0.4;POLYGON Z ((356115.8 6689730.8 30.2, 356115.7 6689731.6 30.2, 356116.1 6689732.6 30.2, 356121.1 6689733.9 30.2, 356121.9 6689733.4 30.2, 356122.1 6689732.2 30.2, 356125.8 6689733.2 30.2, 356127.7 6689726.6 30.2, 356127.1 6689726.4 30.2, 356134.2 6689701 30.2, 356135 6689701.3 30.2, 356136.7 6689695 30.2, 356136.3 6689694.5 30.2, 356138.3 6689691.7 30.2, 356142.5 6689693.3 30.2, 356142.5 6689692.8 30.2, 356144.3 6689680.7 30.2, 356145.3 6689680 30.2, 356144.7 6689678.7 30.2, 356143.7 6689679.1 30.2, 356145.9 6689675.2 30.2, 356147.9 6689675.5 30.2, 356148.2 6689671.4 30.2, 356145.8 6689668.6 30.2, 356146.9 6689666.3 30.2, 356145.2 6689666.1 30.2, 356144.7 6689666.8 30.2, 356143.9 6689673.6 30.2, 356138.5 6689674.7 30.2, 356136 6689682.6 30.2, 356131.8 6689681.6 30.2, 356128.5 6689692.3 30.2, 356123.3 6689690.7 30.2, 356121.4 6689697.2 30.2, 356122 6689697.6 30.2, 356114.6 6689723.1 30.2, 356113.9 6689722.8 30.2, 356112.2 6689729.5 30.2, 356115.8 6689730.8 30.2))
BATIMENT0000000302930605;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;12.4;11.9;24.4;27.2;13.7;Cadastre;A 1.0;POLYGON Z ((355726.3 6689539.1 24.4, 355748.1 6689542.2 24.4, 355749.4 6689533.7 24.4, 355749.7 6689532.4 24.4, 355741.7 6689530.5 24.4, 355738.8 6689529.7 24.4, 355738.6 6689530.5 24.4, 355738.3 6689532.5 24.4, 355737.9 6689535.3 24.4, 355733.7 6689534.8 24.4, 355734.5 6689529.7 24.4, 355734.6 6689528.5 24.4, 355726.9 6689527.4 24.4, 355726.3 6689539.1 24.4))
BATIMENT0000000302931354;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;7.0;39;30;19.8;13.0;32.8;;;Cadastre;A 1.0;POLYGON Z ((355690.1 6689532 32.8, 355676.9 6689525.6 32.8, 355672.5 6689529.3 32.8, 355672.2 6689529.5 32.8, 355674.6 6689532.6 32.8, 355674.3 6689532.8 32.8, 355676.9 6689536.1 32.8, 355676.1 6689537.8 32.8, 355675.3 6689538.8 32.8, 355676.2 6689539.7 32.8, 355677.5 6689538.5 32.8, 355682.8 6689543 32.8, 355682.4 6689543.7 32.8, 355683.9 6689544.5 32.8, 355690.1 6689532 32.8))
BATIMENT0000000302931355;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;6.0;12;20;18.3;13.0;31.3;33.5;13.3;Cadastre;A 1.0;POLYGON Z ((355661.8 6689554.2 31.3, 355669.7 6689549.7 31.3, 355672.8 6689553.9 31.3, 355677.5 6689549.8 31.3, 355680.3 6689551.3 31.3, 355683.9 6689544.5 31.3, 355682.4 6689543.7 31.3, 355682.8 6689543 31.3, 355677.5 6689538.5 31.3, 355676.2 6689539.7 31.3, 355675.3 6689538.8 31.3, 355675.1 6689538.9 31.3, 355668.9 6689533 31.3, 355654.7 6689541.5 31.3, 355661.8 6689554.2 31.3), (355667.3 6689539.3 31.3, 355673.4 6689545.6 31.3, 355670.9 6689548 31.3, 355664.7 6689541.7 31.3, 355667.3 6689539.3 31.3))
BATIMENT0000000302930748;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;6.0;10;20;19.9;12.8;32.7;36.5;13.7;Cadastre;A 1.0;POLYGON Z ((355696.5 6689552.5 32.7, 355704.2 6689556.1 32.7, 355705.5 6689551.8 32.7, 355709.8 6689553.3 32.7, 355709.5 6689553.7 32.7, 355712.9 6689554.8 32.7, 355721.7 6689557.7 32.7, 355721.3 6689537.6 32.7, 355719.4 6689535.3 32.7, 355708.7 6689534.2 32.7, 355704.4 6689536.6 32.7, 355696.5 6689552.5 32.7), (355708.1 6689546.9 32.7, 355711.7 6689548.7 32.7, 355710.8 6689550.3 32.7, 355707.3 6689548.7 32.7, 355708.1 6689546.9 32.7))
BATIMENT0000000302930604;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;13.2;12.6;25.8;31.5;13.7;Cadastre;A 1.0;POLYGON Z ((355725.4 6689554 25.8, 355728.2 6689554.3 25.8, 355728.3 6689554.1 25.8, 355739.2 6689555.7 25.8, 355739.6 6689553.1 25.8, 355746.4 6689554 25.8, 355747.2 6689548.8 25.8, 355748.1 6689542.9 25.8, 355748.1 6689542.2 25.8, 355726.3 6689539.1 25.8, 355725.4 6689554 25.8))
BATIMENT0000000302930749;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;29;23;18.3;12.8;31.1;32.9;13.8;Cadastre;A 1.0;POLYGON Z ((355721.7 6689557.7 31.1, 355712.9 6689554.8 31.1, 355711.8 6689558 31.1, 355708.6 6689557 31.1, 355709.5 6689553.7 31.1, 355709.8 6689553.3 31.1, 355705.5 6689551.8 31.1, 355704.2 6689556.1 31.1, 355703.6 6689557.9 31.1, 355721.8 6689563.7 31.1, 355721.7 6689557.7 31.1))
BATIMENT0000000302931357;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;18.1;13.0;31.1;34.9;13.4;Cadastre;A 1.0;POLYGON Z ((355665.4 6689560.2 31.1, 355669 6689566.8 31.1, 355672.6 6689566.7 31.1, 355680.3 6689551.3 31.1, 355677.5 6689549.8 31.1, 355672.8 6689553.9 31.1, 355669.7 6689549.7 31.1, 355661.8 6689554.2 31.1, 355665.4 6689560.2 31.1))
BATIMENT0000000302930743;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;10;20;19.1;12.9;32.0;35.1;14.2;Cadastre;A 1.0;POLYGON Z ((355689.2 6689566.9 32, 355692.7 6689569 32, 355696.8 6689572.3 32, 355697.9 6689573.2 32, 355698.5 6689573.4 32, 355703.7 6689575.2 32, 355706.4 6689567.1 32, 355702.2 6689565 32, 355704 6689561.1 32, 355708.9 6689562.6 32, 355707.6 6689565.5 32, 355709.4 6689566.2 32, 355722 6689570.5 32, 355721.8 6689563.7 32, 355703.6 6689557.9 32, 355704.2 6689556.1 32, 355696.5 6689552.5 32, 355689.2 6689566.9 32))
BATIMENT0000000302930745;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.2;12.8;32.0;32.5;14.1;Cadastre;;POLYGON Z ((355697.9 6689573.2 32, 355696.8 6689572.3 32, 355696.3 6689573.9 32, 355698.2 6689574.6 32, 355698.5 6689573.4 32, 355697.9 6689573.2 32))
BATIMENT0000000302930750;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;20;20;17.7;12.8;30.5;33.2;14.5;Cadastre;A 1.0;POLYGON Z ((355720 6689580.8 30.5, 355722 6689570.5 30.5, 355709.4 6689566.2 30.5, 355708.4 6689569 30.5, 355707.5 6689569.2 30.5, 355706.7 6689571.4 30.5, 355707.3 6689572.5 30.5, 355706 6689575.9 30.5, 355706.6 6689576.1 30.5, 355718.2 6689579.9 30.5, 355718 6689580.2 30.5, 355720 6689580.8 30.5))
BATIMENT0000000302930576;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;90;20;14.8;13.1;27.9;;;Cadastre;A 1.0;POLYGON Z ((355644.6 6689542.8 27.9, 355640.6 6689544.8 27.9, 355641.1 6689545.7 27.9, 355639.9 6689546.3 27.9, 355639.4 6689545.6 27.9, 355636.8 6689546.9 27.9, 355636.6 6689546.4 27.9, 355626.2 6689549.5 27.9, 355627.1 6689552.8 27.9, 355624 6689553.5 27.9, 355625.3 6689558.9 27.9, 355635.7 6689555.2 27.9, 355635.2 6689553.8 27.9, 355634 6689549.6 27.9, 355635.9 6689548.9 27.9, 355636.1 6689550 27.9, 355638.7 6689549.9 27.9, 355639.3 6689552.5 27.9, 355639.6 6689553.7 27.9, 355648.9 6689550.7 27.9, 355644.6 6689542.8 27.9))
BATIMENT0000000302930584;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;12.3;24.9;27.2;12.8;Cadastre;;POLYGON Z ((355635.7 6689555.2 24.9, 355637.2 6689554.8 24.9, 355637.1 6689554.4 24.9, 355639.6 6689553.7 24.9, 355639.3 6689552.5 24.9, 355636.9 6689552.7 24.9, 355635.2 6689553.8 24.9, 355635.7 6689555.2 24.9))
BATIMENT0000000302930591;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;12.9;12.3;25.2;28.2;13.5;Cadastre;A 1.0;POLYGON Z ((355648.9 6689550.7 25.2, 355639.6 6689553.7 25.2, 355639.7 6689553.8 25.2, 355639.7 6689554.1 25.2, 355639.7 6689554.3 25.2, 355639.7 6689554.5 25.2, 355639.7 6689554.7 25.2, 355639.6 6689554.9 25.2, 355639.6 6689555.1 25.2, 355641.4 6689558.9 25.2, 355642.9 6689560.1 25.2, 355643.4 6689561.5 25.2, 355644.5 6689564.5 25.2, 355647.5 6689563.2 25.2, 355647.4 6689562.7 25.2, 355654.2 6689559.6 25.2, 355648.9 6689550.7 25.2))
BATIMENT0000000302930578;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;14.9;13.1;28.0;30.8;13.5;Cadastre;A 1.0;POLYGON Z ((355624.7 6689559.4 28, 355625.3 6689561.9 28, 355626.2 6689566.6 28, 355634 6689564.4 28, 355634 6689563.7 28, 355639.6 6689561.2 28, 355640.3 6689563.2 28, 355643.4 6689561.5 28, 355642.9 6689560.1 28, 355641.4 6689558.9 28, 355639.3 6689559.7 28, 355638 6689556.6 28, 355638.4 6689556.4 28, 355638.5 6689556.3 28, 355638.9 6689556 28, 355639 6689555.9 28, 355639.1 6689555.8 28, 355639.2 6689555.6 28, 355639.3 6689555.6 28, 355639.4 6689555.4 28, 355639.5 6689555.2 28, 355639.6 6689555.1 28, 355639.6 6689554.9 28, 355639.7 6689554.7 28, 355639.7 6689554.5 28, 355639.7 6689554.3 28, 355639.7 6689554.1 28, 355639.7 6689553.8 28, 355639.6 6689553.7 28, 355637.1 6689554.4 28, 355637.2 6689554.8 28, 355635.7 6689555.2 28, 355625.3 6689558.9 28, 355624.7 6689559.1 28, 355624.7 6689559.4 28))
BATIMENT0000000302930575;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;15;20;14.5;12.8;27.3;28.6;13.1;Cadastre;B 0.4;POLYGON Z ((355600.9 6689568.9 27.3, 355612.6 6689570.7 27.3, 355612.7 6689570.3 27.3, 355613 6689567.2 27.3, 355613.2 6689566.5 27.3, 355609.6 6689566.2 27.3, 355610 6689561.7 27.3, 355613.3 6689561.9 27.3, 355613.5 6689561 27.3, 355615.3 6689561.2 27.3, 355615.4 6689560.5 27.3, 355624.7 6689559.4 27.3, 355624.7 6689559.1 27.3, 355625.3 6689558.9 27.3, 355624 6689553.5 27.3, 355623.8 6689552.9 27.3, 355621.5 6689553.4 27.3, 355621.3 6689553 27.3, 355619.1 6689553.5 27.3, 355618.6 6689551.2 27.3, 355602.6 6689553.4 27.3, 355600.9 6689568.9 27.3))
BATIMENT0000000302930582;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;12.5;19.2;26.7;13.0;Cadastre;;POLYGON Z ((355620.5 6689568.1 19.2, 355626.2 6689566.6 19.2, 355625.3 6689561.9 19.2, 355617.1 6689563 19.2, 355616.7 6689567.6 19.2, 355620.5 6689568.1 19.2))
BATIMENT0000000302930583;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;20;20;14.8;13.1;27.9;32.2;13.7;Cadastre;A 1.0;POLYGON Z ((355654.2 6689559.6 27.9, 355647.4 6689562.7 27.9, 355647.5 6689563.2 27.9, 355644.5 6689564.5 27.9, 355641.4 6689566 27.9, 355641.9 6689568 27.9, 355635.7 6689569.8 27.9, 355637.7 6689575.8 27.9, 355645.1 6689572.5 27.9, 355644.2 6689569.8 27.9, 355647.2 6689568.5 27.9, 355647.1 6689568.1 27.9, 355649.6 6689567.2 27.9, 355649.8 6689567.8 27.9, 355657.2 6689564.7 27.9, 355654.2 6689559.6 27.9))
BATIMENT0000000302930580;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;16;20;14.5;13.1;27.6;30.5;13.6;Cadastre;A 1.0;POLYGON Z ((355635.6 6689578.3 27.6, 355638.6 6689578.5 27.6, 355637.7 6689575.8 27.6, 355635.7 6689569.8 27.6, 355641.9 6689568 27.6, 355641.4 6689566 27.6, 355644.5 6689564.5 27.6, 355643.4 6689561.5 27.6, 355640.3 6689563.2 27.6, 355639.6 6689561.2 27.6, 355634 6689563.7 27.6, 355634 6689564.4 27.6, 355634.9 6689567.9 27.6, 355633.1 6689568.5 27.6, 355633.3 6689570.1 27.6, 355632.2 6689570.4 27.6, 355632.5 6689572.6 27.6, 355630.8 6689573.1 27.6, 355629.4 6689572.8 27.6, 355629 6689577.8 27.6, 355635.6 6689578.3 27.6))
BATIMENT0000000302931158;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;12.5;10.6;23.2;29.0;13.0;Cadastre;A 1.0;POLYGON Z ((355562.3 6689590.1 23.2, 355574.8 6689595.1 23.2, 355576.9 6689581.6 23.2, 355576.5 6689581.6 23.2, 355577.8 6689574.1 23.2, 355577.9 6689574.2 23.2, 355578 6689573.6 23.2, 355578.1 6689573.6 23.2, 355578.3 6689572.8 23.2, 355577.5 6689572.6 23.2, 355577.5 6689572.8 23.2, 355574.2 6689572.2 23.2, 355576.8 6689557.8 23.2, 355588.7 6689559.6 23.2, 355586.4 6689573.9 23.2, 355586.9 6689574 23.2, 355586.6 6689575.7 23.2, 355593.4 6689576.8 23.2, 355595.8 6689560.2 23.2, 355596.4 6689554.6 23.2, 355596.7 6689548.5 23.2, 355582.4 6689547.5 23.2, 355581.8 6689547.5 23.2, 355569.7 6689546.6 23.2, 355568.2 6689556.6 23.2, 355567.8 6689556.7 23.2, 355562.3 6689590.1 23.2))
BATIMENT0000000302930589;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;10;20;8.7;12.5;21.2;27.0;13.2;Cadastre;C 0.1;POLYGON Z ((355616.4 6689574.9 21.2, 355625.5 6689576.4 21.2, 355625.4 6689577.6 21.2, 355629 6689577.8 21.2, 355629.4 6689572.8 21.2, 355614.8 6689570.7 21.2, 355616.4 6689574.9 21.2))
BATIMENT0000000302930607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;14.0;20.2;23.7;14.3;Cadastre;;POLYGON Z ((355770.4 6689559.2 20.2, 355769.1 6689563.2 20.2, 355771 6689563.8 20.2, 355772.5 6689559.5 20.2, 355770.4 6689559.2 20.2))
BATIMENT0000000302930608;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;11.8;13.7;25.5;27.8;14.5;Cadastre;B 0.4;POLYGON Z ((355777.5 6689563.3 25.5, 355782 6689564.8 25.5, 355786.1 6689565.9 25.5, 355786.3 6689566 25.5, 355787.2 6689560.1 25.5, 355785.2 6689559.5 25.5, 355785.3 6689559.2 25.5, 355779.6 6689557.5 25.5, 355779.6 6689557.7 25.5, 355778.8 6689560.7 25.5, 355778.1 6689560.5 25.5, 355777.3 6689563.2 25.5, 355777.5 6689563.3 25.5))
BATIMENT0000000302930600;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;6.8;12.9;19.8;26.9;14.6;Cadastre;A 1.0;POLYGON Z ((355769.5 6689578.8 19.8, 355769.7 6689579 19.8, 355770.6 6689576.3 19.8, 355772.6 6689577 19.8, 355772.7 6689576.7 19.8, 355773.1 6689575 19.8, 355774.2 6689575.2 19.8, 355774.5 6689574.3 19.8, 355774.3 6689574.2 19.8, 355775 6689571.9 19.8, 355775.2 6689571.9 19.8, 355775.4 6689571 19.8, 355775.3 6689570.9 19.8, 355776 6689568.1 19.8, 355776.2 6689568.2 19.8, 355776.5 6689567.2 19.8, 355776.3 6689567.2 19.8, 355777 6689565 19.8, 355777.2 6689565 19.8, 355777.4 6689564.1 19.8, 355777.3 6689564 19.8, 355777.5 6689563.3 19.8, 355777.3 6689563.2 19.8, 355778.1 6689560.5 19.8, 355773 6689559.1 19.8, 355774 6689556.2 19.8, 355775.2 6689552.4 19.8, 355758 6689550.1 19.8, 355756.5 6689556.3 19.8, 355756.8 6689556.4 19.8, 355757.1 6689556.4 19.8, 355757.1 6689556.2 19.8, 355758.4 6689556.5 19.8, 355770.4 6689559.2 19.8, 355772.5 6689559.5 19.8, 355771 6689563.8 19.8, 355769.1 6689568.9 19.8, 355769.3 6689569 19.8, 355767.4 6689574.3 19.8, 355766.2 6689577.5 19.8, 355769.5 6689578.8 19.8))
BATIMENT0000000302930599;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;14.1;13.1;27.3;29.9;14.3;Cadastre;A 1.0;POLYGON Z ((355802.9 6689578.8 27.3, 355808.5 6689557.4 27.3, 355808.5 6689557.2 27.3, 355775.7 6689551.2 27.3, 355775.2 6689552.4 27.3, 355774 6689556.2 27.3, 355779.6 6689557.7 27.3, 355779.6 6689557.5 27.3, 355785.3 6689559.2 27.3, 355785.8 6689557.9 27.3, 355784.2 6689557.5 27.3, 355784.8 6689555.3 27.3, 355787.4 6689556.2 27.3, 355788.5 6689556.2 27.3, 355788.2 6689557.3 27.3, 355795.3 6689559 27.3, 355794.6 6689562.2 27.3, 355791.4 6689574.7 27.3, 355791.6 6689575.7 27.3, 355796.9 6689577.1 27.3, 355796.9 6689576.8 27.3, 355802.6 6689578.4 27.3, 355802.6 6689578.7 27.3, 355802.9 6689578.8 27.3))
BATIMENT0000000302930614;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;;;7.4;13.7;21.2;24.1;14.4;Cadastre;A 1.0;POLYGON Z ((355753.1 6689567.7 21.2, 355767.4 6689574.3 21.2, 355769.3 6689569 21.2, 355769.1 6689568.9 21.2, 355754.4 6689562.3 21.2, 355754.1 6689562.5 21.2, 355745.7 6689558.9 21.2, 355744.8 6689564.4 21.2, 355746.7 6689565.2 21.2, 355746.8 6689565 21.2, 355753.1 6689567.7 21.2))
BATIMENT0000000302930610;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;9.8;13.4;23.2;28.2;14.8;Cadastre;A 1.0;POLYGON Z ((355728.6 6689567.4 23.2, 355727.3 6689575.1 23.2, 355733.9 6689576.1 23.2, 355734 6689576.7 23.2, 355750.4 6689579.5 23.2, 355753.1 6689567.7 23.2, 355746.8 6689565 23.2, 355746.7 6689565.2 23.2, 355744.4 6689575.1 23.2, 355737.1 6689574 23.2, 355737.2 6689570.8 23.2, 355736.7 6689570.6 23.2, 355736.4 6689570 23.2, 355735.3 6689569.9 23.2, 355735.4 6689568.9 23.2, 355735.6 6689569 23.2, 355735.7 6689569 23.2, 355735.9 6689569 23.2, 355736 6689568.9 23.2, 355736.1 6689568.9 23.2, 355736.2 6689568.8 23.2, 355736.3 6689568.7 23.2, 355736.4 6689568.6 23.2, 355736.4 6689568.5 23.2, 355736.5 6689568.4 23.2, 355736.5 6689568.2 23.2, 355736.5 6689568.1 23.2, 355736.5 6689568 23.2, 355736.5 6689567.8 23.2, 355736.5 6689567.7 23.2, 355736.4 6689567.6 23.2, 355736.3 6689567.5 23.2, 355736.2 6689567.4 23.2, 355736.1 6689567.3 23.2, 355735.9 6689567.2 23.2, 355735.7 6689567.2 23.2, 355735.5 6689567.2 23.2, 355735.7 6689564.1 23.2, 355735.9 6689558.7 23.2, 355738.8 6689558.9 23.2, 355740.3 6689560.3 23.2, 355739.9 6689564.2 23.2, 355744.8 6689564.4 23.2, 355745.7 6689558.9 23.2, 355746 6689556.8 23.2, 355739.2 6689555.7 23.2, 355728.3 6689554.1 23.2, 355728.2 6689554.3 23.2, 355728.6 6689567.4 23.2))
BATIMENT0000000302930627;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.2;13.9;17.2;17.5;14.2;Cadastre;C 1.0;POLYGON Z ((355784.3 6689573.7 17.2, 355787.9 6689574.7 17.2, 355788.7 6689571.3 17.2, 355785 6689570.4 17.2, 355784.3 6689573.7 17.2))
BATIMENT0000000302930616;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;6.4;15.5;21.9;;;Cadastre;B 0.1;POLYGON Z ((355757.7 6689573.8 21.9, 355766.2 6689577.5 21.9, 355767.4 6689574.3 21.9, 355753.1 6689567.7 21.9, 355750.4 6689579.5 21.9, 355750 6689581.1 21.9, 355755.6 6689581.8 21.9, 355757.2 6689576 21.9, 355757.7 6689573.8 21.9))
BATIMENT0000000302930624;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;14.3;16.7;19.7;16.1;Cadastre;;POLYGON Z ((355763.7 6689584.8 16.7, 355765.7 6689579.5 16.7, 355757.2 6689576 16.7, 355755.6 6689581.8 16.7, 355759.5 6689582.4 16.7, 355763.7 6689584.8 16.7))
BATIMENT0000000302930615;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;12.3;14.1;26.5;29.2;15.9;Cadastre;B 0.6;POLYGON Z ((355768 6689583.3 26.5, 355767.2 6689585.7 26.5, 355767.9 6689586.1 26.5, 355777.5 6689590.3 26.5, 355777.9 6689589.1 26.5, 355775.5 6689588.1 26.5, 355776 6689586.5 26.5, 355778.5 6689587.3 26.5, 355781.2 6689579 26.5, 355772.7 6689576.7 26.5, 355772.6 6689577 26.5, 355770.6 6689576.3 26.5, 355769.7 6689579 26.5, 355769.5 6689578.8 26.5, 355768 6689583.3 26.5))
BATIMENT0000000302930742;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;10;20;20.2;12.8;33.0;36.8;14.1;Cadastre;A 1.0;POLYGON Z ((355680.5 6689584.1 33, 355684 6689589.2 33, 355692.5 6689579.5 33, 355691 6689578.7 33, 355691.5 6689577.7 33, 355691.1 6689576.6 33, 355690.6 6689576.4 33, 355690.9 6689576 33, 355693.9 6689577.8 33, 355695.3 6689578.6 33, 355695.9 6689576 33, 355696.3 6689573.9 33, 355696.8 6689572.3 33, 355692.7 6689569 33, 355689.2 6689566.9 33, 355680.5 6689584.1 33))
BATIMENT0000000302930746;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.0;13.7;28.7;31.0;14.3;Cadastre;;POLYGON Z ((355695.3 6689578.6 28.7, 355694.9 6689580.2 28.7, 355696.3 6689580.8 28.7, 355697.7 6689576.5 28.7, 355695.9 6689576 28.7, 355695.3 6689578.6 28.7))
BATIMENT0000000302930747;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;13;20;16.6;13.6;30.2;32.2;14.7;Cadastre;C 0.6;POLYGON Z ((355698.5 6689573.4 30.2, 355698.2 6689574.6 30.2, 355697.7 6689576.5 30.2, 355696.3 6689580.8 30.2, 355696.2 6689581 30.2, 355697.6 6689581.5 30.2, 355696.1 6689585 30.2, 355697.6 6689585.4 30.2, 355697.5 6689585.6 30.2, 355700.3 6689586.7 30.2, 355700.6 6689585.9 30.2, 355703.7 6689585.6 30.2, 355705.3 6689581.1 30.2, 355704.8 6689581 30.2, 355706.6 6689576.1 30.2, 355706 6689575.9 30.2, 355703.7 6689575.2 30.2, 355698.5 6689573.4 30.2))
BATIMENT0000000302930754;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;00;00;17.3;12.8;30.1;32.0;14.8;Cadastre;A 1.0;POLYGON Z ((355718 6689580.2 30.1, 355718.2 6689579.9 30.1, 355706.6 6689576.1 30.1, 355704.8 6689581 30.1, 355705.3 6689581.1 30.1, 355708.1 6689582.1 30.1, 355709.8 6689582.7 30.1, 355709.3 6689584.7 30.1, 355710.4 6689585.1 30.1, 355709.6 6689587.4 30.1, 355709.1 6689589.2 30.1, 355709 6689589.6 30.1, 355715.6 6689591.9 30.1, 355718 6689580.2 30.1))
BATIMENT0000000302930744;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;20;17.0;13.7;30.7;34.4;14.5;Cadastre;A 1.0;POLYGON Z ((355690 6689598.4 30.7, 355693.1 6689592.9 30.7, 355694.9 6689589.7 30.7, 355695.1 6689589.8 30.7, 355697.5 6689585.6 30.7, 355697.6 6689585.4 30.7, 355696.1 6689585 30.7, 355697.6 6689581.5 30.7, 355696.2 6689581 30.7, 355696.3 6689580.8 30.7, 355694.9 6689580.2 30.7, 355695.3 6689578.6 30.7, 355693.9 6689577.8 30.7, 355692.5 6689579.5 30.7, 355684 6689589.2 30.7, 355690 6689598.4 30.7))
BATIMENT0000000302930625;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;10.2;14.1;24.3;26.7;15.8;Cadastre;A 1.0;POLYGON Z ((355722.9 6689596.6 24.3, 355728.7 6689598 24.3, 355734.4 6689599.1 24.3, 355741.3 6689600.9 24.3, 355743.4 6689592.9 24.3, 355724.9 6689588.9 24.3, 355722.9 6689596.6 24.3))
BATIMENT0000000302930751;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;19.5;12.8;32.3;36.5;14.6;Cadastre;C 0.4;POLYGON Z ((355695.8 6689607.3 32.3, 355697.5 6689605.6 32.3, 355702.9 6689591 32.3, 355703.1 6689591 32.3, 355704.2 6689587.7 32.3, 355702.5 6689587 32.3, 355701.4 6689587.2 32.3, 355699.6 6689591.7 32.3, 355698.6 6689591.3 32.3, 355695.1 6689589.8 32.3, 355694.9 6689589.7 32.3, 355693.1 6689592.9 32.3, 355696 6689594 32.3, 355692.7 6689602.5 32.3, 355695.8 6689607.3 32.3))
BATIMENT0000000302930752;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;20.1;12.8;32.9;36.5;14.5;Cadastre;A 1.0;POLYGON Z ((355692.7 6689602.5 32.9, 355696 6689594 32.9, 355693.1 6689592.9 32.9, 355690 6689598.4 32.9, 355692.7 6689602.5 32.9))
BATIMENT0000000302930753;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;10;20;18.2;12.8;31.0;34.0;14.7;Cadastre;A 1.0;POLYGON Z ((355701.9 6689608.9 31, 355705.1 6689600.7 31, 355705.9 6689598.1 31, 355708.9 6689599.4 31, 355709.5 6689597.7 31, 355714.1 6689599.8 31, 355714.2 6689599.6 31, 355715.6 6689591.9 31, 355709 6689589.6 31, 355709.1 6689589.2 31, 355707.2 6689588.7 31, 355706.4 6689591.1 31, 355705.3 6689590.7 31, 355705 6689591.7 31, 355703.1 6689591 31, 355702.9 6689591 31, 355697.5 6689605.6 31, 355701.9 6689608.9 31))
BATIMENT0000000302930684;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;15.0;20.0;24.7;15.6;Cadastre;;POLYGON Z ((355731.7 6689601.3 20, 355730 6689605.6 20, 355734.5 6689606.7 20, 355735.6 6689602.4 20, 355731.7 6689601.3 20))
BATIMENT0000000302930623;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;14.2;20.5;24.7;16.0;Cadastre;;POLYGON Z ((355765.6 6689582.3 20.5, 355764.6 6689585 20.5, 355767.2 6689585.7 20.5, 355768 6689583.3 20.5, 355765.6 6689582.3 20.5))
BATIMENT0000000302930618;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1699-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;10;20;13.8;14.0;27.9;31.9;15.3;Cadastre;A 1.0;POLYGON Z ((355802.6 6689578.7 27.9, 355802.6 6689578.4 27.9, 355796.9 6689576.8 27.9, 355796.9 6689577.1 27.9, 355795.5 6689582.5 27.9, 355781.2 6689579 27.9, 355778.5 6689587.3 27.9, 355777.9 6689589.1 27.9, 355777.5 6689590.3 27.9, 355780.5 6689591.6 27.9, 355789.3 6689593.7 27.9, 355789.4 6689593.4 27.9, 355790.3 6689590.3 27.9, 355792.5 6689590.9 27.9, 355792.5 6689590.7 27.9, 355798.8 6689592.7 27.9, 355802.6 6689578.7 27.9))
BATIMENT0000000302930622;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;20;20;13.5;13.9;27.5;31.8;16.2;Cadastre;A 1.0;POLYGON Z ((355743.4 6689592.9 27.5, 355748.2 6689594.1 27.5, 355756.6 6689596.1 27.5, 355757.1 6689592.5 27.5, 355757.9 6689589.9 27.5, 355755.9 6689589.4 27.5, 355756.5 6689587.1 27.5, 355758.4 6689587.5 27.5, 355759.5 6689582.4 27.5, 355755.6 6689581.8 27.5, 355750 6689581.1 27.5, 355750.4 6689579.5 27.5, 355734 6689576.7 27.5, 355733.9 6689576.1 27.5, 355727.3 6689575.1 27.5, 355724.9 6689588.9 27.5, 355743.4 6689592.9 27.5), (355742.6 6689580.8 27.5, 355745.4 6689582.6 27.5, 355751.2 6689584 27.5, 355752.3 6689585.9 27.5, 355751.8 6689588.3 27.5, 355749.8 6689589.4 27.5, 355741.8 6689587.4 27.5, 355742.6 6689580.8 27.5))
BATIMENT0000000302930619;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1500-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;10;20;11.7;13.2;24.9;26.8;16.2;Cadastre;C 0.4;POLYGON Z ((355766 6689591.6 24.9, 355779.1 6689597.5 24.9, 355779.8 6689595.9 24.9, 355787.2 6689597.7 24.9, 355787.1 6689598.7 24.9, 355789.6 6689599.3 24.9, 355787.8 6689605.7 24.9, 355793.6 6689607.4 24.9, 355798.8 6689592.7 24.9, 355792.5 6689590.7 24.9, 355792.5 6689590.9 24.9, 355791.8 6689593.1 24.9, 355791.5 6689593 24.9, 355791.2 6689593.8 24.9, 355789.4 6689593.4 24.9, 355789.3 6689593.7 24.9, 355780.5 6689591.6 24.9, 355777.5 6689590.3 24.9, 355767.9 6689586.1 24.9, 355766 6689591.6 24.9))
BATIMENT0000000302930626;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1500-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;5.9;15.2;21.2;26.7;15.9;Cadastre;C 0.1;POLYGON Z ((355746.1 6689602.1 21.2, 355748.2 6689594.1 21.2, 355743.4 6689592.9 21.2, 355741.3 6689600.9 21.2, 355746.1 6689602.1 21.2))
BATIMENT0000000302931497;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;13.3;14.4;27.7;31.2;16.1;Cadastre;A 1.0;POLYGON Z ((355801.5 6689600.3 27.7, 355809.9 6689601.7 27.7, 355808.4 6689607.8 27.7, 355799.9 6689606.5 27.7, 355798.8 6689611 27.7, 355798.7 6689610.9 27.7, 355798.6 6689611.2 27.7, 355811 6689613.2 27.7, 355810.9 6689613.6 27.7, 355812.2 6689613.9 27.7, 355813.2 6689610.2 27.7, 355816.7 6689610.8 27.7, 355816.8 6689610.5 27.7, 355819.3 6689611 27.7, 355820.1 6689607.2 27.7, 355813.6 6689606 27.7, 355813.9 6689604.3 27.7, 355814.3 6689602.7 27.7, 355813.9 6689602.7 27.7, 355814.5 6689599.1 27.7, 355815.5 6689590.6 27.7, 355812.8 6689590.1 27.7, 355812.9 6689589.9 27.7, 355808.6 6689589.3 27.7, 355809.1 6689586.4 27.7, 355805.9 6689585.7 27.7, 355801.5 6689600.3 27.7))
BATIMENT0000000302930669;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1500-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;10.7;15.2;26.0;31.7;16.2;Cadastre;C 0.5;POLYGON Z ((355795 6689610.3 26, 355793.7 6689610 26, 355786 6689608.1 26, 355785 6689613.3 26, 355776.5 6689611.1 26, 355778.9 6689604.3 26, 355775.2 6689602.9 26, 355775.5 6689601.8 26, 355773.9 6689601.1 26, 355774.3 6689599.5 26, 355765.1 6689596.4 26, 355762.5 6689606 26, 355755.4 6689603.9 26, 355755.8 6689602.3 26, 355754.1 6689601.7 26, 355752.3 6689606.5 26, 355756.4 6689607.7 26, 355756.5 6689607.2 26, 355780.1 6689615.3 26, 355792.9 6689618.6 26, 355795 6689610.3 26))
BATIMENT0000000302930680;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;15.1;15.4;30.6;32.0;16.2;Cadastre;B 0.7;POLYGON Z ((355748 6689605.6 30.6, 355744.9 6689604.7 30.6, 355739.2 6689603.3 30.6, 355736.1 6689613.8 30.6, 355737.3 6689614.4 30.6, 355740.2 6689615.2 30.6, 355744.5 6689616.7 30.6, 355744.6 6689616.6 30.6, 355748 6689605.6 30.6))
BATIMENT0000000302930670;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;20;6.0;15.8;21.9;27.0;16.2;Cadastre;B 0.6;POLYGON Z ((355750.7 6689606.2 21.9, 355750 6689609.8 21.9, 355750.3 6689609.9 21.9, 355748.6 6689615.5 21.9, 355750.1 6689616.2 21.9, 355752.2 6689619.3 21.9, 355752.5 6689619.5 21.9, 355753.7 6689615.9 21.9, 355754.9 6689612.1 21.9, 355756.4 6689607.7 21.9, 355752.3 6689606.5 21.9, 355750.7 6689606.2 21.9))
BATIMENT0000000302931494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.9;13.6;26.5;27.7;15.8;Cadastre;;POLYGON Z ((355809.2 6689618.7 26.5, 355809.7 6689618.8 26.5, 355810 6689617.3 26.5, 355808.6 6689617 26.5, 355804.8 6689616.4 26.5, 355804.2 6689621.6 26.5, 355807.5 6689621.8 26.5, 355808.3 6689618.5 26.5, 355809.2 6689618.7 26.5))
BATIMENT0000000302930586;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;14.8;13.1;27.9;31.3;13.7;Cadastre;A 1.0;POLYGON Z ((355661.1 6689571.3 27.9, 355657.2 6689564.7 27.9, 355649.8 6689567.8 27.9, 355649.6 6689567.2 27.9, 355647.1 6689568.1 27.9, 355647.2 6689568.5 27.9, 355648.8 6689571.2 27.9, 355645.3 6689573.1 27.9, 355645.1 6689572.5 27.9, 355637.7 6689575.8 27.9, 355638.6 6689578.5 27.9, 355640 6689582.3 27.9, 355635 6689581.6 27.9, 355634.7 6689583.3 27.9, 355640.7 6689584.3 27.9, 355640.2 6689582.7 27.9, 355649.3 6689581.5 27.9, 355650 6689581.2 27.9, 355649 6689578.4 27.9, 355648.6 6689576.9 27.9, 355658.6 6689572.3 27.9, 355660.4 6689571.3 27.9, 355660.7 6689571.5 27.9, 355661.1 6689571.3 27.9))
BATIMENT0000000302930592;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;20;20;16.8;13.1;29.9;33.2;13.6;Cadastre;A 1.0;POLYGON Z ((355660.7 6689571.5 29.9, 355660.4 6689571.3 29.9, 355658.6 6689572.3 29.9, 355648.6 6689576.9 29.9, 355649 6689578.4 29.9, 355651.8 6689577.3 29.9, 355652.3 6689577.9 29.9, 355654.1 6689577 29.9, 355655 6689578.7 29.9, 355662.6 6689574.9 29.9, 355660.7 6689571.5 29.9))
BATIMENT0000000302930577;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;30.0;5.0;10;20;16.7;13.1;29.8;33.0;13.8;Cadastre;A 1.0;POLYGON Z ((355599.8 6689574.9 29.8, 355599 6689580.1 29.8, 355599.3 6689580.2 29.8, 355597.3 6689593.1 29.8, 355597.6 6689593 29.8, 355599.9 6689595.8 29.8, 355599.8 6689596 29.8, 355623.7 6689596.3 29.8, 355624.2 6689589.9 29.8, 355622.8 6689589.7 29.8, 355623 6689588 29.8, 355623.1 6689585.8 29.8, 355622.8 6689585.1 29.8, 355622.4 6689584.7 29.8, 355621.7 6689584.7 29.8, 355621.2 6689585 29.8, 355620.6 6689584.9 29.8, 355620.9 6689581 29.8, 355623.9 6689581.3 29.8, 355623.8 6689581.7 29.8, 355625 6689581.8 29.8, 355625.4 6689577.6 29.8, 355625.5 6689576.4 29.8, 355616.4 6689574.9 29.8, 355614.8 6689570.7 29.8, 355612.7 6689570.3 29.8, 355612.6 6689570.7 29.8, 355600.9 6689568.9 29.8, 355600 6689575 29.8, 355599.8 6689574.9 29.8), (355609.8 6689577 29.8, 355615.1 6689577.6 29.8, 355614.1 6689587.3 29.8, 355608.8 6689586.6 29.8, 355609.8 6689577 29.8))
BATIMENT0000000302930585;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;7.0;20;20;19.7;13.1;32.8;38.6;14.0;Cadastre;A 1.0;POLYGON Z ((355650 6689581.2 32.8, 355649.3 6689581.5 32.8, 355640.2 6689582.7 32.8, 355640.7 6689584.3 32.8, 355640.1 6689587.3 32.8, 355643.1 6689588 32.8, 355645.8 6689588.5 32.8, 355644.1 6689593.3 32.8, 355644 6689596.7 32.8, 355656.8 6689596.9 32.8, 355665.4 6689579.9 32.8, 355662.6 6689574.9 32.8, 355655 6689578.7 32.8, 355650 6689581.2 32.8), (355651.6 6689585.1 32.8, 355651.8 6689587.8 32.8, 355648.3 6689588.1 32.8, 355648.1 6689585.7 32.8, 355649.1 6689585.3 32.8, 355651.6 6689585.1 32.8))
BATIMENT0000000302931161;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;00;00;10.2;11.2;21.5;28.1;12.4;Cadastre;A 1.0;POLYGON Z ((355583.7 6689596.8 21.5, 355584 6689594 21.5, 355586.8 6689594.3 21.5, 355587.7 6689590.1 21.5, 355591.7 6689587.2 21.5, 355593.4 6689576.8 21.5, 355586.6 6689575.7 21.5, 355585.3 6689582.9 21.5, 355576.9 6689581.6 21.5, 355574.8 6689595.1 21.5, 355583.7 6689596.8 21.5))
BATIMENT0000000302930579;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;13.9;13.1;27.0;31.2;14.0;Cadastre;A 1.0;POLYGON Z ((355628 6689596.4 27, 355628 6689591.2 27, 355627.5 6689590 27, 355639.5 6689592.5 27, 355639.1 6689596.6 27, 355644 6689596.7 27, 355644.1 6689593.3 27, 355645.8 6689588.5 27, 355643.1 6689588 27, 355640.1 6689587.3 27, 355640.7 6689584.3 27, 355634.7 6689583.3 27, 355635 6689581.6 27, 355635.6 6689578.3 27, 355629 6689577.8 27, 355625.4 6689577.6 27, 355625 6689581.8 27, 355624.3 6689588.1 27, 355624.2 6689589.9 27, 355623.7 6689596.3 27, 355628 6689596.4 27))
BATIMENT0000000302930590;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;13.1;27.5;29.0;13.8;Cadastre;;POLYGON Z ((355623 6689588 27.5, 355622.8 6689589.7 27.5, 355624.2 6689589.9 27.5, 355624.3 6689588.1 27.5, 355623 6689588 27.5))
BATIMENT0000000302930697;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;13;20;17.3;11.6;28.9;32.5;13.1;Cadastre;A 1.0;POLYGON Z ((355597.6 6689603.8 28.9, 355595.5 6689605.9 28.9, 355595.5 6689609.5 28.9, 355595.2 6689609.5 28.9, 355595.3 6689610 28.9, 355619.7 6689610.9 28.9, 355619.8 6689610.5 28.9, 355619.9 6689609.1 28.9, 355619.6 6689609.1 28.9, 355619.7 6689604.2 28.9, 355597.6 6689603.8 28.9))
BATIMENT0000000302930695;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;;;17.0;11.6;28.6;31.2;13.2;Cadastre;A 1.0;POLYGON Z ((355595.2 6689611.1 28.6, 355595.4 6689611 28.6, 355595.4 6689615.5 28.6, 355595.2 6689615.5 28.6, 355595.2 6689616.8 28.6, 355595.4 6689616.9 28.6, 355598.1 6689617 28.6, 355598.5 6689617.9 28.6, 355599.1 6689618.6 28.6, 355599.8 6689619.1 28.6, 355599.7 6689619.8 28.6, 355605.1 6689621.9 28.6, 355609.3 6689622.3 28.6, 355609.3 6689623.6 28.6, 355619.3 6689623.9 28.6, 355619.4 6689623.7 28.6, 355619.4 6689622 28.6, 355619.6 6689618.3 28.6, 355620.8 6689617.9 28.6, 355621.4 6689617 28.6, 355621.8 6689617.2 28.6, 355622.6 6689615.9 28.6, 355622.4 6689615.6 28.6, 355622.7 6689614 28.6, 355622.4 6689612.9 28.6, 355622.6 6689612.7 28.6, 355621.9 6689611.4 28.6, 355621.6 6689611.5 28.6, 355621 6689610.9 28.6, 355619.8 6689610.5 28.6, 355619.7 6689610.9 28.6, 355595.3 6689610 28.6, 355595.2 6689611.1 28.6))
BATIMENT0000000302930696;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.0;12.7;20.8;35.2;14.1;Cadastre;A 1.0;POLYGON Z ((355620.8 6689622 20.8, 355620.2 6689623.8 20.8, 355621.6 6689624.2 20.8, 355621.7 6689623.9 20.8, 355629.1 6689627.9 20.8, 355623.7 6689639 20.8, 355624.3 6689639.6 20.8, 355624 6689643 20.8, 355633.2 6689644.2 20.8, 355651.5 6689608.2 20.8, 355649.5 6689604.8 20.8, 355619.7 6689604.2 20.8, 355619.6 6689609.1 20.8, 355619.9 6689609.1 20.8, 355619.8 6689610.5 20.8, 355621 6689610.9 20.8, 355621.6 6689611.5 20.8, 355621.9 6689611.4 20.8, 355622.6 6689612.7 20.8, 355622.4 6689612.9 20.8, 355622.7 6689614 20.8, 355622.4 6689615.6 20.8, 355622.6 6689615.9 20.8, 355621.8 6689617.2 20.8, 355621.4 6689617 20.8, 355620.8 6689617.9 20.8, 355619.6 6689618.3 20.8, 355619.4 6689622 20.8, 355620.8 6689622 20.8))
BATIMENT0000000302930682;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;30;20;14.1;15.0;29.1;31.9;15.2;Cadastre;A 1.0;POLYGON Z ((355722.3 6689599.3 29.1, 355720.4 6689608.8 29.1, 355722.5 6689609.7 29.1, 355723.9 6689610.1 29.1, 355725.2 6689610.4 29.1, 355725.7 6689608.9 29.1, 355727.4 6689609.4 29.1, 355727 6689611 29.1, 355727.8 6689611.2 29.1, 355728.2 6689611.4 29.1, 355729.3 6689606.7 29.1, 355729.7 6689606.9 29.1, 355730 6689605.6 29.1, 355731.7 6689601.3 29.1, 355722.3 6689599.3 29.1))
BATIMENT0000000302930756;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1400-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;;;16.9;12.8;29.7;31.7;15.1;Cadastre;A 1.0;POLYGON Z ((355710.6 6689615.3 29.7, 355711.8 6689614.9 29.7, 355716.3 6689600.5 29.7, 355714.2 6689599.6 29.7, 355714.1 6689599.8 29.7, 355709.5 6689597.7 29.7, 355708.9 6689599.4 29.7, 355705.9 6689598.1 29.7, 355705.1 6689600.7 29.7, 355708.1 6689602.1 29.7, 355707.4 6689603.9 29.7, 355711.1 6689605.6 29.7, 355708.7 6689609.9 29.7, 355707.3 6689612.9 29.7, 355710.6 6689615.3 29.7))
BATIMENT0000000302930755;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;46;20;17.7;12.7;30.4;32.0;14.9;Cadastre;A 1.0;POLYGON Z ((355707.3 6689612.9 30.4, 355708.7 6689609.9 30.4, 355711.1 6689605.6 30.4, 355707.4 6689603.9 30.4, 355708.1 6689602.1 30.4, 355705.1 6689600.7 30.4, 355701.9 6689608.9 30.4, 355707.3 6689612.9 30.4))
BATIMENT0000000302930681;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;20;20;18.4;15.1;33.5;36.4;15.8;Cadastre;A 1.0;POLYGON Z ((355735.6 6689602.4 33.5, 355734.5 6689606.7 33.5, 355735.7 6689607 33.5, 355735.4 6689608.3 33.5, 355729.7 6689606.9 33.5, 355729.3 6689606.7 33.5, 355728.2 6689611.4 33.5, 355727.8 6689611.2 33.5, 355724 6689621.9 33.5, 355728.6 6689623.9 33.5, 355732.7 6689614.2 33.5, 355735.7 6689615.4 33.5, 355736.1 6689613.8 33.5, 355739.2 6689603.3 33.5, 355735.6 6689602.4 33.5))
BATIMENT0000000302930683;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;10;20;14.6;15.3;29.9;34.5;15.3;Cadastre;A 1.0;POLYGON Z ((355718.3 6689619.4 29.9, 355720.1 6689620.2 29.9, 355723.3 6689611.8 29.9, 355723.9 6689610.1 29.9, 355722.5 6689609.7 29.9, 355720.4 6689608.8 29.9, 355718.3 6689619.4 29.9))
BATIMENT0000000302930685;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;19.1;14.9;34.0;36.4;15.4;Cadastre;A 1.0;POLYGON Z ((355724 6689621.9 34, 355727.8 6689611.2 34, 355727 6689611 34, 355725.2 6689610.4 34, 355724.7 6689612.3 34, 355723.3 6689611.8 34, 355720.1 6689620.2 34, 355724 6689621.9 34))
BATIMENT0000000302931668;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;20.5;13.9;34.5;38.1;15.2;Cadastre;A 1.0;POLYGON Z ((355682.8 6689605.5 34.5, 355675.2 6689605.4 34.5, 355674.7 6689612.7 34.5, 355676.5 6689613.4 34.5, 355676.5 6689618.7 34.5, 355676.9 6689620.4 34.5, 355677.1 6689626.3 34.5, 355677.2 6689629.5 34.5, 355683.1 6689629.4 34.5, 355683.1 6689623.9 34.5, 355679 6689623.5 34.5, 355679.4 6689617.7 34.5, 355683 6689618.2 34.5, 355683.8 6689608 34.5, 355684.3 6689607.7 34.5, 355682.8 6689605.5 34.5))
BATIMENT0000000302931663;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;20.8;13.2;34.0;38.2;15.2;Cadastre;A 1.0;POLYGON Z ((355669.8 6689605.2 34, 355657.7 6689628.8 34, 355662.6 6689631.2 34, 355666.5 6689631 34, 355667.9 6689627.9 34, 355669.2 6689628 34, 355669 6689631.1 34, 355673.2 6689631.1 34, 355673 6689626.4 34, 355674.8 6689622.9 34, 355674.1 6689622.4 34, 355675 6689620.5 34, 355674.7 6689618.9 34, 355676.5 6689618.7 34, 355676.5 6689613.4 34, 355674.7 6689612.7 34, 355675.2 6689605.4 34, 355669.8 6689605.2 34))
BATIMENT0000000302931669;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;10;20;19.9;14.5;34.5;37.2;15.5;Cadastre;A 1.0;POLYGON Z ((355689.8 6689615.8 34.5, 355684.3 6689607.7 34.5, 355683.8 6689608 34.5, 355683 6689618.2 34.5, 355682.8 6689620.9 34.5, 355683.1 6689621 34.5, 355683.1 6689623.9 34.5, 355683.1 6689629.4 34.5, 355683.1 6689630.6 34.5, 355682.8 6689630.6 34.5, 355682.9 6689632 34.5, 355684.3 6689632.1 34.5, 355684.3 6689631.7 34.5, 355694 6689632.8 34.5, 355689.8 6689615.8 34.5))
BATIMENT0000000302930679;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;19.7;15.3;35.0;36.4;15.9;Cadastre;A 1.0;POLYGON Z ((355734 6689626.6 35, 355740.2 6689615.2 35, 355737.3 6689614.4 35, 355736.7 6689615.9 35, 355735.7 6689615.4 35, 355732.7 6689614.2 35, 355728.6 6689623.9 35, 355734 6689626.6 35))
BATIMENT0000000302930678;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;7.4;15.8;23.2;24.5;16.4;Cadastre;B 0.1;POLYGON Z ((355750.9 6689621.9 23.2, 355751.1 6689621.4 23.2, 355749.8 6689620.1 23.2, 355748.9 6689619 23.2, 355747.9 6689620.9 23.2, 355750.7 6689622.3 23.2, 355750.9 6689621.9 23.2))
BATIMENT0000000302930672;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;15.7;23.0;24.2;16.2;Cadastre;;POLYGON Z ((355752.2 6689619.3 23, 355752.2 6689619.6 23, 355752.8 6689621 23, 355755.8 6689623.5 23, 355758.2 6689624.1 23, 355758.8 6689623.2 23, 355759.2 6689621.6 23, 355752.5 6689619.5 23, 355752.2 6689619.3 23))
BATIMENT0000000302930677;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;14.6;17.2;31.8;;;Cadastre;A 1.0;POLYGON Z ((355748.9 6689619 31.8, 355747.9 6689618 31.8, 355744.6 6689616.6 31.8, 355744.5 6689616.7 31.8, 355740.2 6689615.2 31.8, 355734 6689626.6 31.8, 355742.8 6689631 31.8, 355747.9 6689620.9 31.8, 355748.9 6689619 31.8))
BATIMENT0000000302931493;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;12;23;13.4;13.6;27.0;31.1;16.9;Cadastre;A 1.0;POLYGON Z ((355797.1 6689623.1 27, 355803.7 6689623.9 27, 355802.6 6689636.2 27, 355807.4 6689636.2 27, 355808.4 6689627.6 27, 355810.3 6689619.9 27, 355809.1 6689619.8 27, 355809.2 6689618.7 27, 355808.3 6689618.5 27, 355807.5 6689621.8 27, 355804.2 6689621.6 27, 355804.8 6689616.4 27, 355808.6 6689617 27, 355810 6689617.3 27, 355810.9 6689613.6 27, 355811 6689613.2 27, 355798.6 6689611.2 27, 355797.1 6689623.1 27))
BATIMENT0000000302930673;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;15.7;22.2;22.7;16.2;Cadastre;;POLYGON Z ((355758.5 6689624.9 22.2, 355759.7 6689625.3 22.2, 355760.2 6689623.6 22.2, 355758.8 6689623.2 22.2, 355758.2 6689624.1 22.2, 355758.5 6689624.9 22.2))
BATIMENT0000000302931496;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.4;15.4;27.9;31.2;16.9;Cadastre;A 1.0;POLYGON Z ((355817.3 6689633 27.9, 355817.3 6689631.9 27.9, 355819.1 6689614.6 27.9, 355818 6689614.8 27.9, 355818.4 6689613.1 27.9, 355816.3 6689612.7 27.9, 355816 6689613.6 27.9, 355816.2 6689613.6 27.9, 355814.7 6689620.5 27.9, 355810.3 6689619.9 27.9, 355808.4 6689627.6 27.9, 355807.4 6689636.2 27.9, 355817.3 6689633 27.9))
BATIMENT0000000302930671;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;16.2;15.7;32.0;39.5;17.1;Cadastre;A 1.0;POLYGON Z ((355786.7 6689642.3 32, 355792.9 6689618.6 32, 355780.1 6689615.3 32, 355756.5 6689607.2 32, 355756.4 6689607.7 32, 355754.9 6689612.1 32, 355761.1 6689614 32, 355759.8 6689617.9 32, 355753.7 6689615.9 32, 355752.5 6689619.5 32, 355759.2 6689621.6 32, 355767.2 6689624.5 32, 355767.3 6689624.2 32, 355769.8 6689617.3 32, 355779.8 6689620.8 32, 355781.1 6689620.2 32, 355782.9 6689620.7 32, 355780.9 6689628.5 32, 355775.9 6689627.5 32, 355775.8 6689628.5 32, 355775.8 6689641.3 32, 355786.7 6689642.3 32))
BATIMENT0000000302930676;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;12;20;16.6;15.7;32.4;36.1;16.4;Cadastre;A 1.0;POLYGON Z ((355749.6 6689624.6 32.4, 355750.7 6689622.3 32.4, 355747.9 6689620.9 32.4, 355742.8 6689631 32.4, 355749.3 6689633.8 32.4, 355752.2 6689625.9 32.4, 355751.9 6689625.7 32.4, 355749.6 6689624.6 32.4))
BATIMENT0000000302931495;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;15.1;13.8;28.9;32.0;16.8;Cadastre;A 1.0;POLYGON Z ((355795.9 6689636.2 28.9, 355802.6 6689636.2 28.9, 355803.7 6689623.9 28.9, 355797.1 6689623.1 28.9, 355795.9 6689636.2 28.9))
BATIMENT0000000302930675;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;13;23;12.6;15.8;28.5;31.7;16.4;Cadastre;A 0.8;POLYGON Z ((355754.2 6689626.7 28.5, 355754.9 6689625.1 28.5, 355752.7 6689623.3 28.5, 355751.9 6689625.7 28.5, 355752.2 6689625.9 28.5, 355749.3 6689633.8 28.5, 355756.5 6689636.9 28.5, 355759.1 6689628.5 28.5, 355758.7 6689628.4 28.5, 355754.2 6689626.7 28.5))
BATIMENT0000000302931670;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.1;14.4;35.6;37.0;15.2;Cadastre;;POLYGON Z ((355683 6689618.2 35.6, 355679.4 6689617.7 35.6, 355679 6689623.5 35.6, 355683.1 6689623.9 35.6, 355683.1 6689621 35.6, 355682.8 6689620.9 35.6, 355683 6689618.2 35.6))
BATIMENT0000000302931665;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.6;14.6;33.2;34.7;15.2;Cadastre;;POLYGON Z ((355675.2 6689630.9 33.2, 355677.1 6689630.8 33.2, 355677.2 6689629.5 33.2, 355677.1 6689626.3 33.2, 355675 6689626.4 33.2, 355675.2 6689630.9 33.2))
BATIMENT0000000302931660;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;21.0;14.1;35.1;35.7;15.1;Cadastre;;POLYGON Z ((355667.3 6689631.1 35.1, 355669 6689631.1 35.1, 355669.2 6689628 35.1, 355667.9 6689627.9 35.1, 355666.5 6689631 35.1, 355667.3 6689631.1 35.1))
BATIMENT0000000302931667;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.2;14.8;33.0;35.7;15.2;Cadastre;;POLYGON Z ((355681.9 6689630.3 33, 355682 6689630.6 33, 355682.8 6689630.6 33, 355683.1 6689630.6 33, 355683.1 6689629.4 33, 355677.2 6689629.5 33, 355677.1 6689630.8 33, 355681.9 6689630.3 33))
BATIMENT0000000302931659;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;12;20;21.9;13.5;35.4;37.2;16.7;Cadastre;A 1.0;POLYGON Z ((355652.6 6689638.6 35.4, 355659.3 6689641.8 35.4, 355663.1 6689642.4 35.4, 355664.4 6689634.8 35.4, 355665.8 6689633.4 35.4, 355667.1 6689633.5 35.4, 355667.3 6689631.1 35.4, 355666.5 6689631 35.4, 355662.6 6689631.2 35.4, 355657.7 6689628.8 35.4, 355652.6 6689638.6 35.4))
BATIMENT0000000302931185;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;12;20;20.4;15.2;35.7;38.8;16.2;Cadastre;A 1.0;POLYGON Z ((355720.8 6689629.1 35.7, 355720.5 6689629.5 35.7, 355720.3 6689629.3 35.7, 355714.6 6689633.9 35.7, 355714.7 6689634.2 35.7, 355714.3 6689634.4 35.7, 355722.8 6689644.5 35.7, 355729.6 6689631.7 35.7, 355720.8 6689629.1 35.7))
BATIMENT0000000302931661;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;14.9;27.6;32.7;16.7;Cadastre;;POLYGON Z ((355665.8 6689633.4 27.6, 355664.4 6689634.8 27.6, 355663.1 6689642.4 27.6, 355666.3 6689642.8 27.6, 355667.1 6689633.5 27.6, 355665.8 6689633.4 27.6))
BATIMENT0000000302931664;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;13.3;14.9;28.2;36.2;16.7;Cadastre;A 1.0;POLYGON Z ((355675.2 6689630.9 28.2, 355673.2 6689631.1 28.2, 355669 6689631.1 28.2, 355667.3 6689631.1 28.2, 355667.1 6689633.5 28.2, 355666.3 6689642.8 28.2, 355675.5 6689644 28.2, 355681.1 6689644.7 28.2, 355682.5 6689645 28.2, 355682.7 6689644.8 28.2, 355685 6689645.1 28.2, 355692.8 6689646.2 28.2, 355693 6689646 28.2, 355694.5 6689634.9 28.2, 355694 6689632.8 28.2, 355684.3 6689631.7 28.2, 355684.3 6689632.1 28.2, 355684 6689635.6 28.2, 355684.7 6689636 28.2, 355684.4 6689637.4 28.2, 355681.5 6689637.2 28.2, 355682 6689630.6 28.2, 355681.9 6689630.3 28.2, 355677.1 6689630.8 28.2, 355675.2 6689630.9 28.2), (355673.5 6689635.1 28.2, 355675.8 6689635.5 28.2, 355675.7 6689637.9 28.2, 355673.4 6689637.9 28.2, 355673.5 6689635.1 28.2))
BATIMENT0000000302931186;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;21.0;15.4;36.5;38.6;16.4;Cadastre;A 1.0;POLYGON Z ((355729.9 6689653.1 36.5, 355733.5 6689653.8 36.5, 355733.9 6689651 36.5, 355737.1 6689645.6 36.5, 355738.2 6689643.9 36.5, 355741.5 6689638.6 36.5, 355741.7 6689638.6 36.5, 355742 6689638 36.5, 355729.6 6689631.7 36.5, 355722.8 6689644.5 36.5, 355729.9 6689653.1 36.5))
BATIMENT0000000302931309;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;21.4;15.3;36.7;39.4;16.3;Cadastre;A 1.0;POLYGON Z ((355706.7 6689640.8 36.7, 355701.2 6689645.3 36.7, 355699.3 6689659.6 36.7, 355704.9 6689660.3 36.7, 355715.6 6689651.5 36.7, 355706.7 6689640.8 36.7))
BATIMENT0000000302930674;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;15.0;15.9;31.0;33.5;16.9;Cadastre;A 0.7;POLYGON Z ((355759.3 6689626.5 31, 355762.6 6689627.3 31, 355762.2 6689628.7 31, 355758.9 6689627.9 31, 355758.7 6689628.4 31, 355759.1 6689628.5 31, 355756.5 6689636.9 31, 355769.1 6689640.7 31, 355775.8 6689641.3 31, 355775.8 6689628.5 31, 355774.4 6689628 31, 355774.5 6689627.1 31, 355767.3 6689624.2 31, 355767.2 6689624.5 31, 355759.2 6689621.6 31, 355758.8 6689623.2 31, 355760.2 6689623.6 31, 355759.7 6689625.3 31, 355759.3 6689626.5 31))
BATIMENT0000000302931187;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;20.9;15.8;36.7;39.5;16.6;Cadastre;A 1.0;POLYGON Z ((355742.8 6689655.5 36.7, 355745.8 6689650.5 36.7, 355745.6 6689650.3 36.7, 355744 6689649.5 36.7, 355745.5 6689646.7 36.7, 355746.3 6689647.1 36.7, 355747.6 6689644.8 36.7, 355748.9 6689641.7 36.7, 355741.7 6689638.6 36.7, 355741.5 6689638.6 36.7, 355738.2 6689643.9 36.7, 355739.6 6689644.6 36.7, 355738.6 6689646.5 36.7, 355737.1 6689645.6 36.7, 355733.9 6689651 36.7, 355733.5 6689653.8 36.7, 355742.8 6689655.5 36.7))
BATIMENT0000000302930636;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;12.0;18.0;30.0;33.2;18.1;Cadastre;C 0.8;POLYGON Z ((355813.2 6689651.9 30, 355815.8 6689648.7 30, 355819.1 6689646.9 30, 355816.1 6689638 30, 355812.1 6689639.5 30, 355800.3 6689641.6 30, 355797.3 6689657.4 30, 355812.1 6689659.5 30, 355813.2 6689651.9 30))
BATIMENT0000000302931188;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;12;20;18.5;17.2;35.7;;;Cadastre;A 1.0;POLYGON Z ((355749.1 6689656.7 35.7, 355750.1 6689650.7 35.7, 355755.3 6689644.8 35.7, 355755.4 6689644.5 35.7, 355748.9 6689641.4 35.7, 355748.9 6689641.7 35.7, 355747.6 6689644.8 35.7, 355748.5 6689645.3 35.7, 355745.6 6689650.3 35.7, 355745.8 6689650.5 35.7, 355742.8 6689655.5 35.7, 355749.1 6689656.7 35.7))
BATIMENT0000000302931189;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;00;00;18.5;17.2;35.7;39.1;17.2;Cadastre;A 1.0;POLYGON Z ((355761.6 6689659.1 35.7, 355764.3 6689647.3 35.7, 355755.3 6689644.8 35.7, 355750.1 6689650.7 35.7, 355749.1 6689656.7 35.7, 355761.6 6689659.1 35.7))
BATIMENT0000000302931190;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;00;00;18.6;17.1;35.7;38.8;17.3;Cadastre;A 1.0;POLYGON Z ((355768.4 6689660.4 35.7, 355774.3 6689656.6 35.7, 355775.3 6689650.6 35.7, 355764.3 6689647.3 35.7, 355761.6 6689659.1 35.7, 355768.4 6689660.4 35.7))
BATIMENT0000000302930635;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;14.0;17.2;31.2;34.1;18.7;Cadastre;A 1.0;POLYGON Z ((355795.6 6689672.7 31.2, 355800.9 6689673.8 31.2, 355806.7 6689674.2 31.2, 355806.8 6689672.5 31.2, 355804.1 6689672.2 31.2, 355804.3 6689671.1 31.2, 355805.6 6689671.2 31.2, 355805.9 6689671.7 31.2, 355806.6 6689671.6 31.2, 355806.4 6689670.8 31.2, 355807.6 6689670 31.2, 355807.5 6689668.3 31.2, 355806.6 6689668.5 31.2, 355805.6 6689667.6 31.2, 355805.8 6689666.9 31.2, 355810 6689667.9 31.2, 355809.6 6689670.3 31.2, 355811.3 6689670.4 31.2, 355811.8 6689667.9 31.2, 355812.7 6689659.7 31.2, 355812.1 6689659.5 31.2, 355797.3 6689657.4 31.2, 355795.6 6689672.7 31.2))
BATIMENT0000000302930637;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;18.1;26.0;32.7;18.7;Cadastre;;POLYGON Z ((355800.9 6689673.8 26, 355800.3 6689678.6 26, 355808.2 6689679.3 26, 355808.5 6689676.8 26, 355807.6 6689676.8 26, 355808.2 6689674.5 26, 355806.7 6689674.2 26, 355800.9 6689673.8 26))
BATIMENT0000000302931850;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;30.0;18.0;48.0;;;Cadastre;;POLYGON Z ((355786.4 6689681.2 48, 355786.5 6689682.4 48, 355787.6 6689682.5 48, 355787.7 6689683.1 48, 355788.6 6689683.1 48, 355789.7 6689681.5 48, 355792.9 6689681.9 48, 355791.9 6689679.7 48, 355792.2 6689677.3 48, 355789.1 6689676 48, 355787.2 6689676 48, 355786 6689676.6 48, 355785.4 6689677.3 48, 355784.5 6689680.9 48, 355786.4 6689681.2 48))
BATIMENT0000000302931849;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;30.0;18.0;48.0;;;Cadastre;;POLYGON Z ((355783.7 6689690.4 48, 355784.1 6689690 48, 355784.3 6689690.6 48, 355785.4 6689690.6 48, 355785.2 6689691.4 48, 355786.4 6689691.4 48, 355786.1 6689692.1 48, 355786.8 6689692.2 48, 355787.8 6689686.4 48, 355787.1 6689686.4 48, 355786.9 6689687 48, 355786 6689686.7 48, 355785.8 6689687.2 48, 355785 6689687 48, 355784.7 6689687.4 48, 355783.3 6689686.9 48, 355782.8 6689690 48, 355783.7 6689690.4 48))
BATIMENT0000000302930691;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.3;7.9;17.2;22.7;8.7;Cadastre;C 0.1;POLYGON Z ((355494.2 6689570.3 17.2, 355494 6689568.2 17.2, 355492.9 6689568.1 17.2, 355486 6689567.2 17.2, 355485.7 6689567.2 17.2, 355485.4 6689568.2 17.2, 355485 6689569.7 17.2, 355486.7 6689570.2 17.2, 355486.1 6689577.5 17.2, 355493.4 6689577.9 17.2, 355494.2 6689570.3 17.2))
BATIMENT0000000302930900;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.2;8.9;20.1;22.2;9.4;Cadastre;;POLYGON Z ((355517.8 6689567.7 20.1, 355517.3 6689577.5 20.1, 355520.1 6689577.8 20.1, 355520.3 6689575.9 20.1, 355519.3 6689575.8 20.1, 355519.7 6689570 20.1, 355520.7 6689570 20.1, 355520.8 6689568 20.1, 355517.8 6689567.7 20.1))
BATIMENT0000000302930897;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;9.6;13.7;15.5;10.2;Cadastre;;POLYGON Z ((355533.8 6689579.8 13.7, 355537.1 6689580 13.7, 355539.3 6689580.4 13.7, 355540 6689578.6 13.7, 355535.4 6689578.1 13.7, 355535.1 6689578.9 13.7, 355533.8 6689578.9 13.7, 355533.8 6689579.8 13.7))
BATIMENT0000000302930896;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;9.3;15.0;19.6;10.4;Cadastre;;POLYGON Z ((355541.3 6689580.8 15, 355553.2 6689585.5 15, 355554.3 6689582.3 15, 355552.4 6689581.7 15, 355554.2 6689576.2 15, 355541.1 6689573.6 15, 355541 6689574.4 15, 355541.7 6689574.5 15, 355540 6689578.6 15, 355539.3 6689580.4 15, 355541.3 6689580.8 15))
BATIMENT0000000302930690;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;13.7;8.4;22.1;24.7;9.4;Cadastre;C 0.8;POLYGON Z ((355473.4 6689574.5 22.1, 355479.2 6689574.7 22.1, 355478.1 6689587 22.1, 355475.7 6689586.7 22.1, 355475.5 6689588.9 22.1, 355477.8 6689589.1 22.1, 355477.6 6689591 22.1, 355477.6 6689591.3 22.1, 355477.9 6689591.4 22.1, 355477.8 6689592.3 22.1, 355479.1 6689592.7 22.1, 355479.1 6689593.3 22.1, 355481.7 6689594.5 22.1, 355482.6 6689594.9 22.1, 355480.5 6689597.9 22.1, 355479.2 6689600.1 22.1, 355479.2 6689600.8 22.1, 355480.9 6689601.7 22.1, 355477.7 6689608.1 22.1, 355481.8 6689610.6 22.1, 355487.4 6689598.2 22.1, 355489.7 6689591.9 22.1, 355492.8 6689582.9 22.1, 355493.4 6689577.9 22.1, 355486.1 6689577.5 22.1, 355486.7 6689570.2 22.1, 355485 6689569.7 22.1, 355476.5 6689567.5 22.1, 355473.4 6689574.5 22.1))
BATIMENT0000000302930839;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1740-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;12;20;15.1;9.1;24.2;27.4;10.7;Cadastre;A 1.0;POLYGON Z ((355507.8 6689597.9 24.2, 355513.8 6689599.3 24.2, 355513.4 6689601 24.2, 355521.9 6689603.8 24.2, 355534.9 6689606 24.2, 355535.4 6689600.4 24.2, 355536.9 6689585.7 24.2, 355510.9 6689583.3 24.2, 355510.5 6689583.2 24.2, 355510.3 6689583.9 24.2, 355507.8 6689597.9 24.2), (355518.6 6689590.1 24.2, 355519.7 6689590.1 24.2, 355519.8 6689590.3 24.2, 355519.8 6689590.5 24.2, 355519.8 6689590.7 24.2, 355519.9 6689590.9 24.2, 355520 6689591.1 24.2, 355520.2 6689591.3 24.2, 355520.3 6689591.4 24.2, 355520.5 6689591.5 24.2, 355520.8 6689591.5 24.2, 355528.2 6689592 24.2, 355528.2 6689594.6 24.2, 355529.5 6689594.7 24.2, 355529.7 6689594.9 24.2, 355529.7 6689595.1 24.2, 355529.8 6689595.3 24.2, 355529.9 6689595.5 24.2, 355530.1 6689595.7 24.2, 355530.3 6689595.8 24.2, 355530.5 6689595.9 24.2, 355530.6 6689596 24.2, 355530.9 6689596 24.2, 355531.9 6689596.1 24.2, 355531.5 6689599 24.2, 355527.5 6689598.5 24.2, 355527.3 6689599.6 24.2, 355522.5 6689599.1 24.2, 355522.6 6689599.8 24.2, 355514.8 6689597.4 24.2, 355515.8 6689592.2 24.2, 355517.9 6689591.6 24.2, 355518.6 6689590.1 24.2))
BATIMENT0000000302930838;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;10;20;14.6;9.9;24.6;27.9;10.7;Cadastre;A 1.0;POLYGON Z ((355552.4 6689592.7 24.6, 355536.9 6689585.7 24.6, 355535.4 6689600.4 24.6, 355539.5 6689600.8 24.6, 355537.5 6689606.5 24.6, 355546.9 6689608 24.6, 355552.4 6689592.7 24.6))
BATIMENT0000000302931657;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.9;10.0;21.9;24.5;11.5;Cadastre;A 1.0;POLYGON Z ((355553.8 6689602 21.9, 355558.6 6689603.7 21.9, 355557.8 6689605.9 21.9, 355553.1 6689604.1 21.9, 355549.1 6689615.4 21.9, 355551.6 6689617.3 21.9, 355564.8 6689611.1 21.9, 355568.3 6689598.9 21.9, 355556.2 6689595.5 21.9, 355553.8 6689602 21.9))
BATIMENT0000000302930837;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;10;17.2;9.7;27.0;30.6;11.0;Cadastre;A 1.0;POLYGON Z ((355526.4 6689618.6 27, 355529 6689625.2 27, 355527.7 6689626.5 27, 355528.4 6689628.3 27, 355541.9 6689621.8 27, 355546.9 6689608 27, 355537.5 6689606.5 27, 355534.9 6689606 27, 355521.9 6689603.8 27, 355518.5 6689616.9 27, 355526.4 6689618.6 27), (355530.4 6689607.9 27, 355535.1 6689608.8 27, 355533.1 6689614.1 27, 355529.3 6689613.4 27, 355530.4 6689607.9 27))
BATIMENT0000000302931050;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;13.8;11.1;25.0;28.3;12.1;Cadastre;A 1.0;POLYGON Z ((355563.7 6689633.5 25, 355575.6 6689633 25, 355581.2 6689632.6 25, 355581.2 6689632.2 25, 355579.7 6689614.5 25, 355576.6 6689612.7 25, 355558.4 6689621.2 25, 355559.2 6689633.7 25, 355563.7 6689633.5 25))
BATIMENT0000000302930870;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;10;20;19.0;7.7;26.7;29.5;9.1;Cadastre;A 1.0;POLYGON Z ((355430.6 6689624.3 26.7, 355439.1 6689624.5 26.7, 355438.7 6689616.6 26.7, 355440.5 6689616.4 26.7, 355440.6 6689611.6 26.7, 355440.6 6689609.7 26.7, 355437.7 6689609.9 26.7, 355428.4 6689610.2 26.7, 355430.6 6689624.3 26.7))
BATIMENT0000000302930871;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;01;01;15.7;7.8;23.5;28.1;9.2;Cadastre;A 1.0;POLYGON Z ((355456.9 6689619 23.5, 355460.9 6689617.6 23.5, 355465.9 6689613.2 23.5, 355470 6689616.8 23.5, 355473.6 6689612.8 23.5, 355464.8 6689605.6 23.5, 355462.8 6689608.3 23.5, 355459.2 6689612.6 23.5, 355459.8 6689614 23.5, 355455.6 6689615.6 23.5, 355449.1 6689617.2 23.5, 355448.7 6689616.9 23.5, 355440.4 6689618.3 23.5, 355440.6 6689624.2 23.5, 355440.1 6689624.6 23.5, 355440.4 6689630 23.5, 355443.6 6689629.6 23.5, 355443.4 6689624.3 23.5, 355445.9 6689623.9 23.5, 355447.5 6689629.2 23.5, 355447.7 6689629.2 23.5, 355447.7 6689629.3 23.5, 355451.2 6689628.9 23.5, 355454.1 6689637.4 23.5, 355456.2 6689644.1 23.5, 355457 6689644 23.5, 355466.9 6689640.8 23.5, 355470.3 6689639.7 23.5, 355471.2 6689636.2 23.5, 355462.8 6689638.9 23.5, 355456.9 6689619 23.5))
BATIMENT0000000302930707;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.3;6.0;14.3;17.3;8.1;Cadastre;;POLYGON Z ((355390.6 6689635.1 14.3, 355391 6689635 14.3, 355391.3 6689637.3 14.3, 355391.6 6689637.3 14.3, 355414 6689633.8 14.3, 355414.3 6689635.6 14.3, 355422.2 6689634.7 14.3, 355422.1 6689634.4 14.3, 355421.6 6689630.7 14.3, 355420 6689619.5 14.3, 355388.9 6689623.9 14.3, 355390.5 6689634.9 14.3, 355390.6 6689635.1 14.3))
BATIMENT0000000302930879;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;19.1;7.3;26.4;27.5;8.0;Cadastre;A 1.0;POLYGON Z ((355432.2 6689634.6 26.4, 355436.4 6689634.3 26.4, 355436.4 6689633 26.4, 355440.6 6689632.5 26.4, 355440.4 6689630 26.4, 355440.1 6689624.6 26.4, 355439.1 6689624.5 26.4, 355430.6 6689624.3 26.4, 355432.2 6689634.6 26.4))
BATIMENT0000000302930873;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.0;7.6;22.7;23.7;8.0;Cadastre;;POLYGON Z ((355444.3 6689632.3 22.7, 355447.5 6689632 22.7, 355448.5 6689631.8 22.7, 355447.7 6689629.3 22.7, 355447.7 6689629.2 22.7, 355447.5 6689629.2 22.7, 355443.8 6689629.6 22.7, 355444.3 6689632.3 22.7))
BATIMENT0000000302930874;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;5.0;10;20;18.6;7.5;26.1;28.4;8.1;Cadastre;A 1.0;POLYGON Z ((355435 6689652.4 26.1, 355442.1 6689652.2 26.1, 355440.6 6689647.5 26.1, 355444.8 6689647.2 26.1, 355444.8 6689645.2 26.1, 355447.2 6689644.5 26.1, 355445.9 6689639.7 26.1, 355444.3 6689640.1 26.1, 355443.5 6689635.5 26.1, 355444.4 6689635.3 26.1, 355444.4 6689633.9 26.1, 355444.3 6689632.3 26.1, 355443.8 6689629.6 26.1, 355443.6 6689629.6 26.1, 355440.4 6689630 26.1, 355440.6 6689632.5 26.1, 355436.4 6689633 26.1, 355436.4 6689634.3 26.1, 355432.2 6689634.6 26.1, 355435 6689652.4 26.1))
BATIMENT0000000302930876;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.8;7.5;26.3;29.4;7.9;Cadastre;;POLYGON Z ((355447.2 6689644.5 26.3, 355448.7 6689644 26.3, 355447.6 6689639.2 26.3, 355446.4 6689639.5 26.3, 355445.9 6689639.7 26.3, 355447.2 6689644.5 26.3))
BATIMENT0000000302930872;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;10;23;18.4;7.7;26.1;29.7;8.9;Cadastre;A 1.0;POLYGON Z ((355459 6689651.8 26.1, 355457 6689644 26.1, 355456.2 6689644.1 26.1, 355454.1 6689637.4 26.1, 355450.6 6689638.5 26.1, 355448.5 6689631.8 26.1, 355447.5 6689632 26.1, 355448.6 6689638.9 26.1, 355447.6 6689639.2 26.1, 355448.7 6689644 26.1, 355447.2 6689644.5 26.1, 355444.8 6689645.2 26.1, 355444.8 6689647.2 26.1, 355440.6 6689647.5 26.1, 355442.1 6689652.2 26.1, 355459 6689651.8 26.1))
BATIMENT0000000302930700;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;10.3;7.3;17.7;25.6;7.9;Cadastre;A 1.0;POLYGON Z ((355421.8 6689637 17.7, 355410 6689638.3 17.7, 355410.2 6689640.3 17.7, 355407.6 6689640.6 17.7, 355407.3 6689638.5 17.7, 355401.3 6689639 17.7, 355401.6 6689641.5 17.7, 355401.8 6689643.3 17.7, 355402.2 6689646.6 17.7, 355415.6 6689645.1 17.7, 355416.2 6689648.8 17.7, 355423.7 6689647.5 17.7, 355421.8 6689637 17.7))
BATIMENT0000000302930698;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;25;20;12.3;5.8;18.1;21.7;7.8;Cadastre;A 1.0;POLYGON Z ((355395.1 6689645.7 18.1, 355397.6 6689645.4 18.1, 355399.1 6689657.2 18.1, 355414.8 6689655.6 18.1, 355414.4 6689653 18.1, 355415.2 6689652.3 18.1, 355416.7 6689651.9 18.1, 355416.2 6689648.8 18.1, 355415.6 6689645.1 18.1, 355402.2 6689646.6 18.1, 355401.8 6689643.3 18.1, 355394.9 6689644.1 18.1, 355395.1 6689645.7 18.1), (355414.2 6689647.6 18.1, 355414.4 6689649.4 18.1, 355415.2 6689649.2 18.1, 355415.3 6689650 18.1, 355410.8 6689651.1 18.1, 355410.1 6689648.2 18.1, 355414.2 6689647.6 18.1))
BATIMENT0000000302930344;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;00;00;16.6;7.6;24.2;27.7;7.9;Cadastre;A 1.0;POLYGON Z ((355349.9 6689602.5 24.2, 355348.8 6689608.9 24.2, 355349 6689614.1 24.2, 355349.4 6689621.3 24.2, 355349.7 6689625 24.2, 355362.9 6689624.3 24.2, 355362.7 6689620.7 24.2, 355361.8 6689605.3 24.2, 355349.9 6689602.5 24.2))
BATIMENT0000000302930343;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;15.8;6.1;21.9;26.3;8.0;Cadastre;A 1.0;POLYGON Z ((355335.7 6689625.7 21.9, 355348.7 6689625 21.9, 355349.7 6689625 21.9, 355349.4 6689621.3 21.9, 355349 6689614.1 21.9, 355337 6689613 21.9, 355335.7 6689625.7 21.9))
BATIMENT0000000302930705;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;16.9;6.0;22.9;28.4;8.0;Cadastre;A 1.0;POLYGON Z ((355369.7 6689610.6 22.9, 355371.7 6689637.4 22.9, 355373.9 6689637.2 22.9, 355379.6 6689636.6 22.9, 355383.2 6689636.3 22.9, 355382.7 6689628.9 22.9, 355383.7 6689628.9 22.9, 355383.5 6689626.4 22.9, 355383.1 6689626.4 22.9, 355383 6689625.8 22.9, 355384 6689625.6 22.9, 355383.9 6689624.4 22.9, 355382.5 6689624.4 22.9, 355381.3 6689609.5 22.9, 355380.7 6689609.6 22.9, 355372.3 6689610.3 22.9, 355369.7 6689610.6 22.9))
BATIMENT0000000302930347;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;12.7;6.0;18.7;22.2;7.9;Cadastre;A 1.0;POLYGON Z ((355349.7 6689644.2 18.7, 355351.2 6689644.1 18.7, 355364.1 6689643.2 18.7, 355362.9 6689624.3 18.7, 355349.7 6689625 18.7, 355348.7 6689625 18.7, 355349.7 6689644.2 18.7), (355352 6689635.8 18.7, 355352.3 6689640.9 18.7, 355351.2 6689641 18.7, 355350.9 6689635.9 18.7, 355352 6689635.8 18.7))
BATIMENT0000000302930346;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;12.6;7.1;19.7;26.5;8.0;Cadastre;A 1.0;POLYGON Z ((355333.8 6689645.3 19.7, 355349.7 6689644.2 19.7, 355348.7 6689625 19.7, 355335.7 6689625.7 19.7, 355333.8 6689645.3 19.7))
BATIMENT0000000302930699;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;7.4;10.5;11.1;7.9;Cadastre;;POLYGON Z ((355395.3 6689639.7 10.5, 355395.4 6689641.4 10.5, 355394.7 6689642.5 10.5, 355401.6 6689641.5 10.5, 355401.3 6689639 10.5, 355395.3 6689639.7 10.5))
BATIMENT0000000302930704;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.0;6.2;12.2;16.0;8.1;Cadastre;;POLYGON Z ((355380.3 6689648.8 12.2, 355384.1 6689648.6 12.2, 355387.4 6689648 12.2, 355387.1 6689640.9 12.2, 355389.7 6689640.5 12.2, 355391.6 6689640.2 12.2, 355391.9 6689640.1 12.2, 355391.6 6689637.3 12.2, 355391.3 6689637.3 12.2, 355391 6689635 12.2, 355390.6 6689635.1 12.2, 355390.2 6689635.1 12.2, 355387.1 6689635.6 12.2, 355387.2 6689635.9 12.2, 355383.2 6689636.3 12.2, 355379.6 6689636.6 12.2, 355380.3 6689648.8 12.2))
BATIMENT0000000302930702;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;4.2;7.5;11.7;21.9;7.9;Cadastre;A 1.0;POLYGON Z ((355399.1 6689657.2 11.7, 355397.6 6689645.4 11.7, 355395.1 6689645.7 11.7, 355394.9 6689644.1 11.7, 355394.7 6689642.5 11.7, 355395.4 6689641.4 11.7, 355395.3 6689639.7 11.7, 355391.9 6689640.1 11.7, 355391.6 6689640.2 11.7, 355392 6689643.7 11.7, 355390.3 6689643.9 11.7, 355389.7 6689640.5 11.7, 355387.1 6689640.9 11.7, 355387.4 6689648 11.7, 355388.5 6689658.4 11.7, 355399.1 6689657.2 11.7))
BATIMENT0000000302930348;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;12;20;15.5;6.0;21.5;25.3;7.9;Cadastre;A 1.0;POLYGON Z ((355365.4 6689661.9 21.5, 355364.1 6689643.2 21.5, 355351.2 6689644.1 21.5, 355351.3 6689645.5 21.5, 355349.1 6689645.6 21.5, 355349.4 6689649.4 21.5, 355355.7 6689648.9 21.5, 355355.9 6689651.3 21.5, 355349.5 6689651.9 21.5, 355350.2 6689661.7 21.5, 355353.7 6689661.2 21.5, 355354 6689663.2 21.5, 355365.4 6689661.9 21.5))
BATIMENT0000000302930703;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;7.0;20;20;13.3;5.9;19.2;22.0;7.9;Cadastre;A 1.0;POLYGON Z ((355374.7 6689649.1 19.2, 355372.6 6689649.2 19.2, 355373 6689660 19.2, 355388.5 6689658.4 19.2, 355387.4 6689648 19.2, 355384.1 6689648.6 19.2, 355380.3 6689648.8 19.2, 355374.7 6689649.1 19.2))
BATIMENT0000000302930349;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;12;20;15.3;6.0;21.3;24.7;7.5;Cadastre;A 1.0;POLYGON Z ((355332.1 6689661.7 21.3, 355335.9 6689665.3 21.3, 355354 6689663.2 21.3, 355353.7 6689661.2 21.3, 355350.2 6689661.7 21.3, 355349.5 6689651.9 21.3, 355349.4 6689649.4 21.3, 355349.1 6689645.6 21.3, 355351.3 6689645.5 21.3, 355351.2 6689644.1 21.3, 355349.7 6689644.2 21.3, 355333.8 6689645.3 21.3, 355332.1 6689661.7 21.3))
BATIMENT0000000302931595;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;;;19.5;7.2;26.7;28.5;7.6;Cadastre;A 1.0;POLYGON Z ((355373.9 6689670 26.7, 355374.4 6689677.7 26.7, 355393.9 6689675.9 26.7, 355395.2 6689667.6 26.7, 355373.9 6689670 26.7))
BATIMENT0000000302931567;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;14.2;7.0;21.2;22.9;7.6;Cadastre;A 1.0;POLYGON Z ((355366 6689670.7 21.2, 355348.8 6689672.6 21.2, 355349.9 6689681.2 21.2, 355358 6689680.7 21.2, 355366.7 6689680.1 21.2, 355366 6689670.7 21.2))
BATIMENT0000000302931568;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;17.1;5.1;22.2;25.9;7.3;Cadastre;A 1.0;POLYGON Z ((355334.2 6689674.3 22.2, 355330.7 6689678 22.2, 355330.3 6689682.4 22.2, 355349.9 6689681.2 22.2, 355348.8 6689672.6 22.2, 355334.2 6689674.3 22.2))
BATIMENT0000000302931594;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;25;20;15.1;5.1;20.2;26.7;7.6;Cadastre;A 1.0;POLYGON Z ((355375 6689686.5 20.2, 355387.1 6689684.6 20.2, 355386.7 6689680 20.2, 355389.3 6689679.8 20.2, 355394.4 6689679.3 20.2, 355393.9 6689675.9 20.2, 355374.4 6689677.7 20.2, 355375 6689686.5 20.2))
BATIMENT0000000302931597;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;12.8;5.0;17.8;22.2;7.3;Cadastre;A 1.0;POLYGON Z ((355375.7 6689696.6 17.8, 355385.4 6689694.7 17.8, 355385.4 6689694.4 17.8, 355393.1 6689693 17.8, 355393 6689683.8 17.8, 355394.9 6689683.5 17.8, 355394.4 6689679.3 17.8, 355389.3 6689679.8 17.8, 355389.5 6689683 17.8, 355389 6689683.1 17.8, 355389 6689684.3 17.8, 355387.1 6689684.6 17.8, 355375 6689686.5 17.8, 355375.7 6689696.6 17.8))
BATIMENT0000000302931570;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;;;9.4;5.1;14.5;17.7;7.3;Cadastre;A 1.0;POLYGON Z ((355366.6 6689698.2 14.5, 355367.9 6689696.7 14.5, 355366.7 6689680.1 14.5, 355358 6689680.7 14.5, 355359.8 6689699.6 14.5, 355366.6 6689698.2 14.5))
BATIMENT0000000302931569;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;27.0;5.0;14;23;19.1;5.1;24.2;28.9;7.2;Cadastre;A 1.0;POLYGON Z ((355328.2 6689704.5 24.2, 355329.4 6689705.7 24.2, 355359.8 6689699.6 24.2, 355358 6689680.7 24.2, 355349.9 6689681.2 24.2, 355330.3 6689682.4 24.2, 355328.2 6689704.5 24.2))
BATIMENT0000000302931325;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;20;20;10.9;5.0;15.9;18.8;7.1;Cadastre;A 1.0;POLYGON Z ((355369 6689710.9 15.9, 355368.7 6689706.3 15.9, 355367.7 6689705.7 15.9, 355360.5 6689707.2 15.9, 355360.5 6689707.4 15.9, 355356.3 6689708.3 15.9, 355357.8 6689713.5 15.9, 355368.9 6689711 15.9, 355369 6689710.9 15.9))
BATIMENT0000000302931184;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.9;6.8;19.7;25.2;7.1;Cadastre;;POLYGON Z ((355387.5 6689722.2 19.7, 355388.7 6689721.9 19.7, 355388.5 6689720.2 19.7, 355391.6 6689719.6 19.7, 355389.7 6689701.8 19.7, 355385.4 6689702.6 19.7, 355387.5 6689722.2 19.7))
BATIMENT0000000302930701;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1790-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;14.9;7.3;22.2;25.2;7.6;Cadastre;A 1.0;POLYGON Z ((355424.2 6689654.5 22.2, 355425 6689653.6 22.2, 355423.7 6689647.5 22.2, 355416.2 6689648.8 22.2, 355416.7 6689651.9 22.2, 355415.2 6689652.3 22.2, 355414.4 6689653 22.2, 355414.8 6689655.6 22.2, 355424.2 6689654.5 22.2))
BATIMENT0000000302931596;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;18.7;5.1;23.8;28.4;7.6;Cadastre;A 1.0;POLYGON Z ((355393.9 6689675.9 23.8, 355394.4 6689679.3 23.8, 355394.9 6689683.5 23.8, 355413.3 6689680.9 23.8, 355429.1 6689678.6 23.8, 355427.1 6689665.3 23.8, 355425.7 6689664.4 23.8, 355425.5 6689664.3 23.8, 355395.2 6689667.6 23.8, 355393.9 6689675.9 23.8), (355408.2 6689677.8 23.8, 355408.4 6689679.1 23.8, 355404.7 6689679.7 23.8, 355404.5 6689678.3 23.8, 355407.9 6689677.9 23.8, 355408.2 6689677.8 23.8))
BATIMENT0000000302931598;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;16.4;5.0;21.4;26.0;7.3;Cadastre;A 1.0;POLYGON Z ((355428.1 6689686.3 21.4, 355429.9 6689683.7 21.4, 355429.1 6689678.6 21.4, 355413.3 6689680.9 21.4, 355414.7 6689688.9 21.4, 355428.1 6689686.3 21.4))
BATIMENT0000000302931599;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;00;00;16.8;5.0;21.8;24.4;7.3;Cadastre;A 1.0;POLYGON Z ((355414.7 6689688.9 21.8, 355413.3 6689680.9 21.8, 355394.9 6689683.5 21.8, 355393 6689683.8 21.8, 355393.1 6689693 21.8, 355414.7 6689688.9 21.8))
BATIMENT0000000302931571;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;7.3;;;;Cadastre;;POLYGON Z ((355443.8 6689703 -1000, 355445.3 6689706.7 -1000, 355448.4 6689705.3 -1000, 355447.1 6689701.8 -1000, 355443.8 6689703 -1000))
BATIMENT0000000302931178;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;20;20;12.5;6.7;19.3;25.3;7.7;Cadastre;A 1.0;POLYGON Z ((355404.3 6689707.5 19.3, 355406.4 6689707.1 19.3, 355406.7 6689708.8 19.3, 355415.4 6689706.6 19.3, 355414.5 6689702.5 19.3, 355416.7 6689702.1 19.3, 355419.8 6689710.8 19.3, 355418.4 6689711.5 19.3, 355418.1 6689710.4 19.3, 355417 6689710.7 19.3, 355416.2 6689708.6 19.3, 355406.9 6689711.1 19.3, 355407.6 6689714.1 19.3, 355406.7 6689714.4 19.3, 355409.3 6689723.9 19.3, 355423.4 6689720.3 19.3, 355428.3 6689733.4 19.3, 355434.5 6689731.2 19.3, 355435.3 6689734.2 19.3, 355411 6689741.3 19.3, 355409.6 6689741.7 19.3, 355411.8 6689748.8 19.3, 355431.6 6689743.2 19.3, 355432.6 6689745.9 19.3, 355448 6689741.1 19.3, 355433 6689703 19.3, 355431.8 6689695.7 19.3, 355429.8 6689693.8 19.3, 355402.6 6689699.2 19.3, 355404.3 6689707.5 19.3), (355432.1 6689721.1 19.3, 355429.6 6689722.1 19.3, 355428.5 6689719.2 19.3, 355431 6689718.2 19.3, 355432.1 6689721.1 19.3), (355428 6689709.5 19.3, 355426.4 6689709.9 19.3, 355425 6689706.2 19.3, 355426.5 6689705.7 19.3, 355428 6689709.5 19.3))
BATIMENT0000000302931177;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;7.0;10.3;16.7;7.5;Cadastre;;POLYGON Z ((355397.5 6689753.3 10.3, 355395.2 6689753.6 10.3, 355398.2 6689759.8 10.3, 355410.2 6689756.2 10.3, 355413.5 6689755.1 10.3, 355411.5 6689749.4 10.3, 355397.5 6689753.3 10.3))
BATIMENT0000000302931181;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;20;20;9.8;7.3;17.2;25.2;8.3;Cadastre;A 1.0;POLYGON Z ((355442.9 6689762.5 17.2, 355443 6689762.7 17.2, 355449.5 6689760.8 17.2, 355449.6 6689761 17.2, 355453.4 6689759.7 17.2, 355453.4 6689759.6 17.2, 355454.2 6689758.1 17.2, 355454.5 6689758 17.2, 355453.2 6689754.3 17.2, 355453.1 6689754.3 17.2, 355448 6689741.1 17.2, 355432.6 6689745.9 17.2, 355433.5 6689748.2 17.2, 355430.5 6689749.2 17.2, 355429.7 6689746.8 17.2, 355414.8 6689751.2 17.2, 355415.8 6689754.3 17.2, 355417.7 6689760 17.2, 355416.5 6689760.3 17.2, 355417.1 6689761.8 17.2, 355414.1 6689762.7 17.2, 355410.4 6689763.8 17.2, 355412.6 6689771.6 17.2, 355442.9 6689762.5 17.2))
BATIMENT0000000302931183;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;7.1;13.5;17.3;7.5;Cadastre;;POLYGON Z ((355417.7 6689760 13.5, 355415.8 6689754.3 13.5, 355413.5 6689755.1 13.5, 355410.2 6689756.2 13.5, 355411.9 6689761.6 13.5, 355413.5 6689761.1 13.5, 355413.7 6689761.3 13.5, 355416.5 6689760.3 13.5, 355417.7 6689760 13.5))
BATIMENT0000000302930356;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.1;8.1;24.2;28.4;11.3;Cadastre;C 0.1;POLYGON Z ((355483.4 6689758.1 24.2, 355466.1 6689758.5 24.2, 355465.7 6689759.2 24.2, 355471.5 6689774.2 24.2, 355472.5 6689775 24.2, 355483.7 6689776.3 24.2, 355483.6 6689773.4 24.2, 355483.4 6689758.1 24.2))
BATIMENT0000000302931054;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;12.5;10.8;23.3;26.5;11.7;Cadastre;A 1.0;POLYGON Z ((355553.7 6689635.4 23.3, 355553.8 6689635.3 23.3, 355553.6 6689635.2 23.3, 355552.2 6689639.6 23.3, 355552 6689639.6 23.3, 355551.9 6689639.6 23.3, 355551.7 6689639.6 23.3, 355551.6 6689639.6 23.3, 355551.5 6689639.7 23.3, 355551.4 6689639.7 23.3, 355551.3 6689639.8 23.3, 355551 6689639.9 23.3, 355551 6689640 23.3, 355550.8 6689640.2 23.3, 355550.6 6689640.4 23.3, 355549.1 6689640 23.3, 355545.4 6689645.2 23.3, 355546.9 6689645.5 23.3, 355546.6 6689647.5 23.3, 355556.9 6689648.7 23.3, 355559.9 6689638.5 23.3, 355559.4 6689638.2 23.3, 355553.7 6689635.4 23.3))
BATIMENT0000000302931053;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;20;20;18.4;11.0;29.4;31.7;11.8;Cadastre;A 1.0;POLYGON Z ((355544 6689647.1 29.4, 355539.3 6689653.7 29.4, 355561.7 6689656.5 29.4, 355568.8 6689645 29.4, 355564.4 6689641.9 29.4, 355560.5 6689649.1 29.4, 355556.9 6689648.7 29.4, 355546.6 6689647.5 29.4, 355544 6689647.1 29.4))
BATIMENT0000000302931194;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;12;12;15.4;11.5;26.9;29.7;11.8;Cadastre;A 1.0;POLYGON Z ((355560.4 6689681.4 26.9, 355559 6689684.4 26.9, 355561.2 6689685.4 26.9, 355559.8 6689688.2 26.9, 355557.7 6689687.2 26.9, 355553.2 6689694.6 26.9, 355562.4 6689700.7 26.9, 355562.7 6689700.9 26.9, 355565.3 6689694.5 26.9, 355560.7 6689692.1 26.9, 355564.8 6689683.1 26.9, 355560.4 6689681.4 26.9))
BATIMENT0000000302931572;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.9;8.3;22.2;27.1;12.1;Cadastre;C 0.4;POLYGON Z ((355482.6 6689662.9 22.2, 355478.2 6689691.4 22.2, 355475.8 6689691.4 22.2, 355475.6 6689694.4 22.2, 355460.2 6689694.7 22.2, 355460 6689691.6 22.2, 355457.7 6689691.6 22.2, 355454.4 6689663.6 22.2, 355454.4 6689663.5 22.2, 355444.1 6689663.6 22.2, 355444.1 6689663.9 22.2, 355448.1 6689698.9 22.2, 355451 6689706.3 22.2, 355514.6 6689705.6 22.2, 355514.6 6689710.7 22.2, 355514.5 6689710.9 22.2, 355514.3 6689711 22.2, 355514 6689711.1 22.2, 355513.7 6689711.4 22.2, 355513.5 6689711.6 22.2, 355513.3 6689711.9 22.2, 355513.2 6689712.1 22.2, 355513 6689712.4 22.2, 355513 6689712.6 22.2, 355512.9 6689712.8 22.2, 355512.9 6689713 22.2, 355512.8 6689713.4 22.2, 355512.8 6689713.6 22.2, 355512.8 6689713.8 22.2, 355512.9 6689714.2 22.2, 355512.9 6689714.4 22.2, 355513 6689714.8 22.2, 355513.1 6689715 22.2, 355513.2 6689715.2 22.2, 355513.5 6689715.5 22.2, 355513.7 6689715.8 22.2, 355514 6689716 22.2, 355513.5 6689718.4 22.2, 355512.5 6689718.3 22.2, 355510.8 6689727 22.2, 355541.1 6689734.5 22.2, 355543 6689731.4 22.2, 355546.5 6689724 22.2, 355547 6689724.2 22.2, 355547.4 6689723.4 22.2, 355524 6689710.3 22.2, 355523.5 6689711.1 22.2, 355520.8 6689709.5 22.2, 355522 6689707.6 22.2, 355519.8 6689706.1 22.2, 355521.6 6689702.4 22.2, 355530 6689708.2 22.2, 355539.2 6689694.3 22.2, 355539.7 6689693.5 22.2, 355531.1 6689687.5 22.2, 355530.5 6689688.5 22.2, 355493.2 6689663.1 22.2, 355493.2 6689662.5 22.2, 355482.6 6689662.8 22.2, 355482.6 6689662.9 22.2), (355495.7 6689672.9 22.2, 355517.1 6689687.4 22.2, 355512.6 6689694 22.2, 355488.3 6689694.3 22.2, 355491.7 6689672.9 22.2, 355495.7 6689672.9 22.2))
BATIMENT0000000302931193;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;15.1;11.5;26.6;30.5;12.1;Cadastre;A 1.0;POLYGON Z ((355562.1 6689701.6 26.6, 355569.6 6689704.5 26.6, 355571.2 6689696.6 26.6, 355565.3 6689694.5 26.6, 355562.7 6689700.9 26.6, 355562.4 6689700.7 26.6, 355562.1 6689701.6 26.6))
BATIMENT0000000302930358;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2022-07-28 16:46:59;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.9;9.4;24.4;30.5;14.0;Cadastre;C 0.2;POLYGON Z ((355567.2 6689713.5 24.4, 355565.6 6689717.1 24.4, 355568.7 6689718.4 24.4, 355564.1 6689728.7 24.4, 355573 6689732.5 24.4, 355570.4 6689736.4 24.4, 355569.3 6689736.2 24.4, 355568.8 6689737.9 24.4, 355564 6689736.8 24.4, 355562.4 6689742.6 24.4, 355556.6 6689741.3 24.4, 355554.5 6689749.3 24.4, 355567.5 6689752.8 24.4, 355558.6 6689769.9 24.4, 355531.3 6689766.4 24.4, 355531.2 6689766.2 24.4, 355528.8 6689765.9 24.4, 355529.1 6689763.4 24.4, 355524.9 6689763.3 24.4, 355520.7 6689763 24.4, 355516.5 6689762.4 24.4, 355512.4 6689761.7 24.4, 355508.3 6689760.7 24.4, 355508 6689763.2 24.4, 355505.6 6689762.9 24.4, 355505.4 6689763.2 24.4, 355487.4 6689760.8 24.4, 355485.8 6689773.6 24.4, 355509.6 6689776.5 24.4, 355509.5 6689776.9 24.4, 355513.8 6689777.4 24.4, 355513.9 6689777.2 24.4, 355520.3 6689777.9 24.4, 355520.3 6689778.3 24.4, 355524.4 6689778.9 24.4, 355524.5 6689778.5 24.4, 355558.9 6689782.8 24.4, 355558.9 6689783.2 24.4, 355559.2 6689783.3 24.4, 355562.5 6689783.6 24.4, 355582.3 6689744.3 24.4, 355581 6689743 24.4, 355573.2 6689740.4 24.4, 355574.1 6689737.4 24.4, 355577.2 6689733.3 24.4, 355579.1 6689734 24.4, 355582.6 6689737.6 24.4, 355588.5 6689732.3 24.4, 355591.6 6689729.5 24.4, 355586.7 6689722.3 24.4, 355582.4 6689718.9 24.4, 355577 6689715.9 24.4, 355568.2 6689711.6 24.4, 355567.2 6689713.5 24.4))
BATIMENT0000000302930357;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;8.3;23.7;23.9;8.7;Cadastre;;POLYGON Z ((355485 6689776.5 23.7, 355485.4 6689773.5 23.7, 355483.6 6689773.4 23.7, 355483.7 6689776.3 23.7, 355485 6689776.5 23.7))
BATIMENT0000000302931123;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;00;00;18.3;7.6;26.0;28.2;9.3;Cadastre;A 1.0;POLYGON Z ((355488.7 6689785.2 26, 355487.7 6689791 26, 355488 6689791.6 26, 355491.4 6689792.5 26, 355489.5 6689796.2 26, 355484 6689792.7 26, 355480.9 6689790.7 26, 355479 6689796.9 26, 355478.2 6689799.7 26, 355479.6 6689800.9 26, 355486.8 6689807.6 26, 355489.9 6689805 26, 355492.1 6689802.5 26, 355494 6689799.9 26, 355495 6689798.1 26, 355499.7 6689786.6 26, 355488.7 6689785.2 26))
BATIMENT0000000302931128;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;8.2;21.8;23.8;9.7;Cadastre;;POLYGON Z ((355502.8 6689800.8 21.8, 355504.2 6689797.1 21.8, 355504.4 6689797.4 21.8, 355508.3 6689787.6 21.8, 355499.7 6689786.6 21.8, 355495 6689798.1 21.8, 355494 6689799.9 21.8, 355492.1 6689802.5 21.8, 355495.7 6689806.3 21.8, 355498.1 6689809 21.8, 355500.4 6689807.1 21.8, 355502.8 6689800.8 21.8))
BATIMENT0000000302931127;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.8;8.1;19.0;23.0;9.7;Cadastre;;POLYGON Z ((355502.7 6689808 19, 355504.9 6689809.1 19, 355507.6 6689802.8 19, 355502.8 6689800.8 19, 355500.4 6689807.1 19, 355502.7 6689808 19))
BATIMENT0000000302931180;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;41.0;5.0;90;20;18.3;6.7;25.1;26.3;7.1;Cadastre;A 1.0;POLYGON Z ((355389.7 6689701.8 25.1, 355391.6 6689719.6 25.1, 355392.2 6689725 25.1, 355392.5 6689728 25.1, 355406.2 6689724.9 25.1, 355403.8 6689713.2 25.1, 355405.3 6689713 25.1, 355404.3 6689707.5 25.1, 355402.6 6689699.2 25.1, 355389.7 6689701.8 25.1))
BATIMENT0000000302931323;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;00;00;12.9;6.2;19.2;22.2;6.7;Cadastre;A 1.0;POLYGON Z ((355345.5 6689710.6 19.2, 355348.4 6689724.9 19.2, 355354.5 6689723.6 19.2, 355353.8 6689721 19.2, 355353.8 6689720.8 19.2, 355351.3 6689721.3 19.2, 355350.9 6689719.6 19.2, 355353.4 6689719.1 19.2, 355356 6689718.5 19.2, 355358.2 6689718.3 19.2, 355357.8 6689713.5 19.2, 355356.3 6689708.3 19.2, 355345.5 6689710.6 19.2))
BATIMENT0000000302931320;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;00;00;11.4;5.0;16.4;19.2;7.2;Cadastre;A 1.0;POLYGON Z ((355368.9 6689711 16.4, 355357.8 6689713.5 16.4, 355358.2 6689718.3 16.4, 355360.2 6689718.1 16.4, 355360.5 6689720.2 16.4, 355358.4 6689720.5 16.4, 355358.6 6689722.7 16.4, 355369.6 6689720.4 16.4, 355368.9 6689711 16.4))
BATIMENT0000000302931179;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;;;11.2;6.8;18.1;20.7;7.3;Cadastre;C 0.6;POLYGON Z ((355376.5 6689704.4 18.1, 355379.2 6689731.6 18.1, 355392.6 6689728.7 18.1, 355392.5 6689728 18.1, 355392.2 6689725 18.1, 355391.6 6689719.6 18.1, 355388.5 6689720.2 18.1, 355388.7 6689721.9 18.1, 355387.5 6689722.2 18.1, 355385.4 6689702.6 18.1, 355376.5 6689704.4 18.1))
BATIMENT0000000302931328;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;12.5;5.2;17.7;20.7;6.6;Cadastre;A 1.0;POLYGON Z ((355336.3 6689712.5 17.7, 355339.1 6689726.8 17.7, 355346.9 6689725.2 17.7, 355348.4 6689724.9 17.7, 355345.5 6689710.6 17.7, 355336.3 6689712.5 17.7))
BATIMENT0000000302931327;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;;;11.6;5.3;16.9;21.2;6.6;Cadastre;A 1.0;POLYGON Z ((355336.2 6689712.4 16.9, 355328.5 6689714 16.9, 355331.4 6689728.5 16.9, 355339.1 6689726.8 16.9, 355336.3 6689712.5 16.9, 355336.2 6689712.4 16.9))
BATIMENT0000000302931319;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;6.4;13.7;17.5;6.8;Cadastre;;POLYGON Z ((355354.5 6689723.6 13.7, 355358.3 6689722.8 13.7, 355358.6 6689722.7 13.7, 355358.4 6689720.5 13.7, 355358.4 6689720.1 13.7, 355353.8 6689721 13.7, 355354.5 6689723.6 13.7))
BATIMENT0000000302931318;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;30;90;11.3;5.0;16.3;20.1;7.2;Cadastre;A 1.0;POLYGON Z ((355358.6 6689722.7 16.3, 355358.3 6689722.8 16.3, 355359 6689733.6 16.3, 355359.5 6689739.3 16.3, 355356.5 6689739.7 16.3, 355356.6 6689741.3 16.3, 355347.8 6689743.3 16.3, 355346.6 6689743.6 16.3, 355348.4 6689749.6 16.3, 355371.4 6689744.2 16.3, 355369.6 6689720.4 16.3, 355358.6 6689722.7 16.3))
BATIMENT0000000302931322;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;18.5;5.0;23.5;27.4;6.6;Cadastre;A 1.0;POLYGON Z ((355335.8 6689745.1 23.5, 355338.2 6689752 23.5, 355348.4 6689749.6 23.5, 355346.6 6689743.6 23.5, 355347.8 6689743.3 23.5, 355347 6689739.5 23.5, 355346.8 6689739.6 23.5, 355344.7 6689729.9 23.5, 355347.9 6689729.1 23.5, 355346.9 6689725.2 23.5, 355339.1 6689726.8 23.5, 355331.4 6689728.5 23.5, 355335.8 6689745.1 23.5))
BATIMENT0000000302931175;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;8.9;6.8;15.7;22.0;7.4;Cadastre;A 0.5;POLYGON Z ((355393 6689732.1 15.7, 355379.4 6689735 15.7, 355381.4 6689755 15.7, 355382.4 6689755 15.7, 355394.2 6689753.8 15.7, 355393.4 6689748.4 15.7, 355385.9 6689749.2 15.7, 355385.2 6689741.3 15.7, 355394.6 6689740.5 15.7, 355394.7 6689741.4 15.7, 355395.3 6689743.9 15.7, 355395.6 6689745.7 15.7, 355395.3 6689745.8 15.7, 355396.9 6689752.6 15.7, 355397.5 6689753.3 15.7, 355411.5 6689749.4 15.7, 355412 6689749.2 15.7, 355411.8 6689748.8 15.7, 355409.6 6689741.7 15.7, 355411 6689741.3 15.7, 355409 6689729.2 15.7, 355407.8 6689729 15.7, 355407.1 6689729.1 15.7, 355406.2 6689724.9 15.7, 355392.5 6689728 15.7, 355392.6 6689728.7 15.7, 355393 6689732.1 15.7))
BATIMENT0000000302931174;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.0;5.0;18.0;19.2;7.1;Cadastre;;POLYGON Z ((355393.9 6689744.2 18, 355395.3 6689743.9 18, 355394.7 6689741.4 18, 355393.3 6689741.7 18, 355393.9 6689744.2 18))
BATIMENT0000000302931321;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;7.0;;;9.2;6.1;15.4;30.9;7.3;Cadastre;A 1.0;POLYGON Z ((355340.1 6689757.2 15.4, 355342.5 6689762.8 15.4, 355355.5 6689759.5 15.4, 355357.8 6689758.9 15.4, 355359.7 6689758.4 15.4, 355372.2 6689755.2 15.4, 355371.4 6689744.2 15.4, 355348.4 6689749.6 15.4, 355338.2 6689752 15.4, 355340.1 6689757.2 15.4))
BATIMENT0000000302931324;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;12.7;6.4;19.2;23.7;7.1;Cadastre;A 1.0;POLYGON Z ((355372.2 6689755.2 19.2, 355359.7 6689758.4 19.2, 355360.7 6689762.1 19.2, 355361 6689763.7 19.2, 355361.3 6689764.6 19.2, 355362.1 6689768.1 19.2, 355364.1 6689767.6 19.2, 355373 6689765.4 19.2, 355372.2 6689755.2 19.2))
BATIMENT0000000302931326;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;20.5;5.0;25.5;28.7;6.6;Cadastre;A 1.0;POLYGON Z ((355344.8 6689767.3 25.5, 355347.5 6689771.9 25.5, 355358 6689769.2 25.5, 355357.6 6689767.8 25.5, 355356.2 6689762.3 25.5, 355355.5 6689759.5 25.5, 355342.5 6689762.8 25.5, 355344.8 6689767.3 25.5))
BATIMENT0000000302931176;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;18.5;5.0;23.5;26.9;7.4;Cadastre;C 0.2;POLYGON Z ((355383.9 6689775.3 23.5, 355389 6689778.7 23.5, 355396.9 6689776.3 23.5, 355394 6689766.8 23.5, 355400.9 6689764.8 23.5, 355398.2 6689759.8 23.5, 355395.2 6689753.6 23.5, 355394.2 6689753.8 23.5, 355382.4 6689755 23.5, 355383.9 6689775.3 23.5))
BATIMENT0000000302931329;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;6.4;20.2;21.5;6.6;Cadastre;;POLYGON Z ((355361.3 6689764.6 20.2, 355359.4 6689765 20.2, 355359.9 6689767.2 20.2, 355360.3 6689768.6 20.2, 355361.5 6689768.3 20.2, 355362.1 6689768.1 20.2, 355361.3 6689764.6 20.2))
BATIMENT0000000302931330;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;6.4;20.7;21.7;6.6;Cadastre;;POLYGON Z ((355358 6689769.2 20.7, 355360.3 6689768.6 20.7, 355359.9 6689767.2 20.7, 355357.6 6689767.8 20.7, 355358 6689769.2 20.7))
BATIMENT0000000302931182;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;;;11.1;7.1;18.2;22.0;7.7;Cadastre;A 1.0;POLYGON Z ((355412.6 6689771.6 18.2, 355410.4 6689763.8 18.2, 355408.5 6689764.4 18.2, 355408 6689762.7 18.2, 355400.9 6689764.8 18.2, 355394 6689766.8 18.2, 355396.9 6689776.3 18.2, 355412.6 6689771.6 18.2))
BATIMENT0000000302931332;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;7.0;20;20;20.3;5.0;25.3;29.3;7.0;Cadastre;A 1.0;POLYGON Z ((355374.4 6689783 25.3, 355373 6689765.4 25.3, 355364.1 6689767.6 25.3, 355364.9 6689776.1 25.3, 355364.2 6689777 25.3, 355366.8 6689785.4 25.3, 355374.4 6689783 25.3))
BATIMENT0000000302931331;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;7.0;13;23;20.7;5.0;25.7;29.5;6.6;Cadastre;A 1.0;POLYGON Z ((355351.2 6689776.4 25.7, 355361.3 6689787.1 25.7, 355366.8 6689785.4 25.7, 355364.2 6689777 25.7, 355362.6 6689777.5 25.7, 355361.7 6689773.7 25.7, 355358 6689769.2 25.7, 355347.5 6689771.9 25.7, 355351.2 6689776.4 25.7))
BATIMENT0000000302930864;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;30;40;15.6;7.1;22.7;25.9;8.1;Cadastre;A 1.0;POLYGON Z ((355443.2 6689769.6 22.7, 355430.6 6689773.5 22.7, 355433.2 6689784.3 22.7, 355434.6 6689783.8 22.7, 355447.4 6689780.8 22.7, 355443.2 6689769.6 22.7))
BATIMENT0000000302930865;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;13.8;6.9;20.7;22.5;7.9;Cadastre;A 1.0;POLYGON Z ((355413.1 6689778.9 20.7, 355415 6689789.5 20.7, 355423.1 6689787.2 20.7, 355424.4 6689786.8 20.7, 355430 6689785.1 20.7, 355430.1 6689785.2 20.7, 355433.2 6689784.3 20.7, 355430.6 6689773.5 20.7, 355413.1 6689778.9 20.7))
BATIMENT0000000302930858;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;12;20;11.1;7.5;18.7;25.0;8.0;Cadastre;A 1.0;POLYGON Z ((355449.8 6689785.4 18.7, 355448.6 6689780.4 18.7, 355447.4 6689780.8 18.7, 355434.6 6689783.8 18.7, 355434.8 6689784.8 18.7, 355435.6 6689788.4 18.7, 355439.3 6689787.6 18.7, 355449.2 6689785.5 18.7, 355449.8 6689785.4 18.7))
BATIMENT0000000302930862;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;7.6;12.0;15.5;7.8;Cadastre;;POLYGON Z ((355415.7 6689792.7 12, 355416.7 6689792.5 12, 355423.9 6689790.9 12, 355423.1 6689787.2 12, 355415 6689789.5 12, 355415.7 6689792.7 12))
BATIMENT0000000302931121;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;20;20;14.8;8.4;23.2;25.6;8.6;Cadastre;A 1.0;POLYGON Z ((355467.8 6689782.6 23.2, 355463.3 6689785.8 23.2, 355462.7 6689788.5 23.2, 355469.9 6689800.2 23.2, 355479 6689796.9 23.2, 355480.9 6689790.7 23.2, 355484 6689792.7 23.2, 355487.3 6689785 23.2, 355467.8 6689782.6 23.2), (355475.2 6689791.6 23.2, 355476 6689792.2 23.2, 355479 6689792.6 23.2, 355478.3 6689794.8 23.2, 355476.7 6689794.8 23.2, 355475.2 6689791.6 23.2))
BATIMENT0000000302930856;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;15;20;13.4;7.5;21.0;28.4;8.0;Cadastre;C 0.7;POLYGON Z ((355421.3 6689807.7 21, 355427.2 6689805.1 21, 355437 6689800.8 21, 355453.5 6689794.5 21, 355451.1 6689789.2 21, 355450.6 6689789.4 21, 355449.2 6689785.5 21, 355439.3 6689787.6 21, 355440.7 6689791.9 21, 355438.7 6689792.6 21, 355439.4 6689794.4 21, 355434.9 6689796 21, 355432.6 6689789.1 21, 355423.9 6689790.9 21, 355416.7 6689792.5 21, 355421.3 6689807.7 21))
BATIMENT0000000302931122;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;15.4;8.1;23.5;;;Cadastre;A 1.0;POLYGON Z ((355472.7 6689804.8 23.5, 355479.6 6689800.9 23.5, 355478.2 6689799.7 23.5, 355479 6689796.9 23.5, 355469.9 6689800.2 23.5, 355472.7 6689804.8 23.5))
BATIMENT0000000302930857;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;20;20;15.2;7.0;22.2;25.3;7.9;Cadastre;A 1.0;POLYGON Z ((355453.5 6689794.5 22.2, 355437 6689800.8 22.2, 355438.1 6689803.2 22.2, 355440.9 6689802.1 22.2, 355441.9 6689801.3 22.2, 355443.9 6689805.4 22.2, 355442.6 6689805.9 22.2, 355442.4 6689805.3 22.2, 355439.7 6689806.6 22.2, 355440.5 6689808.4 22.2, 355441.5 6689807.9 22.2, 355447 6689805.3 22.2, 355457.1 6689800.6 22.2, 355453.5 6689794.5 22.2))
BATIMENT0000000302930855;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;00;00;10.2;7.4;17.7;21.0;7.9;Cadastre;A 1.0;POLYGON Z ((355427.2 6689805.1 17.7, 355431 6689812.8 17.7, 355432.5 6689812.1 17.7, 355440.5 6689808.4 17.7, 355439.7 6689806.6 17.7, 355437.3 6689807.8 17.7, 355436.2 6689808.9 17.7, 355433.8 6689804.3 17.7, 355435.3 6689804.2 17.7, 355438.1 6689803.2 17.7, 355437 6689800.8 17.7, 355427.2 6689805.1 17.7))
BATIMENT0000000302930860;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;14.2;7.0;21.2;23.8;7.5;Cadastre;A 1.0;POLYGON Z ((355457.1 6689800.6 21.2, 355447 6689805.3 21.2, 355447.7 6689806.5 21.2, 355445 6689807.7 21.2, 355446.4 6689810.6 21.2, 355443.8 6689812.2 21.2, 355444 6689812.7 21.2, 355441.6 6689813.9 21.2, 355443.8 6689817.6 21.2, 355460.8 6689806.7 21.2, 355457.1 6689800.6 21.2))
BATIMENT0000000302931129;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.3;8.4;18.7;24.7;10.9;Cadastre;A 1.0;POLYGON Z ((355523.5 6689819.9 18.7, 355535.7 6689793.8 18.7, 355534.6 6689791.7 18.7, 355525.7 6689790.5 18.7, 355525.9 6689789.8 18.7, 355508.3 6689787.6 18.7, 355504.4 6689797.4 18.7, 355505.6 6689799.7 18.7, 355517.5 6689801.5 18.7, 355516.3 6689804.2 18.7, 355517.4 6689804.7 18.7, 355516.4 6689807 18.7, 355518.1 6689807.8 18.7, 355520.5 6689809 18.7, 355519.7 6689810.8 18.7, 355517.3 6689809.6 18.7, 355515.7 6689813.4 18.7, 355512.8 6689812 18.7, 355512.4 6689811.8 18.7, 355512.2 6689812.3 18.7, 355507.5 6689820.1 18.7, 355508.9 6689820.9 18.7, 355511 6689822.3 18.7, 355512.1 6689820.2 18.7, 355513.7 6689821.1 18.7, 355512.5 6689823.3 18.7, 355518.8 6689827.3 18.7, 355523.5 6689819.9 18.7))
BATIMENT0000000302931125;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;15;20;15.4;8.0;23.4;;;Cadastre;A 1.0;POLYGON Z ((355478.7 6689814.6 23.4, 355486.8 6689807.6 23.4, 355479.6 6689800.9 23.4, 355472.7 6689804.8 23.4, 355478.7 6689814.6 23.4))
BATIMENT0000000302931011;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;18.9;8.5;27.4;32.1;11.2;Cadastre;A 1.0;POLYGON Z ((355556 6689796.5 27.4, 355553.7 6689792.9 27.4, 355546.1 6689791.9 27.4, 355545.1 6689792.8 27.4, 355532.6 6689819.1 27.4, 355541.8 6689824.8 27.4, 355556 6689796.5 27.4))
BATIMENT0000000302931130;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;9.3;12.9;20.2;9.7;Cadastre;;POLYGON Z ((355515.3 6689806.3 12.9, 355512.8 6689812 12.9, 355515.7 6689813.4 12.9, 355517.3 6689809.6 12.9, 355519.7 6689810.8 12.9, 355520.5 6689809 12.9, 355518.1 6689807.8 12.9, 355516.4 6689807 12.9, 355517.4 6689804.7 12.9, 355516.3 6689804.2 12.9, 355515.3 6689806.3 12.9))
BATIMENT0000000302931132;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;7.5;17.6;20.7;8.4;Cadastre;;POLYGON Z ((355494.3 6689812.2 17.6, 355498.1 6689809 17.6, 355495.7 6689806.3 17.6, 355492.3 6689810.1 17.6, 355492.9 6689810.8 17.6, 355494.3 6689812.2 17.6))
BATIMENT0000000302931124;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;15;20;15.6;7.7;23.3;26.0;8.4;Cadastre;A 1.0;POLYGON Z ((355483.1 6689821.7 23.3, 355494.3 6689812.2 23.3, 355492.9 6689810.8 23.3, 355492.3 6689811.5 23.3, 355491.3 6689811.6 23.3, 355489.6 6689812.8 23.3, 355488.8 6689811.7 23.3, 355491.5 6689809.4 23.3, 355492.3 6689810.1 23.3, 355495.7 6689806.3 23.3, 355492.1 6689802.5 23.3, 355489.9 6689805 23.3, 355486.8 6689807.6 23.3, 355478.7 6689814.6 23.3, 355483.1 6689821.7 23.3))
BATIMENT0000000302931133;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;;;12.7;7.3;20.0;23.5;9.0;Cadastre;A 1.0;POLYGON Z ((355486 6689827 20, 355493.9 6689819 20, 355495.3 6689817.6 20, 355502.7 6689808 20, 355500.4 6689807.1 20, 355498.1 6689809 20, 355494.3 6689812.2 20, 355483.1 6689821.7 20, 355486 6689827 20))
BATIMENT0000000302931135;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;19.0;5.0;10;20;14.9;8.4;23.3;24.0;9.5;Cadastre;C 0.6;POLYGON Z ((355495.3 6689817.6 23.3, 355508.1 6689827.5 23.3, 355510.3 6689824 23.3, 355508 6689822.4 23.3, 355508.4 6689822.1 23.3, 355508.8 6689821.3 23.3, 355508.9 6689820.9 23.3, 355507.5 6689820.1 23.3, 355512.2 6689812.3 23.3, 355510 6689811.3 23.3, 355508.2 6689814.2 23.3, 355503.4 6689811.1 23.3, 355505.1 6689809.1 23.3, 355504.9 6689809.1 23.3, 355502.7 6689808 23.3, 355495.3 6689817.6 23.3))
BATIMENT0000000302931134;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;15.4;8.4;23.8;;;Cadastre;C 0.8;POLYGON Z ((355498.8 6689843.5 23.8, 355506 6689830.6 23.8, 355497.8 6689822.5 23.8, 355493.9 6689819 23.8, 355486 6689827 23.8, 355488.7 6689831.9 23.8, 355498.8 6689843.5 23.8))
BATIMENT0000000302931131;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1826-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;14.5;8.4;22.9;24.4;8.8;Cadastre;A 1.0;POLYGON Z ((355505.2 6689848.5 22.9, 355518.8 6689827.3 22.9, 355512.5 6689823.3 22.9, 355511.3 6689822.5 22.9, 355510.3 6689824 22.9, 355508.1 6689827.5 22.9, 355510.5 6689829.4 22.9, 355509.4 6689830.9 22.9, 355507 6689829.1 22.9, 355506 6689830.6 22.9, 355498.8 6689843.5 22.9, 355505.2 6689848.5 22.9))
BATIMENT0000000302931883;Château;Indifférencié;;Non;En service;2012-06-19 19:09:03;2012-09-27 15:33:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.3;4.9;22.2;;;Cadastre;;POLYGON Z ((355907 6689528.7 22.2, 355903.8 6689511.1 22.2, 355904.9 6689511 22.2, 355906 6689510.5 22.2, 355906.1 6689509.3 22.2, 355905.9 6689508.5 22.2, 355933 6689506.3 22.2, 355954.3 6689500.6 22.2, 355957 6689502.7 22.2, 355975.4 6689503.8 22.2, 355978.9 6689503.7 22.2, 355980.8 6689503.4 22.2, 355983.6 6689502.4 22.2, 355986.1 6689500.7 22.2, 355987.5 6689499.2 22.2, 355988.6 6689497.5 22.2, 355989.7 6689494.8 22.2, 355990.2 6689491.8 22.2, 355990 6689489.8 22.2, 355989.3 6689487.2 22.2, 355988.4 6689485.4 22.2, 355987.3 6689483.9 22.2, 355984.8 6689481.7 22.2, 355982.2 6689480.4 22.2, 355977.1 6689480.1 22.2, 355958.7 6689481.6 22.2, 355959.2 6689484.9 22.2, 355958.1 6689485.1 22.2, 355958.1 6689486.5 22.2, 355958.9 6689487.5 22.2, 355960.5 6689495.3 22.2, 355957.3 6689494.8 22.2, 355956.8 6689493.3 22.2, 355931.7 6689498.4 22.2, 355926.9 6689498.8 22.2, 355903.4 6689502.1 22.2, 355904.3 6689499.5 22.2, 355901.4 6689494.7 22.2, 355901.7 6689490.7 22.2, 355897.4 6689483.6 22.2, 355889.4 6689488.1 22.2, 355889.7 6689488.6 22.2, 355888 6689490.2 22.2, 355887.5 6689490 22.2, 355887.2 6689490.6 22.2, 355887.6 6689490.7 22.2, 355888.1 6689493.3 22.2, 355887.7 6689493.5 22.2, 355887.8 6689494 22.2, 355887 6689494.3 22.2, 355887.3 6689495.3 22.2, 355889.5 6689494.8 22.2, 355890.5 6689495.3 22.2, 355891.9 6689500.4 22.2, 355889.1 6689500.9 22.2, 355889.4 6689502.6 22.2, 355889.9 6689502.5 22.2, 355891.8 6689510.4 22.2, 355889.8 6689510.6 22.2, 355889.9 6689514.8 22.2, 355886.9 6689515.7 22.2, 355885.6 6689522.9 22.2, 355907 6689528.7 22.2))
BATIMENT0000000303961863;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;16.5;15.9;32.5;35.8;17.5;Cadastre;A 1.0;POLYGON Z ((355970.2 6689710.9 32.5, 355969.4 6689710.5 32.5, 355965.1 6689719.8 32.5, 355966 6689721.1 32.5, 355986.3 6689730.7 32.5, 355995.3 6689707.9 32.5, 355999.1 6689698.2 32.5, 355980.3 6689689.4 32.5, 355970.2 6689710.9 32.5), (355986.8 6689710.5 32.5, 355989.3 6689711.6 32.5, 355984.5 6689719.9 32.5, 355979.2 6689717.6 32.5, 355981.2 6689713.5 32.5, 355983.1 6689714.1 32.5, 355983.8 6689712.6 32.5, 355985.4 6689713.3 32.5, 355986.8 6689710.5 32.5))
BATIMENT0000000303961750;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;19.6;16.8;36.5;39.9;18.6;Cadastre;C 0.9;POLYGON Z ((355985.8 6689761.5 36.5, 355986.8 6689761.9 36.5, 355987.8 6689761.6 36.5, 355990 6689757 36.5, 355989.6 6689755.8 36.5, 355988.8 6689755.4 36.5, 355991.4 6689750.3 36.5, 355977.6 6689743.5 36.5, 355976.1 6689746.6 36.5, 355975.8 6689746.6 36.5, 355974.6 6689749.4 36.5, 355974 6689749.6 36.5, 355967.4 6689763.4 36.5, 355967.7 6689763.5 36.5, 355966.2 6689766.6 36.5, 355970.6 6689768.6 36.5, 355971.1 6689766.5 36.5, 355974.9 6689768.2 36.5, 355974 6689770.4 36.5, 355976.1 6689771.5 36.5, 355975.8 6689772.1 36.5, 355978.9 6689773.3 36.5, 355980.7 6689772.2 36.5, 355982.9 6689767.4 36.5, 355985.8 6689761.5 36.5))
BATIMENT0000000303961743;Eglise;Indifférencié;;Non;En service;2012-06-26 20:04:17;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.3;18.0;34.3;;;Cadastre;;POLYGON Z ((355965.5 6689766.1 34.3, 355959.3 6689779.1 34.3, 355960.4 6689779.7 34.3, 355965.4 6689781.5 34.3, 355967.4 6689782.3 34.3, 355973.4 6689784.9 34.3, 355973.2 6689786.6 34.3, 355971.6 6689789.7 34.3, 355971.1 6689791.3 34.3, 355973 6689792.4 34.3, 355973.1 6689792.1 34.3, 355976 6689793.4 34.3, 355980.8 6689795.8 34.3, 355982.9 6689791.4 34.3, 355985.2 6689790.6 34.3, 355985.7 6689790.9 34.3, 355986.4 6689791.2 34.3, 355987 6689791.4 34.3, 355987.6 6689791.5 34.3, 355988.3 6689791.6 34.3, 355988.9 6689791.7 34.3, 355989.6 6689791.6 34.3, 355990.2 6689791.6 34.3, 355990.9 6689791.4 34.3, 355991.5 6689791.3 34.3, 355992.1 6689791 34.3, 355992.7 6689790.7 34.3, 355993.3 6689790.4 34.3, 355993.8 6689790 34.3, 355994.3 6689789.6 34.3, 355994.8 6689789.1 34.3, 355995.2 6689788.6 34.3, 355995.5 6689787.7 34.3, 355995.7 6689786.8 34.3, 355995.8 6689785.9 34.3, 355995.9 6689784.9 34.3, 355995.9 6689784 34.3, 355995.8 6689783 34.3, 355995.5 6689782.5 34.3, 355994.7 6689781.5 34.3, 355993.8 6689781.1 34.3, 355991 6689779.6 34.3, 355990 6689776.5 34.3, 355991.1 6689773.7 34.3, 355991.6 6689773.9 34.3, 355992.2 6689772.1 34.3, 355990.4 6689771.3 34.3, 355990.2 6689771.6 34.3, 355984 6689768.6 34.3, 355984.3 6689768 34.3, 355982.9 6689767.4 34.3, 355980.7 6689772.2 34.3, 355978.9 6689773.3 34.3, 355975.8 6689772.1 34.3, 355976.1 6689771.5 34.3, 355974 6689770.4 34.3, 355970.6 6689768.6 34.3, 355966.2 6689766.6 34.3, 355965.5 6689766.1 34.3))
BATIMENT0000000303961746;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;18.1;18.0;36.1;40.0;18.3;Cadastre;C 0.1;POLYGON Z ((355965.4 6689781.5 36.1, 355964.9 6689783.1 36.1, 355966.8 6689784.2 36.1, 355967.4 6689782.3 36.1, 355965.4 6689781.5 36.1))
BATIMENT0000000303961866;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;4.9;18.0;23.0;26.7;18.5;Cadastre;A 1.0;POLYGON Z ((355914.8 6689786.6 23, 355918.9 6689788.6 23, 355921.2 6689784 23, 355917 6689782 23, 355914.8 6689786.6 23))
BATIMENT0000000303961747;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.0;18.1;24.2;31.7;18.7;Cadastre;C 0.3;POLYGON Z ((355976 6689793.4 24.2, 355974.2 6689797.5 24.2, 355982.7 6689801.3 24.2, 355984.3 6689797.9 24.2, 355980.8 6689795.8 24.2, 355976 6689793.4 24.2))
BATIMENT0000000303961741;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;10;20;19.4;18.0;37.5;41.7;18.9;Cadastre;C 0.8;POLYGON Z ((355955.7 6689789.1 37.5, 355955.2 6689788.9 37.5, 355949.9 6689800.2 37.5, 355950.3 6689800.4 37.5, 355945.5 6689810 37.5, 355944.3 6689813.3 37.5, 355948.4 6689815.6 37.5, 355947.2 6689818.1 37.5, 355955.5 6689821.7 37.5, 355957.1 6689822 37.5, 355964.2 6689806.8 37.5, 355965.2 6689806.9 37.5, 355970.1 6689797.1 37.5, 355969.8 6689795.1 37.5, 355970.4 6689793.6 37.5, 355969.9 6689792.3 37.5, 355969.4 6689791.6 37.5, 355970 6689789.6 37.5, 355971.6 6689789.7 37.5, 355973.2 6689786.6 37.5, 355973.4 6689784.9 37.5, 355967.4 6689782.3 37.5, 355966.8 6689784.2 37.5, 355964.9 6689783.1 37.5, 355965.4 6689781.5 37.5, 355960.4 6689779.7 37.5, 355955.7 6689789.1 37.5))
BATIMENT0000000303961739;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;15.3;18.0;33.3;37.0;19.4;Cadastre;A 1.0;POLYGON Z ((355917.4 6689824.8 33.3, 355953.4 6689826.1 33.3, 355955.5 6689821.7 33.3, 355947.2 6689818.1 33.3, 355942.9 6689816.3 33.3, 355944.3 6689813.3 33.3, 355945.5 6689810 33.3, 355925.6 6689800.1 33.3, 355915 6689821.8 33.3, 355917.4 6689824.8 33.3), (355933.5 6689813.6 33.3, 355941 6689816.9 33.3, 355942.1 6689818.1 33.3, 355939.4 6689823 33.3, 355938 6689823 33.3, 355937.5 6689824 33.3, 355929.9 6689820.4 33.3, 355933.5 6689813.6 33.3))
BATIMENT0000000303961748;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;90;20;6.3;18.2;24.5;28.0;19.2;Cadastre;C 0.5;POLYGON Z ((355977.4 6689831.2 24.5, 355978.3 6689829.5 24.5, 355979.1 6689827.8 24.5, 355974.7 6689825.6 24.5, 355975.2 6689824.2 24.5, 355963 6689818.5 24.5, 355960.7 6689823.1 24.5, 355977.4 6689831.2 24.5))
BATIMENT0000000303962910;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;15;20;6.2;11.5;17.7;28.8;13.9;Cadastre;A 1.0;POLYGON Z ((356038.7 6689636.6 17.7, 356044.3 6689624.6 17.7, 356045.9 6689621.3 17.7, 356046.5 6689619.7 17.7, 356037.2 6689615.7 17.7, 356037.4 6689614.7 17.7, 356035.9 6689614.1 17.7, 356033.2 6689620.9 17.7, 356032.6 6689622.1 17.7, 356034.5 6689622.9 17.7, 356036.5 6689618.3 17.7, 356042.2 6689620.6 17.7, 356039.6 6689627.5 17.7, 356031.7 6689624.4 17.7, 356031.5 6689625.1 17.7, 356029.6 6689624.1 17.7, 356027 6689630.7 17.7, 356038.7 6689636.6 17.7))
BATIMENT0000000303962915;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;14.3;12.6;26.9;29.2;13.9;Cadastre;B 1.0;POLYGON Z ((356038.4 6689637.5 26.9, 356047.7 6689641.9 26.9, 356053.8 6689628.8 26.9, 356044.3 6689624.6 26.9, 356038.7 6689636.6 26.9, 356038.4 6689637.5 26.9))
BATIMENT0000000303962407;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;17.5;13.2;30.7;35.0;14.3;Cadastre;A 1.0;POLYGON Z ((356004 6689638.8 30.7, 356004.5 6689639.1 30.7, 356002.4 6689643.5 30.7, 356017.5 6689650.3 30.7, 356023.4 6689636.4 30.7, 356009.5 6689629.3 30.7, 356008.1 6689629.7 30.7, 356004 6689638.8 30.7), (356013.7 6689643.7 30.7, 356016.9 6689645.3 30.7, 356016.2 6689646.9 30.7, 356011.9 6689645.1 30.7, 356012.3 6689644.5 30.7, 356013.7 6689643.7 30.7))
BATIMENT0000000303962404;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;9.6;13.6;23.2;26.1;14.6;Cadastre;A 1.0;POLYGON Z ((356022.9 6689653.5 23.2, 356025.2 6689654.6 23.2, 356034.4 6689658.9 23.2, 356041.9 6689644.4 23.2, 356036.4 6689642 23.2, 356034.8 6689645.4 23.2, 356035.5 6689645.8 23.2, 356033.6 6689649.6 23.2, 356023 6689644.5 23.2, 356024.4 6689641 23.2, 356027.3 6689642.3 23.2, 356029.1 6689638.4 23.2, 356023.6 6689635.8 23.2, 356023.4 6689636.4 23.2, 356017.5 6689650.3 23.2, 356017.6 6689651 23.2, 356019.6 6689652 23.2, 356022.9 6689653.5 23.2))
BATIMENT0000000303961859;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2023-01-31 17:56:48;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;12;20;18.2;14.0;32.2;36.0;15.0;Cadastre;A 0.8;POLYGON Z ((355998.2 6689652 32.2, 356001.1 6689653.4 32.2, 356021.8 6689663.1 32.2, 356023.8 6689658.2 32.2, 356022.5 6689657.7 32.2, 356022.2 6689658.9 32.2, 356010.8 6689653.5 32.2, 356011.8 6689650.5 32.2, 356018.9 6689653.5 32.2, 356019.6 6689652 32.2, 356017.6 6689651 32.2, 356017.5 6689650.3 32.2, 356002.4 6689643.5 32.2, 355998.2 6689652 32.2))
BATIMENT0000000303962403;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;14.2;22.5;23.0;14.9;Cadastre;;POLYGON Z ((356022.3 6689655.3 22.5, 356024.5 6689656.3 22.5, 356025.2 6689654.6 22.5, 356022.9 6689653.5 22.5, 356022.3 6689655.3 22.5))
BATIMENT0000000303962405;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;3.0;10;20;10.4;13.8;24.2;27.0;14.8;Cadastre;A 1.0;POLYGON Z ((356038.9 6689661 24.2, 356051.2 6689666.7 24.2, 356058.1 6689652.1 24.2, 356050.2 6689648.4 24.2, 356049.5 6689650.2 24.2, 356052.9 6689651.8 24.2, 356050.1 6689657.7 24.2, 356040.9 6689653.4 24.2, 356042.7 6689649.7 24.2, 356046.4 6689651.4 24.2, 356048.2 6689647.5 24.2, 356041.9 6689644.4 24.2, 356034.4 6689658.9 24.2, 356038.9 6689661 24.2))
BATIMENT0000000303961860;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;16.0;14.3;30.3;36.7;16.4;Cadastre;A 1.0;POLYGON Z ((355993.4 6689663 30.3, 356009.9 6689670.6 30.3, 356011 6689668.3 30.3, 356015.9 6689670.4 30.3, 356014.5 6689672.7 30.3, 356017.5 6689674.1 30.3, 356021.8 6689663.1 30.3, 356001.1 6689653.4 30.3, 355998.2 6689652 30.3, 355996 6689657.1 30.3, 355993.4 6689663 30.3), (356015.5 6689662.4 30.3, 356018.2 6689663.6 30.3, 356017.1 6689665.9 30.3, 356012.1 6689663.5 30.3, 356013 6689661.3 30.3, 356015.5 6689662.4 30.3), (356003 6689659.4 30.3, 356007.8 6689661.5 30.3, 356006.5 6689664.3 30.3, 356001.6 6689662.2 30.3, 356002.8 6689659.3 30.3, 356003 6689659.4 30.3))
BATIMENT0000000303961861;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;18.4;14.7;33.2;36.1;16.9;Cadastre;A 1.0;POLYGON Z ((355991 6689667.3 33.2, 355990.4 6689667.1 33.2, 355988.2 6689672.7 33.2, 356005.5 6689680.9 33.2, 356008.9 6689673.3 33.2, 356016.4 6689676.9 33.2, 356017.5 6689674.1 33.2, 356014.5 6689672.7 33.2, 356009.9 6689670.6 33.2, 355993.4 6689663 33.2, 355991 6689667.3 33.2), (356003.5 6689669.7 33.2, 356004.7 6689670.1 33.2, 356005.5 6689672.7 33.2, 356004.1 6689675.8 33.2, 356001.9 6689676.4 33.2, 356000.7 6689675.7 33.2, 356003.5 6689669.7 33.2))
BATIMENT0000000303961862;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2023-01-31 17:56:48;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;16.9;15.3;32.2;35.9;16.9;Cadastre;A 0.8;POLYGON Z ((355983.3 6689682.1 32.2, 355983.7 6689682.3 32.2, 355980.3 6689689.4 32.2, 355999.1 6689698.2 32.2, 356000 6689695.9 32.2, 356004 6689697.4 32.2, 356005.4 6689693.9 32.2, 356004.6 6689692.1 32.2, 356001.7 6689691 32.2, 356002.5 6689688.9 32.2, 356004.9 6689690 32.2, 356006.5 6689689.2 32.2, 356008.2 6689685.5 32.2, 356007.2 6689685.1 32.2, 356008.5 6689682.3 32.2, 356005.5 6689680.9 32.2, 355988.2 6689672.7 32.2, 355983.3 6689682.1 32.2))
BATIMENT0000000303963107;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.5;15.4;20.0;24.7;15.8;Cadastre;;POLYGON Z ((356019.9 6689697.5 20, 356019 6689699.5 20, 356020 6689701.3 20, 356021.5 6689702.2 20, 356023.6 6689697 20, 356021.6 6689696.8 20, 356019.9 6689697.5 20))
BATIMENT0000000303961864;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;9.5;17.3;26.8;30.8;17.6;Cadastre;A 1.0;POLYGON Z ((355991 6689733.1 26.8, 355995.5 6689724.8 26.8, 356009.7 6689731.8 26.8, 356015.2 6689719.6 26.8, 356001.3 6689712.6 26.8, 356002 6689711.1 26.8, 355995.3 6689707.9 26.8, 355986.3 6689730.7 26.8, 355991 6689733.1 26.8))
BATIMENT0000000303962412;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;16.0;23.7;25.7;16.4;Cadastre;;POLYGON Z ((356030.7 6689728.2 23.7, 356029.5 6689727.7 23.7, 356027.9 6689731.2 23.7, 356029.2 6689731.7 23.7, 356030.7 6689728.2 23.7))
BATIMENT0000000303962414;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;16.1;20.2;26.3;16.9;Cadastre;;POLYGON Z ((356036.7 6689732 20.2, 356038 6689732.3 20.2, 356038.6 6689730.9 20.2, 356039.2 6689731.2 20.2, 356040.3 6689728.6 20.2, 356039.9 6689728.3 20.2, 356040.9 6689726.7 20.2, 356037.5 6689725.2 20.2, 356031.7 6689736.4 20.2, 356033.9 6689737.4 20.2, 356036.7 6689732 20.2))
BATIMENT0000000303962408;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;9.4;17.3;26.7;31.0;17.4;Cadastre;C 0.8;POLYGON Z ((356024.1 6689739.2 26.7, 356019.6 6689747.2 26.7, 356024.7 6689749.8 26.7, 356031.7 6689736.4 26.7, 356037.5 6689725.2 26.7, 356033 6689722.5 26.7, 356030.8 6689725.7 26.7, 356032.8 6689726.8 26.7, 356032 6689728.7 26.7, 356033.3 6689729.6 26.7, 356031.2 6689732.6 26.7, 356029.2 6689731.7 26.7, 356027.9 6689731.2 26.7, 356029.5 6689727.7 26.7, 356029.8 6689727.2 26.7, 356015.2 6689719.6 26.7, 356009.7 6689731.8 26.7, 356024.1 6689739.2 26.7))
BATIMENT0000000303963108;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.7;17.0;19.7;22.2;17.2;Cadastre;;POLYGON Z ((356004.6 6689740.3 19.7, 356008.3 6689742.1 19.7, 356010.6 6689738 19.7, 356006.8 6689736.1 19.7, 356004.6 6689740.3 19.7))
BATIMENT0000000303962409;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;10;20;17.4;16.6;34.0;36.8;17.6;Cadastre;A 1.0;POLYGON Z ((356064.5 6689751.7 34, 356050 6689745 34, 356033.9 6689737.4 34, 356031.7 6689736.4 34, 356024.7 6689749.8 34, 356064.6 6689769.5 34, 356075.6 6689747.8 34, 356068.3 6689744.1 34, 356064.5 6689751.7 34), (356067.9 6689748.6 34, 356070.4 6689749.8 34, 356067.1 6689756.9 34, 356065.1 6689756.1 34, 356065.9 6689754.2 34, 356065.4 6689754 34, 356067.1 6689750.3 34, 356067.9 6689748.6 34))
BATIMENT0000000303961745;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;7.3;18.1;25.4;30.2;18.3;Cadastre;C 0.5;POLYGON Z ((356004.6 6689756.9 25.4, 355998.5 6689768.5 25.4, 355998.3 6689770.2 25.4, 355999.6 6689770.5 25.4, 355997.7 6689773.9 25.4, 355998.6 6689774.6 25.4, 355998.3 6689775.4 25.4, 355992.2 6689772.1 25.4, 355991.6 6689773.9 25.4, 355991.1 6689773.7 25.4, 355990 6689776.5 25.4, 355991 6689779.6 25.4, 355993.8 6689781.1 25.4, 355994.7 6689781.5 25.4, 355995.5 6689782.5 25.4, 355996.3 6689781.4 25.4, 356000 6689783.1 25.4, 356011.7 6689760.4 25.4, 356004.6 6689756.9 25.4))
BATIMENT0000002011294998;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;1970-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;19.0;7.0;50;20;22.0;16.9;;42.3;18.2;Imagerie aérienne;A 1.0;POLYGON Z ((356005.4 6689772.7 25.4, 356005.8 6689773.1 38.9, 356032.9 6689786.5 38.9, 356038.9 6689774.7 38.9, 356015.2 6689762.9 38.9, 356012.8 6689762.6 34.9, 356011.2 6689761.4 25.4, 356005.4 6689772.7 25.4))
BATIMENT0000000303961744;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.7;18.0;22.7;24.5;18.7;Cadastre;C 0.1;POLYGON Z ((355995.9 6689784 22.7, 355995.9 6689784.9 22.7, 355995.8 6689785.9 22.7, 355995.7 6689786.8 22.7, 355995.5 6689787.7 22.7, 355995.2 6689788.6 22.7, 355996.9 6689789.2 22.7, 355999.1 6689784.9 22.7, 355995.8 6689783 22.7, 355995.9 6689784 22.7))
BATIMENT0000000302930638;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.0;18.0;28.0;31.2;18.8;Cadastre;;POLYGON Z ((355834.1 6689670.7 28, 355835.8 6689662.9 28, 355812.7 6689659.7 28, 355811.8 6689667.9 28, 355834.1 6689670.7 28))
BATIMENT0000000302930640;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;16.6;22.7;24.7;18.7;Cadastre;;POLYGON Z ((355864.2 6689663.1 22.7, 355861.8 6689676 22.7, 355864.4 6689676.4 22.7, 355872.7 6689678.2 22.7, 355873.1 6689675.6 22.7, 355865.1 6689673.9 22.7, 355866.1 6689667 22.7, 355874.4 6689668.1 22.7, 355874.9 6689665.1 22.7, 355864.2 6689663.1 22.7))
BATIMENT0000000302931845;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.0;18.0;25.0;;;Cadastre;;POLYGON Z ((355865.3 6689683.9 25, 355864.9 6689686 25, 355872.1 6689687.1 25, 355872.5 6689685.1 25, 355878.6 6689686.1 25, 355879.2 6689683.5 25, 355880 6689683.6 25, 355883.6 6689666.1 25, 355875 6689664.6 25, 355874.9 6689665.1 25, 355874.4 6689668.1 25, 355873.1 6689675.6 25, 355872.7 6689678.2 25, 355864.4 6689676.4 25, 355861.8 6689676 25, 355864.2 6689663.1 25, 355860.2 6689662.2 25, 355859.6 6689666.5 25, 355859 6689666.5 25, 355856.1 6689682 25, 355865.3 6689683.9 25))
BATIMENT0000000302931847;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;30.0;18.0;48.0;;;Cadastre;;POLYGON Z ((355779.6 6689714.2 48, 355781.2 6689715.4 48, 355781.7 6689716.6 48, 355783.5 6689717 48, 355784.2 6689714.1 48, 355790.3 6689715.1 48, 355791.5 6689716.8 48, 355790.9 6689718.5 48, 355793.2 6689718.9 48, 355792.7 6689721.3 48, 355795.4 6689721.8 48, 355796.1 6689719 48, 355798.6 6689719.5 48, 355798.1 6689722.5 48, 355799.8 6689722.8 48, 355800.5 6689719.9 48, 355805.6 6689720.7 48, 355805.1 6689723.8 48, 355807.1 6689724.2 48, 355807.8 6689721.2 48, 355812.6 6689722.2 48, 355812.1 6689725.3 48, 355813.8 6689725.7 48, 355814.2 6689722.4 48, 355819.4 6689723.4 48, 355819 6689726.7 48, 355820.5 6689727.1 48, 355820.8 6689724.2 48, 355825.6 6689724.7 48, 355825.6 6689725.5 48, 355826.5 6689725.5 48, 355826.4 6689726.7 48, 355827.2 6689726.7 48, 355827.2 6689728.4 48, 355828.3 6689728.7 48, 355829.3 6689728.7 48, 355829.6 6689726 48, 355839.8 6689728.1 48, 355839.5 6689730.4 48, 355841.3 6689730.8 48, 355841.6 6689729.6 48, 355842.5 6689729.7 48, 355842.7 6689728.9 48, 355843.7 6689729 48, 355843.8 6689728.2 48, 355848.2 6689729 48, 355847.7 6689732 48, 355849.8 6689732.1 48, 355850.2 6689729.6 48, 355855.8 6689730.6 48, 355855.1 6689733.6 48, 355856.9 6689733.8 48, 355857.5 6689731.2 48, 355859.8 6689731.5 48, 355858.8 6689732.1 48, 355858.4 6689734.2 48, 355859.8 6689735.8 48, 355861.8 6689734.7 48, 355862.6 6689734.8 48, 355863.1 6689732.5 48, 355865.6 6689734.4 48, 355865.3 6689735.9 48, 355866.7 6689736.3 48, 355866.9 6689734.9 48, 355870.3 6689734.8 48, 355871.4 6689736.1 48, 355872.4 6689735.3 48, 355871.2 6689734 48, 355874.3 6689730.9 48, 355875 6689732.2 48, 355876.3 6689731.7 48, 355875.7 6689730.4 48, 355880.5 6689730.8 48, 355880.8 6689732.1 48, 355882.4 6689731.7 48, 355882 6689730 48, 355884.4 6689727.9 48, 355886.5 6689728.6 48, 355887.2 6689727.2 48, 355885.1 6689726.4 48, 355883.8 6689722.1 48, 355885.5 6689722.5 48, 355886.1 6689720.7 48, 355885 6689720.1 48, 355889.7 6689718.9 48, 355891.3 6689719.9 48, 355892.2 6689718.4 48, 355890.3 6689717.5 48, 355891.3 6689713.8 48, 355892.6 6689713.4 48, 355892.3 6689711.7 48, 355890.4 6689712.2 48, 355886.7 6689709.7 48, 355888 6689709.4 48, 355887.7 6689707.4 48, 355886.3 6689707.4 48, 355888.7 6689703.9 48, 355890.3 6689703.8 48, 355890.4 6689702.1 48, 355888.9 6689702 48, 355886.9 6689699.3 48, 355887.5 6689697.7 48, 355886.2 6689697.1 48, 355885.7 6689698 48, 355881.4 6689697 48, 355882.1 6689695.8 48, 355881.1 6689695 48, 355880 6689695.7 48, 355878.4 6689692 48, 355879.6 6689691 48, 355878.9 6689690 48, 355877.6 6689690.8 48, 355874.6 6689689.5 48, 355874.6 6689687.5 48, 355872.8 6689687.6 48, 355872.7 6689688 48, 355872 6689688 48, 355872.1 6689687.1 48, 355864.9 6689686 48, 355864.5 6689687.9 48, 355863.1 6689687.6 48, 355862.7 6689690 48, 355856.8 6689688.8 48, 355857.1 6689686.3 48, 355855.8 6689686 48, 355855.2 6689688.4 48, 355850.3 6689687.4 48, 355850.2 6689686.7 48, 355849.2 6689686.4 48, 355849 6689684.8 48, 355847.5 6689684.4 48, 355847.1 6689685.6 48, 355836.6 6689683.5 48, 355836.9 6689682.8 48, 355835.3 6689682.5 48, 355835.1 6689683.6 48, 355834 6689683.4 48, 355833.8 6689684 48, 355833 6689683.9 48, 355833.1 6689683.6 48, 355829.6 6689683 48, 355829.6 6689683.3 48, 355828.8 6689683.3 48, 355829.2 6689681 48, 355827.8 6689680.8 48, 355827.3 6689683.1 48, 355822.1 6689682 48, 355822.6 6689679.8 48, 355820.8 6689679.5 48, 355820.3 6689681.5 48, 355814.7 6689680.6 48, 355815.1 6689678.5 48, 355813.6 6689678.2 48, 355813.3 6689680.2 48, 355808.2 6689679.3 48, 355800.3 6689678.6 48, 355798.2 6689678.2 48, 355798.2 6689679.8 48, 355797 6689680.3 48, 355796.7 6689681.1 48, 355795.8 6689680.9 48, 355795.6 6689682.6 48, 355799.3 6689683 48, 355799.3 6689691.8 48, 355816.3 6689695.6 48, 355813.4 6689709.4 48, 355795.9 6689705.9 48, 355794.2 6689714.3 48, 355782.9 6689712.1 48, 355783.6 6689708.9 48, 355782.6 6689708.9 48, 355782.5 6689709.6 48, 355781.6 6689709.3 48, 355781.4 6689709.9 48, 355780.8 6689709.6 48, 355780.5 6689710.1 48, 355779.4 6689709.7 48, 355778.4 6689715 48, 355779 6689715 48, 355779.6 6689714.2 48))
BATIMENT0000000302930350;Tour, donjon;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;21.0;18.0;39.0;;;Cadastre;A 1.0;POLYGON Z ((355832.9 6689751.9 39, 355834.6 6689753.4 39, 355829.9 6689758.3 39, 355824 6689765.8 39, 355826.3 6689768.3 39, 355830.9 6689770.5 39, 355836.4 6689763.5 39, 355840.1 6689757.9 39, 355838.6 6689756.4 39, 355840.1 6689754.9 39, 355841.1 6689752.4 39, 355840.3 6689752 39, 355839.8 6689752.7 39, 355837.3 6689751.6 39, 355836.3 6689752.2 39, 355833.9 6689750.4 39, 355832.9 6689751.9 39))
BATIMENT0000000302931808;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.2;18.7;21.0;21.3;19.2;Cadastre;;POLYGON Z ((355826.8 6689800.9 21, 355826 6689800.5 21, 355824.1 6689804.4 21, 355825 6689804.8 21, 355826.8 6689800.9 21))
BATIMENT0000000302931805;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;18.9;21.2;21.4;19.2;Cadastre;;POLYGON Z ((355833.1 6689804 21.2, 355832.3 6689803.6 21.2, 355830.3 6689807.4 21.2, 355831.2 6689807.9 21.2, 355833.1 6689804 21.2))
BATIMENT0000000302931807;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.4;18.7;21.2;21.4;19.1;Cadastre;;POLYGON Z ((355828.1 6689814.4 21.2, 355827.3 6689814 21.2, 355825.3 6689817.8 21.2, 355826.1 6689818.3 21.2, 355828.1 6689814.4 21.2))
BATIMENT0000000303961856;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;13.3;19.8;33.1;36.0;20.2;Cadastre;A 1.0;POLYGON Z ((355882.6 6689888.9 33.1, 355893.5 6689894.2 33.1, 355897.8 6689885.3 33.1, 355899.6 6689885.9 33.1, 355901 6689883.1 33.1, 355908 6689891.2 33.1, 355912.4 6689888 33.1, 355896.8 6689868.6 33.1, 355892.3 6689868.3 33.1, 355882.6 6689888.9 33.1))
BATIMENT0000000303961857;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.2;19.0;31.2;36.1;19.8;Cadastre;A 1.0;POLYGON Z ((355901 6689883.1 31.2, 355899.6 6689885.9 31.2, 355897.8 6689885.3 31.2, 355893.5 6689894.2 31.2, 355899.7 6689897.4 31.2, 355908 6689891.2 31.2, 355901 6689883.1 31.2))
BATIMENT0000000303961740;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:59;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;3.0;10;20;11.1;18.4;29.5;29.7;19.6;Cadastre;A 1.0;POLYGON Z ((355980.3 6689837.7 29.5, 355982.5 6689833.6 29.5, 355979.6 6689832.2 29.5, 355977.4 6689831.2 29.5, 355960.7 6689823.1 29.5, 355957.1 6689822 29.5, 355955.5 6689821.7 29.5, 355953.4 6689826.1 29.5, 355980.3 6689837.7 29.5))
BATIMENT0000000303961855;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;4.0;10;20;6.8;18.8;25.6;38.1;20.5;Cadastre;A 1.0;POLYGON Z ((355944.5 6689835.6 25.6, 355943.7 6689834.3 25.6, 355915.5 6689834 25.6, 355915 6689833.5 25.6, 355906.9 6689833.4 25.6, 355903.6 6689840.2 25.6, 355903.1 6689839.9 25.6, 355899.2 6689848 25.6, 355899.7 6689848.2 25.6, 355896.4 6689855.4 25.6, 355906.5 6689867.3 25.6, 355911.9 6689861.8 25.6, 355914.3 6689857.1 25.6, 355912.2 6689856.3 25.6, 355917.6 6689845.5 25.6, 355919.3 6689846.2 25.6, 355919.9 6689845.8 25.6, 355920.3 6689845.4 25.6, 355931.6 6689845.5 25.6, 355931.9 6689844.7 25.6, 355933.3 6689844.8 25.6, 355933.4 6689846 25.6, 355932.5 6689846.4 25.6, 355929.3 6689852.2 25.6, 355928.3 6689851.6 25.6, 355927.5 6689851.8 25.6, 355927.1 6689852.8 25.6, 355927.4 6689853 25.6, 355923.9 6689859 25.6, 355923.3 6689859.5 25.6, 355923.4 6689860.7 25.6, 355924.4 6689861.4 25.6, 355921.3 6689867.2 25.6, 355922.2 6689868.1 25.6, 355926.5 6689870.1 25.6, 355944.5 6689835.6 25.6))
BATIMENT0000000303961841;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;3.0;00;00;10.6;19.9;30.5;32.2;20.8;Cadastre;C 0.7;POLYGON Z ((355951.4 6689886.2 30.5, 355949.1 6689884.8 30.5, 355949.3 6689884.2 30.5, 355944.1 6689881.5 30.5, 355946.1 6689877.9 30.5, 355941 6689874.9 30.5, 355958.4 6689841.9 30.5, 355950.4 6689838.3 30.5, 355928.9 6689879.1 30.5, 355946.8 6689888.8 30.5, 355949 6689890 30.5, 355949.3 6689890.1 30.5, 355951.4 6689886.2 30.5))
BATIMENT0000000303961854;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;18.4;19.5;38.0;39.8;20.5;Cadastre;A 1.0;POLYGON Z ((355918.9 6689882 38, 355920.1 6689882.4 38, 355926.5 6689870.1 38, 355922.2 6689868.1 38, 355920.8 6689869.3 38, 355918.4 6689866.7 38, 355919.8 6689865.4 38, 355916.1 6689861.2 38, 355914.5 6689862.8 38, 355911.9 6689861.8 38, 355906.5 6689867.3 38, 355918.9 6689882 38))
BATIMENT0000000303961858;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;3.0;00;00;10.1;20.0;30.1;;;Cadastre;C 0.6;POLYGON Z ((355949.7 6689877.8 30.1, 355954.2 6689880.2 30.1, 355955.9 6689877.1 30.1, 355968.8 6689883.6 30.1, 355966.9 6689887.1 30.1, 355971.7 6689889.7 30.1, 355979.9 6689873.4 30.1, 355975.4 6689871 30.1, 355973.3 6689874 30.1, 355960.9 6689867.4 30.1, 355962.7 6689864.1 30.1, 355958 6689861.8 30.1, 355949.7 6689877.8 30.1))
BATIMENT0000000303961842;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;00;00;9.6;19.3;29.0;37.9;21.3;Cadastre;C 0.2;POLYGON Z ((355985.5 6689899.6 29, 355985.1 6689899.1 29, 355991.8 6689886.9 29, 355992.3 6689887.1 29, 355995.8 6689880.6 29, 355995 6689880.3 29, 356001.6 6689868 29, 356002.1 6689868.2 29, 356004.8 6689862.9 29, 355996.4 6689859.3 29, 355976.8 6689897.2 29, 355965.9 6689891.8 29, 355965.3 6689892.7 29, 355953.1 6689886.4 29, 355950.8 6689890.9 29, 355956.2 6689893.9 29, 355964.9 6689898.5 29, 355981.3 6689907.5 29, 355985.5 6689899.6 29))
BATIMENT0000000303961843;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;13.5;20.2;33.7;34.9;21.0;Cadastre;A 1.0;POLYGON Z ((355944.5 6689889.2 33.7, 355928.4 6689879.9 33.7, 355926.2 6689884.3 33.7, 355936.7 6689891.5 33.7, 355941.5 6689894.2 33.7, 355944.5 6689889.2 33.7))
BATIMENT0000000303961848;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;;;11.2;21.0;32.2;;;Cadastre;A 1.0;POLYGON Z ((355924.1 6689888.2 32.2, 355931 6689896.4 32.2, 355936.7 6689891.5 32.2, 355926.2 6689884.3 32.2, 355924.1 6689888.2 32.2))
BATIMENT0000000303961847;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;13.7;20.4;34.1;36.0;21.0;Cadastre;A 1.0;POLYGON Z ((355934.2 6689900.4 34.1, 355941.4 6689894.4 34.1, 355941.5 6689894.2 34.1, 355936.7 6689891.5 34.1, 355931 6689896.4 34.1, 355934.2 6689900.4 34.1))
BATIMENT0000000303961844;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;16.0;20.1;36.2;38.1;21.1;Cadastre;A 1.0;POLYGON Z ((355945.9 6689895.2 36.2, 355944.7 6689895 36.2, 355944 6689896.3 36.2, 355943.3 6689895.4 36.2, 355942 6689894.8 36.2, 355941.5 6689894.2 36.2, 355941.4 6689894.4 36.2, 355934.2 6689900.4 36.2, 355938.5 6689905.7 36.2, 355946.7 6689898.6 36.2, 355950.8 6689901.6 36.2, 355952.3 6689900.1 36.2, 355953.3 6689899.2 36.2, 355954.9 6689897.7 36.2, 355956.2 6689893.9 36.2, 355950.8 6689890.9 36.2, 355949.3 6689890.1 36.2, 355949 6689890 36.2, 355945.9 6689895.2 36.2))
BATIMENT0000000303961742;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:04:17;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;18.3;26.0;32.4;18.9;Cadastre;;POLYGON Z ((355994.8 6689789.1 26, 355994.3 6689789.6 26, 355993.8 6689790 26, 355993.3 6689790.4 26, 355992.7 6689790.7 26, 355992.1 6689791 26, 355991.5 6689791.3 26, 355990.9 6689791.4 26, 355990.2 6689791.6 26, 355989.6 6689791.6 26, 355988.9 6689791.7 26, 355988.3 6689791.6 26, 355987.6 6689791.5 26, 355987 6689791.4 26, 355986.4 6689791.2 26, 355985.7 6689790.9 26, 355985.2 6689790.6 26, 355982.9 6689791.4 26, 355980.8 6689795.8 26, 355984.3 6689797.9 26, 355988.5 6689799.7 26, 355991.1 6689800.4 26, 355996.9 6689789.2 26, 355995.2 6689788.6 26, 355994.8 6689789.1 26))
BATIMENT0000000303961749;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.4;18.2;26.6;28.8;18.9;Cadastre;;POLYGON Z ((355991.9 6689806.6 26.6, 355994.1 6689801.8 26.6, 355991.1 6689800.4 26.6, 355988.5 6689799.7 26.6, 355985 6689807 26.6, 355983.9 6689806.6 26.6, 355981.5 6689811.6 26.6, 355982.8 6689812.2 26.6, 355976.7 6689824.9 26.6, 355981.7 6689827.3 26.6, 355991.9 6689806.6 26.6))
BATIMENT0000002011295553;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;23.1;18.2;;45.7;19.6;Imagerie aérienne;;POLYGON Z ((356022 6689827 41.3, 356015.2 6689823.5 40, 355993.7 6689812.5 40, 355980.7 6689838.6 40, 356002.8 6689848.9 40, 356010.7 6689833.1 40, 356017.3 6689836.4 41.3, 356022 6689827 41.3))
BATIMENT0000000303962375;Indifférenciée;Annexe;;Oui;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.5;19.2;22.7;25.1;20.0;Cadastre;A 0.1;POLYGON Z ((356033.4 6689878.8 22.7, 356031 6689882.8 22.7, 356054.6 6689896.1 22.7, 356057.3 6689891.2 22.7, 356033.4 6689878.8 22.7))
BATIMENT0000000303961828;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;88.0;4.0;00;00;14.6;19.5;34.2;38.1;20.6;Cadastre;A 0.7;POLYGON Z ((356067.8 6689896.7 34.2, 356057.3 6689891.2 34.2, 356054.6 6689896.1 34.2, 356043.9 6689914.7 34.2, 356020.6 6689901.9 34.2, 356031 6689882.8 34.2, 356033.4 6689878.8 34.2, 356033.8 6689878 34.2, 356024 6689872.6 34.2, 356014.4 6689889.6 34.2, 356008.3 6689886.3 34.2, 355997.6 6689905.2 34.2, 356018.4 6689916.5 34.2, 356017.4 6689918.7 34.2, 356020.9 6689920.7 34.2, 356021.9 6689919 34.2, 356026.9 6689921.6 34.2, 356027.2 6689921 34.2, 356028.4 6689921.7 34.2, 356029.3 6689920.1 34.2, 356039.3 6689925.6 34.2, 356034.2 6689934.5 34.2, 356029 6689931.8 34.2, 356031.8 6689927 34.2, 356024.9 6689923.2 34.2, 356024.2 6689924.4 34.2, 356022.9 6689923.8 34.2, 356019.7 6689928.7 34.2, 356024.7 6689933.3 34.2, 356036.1 6689943.8 34.2, 356038.9 6689946.4 34.2, 356067.8 6689896.7 34.2))
BATIMENT0000000303961832;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;00;00;6.9;21.0;27.9;;;Cadastre;A 1.0;POLYGON Z ((356000.8 6689912.6 27.9, 356001.4 6689911.8 27.9, 355996.5 6689907.2 27.9, 355996.1 6689907.1 27.9, 355992.9 6689912.9 27.9, 355992.7 6689913.3 27.9, 355992.9 6689913.5 27.9, 355989.7 6689917.9 27.9, 355990.7 6689918.6 27.9, 355994.2 6689921.5 27.9, 356000.8 6689912.6 27.9))
BATIMENT0000000303961829;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.4;20.1;26.5;31.0;20.5;Cadastre;;POLYGON Z ((356004.1 6689920.6 26.5, 356007.5 6689917.5 26.5, 356001.4 6689911.8 26.5, 356000.8 6689912.6 26.5, 356002 6689913.8 26.5, 355999.3 6689917.3 26.5, 356003.7 6689921.1 26.5, 356004.1 6689920.6 26.5))
BATIMENT0000000303962374;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.6;20.1;26.7;26.7;20.4;Cadastre;;POLYGON Z ((356007.5 6689917.5 26.7, 356004.1 6689920.6 26.7, 356006.4 6689922.7 26.7, 356006.6 6689922.9 26.7, 356007.2 6689923.4 26.7, 356013.6 6689929.2 26.7, 356016.6 6689925.8 26.7, 356015.1 6689924.4 26.7, 356007.5 6689917.5 26.7))
BATIMENT0000000303962379;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;20.0;23.7;25.7;20.2;Cadastre;;POLYGON Z ((356020.3 6689925 23.7, 356017 6689922.1 23.7, 356015.1 6689924.4 23.7, 356016.6 6689925.8 23.7, 356017.8 6689927 23.7, 356018.3 6689927.4 23.7, 356020.3 6689925 23.7))
BATIMENT0000000303962372;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.3;20.2;27.5;29.2;20.3;Cadastre;;POLYGON Z ((356018.3 6689927.4 27.5, 356017.8 6689927 27.5, 356016.9 6689927.2 27.5, 356016.8 6689928.1 27.5, 356017.4 6689928.9 27.5, 356018.3 6689928.8 27.5, 356019.4 6689929.6 27.5, 356011.1 6689936.4 27.5, 356010.1 6689937.2 27.5, 356014.6 6689941.3 27.5, 356024.7 6689933.3 27.5, 356019.7 6689928.7 27.5, 356018.3 6689927.4 27.5))
BATIMENT0000000303961846;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;21.0;28.1;36.5;21.3;Cadastre;;POLYGON Z ((355961.3 6689903.8 28.1, 355962.7 6689902.5 28.1, 355964.9 6689898.5 28.1, 355956.2 6689893.9 28.1, 355954.9 6689897.7 28.1, 355953.3 6689899.2 28.1, 355961.3 6689903.8 28.1))
BATIMENT0000000303961850;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;12.0;21.0;33.0;37.7;21.1;Cadastre;A 1.0;POLYGON Z ((355942.2 6689910.2 33, 355950.8 6689901.6 33, 355946.7 6689898.6 33, 355938.5 6689905.7 33, 355942.2 6689910.2 33))
BATIMENT0000000303961802;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.8;20.1;34.0;36.5;22.3;Cadastre;A 1.0;POLYGON Z ((355910.6 6689908 34, 355908.5 6689905.6 34, 355912.9 6689902.4 34, 355914.8 6689904.9 34, 355922.4 6689899.6 34, 355919 6689895.3 34, 355898.4 6689910.1 34, 355901.6 6689914.3 34, 355910.6 6689908 34))
BATIMENT0000000303961845;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;00;00;6.6;20.5;27.2;30.2;21.4;Cadastre;A 0.5;POLYGON Z ((355973.7 6689908.8 27.2, 355972 6689912.8 27.2, 355975.9 6689915.6 27.2, 355981.4 6689907.6 27.2, 355981.3 6689907.5 27.2, 355964.9 6689898.5 27.2, 355962.7 6689902.5 27.2, 355973.7 6689908.8 27.2))
BATIMENT0000000303961805;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;21.7;32.7;34.0;22.3;Cadastre;;POLYGON Z ((355913 6689909.4 32.7, 355915.6 6689907.4 32.7, 355914.1 6689905.4 32.7, 355911.4 6689907.3 32.7, 355913 6689909.4 32.7))
BATIMENT0000000303961849;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;14.1;21.1;35.2;35.7;21.2;Cadastre;A 1.0;POLYGON Z ((355945.4 6689914.1 35.2, 355952.3 6689905.8 35.2, 355953.8 6689904.1 35.2, 355950.8 6689901.6 35.2, 355942.2 6689910.2 35.2, 355945.4 6689914.1 35.2))
BATIMENT0000000303961780;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;14;20;10.1;21.4;31.5;36.0;21.8;Cadastre;A 1.0;POLYGON Z ((355932.5 6689911.7 31.5, 355927.2 6689905.4 31.5, 355915.1 6689914.5 31.5, 355917.5 6689917.5 31.5, 355918.1 6689917.2 31.5, 355919.5 6689918.8 31.5, 355922.7 6689916.3 31.5, 355924.4 6689918.1 31.5, 355932.5 6689911.7 31.5))
BATIMENT0000000303961853;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;21.2;28.2;32.7;21.5;Cadastre;;POLYGON Z ((355962.6 6689914 28.2, 355964.1 6689915.2 28.2, 355966.3 6689912 28.2, 355965.5 6689911.2 28.2, 355964.3 6689911 28.2, 355962.6 6689914 28.2))
BATIMENT0000000303961851;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;13.2;21.0;34.2;38.4;21.7;Cadastre;A 1.0;POLYGON Z ((355955.1 6689926.3 34.2, 355960.7 6689921.7 34.2, 355966.7 6689928.7 34.2, 355974.2 6689918.1 34.2, 355967.4 6689913.2 34.2, 355967.6 6689912.8 34.2, 355965 6689916.5 34.2, 355961.3 6689914.2 34.2, 355963.4 6689910.2 34.2, 355959.8 6689905.8 34.2, 355959 6689906.7 34.2, 355955 6689904.4 34.2, 355955.7 6689902.9 34.2, 355952.3 6689900.1 34.2, 355950.8 6689901.6 34.2, 355953.8 6689904.1 34.2, 355952.3 6689905.8 34.2, 355945.4 6689914.1 34.2, 355955.1 6689926.3 34.2))
BATIMENT0000000303961777;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;13.3;19.7;33.0;36.2;22.3;Cadastre;C 0.6;POLYGON Z ((355914.1 6689905.4 33, 355915.6 6689907.4 33, 355917.1 6689909.4 33, 355914.3 6689911.4 33, 355913 6689909.4 33, 355911.4 6689907.3 33, 355910.6 6689908 33, 355901.6 6689914.3 33, 355899.7 6689915.4 33, 355895.8 6689912.1 33, 355894.4 6689910.6 33, 355894.2 6689910.9 33, 355892.1 6689915.7 33, 355898.1 6689921.3 33, 355897.5 6689922.1 33, 355895.5 6689920.3 33, 355893.6 6689921.9 33, 355895.5 6689923.9 33, 355893.8 6689925.4 33, 355896.8 6689929.4 33, 355897.6 6689928.7 33, 355899.2 6689927.2 33, 355905.5 6689921.7 33, 355915.1 6689914.5 33, 355927.2 6689905.4 33, 355922.4 6689899.6 33, 355914.8 6689904.9 33, 355914.1 6689905.4 33), (355907.6 6689913.9 33, 355908.4 6689914.6 33, 355909.4 6689915.8 33, 355908.3 6689916.7 33, 355907.4 6689915.5 33, 355903.4 6689918.9 33, 355900.5 6689916.5 33, 355902.4 6689915.4 33, 355903.7 6689916.9 33, 355907.6 6689913.9 33))
BATIMENT0000000303961810;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;15;40;11.9;19.1;31.0;33.7;22.3;Cadastre;A 1.0;POLYGON Z ((355898.7 6689901.8 31, 355896 6689907.1 31, 355898.1 6689909.9 31, 355898.4 6689910.1 31, 355919 6689895.3 31, 355915.4 6689890.9 31, 355898.7 6689901.8 31))
BATIMENT0000000303961790;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1760-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;14.9;18.3;33.2;35.7;19.5;Cadastre;A 1.0;POLYGON Z ((355895.3 6689900.4 33.2, 355880.8 6689892.9 33.2, 355869.5 6689915.8 33.2, 355884.2 6689923 33.2, 355885.2 6689920.7 33.2, 355878.4 6689917.5 33.2, 355879.7 6689915.2 33.2, 355880.3 6689915.6 33.2, 355880.9 6689915.4 33.2, 355881.3 6689914.5 33.2, 355886.8 6689917.3 33.2, 355891.2 6689908.9 33.2, 355885.7 6689906 33.2, 355886.1 6689904.8 33.2, 355885.7 6689904.3 33.2, 355885 6689903.9 33.2, 355886.3 6689901.6 33.2, 355892.9 6689905.2 33.2, 355895.3 6689900.4 33.2))
BATIMENT0000000303961776;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;00;00;6.6;18.5;25.1;30.5;20.4;Cadastre;C 0.3;POLYGON Z ((355893.1 6689927.3 25.1, 355892.8 6689924.1 25.1, 355887.9 6689919.4 25.1, 355886.6 6689920.7 25.1, 355885.2 6689920.7 25.1, 355884.2 6689923 25.1, 355891.3 6689930 25.1, 355893.1 6689927.3 25.1))
BATIMENT0000000303961797;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.6;21.5;33.1;33.5;21.5;Cadastre;;POLYGON Z ((355897.6 6689928.7 33.1, 355898.7 6689929.9 33.1, 355900.3 6689928.4 33.1, 355899.2 6689927.2 33.1, 355897.6 6689928.7 33.1))
BATIMENT0000000303961798;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.3;21.5;33.8;;;Cadastre;;POLYGON Z ((355903.5 6689932.2 33.8, 355901 6689929.1 33.8, 355899.3 6689930.5 33.8, 355901.8 6689933.6 33.8, 355903.5 6689932.2 33.8))
BATIMENT0000000303961801;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;12.1;21.5;33.6;35.1;21.5;Cadastre;B 0.6;POLYGON Z ((355896.8 6689929.4 33.6, 355894.1 6689931.4 33.6, 355895.8 6689933.5 33.6, 355898.9 6689937 33.6, 355902.3 6689934.2 33.6, 355901.8 6689933.6 33.6, 355899.3 6689930.5 33.6, 355898.7 6689929.9 33.6, 355897.6 6689928.7 33.6, 355896.8 6689929.4 33.6))
BATIMENT0000000303961799;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.3;19.3;28.7;34.9;21.4;Cadastre;;POLYGON Z ((355890.8 6689934.3 28.7, 355892.5 6689936.4 28.7, 355895.8 6689933.5 28.7, 355894.1 6689931.4 28.7, 355890.8 6689934.3 28.7))
BATIMENT0000000303961768;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;16;20;11.4;18.2;29.6;31.5;21.2;Cadastre;B 0.5;POLYGON Z ((355886.8 6689937.9 29.6, 355886.1 6689938.6 29.6, 355890.5 6689943.9 29.6, 355891.2 6689944.7 29.6, 355894.9 6689941.7 29.6, 355896 6689940.9 29.6, 355892.5 6689936.4 29.6, 355890.8 6689934.3 29.6, 355886.8 6689937.9 29.6))
BATIMENT0000000303961800;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;19.7;25.2;30.0;21.3;Cadastre;;POLYGON Z ((355902.1 6689938.5 25.2, 355900.8 6689937 25.2, 355896 6689940.9 25.2, 355894.9 6689941.7 25.2, 355896.2 6689943.2 25.2, 355902.1 6689938.5 25.2))
BATIMENT0000000303961766;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;4.0;10;20;11.7;17.7;29.5;36.5;20.1;Cadastre;A 1.0;POLYGON Z ((355886.1 6689938.6 29.5, 355886.8 6689937.9 29.5, 355884.9 6689936.2 29.5, 355891.3 6689930 29.5, 355884.2 6689923 29.5, 355869.5 6689915.8 29.5, 355859.6 6689936 29.5, 355877.5 6689954.5 29.5, 355878.3 6689954.2 29.5, 355879.6 6689954.1 29.5, 355882 6689956.3 29.5, 355882.5 6689957.8 29.5, 355881.6 6689958.7 29.5, 355888.5 6689965.8 29.5, 355894.5 6689960.3 29.5, 355899.8 6689955.3 29.5, 355896 6689950.6 29.5, 355895.3 6689949.9 29.5, 355888.3 6689956.5 29.5, 355883 6689951 29.5, 355886.7 6689947.2 29.5, 355879.8 6689940.8 29.5, 355873.6 6689937.8 29.5, 355878.5 6689927.2 29.5, 355885.5 6689930.9 29.5, 355883.2 6689935.2 29.5, 355882.5 6689935 29.5, 355880.6 6689938.6 29.5, 355888.2 6689946.2 29.5, 355890.5 6689943.9 29.5, 355886.1 6689938.6 29.5))
BATIMENT0000000303961804;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.9;21.3;31.2;33.0;21.8;Cadastre;;POLYGON Z ((355908.3 6689916.7 31.2, 355909.4 6689915.8 31.2, 355908.4 6689914.6 31.2, 355907.4 6689915.5 31.2, 355908.3 6689916.7 31.2))
BATIMENT0000000303961786;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;12;20;15.4;20.7;36.2;39.3;21.5;Cadastre;C 0.6;POLYGON Z ((355936.6 6689916.7 36.2, 355932.5 6689911.7 36.2, 355924.4 6689918.1 36.2, 355921.8 6689920.3 36.2, 355924.9 6689924 36.2, 355923.3 6689925.4 36.2, 355924.4 6689926.9 36.2, 355936.6 6689916.7 36.2))
BATIMENT0000000303961771;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;16;20;11.2;21.5;32.7;34.6;21.7;Cadastre;B 0.5;POLYGON Z ((355901 6689929.1 32.7, 355903.5 6689932.2 32.7, 355904 6689932.8 32.7, 355907.7 6689929.8 32.7, 355903.4 6689925 32.7, 355904.4 6689924.1 32.7, 355905.4 6689925.3 32.7, 355906.7 6689924.4 32.7, 355910.9 6689929 32.7, 355917.2 6689923.9 32.7, 355918.7 6689922.8 32.7, 355918 6689922.1 32.7, 355917 6689923.1 32.7, 355916.5 6689922.7 32.7, 355915.1 6689923.9 32.7, 355913.4 6689922 32.7, 355917.7 6689918.4 32.7, 355917.3 6689918 32.7, 355917.5 6689917.5 32.7, 355915.1 6689914.5 32.7, 355905.5 6689921.7 32.7, 355899.2 6689927.2 32.7, 355900.3 6689928.4 32.7, 355901 6689929.1 32.7))
BATIMENT0000000303961833;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;2.0;00;00;7.3;20.7;28.0;31.0;21.7;Cadastre;A 1.0;POLYGON Z ((355983.1 6689936.5 28, 355994.2 6689921.5 28, 355990.6 6689918.8 28, 355990.7 6689918.6 28, 355989.7 6689917.9 28, 355992.9 6689913.5 28, 355992.7 6689913.3 28, 355992.9 6689912.9 28, 355988.5 6689910.5 28, 355973.1 6689931.9 28, 355980.9 6689936.8 28, 355982 6689937.7 28, 355983.1 6689936.5 28))
BATIMENT0000000303961852;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;13.9;21.0;34.9;37.5;21.7;Cadastre;A 1.0;POLYGON Z ((355961.4 6689933.9 34.9, 355966.7 6689928.7 34.9, 355960.7 6689921.7 34.9, 355955.1 6689926.3 34.9, 355961.4 6689933.9 34.9))
BATIMENT0000000303961770;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;10.1;21.5;31.6;38.5;21.5;Cadastre;C 0.9;POLYGON Z ((355940.6 6689921.7 31.6, 355936.6 6689916.7 31.6, 355924.4 6689926.9 31.6, 355921.6 6689929.2 31.6, 355909.7 6689939.1 31.6, 355911.9 6689941.9 31.6, 355914.3 6689939 31.6, 355915 6689939.6 31.6, 355929.2 6689928.1 31.6, 355928 6689926.9 31.6, 355929 6689925.9 31.6, 355931.8 6689929 31.6, 355940.6 6689921.7 31.6))
BATIMENT0000000303961769;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;12;20;12.2;21.5;33.7;34.7;21.5;Cadastre;C 0.4;POLYGON Z ((355909.7 6689939.1 33.7, 355921.6 6689929.2 33.7, 355917.2 6689923.9 33.7, 355910.9 6689929 33.7, 355902.6 6689935.6 33.7, 355907.3 6689941.1 33.7, 355909.7 6689939.1 33.7))
BATIMENT0000000303961767;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;5.8;21.1;27.0;38.0;21.6;Cadastre;A 0.5;POLYGON Z ((355913.7 6689943.8 27, 355908.1 6689948.6 27, 355910.9 6689952.8 27, 355908.8 6689954.7 27, 355910.5 6689956.5 27, 355913.5 6689953.8 27, 355911.9 6689951.8 27, 355917.8 6689946.9 27, 355915.3 6689944.2 27, 355918.3 6689941.7 27, 355919.6 6689942.9 27, 355921.6 6689941 27, 355926.3 6689946.6 27, 355930.2 6689943 27, 355946.5 6689928.9 27, 355940.6 6689921.7 27, 355931.8 6689929 27, 355913.7 6689943.8 27), (355931.3 6689933.9 27, 355931.6 6689934.3 27, 355931.4 6689934.3 27, 355932.4 6689935.4 27, 355930.6 6689935.5 27, 355929.7 6689936.5 27, 355928.8 6689935.8 27, 355931.3 6689933.9 27))
BATIMENT0000000303961839;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;10.9;21.0;31.9;34.7;21.8;Cadastre;A 1.0;POLYGON Z ((355970.5 6689936.1 31.9, 355968.1 6689940.1 31.9, 355973.3 6689946.2 31.9, 355973.5 6689945.7 31.9, 355977.5 6689940.8 31.9, 355970.5 6689936.1 31.9))
BATIMENT0000000303961774;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;6.8;21.1;28.0;38.2;21.6;Cadastre;C 0.6;POLYGON Z ((355931.2 6689944.4 28, 355924.8 6689950.6 28, 355924.4 6689950.3 28, 355920.9 6689953.4 28, 355921.1 6689954.8 28, 355920.4 6689955.5 28, 355919.9 6689955 28, 355919.2 6689954.9 28, 355914.4 6689959.1 28, 355917.8 6689962 28, 355922.1 6689957.6 28, 355928.3 6689951 28, 355928.1 6689950.6 28, 355949.4 6689932.3 28, 355946.5 6689928.9 28, 355930.2 6689943 28, 355931.2 6689944.4 28))
BATIMENT0000000303961840;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;20.1;23.4;26.2;21.1;Cadastre;;POLYGON Z ((355984.6 6689939.8 23.4, 355989.3 6689942.4 23.4, 355996.1 6689935.3 23.4, 356002 6689929.1 23.4, 355998.1 6689926 23.4, 355984.6 6689939.8 23.4))
BATIMENT0000000303962373;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;10;20;5.1;20.1;25.2;32.4;20.7;Cadastre;C 0.2;POLYGON Z ((356003.5 6689951.6 25.2, 356004.4 6689952.2 25.2, 356006.9 6689952.2 25.2, 356021.4 6689940.6 25.2, 356030.5 6689948.7 25.2, 356036.1 6689943.8 25.2, 356024.7 6689933.3 25.2, 356014.6 6689941.3 25.2, 356011.4 6689944 25.2, 356001.9 6689951.8 25.2, 356003.5 6689951.6 25.2))
BATIMENT0000000303961826;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;5.9;21.0;26.9;27.7;21.0;Cadastre;A 0.2;POLYGON Z ((356007.8 6689939 26.9, 355999.6 6689945.7 26.9, 355997.9 6689947.1 26.9, 355997 6689948 26.9, 356001.9 6689951.8 26.9, 356011.4 6689944 26.9, 356014.6 6689941.3 26.9, 356010.1 6689937.2 26.9, 356007.8 6689939 26.9))
BATIMENT0000000303961827;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;20.4;22.7;25.0;21.1;Cadastre;;POLYGON Z ((355994.6 6689943.4 22.7, 355993.4 6689942.6 22.7, 355992.3 6689944.4 22.7, 355994.6 6689946.2 22.7, 355995.5 6689946.8 22.7, 355996.2 6689946.2 22.7, 355996.6 6689945.2 22.7, 355995.7 6689944.7 22.7, 355995.7 6689944 22.7, 355994.6 6689943.4 22.7))
BATIMENT0000000303961825;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;20.4;24.2;25.2;21.0;Cadastre;;POLYGON Z ((355997 6689948 24.2, 355997.9 6689947.1 24.2, 355999.6 6689945.7 24.2, 355998.5 6689944.2 24.2, 355996.2 6689946.2 24.2, 355995.5 6689946.8 24.2, 355997 6689948 24.2))
BATIMENT0000000303961837;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;14.0;20.9;35.0;37.1;21.5;Cadastre;A 1.0;POLYGON Z ((355990.4 6689946.2 35, 355985.2 6689944.3 35, 355978.6 6689952 35, 355983.1 6689957.6 35, 355991.6 6689947 35, 355990.4 6689946.2 35))
BATIMENT0000002011292308;Indifférenciée;Annexe;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;2.0;00;00;10.4;20.5;;;;Imagerie aérienne;C 0.4;POLYGON Z ((356049.9 6689956.6 27.3, 356050.2 6689956.9 27.3, 356053.2 6689957.8 30.9, 356055.5 6689955.9 23.2, 356053.5 6689953.9 24.3, 356055.1 6689952.3 24.3, 356048.8 6689946.5 24.9, 356043.9 6689951.1 27.3, 356049.9 6689956.6 27.3))
BATIMENT0000000303961836;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;13.8;20.7;34.5;37.0;21.6;Cadastre;A 1.0;POLYGON Z ((355993.1 6689948 34.5, 355991.6 6689947 34.5, 355983.1 6689957.6 34.5, 355982.6 6689958.2 34.5, 355984.8 6689961 34.5, 355985.2 6689960.5 34.5, 355994.9 6689949.3 34.5, 355993.1 6689948 34.5))
BATIMENT0000000303962377;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;21.0;25.7;26.5;21.1;Cadastre;;POLYGON Z ((356023.4 6689948 25.7, 356011 6689958.8 25.7, 356014.4 6689962.8 25.7, 356015.2 6689962.3 25.7, 356027 6689951.7 25.7, 356023.4 6689948 25.7))
BATIMENT0000000303961835;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;14.3;20.6;35.0;38.7;21.4;Cadastre;A 1.0;POLYGON Z ((355999.9 6689953.3 35, 355994.9 6689949.3 35, 355985.2 6689960.5 35, 355989.6 6689965.4 35, 356000.2 6689953.8 35, 355999.9 6689953.3 35))
BATIMENT0000000302930694;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;6.0;;;17.3;11.6;28.9;32.1;14.4;Cadastre;A 1.0;POLYGON Z ((355620.7 6689636.8 28.9, 355621.5 6689627 28.9, 355617 6689626.4 28.9, 355608.7 6689625.4 28.9, 355607.1 6689624 28.9, 355604 6689627.6 28.9, 355599.1 6689623.4 28.9, 355595.5 6689623.1 28.9, 355595.2 6689658 28.9, 355597.7 6689661 28.9, 355618.5 6689663.5 28.9, 355619.3 6689663 28.9, 355619.4 6689663.3 28.9, 355624.7 6689660.3 28.9, 355624.9 6689660 28.9, 355625.3 6689659.7 28.9, 355633.2 6689644.2 28.9, 355624 6689643 28.9, 355624.3 6689639.6 28.9, 355623.7 6689639 28.9, 355620.7 6689636.8 28.9))
BATIMENT0000000302931051;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;11.7;11.3;23.1;28.5;12.4;Cadastre;A 1.0;POLYGON Z ((355563.7 6689633.5 23.1, 355559.2 6689633.7 23.1, 355559.4 6689638.2 23.1, 355559.9 6689638.5 23.1, 355564.4 6689641.9 23.1, 355568.8 6689645 23.1, 355573.4 6689648.4 23.1, 355575.5 6689650 23.1, 355583 6689655.6 23.1, 355581.5 6689635.8 23.1, 355581.2 6689632.6 23.1, 355575.6 6689633 23.1, 355563.7 6689633.5 23.1))
BATIMENT0000000302931052;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;11.6;28.0;30.2;12.5;Cadastre;;POLYGON Z ((355580.2 6689658.8 28, 355583.1 6689656.1 28, 355583 6689655.6 28, 355575.5 6689650 28, 355575.2 6689651.3 28, 355572.9 6689651 28, 355573.4 6689648.4 28, 355568.8 6689645 28, 355561.7 6689656.5 28, 355580.2 6689658.8 28))
BATIMENT0000000302931662;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;30;20;14.8;13.8;28.7;36.4;16.7;Cadastre;A 1.0;POLYGON Z ((355650.3 6689643.1 28.7, 355650.5 6689643.3 28.7, 355649.2 6689645.9 28.7, 355648.9 6689645.8 28.7, 355645.9 6689652 28.7, 355646.1 6689652.1 28.7, 355644.7 6689654.7 28.7, 355644.4 6689654.6 28.7, 355642.4 6689658.9 28.7, 355642.4 6689659.6 28.7, 355642 6689659.6 28.7, 355642.2 6689659.9 28.7, 355641.7 6689660.5 28.7, 355641.5 6689661.1 28.7, 355641.7 6689661.7 28.7, 355641.4 6689662.1 28.7, 355643.5 6689666.1 28.7, 355644 6689666.1 28.7, 355644.6 6689666.4 28.7, 355645.1 6689666.6 28.7, 355645.7 6689666.5 28.7, 355646 6689666.7 28.7, 355646.5 6689666.5 28.7, 355648.1 6689666.8 28.7, 355648.2 6689667 28.7, 355671.4 6689669.9 28.7, 355673.2 6689658.1 28.7, 355673.6 6689658.2 28.7, 355675.5 6689644 28.7, 355666.3 6689642.8 28.7, 355663.1 6689642.4 28.7, 355659.3 6689641.8 28.7, 355652.6 6689638.6 28.7, 355650.3 6689643.1 28.7))
BATIMENT0000000302931519;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;7.0;;;21.5;13.2;34.7;38.4;14.0;Cadastre;A 1.0;POLYGON Z ((355595 6689703.3 34.7, 355603 6689703.2 34.7, 355613.5 6689682.7 34.7, 355610.7 6689677.4 34.7, 355595.8 6689675.6 34.7, 355592.9 6689678.5 34.7, 355595 6689703.3 34.7), (355601.7 6689683.3 34.7, 355602.5 6689683.5 34.7, 355603.5 6689683.7 34.7, 355604.3 6689685.4 34.7, 355602.2 6689689.6 34.7, 355600.5 6689689.2 34.7, 355600.1 6689686.8 34.7, 355601.2 6689686.6 34.7, 355600.7 6689684.9 34.7, 355601.7 6689683.3 34.7))
BATIMENT0000000302931192;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;14.9;11.5;26.4;30.3;13.1;Cadastre;A 1.0;POLYGON Z ((355575.3 6689705.5 26.4, 355583.7 6689705 26.4, 355583.6 6689703.1 26.4, 355575.2 6689703.2 26.4, 355575.3 6689697.4 26.4, 355586.4 6689697 26.4, 355585.7 6689687.4 26.4, 355581.3 6689687.3 26.4, 355581.1 6689684.8 26.4, 355577.3 6689684.5 26.4, 355574.3 6689684.1 26.4, 355573.4 6689683.7 26.4, 355573.6 6689690.9 26.4, 355566.4 6689689.2 26.4, 355567.1 6689688.4 26.4, 355569.4 6689684.7 26.4, 355570.9 6689685.2 26.4, 355571.6 6689683.2 26.4, 355568.9 6689682.2 26.4, 355567.8 6689684.4 26.4, 355564.8 6689683.1 26.4, 355560.7 6689692.1 26.4, 355565.3 6689694.5 26.4, 355571.2 6689696.6 26.4, 355569.6 6689704.5 26.4, 355575.3 6689705.5 26.4))
BATIMENT0000000302930888;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;15.7;14.1;29.8;34.1;15.5;Cadastre;A 1.0;POLYGON Z ((355640.9 6689689.4 29.8, 355640.7 6689688.5 29.8, 355640.4 6689688.1 29.8, 355640.2 6689688 29.8, 355640 6689687.9 29.8, 355639.8 6689688 29.8, 355639.6 6689688 29.8, 355639.4 6689688.1 29.8, 355633 6689690.9 29.8, 355632.8 6689691.3 29.8, 355632.6 6689691.6 29.8, 355632.5 6689691.7 29.8, 355632.4 6689691.9 29.8, 355632.4 6689692.1 29.8, 355632.5 6689692.3 29.8, 355632.5 6689692.5 29.8, 355632.6 6689692.7 29.8, 355632.7 6689692.9 29.8, 355627.3 6689695.9 29.8, 355624.3 6689694.2 29.8, 355621.3 6689700.5 29.8, 355622.8 6689703.2 29.8, 355660 6689702.5 29.8, 355660 6689689 29.8, 355657.3 6689688.8 29.8, 355640.9 6689689.4 29.8))
BATIMENT0000000302931191;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;13.9;11.5;25.4;29.7;13.3;Cadastre;A 1.0;POLYGON Z ((355586.7 6689704.9 25.4, 355587 6689704.5 25.4, 355586.4 6689697 25.4, 355575.3 6689697.4 25.4, 355575.2 6689703.2 25.4, 355583.6 6689703.1 25.4, 355583.7 6689705 25.4, 355586.7 6689704.9 25.4))
BATIMENT0000000302930664;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;20;20;17.6;13.7;31.3;35.7;14.6;Cadastre;A 1.0;POLYGON Z ((355628.8 6689711.9 31.3, 355618.6 6689712.1 31.3, 355618.5 6689719.9 31.3, 355619 6689728.7 31.3, 355623.3 6689728.6 31.3, 355628.9 6689728.3 31.3, 355628.8 6689711.9 31.3))
BATIMENT0000000302930662;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;21.2;14.4;35.7;38.2;16.2;Cadastre;A 1.0;POLYGON Z ((355628.9 6689728.3 35.7, 355629.1 6689731 35.7, 355630.4 6689731.2 35.7, 355635.1 6689731 35.7, 355635.1 6689733.4 35.7, 355630.6 6689733.8 35.7, 355630.8 6689737.3 35.7, 355636.7 6689737 35.7, 355636.9 6689739.4 35.7, 355640 6689739.3 35.7, 355640.4 6689742.3 35.7, 355637.1 6689742.5 35.7, 355637.2 6689744.7 35.7, 355637.8 6689752.5 35.7, 355647 6689752.1 35.7, 355648.2 6689752 35.7, 355648.2 6689751.6 35.7, 355647.3 6689711.6 35.7, 355628.8 6689711.9 35.7, 355628.9 6689728.3 35.7), (355639.3 6689728.9 35.7, 355637 6689728.9 35.7, 355637.1 6689726.5 35.7, 355639.4 6689726.4 35.7, 355639.3 6689728.9 35.7), (355638.7 6689723 35.7, 355633.8 6689723.3 35.7, 355633.7 6689720.7 35.7, 355638.7 6689720.5 35.7, 355638.7 6689723 35.7), (355635.1 6689727.2 35.7, 355635.1 6689728.5 35.7, 355633.9 6689728.6 35.7, 355633.9 6689727.2 35.7, 355635.1 6689727.2 35.7))
BATIMENT0000000302931666;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;6.0;10;20;16.6;15.9;32.5;35.4;16.6;Cadastre;A 1.0;POLYGON Z ((355673.6 6689658.2 32.5, 355673.2 6689658.1 32.5, 355671.4 6689669.9 32.5, 355687.3 6689672 32.5, 355689.6 6689670.3 32.5, 355690.9 6689660.9 32.5, 355691.5 6689661 32.5, 355693.2 6689646 32.5, 355693 6689646 32.5, 355692.8 6689646.2 32.5, 355685 6689645.1 32.5, 355684.5 6689649.8 32.5, 355680.7 6689649.4 32.5, 355681.1 6689644.7 32.5, 355675.5 6689644 32.5, 355673.6 6689658.2 32.5), (355678.4 6689658.8 32.5, 355683 6689659.6 32.5, 355682.5 6689662.8 32.5, 355677.9 6689662.1 32.5, 355678.4 6689658.8 32.5))
BATIMENT0000000302931308;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1869-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;20.5;15.7;36.2;38.4;17.0;Cadastre;A 1.0;POLYGON Z ((355699.3 6689659.6 36.2, 355697.7 6689671.3 36.2, 355699.6 6689673.5 36.2, 355719.6 6689676 36.2, 355722.2 6689659.2 36.2, 355715.6 6689651.5 36.2, 355704.9 6689660.3 36.2, 355699.3 6689659.6 36.2), (355708.5 6689660.3 36.2, 355713.4 6689661 36.2, 355713.2 6689663.1 36.2, 355711.3 6689662.8 36.2, 355709.9 6689663.8 36.2, 355707.8 6689663.5 36.2, 355707.8 6689662.3 36.2, 355708.2 6689661.9 36.2, 355708.5 6689660.3 36.2))
BATIMENT0000000302930887;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;14.6;17.2;20.2;15.0;Cadastre;;POLYGON Z ((355660.4 6689683.5 17.2, 355657.6 6689683.1 17.2, 355657.3 6689688.8 17.2, 355660 6689689 17.2, 355660.4 6689683.5 17.2))
BATIMENT0000000302930886;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;12;20;19.2;15.0;34.2;37.5;16.3;Cadastre;A 1.0;POLYGON Z ((355660 6689702.5 34.2, 355679.4 6689702.1 34.2, 355679.3 6689696.2 34.2, 355678.2 6689695.8 34.2, 355678.8 6689691.2 34.2, 355686.8 6689691.8 34.2, 355687.1 6689689 34.2, 355685.2 6689686.6 34.2, 355664.3 6689684.2 34.2, 355663.8 6689689.3 34.2, 355660 6689689 34.2, 355660 6689702.5 34.2))
BATIMENT0000000302930885;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;20;20;17.8;15.8;33.6;35.4;16.4;Cadastre;C 0.5;POLYGON Z ((355678.2 6689695.8 33.6, 355679.3 6689696.2 33.6, 355679.4 6689702.1 33.6, 355683.5 6689702.1 33.6, 355685.8 6689700.2 33.6, 355686.8 6689691.8 33.6, 355678.8 6689691.2 33.6, 355678.2 6689695.8 33.6))
BATIMENT0000000302931006;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;7.0;10;20;19.3;16.3;35.6;39.6;17.0;Cadastre;A 1.0;POLYGON Z ((355691.2 6689717.5 35.6, 355694 6689719 35.6, 355714.8 6689707.5 35.6, 355717.3 6689690.5 35.6, 355697.6 6689688.2 35.6, 355695.2 6689690.1 35.6, 355691.2 6689717.5 35.6), (355702.3 6689697.7 35.6, 355703.7 6689697.9 35.6, 355704.6 6689698.9 35.6, 355704.4 6689699.9 35.6, 355703.1 6689699.9 35.6, 355702.9 6689701.7 35.6, 355704.2 6689701.9 35.6, 355704 6689703.1 35.6, 355702.6 6689704.1 35.6, 355701.2 6689704 35.6, 355700.1 6689702.4 35.6, 355700.8 6689698.7 35.6, 355702.3 6689697.7 35.6))
BATIMENT0000000302931201;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;21.3;16.5;37.9;39.6;17.9;Cadastre;A 1.0;POLYGON Z ((355711.4 6689737.9 37.9, 355722.3 6689741 37.9, 355723.6 6689734.8 37.9, 355722.6 6689734.4 37.9, 355722.4 6689734.3 37.9, 355722.3 6689734.1 37.9, 355722.3 6689733.9 37.9, 355722.3 6689733.7 37.9, 355722.3 6689733.4 37.9, 355722.3 6689733.2 37.9, 355722.4 6689732.6 37.9, 355722.4 6689731.8 37.9, 355722.4 6689731.6 37.9, 355722.5 6689731.4 37.9, 355722.6 6689731.2 37.9, 355722.8 6689731.2 37.9, 355735.2 6689733.6 37.9, 355734.9 6689735.1 37.9, 355734.9 6689735.3 37.9, 355734.7 6689735.5 37.9, 355734.6 6689735.6 37.9, 355734.4 6689735.7 37.9, 355734.1 6689735.9 37.9, 355733.9 6689736 37.9, 355733.7 6689736 37.9, 355733.3 6689736.1 37.9, 355733.1 6689736.2 37.9, 355732.9 6689736.3 37.9, 355732.8 6689736.5 37.9, 355731.6 6689743.4 37.9, 355739 6689745.5 37.9, 355744.5 6689720.9 37.9, 355719.1 6689716.3 37.9, 355709.9 6689721.6 37.9, 355712.9 6689726.7 37.9, 355717.2 6689724.6 37.9, 355716.4 6689729 37.9, 355712.8 6689728.5 37.9, 355711.4 6689737.9 37.9))
BATIMENT0000000302931200;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;10;20;13.4;16.5;30.0;36.5;18.3;Cadastre;A 1.0;POLYGON Z ((355695 6689729.8 30, 355698.6 6689730.1 30, 355698.4 6689738.4 30, 355698.5 6689739.2 30, 355706.8 6689739.6 30, 355706.7 6689740.5 30, 355710.7 6689741.1 30, 355711.4 6689737.9 30, 355712.8 6689728.5 30, 355712.9 6689726.7 30, 355709.9 6689721.6 30, 355695 6689729.8 30))
BATIMENT0000000302931199;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;10.9;16.7;27.7;29.7;17.7;Cadastre;A 1.0;POLYGON Z ((355691.1 6689730.4 27.7, 355691.8 6689730.5 27.7, 355692 6689736.6 27.7, 355698.4 6689738.4 27.7, 355698.6 6689730.1 27.7, 355695 6689729.8 27.7, 355691.5 6689729.6 27.7, 355691.1 6689730.4 27.7))
BATIMENT0000000302930666;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;15;20;10.2;15.7;25.9;28.6;16.7;Cadastre;A 1.0;POLYGON Z ((355667.7 6689745.8 25.9, 355664.4 6689745.6 25.9, 355664.2 6689751.9 25.9, 355661.7 6689751.9 25.9, 355661.6 6689755.8 25.9, 355661.5 6689758.1 25.9, 355661.4 6689765.8 25.9, 355679.7 6689764.8 25.9, 355680.2 6689755.9 25.9, 355680.6 6689755.7 25.9, 355680.8 6689745.4 25.9, 355678.9 6689745.1 25.9, 355669.2 6689745 25.9, 355667.7 6689745.8 25.9))
BATIMENT0000000302931846;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;52.2;18.0;70.2;;;Cadastre;;POLYGON Z ((355794.2 6689714.3 70.2, 355795.9 6689705.9 70.2, 355813.4 6689709.4 70.2, 355816.3 6689695.6 70.2, 355799.3 6689691.8 70.2, 355799.3 6689683 70.2, 355795.6 6689682.6 70.2, 355792.9 6689681.9 70.2, 355789.7 6689681.5 70.2, 355788.6 6689683.1 70.2, 355787.8 6689686.4 70.2, 355786.8 6689692.2 70.2, 355785.3 6689700.3 70.2, 355784.3 6689706 70.2, 355783.6 6689708.9 70.2, 355782.9 6689712.1 70.2, 355794.2 6689714.3 70.2))
BATIMENT0000000302931848;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;30.0;18.0;48.0;;;Cadastre;;POLYGON Z ((355781.5 6689703.4 48, 355781.7 6689704 48, 355782.6 6689703.8 48, 355782.7 6689704.8 48, 355783.7 6689705 48, 355783.6 6689705.8 48, 355784.3 6689706 48, 355785.3 6689700.3 48, 355784.3 6689700 48, 355784.2 6689700.6 48, 355783.6 6689700.4 48, 355783.3 6689701.2 48, 355782 6689700.9 48, 355781.9 6689700.5 48, 355781.1 6689700.6 48, 355780.5 6689703.4 48, 355781.5 6689703.4 48))
BATIMENT0000000302931202;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;10;20;18.7;17.0;35.7;39.1;17.3;Cadastre;A 1.0;POLYGON Z ((355743.9 6689746.9 35.7, 355755 6689750.1 35.7, 355758 6689748.1 35.7, 355761.3 6689728.9 35.7, 355757.6 6689723.1 35.7, 355744.5 6689720.9 35.7, 355739 6689745.5 35.7, 355743.9 6689746.9 35.7), (355743.9 6689734.3 35.7, 355748.5 6689735.2 35.7, 355747.3 6689741.4 35.7, 355742.7 6689740.3 35.7, 355742.9 6689739 35.7, 355743.7 6689739.1 35.7, 355744.2 6689737.3 35.7, 355743.2 6689737 35.7, 355743.9 6689734.3 35.7))
BATIMENT0000000302931809;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;17.3;18.2;35.5;36.0;18.7;Cadastre;;POLYGON Z ((355812.3 6689742.6 35.5, 355817.9 6689749.4 35.5, 355818.6 6689748.8 35.5, 355813.1 6689742 35.5, 355812.3 6689742.6 35.5))
BATIMENT0000000302930512;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;10;20;16.0;18.0;34.0;37.4;18.5;Cadastre;A 1.0;POLYGON Z ((355781.7 6689763 34, 355788.6 6689755.1 34, 355787.2 6689754.1 34, 355787.4 6689753.6 34, 355794.9 6689747.6 34, 355784.2 6689734.7 34, 355781.6 6689734.7 34, 355769.6 6689755.6 34, 355781.7 6689763 34), (355783.8 6689750.2 34, 355786.2 6689753.2 34, 355781.4 6689758.9 34, 355779.3 6689757.3 34, 355781.4 6689753.8 34, 355782.4 6689753.8 34, 355782.7 6689753.6 34, 355782.7 6689753.5 34, 355782.8 6689753.4 34, 355782.9 6689753.2 34, 355782.9 6689753 34, 355783 6689752.9 34, 355783 6689752.8 34, 355783 6689752.7 34, 355782.9 6689752.5 34, 355782.9 6689752.3 34, 355782.8 6689752.1 34, 355782.7 6689752 34, 355782.6 6689751.9 34, 355782.5 6689751.8 34, 355782.3 6689751.7 34, 355783.8 6689750.2 34))
BATIMENT0000000302930513;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;12.6;17.6;30.2;36.2;18.6;Cadastre;A 1.0;POLYGON Z ((355787.4 6689753.6 30.2, 355787.2 6689754.1 30.2, 355788.6 6689755.1 30.2, 355781.7 6689763 30.2, 355782.6 6689763.5 30.2, 355784.3 6689765.3 30.2, 355780.3 6689768.7 30.2, 355781.7 6689770.2 30.2, 355784.5 6689773 30.2, 355803.2 6689758 30.2, 355794.9 6689747.6 30.2, 355787.4 6689753.6 30.2))
BATIMENT0000000302930511;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;11.5;16.8;28.4;31.6;18.1;Cadastre;A 1.0;POLYGON Z ((355759.2 6689773.1 28.4, 355775.4 6689780.8 28.4, 355781.7 6689770.2 28.4, 355780.3 6689768.7 28.4, 355784.3 6689765.3 28.4, 355782.6 6689763.5 28.4, 355781.7 6689763 28.4, 355769.6 6689755.6 28.4, 355759.2 6689773.1 28.4))
BATIMENT0000000302930509;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;18.9;18.1;37.0;39.9;18.8;Cadastre;A 1.0;POLYGON Z ((355802.1 6689777.8 37, 355803.6 6689776.7 37, 355812.5 6689769.3 37, 355803.2 6689758 37, 355784.5 6689773 37, 355790.4 6689778.9 37, 355795.5 6689784.2 37, 355797 6689784 37, 355797.9 6689781.3 37, 355796 6689779 37, 355793.6 6689776.2 37, 355791.2 6689773.5 37, 355795.5 6689769.8 37, 355802.1 6689777.8 37))
BATIMENT0000000302930510;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;00;00;14.0;17.9;31.9;35.0;18.5;Cadastre;A 1.0;POLYGON Z ((355775.4 6689780.8 31.9, 355792 6689788.8 31.9, 355795.5 6689784.2 31.9, 355790.4 6689778.9 31.9, 355784.5 6689773 31.9, 355781.7 6689770.2 31.9, 355775.4 6689780.8 31.9))
BATIMENT0000000302930508;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;17.6;18.0;35.6;39.5;19.1;Cadastre;A 1.0;POLYGON Z ((355795.5 6689784.2 35.6, 355792 6689788.8 35.6, 355800.7 6689793.1 35.6, 355810.2 6689797.5 35.6, 355811 6689795.9 35.6, 355810.5 6689795.7 35.6, 355819.4 6689777.6 35.6, 355812.5 6689769.3 35.6, 355803.6 6689776.7 35.6, 355806.2 6689779.5 35.6, 355806.5 6689781.7 35.6, 355804.7 6689784.9 35.6, 355803.7 6689784.3 35.6, 355802.7 6689784.4 35.6, 355801.5 6689785.2 35.6, 355800.9 6689785.1 35.6, 355800.2 6689785.7 35.6, 355797 6689784 35.6, 355795.5 6689784.2 35.6))
BATIMENT0000000302930715;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1680-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;9.0;18.1;27.2;30.2;19.0;Cadastre;A 1.0;POLYGON Z ((355704.4 6689753.8 27.2, 355703.8 6689763.6 27.2, 355703.6 6689767.4 27.2, 355708.6 6689767.7 27.2, 355709.1 6689757.4 27.2, 355710.8 6689757.8 27.2, 355711.8 6689756.8 27.2, 355711.9 6689755.6 27.2, 355716.7 6689757 27.2, 355717.2 6689749.6 27.2, 355704.7 6689746.4 27.2, 355704.4 6689753.8 27.2))
BATIMENT0000000302930712;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;9.7;16.2;26.0;32.0;17.3;Cadastre;A 1.0;POLYGON Z ((355685.4 6689750.6 26, 355684.6 6689764.6 26, 355684.5 6689773.1 26, 355687.1 6689773.4 26, 355688.5 6689773.5 26, 355690.8 6689742.8 26, 355690.8 6689742.6 26, 355686.5 6689741.4 26, 355685.4 6689750.6 26))
BATIMENT0000000302930721;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;10.0;17.4;27.5;30.8;18.8;Cadastre;A 1.0;POLYGON Z ((355716.7 6689757 27.5, 355718.1 6689757.1 27.5, 355721.7 6689757.8 27.5, 355720 6689762.8 27.5, 355718.3 6689762.8 27.5, 355718.1 6689767.2 27.5, 355722.8 6689768.4 27.5, 355722.9 6689769.5 27.5, 355724.8 6689769.6 27.5, 355725.5 6689765.6 27.5, 355725.6 6689764.5 27.5, 355724.6 6689764.3 27.5, 355725.2 6689759.9 27.5, 355727.7 6689760.4 27.5, 355729.2 6689753.2 27.5, 355725.7 6689752.2 27.5, 355725.8 6689751.1 27.5, 355717.2 6689749.6 27.5, 355716.7 6689757 27.5))
BATIMENT0000000302930711;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;16.4;16.6;33.0;36.5;18.9;Cadastre;C 0.9;POLYGON Z ((355703.1 6689776.8 33, 355703.6 6689767.4 33, 355703.8 6689763.6 33, 355695.5 6689763.4 33, 355694.4 6689761.6 33, 355694.6 6689755.1 33, 355696.6 6689753.5 33, 355704.4 6689753.8 33, 355704.7 6689746.4 33, 355690.8 6689742.8 33, 355688.5 6689773.5 33, 355688.5 6689775.8 33, 355694.7 6689776.2 33, 355703.1 6689776.8 33))
BATIMENT0000000302930725;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;14.7;17.0;31.7;34.5;18.5;Cadastre;A 1.0;POLYGON Z ((355727.7 6689760.4 31.7, 355725.2 6689759.9 31.7, 355724.6 6689764.3 31.7, 355725.6 6689764.5 31.7, 355727.5 6689764.9 31.7, 355727.9 6689763.6 31.7, 355736.1 6689765.7 31.7, 355746.8 6689768.6 31.7, 355751.8 6689760.3 31.7, 355751.3 6689759 31.7, 355729.2 6689753.2 31.7, 355727.7 6689760.4 31.7))
BATIMENT0000000302930723;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;6.4;17.3;23.8;24.9;18.5;Cadastre;A 1.0;POLYGON Z ((355718.2 6689770.6 23.8, 355720.7 6689770.7 23.8, 355724.7 6689770.9 23.8, 355724.8 6689769.6 23.8, 355722.9 6689769.5 23.8, 355722.8 6689768.4 23.8, 355718.1 6689767.2 23.8, 355718.2 6689770.6 23.8))
BATIMENT0000000302930722;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;8.1;17.1;25.3;27.1;18.3;Cadastre;A 1.0;POLYGON Z ((355720.3 6689774.5 25.3, 355717.3 6689774.4 25.3, 355716.8 6689778.4 25.3, 355722.5 6689778.8 25.3, 355723.8 6689778.9 25.3, 355724.7 6689770.9 25.3, 355720.7 6689770.7 25.3, 355720.3 6689774.5 25.3))
BATIMENT0000000302930710;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;8.6;15.8;24.4;30.5;17.5;Cadastre;C 0.1;POLYGON Z ((355686.3 6689784.9 24.4, 355694.2 6689784.6 24.4, 355694.7 6689776.2 24.4, 355688.5 6689775.8 24.4, 355688.5 6689773.5 24.4, 355687.1 6689773.4 24.4, 355686.3 6689784.9 24.4))
BATIMENT0000000302930718;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.9;15.8;32.8;35.4;17.8;Cadastre;A 1.0;POLYGON Z ((355746.8 6689768.6 32.8, 355736.1 6689765.7 32.8, 355735.5 6689767.2 32.8, 355735 6689767.2 32.8, 355732.9 6689770.5 32.8, 355729.9 6689768.7 32.8, 355730.8 6689767.1 32.8, 355725.5 6689765.6 32.8, 355724.8 6689769.6 32.8, 355724.7 6689770.9 32.8, 355723.8 6689778.9 32.8, 355723.7 6689781 32.8, 355723.5 6689783.1 32.8, 355722.8 6689787.8 32.8, 355732.1 6689793 32.8, 355746.8 6689768.6 32.8))
BATIMENT0000000302930724;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.4;16.8;26.2;28.5;17.7;Cadastre;;POLYGON Z ((355722.4 6689780.9 26.2, 355723.7 6689781 26.2, 355723.8 6689778.9 26.2, 355722.5 6689778.8 26.2, 355722.4 6689780.9 26.2))
BATIMENT0000000302930663;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;19.3;12.8;32.2;33.4;13.6;Cadastre;A 1.0;POLYGON Z ((355602.8 6689737 32.2, 355604.3 6689741 32.2, 355605 6689741 32.2, 355610.9 6689739.5 32.2, 355610.7 6689731.4 32.2, 355610.7 6689729.7 32.2, 355607.3 6689728 32.2, 355602.8 6689737 32.2))
BATIMENT0000000302930661;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.4;12.7;24.2;31.3;15.4;Cadastre;A 1.0;POLYGON Z ((355616.7 6689720.1 24.2, 355616.7 6689721.5 24.2, 355614.9 6689721.5 24.2, 355615.5 6689731.1 24.2, 355610.7 6689731.4 24.2, 355610.9 6689739.5 24.2, 355605 6689741 24.2, 355607.3 6689745.7 24.2, 355607.6 6689746 24.2, 355617.4 6689744.5 24.2, 355618.2 6689751.3 24.2, 355608.3 6689752.6 24.2, 355614.2 6689770.4 24.2, 355621.6 6689769.6 24.2, 355620.7 6689759.5 24.2, 355621.3 6689759.5 24.2, 355624.5 6689759.5 24.2, 355624 6689754.1 24.2, 355629.8 6689753.3 24.2, 355631 6689753.2 24.2, 355637.8 6689752.5 24.2, 355637.2 6689744.7 24.2, 355626.7 6689745.7 24.2, 355626.8 6689744.8 24.2, 355626.1 6689744.8 24.2, 355626 6689737.7 24.2, 355630.8 6689737.3 24.2, 355630.6 6689733.8 24.2, 355630.4 6689731.2 24.2, 355629.1 6689731 24.2, 355623.2 6689731 24.2, 355623.3 6689728.6 24.2, 355619 6689728.7 24.2, 355618.5 6689719.9 24.2, 355616.7 6689720.1 24.2))
BATIMENT0000000302930657;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;14.5;27.7;35.2;16.0;Cadastre;;POLYGON Z ((355647.1 6689754.1 27.7, 355647 6689752.1 27.7, 355637.8 6689752.5 27.7, 355631 6689753.2 27.7, 355631.3 6689755.8 27.7, 355647.1 6689754.1 27.7))
BATIMENT0000000302930658;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.7;13.7;24.4;27.2;14.8;Cadastre;;POLYGON Z ((355629.9 6689758.1 24.4, 355630.1 6689758.8 24.4, 355631.4 6689758.7 24.4, 355631.3 6689755.8 24.4, 355631 6689753.2 24.4, 355629.8 6689753.3 24.4, 355629.9 6689757.8 24.4, 355629.9 6689758.1 24.4))
BATIMENT0000000327821920;Indifférenciée;Résidentiel;;Non;En service;2013-09-26 18:45:28;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;6.0;5.0;00;00;17.9;14.5;;36.2;16.1;Imagerie aérienne;C 0.2;POLYGON Z ((355652.3 6689760.2 32.4, 355652.6 6689766.9 32.4, 355661.4 6689765.8 32.4, 355661.5 6689758.1 32.4, 355661.6 6689755.8 32.4, 355661.7 6689751.9 32.4, 355648.2 6689752 32.4, 355647 6689752.1 32.4, 355647.1 6689754.1 32.4, 355647.3 6689755.3 32.4, 355647.2 6689757.1 32.4, 355647.6 6689757.1 32.4, 355647.8 6689759.1 32.4, 355646.7 6689759.4 32.4, 355646.8 6689759.8 32.4, 355652.3 6689760.2 32.4))
BATIMENT0000000302930660;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;00;00;15.1;13.3;28.5;30.9;15.8;Cadastre;C 0.6;POLYGON Z ((355620.7 6689759.5 28.5, 355621.6 6689769.6 28.5, 355648.6 6689767.2 28.5, 355648.4 6689765.6 28.5, 355647.4 6689765.7 28.5, 355647 6689762 28.5, 355647.3 6689761.9 28.5, 355647.2 6689760.7 28.5, 355647 6689760.7 28.5, 355646.7 6689759.4 28.5, 355647.8 6689759.1 28.5, 355647.6 6689757.1 28.5, 355647.2 6689757.1 28.5, 355647.3 6689755.3 28.5, 355647.1 6689754.1 28.5, 355631.3 6689755.8 28.5, 355631.4 6689758.7 28.5, 355630.1 6689758.8 28.5, 355626.6 6689759.2 28.5, 355624.5 6689759.5 28.5, 355621.3 6689759.5 28.5, 355620.7 6689759.5 28.5))
BATIMENT0000000302931138;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;10;20;19.9;12.1;32.0;36.5;12.9;Cadastre;A 1.0;POLYGON Z ((355578.2 6689785.7 32, 355580.3 6689790.2 32, 355599.8 6689794.3 32, 355602.1 6689792.7 32, 355602.6 6689786.2 32, 355593.1 6689784.2 32, 355595.2 6689780.1 32, 355595.6 6689780.3 32, 355597.2 6689779.8 32, 355598.6 6689777.1 32, 355598.1 6689775.5 32, 355597.7 6689775.3 32, 355600.9 6689769.1 32, 355601.8 6689768.8 32, 355602.1 6689769.8 32, 355603.5 6689769.3 32, 355603.2 6689768.3 32, 355604.3 6689768 32, 355599.5 6689752.5 32, 355595.2 6689752.3 32, 355578.2 6689785.7 32))
BATIMENT0000000302930553;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;14.3;19.5;19.7;14.8;Cadastre;;POLYGON Z ((355635.8 6689775 19.5, 355636.2 6689781.1 19.5, 355649.8 6689779.5 19.5, 355649.5 6689774 19.5, 355635.8 6689775 19.5))
BATIMENT0000000302930551;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.6;13.5;25.2;33.2;16.2;Cadastre;A 0.2;POLYGON Z ((355650.1 6689781.1 25.2, 355660.7 6689780.3 25.2, 355661.2 6689783.7 25.2, 355629.5 6689786.6 25.2, 355630.7 6689790.7 25.2, 355648.2 6689789.3 25.2, 355650.7 6689814.7 25.2, 355655.5 6689814.1 25.2, 355655.5 6689814.5 25.2, 355659.8 6689814.4 25.2, 355660.3 6689819.3 25.2, 355674.2 6689818.5 25.2, 355678.1 6689818 25.2, 355677.3 6689806.9 25.2, 355674 6689807.2 25.2, 355660.2 6689808.5 25.2, 355659.2 6689797.4 25.2, 355658.8 6689793.1 25.2, 355668 6689792.4 25.2, 355667.8 6689796.6 25.2, 355675.5 6689797.2 25.2, 355676.8 6689776.6 25.2, 355674.8 6689771.4 25.2, 355649.5 6689774 25.2, 355649.8 6689779.5 25.2, 355650.1 6689781.1 25.2))
BATIMENT0000000302930549;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;20;20;12.4;13.1;25.5;28.5;13.7;Cadastre;A 1.0;POLYGON Z ((355610.8 6689807.8 25.5, 355616.4 6689817 25.5, 355630.2 6689806.8 25.5, 355630 6689802.7 25.5, 355628.5 6689786.7 25.5, 355612.4 6689788.1 25.5, 355610.8 6689807.8 25.5), (355624.1 6689799.9 25.5, 355624.6 6689805.1 25.5, 355619.8 6689807.5 25.5, 355619 6689806.8 25.5, 355618.8 6689800 25.5, 355624.1 6689799.9 25.5))
BATIMENT0000000302930716;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;13.9;17.0;30.9;32.7;17.5;Cadastre;A 1.0;POLYGON Z ((355702.6 6689784.7 30.9, 355699.5 6689789.7 30.9, 355699.8 6689790 30.9, 355699.8 6689790.5 30.9, 355709.8 6689796.4 30.9, 355724.8 6689805.2 30.9, 355732.1 6689793 30.9, 355722.8 6689787.8 30.9, 355723.5 6689783.1 30.9, 355723.7 6689781 30.9, 355722.4 6689780.9 30.9, 355715.4 6689780.5 30.9, 355715.1 6689783.6 30.9, 355702.6 6689784.7 30.9), (355709.9 6689786.5 30.9, 355718.4 6689791.5 30.9, 355716.1 6689795.6 30.9, 355707.5 6689790.7 30.9, 355709.9 6689786.5 30.9))
BATIMENT0000000302930552;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.6;14.3;26.0;30.7;15.1;Cadastre;;POLYGON Z ((355667.8 6689796.6 26, 355668 6689792.4 26, 355658.8 6689793.1 26, 355659.2 6689797.4 26, 355667.8 6689796.6 26))
BATIMENT0000000302930713;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;14.7;15.0;29.7;32.7;16.8;Cadastre;A 1.0;POLYGON Z ((355693.5 6689801.8 29.7, 355695.8 6689801.8 29.7, 355695.8 6689800.7 29.7, 355697.9 6689800.5 29.7, 355698.2 6689798.8 29.7, 355698.7 6689795.5 29.7, 355699.7 6689790.5 29.7, 355699.8 6689790.5 29.7, 355699.8 6689790 29.7, 355699.5 6689789.7 29.7, 355695.3 6689789.5 29.7, 355695.6 6689784.7 29.7, 355694.2 6689784.6 29.7, 355686.3 6689784.9 29.7, 355685.1 6689804.5 29.7, 355685 6689805.1 29.7, 355693.1 6689805.4 29.7, 355693.5 6689801.8 29.7))
BATIMENT0000000302930719;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;14.9;21.7;22.5;15.5;Cadastre;;POLYGON Z ((355697.9 6689800.5 21.7, 355697.8 6689802.3 21.7, 355697.6 6689804.5 21.7, 355700.5 6689799.9 21.7, 355698.2 6689798.8 21.7, 355697.9 6689800.5 21.7))
BATIMENT0000000302930720;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;20;20;6.0;14.7;20.7;22.5;15.2;Cadastre;C 0.5;POLYGON Z ((355699.8 6689807.3 20.7, 355704.1 6689800.4 20.7, 355701.3 6689798.5 20.7, 355700.5 6689799.9 20.7, 355697.6 6689804.5 20.7, 355697.4 6689805.4 20.7, 355697.5 6689806 20.7, 355699.8 6689807.3 20.7))
BATIMENT0000000302930726;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;16.7;14.5;31.2;34.8;15.4;Cadastre;C 0.9;POLYGON Z ((355724.8 6689805.2 31.2, 355709.8 6689796.4 31.2, 355707.4 6689800.5 31.2, 355711.3 6689802.7 31.2, 355711.8 6689804.1 31.2, 355706.5 6689812.3 31.2, 355705.1 6689812.4 31.2, 355697.5 6689808 31.2, 355697.7 6689811.3 31.2, 355692.6 6689811.7 31.2, 355692.7 6689816.1 31.2, 355697.2 6689816 31.2, 355698 6689814.7 31.2, 355697.8 6689813.5 31.2, 355714.1 6689822.9 31.2, 355724.8 6689805.2 31.2))
BATIMENT0000000302930714;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;29;11.2;14.2;25.4;29.4;15.3;Cadastre;A 1.0;POLYGON Z ((355682 6689804.5 25.4, 355683 6689818.7 25.4, 355686.7 6689818.9 25.4, 355686.8 6689815.8 25.4, 355692.7 6689816.1 25.4, 355692.6 6689811.7 25.4, 355697.7 6689811.3 25.4, 355697.5 6689808 25.4, 355697.5 6689806 25.4, 355697.4 6689805.4 25.4, 355693.1 6689805.4 25.4, 355685 6689805.1 25.4, 355685.1 6689804.5 25.4, 355682 6689804.5 25.4))
BATIMENT0000000302930728;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;25;20;18.8;13.6;32.5;36.6;14.8;Cadastre;A 1.0;POLYGON Z ((355697.2 6689816 32.5, 355695.3 6689819.1 32.5, 355693.4 6689822.4 32.5, 355708.9 6689831.6 32.5, 355714.1 6689822.9 32.5, 355697.8 6689813.5 32.5, 355698 6689814.7 32.5, 355697.2 6689816 32.5), (355700.7 6689816.8 32.5, 355703.4 6689818.4 32.5, 355701.7 6689821.2 32.5, 355698.7 6689819.6 32.5, 355700.7 6689816.8 32.5))
BATIMENT0000000302930727;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;90;90;7.0;13.5;20.5;29.2;14.6;Cadastre;A 1.0;POLYGON Z ((355683.3 6689823.9 20.5, 355683.5 6689827.8 20.5, 355682.9 6689828.8 20.5, 355686.8 6689831.2 20.5, 355692.7 6689822 20.5, 355693.4 6689822.4 20.5, 355695.3 6689819.1 20.5, 355697.2 6689816 20.5, 355692.7 6689816.1 20.5, 355686.8 6689815.8 20.5, 355686.7 6689818.9 20.5, 355683 6689818.7 20.5, 355683.3 6689823.9 20.5))
BATIMENT0000000302930497;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;14.6;14.5;29.2;31.9;19.5;Cadastre;A 1.0;POLYGON Z ((355723.8 6689832.1 29.2, 355737.6 6689839 29.2, 355740.1 6689833.9 29.2, 355748.1 6689817.7 29.2, 355736 6689811.7 29.2, 355723.8 6689832.1 29.2))
BATIMENT0000000302930507;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-01 15:16:53;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.4;18.0;36.4;40.1;18.7;Cadastre;;POLYGON Z ((355797.2 6689800.2 36.4, 355806.8 6689804.6 36.4, 355810.2 6689797.5 36.4, 355800.7 6689793.1 36.4, 355797.2 6689800.2 36.4))
BATIMENT0000000302931811;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;18.5;20.8;21.0;19.0;Cadastre;;POLYGON Z ((355820.6 6689797.9 20.8, 355819.7 6689797.5 20.8, 355817.8 6689801.3 20.8, 355818.6 6689801.7 20.8, 355820.6 6689797.9 20.8))
BATIMENT0000000302930503;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.0;15.7;24.8;29.5;19.3;Cadastre;A 1.0;POLYGON Z ((355763.2 6689790.1 24.8, 355765.5 6689791.1 24.8, 355757.1 6689807.9 24.8, 355754.6 6689806.8 24.8, 355754.2 6689807.6 24.8, 355747.4 6689804.3 24.8, 355747.2 6689804.8 24.8, 355741.8 6689802 24.8, 355736 6689811.7 24.8, 355748.1 6689817.7 24.8, 355748.6 6689816.8 24.8, 355751.8 6689811 24.8, 355761.4 6689815.5 24.8, 355763.1 6689812 24.8, 355762.3 6689811.7 24.8, 355773.8 6689789.3 24.8, 355765.5 6689785.5 24.8, 355763.2 6689790.1 24.8))
BATIMENT0000000302930505;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;6.0;10;20;17.3;18.0;35.3;39.6;19.2;Cadastre;A 1.0;POLYGON Z ((355775.4 6689822.4 35.3, 355796.9 6689824.4 35.3, 355805.6 6689805.7 35.3, 355806.2 6689806 35.3, 355806.8 6689804.6 35.3, 355797.2 6689800.2 35.3, 355797.1 6689800.6 35.3, 355773.8 6689789.3 35.3, 355762.3 6689811.7 35.3, 355763.1 6689812 35.3, 355767.2 6689814 35.3, 355767.7 6689814.2 35.3, 355773.3 6689802.7 35.3, 355772.7 6689801.9 35.3, 355775.2 6689797.3 35.3, 355790.5 6689804.5 35.3, 355791.3 6689806.3 35.3, 355788.4 6689812.3 35.3, 355786.8 6689812.5 35.3, 355783 6689820.4 35.3, 355769.3 6689814.1 35.3, 355768.4 6689815.7 35.3, 355766.9 6689814.9 35.3, 355765.5 6689817.5 35.3, 355775.4 6689822.4 35.3))
BATIMENT0000000302931810;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.4;18.4;20.8;21.0;19.0;Cadastre;;POLYGON Z ((355815.5 6689808.2 20.8, 355814.7 6689807.8 20.8, 355812.8 6689811.6 20.8, 355813.6 6689812.1 20.8, 355815.5 6689808.2 20.8))
BATIMENT0000000302931806;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;18.6;20.9;21.2;19.1;Cadastre;;POLYGON Z ((355821.8 6689811.3 20.9, 355820.9 6689810.9 20.9, 355819 6689814.7 20.9, 355819.9 6689815.2 20.9, 355821.8 6689811.3 20.9))
BATIMENT0000000302930504;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;8.9;18.0;26.9;29.3;19.3;Cadastre;C 0.3;POLYGON Z ((355762.9 6689823.5 26.9, 355773.3 6689824.2 26.9, 355775.2 6689824.8 26.9, 355775.4 6689822.4 26.9, 355765.5 6689817.5 26.9, 355761.4 6689815.5 26.9, 355751.8 6689811 26.9, 355748.6 6689816.8 26.9, 355762.9 6689823.5 26.9))
BATIMENT0000000302930499;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.4;15.8;25.2;31.7;19.4;Cadastre;C 0.2;POLYGON Z ((355737.6 6689839 25.2, 355749.8 6689845 25.2, 355750.5 6689845.3 25.2, 355752.7 6689840.8 25.2, 355752.9 6689840.2 25.2, 355740.1 6689833.9 25.2, 355737.6 6689839 25.2))
BATIMENT0000000302930498;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;33.0;4.0;00;00;16.7;18.5;35.2;40.9;19.4;Cadastre;C 0.8;POLYGON Z ((355805.7 6689872.4 35.2, 355814.3 6689854.6 35.2, 355814.5 6689854.8 35.2, 355819.3 6689844.5 35.2, 355812.1 6689840.9 35.2, 355812.2 6689840.4 35.2, 355800.9 6689834.8 35.2, 355800.4 6689835.4 35.2, 355793 6689831.8 35.2, 355792.7 6689832.1 35.2, 355774.8 6689831.4 35.2, 355775 6689828.8 35.2, 355767.7 6689828.5 35.2, 355765.8 6689833 35.2, 355803.3 6689851.3 35.2, 355795.6 6689867.5 35.2, 355805.7 6689872.4 35.2))
BATIMENT0000000302930506;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;00;00;2.5;18.7;21.2;24.5;19.5;Cadastre;C 0.4;POLYGON Z ((355788.7 6689853.4 21.2, 355768.4 6689843.3 21.2, 355764 6689852 21.2, 355768.6 6689854.2 21.2, 355777.4 6689858.6 21.2, 355784.8 6689862.3 21.2, 355788.7 6689853.4 21.2))
BATIMENT0000000302931170;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;20;20;12.8;10.0;22.8;24.9;11.3;Cadastre;A 1.0;POLYGON Z ((355602.3 6689804.2 22.8, 355601.9 6689802.9 22.8, 355587.8 6689799.7 22.8, 355586.6 6689804.4 22.8, 355585.8 6689806.3 22.8, 355584.6 6689809.3 22.8, 355584.4 6689809.7 22.8, 355594.8 6689814.8 22.8, 355602.3 6689804.2 22.8))
BATIMENT0000000302931169;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;17.2;10.6;27.9;29.9;11.2;Cadastre;A 1.0;POLYGON Z ((355575.2 6689796.9 27.9, 355571.6 6689798.7 27.9, 355565.6 6689810.6 27.9, 355573.7 6689814.5 27.9, 355580.8 6689818 27.9, 355584.4 6689809.7 27.9, 355584.6 6689809.3 27.9, 355583 6689808.7 27.9, 355583.4 6689807.5 27.9, 355583.7 6689807.5 27.9, 355584.3 6689805.8 27.9, 355585.8 6689806.3 27.9, 355586.6 6689804.4 27.9, 355587.8 6689799.7 27.9, 355575.2 6689796.9 27.9))
BATIMENT0000000302931171;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;15.4;10.3;25.7;28.2;10.9;Cadastre;A 1.0;POLYGON Z ((355571.5 6689818.8 25.7, 355572.4 6689819.2 25.7, 355575.8 6689821.1 25.7, 355576.3 6689819.8 25.7, 355582.2 6689822.5 25.7, 355587.5 6689825 25.7, 355594.8 6689814.8 25.7, 355584.4 6689809.7 25.7, 355580.8 6689818 25.7, 355573.7 6689814.5 25.7, 355571.5 6689818.8 25.7))
BATIMENT0000000302931865;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.7;11.3;31.0;36.7;14.0;Cadastre;C 0.3;POLYGON Z ((355632.8 6689843.7 31, 355641.4 6689841.7 31, 355641.3 6689836.8 31, 355655.2 6689836.6 31, 355655.3 6689841.6 31, 355664.9 6689842.4 31, 355668.4 6689836.5 31, 355673.6 6689828 31, 355673.8 6689825.1 31, 355631.7 6689824.1 31, 355631.5 6689820.8 31, 355630.9 6689814.2 31, 355630.7 6689810.8 31, 355630.2 6689806.8 31, 355616.4 6689817 31, 355628.6 6689836.9 31, 355632.8 6689843.7 31))
BATIMENT0000000302931172;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;7.0;;;16.1;9.1;25.2;29.9;10.8;Cadastre;A 1.0;POLYGON Z ((355553.8 6689833.7 25.2, 355564.2 6689839.7 25.2, 355566.2 6689835.8 25.2, 355575.2 6689840.3 25.2, 355587.5 6689825 25.2, 355582.2 6689822.5 25.2, 355577.4 6689828.5 25.2, 355573 6689826.3 25.2, 355571.9 6689828.4 25.2, 355570.4 6689827.7 25.2, 355570.2 6689827 25.2, 355568.8 6689826.3 25.2, 355572.4 6689819.2 25.2, 355571.5 6689818.8 25.2, 355573.7 6689814.5 25.2, 355565.6 6689810.6 25.2, 355553.8 6689833.7 25.2))
BATIMENT0000000302930525;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;18.1;10.9;29.0;32.6;11.2;Cadastre;A 1.0;POLYGON Z ((355607.1 6689844.2 29, 355619 6689837.5 29, 355607.1 6689817.9 29, 355603.3 6689817.7 29, 355592.5 6689832.7 29, 355601.9 6689838.7 29, 355603.1 6689836.9 29, 355603.2 6689836.9 29, 355603.4 6689837 29, 355603.6 6689837 29, 355603.8 6689837 29, 355604.1 6689836.9 29, 355604.3 6689836.8 29, 355604.4 6689836.7 29, 355604.5 6689836.6 29, 355604.6 6689836.5 29, 355604.6 6689836.4 29, 355604.7 6689836.3 29, 355604.7 6689836.1 29, 355604.7 6689835.9 29, 355604.7 6689835.6 29, 355604.6 6689835.6 29, 355604.6 6689835.5 29, 355604.5 6689835.3 29, 355605.7 6689833.7 29, 355607.2 6689832.8 29, 355609.7 6689836.7 29, 355603.3 6689840.4 29, 355607.1 6689844.2 29))
BATIMENT0000000302930550;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;12.5;24.2;33.4;13.1;Cadastre;;POLYGON Z ((355641.3 6689836.8 24.2, 355641.4 6689841.7 24.2, 355642.9 6689841.7 24.2, 355653.8 6689841.6 24.2, 355655.3 6689841.6 24.2, 355655.2 6689836.6 24.2, 355641.3 6689836.8 24.2))
BATIMENT0000000302931864;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;13.2;16.9;;;Cadastre;;POLYGON Z ((355643.1 6689846.5 16.9, 355642.9 6689841.7 16.9, 355641.4 6689841.7 16.9, 355632.8 6689843.7 16.9, 355636.9 6689850.5 16.9, 355643.1 6689846.5 16.9))
BATIMENT0000000302930519;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;7.8;8.8;16.7;24.2;11.4;Cadastre;A 1.0;POLYGON Z ((355583.9 6689844.8 16.7, 355592.2 6689851.4 16.7, 355587.4 6689858 16.7, 355585.1 6689856.3 16.7, 355585.5 6689855.9 16.7, 355582.1 6689852.9 16.7, 355581.7 6689853.3 16.7, 355579.2 6689851.3 16.7, 355573.8 6689858.9 16.7, 355583.2 6689865.9 16.7, 355582.8 6689866.6 16.7, 355583.7 6689867.5 16.7, 355586.7 6689870.1 16.7, 355590 6689871.6 16.7, 355591.1 6689872.1 16.7, 355600.5 6689852.9 16.7, 355607.1 6689844.2 16.7, 355603.3 6689840.4 16.7, 355601.9 6689838.7 16.7, 355592.5 6689832.7 16.7, 355583.9 6689844.8 16.7))
BATIMENT0000000302930523;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;10.2;12.6;16.8;11.2;Cadastre;;POLYGON Z ((355603.9 6689857.9 12.6, 355595.1 6689870.1 12.6, 355602.8 6689873.5 12.6, 355608.5 6689865.5 12.6, 355603.9 6689857.9 12.6))
BATIMENT0000000302930729;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;15.1;13.3;28.5;32.8;14.3;Cadastre;A 1.0;POLYGON Z ((355688.6 6689832.1 28.5, 355703.3 6689841 28.5, 355708.9 6689831.6 28.5, 355693.4 6689822.4 28.5, 355692.7 6689822 28.5, 355686.8 6689831.2 28.5, 355688.6 6689832.1 28.5), (355695 6689825.2 28.5, 355697.1 6689826.4 28.5, 355694.4 6689830.7 28.5, 355691.6 6689828.6 28.5, 355692.2 6689827.7 28.5, 355693.4 6689827.9 28.5, 355695 6689825.2 28.5))
BATIMENT0000000302930730;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;20;20;11.3;13.4;24.7;26.7;14.0;Cadastre;A 1.0;POLYGON Z ((355677.2 6689838.4 24.7, 355682.7 6689841.5 24.7, 355684.4 6689839 24.7, 355685.8 6689836.5 24.7, 355688.6 6689832.1 24.7, 355686.8 6689831.2 24.7, 355682.9 6689828.8 24.7, 355677.2 6689838.4 24.7))
BATIMENT0000000302930731;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;20;20;15.4;13.5;28.9;33.7;14.1;Cadastre;A 1.0;POLYGON Z ((355682.7 6689841.5 28.9, 355685.7 6689843.3 28.9, 355687.8 6689844.5 28.9, 355697.6 6689850.4 28.9, 355703.3 6689841 28.9, 355688.6 6689832.1 28.9, 355685.8 6689836.5 28.9, 355688.5 6689838.1 28.9, 355690 6689835.8 28.9, 355692.9 6689837.5 28.9, 355689.8 6689842.2 28.9, 355684.4 6689839 28.9, 355682.7 6689841.5 28.9))
BATIMENT0000000302930732;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;13.1;16.0;27.7;13.8;Cadastre;C 0.2;POLYGON Z ((355682.7 6689841.5 16, 355677.2 6689838.4 16, 355674.1 6689843.5 16, 355678.1 6689845.7 16, 355678.7 6689845.4 16, 355681 6689847.4 16, 355682 6689846.2 16, 355685.7 6689843.3 16, 355682.7 6689841.5 16))
BATIMENT0000000302931863;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;13.2;16.7;;;Cadastre;;POLYGON Z ((355660.3 6689850.1 16.7, 355664.9 6689842.4 16.7, 355655.3 6689841.6 16.7, 355653.8 6689841.6 16.7, 355654 6689846.4 16.7, 355660.3 6689850.1 16.7))
BATIMENT0000000302930481;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;10;20;16.4;13.8;30.3;34.2;19.4;Cadastre;A 1.0;POLYGON Z ((355739.3 6689865.7 30.3, 355739 6689865.3 30.3, 355747.1 6689849.3 30.3, 355747.5 6689849.4 30.3, 355749.8 6689845 30.3, 355737.6 6689839 30.3, 355723.8 6689832.1 30.3, 355720.1 6689838.3 30.3, 355733.9 6689844 30.3, 355728.7 6689855 30.3, 355713.6 6689849 30.3, 355709 6689856.7 30.3, 355719.8 6689861 30.3, 355721.7 6689862 30.3, 355727.4 6689864.7 30.3, 355737.6 6689869.4 30.3, 355739.3 6689865.7 30.3))
BATIMENT0000000302930736;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;12.4;15.0;20.2;13.5;Cadastre;C 0.3;POLYGON Z ((355676 6689858.7 15, 355673.6 6689857.2 15, 355672.7 6689856.7 15, 355675.2 6689852.2 15, 355676.9 6689849.4 15, 355677 6689848.7 15, 355676.7 6689848.1 15, 355672.7 6689845.7 15, 355665.2 6689858.5 15, 355669.7 6689861.3 15, 355671.7 6689862.5 15, 355673.2 6689863.4 15, 355676 6689858.7 15))
BATIMENT0000000302930737;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;13.1;14.8;17.9;13.4;Cadastre;;POLYGON Z ((355676.3 6689852.9 14.8, 355675.2 6689852.2 14.8, 355672.7 6689856.7 14.8, 355673.6 6689857.2 14.8, 355676.3 6689852.9 14.8))
BATIMENT0000000302930733;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;8.0;20;20;21.6;12.6;34.2;38.6;13.8;Cadastre;C 0.8;POLYGON Z ((355684 6689850.8 34.2, 355682.6 6689850 34.2, 355678.1 6689857.8 34.2, 355679.3 6689858.7 34.2, 355675.6 6689864.8 34.2, 355685.5 6689870.6 34.2, 355697.6 6689850.4 34.2, 355687.8 6689844.5 34.2, 355684 6689850.8 34.2))
BATIMENT0000000302930735;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;12.2;14.4;27.5;13.5;Cadastre;;POLYGON Z ((355670.4 6689864.6 14.4, 355671.7 6689862.5 14.4, 355669.7 6689861.3 14.4, 355668.5 6689863.2 14.4, 355670.4 6689864.6 14.4))
BATIMENT0000000302930738;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;12.0;14.6;15.5;13.3;Cadastre;C 0.3;POLYGON Z ((355665.2 6689858.5 14.6, 355659.9 6689866.8 14.6, 355664.4 6689869.8 14.6, 355668.5 6689863.2 14.6, 355669.7 6689861.3 14.6, 355665.2 6689858.5 14.6))
BATIMENT0000000302930478;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1858-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;12;20;18.5;12.9;31.5;34.1;14.6;Cadastre;A 1.0;POLYGON Z ((355699.7 6689872.2 31.5, 355711.5 6689879.2 31.5, 355721.7 6689862 31.5, 355719.8 6689861 31.5, 355709 6689856.7 31.5, 355699.7 6689872.2 31.5))
BATIMENT0000000302930734;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;20;20;16.5;11.6;28.2;31.2;13.5;Cadastre;C 1.0;POLYGON Z ((355674.7 6689867.6 28.2, 355669.1 6689876.8 28.2, 355658.1 6689870 28.2, 355653 6689878.1 28.2, 355653.2 6689879.1 28.2, 355673.1 6689891.1 28.2, 355685.5 6689870.6 28.2, 355675.6 6689864.8 28.2, 355673.2 6689863.4 28.2, 355671.7 6689862.5 28.2, 355670.4 6689864.6 28.2, 355674.7 6689867.6 28.2))
BATIMENT0000000302930477;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;00;00;19.6;11.8;31.4;34.2;13.7;Cadastre;A 1.0;POLYGON Z ((355709 6689883.2 31.4, 355711.5 6689879.2 31.4, 355699.7 6689872.2 31.4, 355689.6 6689888.9 31.4, 355697.3 6689893.2 31.4, 355699.1 6689890 31.4, 355700.1 6689888.3 31.4, 355702.8 6689890 31.4, 355703.8 6689890.5 31.4, 355703.4 6689891.1 31.4, 355704.2 6689891.5 31.4, 355705.2 6689889.8 31.4, 355709 6689883.2 31.4))
BATIMENT0000000302930494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;12.5;27.7;33.5;15.0;Cadastre;;POLYGON Z ((355718.2 6689883.1 27.7, 355715.7 6689881.7 27.7, 355713.4 6689885.7 27.7, 355712.3 6689887.6 27.7, 355714.9 6689889 27.7, 355718.2 6689883.1 27.7))
BATIMENT0000000302930479;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.6;11.6;29.2;34.0;12.5;Cadastre;;POLYGON Z ((355700.1 6689888.3 29.2, 355699.1 6689890 29.2, 355701.8 6689891.8 29.2, 355702.8 6689890 29.2, 355700.1 6689888.3 29.2))
BATIMENT0000000302930486;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;11.9;26.2;31.2;13.4;Cadastre;;POLYGON Z ((355713.2 6689894.7 26.2, 355713 6689892.4 26.2, 355714.9 6689889 26.2, 355712.3 6689887.6 26.2, 355709.4 6689892.4 26.2, 355713.2 6689894.7 26.2))
BATIMENT0000000302930480;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;11.4;28.5;31.5;13.0;Cadastre;;POLYGON Z ((355689.6 6689888.9 28.5, 355684.4 6689897.3 28.5, 355704.7 6689909.3 28.5, 355709.9 6689900.5 28.5, 355711.8 6689897.3 28.5, 355710.5 6689896.5 28.5, 355711.3 6689894.9 28.5, 355712.8 6689895.6 28.5, 355713.4 6689894.9 28.5, 355713.2 6689894.7 28.5, 355709.4 6689892.4 28.5, 355705.2 6689889.8 28.5, 355704.2 6689891.5 28.5, 355701.6 6689895.7 28.5, 355697.3 6689893.2 28.5, 355689.6 6689888.9 28.5))
BATIMENT0000000302930495;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;21.9;11.8;33.7;38.0;17.3;Cadastre;A 1.0;POLYGON Z ((355717.1 6689897.9 33.7, 355717.6 6689903.1 33.7, 355728.2 6689902.4 33.7, 355728.3 6689902 33.7, 355728.2 6689896.9 33.7, 355717.1 6689897.9 33.7))
BATIMENT0000000302930496;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;13.3;21.0;22.7;16.2;Cadastre;;POLYGON Z ((355728.4 6689911.1 21, 355729 6689911.5 21, 355730.2 6689909.2 21, 355730 6689909 21, 355730.3 6689908.4 21, 355728.3 6689907.3 21, 355728.4 6689911.1 21))
BATIMENT0000000303962875;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;14.5;18.4;21.5;15.4;Cadastre;;POLYGON Z ((356265.8 6689736.2 18.4, 356264.5 6689735.6 18.4, 356287.6 6689688.8 18.4, 356284.9 6689687.3 18.4, 356233.9 6689790.9 18.4, 356237.7 6689792.9 18.4, 356238.8 6689790.6 18.4, 356244.6 6689778.7 18.4, 356243.7 6689777.9 18.4, 356254.8 6689755.5 18.4, 356256.1 6689756.1 18.4, 356265.8 6689736.2 18.4))
BATIMENT0000000303963172;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;10.3;22.7;33.2;17.9;Cadastre;;POLYGON Z ((356128.1 6689800.5 22.7, 356128.8 6689799.2 22.7, 356152.2 6689810.6 22.7, 356152 6689811.3 22.7, 356173.9 6689822.1 22.7, 356173.6 6689822.7 22.7, 356174.7 6689823.2 22.7, 356174.4 6689823.9 22.7, 356177.3 6689825.3 22.7, 356177.6 6689824.6 22.7, 356180.7 6689826.2 22.7, 356180.5 6689826.8 22.7, 356182.7 6689827.9 22.7, 356183 6689827.3 22.7, 356184.3 6689827.9 22.7, 356184.5 6689827.5 22.7, 356206.3 6689838.2 22.7, 356206.6 6689837.7 22.7, 356230.1 6689849 22.7, 356229.5 6689850.4 22.7, 356237.5 6689853.9 22.7, 356241.1 6689846.2 22.7, 356245.5 6689848.3 22.7, 356247.1 6689845 22.7, 356242.8 6689843.1 22.7, 356254.9 6689817.7 22.7, 356259.5 6689820 22.7, 356261.5 6689815.9 22.7, 356256.9 6689814.1 22.7, 356260.1 6689807.4 22.7, 356258 6689806.4 22.7, 356260.5 6689801.1 22.7, 356257.1 6689798.6 22.7, 356252.4 6689795.8 22.7, 356247.4 6689793.5 22.7, 356242.3 6689791.6 22.7, 356238.8 6689790.6 22.7, 356237.7 6689792.9 22.7, 356236.4 6689795.5 22.7, 356206.2 6689780.5 22.7, 356223.4 6689744.6 22.7, 356224 6689744.8 22.7, 356223.7 6689745.7 22.7, 356224.5 6689746.1 22.7, 356224.9 6689745.2 22.7, 356225.4 6689745.4 22.7, 356227.8 6689740.3 22.7, 356226.2 6689739.4 22.7, 356243.5 6689703.7 22.7, 356243.9 6689703.9 22.7, 356243.7 6689704.8 22.7, 356244.3 6689705.1 22.7, 356244.8 6689704.3 22.7, 356245.3 6689704.6 22.7, 356247.8 6689699.8 22.7, 356246 6689698.9 22.7, 356263.9 6689662.9 22.7, 356267.3 6689664.6 22.7, 356266.1 6689666.9 22.7, 356296.6 6689682 22.7, 356294.5 6689686.4 22.7, 356289.9 6689684.1 22.7, 356287.6 6689688.8 22.7, 356264.5 6689735.6 22.7, 356265.8 6689736.2 22.7, 356271.3 6689738.8 22.7, 356270 6689741.2 22.7, 356280.1 6689746 22.7, 356281.3 6689743.7 22.7, 356290.9 6689748.3 22.7, 356317.2 6689694.7 22.7, 356315.6 6689693.9 22.7, 356316.1 6689693.2 22.7, 356316.6 6689692.8 22.7, 356320.6 6689684.4 22.7, 356321.4 6689684.6 22.7, 356323.1 6689680.8 22.7, 356322.4 6689680.4 22.7, 356326.8 6689671.8 22.7, 356320.2 6689668.5 22.7, 356313.7 6689681 22.7, 356312.6 6689680.3 22.7, 356313.4 6689678.6 22.7, 356275.5 6689659.8 22.7, 356255.6 6689649.2 22.7, 356253.9 6689652.4 22.7, 356251.5 6689651.3 22.7, 356249.5 6689655.4 22.7, 356250 6689656.3 22.7, 356253.4 6689657.9 22.7, 356242 6689681.4 22.7, 356240.4 6689680.7 22.7, 356238.4 6689684.8 22.7, 356239.9 6689685.6 22.7, 356237 6689691.5 22.7, 356206.4 6689676.5 22.7, 356206.5 6689676 22.7, 356202.3 6689674.1 22.7, 356197.1 6689684.4 22.7, 356231.9 6689701.9 22.7, 356225.3 6689714.9 22.7, 356223.8 6689717.9 22.7, 356215 6689735.2 22.7, 356155.3 6689705.8 22.7, 356153.9 6689705.3 22.7, 356152.2 6689705.2 22.7, 356150.8 6689705.4 22.7, 356148.9 6689706.7 22.7, 356148.3 6689707.6 22.7, 356147.5 6689709.4 22.7, 356147.5 6689712.1 22.7, 356148.3 6689713.9 22.7, 356149.4 6689715.3 22.7, 356159 6689720.2 22.7, 356145.3 6689747 22.7, 356142 6689745.4 22.7, 356135.9 6689758.4 22.7, 356138.8 6689759.9 22.7, 356126.1 6689785.4 22.7, 356124.4 6689784.8 22.7, 356124 6689785 22.7, 356123 6689786.9 22.7, 356123.4 6689788.1 22.7, 356124.7 6689788.6 22.7, 356120.4 6689796.7 22.7, 356128.1 6689800.5 22.7), (356147.8 6689760.9 22.7, 356248.6 6689811 22.7, 356233.7 6689842 22.7, 356153.9 6689802.2 22.7, 356132.6 6689791.9 22.7, 356147.8 6689760.9 22.7), (356151.7 6689753.2 22.7, 356166.5 6689724.1 22.7, 356210 6689745.3 22.7, 356204.9 6689755.5 22.7, 356201.7 6689753.8 22.7, 356202.1 6689752.7 22.7, 356173.3 6689738.7 22.7, 356172.6 6689740.1 22.7, 356171.3 6689739.5 22.7, 356166.7 6689748.7 22.7, 356168 6689749.6 22.7, 356167.4 6689751.1 22.7, 356196 6689765.1 22.7, 356196.5 6689763.9 22.7, 356200.3 6689765.5 22.7, 356195.6 6689775.2 22.7, 356156.3 6689756.2 22.7, 356156.5 6689755.5 22.7, 356151.7 6689753.2 22.7))
BATIMENT0000000303962880;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;14.1;18.6;23.5;15.0;Cadastre;;POLYGON Z ((356246.8 6689780.5 18.6, 356251.7 6689784 18.6, 356258.4 6689787.5 18.6, 356265.5 6689790 18.6, 356269.9 6689791 18.6, 356281 6689768.4 18.6, 356271.5 6689763.6 18.6, 356272.6 6689761.3 18.6, 356262.6 6689756.4 18.6, 356261.5 6689758.6 18.6, 356256.1 6689756.1 18.6, 356254.8 6689755.5 18.6, 356243.7 6689777.9 18.6, 356244.6 6689778.7 18.6, 356246.8 6689780.5 18.6))
BATIMENT0000000303963077;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;15.9;23.1;25.8;18.0;Cadastre;;POLYGON Z ((356196.1 6689852.1 23.1, 356187.5 6689861.5 23.1, 356178.2 6689853.2 23.1, 356172.2 6689859.3 23.1, 356184.7 6689870.9 23.1, 356187.2 6689868 23.1, 356189.3 6689865.5 23.1, 356198.5 6689855.9 23.1, 356199.5 6689853.7 23.1, 356196.1 6689852.1 23.1))
BATIMENT0000000303963078;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;47.0;8.0;30;40;7.9;15.8;23.7;42.0;18.4;Cadastre;A 1.0;POLYGON Z ((356181.4 6689874.5 23.7, 356188 6689880.2 23.7, 356198.9 6689890.8 23.7, 356208.2 6689899.4 23.7, 356222.5 6689885 23.7, 356222.9 6689884 23.7, 356230.9 6689869.3 23.7, 356199.5 6689853.7 23.7, 356198.5 6689855.9 23.7, 356189.3 6689865.5 23.7, 356192 6689868.1 23.7, 356193.2 6689867.9 23.7, 356197.4 6689863.5 23.7, 356202.5 6689865.8 23.7, 356200.5 6689869.6 23.7, 356204.2 6689871.3 23.7, 356206 6689867.7 23.7, 356218 6689873.5 23.7, 356216 6689877.5 23.7, 356206.8 6689886.9 23.7, 356187.2 6689868 23.7, 356184.7 6689870.9 23.7, 356181.4 6689874.5 23.7))
BATIMENT0000000303963080;Indifférenciée;Annexe;Commercial et services;Oui;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.4;17.2;21.6;22.5;18.8;Cadastre;C 0.2;POLYGON Z ((356188 6689880.2 21.6, 356183.7 6689884 21.6, 356183.8 6689884.2 21.6, 356195 6689895 21.6, 356196 6689894 21.6, 356198.9 6689890.8 21.6, 356188 6689880.2 21.6))
BATIMENT0000000303963081;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;4.9;18.2;23.2;32.2;19.3;Cadastre;C 0.5;POLYGON Z ((356171.8 6689884.9 23.2, 356168.5 6689888.5 23.2, 356163.3 6689894.2 23.2, 356156.7 6689901.1 23.2, 356155.9 6689902.1 23.2, 356148.6 6689910.3 23.2, 356147 6689912.1 23.2, 356162.7 6689919.1 23.2, 356164.8 6689913.6 23.2, 356163.9 6689911.6 23.2, 356161.4 6689910.7 23.2, 356158.6 6689907.3 23.2, 356160.2 6689905.9 23.2, 356161.5 6689907 23.2, 356167.5 6689900.6 23.2, 356167.9 6689900.6 23.2, 356179.6 6689911.8 23.2, 356187.5 6689903.2 23.2, 356188.6 6689902.1 23.2, 356184 6689897.7 23.2, 356185.4 6689895.9 23.2, 356181.3 6689892.1 23.2, 356172.6 6689900.7 23.2, 356170.2 6689898.3 23.2, 356174.4 6689893.8 23.2, 356178.5 6689889.6 23.2, 356176.4 6689887.5 23.2, 356181.6 6689882.2 23.2, 356183.8 6689884.2 23.2, 356183.7 6689884 23.2, 356188 6689880.2 23.2, 356181.4 6689874.5 23.2, 356171.8 6689884.9 23.2))
BATIMENT0000000303962897;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;16.1;24.3;27.6;17.3;Cadastre;;POLYGON Z ((356253.4 6689908.2 24.3, 356261.2 6689900.7 24.3, 356253.2 6689892.6 24.3, 356246.1 6689899.7 24.3, 356253.4 6689908.2 24.3))
BATIMENT0000000303963079;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;12;14.7;17.4;32.1;35.2;19.1;Cadastre;A 1.0;POLYGON Z ((356208.2 6689899.4 32.1, 356198.9 6689890.8 32.1, 356196 6689894 32.1, 356197.6 6689895.5 32.1, 356195.7 6689897.7 32.1, 356195.2 6689900.7 32.1, 356196.1 6689901.4 32.1, 356194.5 6689903.3 32.1, 356190.7 6689899.8 32.1, 356188.6 6689902.1 32.1, 356187.5 6689903.2 32.1, 356197.2 6689910.6 32.1, 356208.2 6689899.4 32.1))
BATIMENT0000000303963082;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;13.5;18.0;31.5;33.9;19.1;Cadastre;C 0.8;POLYGON Z ((356179.7 6689911.9 31.5, 356187.9 6689919.7 31.5, 356197.2 6689910.6 31.5, 356187.5 6689903.2 31.5, 356179.6 6689911.8 31.5, 356179.7 6689911.9 31.5))
BATIMENT0000000303962971;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;14.6;17.5;19.7;15.7;Cadastre;;POLYGON Z ((356051.7 6689698.8 17.5, 356074.3 6689708.5 17.5, 356076.6 6689703.6 17.5, 356053.8 6689694 17.5, 356051.7 6689698.8 17.5))
BATIMENT0000000303962411;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;3.2;16.1;19.3;21.7;17.0;Cadastre;A 1.0;POLYGON Z ((356067.9 6689732.7 19.3, 356067.7 6689732.9 19.3, 356067.1 6689732.6 19.3, 356065 6689736.9 19.3, 356063.5 6689736.2 19.3, 356063 6689737.4 19.3, 356058.5 6689735.1 19.3, 356056.8 6689738.5 19.3, 356058.6 6689739.3 19.3, 356061.5 6689740.5 19.3, 356062.9 6689741.2 19.3, 356068.3 6689744.1 19.3, 356070.3 6689740 19.3, 356072.5 6689735 19.3, 356076.5 6689726.8 19.3, 356080 6689719.8 19.3, 356081.2 6689717.5 19.3, 356078.9 6689716.3 19.3, 356076.4 6689715.2 19.3, 356075.9 6689715 19.3, 356071.2 6689724.3 19.3, 356071.8 6689724.6 19.3, 356067.9 6689732.7 19.3))
BATIMENT0000000303963070;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;13.9;17.6;17.6;16.5;Cadastre;;POLYGON Z ((356111.8 6689742.1 17.6, 356108.6 6689740.6 17.6, 356107.8 6689742.3 17.6, 356116 6689746.5 17.6, 356118.4 6689741.8 17.6, 356113.4 6689739 17.6, 356111.8 6689742.1 17.6))
BATIMENT0000000303962410;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;17.8;15.8;33.7;35.6;17.7;Cadastre;A 1.0;POLYGON Z ((356075.6 6689747.8 33.7, 356064.6 6689769.5 33.7, 356084.3 6689779.3 33.7, 356089.8 6689763.5 33.7, 356093.8 6689755.3 33.7, 356095.3 6689752.2 33.7, 356093.3 6689751.3 33.7, 356090.8 6689757.2 33.7, 356081.7 6689752.7 33.7, 356077.3 6689750.7 33.7, 356080.1 6689745.1 33.7, 356070.3 6689740 33.7, 356068.3 6689744.1 33.7, 356075.6 6689747.8 33.7), (356076.7 6689758.8 33.7, 356078.6 6689759.7 33.7, 356084.1 6689762.5 33.7, 356080.5 6689769.8 33.7, 356073.1 6689766.4 33.7, 356072.3 6689764 33.7, 356074.2 6689760.2 33.7, 356076.7 6689758.8 33.7))
BATIMENT0000000303962413;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;37.0;6.0;09;09;15.4;17.4;32.8;35.4;17.4;Cadastre;A 1.0;POLYGON Z ((356111.8 6689792.9 32.8, 356112.7 6689791.4 32.8, 356116.2 6689781.6 32.8, 356111.2 6689779.2 32.8, 356117.1 6689766.6 32.8, 356093.8 6689755.3 32.8, 356089.8 6689763.5 32.8, 356084.3 6689779.3 32.8, 356111.8 6689792.9 32.8))
BATIMENT0000000303963017;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.2;17.5;36.7;43.0;19.3;Cadastre;;POLYGON Z ((356042.3 6689785.2 36.7, 356041.5 6689784.9 36.7, 356035.4 6689797 36.7, 356036.1 6689797.3 36.7, 356032.4 6689804.9 36.7, 356032.8 6689805.3 36.7, 356016.6 6689837.9 36.7, 356015.7 6689837.6 36.7, 356009.7 6689849.9 36.7, 356010.2 6689850.9 36.7, 356022.1 6689856.4 36.7, 356022.6 6689855.8 36.7, 356055.3 6689870.4 36.7, 356055.2 6689870.8 36.7, 356067.8 6689876.5 36.7, 356068.4 6689876.1 36.7, 356074.4 6689864.2 36.7, 356073 6689863.7 36.7, 356088.3 6689833.2 36.7, 356088.9 6689833.6 36.7, 356092.3 6689826.2 36.7, 356093.4 6689826.1 36.7, 356099.7 6689813.4 36.7, 356099 6689813.2 36.7, 356102.8 6689805.8 36.7, 356102 6689805.5 36.7, 356102.5 6689804.6 36.7, 356091.7 6689799.2 36.7, 356091.3 6689800 36.7, 356090.7 6689799.8 36.7, 356087.1 6689806.4 36.7, 356075.7 6689800.8 36.7, 356066.7 6689796.1 36.7, 356054.8 6689790.1 36.7, 356058.1 6689783.6 36.7, 356057.1 6689783.1 36.7, 356057.2 6689782.3 36.7, 356048.2 6689778 36.7, 356047.8 6689778.5 36.7, 356046.2 6689777.7 36.7, 356042.3 6689785.2 36.7))
BATIMENT0000000303962964;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;3.0;10;20;11.1;16.9;28.1;30.9;17.9;Cadastre;C 1.0;POLYGON Z ((356140.9 6689839.7 28.1, 356146.9 6689828.3 28.1, 356140.2 6689825.1 28.1, 356140.2 6689824.4 28.1, 356137 6689822.9 28.1, 356136.9 6689823.3 28.1, 356130 6689820 28.1, 356129.3 6689821.4 28.1, 356124.8 6689831.4 28.1, 356140.9 6689839.7 28.1))
BATIMENT0000000303962963;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.3;17.3;30.7;32.4;18.3;Cadastre;C 0.4;POLYGON Z ((356118.7 6689844.5 30.7, 356124.8 6689831.4 30.7, 356129.3 6689821.4 30.7, 356111.4 6689812.6 30.7, 356098.5 6689839.1 30.7, 356104.6 6689842.3 30.7, 356107.3 6689837.3 30.7, 356109.2 6689838.3 30.7, 356114.1 6689828.6 30.7, 356113.5 6689828.3 30.7, 356113.9 6689827.4 30.7, 356119.8 6689830.2 30.7, 356114.1 6689842 30.7, 356112.6 6689841.2 30.7, 356111 6689845 30.7, 356116.3 6689847.8 30.7, 356118.7 6689844.5 30.7))
BATIMENT0000000303962961;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.8;19.7;21.5;;;Cadastre;;POLYGON Z ((356094.9 6689857.4 21.5, 356100.6 6689845 21.5, 356096.7 6689842.7 21.5, 356090.5 6689855.3 21.5, 356094.9 6689857.4 21.5))
BATIMENT0000000303962966;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;17.5;25.2;27.2;17.8;Cadastre;;POLYGON Z ((356156.6 6689851 25.2, 356155.1 6689849.3 25.2, 356151.1 6689852.7 25.2, 356152.6 6689854.5 25.2, 356156.6 6689851 25.2))
BATIMENT0000000303963152;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;20;20;6.5;7.5;14.0;22.5;8.0;Cadastre;C 0.6;POLYGON Z ((356403.3 6689664.6 14, 356405.2 6689657 14, 356402.5 6689656.4 14, 356399.7 6689655.8 14, 356402.9 6689640.3 14, 356403.6 6689636.8 14, 356396.5 6689635.2 14, 356395.9 6689638.7 14, 356397.3 6689639 14, 356391.5 6689665.2 14, 356390.5 6689665 14, 356389.6 6689669.3 14, 356388.9 6689669.6 14, 356388.7 6689670.4 14, 356397.3 6689667 14, 356403.3 6689664.6 14))
BATIMENT0000000303962900;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;6.8;12.8;14.0;8.6;Cadastre;;POLYGON Z ((356376.7 6689658.4 12.8, 356387.5 6689659.5 12.8, 356388.5 6689655 12.8, 356388.6 6689654.4 12.8, 356381.1 6689653.4 12.8, 356379.4 6689653.1 12.8, 356376.7 6689658.4 12.8))
BATIMENT0000000303962904;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;10;20;18.7;7.7;26.4;28.4;8.4;Cadastre;A 1.0;POLYGON Z ((356354.2 6689658.5 26.4, 356361.5 6689662.1 26.4, 356363 6689662.9 26.4, 356364.2 6689663.5 26.4, 356368.2 6689665.5 26.4, 356370.5 6689666.7 26.4, 356372 6689667.4 26.4, 356374.6 6689662.5 26.4, 356375.1 6689661.4 26.4, 356368.9 6689658.8 26.4, 356368 6689659.7 26.4, 356366.9 6689661.3 26.4, 356366 6689660.9 26.4, 356368.7 6689655.4 26.4, 356370.2 6689656 26.4, 356372 6689651.9 26.4, 356369.8 6689651.6 26.4, 356358.6 6689649.9 26.4, 356354.2 6689658.5 26.4))
BATIMENT0000000303962905;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;10;20;18.7;7.5;26.2;29.6;8.4;Cadastre;A 1.0;POLYGON Z ((356363 6689662.9 26.2, 356362 6689665 26.2, 356360.5 6689665.5 26.2, 356359.9 6689665.1 26.2, 356361.5 6689662.1 26.2, 356354.2 6689658.5 26.2, 356349.4 6689668.1 26.2, 356351.1 6689672.3 26.2, 356362.9 6689678.3 26.2, 356365.7 6689673.2 26.2, 356367.6 6689674.1 26.2, 356368.6 6689672.3 26.2, 356366.6 6689671.3 26.2, 356368.3 6689668.1 26.2, 356367.1 6689667.5 26.2, 356363.2 6689665.5 26.2, 356364.2 6689663.5 26.2, 356363 6689662.9 26.2))
BATIMENT0000000303962907;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;18.7;7.5;26.2;29.6;8.2;Cadastre;C 0.8;POLYGON Z ((356372 6689667.4 26.2, 356370.5 6689666.7 26.2, 356369.5 6689668.7 26.2, 356368.3 6689668.1 26.2, 356366.6 6689671.3 26.2, 356368.6 6689672.3 26.2, 356367.6 6689674.1 26.2, 356365.7 6689673.2 26.2, 356362.9 6689678.3 26.2, 356365.7 6689679.6 26.2, 356384.7 6689672.1 26.2, 356387.1 6689661.2 26.2, 356385.9 6689659.9 26.2, 356376.4 6689663.3 26.2, 356374.6 6689662.5 26.2, 356372 6689667.4 26.2))
BATIMENT0000002011293142;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.5;13.3;;17.4;14.0;Imagerie aérienne;;POLYGON Z ((356324.1 6689893 16.8, 356325 6689892.4 16.8, 356325.8 6689891.8 16.8, 356326.2 6689890.6 16.8, 356326.2 6689889.2 16.8, 356325.6 6689887.7 16.8, 356324.6 6689887 16.8, 356311.5 6689882.2 16.8, 356309.7 6689882.2 16.8, 356308.6 6689882.9 16.8, 356308 6689883.7 16.8, 356307.7 6689884.7 16.8, 356307.7 6689886 16.8, 356308.1 6689886.9 16.8, 356308.9 6689888.1 16.8, 356322.7 6689893.2 16.8, 356324.1 6689893 16.8))
BATIMENT0000000303962732;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.8;11.2;27.0;30.0;14.5;Cadastre;C 0.3;MULTIPOLYGON Z (((356487.3 6689909.2 27, 356476.7 6689921 27, 356488.7 6689930.9 27, 356493.8 6689921.6 27, 356494.4 6689921.5 27, 356494.3 6689920.9 27, 356495.3 6689920.6 27, 356506.81139568595 6689927.05035103 27, 356506.81139568595 6689903.670546284 27, 356503.1 6689910.4 27, 356500.6 6689909 27, 356500.1 6689909.9 27, 356497.6 6689908.5 27, 356498.1 6689907.6 27, 356497 6689907.1 27, 356490 6689903.2 27, 356487.3 6689909.2 27)), ((356506.1 6689867 27, 356506.81139568595 6689867.393139721 27, 356506.81139568595 6689865.419120698 27, 356506.1 6689867 27)))
BATIMENT0000000303962733;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.4;11.2;27.6;27.7;13.3;Cadastre;;POLYGON Z ((356490 6689903.2 27.6, 356497 6689907.1 27.6, 356497.6 6689906 27.6, 356490.5 6689902.1 27.6, 356490 6689903.2 27.6))
BATIMENT0000000303962972;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.1;17.3;25.4;27.1;17.6;Cadastre;;POLYGON Z ((356314.8 6689963.4 25.4, 356321.4 6689967.5 25.4, 356318.9 6689971.3 25.4, 356328.7 6689977.5 25.4, 356334.8 6689968.1 25.4, 356318.5 6689957.6 25.4, 356314.8 6689963.4 25.4))
BATIMENT0000000303962896;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;16.2;19.1;26.0;16.9;Cadastre;;POLYGON Z ((356343.5 6689966.9 19.1, 356349.8 6689970.9 19.1, 356349.4 6689971.5 19.1, 356351.7 6689972.9 19.1, 356350.7 6689974.6 19.1, 356357 6689978.6 19.1, 356358.1 6689976.9 19.1, 356360 6689978.1 19.1, 356360.3 6689977.7 19.1, 356366.6 6689981.6 19.1, 356369.8 6689976.7 19.1, 356363.4 6689972.7 19.1, 356363.8 6689972.2 19.1, 356361.8 6689970.9 19.1, 356363 6689968.8 19.1, 356356.7 6689964.9 19.1, 356355.5 6689967 19.1, 356353.3 6689965.6 19.1, 356353 6689966 19.1, 356346.6 6689962 19.1, 356343.5 6689966.9 19.1))
BATIMENT0000000303962965;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.6;18.1;29.7;32.2;18.7;Cadastre;C 0.2;POLYGON Z ((356140.5 6689840.6 29.7, 356144.2 6689842.4 29.7, 356145.2 6689840.2 29.7, 356160.4 6689847.9 29.7, 356156.6 6689851 29.7, 356152.6 6689854.5 29.7, 356132 6689872.1 29.7, 356133 6689873.4 29.7, 356131.4 6689874.3 29.7, 356136.2 6689876.5 29.7, 356159.4 6689856.7 29.7, 356176.5 6689842.1 29.7, 356147.1 6689828 29.7, 356146.9 6689828.3 29.7, 356140.9 6689839.7 29.7, 356140.5 6689840.6 29.7))
BATIMENT0000000303962960;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;1.0;00;00;4.6;17.7;22.3;25.5;18.5;Cadastre;C 0.4;POLYGON Z ((356115.9 6689848.6 22.3, 356127 6689854.4 22.3, 356124.2 6689860 22.3, 356115.7 6689855.7 22.3, 356117.5 6689852 22.3, 356115 6689850.2 22.3, 356112 6689855.9 22.3, 356115 6689857.5 22.3, 356123.3 6689861.8 22.3, 356127.7 6689864.1 22.3, 356134.3 6689852.5 22.3, 356118.7 6689844.5 22.3, 356116.3 6689847.8 22.3, 356115.9 6689848.6 22.3))
BATIMENT0000000303962956;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;17.8;22.5;32.7;18.4;Cadastre;;POLYGON Z ((356090.5 6689855.3 22.5, 356087.6 6689860.9 22.5, 356092.2 6689863.4 22.5, 356093.6 6689864.2 22.5, 356090.5 6689855.3 22.5))
BATIMENT0000000303962958;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;00;00;7.6;17.7;25.3;28.0;18.7;Cadastre;C 0.4;POLYGON Z ((356122.4 6689876.5 25.3, 356122.1 6689874.6 25.3, 356124.1 6689870.9 25.3, 356127.7 6689864.1 25.3, 356123.3 6689861.8 25.3, 356116.4 6689874.8 25.3, 356118.9 6689876.2 25.3, 356121.8 6689877.7 25.3, 356122.4 6689876.5 25.3))
BATIMENT0000000303962955;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;6.0;09;02;13.4;18.3;31.7;35.7;19.2;Cadastre;A 1.0;POLYGON Z ((356102.4 6689866.4 31.7, 356099.1 6689867.2 31.7, 356097.1 6689866.8 31.7, 356094.8 6689865.1 31.7, 356093.6 6689864.2 31.7, 356092.2 6689863.4 31.7, 356087.6 6689860.9 31.7, 356082.7 6689870.9 31.7, 356077.4 6689881.6 31.7, 356094.4 6689888.9 31.7, 356105 6689869.1 31.7, 356105.4 6689868.3 31.7, 356106.7 6689865.3 31.7, 356102.4 6689866.4 31.7))
BATIMENT0000000303962957;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;7.7;18.3;26.1;35.6;19.2;Cadastre;C 0.7;POLYGON Z ((356105.4 6689868.3 26.1, 356105 6689869.1 26.1, 356094.4 6689888.9 26.1, 356113.1 6689897 26.1, 356118.3 6689885.6 26.1, 356118 6689885.4 26.1, 356119.6 6689882.3 26.1, 356121 6689879.7 26.1, 356118.1 6689878 26.1, 356109.7 6689872.9 26.1, 356110 6689871.9 26.1, 356107.9 6689870.8 26.1, 356115 6689857.5 26.1, 356112 6689855.9 26.1, 356106.7 6689865.3 26.1, 356105.4 6689868.3 26.1), (356107 6689878.6 26.1, 356110.4 6689880.4 26.1, 356115.2 6689883.6 26.1, 356113.5 6689887.8 26.1, 356112.8 6689887.6 26.1, 356112.8 6689886.9 26.1, 356110.8 6689886.1 26.1, 356110.9 6689885.7 26.1, 356109 6689885 26.1, 356108.2 6689885.2 26.1, 356104.7 6689883.6 26.1, 356107 6689878.6 26.1))
BATIMENT0000000303962959;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;18.5;25.8;26.1;18.8;Cadastre;;POLYGON Z ((356121.8 6689877.7 25.8, 356118.9 6689876.2 25.8, 356118.1 6689878 25.8, 356121 6689879.7 25.8, 356121.8 6689877.7 25.8))
BATIMENT0000000303962962;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;52.0;6.0;00;00;16.1;18.0;34.1;38.0;18.9;Cadastre;A 0.7;POLYGON Z ((356140.2 6689909.1 34.1, 356151.3 6689896.4 34.1, 356119.6 6689882.3 34.1, 356118 6689885.4 34.1, 356118.3 6689885.6 34.1, 356113.1 6689897 34.1, 356140.2 6689909.1 34.1))
BATIMENT0000002011294303;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;3.2;19.7;;;;Imagerie aérienne;C 0.3;POLYGON Z ((356068.7 6689921.1 22.9, 356076.2 6689922.2 22.9, 356076.8 6689911.6 22.9, 356082.9 6689896.9 22.9, 356078.6 6689895.1 22.9, 356070.4 6689909.2 22.9, 356068.7 6689921.1 22.9))
BATIMENT0000002011295071;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;23.0;6.0;00;00;16.0;18.7;;36.1;19.7;Imagerie aérienne;C 0.5;POLYGON Z ((356076.8 6689911.6 33, 356096.2 6689920.6 33.2, 356102.1 6689923.2 33.9, 356104.3 6689919.2 34.7, 356103.1 6689918.3 34.7, 356106.4 6689911.8 34.7, 356107.6 6689912.4 34.7, 356108.7 6689908.6 33.8, 356082.9 6689896.9 33.8, 356076.8 6689911.6 33))
BATIMENT0000000303963083;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;18.4;21.5;24.8;18.7;Cadastre;A 0.1;POLYGON Z ((356148.6 6689910.3 21.5, 356147.3 6689909.3 21.5, 356145.5 6689911.4 21.5, 356147 6689912.1 21.5, 356148.6 6689910.3 21.5))
BATIMENT0000002011295836;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;23.0;6.0;00;00;18.0;19.7;;;;Imagerie aérienne;C 0.6;POLYGON Z ((356106.7 6689925.2 34.4, 356133.3 6689936.8 32.9, 356134.9 6689933.4 35.3, 356138.1 6689934.7 36, 356145.6 6689938.2 35.9, 356147.7 6689936.4 36.4, 356150.3 6689940.6 28.7, 356156.2 6689946.5 28.7, 356156.8 6689946.5 31.3, 356164.7 6689940.4 31.1, 356163.7 6689933.2 31, 356143.9 6689924.2 31.2, 356142.9 6689924.9 36.2, 356136.4 6689922.2 36.3, 356137.1 6689921.1 33.7, 356113.5 6689910.7 33.9, 356111.6 6689914.7 34.5, 356113.4 6689915.4 36.1, 356109.9 6689922.4 37.7, 356108.6 6689921.8 34.4, 356106.7 6689925.2 34.4))
BATIMENT0000002011296056;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;18.0;19.7;;;;Imagerie aérienne;C 0.1;POLYGON Z ((356090.3 6689933.2 23, 356097.5 6689936.1 22.6, 356100.6 6689928 23, 356105 6689929.9 22.7, 356103.8 6689932.6 22.8, 356116.4 6689937.5 25.3, 356115.3 6689940.3 25.4, 356104.8 6689948 25.3, 356106.5 6689950.4 25.3, 356099.1 6689957.8 23, 356106.7 6689965.4 22.6, 356124.7 6689946.6 22.6, 356126.5 6689947.5 22.5, 356129.2 6689940.7 25.2, 356133.3 6689936.8 32.9, 356106.7 6689925.2 34.4, 356108.6 6689921.8 34.4, 356109.9 6689922.4 37.7, 356113.4 6689915.4 36.1, 356111.6 6689914.7 34.5, 356113.5 6689910.7 33.9, 356108.7 6689908.6 33.8, 356107.6 6689912.4 34.7, 356106.4 6689911.8 34.7, 356103.1 6689918.3 34.7, 356104.3 6689919.2 34.7, 356102.1 6689923.2 33.9, 356096.2 6689920.6 33.2, 356090.3 6689933.2 23))
BATIMENT0000002011292825;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.6;19.0;;36.2;19.6;Imagerie aérienne;;POLYGON Z ((356132.4 6689950 22.6, 356145.6 6689938.2 22.6, 356138.1 6689934.7 22.6, 356132.4 6689950 22.6))
BATIMENT0000000303962399;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.0;18.9;29.0;31.2;19.8;Cadastre;A 1.0;POLYGON Z ((356120.4 6689967.8 29, 356121.2 6689968.8 29, 356122.5 6689970.3 29, 356123.7 6689971.8 29, 356125.4 6689974 29, 356140.3 6689961.8 29, 356156.2 6689946.5 29, 356152.2 6689942.4 29, 356150.3 6689940.6 29, 356139.9 6689950.9 29, 356122.7 6689965.2 29, 356119.6 6689961.5 29, 356117 6689963.6 29, 356120.4 6689967.8 29))
BATIMENT0000000303962398;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;19.6;26.5;26.9;19.9;Cadastre;;POLYGON Z ((356118.4 6689969.5 26.5, 356112.5 6689974.3 26.5, 356113.4 6689975.5 26.5, 356119.2 6689970.5 26.5, 356118.4 6689969.5 26.5))
BATIMENT0000000303962389;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.7;19.6;27.4;31.2;20.5;Cadastre;C 0.2;POLYGON Z ((356102.5 6689982.1 27.4, 356102.9 6689982.2 27.4, 356112.4 6689974.4 27.4, 356112.5 6689974.3 27.4, 356118.4 6689969.5 27.4, 356119.2 6689970.5 27.4, 356121.2 6689968.8 27.4, 356120.4 6689967.8 27.4, 356117 6689963.6 27.4, 356096.9 6689979.9 27.4, 356100.3 6689984.3 27.4, 356100.7 6689983.7 27.4, 356102.5 6689982.1 27.4))
BATIMENT0000000303962400;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;19.3;23.0;27.0;20.0;Cadastre;;POLYGON Z ((356113 6689978 23, 356112.9 6689978.1 23, 356112.7 6689978.2 23, 356112.7 6689978.3 23, 356112.6 6689978.5 23, 356112.5 6689978.5 23, 356112.5 6689978.7 23, 356112.4 6689978.9 23, 356112.4 6689979 23, 356112.4 6689979.1 23, 356112.3 6689979.2 23, 356112.3 6689979.5 23, 356112.3 6689979.6 23, 356112.4 6689979.7 23, 356112.4 6689979.8 23, 356112.5 6689980 23, 356112.5 6689980.1 23, 356114.6 6689982.6 23, 356123.3 6689975.3 23, 356125.4 6689974 23, 356123.7 6689971.8 23, 356122.5 6689970.3 23, 356113 6689978 23))
BATIMENT0000002011293509;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:56:49;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;7.0;3.0;00;00;8.9;20.5;;32.3;20.9;Imagerie aérienne;C 1.0;POLYGON Z ((356070.1 6689977.7 29.4, 356064.4 6689971.9 29.4, 356052 6689985.1 28.9, 356058.2 6689990.4 27.9, 356061.4 6689986.5 27.9, 356070.1 6689977.7 29.4))
BATIMENT0000000303962397;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;4.8;20.1;25.0;26.4;20.6;Cadastre;C 0.2;POLYGON Z ((356087.9 6689987.1 25, 356083.2 6689981.2 25, 356078.5 6689984.6 25, 356077.8 6689983.9 25, 356077.5 6689984.3 25, 356084 6689990.3 25, 356087.9 6689987.1 25))
BATIMENT0000000303963121;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;01;02;2.5;18.2;20.8;25.5;19.0;Cadastre;C 0.4;POLYGON Z ((356170.4 6689922.5 20.8, 356175.8 6689924.9 20.8, 356174.5 6689917.9 20.8, 356170.4 6689922.5 20.8))
BATIMENT0000000303963072;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;16.9;21.0;21.4;17.4;Cadastre;;POLYGON Z ((356278.9 6689930.2 21, 356273.6 6689924.5 21, 356269.8 6689928 21, 356275.1 6689933.7 21, 356278.9 6689930.2 21))
BATIMENT0000000303963073;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;16.9;21.0;21.4;17.4;Cadastre;;POLYGON Z ((356277.6 6689936.4 21, 356281.4 6689932.9 21, 356278.9 6689930.2 21, 356275.1 6689933.7 21, 356277.6 6689936.4 21))
BATIMENT0000000303963016;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.5;18.2;34.7;36.5;18.8;Cadastre;;POLYGON Z ((356195.9 6689946.5 34.7, 356198.8 6689951.6 34.7, 356202.2 6689949.4 34.7, 356195.9 6689946.5 34.7))
BATIMENT0000000303963015;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;7.0;30;20;16.5;18.4;35.0;38.8;19.5;Cadastre;A 1.0;POLYGON Z ((356179 6689943 35, 356166.5 6689953.2 35, 356169.4 6689956.7 35, 356168.5 6689957.4 35, 356174.3 6689964.3 35, 356180.1 6689959.7 35, 356179.7 6689959.2 35, 356182.7 6689956.9 35, 356194.8 6689962.2 35, 356195.2 6689961.8 35, 356196.6 6689962.5 35, 356201.2 6689967.9 35, 356204.2 6689965.5 35, 356212.1 6689959.5 35, 356209.2 6689956.3 35, 356209.7 6689955.9 35, 356205.6 6689950.9 35, 356202.2 6689949.4 35, 356198.8 6689951.6 35, 356195.9 6689946.5 35, 356186.1 6689942.1 35, 356179 6689943 35))
BATIMENT0000000303963014;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.7;20.1;30.8;;;Cadastre;;POLYGON Z ((356165.6 6689954 30.8, 356168.5 6689957.4 30.8, 356169.4 6689956.7 30.8, 356166.5 6689953.2 30.8, 356165.6 6689954 30.8))
BATIMENT0000000303962988;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.8;18.0;20.8;22.2;18.0;Cadastre;;POLYGON Z ((356273.2 6689967.6 20.8, 356303.3 6689981 20.8, 356305.9 6689976.8 20.8, 356296.5 6689970.8 20.8, 356298.3 6689967.6 20.8, 356298.6 6689967.3 20.8, 356298.8 6689966.5 20.8, 356298.9 6689966 20.8, 356298.9 6689965.3 20.8, 356298.9 6689964.4 20.8, 356298.8 6689963.6 20.8, 356298.5 6689963.1 20.8, 356298.2 6689962.6 20.8, 356297.5 6689961.6 20.8, 356297.9 6689961.1 20.8, 356295.6 6689959.8 20.8, 356295.1 6689960.5 20.8, 356294.6 6689960.2 20.8, 356294.3 6689960.1 20.8, 356293.6 6689960.1 20.8, 356292.8 6689960.1 20.8, 356292 6689960.3 20.8, 356291.1 6689960.8 20.8, 356290.4 6689961.4 20.8, 356287.8 6689965.5 20.8, 356278.3 6689959.6 20.8, 356273.2 6689967.6 20.8))
BATIMENT0000000303963120;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.2;19.0;22.2;23.5;20.3;Cadastre;;POLYGON Z ((356157.6 6689959.8 22.2, 356175.6 6689981.6 22.2, 356171.4 6689984.9 22.2, 356173.4 6689987.3 22.2, 356171.2 6689989.2 22.2, 356172.5 6689991 22.2, 356181.7 6689984.9 22.2, 356180.7 6689983.7 22.2, 356169.2 6689970 22.2, 356159.3 6689958.3 22.2, 356157.6 6689959.8 22.2))
BATIMENT0000000303962973;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.3;18.7;21.0;;;Cadastre;;POLYGON Z ((356246 6689969 21, 356242.4 6689973.2 21, 356247.6 6689981.7 21, 356249.2 6689980.7 21, 356252.5 6689978.6 21, 356250.7 6689975.8 21, 356255.3 6689973 21, 356246 6689969 21))
BATIMENT0000000303962975;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.1;17.8;22.0;25.4;18.5;Cadastre;C 0.2;POLYGON Z ((356255.3 6689973 22, 356250.7 6689975.8 22, 356252.5 6689978.6 22, 356257.4 6689975.6 22, 356259 6689974.6 22, 356255.3 6689973 22))
BATIMENT0000000303962976;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.4;17.8;22.2;32.7;18.4;Cadastre;C 0.1;POLYGON Z ((356259 6689974.6 22.2, 356257.4 6689975.6 22.2, 356259.9 6689979.4 22.2, 356261 6689978.9 22.2, 356262.5 6689981 22.2, 356264.7 6689977.1 22.2, 356259 6689974.6 22.2))
BATIMENT0000000303962977;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;8.2;17.7;26.0;32.2;18.2;Cadastre;C 0.5;POLYGON Z ((356263.8 6689982.7 26, 356266.6 6689984 26, 356269.1 6689979 26, 356266.3 6689977.8 26, 356264.1 6689982.1 26, 356263.8 6689982.7 26))
BATIMENT0000000303962978;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;5.5;17.7;23.2;33.0;18.3;Cadastre;C 0.5;POLYGON Z ((356269.4 6689985.3 23.2, 356271.9 6689980.3 23.2, 356269.1 6689979 23.2, 356266.6 6689984 23.2, 356269.4 6689985.3 23.2))
BATIMENT0000000303962979;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.8;18.7;21.5;;;Cadastre;C 0.5;POLYGON Z ((356272.3 6689986.6 21.5, 356274.7 6689981.5 21.5, 356271.9 6689980.3 21.5, 356269.4 6689985.3 21.5, 356272.3 6689986.6 21.5))
BATIMENT0000000303962980;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.1;18.6;21.7;23.9;18.7;Cadastre;C 0.5;POLYGON Z ((356275.3 6689987.9 21.7, 356277.6 6689982.8 21.7, 356274.7 6689981.5 21.7, 356272.3 6689986.6 21.7, 356275.3 6689987.9 21.7))
BATIMENT0000000303962981;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:49;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.4;18.6;22.0;22.0;19.0;Cadastre;C 0.5;POLYGON Z ((356278.1 6689989.2 22, 356280.6 6689984.1 22, 356277.6 6689982.8 22, 356275.3 6689987.9 22, 356278.1 6689989.2 22))
BATIMENT0000000303962982;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;17.6;20.3;20.4;19.0;Cadastre;C 0.5;POLYGON Z ((356280.9 6689990.5 20.3, 356283.4 6689985.3 20.3, 356280.6 6689984.1 20.3, 356278.1 6689989.2 20.3, 356280.9 6689990.5 20.3))
BATIMENT0000000303962983;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.4;17.6;20.1;20.5;19.2;Cadastre;C 0.5;POLYGON Z ((356283.9 6689991.8 20.1, 356286.2 6689986.5 20.1, 356283.4 6689985.3 20.1, 356280.9 6689990.5 20.1, 356283.9 6689991.8 20.1))
BATIMENT0000000303962974;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;20;20;19.0;18.7;37.7;38.9;19.8;Cadastre;A 1.0;POLYGON Z ((356263.1 6690003.7 37.7, 356273.8 6689997.1 37.7, 356268.7 6689988.7 37.7, 356267.6 6689989.4 37.7, 356263.1 6689982.3 37.7, 356264.1 6689982.1 37.7, 356266.3 6689977.8 37.7, 356264.7 6689977.1 37.7, 356262.5 6689981 37.7, 356261 6689978.9 37.7, 356259.9 6689979.4 37.7, 356257.4 6689975.6 37.7, 356252.5 6689978.6 37.7, 356249.2 6689980.7 37.7, 356263.1 6690003.7 37.7))
BATIMENT0000000303962984;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;17.5;20.4;24.2;19.2;Cadastre;;POLYGON Z ((356286.8 6689993.1 20.4, 356289.1 6689988.1 20.4, 356289.1 6689987.8 20.4, 356286.2 6689986.5 20.4, 356283.9 6689991.8 20.4, 356286.8 6689993.1 20.4))
BATIMENT0000000303962396;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;21.6;24.5;;;Cadastre;;POLYGON Z ((356097 6689988.8 24.5, 356097.4 6689990.2 24.5, 356098.7 6689990.8 24.5, 356100 6689989.4 24.5, 356098.3 6689987.6 24.5, 356097 6689988.8 24.5))
BATIMENT0000000303962384;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;00;00;7.9;21.0;28.9;31.2;21.4;Cadastre;A 1.0;POLYGON Z ((356056.5 6689999.2 28.9, 356061.9 6689993.5 28.9, 356058.2 6689990.4 28.9, 356052.4 6689985.5 28.9, 356047.3 6689981.1 28.9, 356043.9 6689983.8 28.9, 356056.5 6689999.2 28.9))
BATIMENT0000000303962388;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.1;20.3;24.5;25.7;20.5;Cadastre;C 0.2;POLYGON Z ((356080.4 6689988.6 24.5, 356076.8 6689991.6 24.5, 356079.1 6689994.3 24.5, 356082.9 6689991.2 24.5, 356080.4 6689988.6 24.5))
BATIMENT0000000303962386;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.4;20.9;25.3;26.0;21.1;Cadastre;A 0.4;POLYGON Z ((356075 6690004.8 25.3, 356077.1 6690003.4 25.3, 356096 6689987.2 25.3, 356095.5 6689986.5 25.3, 356096.4 6689985.5 25.3, 356098.3 6689987.6 25.3, 356100 6689989.4 25.3, 356102.3 6689992.9 25.3, 356106 6689989.9 25.3, 356102.9 6689986.2 25.3, 356100.7 6689983.7 25.3, 356100.3 6689984.3 25.3, 356096.9 6689979.9 25.3, 356094.3 6689982 25.3, 356087.9 6689987.1 25.3, 356084 6689990.3 25.3, 356082.9 6689991.2 25.3, 356079.1 6689994.3 25.3, 356074.4 6689998.1 25.3, 356071.7 6690000.3 25.3, 356075 6690004.8 25.3))
BATIMENT0000000303962385;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;6.9;21.0;27.9;30.1;21.2;Cadastre;C 0.1;POLYGON Z ((356061.9 6689993.5 27.9, 356070.8 6690001 27.9, 356071.7 6690000.3 27.9, 356074.4 6689998.1 27.9, 356061.4 6689986.5 27.9, 356058.2 6689990.4 27.9, 356061.9 6689993.5 27.9))
BATIMENT0000000303963076;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;20.8;23.4;23.6;20.8;Cadastre;;POLYGON Z ((356081.2 6690003.5 23.4, 356080.6 6690005.5 23.4, 356082.2 6690007.5 23.4, 356097.7 6689994.8 23.4, 356095.3 6689992.3 23.4, 356081.2 6690003.5 23.4))
BATIMENT0000000303962967;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.3;20.2;30.5;33.6;20.7;Cadastre;B 0.8;POLYGON Z ((356126.3 6689996.5 30.5, 356137.7 6690010.5 30.5, 356137.5 6690010.7 30.5, 356141.6 6690015.5 30.5, 356151.3 6690007.7 30.5, 356147.1 6690002.7 30.5, 356147.3 6690002.6 30.5, 356136 6689988.6 30.5, 356126.3 6689996.5 30.5))
BATIMENT0000000303962387;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.7;20.5;25.2;30.7;21.2;Cadastre;B 1.0;POLYGON Z ((356054.2 6690001.6 25.2, 356051.9 6689999.6 25.2, 356048.3 6690003.4 25.2, 356050.2 6690005.2 25.2, 356054.2 6690001.6 25.2))
BATIMENT0000000303962383;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;00;00;12.8;20.7;33.5;35.2;21.6;Cadastre;C 0.3;POLYGON Z ((356070.8 6690001 33.5, 356061.9 6689993.5 33.5, 356056.5 6689999.2 33.5, 356054.2 6690001.6 33.5, 356050.2 6690005.2 33.5, 356045.6 6690009.8 33.5, 356045.5 6690010 33.5, 356047.4 6690012.1 33.5, 356050.9 6690009.6 33.5, 356052.1 6690011 33.5, 356058.5 6690005.2 33.5, 356056.7 6690003.7 33.5, 356058.7 6690000.6 33.5, 356063.4 6690004.2 33.5, 356060.5 6690007.7 33.5, 356051.5 6690016.5 33.5, 356052.3 6690017.5 33.5, 356057.3 6690013.8 33.5, 356061.4 6690010.4 33.5, 356066.5 6690005.2 33.5, 356070.8 6690001 33.5))
BATIMENT0000000303967637;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;21.4;;;;Cadastre;;POLYGON Z ((356077.7 6690008.1 -1000, 356079.6 6690006.5 -1000, 356077.1 6690003.4 -1000, 356075 6690004.8 -1000, 356077.7 6690008.1 -1000))
BATIMENT0000000303962990;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;17.0;20.7;24.5;17.7;Cadastre;;POLYGON Z ((356333.5 6689984.7 20.7, 356337.6 6689987.3 20.7, 356335.9 6689989.9 20.7, 356331.7 6689987.2 20.7, 356328.6 6689991.8 20.7, 356348.5 6690000.6 20.7, 356350.2 6689998 20.7, 356354.3 6690000.8 20.7, 356363.4 6689987.1 20.7, 356358.7 6689984.1 20.7, 356353.9 6689991.3 20.7, 356341.2 6689983 20.7, 356346.1 6689975.7 20.7, 356341.6 6689972.7 20.7, 356333.5 6689984.7 20.7))
BATIMENT0000000303963022;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;17.6;20.8;;;Cadastre;;POLYGON Z ((356376.2 6689994.2 20.8, 356376.2 6689996.5 20.8, 356370.6 6689996.6 20.8, 356370.6 6690000.7 20.8, 356387.4 6690000.6 20.8, 356387.3 6689996.6 20.8, 356381.8 6689996.6 20.8, 356381.8 6689994.1 20.8, 356376.2 6689994.2 20.8))
BATIMENT0000000303962986;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;00;00;16.2;17.4;33.7;37.7;18.1;Cadastre;A 1.0;POLYGON Z ((356323.7 6690014.6 33.7, 356325.1 6690012.2 33.7, 356329 6690005.5 33.7, 356310.2 6689997.3 33.7, 356306.3 6690006.7 33.7, 356323.7 6690014.6 33.7))
BATIMENT0000000303969105;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;17.3;21.3;;;Cadastre;;POLYGON Z ((356400.9 6690005.8 21.3, 356399.2 6690011.7 21.3, 356398.7 6690011.7 21.3, 356398.4 6690012.6 21.3, 356412.3 6690016.1 21.3, 356414.1 6690008.3 21.3, 356401.6 6690005.2 21.3, 356400.9 6690005.8 21.3))
BATIMENT0000000303969737;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;;;7.8;17.4;25.2;27.0;18.2;Cadastre;C 0.9;POLYGON Z ((356335.3 6690013.3 25.2, 356334.6 6690007.9 25.2, 356329 6690005.5 25.2, 356325.1 6690012.2 25.2, 356328.4 6690015.4 25.2, 356323.4 6690020.8 25.2, 356325.8 6690023 25.2, 356335.3 6690013.3 25.2))
BATIMENT0000000303969736;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.3;18.1;23.4;26.7;18.2;Cadastre;;POLYGON Z ((356323.4 6690020.8 23.4, 356328.4 6690015.4 23.4, 356325.1 6690012.2 23.4, 356323.7 6690014.6 23.4, 356321.1 6690018.5 23.4, 356321.7 6690019.2 23.4, 356323.4 6690020.8 23.4))
BATIMENT0000000303967757;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.9;18.4;21.3;21.8;18.6;Cadastre;A 1.0;POLYGON Z ((356311.1 6690030 21.3, 356312.2 6690031.1 21.3, 356315 6690033.8 21.3, 356325.8 6690023 21.3, 356323.4 6690020.8 21.3, 356321.7 6690019.2 21.3, 356311.1 6690030 21.3))
BATIMENT0000000303969326;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;4.0;16.7;20.8;23.7;17.0;Cadastre;B 0.4;POLYGON Z ((356394 6690025.8 20.8, 356406.5 6690032.6 20.8, 356408.1 6690029 20.8, 356394.1 6690025.2 20.8, 356394 6690025.8 20.8))
BATIMENT0000000303967758;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;18.4;22.0;26.3;19.2;Cadastre;;POLYGON Z ((356308.1 6690035.1 22, 356310.9 6690037.9 22, 356315 6690033.8 22, 356312.2 6690031.1 22, 356308.1 6690035.1 22))
BATIMENT0000000303969165;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.6;18.2;30.8;;;Cadastre;;POLYGON Z ((356395.3 6690041.7 30.8, 356422.2 6690056.4 30.8, 356423 6690055.1 30.8, 356396 6690040.3 30.8, 356395.3 6690041.7 30.8))
BATIMENT0000000303962985;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;30;20;16.2;17.5;33.7;37.8;19.7;Cadastre;A 1.0;POLYGON Z ((356289.3 6689995 33.7, 356296.3 6690004.7 33.7, 356300.8 6690006.6 33.7, 356301.7 6690004.7 33.7, 356302.8 6690005 33.7, 356306.3 6690006.7 33.7, 356310.2 6689997.3 33.7, 356289.1 6689988.1 33.7, 356286.8 6689993.1 33.7, 356285.5 6689995.9 33.7, 356284.1 6689998.4 33.7, 356286.1 6690001.3 33.7, 356287.5 6689998.7 33.7, 356289.3 6689995 33.7))
BATIMENT0000000303963075;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:50;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.4;18.5;24.9;36.3;22.0;Cadastre;C 0.3;POLYGON Z ((356183 6690008.7 24.9, 356186.7 6690013.2 24.9, 356177.5 6690020.7 24.9, 356180.6 6690024.6 24.9, 356189.9 6690017 24.9, 356204.2 6690034.4 24.9, 356242.9 6690002.8 24.9, 356227.7 6689984.2 24.9, 356222.1 6689977.2 24.9, 356216.9 6689970.9 24.9, 356207.9 6689978.3 24.9, 356207.3 6689977.6 24.9, 356182.9 6689997.6 24.9, 356179.1 6690000.7 24.9, 356179.9 6690001.6 24.9, 356178.5 6690002.7 24.9, 356177.8 6690001.8 24.9, 356177.5 6690002 24.9, 356181.4 6690006.7 24.9, 356183 6690008.7 24.9))
BATIMENT0000000303963102;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2023-01-31 17:56:48;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;20;20;14.1;18.7;32.9;37.4;20.3;Cadastre;A 1.0;POLYGON Z ((356280.1 6690019.1 32.9, 356284.3 6690016.5 32.9, 356281.5 6690011.9 32.9, 356286.2 6690008.9 32.9, 356279.6 6689998.3 32.9, 356270.9 6690003.7 32.9, 356272.3 6690006.3 32.9, 356264.7 6690011 32.9, 356277.8 6690032.4 32.9, 356284.2 6690025.6 32.9, 356280.1 6690019.1 32.9))
BATIMENT0000000303969129;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.5;19.9;28.4;31.1;20.0;Cadastre;A 1.0;POLYGON Z ((356284.1 6690042.7 28.4, 356291.9 6690038.1 28.4, 356284.2 6690025.6 28.4, 356277.8 6690032.4 28.4, 356284.1 6690042.7 28.4))
BATIMENT0000000303969071;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;18.9;24.3;27.6;21.3;Cadastre;;POLYGON Z ((356250.8 6690041.1 24.3, 356262.6 6690031 24.3, 356247 6690011.9 24.3, 356234.9 6690021.7 24.3, 356235.5 6690022.3 24.3, 356195.9 6690054.5 24.3, 356197 6690055.8 24.3, 356203.8 6690064.2 24.3, 356204 6690064.1 24.3, 356205.8 6690062.8 24.3, 356221.6 6690050.6 24.3, 356228.4 6690045.4 24.3, 356236.3 6690039.3 24.3, 356242.9 6690034.2 24.3, 356248.6 6690040.7 24.3, 356250.7 6690041.3 24.3, 356250.8 6690041.1 24.3))
BATIMENT0000000303969078;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;20;20;7.0;20.9;27.9;;;Cadastre;A 1.0;POLYGON Z ((356264.3 6690038.7 27.9, 356259 6690042.9 27.9, 356260.3 6690044.3 27.9, 356262.9 6690042.8 27.9, 356265.9 6690047.6 27.9, 356263.5 6690049.3 27.9, 356264.5 6690050.7 27.9, 356266.5 6690049.3 27.9, 356274.3 6690044.9 27.9, 356268.9 6690036.1 27.9, 356264.3 6690038.7 27.9))
BATIMENT0000000303969130;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;00;00;8.8;19.4;28.2;30.9;19.6;Cadastre;A 1.0;POLYGON Z ((356291.6 6690055 28.2, 356294.7 6690055.3 28.2, 356299.5 6690050.4 28.2, 356291.9 6690038.1 28.2, 356284.1 6690042.7 28.2, 356291.6 6690055 28.2))
BATIMENT0000000303969073;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.2;20.2;29.5;32.0;21.1;Cadastre;A 1.0;POLYGON Z ((356236.3 6690039.3 29.5, 356228.4 6690045.4 29.5, 356238.6 6690056.8 29.5, 356246.2 6690050.9 29.5, 356236.3 6690039.3 29.5))
BATIMENT0000000303969077;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.6;20.9;29.5;;;Cadastre;A 1.0;POLYGON Z ((356277.6 6690054 29.5, 356279.2 6690053 29.5, 356274.9 6690046 29.5, 356265.6 6690052 29.5, 356270.3 6690059.1 29.5, 356277 6690054.4 29.5, 356277.6 6690054 29.5))
BATIMENT0000000303969074;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;36;20;4.3;20.1;24.5;26.1;20.6;Cadastre;A 1.0;POLYGON Z ((356237.5 6690060 24.5, 356241.4 6690064.9 24.5, 356252.4 6690056.1 24.5, 356248.3 6690051.4 24.5, 356237.5 6690060 24.5))
BATIMENT0000000302928760;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.7;7.2;16.0;18.4;7.9;Cadastre;A 1.0;POLYGON Z ((354099.7 6689270 16, 354093.3 6689263.6 16, 354088.4 6689268.5 16, 354094.7 6689275 16, 354099.7 6689270 16))
BATIMENT0000000302928762;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;8.6;7.3;16.0;18.5;7.9;Cadastre;A 1.0;POLYGON Z ((354094.7 6689275 16, 354088.4 6689268.5 16, 354083.4 6689273.3 16, 354090 6689279.7 16, 354094.7 6689275 16))
BATIMENT0000000302928766;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;8.5;7.4;16.0;18.7;8.1;Cadastre;A 1.0;POLYGON Z ((354090 6689279.7 16, 354083.4 6689273.3 16, 354079 6689277.8 16, 354085.6 6689284.3 16, 354090 6689279.7 16))
BATIMENT0000000302928769;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;23;9.3;7.6;16.9;18.6;8.2;Cadastre;A 1.0;POLYGON Z ((354085.6 6689284.3 16.9, 354079 6689277.8 16.9, 354073.9 6689282.7 16.9, 354080.6 6689289.2 16.9, 354080.9 6689289.5 16.9, 354085.9 6689284.7 16.9, 354085.6 6689284.3 16.9))
BATIMENT0000000302928770;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.3;7.7;18.1;20.7;8.1;Cadastre;A 1.0;POLYGON Z ((354080.6 6689289.2 18.1, 354073.9 6689282.7 18.1, 354069.3 6689287.2 18.1, 354076 6689293.8 18.1, 354080.6 6689289.2 18.1))
BATIMENT0000000302928771;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.3;9.3;15.6;;;Cadastre;A 1.0;POLYGON Z ((354076 6689293.8 15.6, 354069.3 6689287.2 15.6, 354062.6 6689293.9 15.6, 354070.5 6689301.3 15.6, 354077.1 6689294.8 15.6, 354076 6689293.8 15.6))
BATIMENT0000000302928772;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;13.4;7.8;21.2;23.4;8.4;Cadastre;B 0.7;POLYGON Z ((354070.5 6689301.3 21.2, 354062.6 6689293.9 21.2, 354050 6689306.1 21.2, 354055.7 6689312.2 21.2, 354058.5 6689315 21.2, 354071.5 6689302.5 21.2, 354070.5 6689301.3 21.2))
BATIMENT0000000302928773;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;23;20;9.0;8.9;17.9;;;Cadastre;A 1.0;POLYGON Z ((354055.7 6689312.2 17.9, 354050 6689306.1 17.9, 354043.3 6689312.7 17.9, 354049.1 6689318.6 17.9, 354055.7 6689312.2 17.9))
BATIMENT0000000302928813;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;10;7.6;10.7;18.3;22.5;12.0;Cadastre;A 1.0;POLYGON Z ((354098.3 6689318.3 18.3, 354094.6 6689316.5 18.3, 354095.7 6689314.4 18.3, 354091.2 6689312.3 18.3, 354088.5 6689317.7 18.3, 354086.2 6689316.5 18.3, 354083.6 6689320.8 18.3, 354087.4 6689322.7 18.3, 354087.5 6689322.3 18.3, 354091.1 6689324.4 18.3, 354091.3 6689324 18.3, 354093.5 6689324.9 18.3, 354093.2 6689325.5 18.3, 354094.3 6689325.8 18.3, 354095 6689324.5 18.3, 354097.4 6689320.1 18.3, 354098.3 6689318.3 18.3))
BATIMENT0000000302928817;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;7.7;7.9;15.7;18.5;11.6;Cadastre;B 0.3;POLYGON Z ((354076.6 6689319.7 15.7, 354073.2 6689325.7 15.7, 354077.6 6689328.5 15.7, 354079.2 6689325.7 15.7, 354080.2 6689326.1 15.7, 354082.2 6689323 15.7, 354076.6 6689319.7 15.7))
BATIMENT0000000302906075;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.7;8.6;12.3;24.7;13.0;Cadastre;C 0.4;POLYGON Z ((353973.3 6689285.9 12.3, 353965.8 6689270.9 12.3, 353954.8 6689276.5 12.3, 353962.9 6689292.2 12.3, 353973.3 6689285.9 12.3))
BATIMENT0000000302903439;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;6.0;00;00;1.9;8.9;10.9;27.4;11.0;Cadastre;A 1.0;POLYGON Z ((354024.6 6689261.6 10.9, 354019.2 6689251.8 10.9, 353985.1 6689268.8 10.9, 353988.8 6689276.3 10.9, 353994.3 6689286.7 10.9, 354001.1 6689300.1 10.9, 354006 6689309.8 10.9, 354009.5 6689316.3 10.9, 354019.6 6689311.2 10.9, 354018.4 6689308.9 10.9, 354027.4 6689304.1 10.9, 354026.2 6689301.7 10.9, 354032.5 6689298.3 10.9, 354031.6 6689296.5 10.9, 354040.6 6689291.7 10.9, 354040.1 6689290.8 10.9, 354034 6689279.2 10.9, 354024.6 6689261.6 10.9))
BATIMENT0000000302906076;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;00;00;17.7;11.4;29.2;29.9;12.8;Cadastre;C 0.6;POLYGON Z ((353962.9 6689292.2 29.2, 353954.8 6689276.5 29.2, 353951.1 6689278.4 29.2, 353942.6 6689282.9 29.2, 353950.9 6689299.6 29.2, 353962.9 6689292.2 29.2))
BATIMENT0000000302903446;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.4;10.3;20.8;22.4;11.6;Cadastre;A 1.0;POLYGON Z ((353952.3 6689302.3 20.8, 353956.2 6689310.2 20.8, 353960.1 6689308.3 20.8, 353959.8 6689307.8 20.8, 353963.6 6689306.1 20.8, 353959.7 6689298.6 20.8, 353952.3 6689302.3 20.8))
BATIMENT0000000302903445;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.7;9.0;25.7;29.2;11.5;Cadastre;;POLYGON Z ((353969 6689303.7 25.7, 353956.9 6689311.7 25.7, 353958.4 6689314.7 25.7, 353970.5 6689306.5 25.7, 353969 6689303.7 25.7))
BATIMENT0000000302903443;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;00;00;17.4;9.3;26.7;29.2;11.2;Cadastre;A 1.0;POLYGON Z ((353970.5 6689306.5 26.7, 353958.4 6689314.7 26.7, 353963.9 6689325.8 26.7, 353972.6 6689321.4 26.7, 353976.3 6689318.4 26.7, 353970.5 6689306.5 26.7))
BATIMENT0000000302903441;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.9;9.0;18.9;25.2;9.8;Cadastre;A 1.0;POLYGON Z ((354001.7 6689313.9 18.9, 354002.2 6689314.6 18.9, 353995.2 6689321.6 18.9, 354002.5 6689329.3 18.9, 354011.7 6689320.3 18.9, 354009.5 6689316.3 18.9, 354006 6689309.8 18.9, 354001.7 6689313.9 18.9))
BATIMENT0000000302903442;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;20;20;18.2;9.0;27.2;30.0;10.8;Cadastre;A 1.0;POLYGON Z ((353985.8 6689311.6 27.2, 353976.3 6689318.4 27.2, 353972.6 6689321.4 27.2, 353963.9 6689325.8 27.2, 353965.7 6689329.7 27.2, 353971.2 6689328.9 27.2, 353976.7 6689328.9 27.2, 353982.1 6689329.5 27.2, 353987.7 6689331 27.2, 353993.2 6689333.2 27.2, 353996.6 6689335 27.2, 354002.5 6689329.3 27.2, 353995.2 6689321.6 27.2, 353985.8 6689311.6 27.2))
BATIMENT0000000302928784;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.5;9.2;27.7;30.7;9.6;Cadastre;A 1.0;POLYGON Z ((354021.2 6689334.3 27.7, 354017.2 6689338.1 27.7, 354022.7 6689343.6 27.7, 354026.6 6689339.7 27.7, 354021.2 6689334.3 27.7))
BATIMENT0000000302929239;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;50;20;18.8;9.3;28.2;30.9;10.1;Cadastre;C 0.9;POLYGON Z ((354011.6 6689350.7 28.2, 354012.6 6689353.1 28.2, 354013.4 6689355.6 28.2, 354014.2 6689358.1 28.2, 354014.7 6689360.7 28.2, 354017.4 6689360.9 28.2, 354025.4 6689360.6 28.2, 354022.1 6689351.6 28.2, 354022.6 6689350.1 28.2, 354022 6689346.9 28.2, 354025.7 6689343.4 28.2, 354027.9 6689341.1 28.2, 354026.6 6689339.7 28.2, 354022.7 6689343.6 28.2, 354017.2 6689338.1 28.2, 354011.7 6689343.5 28.2, 354010.5 6689344.8 28.2, 354010.5 6689348.3 28.2, 354011.6 6689350.7 28.2))
BATIMENT0000000302903486;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.2;11.5;20.7;22.4;13.8;Cadastre;A 0.8;POLYGON Z ((353931.2 6689322 20.7, 353939.2 6689318.5 20.7, 353935 6689309.8 20.7, 353927 6689313.3 20.7, 353931.2 6689322 20.7))
BATIMENT0000000302903468;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.8;16.5;23.3;25.6;16.9;Cadastre;A 1.0;POLYGON Z ((353892.9 6689323.7 23.3, 353899.9 6689315.8 23.3, 353892.0022898072 6689309.635933508 23.3, 353892.0022898072 6689322.999048206 23.3, 353892.9 6689323.7 23.3))
BATIMENT0000000302903470;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.9;14.5;18.4;19.3;15.8;Cadastre;A 0.3;POLYGON Z ((353910.9 6689314.9 18.4, 353909.2 6689315.7 18.4, 353911.1 6689319.6 18.4, 353912.7 6689318.9 18.4, 353910.9 6689314.9 18.4))
BATIMENT0000000302903467;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1871-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.3;14.9;24.3;26.4;15.9;Cadastre;A 1.0;POLYGON Z ((353899.9 6689317.7 24.3, 353894.9 6689325.3 24.3, 353902.6 6689331.1 24.3, 353907.6 6689324.7 24.3, 353899.9 6689317.7 24.3))
BATIMENT0000000302903466;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;14.5;20.1;21.0;15.8;Cadastre;;POLYGON Z ((353910.3 6689325.4 20.1, 353908.7 6689323.1 20.1, 353908 6689323.9 20.1, 353909.4 6689325.9 20.1, 353910.3 6689325.4 20.1))
BATIMENT0000000302903488;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;30;9.0;11.2;20.3;21.6;13.1;Cadastre;A 1.0;POLYGON Z ((353935.7 6689330.5 20.3, 353936.3 6689331.7 20.3, 353943.8 6689327.5 20.3, 353939.2 6689318.5 20.3, 353931.2 6689322 20.3, 353935.7 6689330.5 20.3))
BATIMENT0000000302903465;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;14.0;18.6;19.0;14.6;Cadastre;;POLYGON Z ((353915.7 6689330.4 18.6, 353914.7 6689328.8 18.6, 353913.3 6689329.3 18.6, 353914.4 6689331 18.6, 353915.7 6689330.4 18.6))
BATIMENT0000000302903508;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;5.0;00;00;13.5;15.4;29.0;31.7;17.1;Cadastre;C 0.8;POLYGON Z ((353894.6 6689337.5 29, 353893.2 6689335.1 29, 353892.0022898072 6689334.104801192 29, 353892.0022898072 6689339.266442931 29, 353894.6 6689337.5 29))
BATIMENT0000000302903489;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;11.8;19.7;20.2;12.7;Cadastre;;POLYGON Z ((353934.6 6689331 19.7, 353935.2 6689332.2 19.7, 353936.3 6689331.7 19.7, 353935.7 6689330.5 19.7, 353934.6 6689331 19.7))
BATIMENT0000000302903464;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;6.6;14.3;21.0;25.0;15.7;Cadastre;A 1.0;POLYGON Z ((353907.8 6689339.1 21, 353915.8 6689333.9 21, 353916.3 6689333.6 21, 353914.4 6689331 21, 353913.3 6689329.3 21, 353911 6689326.3 21, 353909.4 6689327.1 21, 353908.9 6689326.3 21, 353909.4 6689325.9 21, 353908 6689323.9 21, 353907.6 6689324.7 21, 353902.6 6689331.1 21, 353907.8 6689339.1 21))
BATIMENT0000000302928815;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;7.5;10.7;18.2;19.7;11.9;Cadastre;A 1.0;POLYGON Z ((354082.2 6689323 18.2, 354080.2 6689326.1 18.2, 354079.2 6689327.6 18.2, 354083.9 6689329.9 18.2, 354086.8 6689325.1 18.2, 354086.2 6689324.8 18.2, 354087.4 6689322.7 18.2, 354083.6 6689320.8 18.2, 354082.2 6689323 18.2))
BATIMENT0000000302928774;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.9;7.6;18.5;20.1;9.0;Cadastre;A 1.0;POLYGON Z ((354049.1 6689318.6 18.5, 354043.3 6689312.7 18.5, 354035.7 6689320 18.5, 354054 6689338.2 18.5, 354057.9 6689330.3 18.5, 354059.1 6689328 18.5, 354056.8 6689326.8 18.5, 354049.1 6689318.6 18.5))
BATIMENT0000000302928811;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.7;11.8;22.6;23.5;12.0;Cadastre;A 1.0;POLYGON Z ((354097.4 6689320.1 22.6, 354095 6689324.5 22.6, 354097.9 6689325.9 22.6, 354097.5 6689326.5 22.6, 354098.2 6689328.2 22.6, 354098.8 6689328.4 22.6, 354097.2 6689331.1 22.6, 354101.4 6689333.3 22.6, 354106 6689324.6 22.6, 354097.4 6689320.1 22.6))
BATIMENT0000000302928814;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;11.8;15.3;17.7;12.0;Cadastre;;POLYGON Z ((354089.8 6689328.5 15.3, 354093.4 6689330.2 15.3, 354093.9 6689329.3 15.3, 354094.5 6689327.9 15.3, 354091.3 6689326.3 15.3, 354089.8 6689328.5 15.3))
BATIMENT0000000302928816;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;9.5;15.0;18.5;11.9;Cadastre;;POLYGON Z ((354077.5 6689330.3 15, 354077 6689331.1 15, 354081.9 6689333.7 15, 354083.9 6689329.9 15, 354079.2 6689327.6 15, 354077.5 6689330.3 15))
BATIMENT0000000302928780;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.9;8.4;16.3;18.1;9.4;Cadastre;C 0.4;POLYGON Z ((354049.8 6689340.8 16.3, 354051.7 6689342.7 16.3, 354054 6689338.2 16.3, 354035.7 6689320 16.3, 354026.8 6689328.8 16.3, 354033.3 6689335.7 16.3, 354044.1 6689346.4 16.3, 354049.8 6689340.8 16.3))
BATIMENT0000000302928781;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;9.0;17.0;21.0;9.4;Cadastre;A 1.0;POLYGON Z ((354026.6 6689339.7 17, 354027.9 6689341.1 17, 354033.3 6689335.7 17, 354026.8 6689328.8 17, 354021.2 6689334.3 17, 354026.6 6689339.7 17))
BATIMENT0000000302929236;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.8;9.8;12.6;;;Cadastre;;POLYGON Z ((354052 6689347.6 12.6, 354052.3 6689344.2 12.6, 354055.3 6689344.2 12.6, 354056.1 6689342.3 12.6, 354055.8 6689341.1 12.6, 354060.3 6689331.7 12.6, 354057.9 6689330.3 12.6, 354054 6689338.2 12.6, 354051.7 6689342.7 12.6, 354049.7 6689346.6 12.6, 354052 6689347.6 12.6))
BATIMENT0000000302928775;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;9.8;9.1;19.0;21.7;11.9;Cadastre;A 1.0;POLYGON Z ((354081.3 6689340.2 19, 354080.7 6689340.1 19, 354078.7 6689339.6 19, 354079.4 6689338.3 19, 354074.2 6689335.7 19, 354073.2 6689338 19, 354071 6689344.9 19, 354076.9 6689346.6 19, 354079.1 6689347.2 19, 354081.3 6689340.2 19))
BATIMENT0000000302928776;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;11.1;19.1;22.6;12.2;Cadastre;A 0.4;POLYGON Z ((354086.1 6689349 19.1, 354088.2 6689342.4 19.1, 354087.5 6689342.1 19.1, 354081.3 6689340.2 19.1, 354079.1 6689347.2 19.1, 354086.1 6689349 19.1))
BATIMENT0000000302903490;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;10.9;20.7;22.6;12.5;Cadastre;A 1.0;POLYGON Z ((353939.5 6689338.1 20.7, 353937.5 6689340.8 20.7, 353935.8 6689340.1 20.7, 353934.4 6689342.5 20.7, 353934.6 6689343.1 20.7, 353934.3 6689343.6 20.7, 353932.4 6689344 20.7, 353931 6689346.8 20.7, 353932 6689347.2 20.7, 353939.5 6689351.6 20.7, 353941 6689348.8 20.7, 353942.6 6689346.1 20.7, 353944.4 6689343.6 20.7, 353946.5 6689341.2 20.7, 353948.6 6689338.9 20.7, 353948.8 6689337.4 20.7, 353943.8 6689327.5 20.7, 353936.3 6689331.7 20.7, 353939.5 6689338.1 20.7))
BATIMENT0000000302903463;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;13.5;22.2;23.7;14.8;Cadastre;;POLYGON Z ((353912.5 6689345.9 22.2, 353914.5 6689344.5 22.2, 353920.2 6689340.5 22.2, 353915.8 6689333.9 22.2, 353907.8 6689339.1 22.2, 353912.5 6689345.9 22.2))
BATIMENT0000000302903510;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;5.9;14.9;20.8;25.2;17.5;Cadastre;A 1.0;POLYGON Z ((353896.8 6689341.5 20.8, 353894.6 6689337.5 20.8, 353892.0022898072 6689339.266442931 20.8, 353892.0022898072 6689344.378626116 20.8, 353896.8 6689341.5 20.8))
BATIMENT0000000302903514;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;15.1;18.5;21.2;17.7;Cadastre;;POLYGON Z ((353892.5 6689345.5 18.5, 353892.0022898072 6689344.788985439 18.5, 353892.0022898072 6689345.838866514 18.5, 353892.5 6689345.5 18.5))
BATIMENT0000000302903516;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.6;14.3;20.0;22.9;16.2;Cadastre;A 1.0;POLYGON Z ((353893 6689346.5 20, 353892.0022898072 6689347.098626116 20, 353892.0022898072 6689352.198643077 20, 353894.7 6689350.6 20, 353900.3 6689347.4 20, 353896.8 6689341.5 20, 353892.0022898072 6689344.378626116 20, 353892.0022898072 6689344.788985439 20, 353892.5 6689345.5 20, 353893 6689346.5 20))
BATIMENT0000002275362685;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:32:42;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;10.2;12.0;;22.7;14.2;Imagerie aérienne;;POLYGON Z ((353924 6689351.8 21.4, 353917.7 6689342.3 22.2, 353914.5 6689344.5 22.2, 353912.5 6689345.9 22.2, 353918.7 6689355.4 21.4, 353924 6689351.8 21.4))
BATIMENT0000000302903518;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;39;24;5.4;14.0;19.5;21.0;15.1;Cadastre;C 0.5;POLYGON Z ((353902.4 6689350.9 19.5, 353900.3 6689347.4 19.5, 353894.7 6689350.6 19.5, 353895.4 6689351.7 19.5, 353896.7 6689354.1 19.5, 353902.4 6689350.9 19.5))
BATIMENT0000000302903517;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;14.6;19.4;20.0;15.3;Cadastre;;POLYGON Z ((353892.0022898072 6689352.198643077 19.4, 353892.0022898072 6689352.203925384 19.4, 353892.7 6689353.4 19.4, 353895.4 6689351.7 19.4, 353894.7 6689350.6 19.4, 353892.0022898072 6689352.198643077 19.4))
BATIMENT0000000302903491;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.1;11.0;19.2;22.0;12.4;Cadastre;A 1.0;POLYGON Z ((353930.9 6689348.1 19.2, 353927.7 6689357.3 19.2, 353930.2 6689358.3 19.2, 353936.8 6689360.2 19.2, 353937.8 6689356.1 19.2, 353939.5 6689351.6 19.2, 353932 6689347.2 19.2, 353930.9 6689348.1 19.2))
BATIMENT0000000302903521;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;14.7;19.1;20.2;17.3;Cadastre;;POLYGON Z ((353893.9 6689355.6 19.1, 353892.7 6689353.4 19.1, 353892.0022898072 6689352.203925384 19.1, 353892.0022898072 6689356.698674322 19.1, 353893.9 6689355.6 19.1))
BATIMENT0000000302929237;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;20;2.8;9.8;12.6;14.2;11.3;Cadastre;B 0.2;POLYGON Z ((354056.5 6689351 12.6, 354060.1 6689351.5 12.6, 354063.4 6689351.9 12.6, 354064.5 6689348.6 12.6, 354070.9 6689349.4 12.6, 354071.5 6689347.7 12.6, 354071.1 6689346.6 12.6, 354066.7 6689345.1 12.6, 354055.3 6689344.2 12.6, 354052.3 6689344.2 12.6, 354052 6689347.6 12.6, 354051.4 6689350.4 12.6, 354056.5 6689351 12.6))
BATIMENT0000000302928777;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;11.1;19.1;21.2;12.4;Cadastre;A 1.0;POLYGON Z ((354087 6689350.7 19.1, 354089.7 6689351.6 19.1, 354089 6689353.5 19.1, 354086.7 6689352.9 19.1, 354085.4 6689352.2 19.1, 354084.6 6689352.5 19.1, 354083.7 6689355.1 19.1, 354090.4 6689356.8 19.1, 354094.8 6689345.6 19.1, 354095.2 6689344.7 19.1, 354088.2 6689342.4 19.1, 354086.1 6689349 19.1, 354087 6689350.7 19.1))
BATIMENT0000000302929238;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;9.3;12.6;13.9;10.3;Cadastre;;POLYGON Z ((354029.8 6689348.5 12.6, 354029.4 6689351.6 12.6, 354032.2 6689351.6 12.6, 354032.3 6689354.5 12.6, 354034.9 6689354.6 12.6, 354035.1 6689360.4 12.6, 354043 6689360.2 12.6, 354044.2 6689357.5 12.6, 354038.5 6689351.9 12.6, 354027.9 6689341.1 12.6, 354025.7 6689343.4 12.6, 354027.3 6689348.3 12.6, 354029.8 6689348.5 12.6))
BATIMENT0000000302928785;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;9.2;12.8;13.6;10.1;Cadastre;;POLYGON Z ((354038.5 6689351.9 12.8, 354044.2 6689357.5 12.8, 354047.9 6689350.2 12.8, 354044.1 6689346.4 12.8, 354038.5 6689351.9 12.8))
BATIMENT0000000302928783;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;1.5;9.4;11.0;12.1;10.0;Cadastre;A 0.2;POLYGON Z ((354059.7 6689354 11, 354060.1 6689351.5 11, 354056.5 6689351 11, 354056.3 6689353.6 11, 354059.7 6689354 11))
BATIMENT0000000302928788;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;4.0;9.9;14.0;14.7;10.4;Cadastre;A 0.5;POLYGON Z ((354049 6689363.3 14, 354048.8 6689365.8 14, 354052.2 6689365.1 14, 354051.6 6689362.9 14, 354049 6689363.3 14))
BATIMENT0000000302928778;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.4;11.0;17.4;22.2;12.5;Cadastre;A 1.0;POLYGON Z ((354080 6689373 17.4, 354096.7 6689369.3 17.4, 354095.6 6689363.5 17.4, 354094 6689363.7 17.4, 354093.4 6689361.4 17.4, 354092.6 6689359.3 17.4, 354092.3 6689358.9 17.4, 354089.8 6689357.8 17.4, 354086.8 6689358.7 17.4, 354085.5 6689360.1 17.4, 354084.8 6689361.2 17.4, 354084.6 6689362.2 17.4, 354078.8 6689363.4 17.4, 354075.7 6689364.2 17.4, 354077.6 6689373.6 17.4, 354080 6689373 17.4))
BATIMENT0000000302928779;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;7.6;11.0;18.6;21.1;11.4;Cadastre;A 1.0;POLYGON Z ((354070.6 6689372.5 18.6, 354071.1 6689374.8 18.6, 354077.6 6689373.6 18.6, 354075.7 6689364.2 18.6, 354075 6689361 18.6, 354075 6689357.3 18.6, 354071 6689358.2 18.6, 354068.8 6689358.6 18.6, 354068.3 6689360.7 18.6, 354068.5 6689361.1 18.6, 354068.9 6689362.9 18.6, 354070.6 6689372.5 18.6))
BATIMENT0000000302928782;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;8.0;10.7;18.7;21.1;11.4;Cadastre;A 1.0;POLYGON Z ((354066.7 6689363.4 18.7, 354066 6689360.4 18.7, 354061.7 6689361.4 18.7, 354062.5 6689364.4 18.7, 354064.5 6689373.9 18.7, 354070.6 6689372.5 18.7, 354068.9 6689362.9 18.7, 354066.7 6689363.4 18.7))
BATIMENT0000000302928786;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;7.4;11.0;18.4;21.4;11.4;Cadastre;A 0.5;POLYGON Z ((354056.8 6689365.8 18.4, 354057.7 6689369.8 18.4, 354053.5 6689370.8 18.4, 354054.8 6689376.1 18.4, 354061.1 6689374.7 18.4, 354061.6 6689377 18.4, 354065 6689376.3 18.4, 354064.5 6689373.9 18.4, 354062.5 6689364.4 18.4, 354056.8 6689365.8 18.4))
BATIMENT0000000302903522;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;20;20;5.9;13.7;19.6;21.7;16.2;Cadastre;A 1.0;POLYGON Z ((353896.7 6689354.1 19.6, 353893.9 6689355.6 19.6, 353892.0022898072 6689356.698674322 19.6, 353892.0022898072 6689361.6045796145 19.6, 353892.6 6689362.8 19.6, 353892.8 6689363 19.6, 353900 6689359.1 19.6, 353900.6 6689360.3 19.6, 353900.9 6689360.8 19.6, 353906.5 6689357.3 19.6, 353902.4 6689350.9 19.6, 353896.7 6689354.1 19.6))
BATIMENT0000000302903493;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;11.6;20.7;22.1;12.3;Cadastre;;POLYGON Z ((353927.7 6689357.3 20.7, 353926.9 6689358.9 20.7, 353927.7 6689359.9 20.7, 353929 6689359 20.7, 353930.2 6689358.3 20.7, 353927.7 6689357.3 20.7))
BATIMENT0000000302903494;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;11.8;16.5;21.0;12.9;Cadastre;;POLYGON Z ((353926.6 6689355.9 16.5, 353922.1 6689358.9 16.5, 353924.2 6689361.9 16.5, 353927.7 6689359.9 16.5, 353926.9 6689358.9 16.5, 353927.7 6689357.3 16.5, 353926.6 6689355.9 16.5))
BATIMENT0000000302903492;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;11.5;22.7;24.2;12.1;Cadastre;;POLYGON Z ((353930.2 6689358.3 22.7, 353929 6689359 22.7, 353930 6689360.7 22.7, 353931.2 6689360 22.7, 353930.2 6689358.3 22.7))
BATIMENT0000000302903519;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;10;6.6;14.6;21.3;23.7;17.8;Cadastre;B 0.8;POLYGON Z ((353892.6 6689362.8 21.3, 353892.0022898072 6689361.6045796145 21.3, 353892.0022898072 6689363.10331562 21.3, 353892.6 6689362.8 21.3))
BATIMENT0000000302903496;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;20;20;11.7;11.1;22.9;24.8;12.7;Cadastre;A 1.0;POLYGON Z ((353929.8 6689370.6 22.9, 353934.9 6689368.5 22.9, 353936.8 6689360.2 22.9, 353930.2 6689358.3 22.9, 353931.2 6689360 22.9, 353930 6689360.7 22.9, 353929 6689359 22.9, 353927.7 6689359.9 22.9, 353924.2 6689361.9 22.9, 353929.8 6689370.6 22.9))
BATIMENT0000000302906100;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;10;20;11.6;12.1;23.7;26.3;14.4;Cadastre;C 0.8;POLYGON Z ((353907.5 6689387.8 23.7, 353919.8 6689380.1 23.7, 353910.5 6689364.2 23.7, 353897.9 6689371 23.7, 353901.5 6689377.3 23.7, 353907.5 6689387.8 23.7))
BATIMENT0000000302903016;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;8.1;11.7;19.8;22.7;13.5;Cadastre;A 0.9;POLYGON Z ((353921.3 6689396.2 19.8, 353926.8 6689391.8 19.8, 353926.7 6689391.5 19.8, 353921.8 6689383.3 19.8, 353913.1 6689388.9 19.8, 353916.9 6689395.4 19.8, 353918.6 6689398.2 19.8, 353921.3 6689396.2 19.8))
BATIMENT0000000302904985;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;12.5;22.2;23.7;13.1;Cadastre;;POLYGON Z ((353909.2 6689391.4 22.2, 353908.4 6689390.2 22.2, 353907.2 6689391.1 22.2, 353907.8 6689392.2 22.2, 353909.2 6689391.4 22.2))
BATIMENT0000000302906101;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.8;13.1;19.0;20.7;18.5;Cadastre;C 0.5;POLYGON Z ((353901.5 6689377.3 19, 353897.9 6689371 19, 353892.0022898072 6689374.188788189 19, 353892.0022898072 6689382.44894179 19, 353901.5 6689377.3 19))
BATIMENT0000000302928791;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;10.1;14.0;15.5;10.4;Cadastre;;POLYGON Z ((354030.1 6689370 14, 354027.2 6689369.9 14, 354027.2 6689372 14, 354028.5 6689372 14, 354030.1 6689371.9 14, 354030.1 6689370 14))
BATIMENT0000000302928787;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;7.2;11.0;18.2;21.1;11.1;Cadastre;A 0.6;POLYGON Z ((354048.4 6689367.9 18.2, 354048.1 6689370 18.2, 354048.7 6689377.4 18.2, 354054.8 6689376.1 18.2, 354053.5 6689370.8 18.2, 354057.7 6689369.8 18.2, 354056.8 6689365.8 18.2, 354048.4 6689367.9 18.2))
BATIMENT0000000302928789;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.6;11.0;17.6;19.2;11.0;Cadastre;A 1.0;POLYGON Z ((354041.2 6689369 17.6, 354039.9 6689377.3 17.6, 354041.2 6689378 17.6, 354043.4 6689377.4 17.6, 354043.8 6689378.6 17.6, 354048.7 6689377.4 17.6, 354048.1 6689370 17.6, 354041.2 6689369 17.6))
BATIMENT0000000302929241;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.9;9.4;16.3;16.9;10.7;Cadastre;C 0.8;POLYGON Z ((354038.2 6689382.2 16.3, 354036.7 6689375.7 16.3, 354038.4 6689371.8 16.3, 354030.1 6689371.9 16.3, 354028.5 6689372 16.3, 354027.8 6689375.4 16.3, 354024.7 6689376 16.3, 354026.5 6689384.7 16.3, 354038.2 6689382.2 16.3))
BATIMENT0000000302928925;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;20;20;14.8;8.6;23.4;25.3;11.4;Cadastre;A 1.0;POLYGON Z ((354096 6689403 23.4, 354097.3 6689402 23.4, 354105 6689395.9 23.4, 354098.3 6689386.2 23.4, 354095 6689385.2 23.4, 354085.1 6689387.3 23.4, 354087.2 6689396.8 23.4, 354090.9 6689396 23.4, 354096 6689403 23.4))
BATIMENT0000000302928926;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1886-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;25;23;11.0;10.0;21.0;23.5;11.3;Cadastre;A 1.0;POLYGON Z ((354061 6689392.4 21, 354062.1 6689396.9 21, 354063.5 6689403.4 21, 354066.8 6689402.6 21, 354076.6 6689400.5 21, 354082.7 6689399.1 21, 354087.6 6689398.1 21, 354087.2 6689396.8 21, 354085.1 6689387.3 21, 354061 6689392.4 21))
BATIMENT0000000302928928;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;8.1;16.2;21.2;9.9;Cadastre;;POLYGON Z ((354082.7 6689399.1 16.2, 354084 6689404.7 16.2, 354086.7 6689404.2 16.2, 354088.3 6689400.8 16.2, 354087.6 6689398.1 16.2, 354082.7 6689399.1 16.2))
BATIMENT0000000302928924;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;11.1;9.3;20.5;26.7;10.4;Cadastre;A 1.0;POLYGON Z ((354046.3 6689406.4 20.5, 354045 6689400.7 20.5, 354044.1 6689396 20.5, 354037 6689397.5 20.5, 354039.3 6689407.9 20.5, 354040 6689407.7 20.5, 354042.9 6689407.1 20.5, 354046.3 6689406.4 20.5))
BATIMENT0000000302927368;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1884-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;7.5;10.0;17.5;20.7;10.4;Cadastre;C 0.5;POLYGON Z ((354026.2 6689399.8 17.5, 354028.5 6689410.1 17.5, 354035.9 6689408.4 17.5, 354033.9 6689398.2 17.5, 354026.2 6689399.8 17.5))
BATIMENT0000000029199165;Indifférenciée;Commercial et services;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2003-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;7.0;;;22.8;10.0;;35.1;11.0;Imagerie aérienne;A 1.0;POLYGON Z ((354045.6 6689400.6 32.2, 354048.1 6689412.3 32.4, 354048.5 6689414.4 32.8, 354065 6689410.9 32.6, 354063.4 6689403.8 32.6, 354062 6689397.1 32, 354045.6 6689400.6 32.2))
BATIMENT0000000302906099;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;6.5;12.6;19.2;21.2;16.0;Cadastre;C 0.5;POLYGON Z ((353892.4 6689397 19.2, 353904.4 6689389.6 19.2, 353900.5 6689382.7 19.2, 353892.0022898072 6689388.004631211 19.2, 353892.0022898072 6689397.254783092 19.2, 353892.4 6689397 19.2))
BATIMENT0000000302903017;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.7;11.2;22.0;24.4;13.4;Cadastre;A 1.0;POLYGON Z ((353930 6689401.5 22, 353930.3 6689401.3 22, 353935.3 6689393.1 22, 353929.3 6689389.4 22, 353926.7 6689391.5 22, 353926.8 6689391.8 22, 353921.3 6689396.2 22, 353930 6689401.5 22))
BATIMENT0000000302904984;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1941-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;15.0;12.7;27.8;30.6;16.2;Cadastre;A 1.0;POLYGON Z ((353898.4 6689396.5 27.8, 353905.2 6689407.3 27.8, 353907.2 6689405.6 27.8, 353906.1 6689404 27.8, 353907.3 6689403.2 27.8, 353906.8 6689402.5 27.8, 353908.2 6689401.5 27.8, 353909.6 6689403.7 27.8, 353913.2 6689400.8 27.8, 353910.7 6689396.7 27.8, 353907.8 6689392.2 27.8, 353907.2 6689391.1 27.8, 353898.4 6689396.5 27.8))
BATIMENT0000000302903018;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;8.8;11.1;20.0;24.7;14.7;Cadastre;A 1.0;POLYGON Z ((353930.3 6689401.3 20, 353930 6689401.5 20, 353928 6689403.2 20, 353929.3 6689404.9 20, 353932.7 6689402 20, 353933.9 6689402.8 20, 353932.8 6689403.7 20, 353933.4 6689404.3 20, 353932.8 6689404.8 20, 353932.6 6689404.5 20, 353929.3 6689407.5 20, 353932 6689410.7 20, 353932.5 6689410.2 20, 353936.6 6689405.4 20, 353937.1 6689404.7 20, 353937.5 6689404.8 20, 353942.1 6689397.2 20, 353935.3 6689393.1 20, 353930.3 6689401.3 20))
BATIMENT0000000302903021;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;11.0;19.0;21.7;13.4;Cadastre;C 0.7;POLYGON Z ((353941.9 6689405 19, 353945.8 6689399.3 19, 353942.1 6689397.2 19, 353937.5 6689404.8 19, 353938.2 6689405.4 19, 353940.5 6689406.8 19, 353941.9 6689405 19))
BATIMENT0000000302903022;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;12.8;20.5;21.7;13.5;Cadastre;;POLYGON Z ((353937.1 6689404.7 20.5, 353936.6 6689405.4 20.5, 353937.4 6689406.3 20.5, 353938.2 6689405.4 20.5, 353937.5 6689404.8 20.5, 353937.1 6689404.7 20.5))
BATIMENT0000000302903023;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.0;13.3;15.4;16.7;15.3;Cadastre;;POLYGON Z ((353924.3 6689406.4 15.4, 353927 6689409.9 15.4, 353928.3 6689408.8 15.4, 353926.6 6689406.7 15.4, 353928 6689405.4 15.4, 353927 6689404.1 15.4, 353924.3 6689406.4 15.4))
BATIMENT0000000302903019;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.5;13.0;16.6;17.7;14.2;Cadastre;C 0.2;POLYGON Z ((353932.5 6689410.2 16.6, 353934 6689412 16.6, 353938.9 6689408.1 16.6, 353937.4 6689406.3 16.6, 353936.6 6689405.4 16.6, 353932.5 6689410.2 16.6))
BATIMENT0000000302903020;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 19:18:06;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;2.6;14.4;17.0;;;Cadastre;C 0.2;POLYGON Z ((353942.5 6689405.3 17, 353941.9 6689405 17, 353940.5 6689406.8 17, 353938.9 6689408.1 17, 353939.7 6689408.8 17, 353938.9 6689413.9 17, 353942.6 6689414.6 17, 353943.1 6689411.8 17, 353944.7 6689412 17, 353945.2 6689408.4 17, 353944 6689406.9 17, 353942.5 6689405.3 17))
BATIMENT0000000302903024;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;12.8;14.4;15.7;13.6;Cadastre;;POLYGON Z ((353942.6 6689414.6 14.4, 353944.2 6689414.9 14.4, 353944.7 6689412 14.4, 353943.1 6689411.8 14.4, 353942.6 6689414.6 14.4))
BATIMENT0000000302928790;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.7;9.9;20.7;26.7;10.4;Cadastre;A 1.0;POLYGON Z ((354017.4 6689360.9 20.7, 354017.8 6689372.1 20.7, 354027.2 6689372 20.7, 354027.2 6689369.9 20.7, 354027.1 6689360.7 20.7, 354025.4 6689360.6 20.7, 354017.4 6689360.9 20.7))
BATIMENT0000000302928792;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;02;03;5.4;10.0;15.4;19.0;10.5;Cadastre;A 1.0;POLYGON Z ((354015.5 6689372.1 15.4, 354014.3 6689378.2 15.4, 354024.7 6689376 15.4, 354027.8 6689375.4 15.4, 354028.5 6689372 15.4, 354027.2 6689372 15.4, 354017.8 6689372.1 15.4, 354015.5 6689372.1 15.4))
BATIMENT0000000302929240;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;6.9;9.4;16.3;16.8;10.6;Cadastre;C 1.0;POLYGON Z ((354017.3 6689386.7 16.3, 354026.5 6689384.7 16.3, 354024.7 6689376 16.3, 354014.3 6689378.2 16.3, 354012.9 6689383 16.3, 354017.3 6689386.7 16.3))
BATIMENT0000000302927367;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;7.6;10.0;17.6;20.3;10.3;Cadastre;A 1.0;POLYGON Z ((354021.8 6689400.7 17.6, 354023.3 6689407.6 17.6, 354024.4 6689411.7 17.6, 354025.8 6689411.5 17.6, 354026.9 6689415.8 17.6, 354027.7 6689415.6 17.6, 354028 6689416.5 17.6, 354029.8 6689416.1 17.6, 354028.5 6689410.1 17.6, 354026.2 6689399.8 17.6, 354021.8 6689400.7 17.6))
BATIMENT0000000302927365;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.6;9.0;21.7;24.1;10.7;Cadastre;A 1.0;POLYGON Z ((354001.9 6689405 21.7, 354004.3 6689416 21.7, 354014.3 6689414 21.7, 354012.1 6689402.8 21.7, 354001.9 6689405 21.7))
BATIMENT0000000302927366;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.3;8.9;19.3;22.6;10.7;Cadastre;A 1.0;POLYGON Z ((354012.1 6689402.8 19.3, 354014.3 6689414 19.3, 354015.5 6689420 19.3, 354016.6 6689420.9 19.3, 354019.2 6689420.3 19.3, 354020.1 6689419.3 19.3, 354019.4 6689415.6 19.3, 354022.1 6689414.9 19.3, 354020.8 6689408.2 19.3, 354023.3 6689407.6 19.3, 354021.8 6689400.7 19.3, 354012.1 6689402.8 19.3))
BATIMENT0000000302906098;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;13.5;10.2;23.7;28.9;10.8;Cadastre;C 0.5;POLYGON Z ((353979.8 6689424.8 23.7, 353980.2 6689424.9 23.7, 353988.2 6689426.4 23.7, 353986.7 6689419.8 23.7, 354004.3 6689416 23.7, 354001.9 6689405 23.7, 353989.3 6689407.6 23.7, 353989.3 6689407.7 23.7, 353989.5 6689408.8 23.7, 353987.9 6689410.4 23.7, 353986.8 6689409.5 23.7, 353986.8 6689408.2 23.7, 353984 6689409.9 23.7, 353983.7 6689408.9 23.7, 353983.7 6689408.8 23.7, 353976.8 6689410.3 23.7, 353976.6 6689411.1 23.7, 353976.3 6689410.9 23.7, 353975.5 6689410.7 23.7, 353974.7 6689410.7 23.7, 353974.7 6689410.8 23.7, 353974.5 6689411.1 23.7, 353974.3 6689411.6 23.7, 353974.1 6689412.2 23.7, 353974 6689412.6 23.7, 353974 6689412.7 23.7, 353973.9 6689413 23.7, 353973.8 6689413.3 23.7, 353973.7 6689413.9 23.7, 353973.7 6689414 23.7, 353973.7 6689414.3 23.7, 353973.6 6689414.7 23.7, 353973 6689414.6 23.7, 353972.3 6689414.6 23.7, 353971.7 6689417.9 23.7, 353971.7 6689418 23.7, 353971.8 6689418.3 23.7, 353971.8 6689418.5 23.7, 353971.8 6689418.8 23.7, 353971.8 6689419.1 23.7, 353971.8 6689419.3 23.7, 353971.9 6689419.5 23.7, 353972 6689420.2 23.7, 353972 6689420.4 23.7, 353972.1 6689420.8 23.7, 353972.2 6689421.3 23.7, 353972.2 6689421.4 23.7, 353972.3 6689421.7 23.7, 353972.3 6689421.8 23.7, 353972.1 6689422.7 23.7, 353970.9 6689422.5 23.7, 353970.8 6689423.1 23.7, 353979.8 6689424.8 23.7))
BATIMENT0000000302906097;Industriel, agricole ou commercial;Industriel;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.4;8.0;16.4;26.1;10.7;Cadastre;;POLYGON Z ((353989.1 6689430.8 16.4, 353993.8 6689429.7 16.4, 353995 6689426.9 16.4, 353999.8 6689425.7 16.4, 353999.9 6689426.3 16.4, 354006 6689425 16.4, 354005.2 6689421.2 16.4, 354004.3 6689416 16.4, 353986.7 6689419.8 16.4, 353988.2 6689426.4 16.4, 353989.1 6689430.8 16.4))
BATIMENT0000000302904665;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;32;10.3;10.0;20.4;24.7;11.5;Cadastre;A 1.0;POLYGON Z ((353968.7 6689434.9 20.4, 353978.1 6689436.7 20.4, 353980.2 6689424.9 20.4, 353979.8 6689424.8 20.4, 353970.8 6689423.1 20.4, 353968.7 6689434.9 20.4))
BATIMENT0000000302904666;Industriel, agricole ou commercial;Industriel;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;8.8;10.7;20.1;10.4;Cadastre;;POLYGON Z ((354008.1 6689434.5 10.7, 354006 6689425 10.7, 353999.9 6689426.3 10.7, 353999.8 6689425.7 10.7, 353995 6689426.9 10.7, 353993.8 6689429.7 10.7, 353989.1 6689430.8 10.7, 353990.6 6689438.1 10.7, 354008.1 6689434.5 10.7))
BATIMENT0000000302928961;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;01;6.1;12.6;18.7;20.8;13.7;Cadastre;C 0.3;POLYGON Z ((354182.5 6689410.2 18.7, 354188.4 6689409.9 18.7, 354188.5 6689408.3 18.7, 354188.6 6689404.8 18.7, 354182.4 6689404.8 18.7, 354182.5 6689410.2 18.7))
BATIMENT0000000302929102;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;11.4;12.0;23.5;27.7;12.6;Cadastre;A 1.0;POLYGON Z ((354185.4 6689421.1 23.5, 354191.3 6689421.2 23.5, 354191.2 6689418.3 23.5, 354185.4 6689418.3 23.5, 354185.4 6689421.1 23.5))
BATIMENT0000000029198343;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1972-01-01;;;;BDTopo;2.5;BDTopo;1.5;28.0;8.0;30;20;22.5;14.2;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354215 6689455.3 36.7, 354215.5 6689442.4 36.5, 354184.4 6689439.9 36.3, 354183.9 6689445.2 36.3, 354183.4 6689452.2 36.5, 354215 6689455.3 36.7))
BATIMENT0000002275362615;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;17.2;14.2;;;;Imagerie aérienne;;POLYGON Z ((354264.8 6689459.8 30.6, 354267.1 6689459.8 28, 354267.9 6689446.1 28, 354245.3 6689443.8 28.8, 354245 6689447.6 30.5, 354239.4 6689447.1 30.6, 354239.2 6689449.9 30.6, 354236 6689449.9 28.2, 354235.5 6689457.6 28.2, 354238.6 6689458 31.1, 354249.7 6689459 31.3, 354249.9 6689457.1 31.3, 354251.8 6689457.3 31.4, 354251.2 6689461.7 31.4, 354264.5 6689462.8 30.4, 354264.8 6689459.8 30.6))
BATIMENT0000000302928659;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.0;10.4;22.5;25.1;11.2;Cadastre;C 0.9;POLYGON Z ((354180.4 6689481.4 22.5, 354188.9 6689482.4 22.5, 354189.8 6689471.7 22.5, 354181.4 6689471 22.5, 354180.4 6689481.4 22.5))
BATIMENT0000000302928578;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.2;11.5;21.7;26.0;13.3;Cadastre;A 1.0;POLYGON Z ((354199.8 6689481.5 21.7, 354207.1 6689482.2 21.7, 354207.4 6689479.9 21.7, 354208.1 6689473.6 21.7, 354200.5 6689472.9 21.7, 354199.8 6689481.5 21.7))
BATIMENT0000000302928660;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.3;10.8;22.2;24.9;12.3;Cadastre;A 1.0;POLYGON Z ((354188.9 6689482.4 22.2, 354197.2 6689483.4 22.2, 354198.2 6689472.6 22.2, 354189.8 6689471.7 22.2, 354188.9 6689482.4 22.2))
BATIMENT0000000302928580;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;8.0;30;40;23.1;15.0;38.2;40.6;18.4;Cadastre;C 0.5;POLYGON Z ((354230.4 6689481.9 38.2, 354228 6689490.8 38.2, 354234.3 6689491.6 38.2, 354234.3 6689492.1 38.2, 354237.7 6689492.6 38.2, 354237.9 6689491.9 38.2, 354241.5 6689492.2 38.2, 354241.7 6689492.8 38.2, 354244.9 6689493.1 38.2, 354244.9 6689492.4 38.2, 354248 6689492.8 38.2, 354247.9 6689493.4 38.2, 354251 6689493.7 38.2, 354251.2 6689493.1 38.2, 354256.6 6689493.7 38.2, 354260.3 6689484.2 38.2, 354251.7 6689483.4 38.2, 354251.7 6689482.6 38.2, 354242.7 6689481.7 38.2, 354243.1 6689476.9 38.2, 354231.9 6689475.8 38.2, 354230.4 6689481.9 38.2))
BATIMENT0000000302928579;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;7.0;50;49;20.5;13.6;34.1;35.5;16.8;Cadastre;A 1.0;POLYGON Z ((354207.1 6689482.2 34.1, 354205.6 6689492.7 34.1, 354212.5 6689493.4 34.1, 354212.6 6689494.3 34.1, 354219.5 6689495.2 34.1, 354219.8 6689494.1 34.1, 354226.9 6689494.7 34.1, 354228 6689490.8 34.1, 354230.4 6689481.9 34.1, 354207.4 6689479.9 34.1, 354207.1 6689482.2 34.1))
BATIMENT0000000302928868;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;18.4;29.5;33.4;22.5;Cadastre;;POLYGON Z ((354266.9 6689478 29.5, 354247.4 6689530.3 29.5, 354267.7 6689540 29.5, 354270.7 6689533.9 29.5, 354256.3 6689526.7 29.5, 354269.9 6689491.3 29.5, 354271.9 6689492.6 29.5, 354270.1 6689495.4 29.5, 354280 6689501.8 29.5, 354283.8 6689496 29.5, 354271.2 6689487.8 29.5, 354273.4 6689482 29.5, 354267.5 6689477.9 29.5, 354266.9 6689478 29.5))
BATIMENT0000000302928641;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;23;7.8;7.6;15.5;17.6;9.0;Cadastre;A 1.0;POLYGON Z ((354122.8 6689451 15.5, 354118.4 6689457.8 15.5, 354126.8 6689463.3 15.5, 354134 6689452 15.5, 354127.9 6689447.8 15.5, 354125.8 6689446.4 15.5, 354122.8 6689451 15.5))
BATIMENT0000000302928643;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;6.5;7.2;13.7;17.1;8.9;Cadastre;A 1.0;POLYGON Z ((354113.8 6689463.2 13.7, 354111.6 6689461.9 13.7, 354108.4 6689467 13.7, 354110.4 6689468.5 13.7, 354108.3 6689471.7 13.7, 354099.3 6689465.9 13.7, 354097.4 6689468.6 13.7, 354105.7 6689474.2 13.7, 354115.5 6689480.5 13.7, 354126.8 6689463.3 13.7, 354118.4 6689457.8 13.7, 354117.7 6689457.5 13.7, 354113.8 6689463.2 13.7))
BATIMENT0000000029197927;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.1;10.7;;19.2;10.7;Imagerie aérienne;;POLYGON Z ((354162 6689472.7 14.8, 354162.4 6689468.9 14.8, 354156.8 6689468.3 14.8, 354152.6 6689476.2 14.8, 354154.1 6689477.1 14.8, 354156.7 6689473.7 14.8, 354161.9 6689473.6 14.8, 354162 6689472.7 14.8))
BATIMENT0000000029197912;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1966-01-01;;;;BDTopo;2.5;BDTopo;1.5;12.0;7.0;10;40;21.1;10.7;;32.5;11.6;Imagerie aérienne;C 0.8;POLYGON Z ((354176.4 6689488.3 31.5, 354176.8 6689484.6 30, 354177.3 6689474.4 26.1, 354161.9 6689473.6 27.9, 354156.7 6689473.7 30.1, 354154.1 6689477.1 27.2, 354151.6 6689482.6 27.8, 354159.3 6689486.6 31.8, 354176.4 6689488.3 31.5))
BATIMENT0000000302928644;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;10;10.5;7.2;17.7;20.2;8.4;Cadastre;A 1.0;POLYGON Z ((354099.7 6689483.3 17.7, 354109.7 6689489.6 17.7, 354115.5 6689480.5 17.7, 354105.7 6689474.2 17.7, 354099.7 6689483.3 17.7))
BATIMENT0000000302929116;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;5.1;10.8;15.9;26.5;12.0;Cadastre;C 0.4;POLYGON Z ((354176.4 6689488.3 15.9, 354175.9 6689494.5 15.9, 354179.3 6689494.9 15.9, 354180 6689485 15.9, 354176.8 6689484.6 15.9, 354176.4 6689488.3 15.9))
BATIMENT0000000029199397;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1966-01-01;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;10;40;6.7;10.7;;22.1;13.4;Imagerie aérienne;C 0.1;POLYGON Z ((354150.1 6689481.9 16.6, 354142.7 6689497.8 17.4, 354151.8 6689501.6 17.2, 354153.1 6689499 17, 354157.8 6689489.2 16.6, 354159.3 6689486.6 16.6, 354151.6 6689482.6 16.6, 354150.1 6689481.9 16.6))
BATIMENT0000000302928667;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.1;6.6;14.7;16.8;11.0;Cadastre;A 1.0;POLYGON Z ((354125.1 6689496.1 14.7, 354133.2 6689500.7 14.7, 354137.9 6689491.5 14.7, 354130.3 6689487.1 14.7, 354125.1 6689496.1 14.7))
BATIMENT0000000302928666;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.9;7.2;15.1;15.9;11.9;Cadastre;C 1.0;POLYGON Z ((354134.5 6689499.9 15.1, 354133.7 6689501.1 15.1, 354136 6689504.9 15.1, 354138.1 6689504.4 15.1, 354137.1 6689499.4 15.1, 354134.5 6689499.9 15.1))
BATIMENT0000000302928665;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;8.1;14.7;19.0;12.0;Cadastre;;POLYGON Z ((354130.7 6689514.2 14.7, 354132.7 6689515.6 14.7, 354137.7 6689507.9 14.7, 354136.4 6689505.7 14.7, 354130.7 6689514.2 14.7))
BATIMENT0000000302928657;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;20.3;23.9;25.7;21.5;Cadastre;;POLYGON Z ((354335 6689438.4 23.9, 354333.1 6689438.3 23.9, 354332.8 6689439.7 23.9, 354334.7 6689440 23.9, 354335 6689438.4 23.9))
BATIMENT0000000302928653;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;20.5;26.2;33.5;21.7;Cadastre;;POLYGON Z ((354331.4 6689447.9 26.2, 354333.3 6689448.2 26.2, 354334.5 6689441.5 26.2, 354334.7 6689440 26.2, 354332.8 6689439.7 26.2, 354331.4 6689447.9 26.2))
BATIMENT0000000302929106;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;1963-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;3.3;17.9;21.2;27.7;18.7;Cadastre;C 0.2;POLYGON Z ((354278.3 6689461.1 21.2, 354285 6689462 21.2, 354286.5 6689451 21.2, 354279.6 6689450.2 21.2, 354278.3 6689461.1 21.2))
BATIMENT0000000302928596;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.3;22.7;32.0;36.4;24.9;Cadastre;A 1.0;POLYGON Z ((354323.6 6689491.4 32, 354324.4 6689489.5 32, 354326.6 6689490.5 32, 354330 6689482.5 32, 354325.1 6689480.4 32, 354325.1 6689480.3 32, 354323.1 6689485 32, 354320.2 6689489.1 32, 354314.4 6689496.7 32, 354328 6689505.6 32, 354332.8 6689498.5 32, 354333.2 6689497.5 32, 354323.6 6689491.4 32))
BATIMENT0000000302928594;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;11.3;22.4;33.7;38.0;25.5;Cadastre;A 1.0;POLYGON Z ((354332.8 6689498.5 33.7, 354328 6689505.6 33.7, 354335.8 6689510.8 33.7, 354337 6689507.4 33.7, 354338.4 6689502.2 33.7, 354332.8 6689498.5 33.7))
BATIMENT0000000302928582;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;9.0;30;40;20.3;20.9;41.2;49.1;24.8;Cadastre;A 1.0;POLYGON Z ((354279.6 6689513.7 41.2, 354275.5 6689522 41.2, 354285.1 6689528.2 41.2, 354283.5 6689530.7 41.2, 354287.7 6689533.4 41.2, 354301.2 6689512 41.2, 354302.8 6689509.5 41.2, 354296.8 6689505.5 41.2, 354298.2 6689503 41.2, 354288.3 6689496.4 41.2, 354279.6 6689513.7 41.2))
BATIMENT0000000302928581;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;43.0;11.0;00;00;25.6;23.8;49.5;57.8;25.3;Cadastre;A 1.0;POLYGON Z ((354287.7 6689533.4 49.5, 354296.7 6689539.3 49.5, 354302.5 6689549.7 49.5, 354309.1 6689538.4 49.5, 354321.5 6689531.9 49.5, 354322.1 6689531.4 49.5, 354316.1 6689519.5 49.5, 354314.1 6689520.1 49.5, 354301.2 6689512 49.5, 354287.7 6689533.4 49.5))
BATIMENT0000000302928583;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;46.0;12.0;90;90;32.5;25.0;57.5;63.7;26.7;Cadastre;A 1.0;POLYGON Z ((354321.5 6689531.9 57.5, 354309.1 6689538.4 57.5, 354302.5 6689549.7 57.5, 354301.9 6689550.8 57.5, 354327.5 6689560.9 57.5, 354330 6689557.1 57.5, 354337.8 6689545 57.5, 354328.8 6689539 57.5, 354328 6689540.2 57.5, 354325.9 6689538.9 57.5, 354322.1 6689531.4 57.5, 354321.5 6689531.9 57.5))
BATIMENT0000000302928584;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;10.0;00;00;31.2;25.4;56.6;57.9;28.2;Cadastre;A 1.0;POLYGON Z ((354330 6689557.1 56.6, 354338.9 6689562.8 56.6, 354340.3 6689560.6 56.6, 354342.4 6689562 56.6, 354345.5 6689557.1 56.6, 354343.6 6689555.9 56.6, 354345.9 6689552 56.6, 354343.9 6689550.7 56.6, 354344.8 6689549.3 56.6, 354337.8 6689545 56.6, 354330 6689557.1 56.6))
BATIMENT0000000302928977;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;11.2;24.6;35.8;36.5;26.9;Cadastre;C 0.1;POLYGON Z ((354277 6689551.6 35.8, 354273.1 6689561.5 35.8, 354287 6689568.5 35.8, 354291.5 6689557.6 35.8, 354277 6689551.6 35.8))
BATIMENT0000000302928973;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;7.2;6.9;14.2;16.4;8.0;Cadastre;A 1.0;POLYGON Z ((354124.7 6689512.6 14.2, 354116.9 6689507.2 14.2, 354111.6 6689514.9 14.2, 354115.8 6689517.6 14.2, 354119.8 6689520.3 14.2, 354124.7 6689512.6 14.2))
BATIMENT0000000302928514;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;4.1;12.6;16.8;24.9;14.6;Cadastre;A 1.0;POLYGON Z ((354164.3 6689507.2 16.8, 354159.4 6689504.7 16.8, 354156.5 6689510.5 16.8, 354157.6 6689511 16.8, 354155.3 6689515.6 16.8, 354151.6 6689513.8 16.8, 354149.6 6689517.7 16.8, 354151.4 6689518.7 16.8, 354150.3 6689520.8 16.8, 354152.4 6689521.9 16.8, 354151.2 6689524.3 16.8, 354155.1 6689526.2 16.8, 354159.2 6689517.9 16.8, 354159.4 6689517.6 16.8, 354164.3 6689507.2 16.8))
BATIMENT0000000302928972;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.3;7.1;15.5;18.2;8.0;Cadastre;A 1.0;POLYGON Z ((354115.8 6689517.6 15.5, 354111.6 6689514.9 15.5, 354105.8 6689510.9 15.5, 354100.9 6689518.6 15.5, 354105.4 6689521.6 15.5, 354110.7 6689525 15.5, 354115.8 6689517.6 15.5))
BATIMENT0000000302928957;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;23;7.6;10.6;18.2;21.1;13.4;Cadastre;A 1.0;POLYGON Z ((354133.5 6689520.5 18.2, 354133.7 6689520.7 18.2, 354141.1 6689524.1 18.2, 354141.6 6689522.9 18.2, 354140 6689513.2 18.2, 354137.8 6689512.1 18.2, 354133.5 6689520.5 18.2))
BATIMENT0000000302928515;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;9.5;11.8;21.3;25.6;14.1;Cadastre;A 1.0;POLYGON Z ((354155.1 6689526.2 21.3, 354154.2 6689528 21.3, 354159.3 6689530.3 21.3, 354161.5 6689525.9 21.3, 354164.3 6689520.2 21.3, 354159.2 6689517.9 21.3, 354155.1 6689526.2 21.3))
BATIMENT0000000302928958;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1942-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;34;10.0;11.0;21.0;21.5;13.4;Cadastre;A 1.0;POLYGON Z ((354132.1 6689523.8 21, 354132.5 6689524.1 21, 354125.9 6689537.1 21, 354125.9 6689537.8 21, 354130.1 6689536.7 21, 354136.4 6689535.3 21, 354138.7 6689534.9 21, 354138.4 6689534.4 21, 354142.6 6689526.5 21, 354142.2 6689524.8 21, 354141.1 6689524.1 21, 354133.7 6689520.7 21, 354132.1 6689523.8 21))
BATIMENT0000000302928516;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;52;20;10.5;12.2;22.7;24.9;14.6;Cadastre;A 1.0;POLYGON Z ((354159.3 6689530.3 22.7, 354158 6689532.9 22.7, 354165.6 6689536.5 22.7, 354169.1 6689529.5 22.7, 354161.5 6689525.9 22.7, 354159.3 6689530.3 22.7))
BATIMENT0000000302928517;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;45;20;6.7;14.3;21.0;24.9;15.4;Cadastre;A 1.0;POLYGON Z ((354170.7 6689526.3 21, 354169.1 6689529.5 21, 354165.6 6689536.5 21, 354173.3 6689540.4 21, 354177.5 6689531.7 21, 354174.2 6689530.1 21, 354175.9 6689526.4 21, 354171.5 6689523.9 21, 354170.7 6689526.3 21))
BATIMENT0000000302928971;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;50;20;7.7;7.2;15.0;19.7;11.0;Cadastre;A 1.0;POLYGON Z ((354097.7 6689533.2 15, 354100.6 6689535.2 15, 354100 6689536.1 15, 354105.4 6689539.6 15, 354104.7 6689540.8 15, 354107.4 6689542.6 15, 354106.9 6689543.4 15, 354112.6 6689546.9 15, 354116.2 6689541.7 15, 354122.1 6689532.6 15, 354120.7 6689531.6 15, 354110.7 6689525 15, 354105.4 6689521.6 15, 354097.7 6689533.2 15))
BATIMENT0000000302928959;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.5;11.3;18.8;20.9;13.3;Cadastre;;POLYGON Z ((354130.4 6689538.3 18.8, 354136.8 6689536.8 18.8, 354136.4 6689535.3 18.8, 354130.1 6689536.7 18.8, 354130.4 6689538.3 18.8))
BATIMENT0000000302928976;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;6.3;15.9;22.2;26.7;19.5;Cadastre;C 0.3;POLYGON Z ((354220.1 6689520 22.2, 354243.2 6689528.8 22.2, 354249.2 6689513.1 22.2, 354224.5 6689503.4 22.2, 354220.1 6689520 22.2))
BATIMENT0000000302928520;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;15.5;18.0;20.7;16.3;Cadastre;;POLYGON Z ((354186.8 6689531.8 18, 354183.8 6689530.3 18, 354182 6689533.9 18, 354185.2 6689535.3 18, 354186.8 6689531.8 18))
BATIMENT0000000302928519;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.2;15.7;23.0;25.0;17.2;Cadastre;A 1.0;POLYGON Z ((354181 6689544 23, 354190.7 6689548.9 23, 354195 6689539.9 23, 354195.2 6689539.6 23, 354188.2 6689536.2 23, 354187.6 6689537.1 23, 354184.9 6689535.9 23, 354181 6689544 23))
BATIMENT0000000302928521;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;23;7.6;16.5;24.2;26.5;17.7;Cadastre;A 1.0;POLYGON Z ((354190.7 6689548.9 24.2, 354199 6689552.9 24.2, 354203.1 6689543.9 24.2, 354195 6689539.9 24.2, 354190.7 6689548.9 24.2))
BATIMENT0000000302928522;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.2;17.2;25.4;28.4;18.2;Cadastre;A 1.0;POLYGON Z ((354199 6689552.9 25.4, 354205.8 6689556.3 25.4, 354209.9 6689548.2 25.4, 354210.3 6689547.3 25.4, 354203.1 6689543.9 25.4, 354199 6689552.9 25.4))
BATIMENT0000000302928523;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.9;17.8;27.7;29.3;19.1;Cadastre;A 1.0;POLYGON Z ((354205.8 6689556.3 27.7, 354212.7 6689559.7 27.7, 354216.6 6689551.4 27.7, 354209.9 6689548.2 27.7, 354205.8 6689556.3 27.7))
BATIMENT0000000302928528;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.9;21.1;29.0;32.5;23.2;Cadastre;A 1.0;POLYGON Z ((354249.5 6689552.6 29, 354250 6689555.6 29, 354248.5 6689556 29, 354249.5 6689562.8 29, 354257.3 6689561.2 29, 354256 6689552.4 29, 354252 6689550.3 29, 354249.5 6689552.6 29))
BATIMENT0000000302928524;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.7;18.6;26.3;28.6;20.1;Cadastre;A 1.0;POLYGON Z ((354216.6 6689551.4 26.3, 354212.7 6689559.7 26.3, 354211.9 6689561.3 26.3, 354216.9 6689563.4 26.3, 354217.4 6689562.3 26.3, 354221.6 6689564.2 26.3, 354226.2 6689554.1 26.3, 354217.4 6689549.8 26.3, 354216.6 6689551.4 26.3))
BATIMENT0000000302928527;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;40;9.5;21.3;30.9;32.3;22.9;Cadastre;A 1.0;POLYGON Z ((354241.2 6689556.5 30.9, 354241.7 6689561 30.9, 354242.5 6689565.6 30.9, 354249.8 6689564.4 30.9, 354249.5 6689562.8 30.9, 354248.5 6689556 30.9, 354248.3 6689555.5 30.9, 354241.2 6689556.5 30.9))
BATIMENT0000000302928525;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;90;20;6.5;19.4;26.0;29.2;20.9;Cadastre;A 1.0;POLYGON Z ((354226.2 6689554.1 26, 354221.6 6689564.2 26, 354220.9 6689565.3 26, 354224.5 6689566.9 26, 354225.1 6689565.8 26, 354229.8 6689567.9 26, 354230.9 6689565.3 26, 354234.7 6689557.6 26, 354235.5 6689555.8 26, 354231.5 6689553.7 26, 354230.7 6689555.5 26, 354226.5 6689553.5 26, 354226.2 6689554.1 26))
BATIMENT0000000302928518;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;15;20;8.7;14.8;23.5;25.1;16.3;Cadastre;A 1.0;POLYGON Z ((354177.5 6689531.7 23.5, 354173.3 6689540.4 23.5, 354181 6689544 23.5, 354184.9 6689535.9 23.5, 354185.2 6689535.3 23.5, 354182 6689533.9 23.5, 354177.5 6689531.7 23.5))
BATIMENT0000000302928970;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;6.7;10.0;16.7;17.5;11.4;Cadastre;A 1.0;POLYGON Z ((354112.6 6689546.9 16.7, 354115.7 6689549.2 16.7, 354116.5 6689548.3 16.7, 354121.2 6689551.6 16.7, 354122.2 6689550.4 16.7, 354124.9 6689546.4 16.7, 354116.2 6689541.7 16.7, 354112.6 6689546.9 16.7))
BATIMENT0000000302928623;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;20;20;12.3;12.1;24.5;26.9;13.5;Cadastre;A 1.0;POLYGON Z ((354135.9 6689549.1 24.5, 354143.6 6689552.7 24.5, 354143.9 6689552.2 24.5, 354148.3 6689543.3 24.5, 354142.5 6689540.7 24.5, 354135.9 6689549.1 24.5))
BATIMENT0000000302928620;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;36;30;8.7;13.2;22.0;24.5;14.5;Cadastre;A 1.0;POLYGON Z ((354143.9 6689552.2 22, 354152.5 6689556.1 22, 354153.4 6689554.2 22, 354157.3 6689545.5 22, 354152.7 6689543.4 22, 354151.9 6689544.9 22, 354148.3 6689543.3 22, 354143.9 6689552.2 22))
BATIMENT0000000302928967;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;30;6.9;10.0;16.9;17.4;12.1;Cadastre;A 1.0;POLYGON Z ((354130.7 6689552.5 16.9, 354132.3 6689550.5 16.9, 354124.9 6689546.4 16.9, 354122.2 6689550.4 16.9, 354129.2 6689554.9 16.9, 354130.7 6689552.5 16.9))
BATIMENT0000000302928619;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;13;20;9.8;13.9;23.7;26.5;14.9;Cadastre;A 1.0;POLYGON Z ((354153.4 6689554.2 23.7, 354160.4 6689557.4 23.7, 354164.4 6689548.9 23.7, 354157.3 6689545.5 23.7, 354153.4 6689554.2 23.7))
BATIMENT0000000302928966;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;9.5;15.5;16.2;11.6;Cadastre;;POLYGON Z ((354121.2 6689551.6 15.5, 354120.7 6689552.4 15.5, 354127.6 6689557.3 15.5, 354129.2 6689554.9 15.5, 354122.2 6689550.4 15.5, 354121.2 6689551.6 15.5))
BATIMENT0000000302928622;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;7.2;14.2;21.5;23.5;15.3;Cadastre;A 1.0;POLYGON Z ((354160.4 6689557.4 21.5, 354167.8 6689561.2 21.5, 354171.4 6689553.6 21.5, 354171.9 6689552.3 21.5, 354164.4 6689548.9 21.5, 354160.4 6689557.4 21.5))
BATIMENT0000000302928621;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.0;13.7;21.7;25.0;14.5;Cadastre;;POLYGON Z ((354159 6689560.2 21.7, 354160.4 6689557.4 21.7, 354153.4 6689554.2 21.7, 354152.5 6689556.1 21.7, 354152.3 6689556.5 21.7, 354152.1 6689556.9 21.7, 354159 6689560.2 21.7))
BATIMENT0000000302928979;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.3;9.6;10.9;;;Cadastre;;POLYGON Z ((354111.5 6689557.6 10.9, 354113.1 6689556.3 10.9, 354113.4 6689555.3 10.9, 354109.7 6689552.7 10.9, 354105.5 6689558.7 10.9, 354103.4 6689562.2 10.9, 354106 6689565.5 10.9, 354109.1 6689561.1 10.9, 354106.6 6689558.6 10.9, 354111.5 6689557.6 10.9))
BATIMENT0000000302928526;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;45;20;9.3;20.4;29.7;31.4;22.3;Cadastre;A 1.0;POLYGON Z ((354230.9 6689565.3 29.7, 354232.2 6689565.9 29.7, 354232.2 6689566.6 29.7, 354232.5 6689567.2 29.7, 354233.1 6689567.6 29.7, 354233.8 6689567.7 29.7, 354234.9 6689567.1 29.7, 354237.8 6689568.4 29.7, 354239.2 6689565.8 29.7, 354240.3 6689566.3 29.7, 354240.3 6689566.8 29.7, 354242.7 6689566.6 29.7, 354242.5 6689565.6 29.7, 354241.7 6689561 29.7, 354234.7 6689557.6 29.7, 354230.9 6689565.3 29.7))
BATIMENT0000000302928625;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;15;20;8.9;15.8;24.7;27.8;17.1;Cadastre;A 1.0;POLYGON Z ((354178.1 6689564.5 24.7, 354188 6689569.2 24.7, 354191.3 6689561.8 24.7, 354181.4 6689557 24.7, 354178.1 6689564.5 24.7))
BATIMENT0000000302928626;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;10.1;16.5;26.7;30.2;18.2;Cadastre;A 1.0;POLYGON Z ((354195.3 6689575.6 26.7, 354199.4 6689566.7 26.7, 354195.4 6689564.9 26.7, 354195.9 6689563.9 26.7, 354191.3 6689561.8 26.7, 354188 6689569.2 26.7, 354186.2 6689573.3 26.7, 354189.8 6689574.9 26.7, 354189.4 6689575.9 26.7, 354194.2 6689578.1 26.7, 354195.3 6689575.6 26.7))
BATIMENT0000000302928628;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1942-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.1;17.8;28.0;30.8;19.2;Cadastre;A 1.0;POLYGON Z ((354199.6 6689577.6 28, 354199.5 6689578 28, 354203.7 6689580 28, 354205.2 6689576.7 28, 354208 6689571 28, 354204.6 6689569.3 28, 354205.1 6689568.4 28, 354199.8 6689565.9 28, 354199.4 6689566.7 28, 354195.3 6689575.6 28, 354199.6 6689577.6 28))
BATIMENT0000000302928629;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;20;10.5;18.7;29.2;31.0;20.1;Cadastre;A 1.0;POLYGON Z ((354208.1 6689578.1 29.2, 354207.5 6689579.5 29.2, 354210.2 6689580.8 29.2, 354210.9 6689579.5 29.2, 354214.3 6689581 29.2, 354217.5 6689574.2 29.2, 354208.4 6689569.8 29.2, 354208 6689571 29.2, 354205.2 6689576.7 29.2, 354208.1 6689578.1 29.2))
BATIMENT0000000302928627;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;16.4;26.0;27.8;18.2;Cadastre;;POLYGON Z ((354185.3 6689575.3 26, 354193.6 6689579.3 26, 354194.2 6689578.1 26, 354189.4 6689575.9 26, 354189.8 6689574.9 26, 354186.2 6689573.3 26, 354185.3 6689575.3 26))
BATIMENT0000000302928608;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;10.7;22.8;33.5;36.4;26.6;Cadastre;A 1.0;POLYGON Z ((354264.4 6689581.1 33.5, 354268.4 6689583.1 33.5, 354268.6 6689582.7 33.5, 354272.5 6689574.8 33.5, 354265 6689571.1 33.5, 354261.2 6689579.6 33.5, 354264.4 6689581.1 33.5))
BATIMENT0000000302928607;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;40;10;8.3;22.8;31.1;34.6;24.4;Cadastre;A 1.0;POLYGON Z ((354260.7 6689580.7 31.1, 354261.2 6689579.6 31.1, 354265 6689571.1 31.1, 354262.8 6689570.7 31.1, 354255 6689573.5 31.1, 354255.4 6689576.1 31.1, 354256.6 6689584 31.1, 354260.2 6689583.5 31.1, 354260.7 6689580.7 31.1))
BATIMENT0000000302928630;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.8;18.6;28.4;32.5;21.6;Cadastre;A 1.0;POLYGON Z ((354214.3 6689581 28.4, 354212.2 6689585.3 28.4, 354217.9 6689587.9 28.4, 354218.1 6689589.2 28.4, 354218.6 6689589.7 28.4, 354222.1 6689591.3 28.4, 354226 6689578.2 28.4, 354217.5 6689574.2 28.4, 354214.3 6689581 28.4))
BATIMENT0000000302928609;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;24.1;33.0;35.1;26.9;Cadastre;;POLYGON Z ((354263.6 6689582.5 33, 354267.6 6689584.6 33, 354268.4 6689583.1 33, 354264.4 6689581.1 33, 354263.6 6689582.5 33))
BATIMENT0000000302928603;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;29;6.3;22.8;29.1;31.6;25.5;Cadastre;A 1.0;POLYGON Z ((354247.6 6689577.4 29.1, 354247.8 6689578.1 29.1, 354248.9 6689585.8 29.1, 354250 6689585.5 29.1, 354253.8 6689584.9 29.1, 354254.2 6689587.1 29.1, 354250.3 6689587.7 29.1, 354249.2 6689587.9 29.1, 354249.4 6689588.6 29.1, 354250.2 6689592.7 29.1, 354254.7 6689588.8 29.1, 354257.4 6689587.8 29.1, 354256.6 6689584 29.1, 354255.4 6689576.1 29.1, 354247.6 6689577.4 29.1))
BATIMENT0000000302928605;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;20;5.7;22.8;28.5;31.1;24.1;Cadastre;A 1.0;POLYGON Z ((354235.6 6689580 28.5, 354236.5 6689591 28.5, 354249.4 6689588.6 28.5, 354249.2 6689587.9 28.5, 354248.9 6689585.8 28.5, 354247.8 6689578.1 28.5, 354235.6 6689580 28.5))
BATIMENT0000000302928604;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;22.8;29.9;31.7;25.6;Cadastre;;POLYGON Z ((354257.4 6689587.8 29.9, 354259.3 6689588 29.9, 354260.2 6689583.5 29.9, 354256.6 6689584 29.9, 354257.4 6689587.8 29.9))
BATIMENT0000000302928606;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;22.7;28.8;29.6;24.0;Cadastre;;POLYGON Z ((354249.2 6689587.9 28.8, 354250.3 6689587.7 28.8, 354250 6689585.5 28.8, 354248.9 6689585.8 28.8, 354249.2 6689587.9 28.8))
BATIMENT0000000302928602;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;23.8;28.0;28.8;26.0;Cadastre;;POLYGON Z ((354256.2 6689591.3 28, 354257.9 6689590.4 28, 354259.3 6689588 28, 354257.4 6689587.8 28, 354254.7 6689588.8 28, 354256.2 6689591.3 28))
BATIMENT0000000302928598;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;26.2;29.0;31.2;26.9;Cadastre;;POLYGON Z ((354264.9 6689593.7 29, 354268 6689595.3 29, 354269.2 6689593.1 29, 354266.3 6689590.8 29, 354264.9 6689593.7 29))
BATIMENT0000000302928599;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;8.7;24.8;33.5;35.5;26.8;Cadastre;A 1.0;POLYGON Z ((354266.4 6689598.1 33.5, 354268 6689595.3 33.5, 354264.9 6689593.7 33.5, 354266.3 6689590.8 33.5, 354265.1 6689589.8 33.5, 354263.7 6689589.4 33.5, 354261.9 6689592.5 33.5, 354258.8 6689591.2 33.5, 354256.5 6689595.5 33.5, 354256.6 6689595.7 33.5, 354265.3 6689600.3 33.5, 354266.4 6689598.1 33.5))
BATIMENT0000000302928968;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1917-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;7.8;16.5;24.3;25.3;17.9;Cadastre;A 1.0;POLYGON Z ((354181.1 6689594.4 24.3, 354177.6 6689597.2 24.3, 354180.3 6689600.3 24.3, 354179.4 6689601 24.3, 354182.6 6689604.3 24.3, 354191.1 6689597.3 24.3, 354185.3 6689590.8 24.3, 354181.1 6689594.4 24.3))
BATIMENT0000000302928601;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;25.5;29.7;34.0;26.6;Cadastre;;POLYGON Z ((354256.1 6689595.3 29.7, 354254 6689599.3 29.7, 354254.3 6689600.4 29.7, 354257.5 6689602.1 29.7, 354258.7 6689601.5 29.7, 354262.9 6689603.5 29.7, 354265.3 6689600.3 29.7, 354256.6 6689595.7 29.7, 354256.5 6689595.5 29.7, 354256.1 6689595.3 29.7))
BATIMENT0000000302929001;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;10;12.6;20.9;33.5;35.6;22.4;Cadastre;A 1.0;POLYGON Z ((354218.4 6689603.7 33.5, 354228.5 6689604.4 33.5, 354228.6 6689603.8 33.5, 354229.4 6689595.8 33.5, 354221.1 6689594.9 33.5, 354218.4 6689603.7 33.5))
BATIMENT0000000302928624;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;15;20;8.2;14.8;23.0;25.2;16.3;Cadastre;A 1.0;POLYGON Z ((354167.8 6689561.2 23, 354167.3 6689562.3 23, 354176.9 6689566.9 23, 354178.1 6689564.5 23, 354181.4 6689557 23, 354176.4 6689554.7 23, 354175.7 6689555.7 23, 354171.4 6689553.6 23, 354167.8 6689561.2 23))
BATIMENT0000000302928965;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.4;9.9;14.4;21.2;13.4;Cadastre;A 1.0;POLYGON Z ((354129.2 6689554.9 14.4, 354127.6 6689557.3 14.4, 354123.4 6689563.6 14.4, 354130.1 6689568.1 14.4, 354131.6 6689565.7 14.4, 354134.7 6689561.5 14.4, 354137.5 6689563.3 14.4, 354141.6 6689556.9 14.4, 354135.6 6689552.5 14.4, 354133.8 6689554.9 14.4, 354130.7 6689552.5 14.4, 354129.2 6689554.9 14.4))
BATIMENT0000000302929118;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.5;9.0;10.5;12.1;10.0;Cadastre;;POLYGON Z ((354112 6689564.4 10.5, 354114 6689565.7 10.5, 354117.9 6689560.1 10.5, 354117.4 6689559.5 10.5, 354118.3 6689557.9 10.5, 354117.2 6689557.1 10.5, 354112 6689564.4 10.5))
BATIMENT0000000302928963;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;10.6;17.2;21.2;12.3;Cadastre;;POLYGON Z ((354134.4 6689567.6 17.2, 354137.5 6689563.3 17.2, 354134.7 6689561.5 17.2, 354131.6 6689565.7 17.2, 354134.4 6689567.6 17.2))
BATIMENT0000000302928969;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;7.7;13.7;21.5;30.2;16.3;Cadastre;C 0.1;POLYGON Z ((354151.8 6689570.7 21.5, 354174.5 6689586.6 21.5, 354178.4 6689583.5 21.5, 354171.6 6689578.6 21.5, 354162.7 6689572.4 21.5, 354155.7 6689567.1 21.5, 354154.9 6689566.4 21.5, 354151.8 6689570.7 21.5))
BATIMENT0000000302928962;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;35;90;15.9;11.5;27.4;31.2;14.9;Cadastre;C 0.5;POLYGON Z ((354134.4 6689567.6 27.4, 354131.5 6689572 27.4, 354157.3 6689601.1 27.4, 354163.3 6689596.1 27.4, 354165 6689594.7 27.4, 354157.4 6689586.1 27.4, 354157.5 6689585.5 27.4, 354155.3 6689583 27.4, 354155 6689583.3 27.4, 354137.5 6689563.3 27.4, 354134.4 6689567.6 27.4))
BATIMENT0000000302928964;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;9.4;13.8;23.3;24.2;16.2;Cadastre;A 1.0;POLYGON Z ((354165 6689594.7 23.3, 354163.3 6689596.1 23.3, 354166 6689599 23.3, 354167.9 6689597.3 23.3, 354168.2 6689597.7 23.3, 354168.6 6689597.3 23.3, 354172.4 6689601.6 23.3, 354177.6 6689597.2 23.3, 354181.1 6689594.4 23.3, 354177 6689589.5 23.3, 354176.3 6689589.9 23.3, 354174 6689587 23.3, 354165 6689594.7 23.3))
BATIMENT0000000302928911;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;13.6;23.7;26.9;16.9;Cadastre;A 1.0;POLYGON Z ((354171 6689615.5 23.7, 354175.4 6689620.2 23.7, 354174.2 6689621.5 23.7, 354177.6 6689625.5 23.7, 354186.3 6689618 23.7, 354183.2 6689614.4 23.7, 354185 6689612.7 23.7, 354180.5 6689607.2 23.7, 354171 6689615.5 23.7))
BATIMENT0000000302928913;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;30;5.4;11.1;16.5;;;Cadastre;C 0.6;POLYGON Z ((354115.8 6689622.1 16.5, 354115.1 6689623.5 16.5, 354119.8 6689628.5 16.5, 354121.3 6689624.3 16.5, 354125.9 6689615.4 16.5, 354120.2 6689612.4 16.5, 354120.6 6689611.5 16.5, 354117.4 6689608 16.5, 354117.3 6689607.9 16.5, 354115.6 6689610 16.5, 354110.7 6689615.5 16.5, 354108.7 6689617.8 16.5, 354108.3 6689618.3 16.5, 354110.8 6689619.5 16.5, 354115.8 6689622.1 16.5))
BATIMENT0000000302928912;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;40;7.9;11.1;19.0;20.1;11.1;Cadastre;A 1.0;POLYGON Z ((354121.3 6689624.3 19, 354128.1 6689627.8 19, 354132.7 6689619.1 19, 354125.9 6689615.4 19, 354121.3 6689624.3 19))
BATIMENT0000000302928940;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;9.8;27.2;37.0;38.3;28.6;Cadastre;C 0.1;POLYGON Z ((354303.6 6689576.8 37, 354311.1 6689580.5 37, 354313.6 6689581.7 37, 354316.6 6689584 37, 354317.8 6689584.5 37, 354323.2 6689570.9 37, 354308.5 6689564.6 37, 354303.6 6689576.8 37))
BATIMENT0000000302928610;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;50;20;14.0;22.8;36.8;39.7;27.7;Cadastre;A 1.0;POLYGON Z ((354272.5 6689574.8 36.8, 354268.6 6689582.7 36.8, 354277.3 6689587 36.8, 354277.2 6689587.6 36.8, 354280.4 6689589.3 36.8, 354285.2 6689580 36.8, 354273 6689573.8 36.8, 354272.5 6689574.8 36.8))
BATIMENT0000000302928573;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;28.2;40.2;42.5;28.8;Cadastre;;POLYGON Z ((354295 6689595.6 40.2, 354311.4 6689602.5 40.2, 354312.3 6689600.3 40.2, 354293.6 6689592.5 40.2, 354291.3 6689597.9 40.2, 354293.6 6689598.9 40.2, 354295 6689595.6 40.2))
BATIMENT0000000302928597;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;26.4;29.4;31.7;27.4;Cadastre;;POLYGON Z ((354272.4 6689601.9 29.4, 354273.9 6689600 29.4, 354275.1 6689598.1 29.4, 354269.2 6689593.1 29.4, 354268 6689595.3 29.4, 354266.4 6689598.1 29.4, 354272.4 6689601.9 29.4))
BATIMENT0000000302928567;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.9;28.7;44.6;46.2;29.9;Cadastre;;POLYGON Z ((354339 6689607.6 44.6, 354339.9 6689605.4 44.6, 354325.8 6689599.5 44.6, 354325 6689601.7 44.6, 354339 6689607.6 44.6))
BATIMENT0000000302928600;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;29;8.1;26.9;35.0;36.9;28.8;Cadastre;A 1.0;POLYGON Z ((354270.2 6689604.6 35, 354279.3 6689609.7 35, 354280.2 6689608.4 35, 354283.1 6689610.3 35, 354285.6 6689605.7 35, 354283.1 6689604.4 35, 354281.8 6689606 35, 354273.9 6689600 35, 354272.4 6689601.9 35, 354270.2 6689604.6 35))
BATIMENT0000000302928570;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;00;00;14.5;28.5;43.0;43.5;28.9;Cadastre;C 0.1;POLYGON Z ((354293.6 6689598.9 43, 354291.2 6689604.4 43, 354296.8 6689606.7 43, 354295.3 6689610.2 43, 354298 6689611.4 43, 354309.1 6689616.1 43, 354311.8 6689617.3 43, 354313.3 6689613.8 43, 354314.8 6689610.4 43, 354312 6689609.2 43, 354315.2 6689601.6 43, 354312.3 6689600.3 43, 354311.4 6689602.5 43, 354295 6689595.6 43, 354293.6 6689598.9 43))
BATIMENT0000000302928565;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;28.6;42.9;44.2;29.3;Cadastre;;POLYGON Z ((354315.2 6689601.6 42.9, 354312 6689609.2 42.9, 354314.8 6689610.4 42.9, 354313.3 6689613.8 42.9, 354318.9 6689616.1 42.9, 354319.8 6689614 42.9, 354323.5 6689605.1 42.9, 354315.2 6689601.6 42.9))
BATIMENT0000000302928572;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;28.7;42.5;43.1;28.9;Cadastre;;POLYGON Z ((354297.2 6689613.4 42.5, 354308.2 6689618.1 42.5, 354309.1 6689616.1 42.5, 354298 6689611.4 42.5, 354297.2 6689613.4 42.5))
BATIMENT0000000302928564;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.7;28.8;44.5;46.5;29.7;Cadastre;;POLYGON Z ((354324.4 6689618.4 44.5, 354325.3 6689616.3 44.5, 354319.8 6689614 44.5, 354318.9 6689616.1 44.5, 354324.4 6689618.4 44.5))
BATIMENT0000000302928927;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;8.7;21.2;28.5;9.9;Cadastre;;POLYGON Z ((354063.5 6689403.4 21.2, 354065.1 6689410.4 21.2, 354068.3 6689409.8 21.2, 354066.8 6689402.6 21.2, 354063.5 6689403.4 21.2))
BATIMENT0000000302928923;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;9.0;19.7;22.2;9.6;Cadastre;;POLYGON Z ((354040.4 6689410.1 19.7, 354041.2 6689410.9 19.7, 354043 6689410.5 19.7, 354043.5 6689409.7 19.7, 354042.9 6689407.1 19.7, 354040 6689407.7 19.7, 354040.4 6689410.1 19.7))
BATIMENT0000000302929010;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1884-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.1;10.0;11.1;;;Cadastre;C 0.2;POLYGON Z ((354037.8 6689424.5 11.1, 354038 6689425.7 11.1, 354032.8 6689426.7 11.1, 354033.6 6689430.8 11.1, 354040.6 6689429.1 11.1, 354039.5 6689424 11.1, 354037.8 6689424.5 11.1))
BATIMENT0000000029199158;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1930-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;2.0;25;20;2.0;10.0;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354045.1 6689430.4 11.4, 354045.7 6689435.3 11.7, 354048.6 6689447.5 11.7, 354041.1 6689448.6 11.7, 354042.6 6689455.9 11.7, 354051.1 6689454.1 11.9, 354052.1 6689459.6 12, 354057.8 6689458.2 11.9, 354050.8 6689428.5 11.7, 354045.1 6689430.4 11.4))
BATIMENT0000000302928669;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;5.1;7.4;12.5;14.3;9.7;Cadastre;A 1.0;POLYGON Z ((354030.3 6689468.6 12.5, 354031.4 6689470.1 12.5, 354037.6 6689477.7 12.5, 354039.3 6689476.5 12.5, 354040.4 6689470.5 12.5, 354040.9 6689467.7 12.5, 354043.4 6689468.3 12.5, 354047 6689465.8 12.5, 354041.8 6689458.1 12.5, 354038.8 6689460 12.5, 354037.2 6689464 12.5, 354030.3 6689468.6 12.5))
BATIMENT0000000302928668;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;7.7;11.2;13.2;8.1;Cadastre;;POLYGON Z ((354040.4 6689470.5 11.2, 354043.4 6689468.3 11.2, 354040.9 6689467.7 11.2, 354040.4 6689470.5 11.2))
BATIMENT0000000302928670;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;6.8;6.4;13.2;14.3;10.2;Cadastre;A 1.0;POLYGON Z ((354025.8 6689482.8 13.2, 354033.8 6689486.5 13.2, 354034.6 6689484.7 13.2, 354038.1 6689486.2 13.2, 354039.6 6689482.9 13.2, 354040.8 6689483.4 13.2, 354041.3 6689482.2 13.2, 354037.6 6689477.7 13.2, 354031.4 6689470.1 13.2, 354025.8 6689482.8 13.2))
BATIMENT0000000302928646;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;6.8;14.7;18.2;7.6;Cadastre;;POLYGON Z ((354094.3 6689479.7 14.7, 354093.8 6689479.4 14.7, 354092.8 6689478.7 14.7, 354090.1 6689483.1 14.7, 354091.6 6689484 14.7, 354094.3 6689479.7 14.7))
BATIMENT0000000302928645;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;00;00;3.8;6.9;10.8;20.0;8.3;Cadastre;A 1.0;POLYGON Z ((354089.5 6689496.9 10.8, 354100.3 6689504.1 10.8, 354109.7 6689489.6 10.8, 354099.7 6689483.3 10.8, 354094.3 6689479.7 10.8, 354091.6 6689484 10.8, 354090.1 6689483.1 10.8, 354088.6 6689485.6 10.8, 354080.6 6689480.4 10.8, 354081.3 6689479.3 10.8, 354074.3 6689474.8 10.8, 354073.3 6689476.4 10.8, 354072.2 6689475.8 10.8, 354071.9 6689476 10.8, 354071.6 6689476.2 10.8, 354071.1 6689476.6 10.8, 354070.7 6689477 10.8, 354070.6 6689477.2 10.8, 354070.4 6689477.3 10.8, 354070.2 6689477.6 10.8, 354069.8 6689478.1 10.8, 354069.6 6689478.4 10.8, 354069.1 6689479.3 10.8, 354068.9 6689479.6 10.8, 354068.9 6689479.8 10.8, 354068.7 6689480.2 10.8, 354068.5 6689480.8 10.8, 354068.5 6689481 10.8, 354068.4 6689481.3 10.8, 354068.4 6689481.5 10.8, 354068.3 6689481.9 10.8, 354068.3 6689482.3 10.8, 354069 6689482.7 10.8, 354067.9 6689484.4 10.8, 354074.8 6689488.9 10.8, 354075.5 6689487.8 10.8, 354084.2 6689493.6 10.8, 354089.5 6689496.9 10.8))
BATIMENT0000000302928648;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;6.3;14.2;16.2;7.1;Cadastre;;POLYGON Z ((354081.4 6689505.8 14.2, 354083.1 6689507 14.2, 354087.6 6689499.9 14.2, 354086.1 6689498.8 14.2, 354081.4 6689505.8 14.2))
BATIMENT0000000302904664;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1887-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;7.7;10.3;18.0;21.6;11.5;Cadastre;A 1.0;POLYGON Z ((353967.4 6689441.9 18, 353976.7 6689443.7 18, 353979.9 6689444.2 18, 353981.3 6689437.4 18, 353978.1 6689436.7 18, 353968.7 6689434.9 18, 353967.4 6689441.9 18))
BATIMENT0000000302928861;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;9.3;13.2;14.0;9.9;Cadastre;;POLYGON Z ((354011 6689446.7 13.2, 354011.2 6689448.3 13.2, 354016.8 6689447 13.2, 354016.6 6689445.5 13.2, 354011 6689446.7 13.2))
BATIMENT0000000302904663;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.0;10.7;19.7;21.2;12.0;Cadastre;A 1.0;POLYGON Z ((353967.4 6689441.9 19.7, 353965.8 6689450.9 19.7, 353975.1 6689452.5 19.7, 353976.7 6689443.7 19.7, 353967.4 6689441.9 19.7))
BATIMENT0000000302928859;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;12;2.8;10.3;13.1;14.9;10.3;Cadastre;A 1.0;POLYGON Z ((354018.6 6689455.8 13.1, 354019.4 6689459.7 13.1, 354023.7 6689460.5 13.1, 354020.7 6689444.8 13.1, 354016.6 6689445.5 13.1, 354016.8 6689447 13.1, 354018.6 6689455.8 13.1))
BATIMENT0000000302928860;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;10.3;12.7;13.7;10.8;Cadastre;;POLYGON Z ((354016.8 6689456 12.7, 354016.1 6689453.4 12.7, 354012.6 6689454.1 12.7, 354013.3 6689458.5 12.7, 354019.4 6689459.7 12.7, 354018.6 6689455.8 12.7, 354016.8 6689456 12.7))
BATIMENT0000000302902892;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;10;20;14.4;11.5;25.9;28.7;12.6;Cadastre;C 0.8;POLYGON Z ((353977.8 6689471.2 25.9, 353972.8 6689470.2 25.9, 353973.6 6689466.1 25.9, 353978 6689467 25.9, 353978.9 6689462.5 25.9, 353982.6 6689463.2 25.9, 353983.8 6689458 25.9, 353965.1 6689454.6 25.9, 353962.1 6689471.1 25.9, 353973.3 6689473.2 25.9, 353977.3 6689473.9 25.9, 353977.8 6689471.2 25.9))
BATIMENT0000000302903916;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;30;20;7.6;12.0;19.6;22.4;12.8;Cadastre;A 1.0;POLYGON Z ((353990.5 6689486.2 19.6, 354000.4 6689488 19.6, 354004.3 6689468.5 19.6, 353994.3 6689466.6 19.6, 353990.5 6689486.2 19.6))
BATIMENT0000000302902894;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;12.6;15.1;17.1;12.6;Cadastre;;POLYGON Z ((353981.4 6689474.8 15.1, 353978.2 6689474.2 15.1, 353976.4 6689483.3 15.1, 353979.5 6689483.8 15.1, 353979.6 6689483 15.1, 353981.4 6689474.8 15.1))
BATIMENT0000000302902899;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;4.6;12.3;17.0;19.2;12.6;Cadastre;C 0.4;POLYGON Z ((353979.6 6689483 17, 353982.9 6689483.7 17, 353984.5 6689475.2 17, 353981.4 6689474.5 17, 353981.4 6689474.8 17, 353979.6 6689483 17))
BATIMENT0000000302902893;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;14.9;12.1;27.0;29.6;13.0;Cadastre;B 0.4;POLYGON Z ((353973.3 6689473.2 27, 353962.1 6689471.1 27, 353959 6689488.4 27, 353969.9 6689490.6 27, 353971.3 6689484.3 27, 353971.6 6689482.3 27, 353973.3 6689473.2 27))
BATIMENT0000000302906104;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.7;14.5;16.2;;;Cadastre;;POLYGON Z ((353940.7 6689425.2 16.2, 353942.6 6689414.6 16.2, 353938.9 6689413.9 16.2, 353936.9 6689424.6 16.2, 353940.7 6689425.2 16.2))
BATIMENT0000000302903025;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1987-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;35;40;4.3;14.5;18.8;18.9;15.8;Cadastre;C 0.4;POLYGON Z ((353928.1 6689418.1 18.8, 353917.4 6689416.3 18.8, 353916.6 6689421.2 18.8, 353927.3 6689423.1 18.8, 353928.1 6689418.1 18.8))
BATIMENT0000000302906105;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2019-02-27 15:39:01;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;13.8;20.7;23.1;15.6;Cadastre;;POLYGON Z ((353938.8 6689435.7 20.7, 353940.7 6689425.2 20.7, 353936.9 6689424.6 20.7, 353927.3 6689423.1 20.7, 353926.7 6689425.8 20.7, 353925.3 6689433.2 20.7, 353938.8 6689435.7 20.7))
BATIMENT0000000302903027;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;15.5;22.4;23.3;15.7;Cadastre;;POLYGON Z ((353918.1 6689443.6 22.4, 353920.8 6689444 22.4, 353921.3 6689442 22.4, 353918.6 6689441.5 22.4, 353918.1 6689443.6 22.4))
BATIMENT0000000302906106;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.5;14.9;24.5;27.2;16.4;Cadastre;;POLYGON Z ((353911.3 6689443.6 24.5, 353911.9 6689440.2 24.5, 353918.6 6689441.5 24.5, 353921.3 6689442 24.5, 353927.6 6689443.3 24.5, 353923.6 6689466 24.5, 353925.6 6689466.5 24.5, 353924.8 6689471.3 24.5, 353930.3 6689472.2 24.5, 353929.9 6689473.6 24.5, 353931.2 6689473.9 24.5, 353931.4 6689472.3 24.5, 353935.2 6689472.8 24.5, 353936.9 6689465 24.5, 353933.9 6689464.4 24.5, 353938.8 6689435.7 24.5, 353925.3 6689433.2 24.5, 353903.8 6689429.4 24.5, 353901.4 6689441.8 24.5, 353911.3 6689443.6 24.5))
BATIMENT0000000302906107;Chapelle;Religieux;;Non;En service;2012-06-19 17:38:43;2012-10-24 11:03:22;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.7;14.5;27.2;;;Cadastre;;POLYGON Z ((353934 6689479.6 27.2, 353934.4 6689477.2 27.2, 353935.6 6689477.4 27.2, 353935.4 6689478.6 27.2, 353935.4 6689479 27.2, 353935.4 6689479.3 27.2, 353935.5 6689479.7 27.2, 353935.5 6689480 27.2, 353935.6 6689480.3 27.2, 353935.7 6689480.7 27.2, 353935.9 6689481 27.2, 353936.1 6689481.3 27.2, 353936.3 6689481.5 27.2, 353936.5 6689481.8 27.2, 353936.7 6689482 27.2, 353937 6689482.3 27.2, 353937.3 6689482.5 27.2, 353937.6 6689482.6 27.2, 353937.9 6689482.8 27.2, 353938.2 6689482.9 27.2, 353938.5 6689483 27.2, 353938.8 6689483.1 27.2, 353939.2 6689483.2 27.2, 353939.5 6689483.2 27.2, 353939.9 6689483.3 27.2, 353940.3 6689483.3 27.2, 353940.6 6689483.2 27.2, 353941 6689483.2 27.2, 353941.3 6689483.1 27.2, 353941.6 6689482.9 27.2, 353941.9 6689482.8 27.2, 353942.3 6689482.6 27.2, 353942.5 6689482.4 27.2, 353942.8 6689482.2 27.2, 353943.1 6689481.9 27.2, 353943.3 6689481.6 27.2, 353943.5 6689481.3 27.2, 353943.7 6689481 27.2, 353943.8 6689480.7 27.2, 353943.9 6689480.4 27.2, 353944 6689480 27.2, 353944.1 6689479.7 27.2, 353944.2 6689478.6 27.2, 353945.5 6689478.8 27.2, 353945.7 6689477.9 27.2, 353944.4 6689477.7 27.2, 353944.8 6689475.6 27.2, 353946.2 6689475.9 27.2, 353946.4 6689474.9 27.2, 353944.9 6689474.6 27.2, 353946.5 6689466.8 27.2, 353949.8 6689467.3 27.2, 353954.7 6689441.1 27.2, 353953.8 6689440.8 27.2, 353954.2 6689438.1 27.2, 353952 6689437.6 27.2, 353952.2 6689436.3 27.2, 353943 6689434.6 27.2, 353942.7 6689436.1 27.2, 353940.4 6689435.6 27.2, 353940.2 6689436 27.2, 353938.8 6689435.7 27.2, 353933.9 6689464.4 27.2, 353936.9 6689465 27.2, 353935.2 6689472.8 27.2, 353931.4 6689472.3 27.2, 353931.2 6689473.9 27.2, 353930.2 6689478.9 27.2, 353934 6689479.6 27.2))
BATIMENT0000000302903026;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.8;11.0;15.9;20.0;12.8;Cadastre;A 1.0;POLYGON Z ((353945.2 6689481.1 15.9, 353944 6689487.2 15.9, 353947.4 6689487.8 15.9, 353948.8 6689480.9 15.9, 353946 6689480.4 15.9, 353945.2 6689481.1 15.9))
BATIMENT0000000302904689;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.9;17.1;26.0;29.2;18.8;Cadastre;;POLYGON Z ((353895.2 6689498.8 26, 353896.9 6689502.8 26, 353892.0022898072 6689505.037225643 26, 353892.0022898072 6689513.35141075 26, 353893.1 6689515.7 26, 353906.2 6689509.7 26, 353903.6 6689504.1 26, 353907.1 6689502.5 26, 353903.5 6689495 26, 353895.2 6689498.8 26))
BATIMENT0000000302903042;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;8.5;13.6;22.1;24.7;13.8;Cadastre;B 0.8;POLYGON Z ((353932 6689519.5 22.1, 353933.5 6689519.7 22.1, 353932.5 6689521.3 22.1, 353936.2 6689522.1 22.1, 353938 6689520.2 22.1, 353941.9 6689516.9 22.1, 353942.1 6689515.7 22.1, 353935.7 6689510.4 22.1, 353929.2 6689513.5 22.1, 353932 6689519.5 22.1))
BATIMENT0000000302903045;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;7.8;13.6;21.4;23.7;14.0;Cadastre;A 1.0;POLYGON Z ((353932.5 6689521.3 21.4, 353933.5 6689519.7 21.4, 353932 6689519.5 21.4, 353929.2 6689513.5 21.4, 353924.6 6689515.8 21.4, 353928.2 6689523.5 21.4, 353931.6 6689522.6 21.4, 353932.5 6689521.3 21.4))
BATIMENT0000000302903040;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;5.1;13.9;19.0;24.2;14.8;Cadastre;C 0.7;POLYGON Z ((353920 6689518 19, 353911.6 6689522.1 19, 353915.3 6689529.7 19, 353916.7 6689532.7 19, 353921.7 6689530.2 19, 353920.3 6689527.4 19, 353923.7 6689525.7 19, 353920 6689518 19))
BATIMENT0000000302903041;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;13.5;21.5;22.9;14.1;Cadastre;;POLYGON Z ((353927.7 6689528.6 21.5, 353928.4 6689527.5 21.5, 353928.5 6689527.5 21.5, 353931.6 6689522.6 21.5, 353928.2 6689523.5 21.5, 353923.7 6689525.7 21.5, 353926.2 6689530.9 21.5, 353927.7 6689528.6 21.5))
BATIMENT0000000302903039;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.9;14.4;23.3;25.3;15.5;Cadastre;A 1.0;POLYGON Z ((353906.6 6689535.8 23.3, 353910.3 6689533.8 23.3, 353909.7 6689532.6 23.3, 353915.3 6689529.7 23.3, 353911.6 6689522.1 23.3, 353902.1 6689526.6 23.3, 353904.9 6689532.2 23.3, 353906.6 6689535.8 23.3))
BATIMENT0000000302903036;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;15.1;21.7;25.1;15.5;Cadastre;;POLYGON Z ((353900 6689527.7 21.7, 353902.9 6689533.3 21.7, 353904.9 6689532.2 21.7, 353902.1 6689526.6 21.7, 353900 6689527.7 21.7))
BATIMENT0000000302903043;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;12.5;15.2;19.2;14.0;Cadastre;B 0.4;POLYGON Z ((353939 6689533 15.2, 353939.6 6689529.2 15.2, 353928.5 6689527.5 15.2, 353928.4 6689527.5 15.2, 353927.7 6689528.6 15.2, 353926.2 6689530.9 15.2, 353932 6689531.9 15.2, 353934.5 6689532.3 15.2, 353939 6689533 15.2))
BATIMENT0000000302903035;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1892-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.8;14.6;22.5;25.7;16.2;Cadastre;A 1.0;POLYGON Z ((353895.7 6689540.5 22.5, 353897 6689543.2 22.5, 353900.7 6689541.3 22.5, 353899.3 6689538.7 22.5, 353903 6689536.8 22.5, 353898.6 6689528.3 22.5, 353892.0022898072 6689531.530128948 22.5, 353892.0022898072 6689539.235524984 22.5, 353892.9 6689541.1 22.5, 353893.3 6689541.8 22.5, 353895.7 6689540.5 22.5))
BATIMENT0000000302903046;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;2.5;12.9;15.4;20.0;13.7;Cadastre;C 0.3;POLYGON Z ((353930.9 6689538.8 15.4, 353937.7 6689539.8 15.4, 353939 6689533 15.4, 353934.5 6689532.3 15.4, 353932 6689531.9 15.4, 353930.9 6689538.8 15.4))
BATIMENT0000000302903038;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;12.9;14.6;27.5;29.6;16.9;Cadastre;A 1.0;POLYGON Z ((353892.9 6689541.1 27.5, 353892.0022898072 6689539.235524984 27.5, 353892.0022898072 6689541.548855096 27.5, 353892.9 6689541.1 27.5))
BATIMENT0000000302903047;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;8.0;12.9;20.9;23.9;13.7;Cadastre;A 1.0;POLYGON Z ((353927.3 6689546.1 20.9, 353936.3 6689547.6 20.9, 353937.7 6689539.8 20.9, 353930.9 6689538.8 20.9, 353928.6 6689538.5 20.9, 353927.3 6689546.1 20.9))
BATIMENT0000000302903037;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;14.5;21.5;25.5;15.0;Cadastre;;POLYGON Z ((353893.3 6689545.6 21.5, 353894.8 6689544.9 21.5, 353893.3 6689541.8 21.5, 353892.9 6689541.1 21.5, 353892.0022898072 6689541.548855096 21.5, 353892.0022898072 6689543.199236143 21.5, 353893.3 6689545.6 21.5))
BATIMENT0000000302902896;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;12.3;16.2;22.7;12.6;Cadastre;;POLYGON Z ((353971.6 6689482.3 16.2, 353971.3 6689484.3 16.2, 353976 6689485.2 16.2, 353976.4 6689483.3 16.2, 353971.6 6689482.3 16.2))
BATIMENT0000000302902897;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;12.4;15.5;19.2;13.0;Cadastre;;POLYGON Z ((353981.1 6689493 15.5, 353982.9 6689483.7 15.5, 353979.6 6689483 15.5, 353979.5 6689483.8 15.5, 353976.4 6689483.3 15.5, 353976 6689485.2 15.5, 353974.7 6689491.6 15.5, 353981.1 6689493 15.5))
BATIMENT0000000302902895;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;5.0;12.4;17.5;26.2;13.6;Cadastre;C 0.7;POLYGON Z ((353957.4 6689497 17.5, 353960.1 6689497.6 17.5, 353971.8 6689499.9 17.5, 353972.1 6689498.1 17.5, 353971.7 6689497.9 17.5, 353972.7 6689493.4 17.5, 353987.7 6689496.7 17.5, 353988.2 6689494.4 17.5, 353981.1 6689493 17.5, 353974.7 6689491.6 17.5, 353969.9 6689490.6 17.5, 353959 6689488.4 17.5, 353957.4 6689497 17.5))
BATIMENT0000000302929113;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;40;90;2.7;10.5;13.2;14.2;12.1;Cadastre;C 0.2;POLYGON Z ((354000.6 6689506.4 13.2, 354003.4 6689507 13.2, 354006.3 6689498.4 13.2, 354003.4 6689497.7 13.2, 354000.6 6689506.4 13.2))
BATIMENT0000000302929115;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.0;10.4;14.5;16.0;12.2;Cadastre;;POLYGON Z ((354002.6 6689511 14.5, 354005.3 6689511.8 14.5, 354006.9 6689507.4 14.5, 354004.2 6689506.3 14.5, 354002.6 6689511 14.5))
BATIMENT0000000302902898;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1973-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;30;40;4.3;12.6;17.0;32.5;13.7;Cadastre;A 1.0;POLYGON Z ((353955.8 6689522.3 17, 353968.2 6689524.8 17, 353969.5 6689525.1 17, 353983.9 6689528 17, 353988.1 6689503.4 17, 353972.4 6689500 17, 353971.8 6689499.9 17, 353960.1 6689497.6 17, 353955.8 6689522.3 17))
BATIMENT0000000302902900;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;8.5;12.4;21.0;25.7;13.7;Cadastre;A 1.0;POLYGON Z ((353968.2 6689524.8 21, 353955.8 6689522.3 21, 353953 6689521.6 21, 353949.6 6689540.2 21, 353959.2 6689542.2 21, 353960.9 6689542.6 21, 353961.8 6689537.9 21, 353960.6 6689537.6 21, 353962.4 6689528.8 21, 353968.5 6689529.8 21, 353969.5 6689525.1 21, 353968.2 6689524.8 21))
BATIMENT0000000302902901;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;5.8;12.1;18.0;23.4;13.3;Cadastre;A 1.0;POLYGON Z ((353945.7 6689561.9 18, 353954.8 6689563.7 18, 353955 6689561.8 18, 353955.9 6689561.9 18, 353957.9 6689551.7 18, 353955.5 6689551.2 18, 353956.4 6689545.7 18, 353958.5 6689546 18, 353959.2 6689542.2 18, 353949.6 6689540.2 18, 353945.7 6689561.9 18))
BATIMENT0000000302929114;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.8;5.3;10.2;13.5;5.9;Cadastre;;POLYGON Z ((354014.9 6689554.8 10.2, 354016.7 6689556.6 10.2, 354019.9 6689552.9 10.2, 354018.2 6689551.1 10.2, 354014.9 6689554.8 10.2))
BATIMENT0000000302902904;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;9.4;15.2;15.6;10.3;Cadastre;;POLYGON Z ((353956.8 6689583.2 15.2, 353954.5 6689582.9 15.2, 353954.3 6689584 15.2, 353956.8 6689583.2 15.2))
BATIMENT0000000302928647;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.9;6.5;16.5;18.9;8.1;Cadastre;A 1.0;POLYGON Z ((354091.3 6689512.3 16.5, 354096.2 6689504.7 16.5, 354088.1 6689499 16.5, 354089.5 6689496.9 16.5, 354084.2 6689493.6 16.5, 354082.1 6689496.4 16.5, 354086.1 6689498.8 16.5, 354087.6 6689499.9 16.5, 354083.1 6689507 16.5, 354091.3 6689512.3 16.5))
BATIMENT0000000302928649;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;52;10;8.9;6.6;15.5;18.3;8.1;Cadastre;A 1.0;POLYGON Z ((354076.9 6689508.9 15.5, 354076.6 6689509.4 15.5, 354078.4 6689510.6 15.5, 354078.6 6689511.8 15.5, 354081.9 6689514 15.5, 354081.3 6689514.7 15.5, 354087.1 6689518.6 15.5, 354091.3 6689512.3 15.5, 354083.1 6689507 15.5, 354081.4 6689505.8 15.5, 354079.6 6689504.6 15.5, 354076.9 6689508.9 15.5))
BATIMENT0000000302928932;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;10;6.8;6.5;13.3;16.9;7.9;Cadastre;A 1.0;POLYGON Z ((354065 6689547.6 13.3, 354061.1 6689543.7 13.3, 354066.9 6689537.9 13.3, 354059 6689529.1 13.3, 354048.7 6689539.6 13.3, 354052.8 6689543.7 13.3, 354054.4 6689545.3 13.3, 354056.6 6689547.4 13.3, 354060.9 6689551.7 13.3, 354065 6689547.6 13.3))
BATIMENT0000000302928929;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;6.6;10.7;13.7;7.1;Cadastre;;POLYGON Z ((354048 6689552 10.7, 354049 6689553 10.7, 354050.1 6689554 10.7, 354056.6 6689547.4 10.7, 354054.4 6689545.3 10.7, 354048 6689552 10.7))
BATIMENT0000000302928930;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;7.1;5.5;12.6;14.9;7.4;Cadastre;A 1.0;POLYGON Z ((354050.1 6689554 12.6, 354056.6 6689560.4 12.6, 354063 6689553.9 12.6, 354060.9 6689551.7 12.6, 354056.6 6689547.4 12.6, 354050.1 6689554 12.6))
BATIMENT0000000302928931;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.0;5.8;12.8;15.7;7.2;Cadastre;A 1.0;POLYGON Z ((354046.8 6689555.2 12.8, 354046 6689554.5 12.8, 354042.3 6689558.4 12.8, 354042.7 6689558.7 12.8, 354050.5 6689566.6 12.8, 354056.6 6689560.4 12.8, 354050.1 6689554 12.8, 354049 6689553 12.8, 354046.8 6689555.2 12.8))
BATIMENT0000000302929075;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;23;8.1;6.1;14.2;16.9;8.4;Cadastre;A 1.0;POLYGON Z ((354067.7 6689562.3 14.2, 354065.4 6689564.7 14.2, 354070.7 6689570.3 14.2, 354073.1 6689568.2 14.2, 354074.6 6689566.7 14.2, 354081.2 6689561 14.2, 354075.4 6689554.5 14.2, 354067.7 6689562.3 14.2))
BATIMENT0000000302928933;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.8;5.9;12.7;16.4;7.1;Cadastre;A 1.0;POLYGON Z ((354035.6 6689565.7 12.7, 354036.1 6689566.3 12.7, 354043.5 6689573.4 12.7, 354050.5 6689566.6 12.7, 354042.7 6689558.7 12.7, 354035.6 6689565.7 12.7))
BATIMENT0000000302929076;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;16;20;8.2;6.1;14.3;17.6;8.8;Cadastre;A 1.0;POLYGON Z ((354074.6 6689566.7 14.3, 354080.7 6689573.6 14.3, 354087.1 6689567.8 14.3, 354081.2 6689561 14.3, 354074.6 6689566.7 14.3))
BATIMENT0000000302928934;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;10;6.1;5.9;12.0;15.9;6.9;Cadastre;A 1.0;POLYGON Z ((354031.6 6689571.1 12, 354038.9 6689578.1 12, 354043.5 6689573.4 12, 354036.1 6689566.3 12, 354031.6 6689571.1 12))
BATIMENT0000000302903952;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.1;12.6;19.7;23.2;13.1;Cadastre;A 1.0;POLYGON Z ((353924.1 6689562 19.7, 353926.4 6689562.4 19.7, 353933.4 6689563.7 19.7, 353935.7 6689550.7 19.7, 353926.4 6689549.2 19.7, 353924.1 6689562 19.7))
BATIMENT0000000302906011;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;3.1;12.4;15.5;17.7;14.7;Cadastre;B 0.3;POLYGON Z ((353896 6689566.5 15.5, 353900 6689567 15.5, 353906.3 6689567.7 15.5, 353907.1 6689563.8 15.5, 353899.2 6689562.6 15.5, 353896 6689566.5 15.5))
BATIMENT0000000302906010;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;12.3;15.5;19.7;14.9;Cadastre;;POLYGON Z ((353896 6689566.5 15.5, 353893.7 6689569.2 15.5, 353895.8 6689570.6 15.5, 353897.3 6689568.7 15.5, 353899.7 6689569.1 15.5, 353900 6689567 15.5, 353896 6689566.5 15.5))
BATIMENT0000000302902902;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;30;11.2;9.1;20.3;21.9;13.0;Cadastre;A 1.0;POLYGON Z ((353942.9 6689577.2 20.3, 353955 6689579.5 20.3, 353957.8 6689564.3 20.3, 353954.8 6689563.7 20.3, 353945.7 6689561.9 20.3, 353942.9 6689577.2 20.3))
BATIMENT0000000302906008;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;2.9;12.3;15.2;18.0;14.9;Cadastre;A 0.1;POLYGON Z ((353892.6 6689570.6 15.2, 353892.0022898072 6689571.272423967 15.2, 353892.0022898072 6689571.659702479 15.2, 353893.7 6689573 15.2, 353895.8 6689570.6 15.2, 353893.7 6689569.2 15.2, 353892.6 6689570.6 15.2))
BATIMENT0000000302903951;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1595-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.8;12.5;21.3;23.2;12.8;Cadastre;B 0.8;POLYGON Z ((353925.7 6689566.8 21.3, 353923.2 6689566.4 21.3, 353920.7 6689579.7 21.3, 353919.4 6689579.5 21.3, 353918.6 6689584.4 21.3, 353929.2 6689586.6 21.3, 353933.4 6689563.7 21.3, 353926.4 6689562.4 21.3, 353925.7 6689566.8 21.3))
BATIMENT0000000302902979;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;12.2;23.0;24.7;13.6;Cadastre;;POLYGON Z ((353895.1 6689580.4 23, 353894.1 6689579.7 23, 353892.9 6689583.1 23, 353894.8 6689583.1 23, 353895.1 6689580.4 23))
BATIMENT0000000302902903;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;26;24;9.0;9.7;18.7;22.1;12.2;Cadastre;A 1.0;POLYGON Z ((353941.3 6689585.9 18.7, 353951.4 6689587.7 18.7, 353953.5 6689588.1 18.7, 353954.3 6689584 18.7, 353954.5 6689582.9 18.7, 353956.8 6689583.2 18.7, 353957.4 6689580 18.7, 353955 6689579.5 18.7, 353942.9 6689577.2 18.7, 353941.3 6689585.9 18.7))
BATIMENT0000000302902980;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.8;13.9;20.7;;;Cadastre;A 0.7;POLYGON Z ((353894.1 6689579.7 20.7, 353895.1 6689580.4 20.7, 353894.8 6689583.1 20.7, 353894.5 6689584.9 20.7, 353892.2 6689585.4 20.7, 353892.0022898072 6689587.574812121 20.7, 353892.0022898072 6689587.600436154 20.7, 353894.1 6689588 20.7, 353900.9 6689589.3 20.7, 353902.7 6689589.6 20.7, 353903.9 6689584 20.7, 353904.5 6689581 20.7, 353898.7 6689580.1 20.7, 353896.9 6689578.6 20.7, 353895.3 6689577.1 20.7, 353894.1 6689579.7 20.7))
BATIMENT0000000302902978;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;29;5.2;12.2;17.5;24.5;14.9;Cadastre;A 0.7;MULTIPOLYGON Z (((353893.2 6689594.1 17.5, 353892.0022898072 6689592.965327186 17.5, 353892.0022898072 6689595.4136176305 17.5, 353893.2 6689594.1 17.5)), ((353894 6689589.2 17.5, 353894.1 6689588 17.5, 353892.0022898072 6689587.600436154 17.5, 353892.0022898072 6689591.493667258 17.5, 353894 6689589.2 17.5)), ((353892.2 6689585.4 17.5, 353894.5 6689584.9 17.5, 353894.8 6689583.1 17.5, 353892.9 6689583.1 17.5, 353894.1 6689579.7 17.5, 353895.3 6689577.1 17.5, 353895.2 6689576.3 17.5, 353892.0022898072 6689573.534412806 17.5, 353892.0022898072 6689587.574812121 17.5, 353892.2 6689585.4 17.5)))
BATIMENT0000000302929077;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;19;9.6;7.8;17.5;19.7;8.9;Cadastre;A 1.0;POLYGON Z ((354080.7 6689573.6 17.5, 354080.4 6689573.8 17.5, 354083 6689577.1 17.5, 354083.7 6689576.4 17.5, 354086 6689579 17.5, 354091.2 6689574.3 17.5, 354088.8 6689571.5 17.5, 354089.6 6689570.7 17.5, 354087.1 6689567.8 17.5, 354080.7 6689573.6 17.5))
BATIMENT0000000302928935;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;16;20;6.7;5.3;12.0;15.5;6.7;Cadastre;A 1.0;POLYGON Z ((354026 6689576.9 12, 354033.2 6689583.9 12, 354038.9 6689578.1 12, 354031.6 6689571.1 12, 354026 6689576.9 12))
BATIMENT0000000302929078;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;00;00;9.3;8.4;17.7;22.7;10.6;Cadastre;A 1.0;POLYGON Z ((354092.6 6689587.2 17.7, 354099.4 6689581.4 17.7, 354092.3 6689573.4 17.7, 354091.2 6689574.3 17.7, 354086 6689579 17.7, 354085.7 6689579.4 17.7, 354080.4 6689584.1 17.7, 354087.4 6689591.9 17.7, 354092.6 6689587.2 17.7))
BATIMENT0000000302928936;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;23;20;7.1;5.3;12.4;16.1;6.6;Cadastre;A 1.0;POLYGON Z ((354020.4 6689582.7 12.4, 354027.7 6689589.5 12.4, 354033.2 6689583.9 12.4, 354026 6689576.9 12.4, 354020.4 6689582.7 12.4))
BATIMENT0000000302928664;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;34;10;5.6;6.4;12.0;15.1;7.1;Cadastre;A 1.0;POLYGON Z ((354049.6 6689586.3 12, 354056.3 6689592.6 12, 354061.9 6689586.7 12, 354055.4 6689580.3 12, 354049.6 6689586.3 12))
BATIMENT0000000302928663;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;23;10;10.3;6.6;17.0;20.1;7.2;Cadastre;A 1.0;POLYGON Z ((354040.4 6689588.6 17, 354047.2 6689595.6 17, 354052 6689590.7 17, 354045.4 6689583.7 17, 354040.4 6689588.6 17))
BATIMENT0000000302928662;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;34;10;8.1;5.4;13.5;17.4;7.0;Cadastre;A 1.0;POLYGON Z ((354035.5 6689593.8 13.5, 354042.1 6689600.6 13.5, 354047.2 6689595.6 13.5, 354040.4 6689588.6 13.5, 354035.5 6689593.8 13.5))
BATIMENT0000000029198359;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2012-06-19 19:00:51;;;;;BDTopo;2.5;BDTopo;1.5;;;;;11.1;10.9;;;;Imagerie aérienne;;POLYGON Z ((354108.4 6689590 21.7, 354091.5 6689595.7 21.6, 354096.2 6689609.8 21.7, 354113.1 6689604.1 22, 354108.4 6689590 21.7))
BATIMENT0000000302928661;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;10;8.1;5.1;13.2;14.9;7.0;Cadastre;A 1.0;POLYGON Z ((354029.3 6689600.1 13.2, 354035.9 6689606.6 13.2, 354042.1 6689600.6 13.2, 354035.5 6689593.8 13.2, 354029.3 6689600.1 13.2))
BATIMENT0000000029199501;Indifférenciée;Résidentiel;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1850-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;1.0;;;6.5;9.3;;16.2;9.6;Imagerie aérienne;C 0.2;POLYGON Z ((354086.3 6689599 15.8, 354065.6 6689616.9 15.4, 354064.3 6689615.4 12, 354057.7 6689621.3 11.3, 354071.2 6689636.8 11.3, 354078.4 6689630.7 12, 354077.1 6689629.3 15.3, 354097.3 6689611.7 15.5, 354086.3 6689599 15.8))
BATIMENT0000000302902985;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;09;01;4.2;12.0;16.2;19.5;12.7;Cadastre;C 0.3;POLYGON Z ((353902.7 6689589.6 16.2, 353906.5 6689590.3 16.2, 353907.7 6689584.7 16.2, 353903.9 6689584 16.2, 353902.7 6689589.6 16.2))
BATIMENT0000000302903950;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.6;11.6;22.3;24.4;12.6;Cadastre;C 1.0;POLYGON Z ((353916.8 6689592.2 22.3, 353927.8 6689594.3 22.3, 353929.2 6689586.6 22.3, 353918.6 6689584.4 22.3, 353918.3 6689584.4 22.3, 353916.8 6689592.2 22.3))
BATIMENT0000000302902906;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;11.7;8.2;19.9;22.6;12.1;Cadastre;A 1.0;POLYGON Z ((353939.7 6689594.7 19.9, 353952.5 6689597 19.9, 353954.2 6689597.3 19.9, 353954.6 6689594.6 19.9, 353953.1 6689594.3 19.9, 353950.1 6689593.8 19.9, 353951.4 6689587.7 19.9, 353941.3 6689585.9 19.9, 353939.7 6689594.7 19.9))
BATIMENT0000000302902907;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;50;20;11.8;8.2;20.0;23.4;12.0;Cadastre;A 1.0;POLYGON Z ((353938.6 6689601.1 20, 353951.4 6689603.4 20, 353952.5 6689597 20, 353939.7 6689594.7 20, 353938.6 6689601.1 20))
BATIMENT0000000302902954;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;10;5.5;13.3;18.8;;;Cadastre;A 1.0;POLYGON Z ((353901.5 6689599.7 18.8, 353894 6689608.3 18.8, 353900.6 6689614.2 18.8, 353905.8 6689608.4 18.8, 353906.6 6689608.2 18.8, 353907.9 6689600.8 18.8, 353906.1 6689600.5 18.8, 353905.9 6689601.8 18.8, 353905.8 6689601.9 18.8, 353905.8 6689602 18.8, 353905.7 6689602 18.8, 353905.6 6689602.1 18.8, 353905.5 6689602.1 18.8, 353905.4 6689602.1 18.8, 353905.3 6689602.1 18.8, 353905.2 6689602.1 18.8, 353905.1 6689602.1 18.8, 353904.9 6689602 18.8, 353904.8 6689601.9 18.8, 353904.7 6689601.7 18.8, 353904.6 6689601.5 18.8, 353903.7 6689600.1 18.8, 353901.5 6689599.7 18.8))
BATIMENT0000000302902908;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;12.3;8.2;20.5;23.9;11.9;Cadastre;A 1.0;POLYGON Z ((353936.6 6689612 20.5, 353946.9 6689613.8 20.5, 353949.4 6689614.1 20.5, 353951.1 6689604.7 20.5, 353951.4 6689603.4 20.5, 353938.6 6689601.1 20.5, 353936.6 6689612 20.5))
BATIMENT0000000302902956;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;5.6;12.5;18.1;;;Cadastre;A 1.0;POLYGON Z ((353915.7 6689610.1 18.1, 353913.8 6689609.8 18.1, 353913.1 6689613 18.1, 353924 6689615 18.1, 353925.7 6689606 18.1, 353924.2 6689603.7 18.1, 353917.2 6689602.5 18.1, 353915.7 6689610.1 18.1))
BATIMENT0000000302902953;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1941-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;5.8;13.3;19.1;;;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6689610.600393555 19.1, 353892.0022898072 6689613.300548416 19.1, 353897.1 6689618 19.1, 353900.6 6689614.2 19.1, 353894 6689608.3 19.1, 353892.0022898072 6689610.600393555 19.1))
BATIMENT0000000302902951;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;40;10;5.8;13.3;19.1;;;Cadastre;A 1.0;POLYGON Z ((353893.8 6689621.8 19.1, 353897.1 6689618 19.1, 353892.0022898072 6689613.300548416 19.1, 353892.0022898072 6689620.195889366 19.1, 353893.8 6689621.8 19.1))
BATIMENT0000000302906006;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.0;11.9;14.0;15.0;12.6;Cadastre;;POLYGON Z ((353898.8 6689620.4 14, 353900.9 6689622.3 14, 353904.3 6689618.4 14, 353902.4 6689616.6 14, 353898.8 6689620.4 14))
BATIMENT0000000302928937;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;6.0;12.2;15.0;6.3;Cadastre;;POLYGON Z ((354018.9 6689581.3 12.2, 354015.5 6689584.8 12.2, 354016.9 6689586.3 12.2, 354020.4 6689582.7 12.2, 354018.9 6689581.3 12.2))
BATIMENT0000000302928938;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.8;6.1;16.0;17.1;6.4;Cadastre;A 1.0;POLYGON Z ((354016.3 6689587.1 16, 354016.6 6689587.4 16, 354023.5 6689593.8 16, 354027.7 6689589.5 16, 354020.4 6689582.7 16, 354016.9 6689586.3 16, 354016.3 6689587.1 16))
BATIMENT0000000302902905;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;9.6;14.7;17.7;10.7;Cadastre;;POLYGON Z ((353954.2 6689588.3 14.7, 353953.5 6689588.1 14.7, 353951.4 6689587.7 14.7, 353950.1 6689593.8 14.7, 353953.1 6689594.3 14.7, 353954.2 6689588.3 14.7))
BATIMENT0000000302928939;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;34;30;7.0;5.4;12.4;14.5;6.5;Cadastre;A 1.0;POLYGON Z ((354014.6 6689589.5 12.4, 354016.6 6689597.7 12.4, 354018.3 6689599.1 12.4, 354023.5 6689593.8 12.4, 354016.6 6689587.4 12.4, 354014.6 6689589.5 12.4))
BATIMENT0000000302906009;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.5;7.0;8.5;12.7;7.7;Cadastre;;POLYGON Z ((353976.7 6689633.6 8.5, 353982.5 6689641.9 8.5, 353987.1 6689638.6 8.5, 353981.2 6689630.3 8.5, 353976.7 6689633.6 8.5))
BATIMENT0000000302902910;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;6.0;30;49;12.8;7.6;20.5;27.8;11.5;Cadastre;C 0.6;POLYGON Z ((353949.7 6689629.2 20.5, 353946.9 6689629.9 20.5, 353937.3 6689632.3 20.5, 353940.2 6689641.4 20.5, 353955.1 6689662.3 20.5, 353965.1 6689655.1 20.5, 353965.4 6689654.9 20.5, 353963.5 6689652.3 20.5, 353974.4 6689644.4 20.5, 353967.4 6689634.3 20.5, 353972.4 6689630.5 20.5, 353968.3 6689624.6 20.5, 353949.7 6689629.2 20.5))
BATIMENT0000000302906089;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;6.8;9.8;16.5;9.6;Cadastre;;POLYGON Z ((353991.2 6689668.5 9.8, 353996.8 6689664.6 9.8, 354006.2 6689658.1 9.8, 354007 6689657.4 9.8, 354001 6689648.6 9.8, 353998.8 6689645.6 9.8, 353974.2 6689662.8 9.8, 353982.5 6689674.6 9.8, 353991.2 6689668.5 9.8))
BATIMENT0000000302902911;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;17.0;7.9;24.9;27.4;10.1;Cadastre;A 1.0;POLYGON Z ((353955.1 6689662.3 24.9, 353961.7 6689671.6 24.9, 353971.9 6689664.5 24.9, 353965.1 6689655.1 24.9, 353955.1 6689662.3 24.9))
BATIMENT0000000302902917;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;7.0;10.3;11.1;9.6;Cadastre;;POLYGON Z ((353996.8 6689664.6 10.3, 353999.7 6689668.7 10.3, 354009.1 6689662.2 10.3, 354006.2 6689658.1 10.3, 353996.8 6689664.6 10.3))
BATIMENT0000000302902916;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;04;01;5.6;6.6;12.2;13.9;9.3;Cadastre;C 0.3;POLYGON Z ((353994.3 6689672.8 12.2, 353994.4 6689672.6 12.2, 353999.7 6689668.8 12.2, 353999.7 6689668.7 12.2, 353996.8 6689664.6 12.2, 353991.2 6689668.5 12.2, 353994.3 6689672.8 12.2))
BATIMENT0000000302928485;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;12.1;25.0;37.1;39.2;26.5;Cadastre;A 1.0;POLYGON Z ((354407 6689401.9 37.1, 354415.3 6689403.6 37.1, 354419 6689404.4 37.1, 354421.6 6689392.6 37.1, 354418 6689391.8 37.1, 354409.5 6689390.1 37.1, 354407 6689401.9 37.1))
BATIMENT0000000302928493;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.6;27.6;34.2;35.0;28.9;Cadastre;;POLYGON Z ((354451.7 6689387.4 34.2, 354445.9 6689387 34.2, 354445.4 6689394.5 34.2, 354445.1 6689397.2 34.2, 354444.1 6689409.3 34.2, 354446.3 6689409.5 34.2, 354450.8 6689409.8 34.2, 354466.5 6689410.9 34.2, 354466.6 6689408.9 34.2, 354466.9 6689405.1 34.2, 354459.4 6689404.5 34.2, 354456.8 6689404.2 34.2, 354450.8 6689397.7 34.2, 354451.2 6689395.1 34.2, 354451.7 6689387.4 34.2))
BATIMENT0000000302928495;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.0;27.9;30.0;33.0;28.5;Cadastre;;POLYGON Z ((354459.3 6689402.4 30, 354458.8 6689400.9 30, 354454.6 6689395.8 30, 354453.6 6689395.3 30, 354451.2 6689395.1 30, 354450.8 6689397.7 30, 354456.8 6689404.2 30, 354459.4 6689404.5 30, 354459.3 6689402.4 30))
BATIMENT0000000302928480;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;23;10.4;25.3;35.7;38.5;26.8;Cadastre;A 1.0;POLYGON Z ((354404.2 6689414.7 35.7, 354415.8 6689417 35.7, 354416.6 6689415.7 35.7, 354416.9 6689414.7 35.7, 354417 6689414.4 35.7, 354416.9 6689414 35.7, 354416.9 6689413.8 35.7, 354416.6 6689412.6 35.7, 354414.8 6689412.3 35.7, 354415.9 6689407 35.7, 354414.7 6689406.7 35.7, 354415.3 6689403.6 35.7, 354407 6689401.9 35.7, 354404.2 6689414.7 35.7))
BATIMENT0000000302928488;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;28.3;31.5;39.9;28.8;Cadastre;;POLYGON Z ((354473 6689411.4 31.5, 354476.2 6689411.5 31.5, 354476.4 6689409.5 31.5, 354466.6 6689408.9 31.5, 354466.5 6689410.9 31.5, 354473 6689411.4 31.5))
BATIMENT0000000302928473;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;10;20;16.6;25.6;42.2;44.9;26.8;Cadastre;A 1.0;POLYGON Z ((354401.5 6689428.1 42.2, 354399.4 6689439.1 42.2, 354412 6689441.9 42.2, 354412.9 6689437.7 42.2, 354415.8 6689438.4 42.2, 354417.3 6689431.5 42.2, 354419.3 6689421.9 42.2, 354416.4 6689421.3 42.2, 354417.2 6689417.4 42.2, 354415.8 6689417 42.2, 354404.2 6689414.7 42.2, 354401.5 6689428.1 42.2))
BATIMENT0000000302929037;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.6;27.8;32.4;36.0;29.0;Cadastre;C 0.4;POLYGON Z ((354462.9 6689441.7 32.4, 354465.1 6689433 32.4, 354454.1 6689430.6 32.4, 354452.2 6689439.4 32.4, 354462.9 6689441.7 32.4))
BATIMENT0000000302928472;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;26.3;29.0;31.2;27.1;Cadastre;;POLYGON Z ((354423.5 6689446.8 29, 354424.1 6689444.7 29, 354418 6689443.3 29, 354418 6689443.4 29, 354417.6 6689445.4 29, 354423.5 6689446.8 29))
BATIMENT0000000302928470;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;26.2;31.0;36.2;26.6;Cadastre;;POLYGON Z ((354413.9 6689444.6 31, 354416.7 6689445.2 31, 354417.6 6689445.4 31, 354418 6689443.4 31, 354418 6689443.3 31, 354412 6689441.9 31, 354410.3 6689449 31, 354412.5 6689449.6 31, 354413.9 6689444.6 31))
BATIMENT0000000302928479;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;7.1;26.5;33.6;34.9;28.2;Cadastre;A 0.3;POLYGON Z ((354421.4 6689455.7 33.6, 354427.5 6689457.4 33.6, 354428.2 6689454.3 33.6, 354428.3 6689454.2 33.6, 354429.5 6689449 33.6, 354430.1 6689446 33.6, 354424.1 6689444.7 33.6, 354423.5 6689446.8 33.6, 354421.4 6689455.7 33.6))
BATIMENT0000000302928899;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;23.2;33.5;36.5;23.5;Cadastre;;POLYGON Z ((354376.9 6689416.7 33.5, 354376.5 6689418.5 33.5, 354379.2 6689419 33.5, 354379.6 6689417.3 33.5, 354376.9 6689416.7 33.5))
BATIMENT0000000302928898;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;15.9;23.3;39.2;42.0;25.9;Cadastre;A 1.0;POLYGON Z ((354378.3 6689423.2 39.2, 354375.9 6689434 39.2, 354388.2 6689436.9 39.2, 354392 6689419.8 39.2, 354381.9 6689417.8 39.2, 354379.6 6689417.3 39.2, 354379.2 6689419 39.2, 354378.3 6689423.2 39.2))
BATIMENT0000000302928900;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;13.7;23.3;37.0;39.3;25.9;Cadastre;A 1.0;POLYGON Z ((354371.8 6689443.7 37, 354386.2 6689447 37, 354388.2 6689436.9 37, 354375.9 6689434 37, 354374 6689433.6 37, 354371.8 6689443.7 37))
BATIMENT0000000302928901;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;23.5;37.6;39.2;25.9;Cadastre;;POLYGON Z ((354371.3 6689446.2 37.6, 354385.6 6689449.6 37.6, 354386.2 6689447 37.6, 354371.8 6689443.7 37.6, 354371.3 6689446.2 37.6))
BATIMENT0000000302928471;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;14.3;26.1;40.4;44.0;26.5;Cadastre;A 1.0;POLYGON Z ((354399.4 6689439.1 40.4, 354395.4 6689458.3 40.4, 354407.7 6689461.2 40.4, 354410.3 6689449 40.4, 354412 6689441.9 40.4, 354399.4 6689439.1 40.4))
BATIMENT0000000302928902;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;00;00;13.2;23.5;36.7;39.2;26.3;Cadastre;C 0.8;POLYGON Z ((354369.2 6689456.5 36.7, 354371.3 6689457 36.7, 354383.6 6689459.9 36.7, 354385.6 6689449.6 36.7, 354371.3 6689446.2 36.7, 354369.2 6689456.5 36.7))
BATIMENT0000000302928903;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1853-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.9;23.6;35.5;39.0;26.3;Cadastre;A 1.0;POLYGON Z ((354370.6 6689460.2 35.5, 354368.4 6689460.7 35.5, 354367.9 6689463 35.5, 354369.7 6689464.3 35.5, 354369.1 6689467.4 35.5, 354371.1 6689468 35.5, 354381.3 6689470.5 35.5, 354383.6 6689459.9 35.5, 354371.3 6689457 35.5, 354370.6 6689460.2 35.5))
BATIMENT0000000302928474;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;17.4;26.1;43.5;46.1;26.7;Cadastre;A 1.0;POLYGON Z ((354392.6 6689470.9 43.5, 354405 6689473.7 43.5, 354407.7 6689461.2 43.5, 354395.4 6689458.3 43.5, 354392.6 6689470.9 43.5))
BATIMENT0000000302929105;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.2;22.9;28.2;32.0;25.4;Cadastre;;POLYGON Z ((354339.8 6689473.4 28.2, 354345.8 6689474.7 28.2, 354353.9 6689476.5 28.2, 354354.4 6689473.9 28.2, 354343.2 6689471.1 28.2, 354343.5 6689470.1 28.2, 354340.6 6689469.4 28.2, 354339.8 6689473.4 28.2))
BATIMENT0000000302928904;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;14.9;24.0;39.0;41.0;26.5;Cadastre;B 0.5;POLYGON Z ((354369 6689476.8 39, 354367.9 6689476.7 39, 354367.2 6689479.5 39, 354378.9 6689482.2 39, 354381.3 6689470.5 39, 354371.1 6689468 39, 354369 6689476.8 39))
BATIMENT0000000302928531;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;50;20;14.6;28.9;43.5;46.9;29.0;Cadastre;A 1.0;POLYGON Z ((354509.6 6689428.6 43.5, 354498.2 6689426.3 43.5, 354495 6689441.1 43.5, 354506.2 6689443.5 43.5, 354509.6 6689428.6 43.5))
BATIMENT0000000302928482;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;00;00;13.7;28.5;42.2;44.4;28.9;Cadastre;A 1.0;POLYGON Z ((354470.7 6689443.2 42.2, 354471.3 6689443.3 42.2, 354483.8 6689446.1 42.2, 354486 6689436.4 42.2, 354473.1 6689433.4 42.2, 354470.7 6689443.2 42.2))
BATIMENT0000000302928537;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;00;00;15.5;28.5;44.0;49.7;30.3;Cadastre;A 1.0;POLYGON Z ((354520.5 6689446.8 44, 354521.1 6689447 44, 354536 6689450.4 44, 354540.2 6689435.2 44, 354524.6 6689431.9 44, 354520.5 6689446.8 44))
BATIMENT0000000302928540;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;20;20;19.8;28.6;48.5;50.0;29.6;Cadastre;A 1.0;POLYGON Z ((354490.9 6689460.1 48.5, 354500 6689462.2 48.5, 354503.5 6689447.6 48.5, 354506.5 6689448.3 48.5, 354509.9 6689449.1 48.5, 354510.1 6689449.1 48.5, 354511.1 6689444.7 48.5, 354506.2 6689443.5 48.5, 354495 6689441.1 48.5, 354490.9 6689460.1 48.5))
BATIMENT0000000302928481;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.7;28.7;41.5;46.0;29.3;Cadastre;A 1.0;POLYGON Z ((354467.6 6689457.8 41.5, 354480.6 6689460.8 41.5, 354483.8 6689446.1 41.5, 354471.3 6689443.3 41.5, 354467.6 6689457.8 41.5))
BATIMENT0000000302928545;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.4;29.5;40.0;42.2;29.7;Cadastre;;POLYGON Z ((354530.1 6689464.9 40, 354531.8 6689465.4 40, 354532.8 6689461.9 40, 354531.2 6689461.5 40, 354530.1 6689464.9 40))
BATIMENT0000000302927920;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1901-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;10;7.8;30.0;37.8;40.2;30.8;Cadastre;A 1.0;POLYGON Z ((354541.8 6689467.7 37.8, 354550.6 6689470.2 37.8, 354552.6 6689462.5 37.8, 354549.4 6689461.6 37.8, 354543.9 6689460 37.8, 354541.8 6689467.7 37.8))
BATIMENT0000000302928542;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;86.0;6.0;90;90;14.9;28.7;43.6;47.2;30.1;Cadastre;A 1.0;POLYGON Z ((354514.9 6689473.8 43.6, 354517.3 6689474.3 43.6, 354515.7 6689481.1 43.6, 354526.8 6689483.6 43.6, 354530.1 6689471.7 43.6, 354530.7 6689469.5 43.6, 354531.8 6689465.4 43.6, 354530.1 6689464.9 43.6, 354531.2 6689461.5 43.6, 354532.8 6689461.9 43.6, 354532.9 6689461.7 43.6, 354534.8 6689454.9 43.6, 354536 6689450.4 43.6, 354521.1 6689447 43.6, 354514.9 6689473.8 43.6))
BATIMENT0000000302928543;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;7.0;50;10;18.5;29.0;47.5;51.5;30.0;Cadastre;A 1.0;POLYGON Z ((354487.8 6689474.9 47.5, 354496.9 6689476.9 47.5, 354506 6689478.8 47.5, 354506.9 6689474.9 47.5, 354498.7 6689473.2 47.5, 354501.4 6689462.5 47.5, 354500 6689462.2 47.5, 354490.9 6689460.1 47.5, 354487.8 6689474.9 47.5))
BATIMENT0000000302928544;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;8.9;29.0;37.9;48.0;30.0;Cadastre;A 1.0;POLYGON Z ((354485.7 6689483.9 37.9, 354494.7 6689485.9 37.9, 354498.4 6689486.9 37.9, 354499.2 6689483.9 37.9, 354495.3 6689482.9 37.9, 354496.9 6689476.9 37.9, 354487.8 6689474.9 37.9, 354485.7 6689483.9 37.9))
BATIMENT0000000302928546;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;10;10;9.4;29.7;39.2;41.6;30.0;Cadastre;A 1.0;POLYGON Z ((354514.2 6689487.2 39.2, 354516.8 6689487.8 39.2, 354525.2 6689490 39.2, 354526.8 6689483.6 39.2, 354515.7 6689481.1 39.2, 354514.2 6689487.2 39.2))
BATIMENT0000000302928547;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1841-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.8;29.0;37.8;39.9;30.0;Cadastre;B 0.9;POLYGON Z ((354483 6689496.4 37.8, 354491.9 6689498.4 37.8, 354492.7 6689494.7 37.8, 354494.2 6689495 37.8, 354494.9 6689494.3 37.8, 354495.4 6689492.4 37.8, 354494.8 6689491.7 37.8, 354493.4 6689491.4 37.8, 354494.7 6689485.9 37.8, 354485.7 6689483.9 37.8, 354483 6689496.4 37.8))
BATIMENT0000000302928550;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;56;20;6.2;29.8;36.0;40.1;30.5;Cadastre;A 1.0;POLYGON Z ((354514.2 6689487.2 36, 354512.4 6689493.1 36, 354515.1 6689493.8 36, 354523.6 6689495.9 36, 354525.2 6689490 36, 354516.8 6689487.8 36, 354514.2 6689487.2 36))
BATIMENT0000000302928553;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1841-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;04;6.8;29.9;36.7;38.0;30.6;Cadastre;B 0.3;POLYGON Z ((354515.1 6689493.8 36.7, 354514.3 6689496.6 36.7, 354517.1 6689497.4 36.7, 354522.7 6689498.8 36.7, 354523.6 6689495.9 36.7, 354515.1 6689493.8 36.7))
BATIMENT0000000302928554;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;6.8;29.9;36.7;40.9;30.6;Cadastre;A 1.0;POLYGON Z ((354506.1 6689501.8 36.7, 354509.3 6689502.7 36.7, 354517.3 6689504.8 36.7, 354518.5 6689500.7 36.7, 354516.3 6689500 36.7, 354517.1 6689497.4 36.7, 354514.3 6689496.6 36.7, 354507.9 6689494.9 36.7, 354506.1 6689501.8 36.7))
BATIMENT0000000302928548;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.1;29.0;38.1;40.8;29.8;Cadastre;A 1.0;POLYGON Z ((354481.1 6689504.9 38.1, 354490.5 6689507 38.1, 354494.6 6689507.8 38.1, 354496.2 6689501.3 38.1, 354491.4 6689500.2 38.1, 354491.9 6689498.4 38.1, 354483 6689496.4 38.1, 354481.1 6689504.9 38.1))
BATIMENT0000000302928557;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;10.5;28.5;39.0;42.0;30.5;Cadastre;A 1.0;POLYGON Z ((354506.9 6689510.9 39, 354512.4 6689512.4 39, 354515 6689513 39, 354517.3 6689504.8 39, 354509.3 6689502.7 39, 354506.9 6689510.9 39))
BATIMENT0000000302929178;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;29.8;37.7;46.2;30.9;Cadastre;;POLYGON Z ((354524.4 6689546.3 37.7, 354529.1 6689547.6 37.7, 354531.4 6689539.7 37.7, 354538.6 6689541.5 37.7, 354541.4 6689536.3 37.7, 354540 6689536 37.7, 354540.7 6689533.6 37.7, 354536.2 6689532.2 37.7, 354543.7 6689505.6 37.7, 354548.3 6689507 37.7, 354550.6 6689498.5 37.7, 354546.2 6689497 37.7, 354551.8 6689476.9 37.7, 354549.4 6689473.8 37.7, 354547.5 6689471.6 37.7, 354541.2 6689469.8 37.7, 354534.5 6689493.9 37.7, 354536.7 6689494.2 37.7, 354525 6689536.6 37.7, 354522.6 6689535.9 37.7, 354520 6689545.4 37.7, 354524.4 6689546.3 37.7))
BATIMENT0000000302928558;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;30.0;33.5;38.5;30.5;Cadastre;;POLYGON Z ((354511.2 6689516.3 33.5, 354517.5 6689517.9 33.5, 354518.6 6689514 33.5, 354515 6689513 33.5, 354512.4 6689512.4 33.5, 354511.2 6689516.3 33.5))
BATIMENT0000000302928549;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;4.0;00;00;11.9;29.0;40.9;44.0;30.4;Cadastre;A 1.0;POLYGON Z ((354477.1 6689522.9 40.9, 354490.3 6689526 40.9, 354493.2 6689519 40.9, 354488 6689518 40.9, 354490.5 6689507 40.9, 354481.1 6689504.9 40.9, 354477.1 6689522.9 40.9))
BATIMENT0000000302928484;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;28.0;31.3;31.4;28.5;Cadastre;;POLYGON Z ((354428.3 6689454.2 31.3, 354428.2 6689454.3 31.3, 354436.1 6689456.2 31.3, 354437.4 6689450.9 31.3, 354433.5 6689450 31.3, 354429.5 6689449 31.3, 354428.3 6689454.2 31.3))
BATIMENT0000000302928475;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;26.2;28.5;31.2;26.6;Cadastre;;POLYGON Z ((354410.8 6689455.9 28.5, 354414 6689456.7 28.5, 354414.7 6689453.8 28.5, 354411.5 6689453.1 28.5, 354410.8 6689455.9 28.5))
BATIMENT0000000302928477;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;27.3;34.2;38.0;28.5;Cadastre;;POLYGON Z ((354424.4 6689482.8 34.2, 354425.5 6689478.4 34.2, 354422.6 6689477.8 34.2, 354421.5 6689482.2 34.2, 354424.4 6689482.8 34.2))
BATIMENT0000000302928476;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.0;26.1;40.1;42.8;29.7;Cadastre;A 1.0;POLYGON Z ((354388.7 6689489.5 40.1, 354407.3 6689494.4 40.1, 354407 6689495.4 40.1, 354411.5 6689496.4 40.1, 354413.4 6689490.2 40.1, 354419.2 6689491.5 40.1, 354419.4 6689490.9 40.1, 354420.3 6689487.1 40.1, 354421.5 6689482.2 40.1, 354422.6 6689477.8 40.1, 354405 6689473.7 40.1, 354392.6 6689470.9 40.1, 354388.7 6689489.5 40.1))
BATIMENT0000000302928478;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;28.6;34.7;46.0;29.8;Cadastre;;POLYGON Z ((354461.2 6689500.9 34.7, 354467.6 6689473.1 34.7, 354463.9 6689472.2 34.7, 354463.2 6689472.1 34.7, 354457.7 6689496.3 34.7, 354420.3 6689487.1 34.7, 354419.4 6689490.9 34.7, 354445.6 6689497.2 34.7, 354456.9 6689500 34.7, 354461.2 6689500.9 34.7))
BATIMENT0000000302929193;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;21.0;26.1;47.1;51.7;30.1;Cadastre;;POLYGON Z ((354409.1 6689547.4 47.1, 354409.2 6689547.8 47.1, 354415.3 6689550.6 47.1, 354423.8 6689554.1 47.1, 354430 6689556.9 47.1, 354430 6689556.6 47.1, 354443.5 6689562.4 47.1, 354446.7 6689560.9 47.1, 354447.4 6689561.8 47.1, 354456.3 6689557.4 47.1, 354456 6689556.1 47.1, 354459.8 6689554.4 47.1, 354480.6 6689460.8 47.1, 354467.6 6689457.8 47.1, 354455.8 6689455.1 47.1, 354455 6689458.3 47.1, 354464.9 6689460.4 47.1, 354465 6689459.6 47.1, 354467 6689460 47.1, 354463.9 6689472.2 47.1, 354467.6 6689473.1 47.1, 354461.2 6689500.9 47.1, 354456.7 6689521 47.1, 354450.5 6689547.7 47.1, 354443 6689551.3 47.1, 354433 6689547 47.1, 354433.5 6689544.2 47.1, 354434.8 6689544.5 47.1, 354436.2 6689538.3 47.1, 354432 6689537.3 47.1, 354432.5 6689534.8 47.1, 354427.5 6689533.7 47.1, 354427.2 6689535 47.1, 354423.8 6689534.3 47.1, 354414.4 6689531.7 47.1, 354412.9 6689538.2 47.1, 354407.1 6689535.7 47.1, 354393.8 6689529.7 47.1, 354392 6689525.3 47.1, 354398.1 6689496.2 47.1, 354401.2 6689494.2 47.1, 354388.3 6689491.6 47.1, 354380 6689532.2 47.1, 354381.9 6689535.9 47.1, 354409.1 6689547.4 47.1))
BATIMENT0000000302929192;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:17:27;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.8;28.7;38.5;42.7;30.2;Cadastre;;POLYGON Z ((354407.1 6689535.7 38.5, 354408 6689533.6 38.5, 354401.1 6689530.3 38.5, 354401.9 6689527.9 38.5, 354400.6 6689526.7 38.5, 354399.9 6689525.5 38.5, 354399.7 6689524.9 38.5, 354400 6689522 38.5, 354401.3 6689521.5 38.5, 354402.3 6689517.1 38.5, 354401 6689515.8 38.5, 354401.4 6689513.7 38.5, 354403.2 6689513.3 38.5, 354404.2 6689509 38.5, 354404 6689508.8 38.5, 354403.8 6689508.6 38.5, 354403.5 6689508.4 38.5, 354403.1 6689508.3 38.5, 354402.8 6689508.4 38.5, 354403 6689505.2 38.5, 354403.3 6689504.1 38.5, 354403.7 6689503.4 38.5, 354404.3 6689502.7 38.5, 354405.3 6689502 38.5, 354405.9 6689501.8 38.5, 354406.8 6689501.7 38.5, 354407.7 6689501.7 38.5, 354411.2 6689502.7 38.5, 354412.4 6689503.5 38.5, 354413.2 6689504.4 38.5, 354413.3 6689504.6 38.5, 354413.5 6689505.4 38.5, 354413.6 6689506 38.5, 354413.7 6689506.6 38.5, 354413.7 6689507.3 38.5, 354412.7 6689511.3 38.5, 354413 6689511.4 38.5, 354413.1 6689510.8 38.5, 354418.8 6689512.2 38.5, 354414.4 6689531.7 38.5, 354423.8 6689534.3 38.5, 354428.2 6689514.5 38.5, 354456.7 6689521 38.5, 354461.2 6689500.9 38.5, 354456.9 6689500 38.5, 354445.6 6689497.2 38.5, 354419.4 6689490.9 38.5, 354419.2 6689491.5 38.5, 354413.4 6689490.2 38.5, 354411.5 6689496.4 38.5, 354407 6689495.4 38.5, 354401.2 6689494.2 38.5, 354398.1 6689496.2 38.5, 354392 6689525.3 38.5, 354393.8 6689529.7 38.5, 354407.1 6689535.7 38.5))
BATIMENT0000000302928850;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.8;31.0;32.8;;;Cadastre;;POLYGON Z ((354476.1 6689561.6 32.8, 354469.4 6689559.9 32.8, 354468.2 6689564 32.8, 354474.4 6689565.7 32.8, 354476.1 6689561.6 32.8))
BATIMENT0000000302928851;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;5.8;31.0;36.8;;;Cadastre;A 1.0;POLYGON Z ((354467.2 6689568.1 36.8, 354464.4 6689574.2 36.8, 354469.8 6689576.7 36.8, 354472.5 6689570.3 36.8, 354467.2 6689568.1 36.8))
BATIMENT0000000302928839;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;30.9;33.4;;;Cadastre;;POLYGON Z ((354438.7 6689572 33.4, 354435.7 6689570.8 33.4, 354433.8 6689574.6 33.4, 354436.7 6689576.1 33.4, 354438.7 6689572 33.4))
BATIMENT0000000302928593;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;20;20;5.5;25.0;30.5;42.9;27.8;Cadastre;A 1.0;POLYGON Z ((354338.4 6689502.2 30.5, 354337 6689507.4 30.5, 354339.9 6689508.3 30.5, 354339.8 6689509 30.5, 354344.3 6689510.3 30.5, 354343.9 6689511.9 30.5, 354346.6 6689512.7 30.5, 354346.2 6689513.7 30.5, 354349.4 6689514.8 30.5, 354349.8 6689513.6 30.5, 354353.4 6689500.3 30.5, 354357 6689487.8 30.5, 354343.8 6689484.5 30.5, 354338.4 6689502.2 30.5))
BATIMENT0000000302928595;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;30;40;14.4;27.1;41.5;42.4;27.8;Cadastre;A 1.0;POLYGON Z ((354349.8 6689513.6 41.5, 354360.9 6689516.4 41.5, 354360.6 6689518.1 41.5, 354361.9 6689518.4 41.5, 354361.2 6689521.6 41.5, 354364.7 6689523.9 41.5, 354367.4 6689524.4 41.5, 354371.8 6689522.2 41.5, 354376.5 6689499 41.5, 354371.3 6689497.8 41.5, 354370.6 6689500.5 41.5, 354368.1 6689500 41.5, 354367.8 6689501.5 41.5, 354359.6 6689499.3 41.5, 354359.2 6689501.7 41.5, 354353.4 6689500.3 41.5, 354349.8 6689513.6 41.5))
BATIMENT0000000029199446;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.1;28.2;;40.0;29.1;Imagerie aérienne;;POLYGON Z ((354358.7 6689538.2 32.3, 354352.1 6689548.9 32.2, 354358.8 6689552.1 32.2, 354364.2 6689541.3 32.2, 354358.7 6689538.2 32.3))
BATIMENT0000000302928586;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.9;28.2;38.2;41.7;29.9;Cadastre;;POLYGON Z ((354353.6 6689554.7 38.2, 354363.6 6689561 38.2, 354364.5 6689558.8 38.2, 354353.6 6689554.7 38.2))
BATIMENT0000000302928616;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.7;31.0;47.7;;;Cadastre;;POLYGON Z ((354378.9 6689552.2 47.7, 354378.3 6689553.4 47.7, 354387.7 6689557.4 47.7, 354387.6 6689558.1 47.7, 354393.6 6689559.7 47.7, 354393.3 6689560.5 47.7, 354399.2 6689561.9 47.7, 354398.9 6689563 47.7, 354405 6689564.3 47.7, 354404.8 6689565.5 47.7, 354409.8 6689566.6 47.7, 354410 6689565.8 47.7, 354378.9 6689552.2 47.7))
BATIMENT0000000302928615;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;7.0;00;00;16.9;29.1;46.1;51.0;30.1;Cadastre;C 0.6;POLYGON Z ((354404.8 6689565.5 46.1, 354405 6689564.3 46.1, 354398.9 6689563 46.1, 354399.2 6689561.9 46.1, 354393.3 6689560.5 46.1, 354393.6 6689559.7 46.1, 354387.6 6689558.1 46.1, 354387.7 6689557.4 46.1, 354378.3 6689553.4 46.1, 354375.9 6689558.7 46.1, 354376.8 6689559.2 46.1, 354375.1 6689565.3 46.1, 354378.5 6689566.1 46.1, 354377.5 6689570 46.1, 354381.2 6689571.1 46.1, 354380.2 6689573.8 46.1, 354388.9 6689576 46.1, 354390.3 6689570.3 46.1, 354402.2 6689573.7 46.1, 354400.5 6689579.2 46.1, 354405.8 6689580.7 46.1, 354408 6689572.7 46.1, 354409.8 6689566.6 46.1, 354404.8 6689565.5 46.1))
BATIMENT0000000302928585;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;00;00;17.1;27.6;44.7;51.7;29.9;Cadastre;C 0.1;POLYGON Z ((354347.8 6689566.2 44.7, 354344.7 6689571.1 44.7, 354345.7 6689571.8 44.7, 354344 6689576 44.7, 354341.3 6689574.7 44.7, 354335.8 6689588.6 44.7, 354349.9 6689594.5 44.7, 354351.1 6689591.6 44.7, 354350.2 6689591.1 44.7, 354350.9 6689589.3 44.7, 354351.8 6689589.7 44.7, 354355.5 6689580.8 44.7, 354354.2 6689580.2 44.7, 354355.2 6689577.8 44.7, 354356.2 6689578.6 44.7, 354363.6 6689561 44.7, 354353.6 6689554.7 44.7, 354348.7 6689551.8 44.7, 354345.5 6689557.1 44.7, 354342.4 6689562 44.7, 354342 6689562.5 44.7, 354347.8 6689566.2 44.7))
BATIMENT0000000302928614;Chapelle;Religieux;;Non;En service;2012-06-19 19:00:51;2012-10-24 11:05:28;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.1;30.5;45.6;;;Cadastre;;POLYGON Z ((354378.9 6689576.6 45.6, 354378 6689579.7 45.6, 354373.5 6689578.3 45.6, 354373.2 6689579.2 45.6, 354371.7 6689578.7 45.6, 354369.4 6689579.8 45.6, 354368.8 6689582.8 45.6, 354370.1 6689584.7 45.6, 354371.7 6689585.2 45.6, 354371.5 6689586 45.6, 354376.4 6689587.6 45.6, 354375.4 6689590.8 45.6, 354384.2 6689593.2 45.6, 354397.1 6689596.9 45.6, 354401.1 6689598 45.6, 354401.2 6689597.5 45.6, 354400.7 6689597.4 45.6, 354401.4 6689594.9 45.6, 354401.9 6689594.9 45.6, 354402.1 6689594.1 45.6, 354401.6 6689594 45.6, 354402 6689592.3 45.6, 354402.6 6689592.4 45.6, 354402.9 6689591.7 45.6, 354402.2 6689591.5 45.6, 354402.7 6689590 45.6, 354403.2 6689590.1 45.6, 354403.4 6689589.3 45.6, 354402.8 6689589.2 45.6, 354403.3 6689587.3 45.6, 354403.9 6689587.5 45.6, 354404.2 6689586.7 45.6, 354403.5 6689586.6 45.6, 354404.2 6689584.3 45.6, 354404.9 6689584.3 45.6, 354405.1 6689583.7 45.6, 354404.3 6689583.5 45.6, 354378.9 6689576.6 45.6))
BATIMENT0000000302928613;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;31.0;45.4;;;Cadastre;;POLYGON Z ((354376.3 6689600 45.4, 354375.7 6689601.2 45.4, 354381.5 6689603 45.4, 354381.9 6689601.6 45.4, 354376.3 6689600 45.4))
BATIMENT0000000302928612;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;6.0;00;00;14.6;31.0;45.6;;;Cadastre;C 0.4;POLYGON Z ((354396 6689616.9 45.6, 354396.1 6689616.3 45.6, 354394.3 6689615.6 45.6, 354395.9 6689609.9 45.6, 354397.7 6689610.6 45.6, 354400.5 6689600.3 45.6, 354396.4 6689599.2 45.6, 354397.1 6689596.9 45.6, 354384.2 6689593.2 45.6, 354381.9 6689601.6 45.6, 354381.5 6689603 45.6, 354375.7 6689601.2 45.6, 354376.3 6689600 45.6, 354377 6689598.3 45.6, 354375.2 6689597.4 45.6, 354374.8 6689598.1 45.6, 354363.5 6689593.3 45.6, 354360 6689602.1 45.6, 354381.1 6689611 45.6, 354396 6689616.9 45.6))
BATIMENT0000000302928551;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;25;20;8.8;30.7;39.5;;;Cadastre;A 1.0;POLYGON Z ((354501.2 6689517.7 39.5, 354499.9 6689521.8 39.5, 354494.7 6689520.5 39.5, 354492.2 6689528.4 39.5, 354489.6 6689527.8 39.5, 354487.1 6689534 39.5, 354500.4 6689537.5 39.5, 354504.4 6689523.2 39.5, 354504.1 6689523 39.5, 354505.4 6689518.6 39.5, 354501.2 6689517.5 39.5, 354501.2 6689517.7 39.5))
BATIMENT0000000302928552;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;23;10.4;29.0;39.4;42.0;30.4;Cadastre;A 1.0;POLYGON Z ((354475.3 6689532.3 39.4, 354484.5 6689534.4 39.4, 354484.1 6689535.9 39.4, 354483.6 6689538.1 39.4, 354485.3 6689538.4 39.4, 354487.1 6689534 39.4, 354489.6 6689527.8 39.4, 354490.3 6689526 39.4, 354477.1 6689522.9 39.4, 354475.3 6689532.3 39.4))
BATIMENT0000000302928555;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;20;8.7;29.6;38.4;39.8;30.3;Cadastre;A 1.0;POLYGON Z ((354473.5 6689540.1 38.4, 354480.9 6689541.9 38.4, 354482 6689537 38.4, 354474.6 6689535.4 38.4, 354473.5 6689540.1 38.4))
BATIMENT0000000302929243;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;30.0;36.2;43.7;31.1;Cadastre;;POLYGON Z ((354541.5 6689545.3 36.2, 354545.7 6689541.8 36.2, 354541.4 6689536.3 36.2, 354538.6 6689541.5 36.2, 354541.5 6689545.3 36.2))
BATIMENT0000000302928556;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;9.3;29.7;39.1;42.4;30.5;Cadastre;A 1.0;POLYGON Z ((354471.3 6689550.2 39.1, 354479.4 6689552.4 39.1, 354480.7 6689549.5 39.1, 354478.6 6689548.9 39.1, 354479.3 6689546.2 39.1, 354481.8 6689546.9 39.1, 354483.6 6689542.4 39.1, 354480.9 6689541.9 39.1, 354473.5 6689540.1 39.1, 354471.3 6689550.2 39.1))
BATIMENT0000000302928559;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;24;20;11.7;29.8;41.5;47.0;30.7;Cadastre;A 1.0;POLYGON Z ((354470.1 6689556.3 41.5, 354477.2 6689558 41.5, 354479.4 6689552.4 41.5, 354471.3 6689550.2 41.5, 354470.1 6689556.3 41.5))
BATIMENT0000000302928849;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;20;20;8.8;31.0;39.8;;;Cadastre;C 0.6;POLYGON Z ((354474.4 6689565.7 39.8, 354472.5 6689570.3 39.8, 354469.8 6689576.7 39.8, 354478.9 6689580.4 39.8, 354479.6 6689579 39.8, 354475.9 6689577.5 39.8, 354477.7 6689573.4 39.8, 354475.3 6689572.4 39.8, 354475.8 6689571.2 39.8, 354499.9 6689581.7 39.8, 354502.5 6689572.2 39.8, 354489.8 6689566.7 39.8, 354479.7 6689562.2 39.8, 354479.3 6689563 39.8, 354476.1 6689561.6 39.8, 354474.4 6689565.7 39.8))
BATIMENT0000000302928852;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;10;5.7;30.5;36.2;38.0;31.0;Cadastre;C 0.1;POLYGON Z ((354491.8 6689586.1 36.2, 354496.1 6689587.9 36.2, 354498.5 6689586.6 36.2, 354499.5 6689583 36.2, 354494.1 6689580.8 36.2, 354491.8 6689586.1 36.2))
BATIMENT0000000302927925;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;7.0;00;00;17.5;31.2;48.7;57.6;31.8;Cadastre;C 0.7;POLYGON Z ((354530.9 6689574.6 48.7, 354534.3 6689578.4 48.7, 354535.2 6689577.7 48.7, 354540.5 6689584.3 48.7, 354530.4 6689592.7 48.7, 354525.1 6689586.3 48.7, 354525.8 6689585.6 48.7, 354522.5 6689581.5 48.7, 354512.3 6689590.3 48.7, 354517.1 6689593 48.7, 354514.3 6689595.7 48.7, 354532.8 6689603.8 48.7, 354551.1 6689588.3 48.7, 354539.1 6689573.8 48.7, 354535.9 6689570.2 48.7, 354530.9 6689574.6 48.7))
BATIMENT0000000302929134;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;1.9;30.8;32.8;34.6;31.6;Cadastre;C 0.1;POLYGON Z ((354505.6 6689587.3 32.8, 354505.4 6689587.4 32.8, 354505.2 6689587.4 32.8, 354504.8 6689587.6 32.8, 354504.7 6689587.7 32.8, 354504.3 6689588 32.8, 354504.2 6689588.1 32.8, 354504.1 6689588.3 32.8, 354503.9 6689588.7 32.8, 354503.8 6689588.9 32.8, 354503.7 6689589.1 32.8, 354503.7 6689589.3 32.8, 354503.7 6689589.5 32.8, 354503.7 6689589.7 32.8, 354503.7 6689589.9 32.8, 354503.7 6689590.1 32.8, 354503.8 6689590.3 32.8, 354503.8 6689590.5 32.8, 354504 6689590.9 32.8, 354504.2 6689591.1 32.8, 354504.3 6689591.3 32.8, 354504.5 6689591.4 32.8, 354504.6 6689591.5 32.8, 354504.8 6689591.6 32.8, 354505.1 6689591.8 32.8, 354505.3 6689591.8 32.8, 354505.5 6689591.9 32.8, 354505.6 6689591.9 32.8, 354505.8 6689592 32.8, 354506 6689592 32.8, 354506.2 6689592 32.8, 354506.6 6689591.9 32.8, 354507 6689591.8 32.8, 354507.1 6689591.7 32.8, 354507.3 6689591.6 32.8, 354507.4 6689591.5 32.8, 354507.6 6689591.3 32.8, 354507.7 6689591.2 32.8, 354507.9 6689590.9 32.8, 354508 6689590.8 32.8, 354508.1 6689590.6 32.8, 354508.2 6689590.2 32.8, 354508.3 6689590.1 32.8, 354508.3 6689589.9 32.8, 354508.3 6689589.7 32.8, 354508.3 6689589.5 32.8, 354508.3 6689589.1 32.8, 354508.2 6689588.9 32.8, 354508.1 6689588.8 32.8, 354508.1 6689588.6 32.8, 354507.9 6689588.2 32.8, 354507.6 6689588 32.8, 354507.3 6689587.7 32.8, 354507 6689587.5 32.8, 354506.8 6689587.4 32.8, 354506.6 6689587.4 32.8, 354506.4 6689587.3 32.8, 354506.2 6689587.3 32.8, 354506 6689587.3 32.8, 354505.6 6689587.3 32.8))
BATIMENT0000000302928837;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;20;23;2.8;30.9;33.7;;;Cadastre;A 1.0;POLYGON Z ((354436.7 6689576.1 33.7, 354433.8 6689574.6 33.7, 354435.7 6689570.8 33.7, 354424.6 6689565.8 33.7, 354418.9 6689569.9 33.7, 354418.5 6689571.3 33.7, 354428.8 6689583.3 33.7, 354430.2 6689584.7 33.7, 354434.1 6689581.7 33.7, 354436.7 6689576.1 33.7))
BATIMENT0000000302928836;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;5.7;29.9;35.7;40.5;30.8;Cadastre;A 1.0;POLYGON Z ((354441.5 6689590.8 35.7, 354443.1 6689589.7 35.7, 354449.8 6689583.9 35.7, 354452.6 6689578.2 35.7, 354441.6 6689573.3 35.7, 354440.6 6689575.8 35.7, 354439 6689579.3 35.7, 354442.7 6689581.2 35.7, 354441.2 6689585.3 35.7, 354438.8 6689587.5 35.7, 354434.1 6689581.7 35.7, 354430.2 6689584.7 35.7, 354437.2 6689593.2 35.7, 354437.8 6689594 35.7, 354441.5 6689590.8 35.7))
BATIMENT0000000302928834;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.9;31.0;37.9;;;Cadastre;B 1.0;POLYGON Z ((354452.6 6689587.9 37.9, 354455.8 6689589.3 37.9, 354460.3 6689591.5 37.9, 354464.1 6689583.2 37.9, 354452.6 6689578.2 37.9, 354449.8 6689583.9 37.9, 354452.6 6689587.9 37.9))
BATIMENT0000000302928835;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;30.5;36.5;38.2;30.6;Cadastre;;POLYGON Z ((354454.8 6689592 36.5, 354455.1 6689593.6 36.5, 354457.7 6689594.7 36.5, 354459.1 6689593.9 36.5, 354460.3 6689591.5 36.5, 354455.8 6689589.3 36.5, 354454.8 6689592 36.5))
BATIMENT0000000302928838;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;15;20;11.5;29.7;41.2;45.6;30.7;Cadastre;A 1.0;POLYGON Z ((354426.6 6689585.7 41.2, 354426.3 6689585.4 41.2, 354422.4 6689588.8 41.2, 354420.6 6689586.8 41.2, 354417 6689589.8 41.2, 354418.7 6689591.9 41.2, 354414.4 6689595.8 41.2, 354414.8 6689596.4 41.2, 354412.4 6689598.6 41.2, 354420.3 6689607.9 41.2, 354423.7 6689605 41.2, 354424.5 6689605.7 41.2, 354428.3 6689602.4 41.2, 354429.8 6689604.2 41.2, 354432.4 6689601.8 41.2, 354431 6689600.4 41.2, 354434.7 6689597 41.2, 354434.1 6689596.2 41.2, 354437.2 6689593.2 41.2, 354430.2 6689584.7 41.2, 354428.8 6689583.3 41.2, 354426.6 6689585.7 41.2))
BATIMENT0000000302928617;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.8;31.0;35.8;;;Cadastre;B 0.3;POLYGON Z ((354463.1 6689594.2 35.8, 354462.5 6689600.6 35.8, 354465.2 6689603.6 35.8, 354471.2 6689598.8 35.8, 354465.4 6689592 35.8, 354463.1 6689594.2 35.8))
BATIMENT0000000302928840;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;13;90;6.2;30.9;37.1;43.0;30.9;Cadastre;A 1.0;POLYGON Z ((354411.5 6689597.5 37.1, 354408.7 6689607.8 37.1, 354414.2 6689609.9 37.1, 354419.4 6689616.2 37.1, 354412.4 6689622.7 37.1, 354418 6689624.8 37.1, 354423.4 6689620.2 37.1, 354427.6 6689616.4 37.1, 354420.3 6689607.9 37.1, 354412.4 6689598.6 37.1, 354411.5 6689597.5 37.1))
BATIMENT0000000302928842;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;30.5;36.0;36.6;31.1;Cadastre;;POLYGON Z ((354425.2 6689622.1 36, 354429.2 6689618.6 36, 354427.6 6689616.4 36, 354423.4 6689620.2 36, 354425.2 6689622.1 36))
BATIMENT0000000302928841;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.1;30.3;34.5;40.5;31.0;Cadastre;A 1.0;POLYGON Z ((354411.2 6689622.3 34.5, 354405.2 6689620.1 34.5, 354404.4 6689623.4 34.5, 354410.4 6689624.9 34.5, 354411.2 6689622.3 34.5))
BATIMENT0000000302928974;Indifférenciée;Annexe;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.8;31.3;37.1;40.0;31.6;Cadastre;C 0.2;POLYGON Z ((354456.8 6689618.4 37.1, 354452.7 6689613.5 37.1, 354435.3 6689627.7 37.1, 354436.3 6689629.1 37.1, 354439.1 6689632.5 37.1, 354442.1 6689635.7 37.1, 354459.1 6689621.2 37.1, 354456.8 6689618.4 37.1))
BATIMENT0000000302928566;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;29.6;44.0;45.2;30.1;Cadastre;;POLYGON Z ((354350.9 6689610 44, 354350 6689612.2 44, 354358.3 6689615.6 44, 354359.2 6689613.5 44, 354350.9 6689610 44))
BATIMENT0000000302928611;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.7;31.0;46.7;;;Cadastre;;POLYGON Z ((354394.3 6689615.6 46.7, 354396.1 6689616.3 46.7, 354397.7 6689610.6 46.7, 354395.9 6689609.9 46.7, 354394.3 6689615.6 46.7))
BATIMENT0000000302928561;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;40.0;6.0;00;00;17.5;29.1;46.6;49.6;30.2;Cadastre;C 0.6;POLYGON Z ((354325.3 6689616.3 46.6, 354328.1 6689617.5 46.6, 354339.1 6689622.1 46.6, 354341.9 6689623.3 46.6, 354347.4 6689625.6 46.6, 354352.9 6689627.9 46.6, 354354.4 6689624.4 46.6, 354361.4 6689627.3 46.6, 354364.5 6689616 46.6, 354364.5 6689615.8 46.6, 354359.2 6689613.5 46.6, 354358.3 6689615.6 46.6, 354350 6689612.2 46.6, 354347.1 6689610.9 46.6, 354344.7 6689616.5 46.6, 354342.2 6689615.4 46.6, 354345.5 6689607.8 46.6, 354342.4 6689606.5 46.6, 354341.5 6689608.6 46.6, 354339 6689607.6 46.6, 354325 6689601.7 46.6, 354323.5 6689605.1 46.6, 354319.8 6689614 46.6, 354325.3 6689616.3 46.6))
BATIMENT0000000302928563;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.5;29.6;46.2;46.7;29.8;Cadastre;;POLYGON Z ((354341 6689625.4 46.2, 354346.5 6689627.7 46.2, 354347.4 6689625.6 46.2, 354341.9 6689623.3 46.2, 354341 6689625.4 46.2))
BATIMENT0000000302928562;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;30;40;4.8;29.9;34.7;52.9;30.5;Cadastre;A 1.0;POLYGON Z ((354363.4 6689637.9 34.7, 354366.3 6689627.7 34.7, 354365.3 6689627.3 34.7, 354365.7 6689626.1 34.7, 354375.5 6689630.2 34.7, 354377.9 6689621.8 34.7, 354364.5 6689616 34.7, 354361.4 6689627.3 34.7, 354359.9 6689632.7 34.7, 354357.4 6689641.9 34.7, 354368.2 6689644.8 34.7, 354369.6 6689639.5 34.7, 354363.4 6689637.9 34.7))
BATIMENT0000000302928568;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;6.0;30;40;18.5;31.0;49.5;;;Cadastre;B 0.5;POLYGON Z ((354387.8 6689650 49.5, 354393.6 6689628.5 49.5, 354377.9 6689621.8 49.5, 354375.5 6689630.2 49.5, 354378.3 6689631.4 49.5, 354381.9 6689638.1 49.5, 354379.4 6689647.9 49.5, 354387.8 6689650 49.5))
BATIMENT0000000302928569;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;30.0;33.7;43.4;30.3;Cadastre;;POLYGON Z ((354378.9 6689642.1 33.7, 354372.7 6689640.4 33.7, 354369.6 6689639.5 33.7, 354368.2 6689644.8 33.7, 354376.6 6689647.1 33.7, 354377.4 6689647.3 33.7, 354378.9 6689642.1 33.7))
BATIMENT0000000302929129;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.3;29.7;31.1;31.2;30.1;Cadastre;;POLYGON Z ((354344.6 6689647.1 31.1, 354345 6689646.1 31.1, 354339.3 6689643.7 31.1, 354338.9 6689644.6 31.1, 354344.6 6689647.1 31.1))
BATIMENT0000000302929126;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.6;29.8;36.5;40.0;30.2;Cadastre;;POLYGON Z ((354353.8 6689651 36.5, 354357.7 6689652.3 36.5, 354359.4 6689647.1 36.5, 354359.6 6689646.5 36.5, 354355.4 6689645.5 36.5, 354353.8 6689651 36.5))
BATIMENT0000000302928571;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;15;10;8.7;31.0;39.7;;;Cadastre;C 0.6;POLYGON Z ((354373.3 6689659.3 39.7, 354384.5 6689662.8 39.7, 354385 6689660.3 39.7, 354387.8 6689650 39.7, 354379.4 6689647.9 39.7, 354377.4 6689647.3 39.7, 354376.6 6689647.1 39.7, 354373.3 6689659.3 39.7))
BATIMENT0000000302928618;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;30;20;5.8;31.0;36.8;37.1;31.6;Cadastre;C 0.9;POLYGON Z ((354478.3 6689607.3 36.8, 354484.6 6689593.5 36.8, 354471.5 6689587.7 36.8, 354470.7 6689589.8 36.8, 354466.4 6689591 36.8, 354465.4 6689592 36.8, 354471.2 6689598.8 36.8, 354478.3 6689607.3 36.8))
BATIMENT0000000029198813;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;5.9;31.0;;51.0;31.4;Imagerie aérienne;;POLYGON Z ((354507.5 6689603.6 36.8, 354503 6689601.3 36.8, 354485.4 6689616.3 36.9, 354487.1 6689618.7 36.8, 354488.7 6689617.2 36.8, 354503 6689605.3 36.8, 354505.2 6689607.6 36.8, 354509.1 6689604.4 36.8, 354507.5 6689603.6 36.8))
BATIMENT0000000302928152;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;8.0;00;00;9.5;31.4;41.0;57.0;31.7;Cadastre;A 1.0;POLYGON Z ((354521.9 6689646.7 41, 354529.9 6689656.2 41, 354531.1 6689657.6 41, 354540.2 6689660.7 41, 354549.9 6689652.4 41, 354535.7 6689634.9 41, 354521.9 6689646.7 41))
BATIMENT0000000302928149;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;20.7;31.0;51.7;54.0;32.1;Cadastre;A 1.0;POLYGON Z ((354506.7 6689659.5 51.7, 354515.2 6689669.3 51.7, 354521.8 6689663.5 51.7, 354523.1 6689662.4 51.7, 354525.7 6689660.1 51.7, 354526.4 6689660.5 51.7, 354528.7 6689658.6 51.7, 354528.2 6689658 51.7, 354529.9 6689656.2 51.7, 354521.9 6689646.7 51.7, 354506.7 6689659.5 51.7))
BATIMENT0000000302928150;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;16;20;5.8;31.0;36.8;40.0;32.1;Cadastre;A 1.0;POLYGON Z ((354529.6 6689659.6 36.8, 354528.1 6689663.7 36.8, 354528.7 6689664 36.8, 354541.3 6689668.3 36.8, 354545 6689662.6 36.8, 354540.2 6689660.7 36.8, 354531.1 6689657.6 36.8, 354529.9 6689656.2 36.8, 354528.2 6689658 36.8, 354528.7 6689658.6 36.8, 354529.6 6689659.6 36.8))
BATIMENT0000000302928151;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;9.0;35;20;23.7;31.7;55.5;60.7;32.4;Cadastre;C 0.7;POLYGON Z ((354492 6689672 55.5, 354498.2 6689679.2 55.5, 354500.5 6689681.8 55.5, 354502.6 6689679.6 55.5, 354504.1 6689681 55.5, 354507.4 6689678.1 55.5, 354507.5 6689677.7 55.5, 354511.3 6689674.4 55.5, 354510.4 6689673.3 55.5, 354515.2 6689669.3 55.5, 354506.7 6689659.5 55.5, 354492 6689672 55.5))
BATIMENT0000000302929228;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;30.6;36.1;36.8;32.3;Cadastre;;POLYGON Z ((354535.8 6689684.8 36.1, 354538.5 6689682.6 36.1, 354542.8 6689687.4 36.1, 354548.7 6689683.3 36.1, 354535.5 6689677 36.1, 354533.6 6689676.4 36.1, 354530.5 6689678.8 36.1, 354535.8 6689684.8 36.1))
BATIMENT0000000302927943;Indifférenciée;Sportif;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.3;30.7;35.0;35.2;32.4;Cadastre;C 0.3;POLYGON Z ((354524.4 6689684.3 35, 354530.5 6689678.8 35, 354533.6 6689676.4 35, 354529.3 6689674.1 35, 354523.6 6689679.4 35, 354522.6 6689678.3 35, 354508.1 6689690.6 35, 354511.7 6689695 35, 354524.4 6689684.3 35))
BATIMENT0000000302927926;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;5.0;;;13.7;31.2;44.9;51.3;32.8;Cadastre;C 0.1;POLYGON Z ((354487.1 6689676.2 44.9, 354472.6 6689688.5 44.9, 354473.8 6689689.9 44.9, 354470.3 6689692.9 44.9, 354469.1 6689691.4 44.9, 354462.1 6689697.3 44.9, 354474.9 6689712.6 44.9, 354485.7 6689703.5 44.9, 354480.1 6689697 44.9, 354495.4 6689683.9 44.9, 354488.1 6689675.3 44.9, 354487.1 6689676.2 44.9))
BATIMENT0000000302927941;Indifférenciée;Sportif;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;30.7;37.0;37.9;32.1;Cadastre;;POLYGON Z ((354519.1 6689697.6 37, 354522.3 6689701.4 37, 354522.8 6689701 37, 354524.5 6689703 37, 354525 6689703.6 37, 354526.9 6689702 37, 354527.5 6689701.5 37, 354522 6689695.1 37, 354519.1 6689697.6 37))
BATIMENT0000000302928088;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.1;29.3;43.4;44.9;29.9;Cadastre;A 0.9;POLYGON Z ((354576.2 6689434.3 43.4, 354576.4 6689434.5 43.4, 354580.4 6689431.2 43.4, 354580.2 6689431 43.4, 354576.2 6689434.3 43.4))
BATIMENT0000000302928076;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;29.8;33.3;34.2;30.8;Cadastre;;POLYGON Z ((354601.5 6689435.4 33.3, 354603.2 6689438.5 33.3, 354612.1 6689433.8 33.3, 354610.6 6689430.8 33.3, 354601.5 6689435.4 33.3))
BATIMENT0000000302927921;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;10;20;17.1;30.0;47.1;;;Cadastre;A 1.0;POLYGON Z ((354556.2 6689425.9 47.1, 354553.3 6689426.3 47.1, 354549.4 6689440.2 47.1, 354558.6 6689442.7 47.1, 354562.1 6689443.6 47.1, 354567.3 6689439 47.1, 354556.2 6689425.9 47.1))
BATIMENT0000000302928087;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.2;29.3;40.5;44.5;30.3;Cadastre;A 0.9;POLYGON Z ((354596.7 6689442.7 40.5, 354596.4 6689442.6 40.5, 354595.4 6689443 40.5, 354590.9 6689437.1 40.5, 354597.4 6689431.7 40.5, 354591 6689424.2 40.5, 354587 6689426 40.5, 354585.8 6689426.8 40.5, 354582.8 6689429.3 40.5, 354580.4 6689431.2 40.5, 354576.4 6689434.5 40.5, 354589.4 6689449.9 40.5, 354597.2 6689443.4 40.5, 354596.7 6689442.7 40.5))
BATIMENT0000000302927918;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;10.0;29.9;39.9;44.2;30.6;Cadastre;A 1.0;POLYGON Z ((354567.3 6689439 39.9, 354562.1 6689443.6 39.9, 354558.6 6689442.7 39.9, 354549.4 6689440.2 39.9, 354546.4 6689451.2 39.9, 354543.9 6689460 39.9, 354549.4 6689461.6 39.9, 354551.8 6689452.7 39.9, 354553.4 6689447.4 39.9, 354557.3 6689447.4 39.9, 354558.9 6689447.3 39.9, 354559.7 6689446.5 39.9, 354562 6689449.3 39.9, 354561.5 6689450.4 39.9, 354573.6 6689465.4 39.9, 354574.8 6689465.6 39.9, 354583.5 6689458.2 39.9, 354567.3 6689439 39.9))
BATIMENT0000000302928095;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;00;00;17.3;29.9;47.2;51.4;31.3;Cadastre;A 1.0;POLYGON Z ((354601.7 6689464.7 47.2, 354606.7 6689461.6 47.2, 354608.6 6689461.1 47.2, 354612.2 6689460.3 47.2, 354613.1 6689459 47.2, 354615.6 6689456.9 47.2, 354601.6 6689439.9 47.2, 354597.2 6689443.4 47.2, 354589.4 6689449.9 47.2, 354601.7 6689464.7 47.2))
BATIMENT0000000302927916;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.1;29.8;39.9;43.5;31.3;Cadastre;A 1.0;POLYGON Z ((354574.3 6689466.1 39.9, 354581.5 6689474.3 39.9, 354589 6689468 39.9, 354590.7 6689466.6 39.9, 354583.5 6689458.2 39.9, 354574.8 6689465.6 39.9, 354574.3 6689466.1 39.9))
BATIMENT0000000302928097;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;14.1;30.1;44.2;46.1;31.3;Cadastre;C 0.7;POLYGON Z ((354615.3 6689480.9 44.2, 354623.5 6689473.8 44.2, 354612.2 6689460.3 44.2, 354608.6 6689461.1 44.2, 354606.7 6689461.6 44.2, 354601.7 6689464.7 44.2, 354615.3 6689480.9 44.2))
BATIMENT0000000302927917;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;6.0;00;00;17.1;29.9;47.0;51.5;31.6;Cadastre;A 1.0;POLYGON Z ((354576.8 6689478.5 47, 354599.7 6689505 47, 354602.7 6689502.5 47, 354611.8 6689494.8 47, 354589 6689468 47, 354581.5 6689474.3 47, 354576.8 6689478.5 47))
BATIMENT0000000302927919;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1974-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;41.0;9.0;30;20;19.4;30.4;49.9;57.4;32.0;Cadastre;A 0.4;POLYGON Z ((354599.2 6689533.3 49.9, 354606.3 6689541.9 49.9, 354632.4 6689519.2 49.9, 354611.8 6689494.8 49.9, 354602.7 6689502.5 49.9, 354614.9 6689516.6 49.9, 354611.9 6689519.3 49.9, 354611 6689518.6 49.9, 354598.2 6689529.7 49.9, 354598.7 6689530.8 49.9, 354597.7 6689531.4 49.9, 354599.2 6689533.3 49.9))
BATIMENT0000000302929177;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;23.3;29.8;53.2;57.2;30.7;Cadastre;C 0.5;POLYGON Z ((354694.1 6689467.4 53.2, 354684.8 6689456.3 53.2, 354661.9 6689475.2 53.2, 354671.3 6689486.6 53.2, 354694.1 6689467.4 53.2))
BATIMENT0000000302927745;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;15.7;30.2;46.0;51.2;30.9;Cadastre;C 1.0;POLYGON Z ((354658 6689476.3 46, 354660.1 6689478.7 46, 354660 6689480.3 46, 354658.2 6689481.8 46, 354652.5 6689475 46, 354649.6 6689477.5 46, 354653.5 6689482 46, 354654.9 6689481 46, 354656.7 6689483.1 46, 354652 6689487.1 46, 354650.6 6689486.8 46, 354648.5 6689484.3 46, 354646 6689486.5 46, 354656.6 6689499.1 46, 354671.3 6689486.6 46, 354661.9 6689475.2 46, 354660.9 6689474 46, 354658 6689476.3 46))
BATIMENT0000000302927754;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;;;13.2;30.0;43.2;48.3;31.0;Cadastre;A 1.0;POLYGON Z ((354642.4 6689482.3 43.2, 354639.3 6689484.9 43.2, 354643.8 6689489.9 43.2, 354643.8 6689491.1 43.2, 354636.3 6689497.4 43.2, 354635.3 6689496.9 43.2, 354631 6689491.9 43.2, 354632.4 6689490.7 43.2, 354625.2 6689482.7 43.2, 354625.7 6689482.1 43.2, 354623 6689478.8 43.2, 354617.5 6689483.2 43.2, 354641.5 6689512.1 43.2, 354656.6 6689499.1 43.2, 354646 6689486.5 43.2, 354642.4 6689482.3 43.2))
BATIMENT0000000302928297;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;13.3;30.1;43.4;48.2;30.8;Cadastre;A 1.0;POLYGON Z ((354689.3 6689505.6 43.4, 354698.4 6689516.5 43.4, 354700.4 6689514.8 43.4, 354699.7 6689513.9 43.4, 354708.8 6689506.1 43.4, 354714.9 6689513.5 43.4, 354718.7 6689510.3 43.4, 354704.4 6689492.8 43.4, 354689.3 6689505.6 43.4))
BATIMENT0000000302928299;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;15.4;30.2;45.7;48.6;31.5;Cadastre;A 1.0;POLYGON Z ((354658.2 6689531.8 45.7, 354677.2 6689554.2 45.7, 354684 6689548.3 45.7, 354676.5 6689539.7 45.7, 354675.2 6689540.7 45.7, 354672.4 6689537.4 45.7, 354674.8 6689535.4 45.7, 354675.9 6689536.7 45.7, 354699.1 6689517.4 45.7, 354698.4 6689516.5 45.7, 354689.3 6689505.6 45.7, 354658.2 6689531.8 45.7))
BATIMENT0000000302927850;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;2.6;30.4;33.1;57.4;31.5;Cadastre;C 0.6;POLYGON Z ((354667.8 6689561.4 33.1, 354658.4 6689549.9 33.1, 354649.2 6689539.2 33.1, 354636.8 6689549.7 33.1, 354655.4 6689571.8 33.1, 354667.8 6689561.4 33.1))
BATIMENT0000000302928300;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;5.0;00;00;16.5;30.0;46.5;50.6;30.8;Cadastre;A 1.0;POLYGON Z ((354698.9 6689579.7 46.5, 354708.1 6689571.8 46.5, 354709.3 6689570.6 46.5, 354707.5 6689568.2 46.5, 354690.1 6689547.3 46.5, 354688.2 6689544.9 46.5, 354684 6689548.3 46.5, 354677.2 6689554.2 46.5, 354698.9 6689579.7 46.5))
BATIMENT0000000302927848;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;35;20;9.4;30.8;40.2;58.7;31.9;Cadastre;C 0.6;POLYGON Z ((354621.3 6689562.9 40.2, 354622.3 6689564.1 40.2, 354626.7 6689569.4 40.2, 354628.4 6689571.5 40.2, 354639.9 6689584.9 40.2, 354655.4 6689571.8 40.2, 354636.8 6689549.7 40.2, 354621.3 6689562.9 40.2))
BATIMENT0000000302928301;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.2;30.0;37.2;41.6;30.5;Cadastre;A 1.0;POLYGON Z ((354703.6 6689585.2 37.2, 354711.5 6689578.7 37.2, 354708.2 6689574.8 37.2, 354709.5 6689573.3 37.2, 354708.1 6689571.8 37.2, 354698.9 6689579.7 37.2, 354703.6 6689585.2 37.2))
BATIMENT0000000302927847;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;18.0;31.1;49.1;54.0;32.0;Cadastre;C 0.8;POLYGON Z ((354611.1 6689573.6 49.1, 354610 6689572.5 49.1, 354606 6689575.9 49.1, 354611.4 6689582.4 49.1, 354613.7 6689580.4 49.1, 354615.5 6689582.4 49.1, 354613.2 6689584.4 49.1, 354618.6 6689590.7 49.1, 354622 6689587.5 49.1, 354620.6 6689585.7 49.1, 354627.8 6689579.3 49.1, 354632.4 6689584.8 49.1, 354631.6 6689585.8 49.1, 354636.8 6689591.6 49.1, 354637.7 6689591.4 49.1, 354640 6689593.9 49.1, 354644.3 6689590.2 49.1, 354639.9 6689584.9 49.1, 354628.4 6689571.5 49.1, 354626.1 6689573.6 49.1, 354624.4 6689571.4 49.1, 354626.7 6689569.4 49.1, 354622.3 6689564.1 49.1, 354611.1 6689573.6 49.1))
BATIMENT0000000302928293;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;12;20;13.3;30.1;43.4;46.2;30.8;Cadastre;A 1.0;POLYGON Z ((354718.7 6689510.3 43.4, 354721.2 6689513.2 43.4, 354733.6 6689502.7 43.4, 354732 6689500.7 43.4, 354727.9 6689495.7 43.4, 354716.7 6689482.4 43.4, 354704.4 6689492.8 43.4, 354718.7 6689510.3 43.4), (354721.3 6689493.8 43.4, 354725.2 6689498.4 43.4, 354718.9 6689503.8 43.4, 354715 6689499.3 43.4, 354716.6 6689497.9 43.4, 354717.4 6689498.9 43.4, 354720.5 6689496.3 43.4, 354719.6 6689495.2 43.4, 354721.3 6689493.8 43.4))
BATIMENT0000000302928298;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;15.2;28.9;44.2;46.5;30.4;Cadastre;A 1.0;POLYGON Z ((354759.2 6689508.3 44.2, 354756.7 6689505.5 44.2, 354747.7 6689512.9 44.2, 354750.1 6689516.2 44.2, 354750.4 6689517.5 44.2, 354747.7 6689519.6 44.2, 354755.5 6689528.8 44.2, 354757.5 6689531 44.2, 354767 6689512.1 44.2, 354761.8 6689506 44.2, 354759.2 6689508.3 44.2))
BATIMENT0000000302928201;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;6.0;00;00;15.2;27.6;42.9;49.3;29.5;Cadastre;A 1.0;POLYGON Z ((354776.9 6689552.4 42.9, 354784.7 6689543 42.9, 354779.1 6689539.8 42.9, 354776.8 6689544.4 42.9, 354772.3 6689542.1 42.9, 354783.7 6689519.7 42.9, 354794 6689531.8 42.9, 354801 6689523.4 42.9, 354784.7 6689503.5 42.9, 354783.9 6689503.3 42.9, 354782.3 6689503.3 42.9, 354779.7 6689502.4 42.9, 354776.4 6689508.7 42.9, 354776.5 6689509.4 42.9, 354775.5 6689511.8 42.9, 354775.1 6689511.7 42.9, 354759.8 6689542.2 42.9, 354776.9 6689552.4 42.9))
BATIMENT0000000302928302;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;16.8;29.4;46.3;47.5;30.1;Cadastre;C 0.5;POLYGON Z ((354735.1 6689526.8 46.3, 354736.2 6689528.5 46.3, 354734.9 6689529.5 46.3, 354732.9 6689531.2 46.3, 354734 6689531.9 46.3, 354731.5 6689534.1 46.3, 354732.3 6689535.4 46.3, 354730.1 6689537.6 46.3, 354730.9 6689538.4 46.3, 354729.1 6689540 46.3, 354730.8 6689542.1 46.3, 354726.3 6689545.6 46.3, 354727.1 6689546.7 46.3, 354725.2 6689548.5 46.3, 354728.4 6689552.3 46.3, 354729.6 6689553.7 46.3, 354734 6689559.3 46.3, 354732.1 6689560.9 46.3, 354735.3 6689564.7 46.3, 354740.1 6689560.7 46.3, 354739.4 6689559.9 46.3, 354741.5 6689558.2 46.3, 354740.2 6689556.6 46.3, 354744 6689553.2 46.3, 354743.3 6689552.3 46.3, 354745.5 6689550.3 46.3, 354744.5 6689549.1 46.3, 354746.9 6689546.9 46.3, 354745 6689544.6 46.3, 354746.4 6689543.4 46.3, 354750.3 6689540 46.3, 354749.4 6689539 46.3, 354751.7 6689537 46.3, 354750.3 6689535.5 46.3, 354754.2 6689532 46.3, 354753.2 6689530.8 46.3, 354755.5 6689528.8 46.3, 354747.7 6689519.6 46.3, 354746.2 6689517.7 46.3, 354735.1 6689526.8 46.3))
BATIMENT0000000302928202;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;28.3;32.9;41.2;29.4;Cadastre;;POLYGON Z ((354782.8 6689555.7 32.9, 354796 6689539.8 32.9, 354791 6689535.4 32.9, 354784.7 6689543 32.9, 354776.9 6689552.4 32.9, 354782.8 6689555.7 32.9))
BATIMENT0000000302928205;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;90;11.2;29.0;40.2;43.0;30.4;Cadastre;A 1.0;POLYGON Z ((354748.5 6689564.3 40.2, 354757.8 6689566.7 40.2, 354761.5 6689567.5 40.2, 354762.2 6689566 40.2, 354762.9 6689566.2 40.2, 354769.3 6689553.9 40.2, 354769.8 6689552.9 40.2, 354757.6 6689546.4 40.2, 354748.5 6689564.3 40.2))
BATIMENT0000000302928200;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;40;5.9;27.8;33.7;40.2;29.6;Cadastre;A 1.0;POLYGON Z ((354789.4 6689566.7 33.7, 354785.9 6689573.4 33.7, 354791 6689574.5 33.7, 354797.1 6689564.2 33.7, 354788 6689558.8 33.7, 354782.8 6689555.7 33.7, 354776.9 6689552.4 33.7, 354759.8 6689542.2 33.7, 354757.6 6689546.4 33.7, 354769.8 6689552.9 33.7, 354773.8 6689557.7 33.7, 354789.4 6689566.7 33.7))
BATIMENT0000000302928188;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;29.5;35.9;39.9;30.9;Cadastre;;POLYGON Z ((354720.2 6689564.9 35.9, 354722 6689567.1 35.9, 354725 6689569 35.9, 354725.9 6689566.9 35.9, 354723.6 6689563.8 35.9, 354721.8 6689563.3 35.9, 354720.2 6689564.9 35.9))
BATIMENT0000000302928206;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.2;29.5;36.7;40.8;30.9;Cadastre;A 1.0;POLYGON Z ((354748.5 6689564.3 36.7, 354741.7 6689577.9 36.7, 354752.2 6689583.2 36.7, 354755.7 6689576.5 36.7, 354754.9 6689576 36.7, 354756 6689574 36.7, 354754.9 6689573.3 36.7, 354757.8 6689566.7 36.7, 354748.5 6689564.3 36.7))
BATIMENT0000000302928189;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;3.0;00;00;10.4;29.5;40.0;43.0;31.0;Cadastre;A 1.0;POLYGON Z ((354737.2 6689572.5 40, 354727.3 6689567.7 40, 354718.1 6689585.8 40, 354720.5 6689585.3 40, 354729 6689589.3 40, 354737.2 6689572.5 40))
BATIMENT0000000302927924;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;31.0;33.7;41.5;31.3;Cadastre;;POLYGON Z ((354541.4 6689536.3 33.7, 354545.7 6689541.8 33.7, 354551.5 6689537 33.7, 354581.1 6689511.7 33.7, 354576.7 6689506.8 33.7, 354541.4 6689536.3 33.7))
BATIMENT0000000302927923;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;31.1;35.5;40.0;32.0;Cadastre;;POLYGON Z ((354585.1 6689523.3 35.5, 354588.3 6689527.2 35.5, 354591 6689525.2 35.5, 354593.7 6689528.3 35.5, 354594.5 6689527.5 35.5, 354588.5 6689520.5 35.5, 354585.1 6689523.3 35.5))
BATIMENT0000000302927922;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;10;10;25.2;31.1;56.3;57.1;32.4;Cadastre;C 0.7;POLYGON Z ((354569.3 6689558.4 56.3, 354576.6 6689566.9 56.3, 354606.3 6689541.9 56.3, 354599.2 6689533.3 56.3, 354569.3 6689558.4 56.3))
BATIMENT0000000302929165;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1982-01-01;;;;BDTopo;2.5;BDTopo;1.5;41.0;8.0;00;00;23.1;30.0;;59.4;32.4;Imagerie aérienne;A 1.0;POLYGON Z ((354551.1 6689588.3 53.1, 354576.6 6689566.9 53.1, 354569.3 6689558.4 53.1, 354564.6 6689552.9 53.1, 354539.1 6689573.8 53.1, 354551.1 6689588.3 53.1))
BATIMENT0000000302927844;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;12;20;15.5;31.0;46.5;51.2;32.1;Cadastre;A 1.0;POLYGON Z ((354590 6689589.3 46.5, 354596.8 6689597.3 46.5, 354608.7 6689611 46.5, 354611 6689609.1 46.5, 354612.8 6689607.6 46.5, 354603.1 6689596.1 46.5, 354602.6 6689595.8 46.5, 354601.9 6689595.5 46.5, 354600.4 6689596.6 46.5, 354599.9 6689596.4 46.5, 354599.5 6689595.7 46.5, 354603.7 6689592.1 46.5, 354608.1 6689597 46.5, 354610.8 6689594.9 46.5, 354607.9 6689591.6 46.5, 354608.4 6689591.2 46.5, 354606.7 6689589.5 46.5, 354609 6689587.6 46.5, 354618.9 6689599.1 46.5, 354622.8 6689595.7 46.5, 354622.1 6689594.9 46.5, 354618.6 6689590.7 46.5, 354613.2 6689584.4 46.5, 354611.4 6689582.4 46.5, 354606 6689575.9 46.5, 354590 6689589.3 46.5))
BATIMENT0000000302927846;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;11.8;31.4;43.2;50.0;32.2;Cadastre;A 1.0;POLYGON Z ((354581.6 6689596.5 43.2, 354584.2 6689599.5 43.2, 354586.2 6689601.8 43.2, 354589.8 6689605.9 43.2, 354593.1 6689602.9 43.2, 354591.9 6689601.5 43.2, 354596.8 6689597.3 43.2, 354590 6689589.3 43.2, 354581.6 6689596.5 43.2))
BATIMENT0000000302927849;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;12.0;31.4;43.5;47.0;32.6;Cadastre;A 1.0;POLYGON Z ((354567.3 6689608.6 43.5, 354575.8 6689618.1 43.5, 354587.1 6689608.6 43.5, 354589.5 6689611.3 43.5, 354592.4 6689608.8 43.5, 354589.8 6689605.9 43.5, 354586.2 6689601.8 43.5, 354583.6 6689604 43.5, 354581.6 6689601.8 43.5, 354584.2 6689599.5 43.5, 354581.6 6689596.5 43.5, 354567.3 6689608.6 43.5))
BATIMENT0000000302927845;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;30.9;;;;Cadastre;;POLYGON Z ((354614.6 6689618.1 -1000, 354616.7 6689616.4 -1000, 354615 6689614.4 -1000, 354615.2 6689614.1 -1000, 354611 6689609.1 -1000, 354608.7 6689611 -1000, 354614.6 6689618.1 -1000))
BATIMENT0000000302927851;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.4;31.0;42.4;45.7;31.9;Cadastre;A 1.0;POLYGON Z ((354555 6689618.8 42.4, 354555 6689621.5 42.4, 354563.5 6689628.1 42.4, 354573 6689619.7 42.4, 354574.5 6689621.3 42.4, 354576.9 6689619.1 42.4, 354575.8 6689618.1 42.4, 354567.3 6689608.6 42.4, 354555 6689618.8 42.4))
BATIMENT0000000302928153;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;8.0;30;24;20.3;31.0;51.3;58.0;31.7;Cadastre;A 1.0;POLYGON Z ((354551.1 6689653.6 51.3, 354558 6689643.4 51.3, 354562.4 6689636.9 51.3, 354547.3 6689625.1 51.3, 354535.7 6689634.9 51.3, 354549.9 6689652.4 51.3, 354551.1 6689653.6 51.3))
BATIMENT0000000302928208;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;20;20;11.2;29.5;40.7;43.2;30.8;Cadastre;A 1.0;POLYGON Z ((354752.2 6689583.2 40.7, 354741.7 6689577.9 40.7, 354736.5 6689588.2 40.7, 354746.6 6689593.2 40.7, 354750.9 6689584.8 40.7, 354754.7 6689586.4 40.7, 354755.3 6689584.7 40.7, 354752.2 6689583.2 40.7))
BATIMENT0000002011295463;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;23.0;7.0;00;00;11.7;25.9;;;;Imagerie aérienne;C 0.4;POLYGON Z ((354779.4 6689607.1 37.6, 354779.5 6689601.7 31.7, 354783.4 6689603 31.7, 354789.1 6689601.5 31.7, 354792.3 6689591.3 31.7, 354783.3 6689585.6 31.7, 354785.6 6689579.8 37.6, 354775.6 6689577.3 37.6, 354775.7 6689576.9 37.6, 354765.2 6689574.3 37.6, 354762.9 6689581.4 34.6, 354758.7 6689602.1 37.5, 354779.4 6689607.1 37.6))
BATIMENT0000000302928190;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;90;7.6;30.6;38.2;41.9;30.8;Cadastre;A 1.0;POLYGON Z ((354717 6689586 38.2, 354713.4 6689589.2 38.2, 354717.1 6689593.4 38.2, 354725 6689597.1 38.2, 354729 6689589.3 38.2, 354720.5 6689585.3 38.2, 354718.1 6689585.8 38.2, 354717 6689586 38.2))
BATIMENT0000000302928209;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.8;29.6;40.4;42.7;30.6;Cadastre;C 0.8;POLYGON Z ((354746.6 6689593.2 40.4, 354736.5 6689588.2 40.4, 354731.2 6689598.7 40.4, 354741.2 6689603.8 40.4, 354746.6 6689593.2 40.4))
BATIMENT0000000302928191;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.9;29.5;39.5;41.4;30.6;Cadastre;A 1.0;POLYGON Z ((354714.3 6689598.8 39.5, 354720.4 6689605.8 39.5, 354720.8 6689605.5 39.5, 354725 6689597.1 39.5, 354717.1 6689593.4 39.5, 354714.3 6689598.8 39.5))
BATIMENT0000000302928210;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;11.1;27.5;38.6;42.3;30.6;Cadastre;C 0.9;POLYGON Z ((354741.2 6689603.8 38.6, 354731.2 6689598.7 38.6, 354725.9 6689609.3 38.6, 354737 6689612 38.6, 354741.2 6689603.8 38.6))
BATIMENT0000000302928207;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.8;28.4;33.2;35.1;30.6;Cadastre;C 0.4;POLYGON Z ((354747.2 6689606.6 33.2, 354744.5 6689613.7 33.2, 354748.5 6689614.6 33.2, 354750.5 6689608.4 33.2, 354747.2 6689606.6 33.2))
BATIMENT0000000302928204;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;7.0;28.1;35.2;39.7;30.5;Cadastre;C 0.4;POLYGON Z ((354754 6689610.2 35.2, 354750.5 6689608.4 35.2, 354748.5 6689614.6 35.2, 354752.9 6689615.6 35.2, 354754 6689610.2 35.2))
BATIMENT0000002275363171;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;17.6;27.4;;45.0;30.4;Imagerie aérienne;;POLYGON Z ((354773.9 6689632.6 41.4, 354774.1 6689631.4 41.4, 354750.3 6689627 44.8, 354728.8 6689621.3 45, 354730.5 6689637.1 45, 354731.6 6689637.4 45, 354734.4 6689640.8 43.7, 354739.5 6689647.9 40.9, 354741.3 6689650.9 38.1, 354748.5 6689647.6 38.3, 354748.3 6689644.6 40.2, 354747.6 6689640.4 40.2, 354755.1 6689641.9 40.1, 354753.2 6689648.2 40, 354753.5 6689648.4 40, 354752.1 6689651.4 37.7, 354760.5 6689656.1 38.3, 354763.2 6689651.8 40.6, 354766.4 6689646.8 42, 354768.2 6689644.1 42.5, 354775.1 6689645.7 38.2, 354785.1 6689635.9 38.3, 354773.9 6689632.6 41.4))
BATIMENT0000002275363134;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.1;26.0;;;;Imagerie aérienne;;POLYGON Z ((354789.9 6689644.5 38.5, 354776.7 6689649.5 38.5, 354777.8 6689652 38.8, 354768.3 6689655.6 38.8, 354769 6689656.8 41.1, 354767.1 6689657.6 41.1, 354772.1 6689670.8 40.9, 354773.9 6689670.1 40.9, 354774.3 6689671.8 38.2, 354783.8 6689668.2 39.7, 354784.7 6689670.6 38.9, 354797.8 6689666.4 39, 354789.9 6689644.5 38.5))
BATIMENT0000000302929166;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1969-01-01;;;;BDTopo;2.5;BDTopo;1.5;34.0;9.0;34;20;13.4;30.2;;47.9;32.3;Imagerie aérienne;C 0.2;POLYGON Z ((354649.8 6689596.6 43.6, 354653.2 6689600.6 43.6, 354651.1 6689602.6 43.6, 354652.6 6689604.4 43.6, 354654.6 6689602.6 43.6, 354659.2 6689608 43.6, 354674.5 6689594.5 43.6, 354665.2 6689583.4 43.6, 354649.8 6689596.6 43.6))
BATIMENT0000000302927843;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.4;31.2;34.7;39.7;32.1;Cadastre;C 0.3;POLYGON Z ((354629.5 6689603.5 34.7, 354634.1 6689599.5 34.7, 354626.9 6689590.8 34.7, 354622.1 6689594.9 34.7, 354622.8 6689595.7 34.7, 354629.5 6689603.5 34.7))
BATIMENT0000000302927893;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;19.0;9.0;30;20;13.5;30.2;43.7;48.5;32.3;Cadastre;C 0.5;POLYGON Z ((354686.1 6689608.3 43.7, 354690.4 6689613.4 43.7, 354690.7 6689620.7 43.7, 354691.5 6689621.6 43.7, 354689.1 6689625.9 43.7, 354690.5 6689628.1 43.7, 354692.1 6689630.6 43.7, 354693.4 6689630.9 43.7, 354702.8 6689635.6 43.7, 354711.2 6689619 43.7, 354710.5 6689611.4 43.7, 354677.6 6689572.6 43.7, 354665.2 6689583.4 43.7, 354674.5 6689594.5 43.7, 354682.1 6689603.5 43.7, 354686.1 6689608.3 43.7))
BATIMENT0000000302927895;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;14.5;30.2;44.7;48.5;33.0;Cadastre;C 0.2;POLYGON Z ((354648 6689594.8 44.7, 354643.7 6689598.7 44.7, 354644.2 6689599 44.7, 354636.9 6689605.4 44.7, 354636.2 6689605.1 44.7, 354633 6689607.6 44.7, 354637.9 6689613.5 44.7, 354639.9 6689611.5 44.7, 354641.4 6689613.3 44.7, 354639.4 6689615.2 44.7, 354642.9 6689619.3 44.7, 354644 6689620.6 44.7, 354648.1 6689617 44.7, 354645.3 6689613.7 44.7, 354647.3 6689612 44.7, 354648 6689612.4 44.7, 354650.8 6689610.2 44.7, 354650.2 6689609.5 44.7, 354652.5 6689607.4 44.7, 354655.6 6689610.8 44.7, 354659.2 6689608 44.7, 354654.6 6689602.6 44.7, 354652.6 6689604.4 44.7, 354651.1 6689602.6 44.7, 354653.2 6689600.6 44.7, 354649.8 6689596.6 44.7, 354648 6689594.8 44.7))
BATIMENT0000000302927894;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;31.4;34.0;34.5;32.0;Cadastre;;POLYGON Z ((354657.9 6689616.7 34, 354661 6689620.5 34, 354665.9 6689616.2 34, 354662.9 6689612.3 34, 354657.9 6689616.7 34))
BATIMENT0000000302929131;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.0;32.1;41.1;50.5;32.9;Cadastre;;POLYGON Z ((354626.1 6689632.6 41.1, 354631.6 6689639.1 41.1, 354634.4 6689636.6 41.1, 354628.9 6689630.2 41.1, 354626.1 6689632.6 41.1))
BATIMENT0000000302927896;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;29.7;35.5;42.7;30.4;Cadastre;;POLYGON Z ((354686.2 6689644.6 35.5, 354686.6 6689643.3 35.5, 354687.6 6689643.1 35.5, 354689.7 6689638.6 35.5, 354686.3 6689636.8 35.5, 354683.9 6689641.7 35.5, 354686.2 6689644.6 35.5))
BATIMENT0000000302927892;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.2;30.2;42.4;44.8;32.0;Cadastre;C 0.4;POLYGON Z ((354686.3 6689636.8 42.4, 354689.7 6689638.6 42.4, 354687.6 6689643.1 42.4, 354686.6 6689643.3 42.4, 354686.2 6689644.6 42.4, 354683.9 6689641.7 42.4, 354668.7 6689622.9 42.4, 354666 6689623.5 42.4, 354665.8 6689622.7 42.4, 354664.1 6689623.1 42.4, 354664.1 6689623.5 42.4, 354661.7 6689623.8 42.4, 354660.4 6689625.1 42.4, 354658.2 6689625.7 42.4, 354657.1 6689626.5 42.4, 354678.7 6689654.3 42.4, 354680.8 6689654.9 42.4, 354680.7 6689656.2 42.4, 354681.9 6689656.7 42.4, 354681.4 6689657.9 42.4, 354678.4 6689660.5 42.4, 354687.2 6689671.1 42.4, 354704.5 6689636.4 42.4, 354702.8 6689635.6 42.4, 354693.4 6689630.9 42.4, 354692.1 6689630.6 42.4, 354690.5 6689628.1 42.4, 354686.3 6689636.8 42.4))
BATIMENT0000000302929130;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.8;31.7;33.5;51.0;32.5;Cadastre;;POLYGON Z ((354650.2 6689645.7 33.5, 354657.5 6689653.9 33.5, 354662.1 6689649.7 33.5, 354655.1 6689641.6 33.5, 354650.2 6689645.7 33.5))
BATIMENT0000000302928182;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;12;23;9.3;30.3;39.6;44.6;31.6;Cadastre;C 0.2;POLYGON Z ((354616.6 6689670 39.6, 354618.5 6689667.5 39.6, 354622.7 6689670.7 39.6, 354623.7 6689669.4 39.6, 354629.8 6689674.2 39.6, 354628.8 6689675.5 39.6, 354632.8 6689678.6 39.6, 354630.9 6689681.2 39.6, 354634.5 6689683.7 39.6, 354645.3 6689670.3 39.6, 354642.5 6689668.2 39.6, 354642.8 6689667.9 39.6, 354638.1 6689664.5 39.6, 354636.8 6689665.7 39.6, 354630.7 6689660.8 39.6, 354632 6689659 39.6, 354624.6 6689653.5 39.6, 354622.4 6689656.4 39.6, 354621.5 6689657.5 39.6, 354617.3 6689662.8 39.6, 354613.6 6689667.6 39.6, 354616.6 6689670 39.6))
BATIMENT0000000302928184;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.5;30.9;37.4;38.7;31.8;Cadastre;A 1.0;POLYGON Z ((354594.7 6689638.4 37.4, 354590.6 6689633.9 37.4, 354581.4 6689642.1 37.4, 354586.2 6689646 37.4, 354593 6689640 37.4, 354594.7 6689638.4 37.4))
BATIMENT0000000302928154;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.7;31.0;40.7;45.4;31.5;Cadastre;A 1.0;POLYGON Z ((354560.8 6689645.5 40.7, 354559.1 6689648.2 40.7, 354565.2 6689653 40.7, 354564.2 6689654.4 40.7, 354564.4 6689655.2 40.7, 354566.7 6689657.2 40.7, 354567.7 6689656.7 40.7, 354568.2 6689655.9 40.7, 354569.4 6689656.5 40.7, 354570.1 6689655.7 40.7, 354575.7 6689647.4 40.7, 354562.4 6689636.9 40.7, 354558 6689643.4 40.7, 354560.8 6689645.5 40.7))
BATIMENT0000000302928183;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;7.0;31.0;38.0;41.2;31.8;Cadastre;A 1.0;POLYGON Z ((354606.7 6689662.3 38, 354610 6689664.7 38, 354613.6 6689667.6 38, 354617.3 6689662.8 38, 354621.5 6689657.5 38, 354622.4 6689656.4 38, 354611.7 6689648.1 38, 354607.9 6689653 38, 354602.9 6689649 38, 354603.4 6689648.3 38, 354593 6689640 38, 354586.2 6689646 38, 354606.7 6689662.3 38))
BATIMENT0000000302928155;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.8;31.0;39.8;41.7;31.3;Cadastre;A 1.0;POLYGON Z ((354585.2 6689667.9 39.8, 354591 6689659.5 39.8, 354575.7 6689647.4 39.8, 354570.1 6689655.7 39.8, 354585.2 6689667.9 39.8))
BATIMENT0000000302928156;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;9.6;31.0;40.6;44.2;31.2;Cadastre;C 0.7;POLYGON Z ((354584.8 6689668.5 40.6, 354585.7 6689669.2 40.6, 354585.4 6689670.1 40.6, 354585.4 6689671 40.6, 354587.2 6689672.2 40.6, 354587.8 6689672.1 40.6, 354588.1 6689671.8 40.6, 354588.3 6689671.4 40.6, 354590.9 6689673.1 40.6, 354591.4 6689673.4 40.6, 354591.2 6689673.7 40.6, 354590.9 6689674.2 40.6, 354591.1 6689675.1 40.6, 354592.7 6689676.1 40.6, 354593.7 6689676 40.6, 354594.1 6689675.4 40.6, 354595.1 6689676.3 40.6, 354601 6689667.4 40.6, 354591 6689659.5 40.6, 354585.2 6689667.9 40.6, 354585.1 6689668.1 40.6, 354584.8 6689668.5 40.6))
BATIMENT0000000302927973;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;13.5;30.5;44.0;48.1;31.7;Cadastre;A 1.0;POLYGON Z ((354610.7 6689696.8 44, 354610.9 6689688.9 44, 354611.1 6689685.9 44, 354616.1 6689679.3 44, 354603.6 6689669.3 44, 354593.2 6689684.7 44, 354599.4 6689687.7 44, 354600.1 6689686.8 44, 354598.5 6689685.7 44, 354600.2 6689683.4 44, 354607.4 6689688.8 44, 354606.1 6689691 44, 354603.1 6689689.7 44, 354601.8 6689692.6 44, 354610.7 6689696.8 44))
BATIMENT0000000302927968;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.0;30.4;35.5;38.2;31.5;Cadastre;C 0.5;POLYGON Z ((354619.1 6689681.6 35.5, 354616.1 6689679.3 35.5, 354611.1 6689685.9 35.5, 354610.9 6689688.9 35.5, 354612.6 6689689.9 35.5, 354619.1 6689681.6 35.5))
BATIMENT0000000302927974;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.6;31.3;39.9;43.5;31.5;Cadastre;;POLYGON Z ((354591.8 6689686.7 39.9, 354591.6 6689687.8 39.9, 354592.1 6689688.7 39.9, 354592.6 6689689.4 39.9, 354601.2 6689693.7 39.9, 354601.8 6689692.6 39.9, 354603.1 6689689.7 39.9, 354599.4 6689687.7 39.9, 354593.2 6689684.7 39.9, 354591.8 6689686.7 39.9))
BATIMENT0000000302927997;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.1;31.7;35.8;38.8;32.0;Cadastre;C 0.3;POLYGON Z ((354569.5 6689692.4 35.8, 354570.8 6689693 35.8, 354575.5 6689695.2 35.8, 354579.3 6689689.6 35.8, 354576.8 6689688.2 35.8, 354577 6689687.7 35.8, 354574 6689685.7 35.8, 354569.5 6689692.4 35.8))
BATIMENT0000000302927964;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.8;31.3;42.1;45.1;31.7;Cadastre;C 0.6;POLYGON Z ((354610.8 6689702.7 42.1, 354614.1 6689705.2 42.1, 354621.2 6689697.2 42.1, 354618.5 6689695.2 42.1, 354619 6689694.4 42.1, 354619 6689693.5 42.1, 354615.8 6689690.7 42.1, 354615.1 6689690.7 42.1, 354614.6 6689690.8 42.1, 354614.2 6689691.2 42.1, 354612.6 6689689.9 42.1, 354610.9 6689688.9 42.1, 354610.7 6689696.8 42.1, 354610.8 6689702.7 42.1))
BATIMENT0000002275362606;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.9;30.0;;45.9;30.6;Imagerie aérienne;;POLYGON Z ((354696.9 6689701.9 45.9, 354697.5 6689702.1 44.3, 354698.6 6689700.3 44.1, 354700 6689699.1 44, 354701.5 6689697.6 44, 354702.2 6689696 43.9, 354702.8 6689694.8 43.5, 354703.8 6689693.5 43.4, 354705.7 6689691.6 43.2, 354706.1 6689690.6 43.2, 354711.4 6689688.8 41.1, 354715.3 6689687.3 37.7, 354716.4 6689683.2 37.7, 354716.9 6689678.8 38, 354716 6689678.6 40.8, 354712.5 6689678.2 43.7, 354709.8 6689676 43.7, 354710.6 6689675 43.7, 354711.7 6689673.2 43.7, 354712.2 6689671.5 43.5, 354715 6689672.3 43.4, 354723.4 6689678.2 37.3, 354729.7 6689669.2 37.3, 354726 6689666.7 40.7, 354726.4 6689666.1 40.8, 354721 6689661.4 43.8, 354717.6 6689657.6 43.8, 354720.5 6689653.8 43.7, 354724.1 6689655 44.5, 354727 6689658.4 40.5, 354730.2 6689662.4 37.7, 354738.5 6689657 37.7, 354735.2 6689652.5 40.9, 354729.6 6689644.1 44, 354730.3 6689642.9 44.3, 354728.6 6689642 45, 354728.8 6689641.4 45, 354716.8 6689629.7 45.8, 354704.7 6689653.5 45.7, 354693.3 6689676.4 45.7, 354682.7 6689697.6 45.7, 354696.1 6689702.8 45.8, 354696.9 6689701.9 45.9))
BATIMENT0000002275362893;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.3;30.1;;45.6;30.5;Imagerie aérienne;;POLYGON Z ((354724.7 6689684.6 40.8, 354719.9 6689687.5 40.8, 354716.1 6689691.2 43.5, 354714.8 6689690.8 43.5, 354714.1 6689692.2 45.2, 354710.9 6689694.8 45.2, 354704.5 6689705.8 45.4, 354761.7 6689728 44.1, 354770.6 6689715 44, 354774.5 6689708.8 40.7, 354780.7 6689700 39.3, 354781.3 6689700.3 39.3, 354795.3 6689680.6 39.2, 354798.5 6689674.2 35.5, 354784.6 6689673.6 35.5, 354782.6 6689676.3 38.4, 354781.8 6689676 38.4, 354777.3 6689680.5 38.5, 354769.7 6689677.8 38.6, 354765.7 6689686.4 38.6, 354769.2 6689689.8 38.6, 354766.5 6689692.8 37.1, 354763 6689689.8 39.5, 354757.7 6689694.6 39.7, 354753.6 6689696.8 39.7, 354754.2 6689707.3 44.1, 354748.7 6689705.9 44.4, 354749.2 6689704.4 44.3, 354749.4 6689699.9 41.5, 354748.8 6689697.1 41.1, 354749.3 6689695.9 41.1, 354751 6689691.1 38.3, 354738.6 6689689.1 38.2, 354737.3 6689692.5 41.5, 354735 6689698.6 43.8, 354729 6689696.5 43.8, 354730.6 6689694.4 41.1, 354730.7 6689693.5 41.1, 354732.4 6689691.5 41.1, 354733.5 6689690.2 38.5, 354729.1 6689682.8 38.8, 354724.7 6689684.6 40.8))
BATIMENT0000000302927905;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:09;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.4;28.8;38.2;46.1;30.5;Cadastre;;POLYGON Z ((354706.7 6689758.5 38.2, 354710.3 6689747.4 38.2, 354732.8 6689754.2 38.2, 354738.1 6689755.9 38.2, 354739 6689743.4 38.2, 354687.3 6689727.1 38.2, 354679.9 6689751.4 38.2, 354692.1 6689754.8 38.2, 354706.7 6689758.5 38.2))
BATIMENT0000000302927907;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;6.0;00;00;13.7;27.7;41.5;46.4;28.8;Cadastre;A 1.0;POLYGON Z ((354753.4 6689760.3 41.5, 354759.5 6689761 41.5, 354759.6 6689764.3 41.5, 354768.1 6689765.4 41.5, 354768.8 6689762.6 41.5, 354771.6 6689753.5 41.5, 354759.2 6689749.6 41.5, 354739 6689743.4 41.5, 354738.1 6689755.9 41.5, 354737.9 6689758.8 41.5, 354753.4 6689760.3 41.5))
BATIMENT0000000302927910;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.7;27.4;31.1;35.5;27.9;Cadastre;A 1.0;POLYGON Z ((354772.7 6689753.7 31.1, 354770.6 6689762.7 31.1, 354776.6 6689764.2 31.1, 354777.5 6689755.6 31.1, 354772.7 6689753.7 31.1))
BATIMENT0000000302927913;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.4;28.0;37.4;;;Cadastre;A 1.0;POLYGON Z ((354779.5 6689762 37.4, 354780.2 6689756.6 37.4, 354777.5 6689755.6 37.4, 354776.6 6689764.2 37.4, 354776.2 6689767.7 37.4, 354787.3 6689770.1 37.4, 354788.6 6689764 37.4, 354779.5 6689762 37.4))
BATIMENT0000000302927906;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:09;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.9;28.3;38.2;43.7;29.3;Cadastre;;POLYGON Z ((354731.7 6689772.4 38.2, 354737 6689772 38.2, 354737.6 6689763.7 38.2, 354737.9 6689758.8 38.2, 354738.1 6689755.9 38.2, 354732.8 6689754.2 38.2, 354731.7 6689772.4 38.2))
BATIMENT0000000302927909;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;13;40;10.8;28.0;38.8;40.4;28.1;Cadastre;A 1.0;POLYGON Z ((354759.1 6689776.1 38.8, 354775.2 6689778.9 38.8, 354776.2 6689767.7 38.8, 354776.6 6689764.2 38.8, 354770.6 6689762.7 38.8, 354772.7 6689753.7 38.8, 354771.6 6689753.5 38.8, 354768.8 6689762.6 38.8, 354768.1 6689765.4 38.8, 354759.6 6689764.3 38.8, 354759.5 6689765.9 38.8, 354759.2 6689775.7 38.8, 354759.1 6689776.1 38.8))
BATIMENT0000000302927912;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;17.6;28.0;45.6;46.6;28.9;Cadastre;A 1.0;POLYGON Z ((354759.2 6689775.7 45.6, 354759.5 6689765.9 45.6, 354737.6 6689763.7 45.6, 354737 6689772 45.6, 354737 6689773.8 45.6, 354759.2 6689775.7 45.6))
BATIMENT0000000302927911;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.8;27.0;36.9;44.8;27.7;Cadastre;A 1.0;POLYGON Z ((354785.4 6689780.8 36.9, 354787.3 6689770.1 36.9, 354776.2 6689767.7 36.9, 354775.2 6689778.9 36.9, 354785.4 6689780.8 36.9))
BATIMENT0000000302928181;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.2;30.9;38.1;46.0;31.0;Cadastre;C 0.6;POLYGON Z ((354643.5 6689690.9 38.1, 354644.4 6689690 38.1, 354658.2 6689700.6 38.1, 354657.4 6689701.7 38.1, 354662 6689705.6 38.1, 354670.2 6689694.9 38.1, 354665.8 6689691.6 38.1, 354667 6689689.7 38.1, 354653.1 6689678.7 38.1, 354652.1 6689679.8 38.1, 354649.3 6689677.5 38.1, 354651.5 6689674.7 38.1, 354645.5 6689670.1 38.1, 354645.3 6689670.3 38.1, 354634.5 6689683.7 38.1, 354643.5 6689690.9 38.1))
BATIMENT0000000302927970;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;9.5;30.2;39.7;49.6;31.5;Cadastre;C 0.6;POLYGON Z ((354637.8 6689696.4 39.7, 354630.9 6689705.3 39.7, 354632.5 6689706.9 39.7, 354633.2 6689706.8 39.7, 354640.2 6689698.3 39.7, 354637.8 6689696.4 39.7))
BATIMENT0000000302927969;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;;;10.3;31.3;41.6;45.1;31.5;Cadastre;C 0.1;POLYGON Z ((354616.8 6689708.1 41.6, 354622.7 6689707.8 41.6, 354632.5 6689706.9 41.6, 354630.9 6689705.3 41.6, 354628.8 6689703.9 41.6, 354629.2 6689703.2 41.6, 354629.1 6689701.9 41.6, 354625.9 6689699.3 41.6, 354624.8 6689699.4 41.6, 354624.3 6689700 41.6, 354621.2 6689697.2 41.6, 354614.1 6689705.2 41.6, 354616.8 6689708.1 41.6))
BATIMENT0000000302927966;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;20;20;15.4;30.0;45.4;50.1;31.1;Cadastre;C 0.8;POLYGON Z ((354660.3 6689724.8 45.4, 354657.6 6689711.8 45.4, 354640.2 6689698.3 45.4, 354633.2 6689706.8 45.4, 354642.5 6689714 45.4, 354644.2 6689715.2 45.4, 354644.9 6689718.9 45.4, 354643.6 6689719.2 45.4, 354645.2 6689726.5 45.4, 354645.8 6689728.8 45.4, 354650.2 6689728.3 45.4, 354658.9 6689727.2 45.4, 354660.3 6689724.8 45.4))
BATIMENT0000000302927972;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.9;30.3;38.3;43.5;30.9;Cadastre;C 0.5;POLYGON Z ((354634 6689715.7 38.3, 354635 6689721 38.3, 354642.4 6689719.5 38.3, 354641.4 6689714.3 38.3, 354634 6689715.7 38.3))
BATIMENT0000000302927971;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;30.3;37.0;43.0;30.9;Cadastre;;POLYGON Z ((354645.2 6689726.5 37, 354641 6689727 37, 354638.9 6689725.7 37, 354636.6 6689726.3 37, 354637 6689729.9 37, 354645.8 6689728.8 37, 354645.2 6689726.5 37))
BATIMENT0000000302927955;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;20;20;10.1;30.0;40.1;44.7;30.9;Cadastre;C 0.6;POLYGON Z ((354643.1 6689742.5 40.1, 354651.5 6689742.3 40.1, 354658.9 6689727.2 40.1, 354650.2 6689728.3 40.1, 354648.1 6689732.2 40.1, 354643.1 6689742.5 40.1))
BATIMENT0000000302927959;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.6;30.5;35.2;40.0;31.0;Cadastre;C 0.5;POLYGON Z ((354648.1 6689732.2 35.2, 354645.3 6689731.2 35.2, 354638.4 6689732.2 35.2, 354639.7 6689742.6 35.2, 354643.1 6689742.5 35.2, 354648.1 6689732.2 35.2))
BATIMENT0000000302927960;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;8.1;30.0;38.1;39.9;31.1;Cadastre;C 0.3;POLYGON Z ((354629.3 6689733.9 38.1, 354627.3 6689734.1 38.1, 354627 6689731.1 38.1, 354619.9 6689731.8 38.1, 354620.9 6689743.1 38.1, 354622.6 6689743.1 38.1, 354630.3 6689742.9 38.1, 354629.3 6689733.9 38.1))
BATIMENT0000000302929143;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;3.6;30.6;34.2;35.2;30.8;Cadastre;C 0.2;POLYGON Z ((354666.7 6689753.9 34.2, 354670.5 6689754.5 34.2, 354671.7 6689749.8 34.2, 354668.1 6689748.9 34.2, 354666.7 6689753.9 34.2))
BATIMENT0000000302927998;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;31.8;35.0;37.5;32.0;Cadastre;;POLYGON Z ((354576.6 6689695.7 35, 354575.5 6689695.2 35, 354570.8 6689693 35, 354568.3 6689698.2 35, 354574.1 6689700.9 35, 354575.1 6689698.9 35, 354578.1 6689700.3 35, 354580.6 6689701.2 35, 354582.2 6689698.4 35, 354576.6 6689695.7 35))
BATIMENT0000000302927967;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.1;32.0;35.1;;;Cadastre;B 0.3;POLYGON Z ((354586.4 6689700.7 35.1, 354586.7 6689700.8 35.1, 354588.5 6689697.6 35.1, 354586.3 6689696.3 35.1, 354581.7 6689704.1 35.1, 354583.8 6689705.2 35.1, 354586.4 6689700.7 35.1))
BATIMENT0000000302927963;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;14;20;8.9;31.3;40.2;42.7;31.7;Cadastre;B 0.4;POLYGON Z ((354597 6689705.5 40.2, 354597.4 6689709.8 40.2, 354598 6689715.5 40.2, 354598.3 6689717.3 40.2, 354600.7 6689717.2 40.2, 354611.5 6689716.1 40.2, 354611.1 6689708.3 40.2, 354610.7 6689703.8 40.2, 354599.3 6689704.9 40.2, 354597 6689705.5 40.2))
BATIMENT0000000302927956;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.7;32.0;39.7;;;Cadastre;B 0.3;POLYGON Z ((354589.4 6689712.6 39.7, 354587.5 6689712.5 39.7, 354587.6 6689710.9 39.7, 354587.5 6689708.6 39.7, 354587.3 6689707 39.7, 354583.8 6689705.2 39.7, 354581.7 6689704.1 39.7, 354578.7 6689709.4 39.7, 354577.8 6689717.7 39.7, 354582.3 6689717.4 39.7, 354589.2 6689716.6 39.7, 354589.4 6689712.6 39.7))
BATIMENT0000000302927962;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;4.0;31.4;35.5;38.2;31.7;Cadastre;B 0.3;POLYGON Z ((354594.8 6689710 35.5, 354595.2 6689715.5 35.5, 354598 6689715.5 35.5, 354597.4 6689709.8 35.5, 354594.8 6689710 35.5))
BATIMENT0000000302927965;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.0;31.3;38.3;41.1;31.7;Cadastre;;POLYGON Z ((354611.1 6689708.3 38.3, 354611.5 6689716.1 38.3, 354611.8 6689719.7 38.3, 354624.9 6689717.5 38.3, 354622.7 6689707.8 38.3, 354616.8 6689708.1 38.3, 354611.1 6689708.3 38.3))
BATIMENT0000000302927957;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;31.6;35.5;37.0;31.7;Cadastre;;POLYGON Z ((354595.2 6689715.5 35.5, 354590.6 6689716.5 35.5, 354590.7 6689718.3 35.5, 354598.3 6689717.3 35.5, 354598 6689715.5 35.5, 354595.2 6689715.5 35.5))
BATIMENT0000000302929229;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;30.6;36.1;37.7;32.0;Cadastre;;POLYGON Z ((354566.7 6689722.9 36.1, 354566.5 6689719.1 36.1, 354561.9 6689713.3 36.1, 354555.7 6689718.5 36.1, 354560.3 6689723.5 36.1, 354566.7 6689722.9 36.1))
BATIMENT0000000302927945;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;31.6;35.9;36.9;31.8;Cadastre;;POLYGON Z ((354575.2 6689723.7 35.9, 354574.9 6689721.5 35.9, 354575.7 6689721.4 35.9, 354575.9 6689720.7 35.9, 354575.7 6689718.1 35.9, 354572 6689718.5 35.9, 354570.3 6689718.5 35.9, 354571.1 6689724.2 35.9, 354575.2 6689723.7 35.9))
BATIMENT0000000302927952;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;4.2;31.8;36.0;39.0;32.0;Cadastre;C 0.4;POLYGON Z ((354589.2 6689716.6 36, 354582.3 6689717.4 36, 354584.6 6689735.6 36, 354586.9 6689735.4 36, 354587.7 6689742 36, 354590.3 6689741.8 36, 354593.9 6689741.5 36, 354590.7 6689718.3 36, 354590.6 6689716.5 36, 354589.2 6689716.6 36))
BATIMENT0000000302928843;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.8;30.3;40.2;43.7;31.3;Cadastre;;POLYGON Z ((354403.1 6689627.8 40.2, 354408.3 6689629.1 40.2, 354409.5 6689628.7 40.2, 354410.4 6689624.9 40.2, 354404.4 6689623.4 40.2, 354403.1 6689627.8 40.2))
BATIMENT0000000302928592;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;31.0;36.5;39.7;31.4;Cadastre;;POLYGON Z ((354415.7 6689641.6 36.5, 354416 6689642 36.5, 354419 6689642.9 36.5, 354424.5 6689638 36.5, 354413.8 6689635.2 36.5, 354412.3 6689640.4 36.5, 354415.7 6689641.6 36.5))
BATIMENT0000000302928590;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;11.4;30.2;41.7;44.5;31.5;Cadastre;A 1.0;POLYGON Z ((354410 6689649 41.7, 354410.4 6689647.3 41.7, 354412.3 6689640.4 41.7, 354413.8 6689635.2 41.7, 354401.2 6689631.5 41.7, 354397.4 6689645.6 41.7, 354408.5 6689648.6 41.7, 354410 6689649 41.7))
BATIMENT0000000302928591;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;30.5;43.2;45.9;31.0;Cadastre;;POLYGON Z ((354412.7 6689649.8 43.2, 354413.1 6689648 43.2, 354410.4 6689647.3 43.2, 354410 6689649 43.2, 354412.7 6689649.8 43.2))
BATIMENT0000000302928588;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;30.5;41.5;49.7;31.2;Cadastre;;POLYGON Z ((354410.9 6689656 41.5, 354408.3 6689655.2 41.5, 354405.5 6689664.9 41.5, 354407.8 6689665.6 41.5, 354410.9 6689656 41.5))
BATIMENT0000000029198920;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;23.1;31.0;;59.2;32.0;Imagerie aérienne;;POLYGON Z ((354486.2 6689619.8 54.1, 354452.6 6689648.2 53.5, 354454.5 6689650.7 52.5, 354434.4 6689667 51.6, 354436 6689669.3 51.5, 354390.7 6689707.5 50.6, 354388.6 6689707.1 50.6, 354387.1 6689714.5 50.7, 354390.9 6689715.3 50.7, 354395.4 6689720.1 50.4, 354464.8 6689661.7 50.8, 354519.6 6689615.3 51.4, 354518.7 6689609 51.8, 354509.1 6689604.4 51.8, 354505.2 6689607.6 51.8, 354503 6689605.3 51.8, 354488.7 6689617.2 51.8, 354487.1 6689618.7 36.9, 354486.2 6689619.8 54.1))
BATIMENT0000000302927927;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;7.0;;;7.1;31.1;38.2;58.4;32.0;Cadastre;A 1.0;POLYGON Z ((354474.9 6689712.6 38.2, 354462.1 6689697.3 38.2, 354450.3 6689707.3 38.2, 354469.4 6689729.9 38.2, 354481 6689719.9 38.2, 354474.9 6689712.6 38.2))
BATIMENT0000000302928502;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;9.0;00;00;9.9;30.7;40.7;57.1;31.3;Cadastre;A 1.0;POLYGON Z ((354460.1 6689734 40.7, 354441.4 6689711.9 40.7, 354428.2 6689722.9 40.7, 354437.6 6689733.9 40.7, 354447.2 6689745.2 40.7, 354460.1 6689734 40.7))
BATIMENT0000000302928503;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;9.0;34;20;14.1;30.6;44.7;58.3;31.3;Cadastre;A 1.0;POLYGON Z ((354420.1 6689729.8 44.7, 354432.3 6689744.4 44.7, 354440.3 6689754 44.7, 354448.6 6689747 44.7, 354447.2 6689745.2 44.7, 354437.6 6689733.9 44.7, 354428.2 6689722.9 44.7, 354420.1 6689729.8 44.7))
BATIMENT0000000302928504;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;9.0;00;00;23.8;30.3;54.2;58.3;31.0;Cadastre;A 1.0;POLYGON Z ((354410.3 6689738 54.2, 354419.3 6689749.1 54.2, 354422.6 6689752.9 54.2, 354432.3 6689744.4 54.2, 354420.1 6689729.8 54.2, 354410.3 6689738 54.2))
BATIMENT0000000302928589;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;13.1;30.1;43.3;46.1;30.8;Cadastre;A 1.0;POLYGON Z ((354393 6689661.5 43.3, 354403.9 6689664.5 43.3, 354408.5 6689648.6 43.3, 354397.4 6689645.6 43.3, 354393 6689661.5 43.3))
BATIMENT0000000302928587;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.5;30.6;38.1;43.5;31.1;Cadastre;A 1.0;POLYGON Z ((354390.3 6689679.6 38.1, 354398 6689682.8 38.1, 354399.1 6689678.7 38.1, 354396.6 6689677.8 38.1, 354400.3 6689664.8 38.1, 354407.5 6689666.7 38.1, 354407.8 6689665.6 38.1, 354405.5 6689664.9 38.1, 354403.9 6689664.5 38.1, 354393 6689661.5 38.1, 354390.3 6689679.6 38.1))
BATIMENT0000000302928679;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;14.6;29.9;44.5;52.8;30.6;Cadastre;C 0.3;POLYGON Z ((354337.2 6689670.5 44.5, 354334.8 6689685.7 44.5, 354340.2 6689686.7 44.5, 354337.7 6689701.1 44.5, 354332.2 6689700.3 44.5, 354330.6 6689708.8 44.5, 354329.2 6689716.2 44.5, 354325.9 6689715.8 44.5, 354324.3 6689724.4 44.5, 354374 6689732.4 44.5, 354375.3 6689724.1 44.5, 354374.5 6689723.9 44.5, 354376.9 6689708.9 44.5, 354377.5 6689709 44.5, 354379.9 6689692.7 44.5, 354379.3 6689692.4 44.5, 354380.3 6689685.3 44.5, 354381.4 6689677.7 44.5, 354382.1 6689677.7 44.5, 354383.3 6689668.8 44.5, 354335.2 6689660.8 44.5, 354333.7 6689669.7 44.5, 354337.2 6689670.5 44.5), (354368.2 6689685.7 44.5, 354369.2 6689680.6 44.5, 354355.1 6689678.2 44.5, 354354.5 6689680.2 44.5, 354352.3 6689679.8 44.5, 354353.1 6689674.9 44.5, 354353.7 6689675.7 44.5, 354354.6 6689675.6 44.5, 354355.5 6689675.2 44.5, 354356 6689673.8 44.5, 354375 6689677.1 44.5, 354373.9 6689684 44.5, 354373.5 6689686.4 44.5, 354368.2 6689685.7 44.5), (354353.9 6689704.3 44.5, 354353.8 6689705.2 44.5, 354354.5 6689705.3 44.5, 354354.8 6689704.5 44.5, 354356.9 6689704.8 44.5, 354356.7 6689705.7 44.5, 354357.6 6689705.9 44.5, 354357.8 6689704.9 44.5, 354360.1 6689705.3 44.5, 354360.1 6689706.2 44.5, 354360.8 6689706.4 44.5, 354361 6689705.6 44.5, 354363.2 6689706 44.5, 354363.1 6689706.8 44.5, 354364.1 6689706.9 44.5, 354364.2 6689706.2 44.5, 354366.2 6689706.5 44.5, 354366.1 6689707.3 44.5, 354366.9 6689707.4 44.5, 354367.1 6689706.8 44.5, 354369.6 6689707.1 44.5, 354369.5 6689707.9 44.5, 354370.3 6689708 44.5, 354368.2 6689722.8 44.5, 354348 6689719.4 44.5, 354348.2 6689718.1 44.5, 354348.1 6689716.6 44.5, 354346.8 6689716.3 44.5, 354346 6689717 44.5, 354347 6689710.9 44.5, 354348.1 6689704.9 44.5, 354348.5 6689705.4 44.5, 354349.5 6689705.5 44.5, 354350.6 6689704.6 44.5, 354351.4 6689704.8 44.5, 354351.5 6689703.8 44.5, 354353.9 6689704.3 44.5))
BATIMENT0000000302928636;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;29.7;36.2;45.6;30.3;Cadastre;;POLYGON Z ((354340.2 6689743.7 36.2, 354342.3 6689748.2 36.2, 354360 6689739.9 36.2, 354363.9 6689740.7 36.2, 354372.7 6689741.8 36.2, 354373.4 6689737.2 36.2, 354359.2 6689734.9 36.2, 354340.2 6689743.7 36.2))
BATIMENT0000000302928634;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;8.0;35;90;21.2;28.4;49.6;53.7;30.0;Cadastre;C 0.3;POLYGON Z ((354362.3 6689751.8 49.6, 354357.9 6689750.9 49.6, 354357.6 6689752.1 49.6, 354352.3 6689751.2 49.6, 354351.1 6689759.8 49.6, 354361.3 6689761.1 49.6, 354360.5 6689767.1 49.6, 354369 6689766.8 49.6, 354372.7 6689741.8 49.6, 354363.9 6689740.7 49.6, 354362.3 6689751.8 49.6))
BATIMENT0000000302929082;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.8;29.3;32.1;40.2;30.0;Cadastre;C 0.4;POLYGON Z ((354331.9 6689762.2 32.1, 354331.9 6689767.5 32.1, 354332 6689768.2 32.1, 354342.4 6689767.2 32.1, 354352.2 6689766.6 32.1, 354351.9 6689761.4 32.1, 354331.9 6689762.2 32.1))
BATIMENT0000000302928506;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;00;00;24.0;29.7;53.7;57.7;31.1;Cadastre;C 0.7;POLYGON Z ((354391.9 6689753.8 53.7, 354389.1 6689757.6 53.7, 354387.3 6689760.2 53.7, 354385.9 6689764.2 53.7, 354385.2 6689768.9 53.7, 354382.9 6689783.9 53.7, 354389.6 6689784.9 53.7, 354392.7 6689785.2 53.7, 354396.8 6689785.9 53.7, 354397.3 6689784 53.7, 354400.4 6689783.6 53.7, 354402.5 6689770.1 53.7, 354399.5 6689769.1 53.7, 354400.2 6689765.6 53.7, 354404.9 6689761.5 53.7, 354395.7 6689750.6 53.7, 354391.9 6689753.8 53.7))
BATIMENT0000000302928635;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1848-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;23;9.7;28.7;38.4;47.4;30.1;Cadastre;A 1.0;POLYGON Z ((354360.5 6689767.1 38.4, 354355.7 6689767.5 38.4, 354356.6 6689770 38.4, 354354.6 6689770.9 38.4, 354356.1 6689774.2 38.4, 354358 6689773.3 38.4, 354360.6 6689779.6 38.4, 354361.9 6689780.2 38.4, 354367.3 6689777.6 38.4, 354369 6689766.8 38.4, 354360.5 6689767.1 38.4))
BATIMENT0000000302929083;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1886-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;3.2;28.8;32.1;37.5;29.7;Cadastre;A 1.0;POLYGON Z ((354333.2 6689770.9 32.1, 354341.1 6689789.5 32.1, 354350.1 6689785.2 32.1, 354346.8 6689777.7 32.1, 354340.5 6689780.5 32.1, 354335.9 6689769.8 32.1, 354333.2 6689770.9 32.1))
BATIMENT0000000302928508;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;27.0;30.1;57.2;57.8;31.3;Cadastre;;POLYGON Z ((354392.4 6689787.2 57.2, 354392.7 6689785.2 57.2, 354389.6 6689784.9 57.2, 354389.2 6689786.7 57.2, 354392.4 6689787.2 57.2))
BATIMENT0000000302929230;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;30.6;36.1;40.6;32.4;Cadastre;;POLYGON Z ((354516.1 6689700.2 36.1, 354519.1 6689697.6 36.1, 354522 6689695.1 36.1, 354527.5 6689701.5 36.1, 354526.9 6689702 36.1, 354546.7 6689725.5 36.1, 354555.7 6689718.5 36.1, 354561.9 6689713.3 36.1, 354569.2 6689706.7 36.1, 354551.6 6689686.3 36.1, 354552.8 6689685.2 36.1, 354550.6 6689684.1 36.1, 354548.7 6689683.3 36.1, 354542.8 6689687.4 36.1, 354538.5 6689682.6 36.1, 354535.8 6689684.8 36.1, 354530.5 6689678.8 36.1, 354524.4 6689684.3 36.1, 354511.7 6689695 36.1, 354515.2 6689699.1 36.1, 354516.1 6689700.2 36.1))
BATIMENT0000000302927938;Indifférenciée;Sportif;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;30.7;36.5;45.0;32.0;Cadastre;;POLYGON Z ((354522.8 6689701 36.5, 354522.3 6689701.4 36.5, 354517.3 6689705.6 36.5, 354519 6689707.6 36.5, 354524.5 6689703 36.5, 354522.8 6689701 36.5))
BATIMENT0000000302927933;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.4;30.7;37.1;42.0;31.9;Cadastre;;POLYGON Z ((354519 6689707.6 37.1, 354521.6 6689710.8 37.1, 354525 6689717.1 37.1, 354527.2 6689719.7 37.1, 354527.9 6689719.1 37.1, 354533.4 6689714.5 37.1, 354533.8 6689714.2 37.1, 354525 6689703.6 37.1, 354524.5 6689703 37.1, 354519 6689707.6 37.1))
BATIMENT0000000302927932;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;31.7;39.4;42.7;32.2;Cadastre;;POLYGON Z ((354546.7 6689725.5 39.4, 354526.9 6689702 39.4, 354525 6689703.6 39.4, 354533.8 6689714.2 39.4, 354533.4 6689714.5 39.4, 354536.5 6689718.2 39.4, 354531.1 6689722.8 39.4, 354527.9 6689719.1 39.4, 354527.2 6689719.7 39.4, 354525 6689717.1 39.4, 354522.9 6689718.8 39.4, 354529.5 6689726.5 39.4, 354529.7 6689726.3 39.4, 354531.4 6689724.8 39.4, 354538 6689719.3 39.4, 354544.6 6689727.2 39.4, 354546.7 6689725.5 39.4))
BATIMENT0000000302927928;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;31.2;39.7;43.6;32.0;Cadastre;;POLYGON Z ((354491.3 6689731.9 39.7, 354481 6689719.9 39.7, 354469.4 6689729.9 39.7, 354479.5 6689741.9 39.7, 354487.5 6689735.1 39.7, 354491.3 6689731.9 39.7))
BATIMENT0000000302927929;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;31.4;40.7;44.6;32.2;Cadastre;;POLYGON Z ((354531.4 6689724.8 40.7, 354532.7 6689726.4 40.7, 354531 6689727.8 40.7, 354529.7 6689726.3 40.7, 354529.5 6689726.5 40.7, 354523.8 6689731.3 40.7, 354524.2 6689731.7 40.7, 354518.8 6689736.3 40.7, 354505.2 6689720.1 40.7, 354494.4 6689729.2 40.7, 354497.1 6689732.2 40.7, 354491.6 6689736.9 40.7, 354490.5 6689735.5 40.7, 354489 6689736.8 40.7, 354487.5 6689735.1 40.7, 354479.5 6689741.9 40.7, 354526.6 6689797.4 40.7, 354532.9 6689792.3 40.7, 354542.1 6689785 40.7, 354549.1 6689778.9 40.7, 354552.7 6689775.9 40.7, 354540.5 6689761.6 40.7, 354545.8 6689757.1 40.7, 354551.8 6689764.1 40.7, 354552.8 6689763.2 40.7, 354555.7 6689766.7 40.7, 354561.6 6689766.2 40.7, 354558.3 6689742.2 40.7, 354556.8 6689743.5 40.7, 354555.7 6689742.1 40.7, 354556.4 6689741.5 40.7, 354551.2 6689735.2 40.7, 354544.7 6689740.6 40.7, 354540.8 6689735.9 40.7, 354547.3 6689730.5 40.7, 354544.6 6689727.2 40.7, 354538 6689719.3 40.7, 354531.4 6689724.8 40.7), (354539.8 6689776.2 40.7, 354529.6 6689784.9 40.7, 354527.8 6689782.5 40.7, 354528.7 6689781.6 40.7, 354526.5 6689779.1 40.7, 354525.5 6689779.8 40.7, 354522.9 6689777 40.7, 354533.2 6689768.3 40.7, 354539.8 6689776.2 40.7), (354529.2 6689764.9 40.7, 354524.4 6689769.2 40.7, 354520.3 6689772.8 40.7, 354504.4 6689754 40.7, 354513.4 6689746.2 40.7, 354529.2 6689764.9 40.7), (354508.1 6689739.2 40.7, 354510.8 6689742.4 40.7, 354505.6 6689746.9 40.7, 354501 6689750.8 40.7, 354495.4 6689744.2 40.7, 354505.4 6689735.8 40.7, 354508.1 6689739.2 40.7))
BATIMENT0000000302928368;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;35;90;17.9;32.0;49.9;;;Cadastre;C 0.9;POLYGON Z ((354474.8 6689767.8 49.9, 354481 6689777 49.9, 354491.4 6689770.5 49.9, 354482.9 6689760.1 49.9, 354474 6689766 49.9, 354474.8 6689767.8 49.9))
BATIMENT0000000302928366;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;7.0;25;30;20.6;32.0;52.6;54.9;32.2;Cadastre;A 1.0;POLYGON Z ((354475.3 6689780.3 52.6, 354471.5 6689783.1 52.6, 354479.5 6689796.4 52.6, 354484.3 6689792.5 52.6, 354491.9 6689786.4 52.6, 354499.6 6689780 52.6, 354491.4 6689770.5 52.6, 354481 6689777 52.6, 354475.3 6689780.3 52.6), (354486.6 6689778.7 52.6, 354488.8 6689781.7 52.6, 354488.5 6689783.4 52.6, 354481.2 6689789.1 52.6, 354478.1 6689784.3 52.6, 354486.6 6689778.7 52.6))
BATIMENT0000000302928369;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;10.9;31.4;42.4;53.5;31.7;Cadastre;A 1.0;POLYGON Z ((354499.6 6689780 42.4, 354491.9 6689786.4 42.4, 354499.4 6689795.4 42.4, 354507.3 6689789 42.4, 354499.6 6689780 42.4))
BATIMENT0000000302927930;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;17.5;31.4;49.0;52.2;31.8;Cadastre;A 1.0;POLYGON Z ((354531.6 6689803.5 49, 354546.9 6689800.9 49, 354545.9 6689791.2 49, 354539.7 6689792.6 49, 354539.2 6689792.1 49, 354537.5 6689792.4 49, 354537.3 6689793.1 49, 354534.1 6689793.8 49, 354532.9 6689792.3 49, 354526.6 6689797.4 49, 354531.6 6689803.5 49))
BATIMENT0000000302928380;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;00;00;11.1;32.0;43.1;;;Cadastre;A 1.0;POLYGON Z ((354459.6 6689749.2 43.1, 354462.9 6689753.5 43.1, 354471.3 6689746.5 43.1, 354462.5 6689735.7 43.1, 354454.2 6689742.8 43.1, 354457.7 6689746.7 43.1, 354457.4 6689747.1 43.1, 354457.2 6689747.2 43.1, 354457.1 6689747.3 43.1, 354457 6689747.5 43.1, 354456.9 6689747.7 43.1, 354456.8 6689747.9 43.1, 354456.8 6689748 43.1, 354456.7 6689748.1 43.1, 354456.7 6689748.3 43.1, 354456.7 6689748.4 43.1, 354456.8 6689748.5 43.1, 354456.8 6689748.6 43.1, 354456.9 6689748.8 43.1, 354457 6689749 43.1, 354457 6689749.1 43.1, 354457.1 6689749.1 43.1, 354457.3 6689749.4 43.1, 354457.3 6689749.5 43.1, 354457.4 6689749.6 43.1, 354457.5 6689749.7 43.1, 354457.7 6689749.8 43.1, 354457.9 6689749.9 43.1, 354458.1 6689750 43.1, 354458.2 6689750 43.1, 354458.5 6689750 43.1, 354458.6 6689750 43.1, 354459 6689749.9 43.1, 354459.6 6689749.2 43.1))
BATIMENT0000000302928505;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1974-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;28.0;9.0;30;20;22.4;30.6;53.0;58.1;31.2;Cadastre;C 0.4;POLYGON Z ((354395.7 6689750.6 53, 354404.9 6689761.5 53, 354406.6 6689760 53, 354409.1 6689761.5 53, 354418.7 6689753.3 53, 354417.3 6689750.9 53, 354419.3 6689749.1 53, 354410.3 6689738 53, 354395.7 6689750.6 53))
BATIMENT0000000302928371;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;30;20;11.8;32.0;43.8;;;Cadastre;A 1.0;POLYGON Z ((354458.5 6689757.3 43.8, 354467.6 6689768.4 43.8, 354469.3 6689768.5 43.8, 354474 6689766 43.8, 354482.9 6689760.1 43.8, 354471.3 6689746.5 43.8, 354462.9 6689753.5 43.8, 354458.5 6689757.3 43.8))
BATIMENT0000000302928920;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;29.0;10.0;30;90;13.4;31.0;44.4;50.5;31.7;Cadastre;C 0.1;POLYGON Z ((354430.3 6689769.6 44.4, 354430.2 6689771.2 44.4, 354421.3 6689772.1 44.4, 354421.3 6689772.8 44.4, 354419.9 6689772.7 44.4, 354421.9 6689790.9 44.4, 354423.5 6689790.9 44.4, 354423.5 6689791.3 44.4, 354433 6689790.3 44.4, 354433.2 6689791.7 44.4, 354435.7 6689791.5 44.4, 354435.5 6689790 44.4, 354440.4 6689789.3 44.4, 354439.8 6689783.6 44.4, 354441 6689783.5 44.4, 354440.7 6689780.6 44.4, 354439.4 6689780.5 44.4, 354439.3 6689778.5 44.4, 354440.6 6689778.2 44.4, 354440.3 6689775.7 44.4, 354438.9 6689775.8 44.4, 354438.7 6689773.5 44.4, 354438.1 6689770.3 44.4, 354435 6689770.6 44.4, 354433.3 6689770.8 44.4, 354432.8 6689769.6 44.4, 354430.3 6689769.6 44.4))
BATIMENT0000000302928367;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.2;31.8;49.0;49.7;32.2;Cadastre;;POLYGON Z ((354474 6689778.3 49, 354472.8 6689778.3 49, 354464.8 6689783.5 49, 354466.3 6689786.1 49, 354471.5 6689783.1 49, 354475.3 6689780.3 49, 354474 6689778.3 49))
BATIMENT0000000302928373;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;31.4;39.8;46.0;32.1;Cadastre;;POLYGON Z ((354453.4 6689783.9 39.8, 354449 6689784.6 39.8, 354450.3 6689792.2 39.8, 354454.6 6689789.8 39.8, 354453.4 6689783.9 39.8))
BATIMENT0000000302928372;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.7;31.5;41.2;49.1;32.3;Cadastre;C 0.2;POLYGON Z ((354456.3 6689792.8 41.2, 354454.6 6689789.8 41.2, 354450.3 6689792.2 41.2, 354450.9 6689799.3 41.2, 354452.1 6689801.5 41.2, 354460.2 6689796.2 41.2, 354469.4 6689790.9 41.2, 354466.3 6689786.1 41.2, 354456.3 6689792.8 41.2))
BATIMENT0000000302928376;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;31.0;38.8;39.6;31.4;Cadastre;;POLYGON Z ((354431.1 6689801.4 38.8, 354433.7 6689807.3 38.8, 354435.3 6689807.1 38.8, 354436.7 6689809.7 38.8, 354441.1 6689807.5 38.8, 354441.7 6689808.4 38.8, 354444.1 6689807.1 38.8, 354441 6689800.6 38.8, 354431.1 6689801.4 38.8))
BATIMENT0000000302928379;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;31.0;40.4;41.8;31.2;Cadastre;A 1.0;POLYGON Z ((354427 6689802 40.4, 354425.4 6689802.1 40.4, 354428.1 6689808 40.4, 354428.8 6689809.6 40.4, 354433.7 6689807.3 40.4, 354431.1 6689801.4 40.4, 354427 6689802 40.4))
BATIMENT0000000302928374;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;4.8;32.0;36.8;;;Cadastre;B 0.3;POLYGON Z ((354441 6689800.6 36.8, 354444.1 6689807.1 36.8, 354447.3 6689813.6 36.8, 354455.8 6689809.6 36.8, 354452.1 6689801.5 36.8, 354450.9 6689799.3 36.8, 354441 6689800.6 36.8))
BATIMENT0000000302928507;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.5;30.3;52.9;55.7;31.3;Cadastre;;POLYGON Z ((354393.5 6689787.3 52.9, 354393.4 6689788.4 52.9, 354397.1 6689789.2 52.9, 354397.4 6689785.9 52.9, 354396.8 6689785.9 52.9, 354392.7 6689785.2 52.9, 354392.4 6689787.2 52.9, 354393.5 6689787.3 52.9))
BATIMENT0000000302928509;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;14;20;12.3;29.4;41.7;51.2;31.5;Cadastre;A 1.0;POLYGON Z ((354382.9 6689783.9 41.7, 354377.6 6689782.9 41.7, 354375.3 6689797 41.7, 354387.8 6689798.8 41.7, 354387.8 6689796.6 41.7, 354389.2 6689786.7 41.7, 354389.6 6689784.9 41.7, 354382.9 6689783.9 41.7))
BATIMENT0000000302928511;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;30.5;37.8;40.0;31.5;Cadastre;;POLYGON Z ((354387.8 6689796.6 37.8, 354387.8 6689798.8 37.8, 354390.8 6689799.2 37.8, 354390.9 6689797.1 37.8, 354387.8 6689796.6 37.8))
BATIMENT0000000302928512;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;31.1;34.5;35.7;31.5;Cadastre;;POLYGON Z ((354395.9 6689796.7 34.5, 354392.3 6689796.2 34.5, 354392.2 6689797.4 34.5, 354390.9 6689797.1 34.5, 354390.8 6689799.2 34.5, 354395.3 6689799.8 34.5, 354395.9 6689796.7 34.5))
BATIMENT0000000302928510;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;90;9.4;31.0;40.4;42.4;31.5;Cadastre;A 1.0;POLYGON Z ((354374.1 6689806.8 40.4, 354387.7 6689805.5 40.4, 354391.1 6689805.2 40.4, 354391.5 6689802.6 40.4, 354397 6689803.3 40.4, 354397.4 6689800.4 40.4, 354395.3 6689799.8 40.4, 354390.8 6689799.2 40.4, 354387.8 6689798.8 40.4, 354375.3 6689797 40.4, 354374.1 6689806.8 40.4))
BATIMENT0000000302928401;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;13;90;15.8;28.9;44.7;45.4;29.9;Cadastre;A 1.0;POLYGON Z ((354363.8 6689802.3 44.7, 354359.9 6689797.4 44.7, 354351.6 6689801.6 44.7, 354355.4 6689810 44.7, 354358.3 6689816.7 44.7, 354361.7 6689816.9 44.7, 354363.8 6689802.3 44.7))
BATIMENT0000000302928402;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;23;8.9;28.8;37.7;44.6;30.0;Cadastre;C 0.9;POLYGON Z ((354351.6 6689801.6 37.7, 354342.9 6689805.8 37.7, 354346.9 6689814.2 37.7, 354355.4 6689810 37.7, 354351.6 6689801.6 37.7))
BATIMENT0000000302928513;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;10.1;29.9;40.0;43.5;31.6;Cadastre;A 1.0;POLYGON Z ((354370.7 6689828.6 40, 354374.3 6689829.1 40, 354385.6 6689830.6 40, 354386.4 6689827.2 40, 354384.8 6689826.7 40, 354387.7 6689805.5 40, 354374.1 6689806.8 40, 354370.7 6689828.6 40))
BATIMENT0000000302928400;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;2.9;29.2;32.1;36.0;29.9;Cadastre;C 0.3;POLYGON Z ((354360.8 6689821.6 32.1, 354361.7 6689816.9 32.1, 354358.3 6689816.7 32.1, 354355.2 6689816 32.1, 354354.3 6689820.7 32.1, 354360.8 6689821.6 32.1))
BATIMENT0000000302928399;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;2.5;29.1;31.6;32.7;29.8;Cadastre;C 0.4;POLYGON Z ((354353.2 6689827.3 31.6, 354353.6 6689827.3 31.6, 354359.9 6689828.2 31.6, 354360.8 6689821.6 31.6, 354354.3 6689820.7 31.6, 354353.2 6689827.3 31.6))
BATIMENT0000000302928377;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;14.5;32.0;46.5;;;Cadastre;A 1.0;POLYGON Z ((354491.3 6689802 46.5, 354496.3 6689809.2 46.5, 354515.6 6689805.1 46.5, 354516.5 6689800.1 46.5, 354507.3 6689789 46.5, 354499.4 6689795.4 46.5, 354491.3 6689802 46.5), (354503.9 6689796.6 46.5, 354504.9 6689800.9 46.5, 354500 6689802.1 46.5, 354499.3 6689799.6 46.5, 354502.4 6689797 46.5, 354503.9 6689796.6 46.5))
BATIMENT0000000302928370;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;13.4;32.0;45.4;53.5;32.0;Cadastre;A 1.0;POLYGON Z ((354496.3 6689809.2 45.4, 354491.3 6689802 45.4, 354484.3 6689792.5 45.4, 354479.5 6689796.4 45.4, 354481.5 6689799.5 45.4, 354482 6689800.1 45.4, 354486 6689797.2 45.4, 354487.3 6689800.6 45.4, 354483.8 6689803.3 45.4, 354488.3 6689810.8 45.4, 354496.3 6689809.2 45.4))
BATIMENT0000000302928381;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;31.7;34.2;36.5;32.1;Cadastre;;POLYGON Z ((354476 6689805 34.2, 354476.8 6689805.7 34.2, 354478.2 6689805 34.2, 354475.7 6689801.1 34.2, 354470.8 6689803.2 34.2, 354470.3 6689805.5 34.2, 354471.4 6689807.3 34.2, 354476 6689805 34.2))
BATIMENT0000000302928378;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.3;31.3;41.7;48.4;32.0;Cadastre;A 1.0;POLYGON Z ((354488.3 6689810.8 41.7, 354483.8 6689803.3 41.7, 354482 6689800.1 41.7, 354481.5 6689799.5 41.7, 354479.9 6689801 41.7, 354481.4 6689803.3 41.7, 354478.2 6689805 41.7, 354483.1 6689813.3 41.7, 354488.3 6689810.8 41.7))
BATIMENT0000000302928387;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;9.3;31.3;40.7;43.2;32.1;Cadastre;A 1.0;POLYGON Z ((354475 6689815.2 40.7, 354475.8 6689816.8 40.7, 354483.1 6689813.3 40.7, 354478.2 6689805 40.7, 354476.8 6689805.7 40.7, 354476 6689805 40.7, 354471.4 6689807.3 40.7, 354471.6 6689807.6 40.7, 354466.6 6689810.1 40.7, 354469.8 6689817.7 40.7, 354475 6689815.2 40.7))
BATIMENT0000000302927858;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;10.8;32.0;42.8;;;Cadastre;A 1.0;POLYGON Z ((354546.2 6689822.4 42.8, 354546.2 6689827.4 42.8, 354551.4 6689827.3 42.8, 354551.5 6689822.9 42.8, 354551.2 6689822.8 42.8, 354551 6689820.8 42.8, 354553.2 6689820.4 42.8, 354553.7 6689823.3 42.8, 354553.6 6689827.5 42.8, 354557 6689827.4 42.8, 354557.3 6689822.1 42.8, 354557.4 6689819.5 42.8, 354557.4 6689809.2 42.8, 354536.1 6689813.5 42.8, 354536.4 6689824.3 42.8, 354546.2 6689822.4 42.8))
BATIMENT0000000302927804;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;90;7.3;31.6;39.0;42.2;32.0;Cadastre;A 1.0;POLYGON Z ((354520.7 6689816.3 39, 354516.1 6689817.3 39, 354517.2 6689823.6 39, 354518.8 6689823.9 39, 354520.7 6689816.3 39))
BATIMENT0000000302927859;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;31.6;41.5;43.7;32.0;Cadastre;A 1.0;POLYGON Z ((354530.1 6689814.4 41.5, 354525.7 6689833.2 41.5, 354536.6 6689835.7 41.5, 354536.4 6689824.3 41.5, 354536.1 6689813.5 41.5, 354530.1 6689814.4 41.5))
BATIMENT0000000302927802;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;12.8;32.0;44.8;49.2;32.2;Cadastre;A 1.0;POLYGON Z ((354491.6 6689822.6 44.8, 354492.2 6689824.9 44.8, 354490.8 6689825.2 44.8, 354493.1 6689836 44.8, 354501.5 6689834 44.8, 354500.8 6689830.9 44.8, 354500.6 6689830.2 44.8, 354498.2 6689820.5 44.8, 354491.6 6689822.6 44.8))
BATIMENT0000000302927803;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1867-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;15.0;32.0;47.0;50.7;32.1;Cadastre;A 1.0;POLYGON Z ((354498.2 6689820.5 47, 354500.6 6689830.2 47, 354507.4 6689828.9 47, 354510.2 6689829.5 47, 354509.6 6689831.9 47, 354508.6 6689831.6 47, 354508.4 6689832.7 47, 354500.8 6689830.9 47, 354501.5 6689834 47, 354502 6689836 47, 354506.6 6689837 47, 354506.3 6689838.3 47, 354514.5 6689840.6 47, 354518.8 6689823.9 47, 354517.2 6689823.6 47, 354516.1 6689817.3 47, 354498.2 6689820.5 47))
BATIMENT0000000302928390;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;10;10.3;31.1;41.4;43.0;31.4;Cadastre;A 1.0;POLYGON Z ((354414.5 6689803 41.4, 354415.2 6689804.7 41.4, 354419.2 6689813.3 41.4, 354423.4 6689811.3 41.4, 354422.9 6689810.2 41.4, 354428.1 6689808 41.4, 354425.4 6689802.1 41.4, 354414.5 6689803 41.4))
BATIMENT0000000302928384;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.2;31.2;40.5;42.3;32.1;Cadastre;A 1.0;POLYGON Z ((354470.8 6689819.2 40.5, 354469.8 6689817.7 40.5, 354466.6 6689810.1 40.5, 354466 6689809.4 40.5, 354457.7 6689813.4 40.5, 354462.3 6689823.2 40.5, 354470.8 6689819.2 40.5))
BATIMENT0000000302928391;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.8;30.6;37.5;43.4;31.4;Cadastre;A 1.0;POLYGON Z ((354406.5 6689813.4 37.5, 354411.6 6689825.2 37.5, 354416.9 6689822.6 37.5, 354420.3 6689829.5 37.5, 354422.4 6689828.6 37.5, 354423.2 6689829.8 37.5, 354426.3 6689828.4 37.5, 354419.2 6689813.3 37.5, 354415.2 6689804.7 37.5, 354406.5 6689813.4 37.5))
BATIMENT0000000302928383;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;31.0;34.8;39.7;31.3;Cadastre;;POLYGON Z ((354444.7 6689821.8 34.8, 354449.7 6689819 34.8, 354448.9 6689817.1 34.8, 354443.9 6689820 34.8, 354444.7 6689821.8 34.8))
BATIMENT0000000302928375;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;8.7;31.0;39.7;41.5;31.8;Cadastre;B 0.6;POLYGON Z ((354462.3 6689823.2 39.7, 354457.7 6689813.4 39.7, 354450.6 6689816.8 39.7, 354449.2 6689813.7 39.7, 354447.7 6689814.5 39.7, 354448.9 6689817.1 39.7, 354449.7 6689819 39.7, 354453.5 6689827.3 39.7, 354462.3 6689823.2 39.7))
BATIMENT0000000302928382;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;5.7;32.0;37.7;;;Cadastre;C 0.3;POLYGON Z ((354453.5 6689827.3 37.7, 354449.7 6689819 37.7, 354444.7 6689821.8 37.7, 354443.9 6689820 37.7, 354441.6 6689815.5 37.7, 354438.3 6689817 37.7, 354439.7 6689819.9 37.7, 354445.1 6689831.5 37.7, 354453.5 6689827.3 37.7))
BATIMENT0000000302928385;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;12;23;12.7;32.0;44.7;;;Cadastre;A 1.0;POLYGON Z ((354445.1 6689831.5 44.7, 354439.7 6689819.9 44.7, 354434 6689822.5 44.7, 354434.8 6689823.5 44.7, 354432.2 6689824.9 44.7, 354432.5 6689825.7 44.7, 354431.1 6689827.5 44.7, 354429.5 6689828.5 44.7, 354428.9 6689827.5 44.7, 354430.5 6689826.5 44.7, 354424.1 6689812.6 44.7, 354423.4 6689811.3 44.7, 354419.2 6689813.3 44.7, 354426.3 6689828.4 44.7, 354431.1 6689838.2 44.7, 354445.1 6689831.5 44.7))
BATIMENT0000000302928386;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;19;20;17.4;30.3;47.7;49.8;30.8;Cadastre;A 1.0;POLYGON Z ((354415.8 6689833.7 47.7, 354416.4 6689835.3 47.7, 354419.9 6689843.3 47.7, 354431.1 6689838.2 47.7, 354426.3 6689828.4 47.7, 354423.2 6689829.8 47.7, 354415.8 6689833.7 47.7))
BATIMENT0000000302927795;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.3;31.4;40.7;42.7;31.7;Cadastre;A 1.0;POLYGON Z ((354474.2 6689847.6 40.7, 354474 6689843.1 40.7, 354473.8 6689830.9 40.7, 354467.6 6689833.6 40.7, 354467.7 6689836.7 40.7, 354463.8 6689836.8 40.7, 354463.9 6689838.8 40.7, 354464.2 6689847.7 40.7, 354474.2 6689847.6 40.7))
BATIMENT0000000302928388;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;7.0;30.1;37.1;47.5;30.6;Cadastre;A 1.0;POLYGON Z ((354407.7 6689841.5 37.1, 354410.5 6689847.7 37.1, 354419.9 6689843.3 37.1, 354416.4 6689835.3 37.1, 354412.5 6689834.7 37.1, 354404.6 6689833.5 37.1, 354406.3 6689837.9 37.1, 354407.7 6689841.5 37.1), (354411 6689837.8 37.1, 354411.9 6689837.8 37.1, 354414.7 6689837.9 37.1, 354415.1 6689839 37.1, 354412 6689840.3 37.1, 354411 6689837.8 37.1))
BATIMENT0000000302927798;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;14;20;11.0;32.0;43.0;46.4;32.2;Cadastre;A 1.0;POLYGON Z ((354489.6 6689825.4 43, 354483.9 6689827 43, 354486.3 6689838.6 43, 354493.4 6689837.3 43, 354493.1 6689836 43, 354490.8 6689825.2 43, 354489.6 6689825.4 43))
BATIMENT0000000302927805;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.9;32.0;41.9;49.2;32.4;Cadastre;A 1.0;POLYGON Z ((354505.8 6689840.7 41.9, 354503 6689840.3 41.9, 354503.9 6689844.5 41.9, 354513 6689847.1 41.9, 354514.5 6689840.6 41.9, 354506.3 6689838.3 41.9, 354505.8 6689840.7 41.9))
BATIMENT0000000302927811;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;32.2;38.2;41.2;32.6;Cadastre;;POLYGON Z ((354500.4 6689843.6 38.2, 354498.5 6689852.5 38.2, 354499 6689852.4 38.2, 354501.2 6689851.9 38.2, 354502.9 6689844.3 38.2, 354500.4 6689843.6 38.2))
BATIMENT0000000302927812;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.4;32.0;40.4;44.0;32.5;Cadastre;A 1.0;POLYGON Z ((354502.9 6689844.3 40.4, 354501.2 6689851.9 40.4, 354501.9 6689852.2 40.4, 354511.2 6689854.6 40.4, 354513 6689847.1 40.4, 354503.9 6689844.5 40.4, 354502.9 6689844.3 40.4))
BATIMENT0000000302927796;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;29;6.8;31.8;38.6;45.5;32.4;Cadastre;A 1.0;POLYGON Z ((354474.4 6689861.7 38.6, 354474.5 6689865.6 38.6, 354481.2 6689865.6 38.6, 354485.4 6689865.5 38.6, 354485.1 6689854.8 38.6, 354485.1 6689845.8 38.6, 354487.9 6689845.7 38.6, 354487.4 6689843.7 38.6, 354486.5 6689839.8 38.6, 354483.1 6689840.4 38.6, 354483.1 6689842.9 38.6, 354474 6689843.1 38.6, 354474.2 6689847.6 38.6, 354474.4 6689861.7 38.6))
BATIMENT0000000302928218;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;9.2;32.0;41.2;43.6;32.2;Cadastre;C 0.5;POLYGON Z ((354519 6689859.1 41.2, 354529.7 6689862.2 41.2, 354530.6 6689858.6 41.2, 354531.2 6689858.8 41.2, 354532.3 6689854.7 41.2, 354531.3 6689854.5 41.2, 354532.1 6689851 41.2, 354527.3 6689849.8 41.2, 354521.5 6689848.5 41.2, 354519 6689859.1 41.2))
BATIMENT0000000302927813;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;26;23;9.3;32.0;41.3;43.5;32.6;Cadastre;A 1.0;POLYGON Z ((354508.3 6689865.7 41.3, 354511.2 6689854.6 41.3, 354501.9 6689852.2 41.3, 354501.2 6689851.9 41.3, 354499 6689852.4 41.3, 354495.9 6689865.5 41.3, 354498.6 6689865.4 41.3, 354508.3 6689865.7 41.3))
BATIMENT0000000302928216;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;12.5;32.0;44.5;46.1;32.4;Cadastre;A 1.0;POLYGON Z ((354515.7 6689872 44.5, 354525.5 6689874.2 44.5, 354527 6689874.6 44.5, 354529.7 6689862.2 44.5, 354519 6689859.1 44.5, 354515.7 6689872 44.5))
BATIMENT0000000302927797;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;32.0;36.8;38.1;32.3;Cadastre;;POLYGON Z ((354474.7 6689871.9 36.8, 354481.1 6689871.7 36.8, 354481.2 6689865.6 36.8, 354474.5 6689865.6 36.8, 354474.7 6689871.9 36.8))
BATIMENT0000000302927814;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.1;32.1;42.2;44.9;32.6;Cadastre;B 0.9;POLYGON Z ((354495.9 6689865.5 42.2, 354495.1 6689865.5 42.2, 354492.3 6689877.5 42.2, 354505.1 6689878.8 42.2, 354508.3 6689865.7 42.2, 354498.6 6689865.4 42.2, 354495.9 6689865.5 42.2))
BATIMENT0000000302927787;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;11.4;31.0;42.4;44.6;31.8;Cadastre;A 1.0;POLYGON Z ((354449 6689842.7 42.4, 354452.9 6689850.5 42.4, 354456.1 6689848.9 42.4, 354455.8 6689839.5 42.4, 354449 6689842.7 42.4))
BATIMENT0000000302927794;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;10.7;31.0;41.7;44.9;32.0;Cadastre;A 1.0;POLYGON Z ((354456.2 6689839.3 41.7, 354455.8 6689839.5 41.7, 354456.1 6689848.9 41.7, 354456.2 6689853.8 41.7, 354459.5 6689853.6 41.7, 354464.2 6689853.5 41.7, 354464.2 6689847.7 41.7, 354463.9 6689838.8 41.7, 354456.2 6689839.3 41.7))
BATIMENT0000000302927786;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.0;30.7;39.7;44.4;32.0;Cadastre;A 1.0;POLYGON Z ((354440.3 6689846.6 39.7, 354444.4 6689855.1 39.7, 354445.5 6689857.4 39.7, 354445.6 6689857.5 39.7, 354452.7 6689854.6 39.7, 354453.2 6689856.1 39.7, 354456.3 6689856.1 39.7, 354456.2 6689853.8 39.7, 354456.1 6689848.9 39.7, 354452.9 6689850.5 39.7, 354449 6689842.7 39.7, 354440.3 6689846.6 39.7))
BATIMENT0000000302927783;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.6;31.0;41.6;44.0;32.0;Cadastre;A 1.0;POLYGON Z ((354430.9 6689851.1 41.6, 354432.4 6689860.9 41.6, 354444.4 6689855.1 41.6, 354440.3 6689846.6 41.6, 354430.9 6689851.1 41.6))
BATIMENT0000000302927788;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;31.0;35.7;40.0;32.0;Cadastre;;POLYGON Z ((354456.4 6689859.8 35.7, 354459.4 6689859.6 35.7, 354459.5 6689853.6 35.7, 354456.2 6689853.8 35.7, 354456.3 6689856.1 35.7, 354456.4 6689859.8 35.7))
BATIMENT0000000302927781;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;13.4;30.2;43.6;44.9;32.1;Cadastre;A 1.0;POLYGON Z ((354418.6 6689856.8 43.6, 354423.1 6689865.9 43.6, 354432.4 6689861.7 43.6, 354432.4 6689860.9 43.6, 354430.9 6689851.1 43.6, 354418.6 6689856.8 43.6))
BATIMENT0000000302927782;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;31.5;35.5;38.5;32.2;Cadastre;;POLYGON Z ((354432.7 6689863.5 35.5, 354445.5 6689857.4 35.5, 354444.4 6689855.1 35.5, 354432.4 6689860.9 35.5, 354432.4 6689861.7 35.5, 354432.7 6689863.5 35.5))
BATIMENT0000000302927770;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;11.7;30.5;42.2;44.5;31.9;Cadastre;A 1.0;POLYGON Z ((354412.6 6689859.5 42.2, 354413.7 6689867.8 42.2, 354416.3 6689867.5 42.2, 354416.4 6689865.3 42.2, 354421.8 6689864.5 42.2, 354418.6 6689856.8 42.2, 354412.6 6689859.5 42.2))
BATIMENT0000000302927784;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.2;31.0;40.2;41.0;32.1;Cadastre;A 1.0;POLYGON Z ((354417.1 6689872 40.2, 354422.6 6689871.4 40.2, 354421.8 6689864.5 40.2, 354416.4 6689865.3 40.2, 354416.3 6689867.5 40.2, 354417.1 6689872 40.2))
BATIMENT0000000302927767;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;6.3;29.9;36.2;43.4;31.9;Cadastre;A 1.0;POLYGON Z ((354403.3 6689863.9 36.2, 354404.4 6689871.9 36.2, 354408.3 6689871.4 36.2, 354408.6 6689873.5 36.2, 354411.1 6689873.2 36.2, 354411.6 6689876.8 36.2, 354405.1 6689877.5 36.2, 354405.7 6689883.3 36.2, 354412.3 6689882.7 36.2, 354415.2 6689882.5 36.2, 354413.7 6689867.8 36.2, 354412.6 6689859.5 36.2, 354403.3 6689863.9 36.2))
BATIMENT0000000302928398;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;23;9.7;29.6;39.3;41.8;29.7;Cadastre;C 0.9;POLYGON Z ((354352.8 6689831 39.3, 354347.5 6689830.1 39.3, 354345.8 6689841.5 39.3, 354346.4 6689841.6 39.3, 354345.6 6689847.3 39.3, 354356.8 6689849.8 39.3, 354359.9 6689828.2 39.3, 354353.6 6689827.3 39.3, 354352.8 6689831 39.3))
BATIMENT0000000302928389;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;6.0;90;20;11.3;29.1;40.5;49.1;30.2;Cadastre;A 1.0;POLYGON Z ((354394.3 6689855.7 40.5, 354406.7 6689849.5 40.5, 354410.5 6689847.7 40.5, 354407.7 6689841.5 40.5, 354406.3 6689837.9 40.5, 354399 6689841.6 40.5, 354398 6689839.2 40.5, 354385.6 6689845.3 40.5, 354382 6689844.6 40.5, 354383 6689838.4 40.5, 354370.6 6689836.3 40.5, 354369.8 6689841.6 40.5, 354367.7 6689855.2 40.5, 354382.1 6689857.3 40.5, 354383.9 6689860.5 40.5, 354394.3 6689855.7 40.5))
BATIMENT0000000302928396;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;01;5.9;28.8;34.7;41.2;29.3;Cadastre;C 0.4;POLYGON Z ((354344.3 6689853.6 34.7, 354346.2 6689854.6 34.7, 354355.5 6689858.6 34.7, 354356.5 6689851.5 34.7, 354345.1 6689849.2 34.7, 354344.3 6689853.6 34.7))
BATIMENT0000000302928392;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;18.3;29.0;47.4;50.2;29.7;Cadastre;A 1.0;POLYGON Z ((354367.1 6689858.4 47.4, 354375.1 6689864.6 47.4, 354383.9 6689860.5 47.4, 354382.1 6689857.3 47.4, 354367.7 6689855.2 47.4, 354367.1 6689858.4 47.4))
BATIMENT0000000302928394;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;15;20;15.1;28.6;43.7;45.5;29.3;Cadastre;C 0.7;POLYGON Z ((354344.5 6689866.7 43.7, 354344 6689866.7 43.7, 354344 6689866.9 43.7, 354344 6689867 43.7, 354343.4 6689870.3 43.7, 354343.7 6689870.6 43.7, 354343.2 6689871.3 43.7, 354338.7 6689873.4 43.7, 354343.1 6689882.2 43.7, 354349.4 6689879.3 43.7, 354353.2 6689874.6 43.7, 354353.2 6689874.1 43.7, 354355.5 6689858.6 43.7, 354346.2 6689854.6 43.7, 354344.5 6689866.7 43.7))
BATIMENT0000000302927766;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;7.7;29.7;37.5;43.6;31.9;Cadastre;A 1.0;POLYGON Z ((354393.7 6689868.4 37.5, 354394.9 6689875.7 37.5, 354400.6 6689874.8 37.5, 354400.7 6689876 37.5, 354400.5 6689876 37.5, 354401.6 6689884.9 37.5, 354405.8 6689884.4 37.5, 354405.7 6689883.3 37.5, 354405.1 6689877.5 37.5, 354404.6 6689874.3 37.5, 354404.4 6689871.9 37.5, 354403.3 6689863.9 37.5, 354393.7 6689868.4 37.5))
BATIMENT0000000302927768;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;10;20;18.7;28.9;47.7;50.7;31.9;Cadastre;C 0.9;POLYGON Z ((354366.2 6689881.4 47.7, 354363.3 6689885.4 47.7, 354361.4 6689899 47.7, 354366 6689899.7 47.7, 354366.5 6689899.4 47.7, 354366.7 6689898.8 47.7, 354368.6 6689899.1 47.7, 354369.8 6689898.5 47.7, 354370.3 6689895.3 47.7, 354377.9 6689891.8 47.7, 354379.6 6689895.3 47.7, 354380.6 6689895.7 47.7, 354385.1 6689893.7 47.7, 354385.6 6689892.3 47.7, 354384.8 6689890.9 47.7, 354386.6 6689890.1 47.7, 354385.7 6689887.7 47.7, 354395.9 6689883 47.7, 354394.9 6689875.7 47.7, 354393.7 6689868.4 47.7, 354366.2 6689881.4 47.7))
BATIMENT0000000302927775;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;31.3;33.4;34.7;32.0;Cadastre;;POLYGON Z ((354405 6689891.1 33.4, 354404.6 6689888.1 33.4, 354396.6 6689888.9 33.4, 354397 6689891.8 33.4, 354403.1 6689891.3 33.4, 354405 6689891.1 33.4))
BATIMENT0000000302927772;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.0;30.6;37.7;41.1;32.0;Cadastre;A 1.0;POLYGON Z ((354397.7 6689897.6 37.7, 354399.2 6689909.2 37.7, 354404.9 6689908.3 37.7, 354404.6 6689905 37.7, 354403.1 6689891.3 37.7, 354397 6689891.8 37.7, 354397.7 6689897.6 37.7))
BATIMENT0000000302928420;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.2;29.0;38.2;39.7;29.3;Cadastre;A 1.0;POLYGON Z ((354344 6689909.3 38.2, 354344.7 6689912.8 38.2, 354346.4 6689913.5 38.2, 354349.6 6689893.7 38.2, 354346.3 6689891.1 38.2, 354341.1 6689893.4 38.2, 354343.3 6689905.4 38.2, 354344 6689909.3 38.2))
BATIMENT0000000302902909;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;13.9;8.2;22.1;25.3;11.6;Cadastre;A 1.0;POLYGON Z ((353934.5 6689623.7 22.1, 353937.3 6689632.3 22.1, 353946.9 6689629.9 22.1, 353945.4 6689624.8 22.1, 353946.9 6689613.8 22.1, 353936.6 6689612 22.1, 353934.5 6689623.7 22.1))
BATIMENT0000000302902955;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.8;11.4;16.2;20.6;12.3;Cadastre;A 1.0;POLYGON Z ((353912.4 6689617.5 16.2, 353917.9 6689618.5 16.2, 353916.8 6689623.8 16.2, 353915.2 6689626.1 16.2, 353913.7 6689625.2 16.2, 353911.9 6689627.9 16.2, 353916.9 6689631.5 16.2, 353922.3 6689624.3 16.2, 353924 6689615 16.2, 353913.1 6689613 16.2, 353912.4 6689617.5 16.2))
BATIMENT0000000302902950;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;10;5.7;13.3;19.0;;;Cadastre;A 1.0;POLYGON Z ((353893.8 6689621.8 19, 353892.0022898072 6689620.195889366 19, 353892.0022898072 6689623.800677473 19, 353893.8 6689621.8 19))
BATIMENT0000000302906007;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.5;12.0;14.5;17.2;12.6;Cadastre;;POLYGON Z ((353895.5 6689624.2 14.5, 353897.6 6689626 14.5, 353900.8 6689622.4 14.5, 353900.9 6689622.3 14.5, 353898.8 6689620.4 14.5, 353895.5 6689624.2 14.5))
BATIMENT0000000302902949;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;3.0;13.3;16.3;20.9;13.4;Cadastre;A 1.0;POLYGON Z ((353892.1 6689632.7 16.3, 353892.0022898072 6689632.613146495 16.3, 353892.0022898072 6689632.791847581 16.3, 353892.1 6689632.7 16.3))
BATIMENT0000000302902952;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;20;6.3;11.6;18.0;21.4;12.5;Cadastre;A 1.0;POLYGON Z ((353911.3 6689628.9 18, 353910.4 6689630.3 18, 353911.5 6689631.1 18, 353903.2 6689638.5 18, 353906.7 6689642.6 18, 353911.9 6689638.1 18, 353916.9 6689631.5 18, 353911.9 6689627.9 18, 353911.3 6689628.9 18))
BATIMENT0000000302902945;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.2;12.5;20.7;22.9;13.5;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6689642.138994286 20.7, 353892.0022898072 6689643.130736812 20.7, 353898.2 6689650.2 20.7, 353905.7 6689643.6 20.7, 353898.8 6689635.9 20.7, 353892.0022898072 6689642.138994286 20.7))
BATIMENT0000000302904715;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;20;7.3;12.7;20.0;;;Cadastre;A 1.0;POLYGON Z ((353917.6 6689646.6 20, 353917.4 6689653.4 20, 353918.8 6689655.1 20, 353924.4 6689655.2 20, 353924.8 6689645.1 20, 353919.3 6689645 20, 353917.6 6689646.6 20))
BATIMENT0000000302904716;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.9;11.0;20.0;23.3;12.5;Cadastre;A 1.0;POLYGON Z ((353924.4 6689655.2 20, 353929.9 6689655.3 20, 353932.2 6689653.9 20, 353932.4 6689647.5 20, 353930.8 6689645.3 20, 353924.8 6689645.1 20, 353924.4 6689655.2 20))
BATIMENT0000000302902944;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;20;20;10.1;12.5;22.6;25.5;14.1;Cadastre;C 0.9;POLYGON Z ((353898.2 6689650.2 22.6, 353892.0022898072 6689643.130736812 22.6, 353892.0022898072 6689655.724046042 22.6, 353898.2 6689650.2 22.6))
BATIMENT0000000302904717;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;90;8.0;13.0;21.0;24.4;13.2;Cadastre;A 1.0;POLYGON Z ((353906.7 6689656.2 21, 353912.8 6689662.9 21, 353918.4 6689657.5 21, 353912.6 6689651 21, 353906.7 6689656.2 21))
BATIMENT0000000302904718;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.1;10.6;19.7;21.7;12.0;Cadastre;A 1.0;POLYGON Z ((353928.8 6689657.6 19.7, 353932.8 6689663.7 19.7, 353937.9 6689660.3 19.7, 353940.3 6689658.7 19.7, 353936.1 6689652.7 19.7, 353928.8 6689657.6 19.7))
BATIMENT0000000302906005;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.7;11.7;15.4;15.8;12.6;Cadastre;;POLYGON Z ((353919.3 6689659.6 15.4, 353921.4 6689661.9 15.4, 353923 6689660.9 15.4, 353920.7 6689658.6 15.4, 353919.3 6689659.6 15.4))
BATIMENT0000000302904719;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.7;13.4;19.1;22.2;13.6;Cadastre;A 1.0;POLYGON Z ((353899.5 6689662.5 19.1, 353906.9 6689671 19.1, 353907.4 6689670.3 19.1, 353906.3 6689669 19.1, 353912.8 6689662.9 19.1, 353906.7 6689656.2 19.1, 353899.5 6689662.5 19.1))
BATIMENT0000000302904720;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;14;23;9.1;10.7;19.9;22.6;11.6;Cadastre;A 1.0;POLYGON Z ((353932.8 6689663.7 19.9, 353928.5 6689666.6 19.9, 353934.2 6689674.6 19.9, 353939.5 6689670.9 19.9, 353942.5 6689668.8 19.9, 353939.3 6689664.2 19.9, 353940.2 6689663.6 19.9, 353937.9 6689660.3 19.9, 353932.8 6689663.7 19.9))
BATIMENT0000000302902926;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;00;00;13.2;15.4;28.6;30.7;16.2;Cadastre;C 0.7;POLYGON Z ((353892.1 6689685.8 28.6, 353897 6689681.4 28.6, 353897.3 6689681.7 28.6, 353898.2 6689681.7 28.6, 353899.6 6689680.4 28.6, 353899.5 6689679.4 28.6, 353899.4 6689679.1 28.6, 353904.8 6689674.3 28.6, 353898.4 6689666.7 28.6, 353892.0022898072 6689672.333804498 28.6, 353892.0022898072 6689685.702289807 28.6, 353892.1 6689685.8 28.6))
BATIMENT0000000302904721;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;00;00;14.1;9.6;23.7;27.7;11.6;Cadastre;A 1.0;POLYGON Z ((353942.5 6689668.8 23.7, 353939.5 6689670.9 23.7, 353934.2 6689674.6 23.7, 353932.2 6689676.1 23.7, 353944.5 6689693.2 23.7, 353948.6 6689690.3 23.7, 353950.7 6689688.8 23.7, 353951.4 6689688.4 23.7, 353956.7 6689684.6 23.7, 353944.4 6689667.4 23.7, 353942.5 6689668.8 23.7))
BATIMENT0000000302904623;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:42;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.0;13.3;16.3;16.5;15.8;Cadastre;C 0.5;POLYGON Z ((353897.3 6689688.1 16.3, 353907.3 6689698.6 16.3, 353911.2 6689695.2 16.3, 353901.2 6689684.6 16.3, 353897.3 6689688.1 16.3))
BATIMENT0000000302905803;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;11.3;17.4;24.2;13.2;Cadastre;;POLYGON Z ((353925.7 6689693.4 17.4, 353922.6 6689690 17.4, 353918 6689693.3 17.4, 353920.5 6689696.9 17.4, 353925.7 6689693.4 17.4))
BATIMENT0000000302905804;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;11.3;17.4;18.3;13.2;Cadastre;;POLYGON Z ((353920.5 6689696.9 17.4, 353918 6689693.3 17.4, 353917 6689694 17.4, 353917.8 6689696.5 17.4, 353918.9 6689698.1 17.4, 353920.5 6689696.9 17.4))
BATIMENT0000000302906088;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;16.5;8.1;24.6;27.1;10.1;Cadastre;C 0.2;POLYGON Z ((353970.1 6689683.3 24.6, 353979.1 6689677 24.6, 353982.5 6689674.6 24.6, 353974.2 6689662.8 24.6, 353971.9 6689664.5 24.6, 353961.7 6689671.6 24.6, 353963.9 6689674.8 24.6, 353970.1 6689683.3 24.6))
BATIMENT0000000302928857;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;7.6;14.7;20.2;8.3;Cadastre;;POLYGON Z ((354004 6689674.8 14.7, 354001.2 6689676.7 14.7, 354004.4 6689681.3 14.7, 354004.5 6689681.6 14.7, 354005.3 6689680.7 14.7, 354007.2 6689679.4 14.7, 354004 6689674.8 14.7))
BATIMENT0000000302905911;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;10.4;7.8;18.2;24.9;8.4;Cadastre;B 0.3;POLYGON Z ((353998.3 6689678.7 18.2, 354001.6 6689683.5 18.2, 354004.4 6689681.3 18.2, 354001.2 6689676.7 18.2, 353998.3 6689678.7 18.2))
BATIMENT0000000302902912;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;8.9;8.2;17.1;22.2;9.5;Cadastre;C 0.8;POLYGON Z ((353970.1 6689683.3 17.1, 353975.2 6689690.6 17.1, 353984.2 6689684.2 17.1, 353983.6 6689683.3 17.1, 353979.1 6689677 17.1, 353970.1 6689683.3 17.1))
BATIMENT0000000302904722;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;9.3;19.2;22.7;10.1;Cadastre;C 0.8;POLYGON Z ((353951 6689693.8 19.2, 353952.2 6689695.6 19.2, 353961.7 6689688.7 19.2, 353958 6689683.6 19.2, 353956.7 6689684.6 19.2, 353951.4 6689688.4 19.2, 353950.7 6689688.8 19.2, 353948.6 6689690.3 19.2, 353951 6689693.8 19.2))
BATIMENT0000000302902915;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;8.4;12.0;13.7;9.0;Cadastre;;POLYGON Z ((353989.6 6689691.9 12, 353987.9 6689689.5 12, 353986.7 6689690.4 12, 353988.2 6689692.9 12, 353989.6 6689691.9 12))
BATIMENT0000000302902913;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;7.9;8.2;16.1;20.0;9.5;Cadastre;B 0.9;POLYGON Z ((353985 6689685.3 16.1, 353984.2 6689684.2 16.1, 353975.2 6689690.6 16.1, 353980.7 6689698.3 16.1, 353988.2 6689692.9 16.1, 353986.7 6689690.4 16.1, 353987.9 6689689.5 16.1, 353985 6689685.3 16.1))
BATIMENT0000000302928858;Industriel, agricole ou commercial;Annexe;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.8;7.4;13.3;19.5;8.1;Cadastre;C 0.2;POLYGON Z ((354010.9 6689688.7 13.3, 354016.9 6689696.9 13.3, 354022.7 6689705.3 13.3, 354026.5 6689710.6 13.3, 354028.6 6689708.9 13.3, 354007.2 6689679.4 13.3, 354005.3 6689680.7 13.3, 354010.9 6689688.7 13.3))
BATIMENT0000000302904723;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;5.6;9.3;15.0;19.1;10.6;Cadastre;A 0.6;POLYGON Z ((353955.1 6689700 15, 353964.6 6689692.9 15, 353961.7 6689688.7 15, 353952.2 6689695.6 15, 353949 6689698 15, 353952.1 6689702.3 15, 353955.1 6689700 15))
BATIMENT0000000302904724;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;9.0;16.1;17.5;9.7;Cadastre;;POLYGON Z ((353955.1 6689700 16.1, 353958 6689704.3 16.1, 353967.8 6689697.3 16.1, 353964.6 6689692.9 16.1, 353955.1 6689700 16.1))
BATIMENT0000000302902914;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;8.2;14.0;16.8;9.1;Cadastre;;POLYGON Z ((353988.2 6689692.9 14, 353980.7 6689698.3 14, 353986.2 6689706 14, 353992.8 6689701.3 14, 353994.2 6689700.2 14, 353992.7 6689698 14, 353993.1 6689697 14, 353989.6 6689691.9 14, 353988.2 6689692.9 14))
BATIMENT0000000302904725;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.9;9.2;16.2;17.9;10.6;Cadastre;A 1.0;POLYGON Z ((353952.1 6689702.3 16.2, 353946.6 6689706.4 16.2, 353949.5 6689710.4 16.2, 353958 6689704.3 16.2, 353955.1 6689700 16.2, 353952.1 6689702.3 16.2))
BATIMENT0000000302902918;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.9;8.2;14.1;16.7;9.0;Cadastre;A 1.0;POLYGON Z ((353986.2 6689706 14.1, 353992.2 6689714.4 14.1, 353998.7 6689709.8 14.1, 353992.8 6689701.3 14.1, 353986.2 6689706 14.1))
BATIMENT0000000302904939;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;2.0;10;20;7.2;9.9;17.1;;;Cadastre;A 1.0;POLYGON Z ((353956.5 6689710.4 17.1, 353960.1 6689715.4 17.1, 353973 6689706 17.1, 353969.5 6689701.1 17.1, 353956.5 6689710.4 17.1))
BATIMENT0000000302904940;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.0;9.9;16.9;;;Cadastre;C 0.8;POLYGON Z ((353960.1 6689715.4 16.9, 353962.8 6689719.3 16.9, 353966 6689716.8 16.9, 353966.4 6689717.1 16.9, 353976 6689710.3 16.9, 353973 6689706 16.9, 353960.1 6689715.4 16.9))
BATIMENT0000000302927334;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;8.1;13.0;14.2;8.5;Cadastre;;POLYGON Z ((354005.4 6689717.3 13, 354006.1 6689716.9 13, 354004.2 6689714.1 13, 354002.5 6689715 13, 354004.5 6689718 13, 354005.4 6689717.3 13))
BATIMENT0000000302902919;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;8.2;15.8;18.7;9.1;Cadastre;A 1.0;POLYGON Z ((353998.7 6689709.8 15.8, 353992.2 6689714.4 15.8, 353998 6689722.6 15.8, 354004.5 6689718 15.8, 354002.5 6689715 15.8, 353998.7 6689709.8 15.8))
BATIMENT0000000302902920;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;10;8.5;8.2;16.7;19.7;8.8;Cadastre;A 1.0;POLYGON Z ((354004.5 6689718 16.7, 353998 6689722.6 16.7, 354002 6689728.2 16.7, 354005.8 6689725.5 16.7, 354009.5 6689723 16.7, 354005.4 6689717.3 16.7, 354004.5 6689718 16.7))
BATIMENT0000000302905770;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;3.8;9.4;13.2;;;Cadastre;C 0.5;POLYGON Z ((353985.6 6689725.3 13.2, 353986 6689723 13.2, 353984.6 6689721 13.2, 353982.6 6689720.8 13.2, 353980.7 6689722.2 13.2, 353980.4 6689724.1 13.2, 353981.1 6689725 13.2, 353978.6 6689726.9 13.2, 353980.6 6689729.7 13.2, 353985.6 6689725.3 13.2))
BATIMENT0000000302927333;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;50;20;13.0;8.2;21.2;23.5;8.6;Cadastre;A 1.0;POLYGON Z ((354009.5 6689723 21.2, 354005.8 6689725.5 21.2, 354012.3 6689734.7 21.2, 354019.9 6689729.3 21.2, 354013.4 6689720.4 21.2, 354009.5 6689723 21.2))
BATIMENT0000000302906050;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.6;12.8;18.5;23.4;14.4;Cadastre;;POLYGON Z ((353916 6689706.7 18.5, 353913.5 6689709 18.5, 353917.5 6689713 18.5, 353920.2 6689711 18.5, 353916 6689706.7 18.5))
BATIMENT0000000291500093;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;1900-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;1.0;50;20;4.4;11.0;;24.7;13.2;Imagerie aérienne;C 0.4;POLYGON Z ((353929.1 6689705.2 14.9, 353921.7 6689710.7 14.9, 353924.6 6689715 15.4, 353932.8 6689709.1 15, 353929.1 6689705.2 14.9))
BATIMENT0000000302904726;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.6;9.5;15.2;17.7;11.3;Cadastre;A 1.0;POLYGON Z ((353942.3 6689709.5 15.2, 353944.6 6689712.6 15.2, 353942.7 6689713.9 15.2, 353944.2 6689715.7 15.2, 353946 6689714.4 15.2, 353946.6 6689715.2 15.2, 353948.6 6689713.9 15.2, 353947.2 6689712.1 15.2, 353949.5 6689710.4 15.2, 353946.6 6689706.4 15.2, 353942.3 6689709.5 15.2))
BATIMENT0000000302904727;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;10.7;13.0;14.2;11.3;Cadastre;;POLYGON Z ((353941.3 6689714.9 13, 353942.8 6689716.7 13, 353944.2 6689715.7 13, 353942.7 6689713.9 13, 353941.3 6689714.9 13))
BATIMENT0000000302903002;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;11.9;16.0;16.5;13.3;Cadastre;;POLYGON Z ((353923.6 6689719.3 16, 353925.5 6689721.3 16, 353927.7 6689719.7 16, 353928.2 6689719.3 16, 353926.4 6689717.1 16, 353923.6 6689719.3 16))
BATIMENT0000000302903015;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;14.8;17.8;21.2;15.0;Cadastre;;POLYGON Z ((353895.2 6689724.2 17.8, 353898.1 6689721.9 17.8, 353896.9 6689720.6 17.8, 353894 6689723.1 17.8, 353895.2 6689724.2 17.8))
BATIMENT0000000302903001;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;11.9;16.0;16.1;12.9;Cadastre;;POLYGON Z ((353925.5 6689721.3 16, 353930.3 6689726.6 16, 353932.3 6689725.1 16, 353927.7 6689719.7 16, 353925.5 6689721.3 16))
BATIMENT0000000302903014;Indifférenciée;Annexe;;Oui;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;09;3.5;15.4;18.9;25.0;16.0;Cadastre;C 0.4;POLYGON Z ((353894 6689723.1 18.9, 353896.9 6689720.6 18.9, 353894.1 6689717.6 18.9, 353892.0022898072 6689719.555492552 18.9, 353892.0022898072 6689724.844835484 18.9, 353894 6689723.1 18.9))
BATIMENT0000000302903003;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;11.6;14.5;15.6;12.3;Cadastre;;POLYGON Z ((353932.3 6689725.1 14.5, 353930.3 6689726.6 14.5, 353936.1 6689732.9 14.5, 353938.4 6689731.3 14.5, 353932.3 6689725.1 14.5))
BATIMENT0000000302903008;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;11.5;14.8;15.6;12.4;Cadastre;;POLYGON Z ((353940.7 6689733.8 14.8, 353938.4 6689731.3 14.8, 353936.1 6689732.9 14.8, 353938.7 6689735.8 14.8, 353940.7 6689733.8 14.8))
BATIMENT0000000302905769;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;9.0;12.9;15.5;9.5;Cadastre;;POLYGON Z ((353977.2 6689725.1 12.9, 353972.7 6689728.9 12.9, 353976.6 6689733.3 12.9, 353980.6 6689729.7 12.9, 353978.6 6689726.9 12.9, 353977.2 6689725.1 12.9))
BATIMENT0000000302905771;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;50;10;10.2;10.0;20.2;22.1;10.6;Cadastre;A 1.0;POLYGON Z ((353967 6689727 20.2, 353966.3 6689726.4 20.2, 353959.1 6689733 20.2, 353966.8 6689742.1 20.2, 353976.6 6689733.3 20.2, 353972.7 6689728.9 20.2, 353969.1 6689725.1 20.2, 353967 6689727 20.2))
BATIMENT0000000302904638;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.4;7.1;12.5;17.6;9.5;Cadastre;A 1.0;POLYGON Z ((353985.3 6689738.8 12.5, 353990.6 6689745.7 12.5, 353994.9 6689741.9 12.5, 353997.8 6689746.3 12.5, 354000.9 6689743.9 12.5, 353993.5 6689733.6 12.5, 353991.3 6689733.5 12.5, 353985.3 6689738.8 12.5))
BATIMENT0000000302904637;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.7;9.0;14.7;17.2;9.6;Cadastre;A 1.0;POLYGON Z ((353977.7 6689745.7 14.7, 353983.5 6689751.9 14.7, 353990.6 6689745.7 14.7, 353985.3 6689738.8 14.7, 353977.7 6689745.7 14.7))
BATIMENT0000000302904636;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;7.7;9.2;17.0;19.2;9.7;Cadastre;A 1.0;POLYGON Z ((353974.5 6689748.5 17, 353979.9 6689755.1 17, 353983.5 6689751.9 17, 353977.7 6689745.7 17, 353974.5 6689748.5 17))
BATIMENT0000000302904639;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;20;5.2;7.0;12.2;16.1;9.6;Cadastre;A 1.0;POLYGON Z ((353999.7 6689757.3 12.2, 354006.8 6689752.1 12.2, 354000.9 6689743.9 12.2, 353997.8 6689746.3 12.2, 353993.5 6689749.5 12.2, 353991 6689751.3 12.2, 353991.9 6689752.7 12.2, 353993.4 6689754.8 12.2, 353994.6 6689753.9 12.2, 353993.8 6689752.8 12.2, 353995.5 6689751.5 12.2, 353996.3 6689752.8 12.2, 353999.7 6689757.3 12.2))
BATIMENT0000000302904640;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;7.0;11.9;14.6;9.2;Cadastre;;POLYGON Z ((353996.3 6689752.8 11.9, 353995.5 6689751.5 11.9, 353993.8 6689752.8 11.9, 353994.6 6689753.9 11.9, 353996.3 6689752.8 11.9))
BATIMENT0000000302904635;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;8.0;8.5;16.5;19.4;9.9;Cadastre;A 1.0;POLYGON Z ((353969.8 6689752.7 16.5, 353975.6 6689758.8 16.5, 353977.1 6689760.4 16.5, 353978.3 6689759.4 16.5, 353976.9 6689757.7 16.5, 353978.3 6689756.5 16.5, 353979.7 6689758.1 16.5, 353981.3 6689756.7 16.5, 353979.9 6689755.1 16.5, 353974.5 6689748.5 16.5, 353969.8 6689752.7 16.5))
BATIMENT0000000302904641;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;5.3;7.0;12.3;15.7;8.7;Cadastre;A 1.0;POLYGON Z ((353999.7 6689757.3 12.3, 353995.7 6689760.2 12.3, 353998 6689763.3 12.3, 353999.9 6689762 12.3, 354001.6 6689764.3 12.3, 354004 6689762.6 12.3, 354004 6689762.3 12.3, 354010.4 6689757.1 12.3, 354006.8 6689752.1 12.3, 353999.7 6689757.3 12.3))
BATIMENT0000000302904634;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;7.2;8.2;15.4;17.7;10.3;Cadastre;A 1.0;POLYGON Z ((353962.3 6689759.5 15.4, 353967.9 6689765.7 15.4, 353975.6 6689758.8 15.4, 353969.8 6689752.7 15.4, 353962.3 6689759.5 15.4))
BATIMENT0000000302903013;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;50;20;11.4;14.7;26.2;28.0;15.7;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6689734.939069772 26.2, 353892.0022898072 6689741.463657157 26.2, 353893.1 6689742.8 26.2, 353896.2 6689739.9 26.2, 353892.0022898072 6689734.939069772 26.2))
BATIMENT0000000302903007;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;11.1;14.7;18.0;12.6;Cadastre;;POLYGON Z ((353942.2 6689739.8 14.7, 353944.2 6689741.8 14.7, 353948.1 6689738.3 14.7, 353943.9 6689734.4 14.7, 353940.2 6689737.6 14.7, 353942.2 6689739.8 14.7))
BATIMENT0000000302903012;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;14.8;23.2;26.1;15.2;Cadastre;;POLYGON Z ((353892.0022898072 6689741.463657157 23.2, 353892.0022898072 6689743.767030408 23.2, 353893.1 6689742.8 23.2, 353892.0022898072 6689741.463657157 23.2))
BATIMENT0000000302903005;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1882-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;7.7;11.6;19.3;20.5;12.5;Cadastre;A 1.0;POLYGON Z ((353950.5 6689748.7 19.3, 353954.1 6689752.6 19.3, 353957.6 6689749.4 19.3, 353948.1 6689738.3 19.3, 353944.2 6689741.8 19.3, 353950.5 6689748.7 19.3))
BATIMENT0000000302903010;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1981-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;23;10.0;14.4;24.5;26.2;15.2;Cadastre;A 1.0;POLYGON Z ((353896.7 6689739.5 24.5, 353896.2 6689739.9 24.5, 353893.1 6689742.8 24.5, 353892.0022898072 6689743.767030408 24.5, 353892.0022898072 6689750.012026196 24.5, 353894.2 6689752.5 24.5, 353902.1 6689745.5 24.5, 353896.7 6689739.5 24.5))
BATIMENT0000000302903011;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;14.1;22.9;25.0;14.5;Cadastre;;POLYGON Z ((353913.7 6689755.6 22.9, 353914.9 6689754.5 22.9, 353908.8 6689747.5 22.9, 353907.5 6689748.7 22.9, 353913.7 6689755.6 22.9))
BATIMENT0000000302906065;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:42;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;11.0;4.0;00;00;9.7;11.6;;25.6;13.8;Imagerie aérienne;A 1.0;POLYGON Z ((353925.9 6689756.7 21.3, 353933 6689764.5 21.3, 353950.5 6689748.7 21.3, 353944.2 6689741.8 21.3, 353942.2 6689739.8 21.3, 353935.5 6689745.8 21.3, 353934.9 6689745.2 21.3, 353924.5 6689755.2 21.3, 353925.9 6689756.7 21.3))
BATIMENT0000000302903006;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.7;11.7;23.4;23.6;14.3;Cadastre;;POLYGON Z ((353921.3 6689760.9 23.4, 353925.9 6689756.7 23.4, 353924.5 6689755.2 23.4, 353919.9 6689759.3 23.4, 353921.3 6689760.9 23.4))
BATIMENT0000000302903009;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;00;00;12.1;11.8;23.9;26.1;14.7;Cadastre;A 1.0;POLYGON Z ((353914.9 6689775.5 23.9, 353917.5 6689778.5 23.9, 353931.7 6689765.6 23.9, 353933 6689764.5 23.9, 353925.9 6689756.7 23.9, 353921.3 6689760.9 23.9, 353919.9 6689759.3 23.9, 353919.1 6689759.2 23.9, 353914.9 6689754.5 23.9, 353913.7 6689755.6 23.9, 353907.5 6689748.7 23.9, 353903.5 6689744.2 23.9, 353902.1 6689745.5 23.9, 353894.2 6689752.5 23.9, 353914.9 6689775.5 23.9))
BATIMENT0000000302904100;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.5;13.3;19.8;22.4;15.9;Cadastre;B 0.7;POLYGON Z ((353893.5 6689783.2 19.8, 353895.5 6689781.2 19.8, 353895.7 6689781.1 19.8, 353902.2 6689775.2 19.8, 353901.3 6689774.2 19.8, 353892.0022898072 6689763.832641732 19.8, 353892.0022898072 6689781.535877564 19.8, 353893.5 6689783.2 19.8))
BATIMENT0000000302929120;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.4;9.0;18.5;26.2;9.7;Cadastre;;POLYGON Z ((354092.1 6689635.6 18.5, 354091.2 6689636.4 18.5, 354101.4 6689648.6 18.5, 354102.3 6689647.8 18.5, 354092.3 6689635.6 18.5, 354092.1 6689635.6 18.5))
BATIMENT0000000302929121;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;8.6;;;;Cadastre;;POLYGON Z ((354080.6 6689665.4 -1000, 354104.1 6689670.5 -1000, 354105.4 6689664.9 -1000, 354081.8 6689659.6 -1000, 354080.6 6689665.4 -1000))
BATIMENT0000000302928672;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;42.0;6.0;10;20;12.7;7.4;20.2;25.2;8.0;Cadastre;C 0.3;POLYGON Z ((354037.8 6689682.8 20.2, 354036.4 6689684 20.2, 354029.5 6689674.6 20.2, 354035.7 6689670.2 20.2, 354035.3 6689669.4 20.2, 354036.7 6689668.4 20.2, 354036.3 6689663.9 20.2, 354035.7 6689662.5 20.2, 354031 6689656.1 20.2, 354027.2 6689658.9 20.2, 354026.5 6689657.8 20.2, 354020.1 6689662.3 20.2, 354019.1 6689661.1 20.2, 354011.6 6689666.5 20.2, 354014 6689669.9 20.2, 354013.4 6689670.5 20.2, 354015.5 6689673.3 20.2, 354014.2 6689674.3 20.2, 354016.9 6689678.1 20.2, 354016.5 6689678.5 20.2, 354020.9 6689684.9 20.2, 354021.8 6689684.3 20.2, 354024.1 6689687.4 20.2, 354023.3 6689688 20.2, 354025.4 6689690.8 20.2, 354024.5 6689691.5 20.2, 354027.2 6689695.2 20.2, 354026.5 6689695.7 20.2, 354033.9 6689706.1 20.2, 354035.5 6689705 20.2, 354035.9 6689705.6 20.2, 354038.8 6689703.5 20.2, 354042.6 6689700.5 20.2, 354037.8 6689682.8 20.2))
BATIMENT0000000302928673;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;7.4;15.2;16.2;8.0;Cadastre;;POLYGON Z ((354039.9 6689704.9 15.2, 354043.2 6689702.5 15.2, 354042.6 6689700.5 15.2, 354038.8 6689703.5 15.2, 354039.9 6689704.9 15.2))
BATIMENT0000000302927335;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;41.0;7.0;00;00;17.9;7.8;25.7;27.6;8.9;Cadastre;A 1.0;POLYGON Z ((354019.9 6689729.3 25.7, 354012.3 6689734.7 25.7, 354008.5 6689737.3 25.7, 354031.3 6689769.4 25.7, 354038.4 6689764.3 25.7, 354036.3 6689761.1 25.7, 354039.5 6689758.9 25.7, 354037.8 6689756.3 25.7, 354039.1 6689755.3 25.7, 354035.9 6689750.5 25.7, 354040.3 6689747.3 25.7, 354038.6 6689744.9 25.7, 354043.7 6689741.3 25.7, 354037.1 6689731.9 25.7, 354027.7 6689738.6 25.7, 354021 6689728.6 25.7, 354019.9 6689729.3 25.7))
BATIMENT0000000302928446;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.4;9.2;19.6;20.7;9.7;Cadastre;;POLYGON Z ((354092.4 6689793.6 19.6, 354093.1 6689793.6 19.6, 354093.1 6689793.5 19.6, 354095.5 6689786.3 19.6, 354094.8 6689786 19.6, 354098.9 6689773.4 19.6, 354097.3 6689772.9 19.6, 354102.2 6689758.2 19.6, 354101.5 6689757.9 19.6, 354089.5 6689793.9 19.6, 354090.4 6689793.8 19.6, 354092.4 6689793.6 19.6))
BATIMENT0000000302928445;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.5;9.4;20.0;20.5;9.5;Cadastre;;POLYGON Z ((354101.9 6689792 20, 354103.2 6689793.2 20, 354104.7 6689792.5 20, 354105.9 6689788.8 20, 354103.3 6689787.9 20, 354103 6689788.8 20, 354101.9 6689792 20))
BATIMENT0000000359013663;Indifférenciée;Commercial et services;;Non;En service;2016-09-08 18:07:33;2019-07-01 11:16:55;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;9.5;10.0;19.5;;;Cadastre;C 0.6;POLYGON Z ((354078.1 6689827.3 19.5, 354088.7 6689822.6 19.5, 354097.1 6689818.4 19.5, 354095.7 6689815.7 19.5, 354110.7 6689808.2 19.5, 354110.3 6689807.2 19.5, 354124.9 6689800 19.5, 354125.7 6689797.1 19.5, 354105.9 6689788.8 19.5, 354104.7 6689792.5 19.5, 354103.2 6689793.2 19.5, 354100.2 6689794.7 19.5, 354099.5 6689794.4 19.5, 354097.2 6689793.9 19.5, 354094.5 6689793.5 19.5, 354093.1 6689793.5 19.5, 354093.1 6689793.6 19.5, 354092.4 6689793.6 19.5, 354090.4 6689793.8 19.5, 354089.5 6689793.9 19.5, 354088.3 6689794.1 19.5, 354086 6689794.9 19.5, 354083.8 6689795.9 19.5, 354081.8 6689796.9 19.5, 354079.5 6689798.7 19.5, 354076.7 6689801.3 19.5, 354075.4 6689803.2 19.5, 354074.1 6689805.4 19.5, 354073 6689807.8 19.5, 354069.3 6689809.5 19.5, 354078.1 6689827.3 19.5))
BATIMENT0000000302927370;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;12.1;20.4;28.0;15.8;Cadastre;;POLYGON Z ((354097.7 6689870.1 20.4, 354093.9 6689872 20.4, 354098.4 6689881.4 20.4, 354102.4 6689879.5 20.4, 354097.7 6689870.1 20.4))
BATIMENT0000000302927371;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;22.1;15.9;38.0;41.5;21.4;Cadastre;A 1.0;POLYGON Z ((354108.1 6689901.7 38, 354103.8 6689892.4 38, 354099.8 6689884.3 38, 354096.5 6689885.9 38, 354096.5 6689885.7 38, 354094.2 6689886.7 38, 354093.6 6689886.6 38, 354092.7 6689886.6 38, 354092.1 6689886.8 38, 354091.4 6689887.3 38, 354091 6689887.8 38, 354090.7 6689888.1 38, 354088.4 6689889.1 38, 354088.5 6689889.3 38, 354087.7 6689890.2 38, 354087.2 6689891.1 38, 354087.1 6689891.7 38, 354087 6689892.9 38, 354087.2 6689894.1 38, 354089.3 6689898.4 38, 354083.6 6689901.1 38, 354083.7 6689901.3 38, 354084.2 6689902.5 38, 354088.4 6689911.1 38, 354108.1 6689901.7 38))
BATIMENT0000000302904633;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;15;10;5.0;9.7;14.7;17.1;10.5;Cadastre;A 1.0;POLYGON Z ((353958.1 6689763.1 14.7, 353963.7 6689769.5 14.7, 353967.9 6689765.7 14.7, 353962.3 6689759.5 14.7, 353958.1 6689763.1 14.7))
BATIMENT0000000302927364;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;5.5;7.0;12.5;15.8;8.3;Cadastre;A 1.0;POLYGON Z ((354004 6689762.3 12.5, 354004 6689762.6 12.5, 354001.6 6689764.3 12.5, 354002.7 6689765.7 12.5, 354001.1 6689767 12.5, 354002.6 6689769.3 12.5, 354002 6689769.9 12.5, 354001.8 6689772 12.5, 354002.9 6689773.6 12.5, 354015.7 6689764.5 12.5, 354010.4 6689757.1 12.5, 354004 6689762.3 12.5))
BATIMENT0000000302904628;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.5;10.2;14.7;17.2;11.3;Cadastre;A 1.0;POLYGON Z ((353961.1 6689771.8 14.7, 353962.7 6689773.6 14.7, 353965.3 6689771.2 14.7, 353963.7 6689769.5 14.7, 353958.1 6689763.1 14.7, 353951.6 6689769 14.7, 353957.2 6689775.1 14.7, 353958.5 6689774.2 14.7, 353961.1 6689771.8 14.7))
BATIMENT0000000302927363;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;7.5;15.7;18.0;8.0;Cadastre;;POLYGON Z ((354017.8 6689767.4 15.7, 354015.8 6689769.1 15.7, 354018.4 6689772.7 15.7, 354020.5 6689771.2 15.7, 354017.8 6689767.4 15.7))
BATIMENT0000000302904632;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.0;10.6;14.7;17.2;11.7;Cadastre;A 1.0;POLYGON Z ((353954.8 6689781.3 14.7, 353959.2 6689777.5 14.7, 353957.2 6689775.1 14.7, 353951.6 6689769 14.7, 353947.9 6689772.3 14.7, 353947.9 6689773.4 14.7, 353954.8 6689781.3 14.7))
BATIMENT0000000302927362;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;11.5;5.6;17.1;20.6;7.9;Cadastre;C 0.3;POLYGON Z ((354009.8 6689773.7 17.1, 354015.1 6689781.4 17.1, 354019 6689778.6 17.1, 354020.6 6689781 17.1, 354025.1 6689777.7 17.1, 354020.5 6689771.2 17.1, 354018.4 6689772.7 17.1, 354015.8 6689769.1 17.1, 354009.8 6689773.7 17.1))
BATIMENT0000000302904696;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;8.1;12.7;13.5;9.9;Cadastre;;POLYGON Z ((353974.1 6689777.5 12.7, 353975 6689778.2 12.7, 353975.8 6689777.7 12.7, 353977.1 6689779 12.7, 353978.5 6689777.6 12.7, 353976.3 6689775 12.7, 353974.1 6689777.5 12.7))
BATIMENT0000000302904627;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;10.4;13.0;14.5;11.2;Cadastre;;POLYGON Z ((353959.2 6689777.5 13, 353964.9 6689783.8 13, 353966.1 6689782.7 13, 353958.5 6689774.2 13, 353957.2 6689775.1 13, 353959.2 6689777.5 13))
BATIMENT0000000302904699;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 17:38:43;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;9.3;11.9;;;Cadastre;;POLYGON Z ((353983.5 6689774.2 11.9, 353981.2 6689771.7 11.9, 353976.3 6689775 11.9, 353978.5 6689777.6 11.9, 353978.8 6689777.9 11.9, 353981.3 6689780.6 11.9, 353983.8 6689783.6 11.9, 353985.8 6689785.8 11.9, 353986.2 6689786.2 11.9, 353987.7 6689788 11.9, 353989.1 6689789.5 11.9, 353993.9 6689785.4 11.9, 353991.2 6689782.5 11.9, 353988.8 6689779.8 11.9, 353986.1 6689776.9 11.9, 353983.5 6689774.2 11.9))
BATIMENT0000000302904625;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;15;20;7.4;10.0;17.5;18.7;11.3;Cadastre;A 1.0;POLYGON Z ((353960.3 6689787.6 17.5, 353965.2 6689793.3 17.5, 353971.9 6689787.4 17.5, 353967.2 6689781.7 17.5, 353966.1 6689782.7 17.5, 353964.9 6689783.8 17.5, 353960.3 6689787.6 17.5))
BATIMENT0000000302904102;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;14.0;22.1;22.3;14.7;Cadastre;;POLYGON Z ((353895.5 6689781.2 22.1, 353893.5 6689783.2 22.1, 353892.1 6689784.5 22.1, 353893.9 6689786.2 22.1, 353896.9 6689783.5 22.1, 353896.7 6689782.2 22.1, 353895.7 6689781.1 22.1, 353895.5 6689781.2 22.1))
BATIMENT0000000302904101;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;23;7.7;13.3;21.0;23.4;14.7;Cadastre;A 1.0;POLYGON Z ((353897.7 6689781.3 21, 353899.5 6689783.1 21, 353899.4 6689783.4 21, 353909.2 6689793.9 21, 353914.7 6689789.1 21, 353902.2 6689775.2 21, 353895.7 6689781.1 21, 353896.7 6689782.2 21, 353897.7 6689781.3 21))
BATIMENT0000000302904728;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;1.0;10;20;4.2;10.9;15.1;18.8;12.5;Cadastre;A 1.0;POLYGON Z ((353933.1 6689786.5 15.1, 353928.4 6689790.7 15.1, 353936.2 6689799.6 15.1, 353942.2 6689794.5 15.1, 353941.3 6689793.3 15.1, 353942.2 6689792.4 15.1, 353941.1 6689790.9 15.1, 353945 6689787.6 15.1, 353947.2 6689789.8 15.1, 353951.5 6689785.9 15.1, 353943.8 6689776.9 15.1, 353939.2 6689781.1 15.1, 353933.1 6689786.5 15.1))
BATIMENT0000000302902799;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;11.5;14.0;16.7;12.9;Cadastre;;POLYGON Z ((353923.1 6689792.6 14, 353920.8 6689794.6 14, 353925.7 6689800.4 14, 353928 6689798.3 14, 353923.1 6689792.6 14))
BATIMENT0000002275363040;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:32:42;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;11.0;13.9;;27.4;15.2;Imagerie aérienne;;POLYGON Z ((353895.8 6689788.5 24.8, 353892.0022898072 6689791.979192563 24.824501356081157, 353892.0022898072 6689808.534589924 23.426812990050717, 353909.2 6689793.9 22.6, 353908.7 6689793.4 22.6, 353899.4 6689783.4 22.6, 353899.5 6689783.1 22.6, 353897.7 6689781.3 22.6, 353896.7 6689782.2 22.6, 353896.9 6689783.5 22.6, 353893.9 6689786.2 22.6, 353895.8 6689788.5 24.8))
BATIMENT0000000302902797;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;50;90;10.5;10.8;21.3;24.0;13.5;Cadastre;B 1.0;POLYGON Z ((353926.4 6689801.1 21.3, 353925.7 6689800.4 21.3, 353920.8 6689794.6 21.3, 353903.9 6689809.7 21.3, 353905.2 6689811.2 21.3, 353909.3 6689815.9 21.3, 353926.4 6689801.1 21.3))
BATIMENT0000000302902800;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;1.3;9.7;11.1;13.3;11.2;Cadastre;A 1.0;POLYGON Z ((353933.1 6689804.3 11.1, 353931 6689806.1 11.1, 353935 6689810.7 11.1, 353937.1 6689808.8 11.1, 353933.1 6689804.3 11.1))
BATIMENT0000000302902795;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.8;9.4;12.2;16.7;11.9;Cadastre;B 0.4;POLYGON Z ((353913.8 6689821.1 12.2, 353917.3 6689825 12.2, 353921.8 6689821.2 12.2, 353927.5 6689816.6 12.2, 353935 6689810.7 12.2, 353931 6689806.1 12.2, 353913.4 6689820.6 12.2, 353913.8 6689821.1 12.2))
BATIMENT0000000302902801;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;4.8;9.3;14.1;17.1;10.6;Cadastre;A 1.0;POLYGON Z ((353927.5 6689816.6 14.1, 353929.5 6689819 14.1, 353931.4 6689817.6 14.1, 353937.4 6689824.7 14.1, 353941.2 6689821.7 14.1, 353942.7 6689820.2 14.1, 353935 6689810.7 14.1, 353927.5 6689816.6 14.1))
BATIMENT0000000302906115;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;14.7;11.6;26.4;27.5;14.3;Cadastre;C 0.6;POLYGON Z ((353913.8 6689821.1 26.4, 353913.4 6689820.6 26.4, 353909.3 6689815.9 26.4, 353905.2 6689811.2 26.4, 353892.0022898072 6689822.941411137 26.4, 353892.0022898072 6689825.688158301 26.4, 353898.9 6689834.1 26.4, 353913.8 6689821.1 26.4))
BATIMENT0000000302929002;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.5;22.2;30.7;33.0;23.4;Cadastre;A 1.0;POLYGON Z ((354228.6 6689603.8 30.7, 354236.2 6689604.5 30.7, 354236.9 6689597.7 30.7, 354236.8 6689596.5 30.7, 354229.4 6689595.8 30.7, 354228.6 6689603.8 30.7))
BATIMENT0000000302929119;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.8;23.4;28.2;28.7;25.8;Cadastre;;POLYGON Z ((354245.9 6689606.4 28.2, 354248.2 6689603 28.2, 354244.5 6689600.5 28.2, 354241.9 6689604.2 28.2, 354241.8 6689604.4 28.2, 354245.6 6689606.9 28.2, 354245.9 6689606.4 28.2))
BATIMENT0000000302929124;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.1;18.6;23.7;34.5;22.4;Cadastre;;POLYGON Z ((354203.2 6689603 23.7, 354206.8 6689605.4 23.7, 354215.3 6689611.6 23.7, 354215.9 6689609.8 23.7, 354216 6689609.3 23.7, 354204.3 6689600.8 23.7, 354203.2 6689603 23.7))
BATIMENT0000000302929125;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;19.1;;;;Cadastre;;POLYGON Z ((354215.3 6689611.6 -1000, 354217.6 6689613.3 -1000, 354226.5 6689617.9 -1000, 354226.7 6689615.4 -1000, 354215.9 6689609.8 -1000, 354215.3 6689611.6 -1000))
BATIMENT0000000302929123;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;21.3;;;;Cadastre;;POLYGON Z ((354227 6689618.2 -1000, 354235.7 6689622.7 -1000, 354237 6689620.6 -1000, 354229 6689616.1 -1000, 354227 6689618.2 -1000))
BATIMENT0000000302928909;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;15.6;19.2;20.5;16.7;Cadastre;;POLYGON Z ((354195 6689629.9 19.2, 354198.2 6689623.7 19.2, 354197.2 6689623.4 19.2, 354195 6689629.9 19.2))
BATIMENT0000000302928910;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;24;10;6.6;14.6;21.2;25.7;16.7;Cadastre;A 1.0;POLYGON Z ((354194.1 6689622.4 21.2, 354194.3 6689622 21.2, 354193.4 6689620.3 21.2, 354191.1 6689619.6 21.2, 354189.5 6689620.4 21.2, 354189.4 6689621 21.2, 354186.2 6689620 21.2, 354183.1 6689630.6 21.2, 354184 6689632.3 21.2, 354192.3 6689635 21.2, 354194 6689630.2 21.2, 354194.7 6689630.4 21.2, 354195 6689629.9 21.2, 354197.2 6689623.4 21.2, 354194.1 6689622.4 21.2))
BATIMENT0000002275362720;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;13.1;19.9;;41.8;26.0;Imagerie aérienne;;POLYGON Z ((354246.9 6689635.7 33, 354215.2 6689635.1 33, 354215.5 6689658.8 33, 354247.1 6689658.6 33, 354246.9 6689635.7 33))
BATIMENT0000000302928956;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;7.0;35;90;22.6;19.5;42.2;43.6;23.2;Cadastre;C 0.8;POLYGON Z ((354201.3 6689710.3 42.2, 354206.9 6689721.8 42.2, 354205.7 6689722.4 42.2, 354207.6 6689726.5 42.2, 354208.4 6689726 42.2, 354212.4 6689734.4 42.2, 354226 6689728 42.2, 354214.7 6689703.8 42.2, 354201.3 6689710.3 42.2))
BATIMENT0000000302928845;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;7.0;35;90;17.4;19.5;37.0;39.7;24.7;Cadastre;C 0.1;POLYGON Z ((354191 6689750.1 37, 354197.8 6689764.6 37, 354194.2 6689766.3 37, 354196.4 6689770.9 37, 354224.3 6689757.7 37, 354222.2 6689753.2 37, 354216 6689756.1 37, 354208.8 6689741.9 37, 354191 6689750.1 37))
BATIMENT0000000302928864;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.1;10.1;17.2;20.6;10.7;Cadastre;A 1.0;POLYGON Z ((354117.8 6689649.1 17.2, 354127.3 6689652.4 17.2, 354130.5 6689643.6 17.2, 354121.1 6689640.2 17.2, 354117.8 6689649.1 17.2))
BATIMENT0000000302929117;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;4.2;9.1;13.3;20.7;9.9;Cadastre;C 0.4;POLYGON Z ((354107.8 6689650.2 13.3, 354110.8 6689651.1 13.3, 354113.4 6689643.7 13.3, 354110.5 6689642.8 13.3, 354107.8 6689650.2 13.3))
BATIMENT0000000302928863;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;12;9.2;10.7;20.0;21.9;12.8;Cadastre;A 1.0;POLYGON Z ((354145.8 6689647.7 20, 354142.7 6689646.7 20, 354142.2 6689648 20, 354139.1 6689656.5 20, 354141.9 6689657.5 20, 354143.6 6689653.2 20, 354154.1 6689657 20, 354156.1 6689651.4 20, 354157.8 6689646.7 20, 354147.6 6689643 20, 354145.8 6689647.7 20))
BATIMENT0000000302928862;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;10.0;9.7;19.7;22.5;11.3;Cadastre;A 1.0;POLYGON Z ((354127.3 6689652.4 19.7, 354133.2 6689654.6 19.7, 354133.1 6689655.4 19.7, 354138.8 6689657.6 19.7, 354139.1 6689656.5 19.7, 354142.2 6689648 19.7, 354130.5 6689643.6 19.7, 354127.3 6689652.4 19.7))
BATIMENT0000000302928865;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.7;11.2;20.0;21.6;13.5;Cadastre;C 0.7;POLYGON Z ((354154.1 6689657 20, 354153.5 6689658.4 20, 354163 6689661.6 20, 354165.4 6689654.9 20, 354156.1 6689651.4 20, 354154.1 6689657 20))
BATIMENT0000000302929122;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;15.1;9.1;24.2;28.7;9.3;Cadastre;;POLYGON Z ((354106.5 6689663.3 24.2, 354111.6 6689664.6 24.2, 354112.6 6689661.9 24.2, 354107.4 6689660.5 24.2, 354106.5 6689663.3 24.2))
BATIMENT0000000302928683;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;5.0;11.7;16.7;21.1;14.0;Cadastre;C 0.3;POLYGON Z ((354154.7 6689674.5 16.7, 354160.6 6689675.8 16.7, 354161.6 6689673 16.7, 354162 6689672.1 16.7, 354156.1 6689670 16.7, 354154.7 6689674.5 16.7))
BATIMENT0000000302928833;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;50;20;7.5;14.1;21.7;27.1;17.7;Cadastre;A 1.0;POLYGON Z ((354175.5 6689666.9 21.7, 354170.5 6689676.4 21.7, 354175.3 6689680.5 21.7, 354176.9 6689678.9 21.7, 354179.5 6689681.3 21.7, 354180.2 6689680.4 21.7, 354181.4 6689681.5 21.7, 354182.9 6689679.8 21.7, 354185.1 6689681.9 21.7, 354191.3 6689675.1 21.7, 354178.4 6689663.9 21.7, 354175.5 6689666.9 21.7))
BATIMENT0000000302929136;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;11.0;9.7;20.7;24.5;12.5;Cadastre;;POLYGON Z ((354154.2 6689682.5 20.7, 354156.6 6689682.8 20.7, 354157.5 6689678.6 20.7, 354155.1 6689678 20.7, 354154.2 6689682.5 20.7))
BATIMENT0000000302928450;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.5;9.3;18.9;20.0;9.6;Cadastre;;POLYGON Z ((354117.2 6689748.8 18.9, 354119.3 6689749.5 18.9, 354119.5 6689749.1 18.9, 354120.3 6689749.2 18.9, 354120.8 6689749.1 18.9, 354122.3 6689748.7 18.9, 354123.8 6689748.2 18.9, 354124.4 6689747.6 18.9, 354124.6 6689747.2 18.9, 354124.6 6689746.8 18.9, 354124.5 6689746.3 18.9, 354124.4 6689745.9 18.9, 354124.1 6689745.6 18.9, 354123.8 6689745.4 18.9, 354123.3 6689745.2 18.9, 354122.8 6689745.2 18.9, 354121.3 6689745.7 18.9, 354120.3 6689746 18.9, 354119.8 6689746.2 18.9, 354119.3 6689746.6 18.9, 354118.8 6689747.1 18.9, 354117.9 6689746.8 18.9, 354117.2 6689748.8 18.9))
BATIMENT0000000302928560;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;29.5;46.4;46.7;29.7;Cadastre;;POLYGON Z ((354327.2 6689619.6 46.4, 354338.2 6689624.2 46.4, 354339.1 6689622.1 46.4, 354328.1 6689617.5 46.4, 354327.2 6689619.6 46.4))
BATIMENT0000000302929127;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.7;28.3;30.0;30.2;28.9;Cadastre;;POLYGON Z ((354288.3 6689626.5 30, 354288.7 6689625.5 30, 354283 6689623.2 30, 354282.6 6689624.1 30, 354288.3 6689626.5 30))
BATIMENT0000000302929128;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.1;28.7;29.9;30.2;29.0;Cadastre;;POLYGON Z ((354304.6 6689633.3 29.9, 354304.9 6689632.3 29.9, 354299.4 6689630 29.9, 354299 6689631 29.9, 354304.6 6689633.3 29.9))
BATIMENT0000002275363036;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;2023-01-31 17:40:56;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;17.8;24.5;;44.2;30.6;Imagerie aérienne;;POLYGON Z ((354328 6689650.7 42.3, 354328.3 6689649.4 41.9, 354264.4 6689632.3 40.1, 354265.7 6689627.5 39, 354253.8 6689624.3 39, 354248.8 6689641.6 38.9, 354260.7 6689644.8 38.9, 354260.4 6689646.6 38.9, 354259.9 6689648.7 36.9, 354282.7 6689655.2 38.8, 354322.4 6689665.7 40, 354329.5 6689667.7 35.2, 354331 6689667.3 35.2, 354334 6689667.8 35.2, 354335.2 6689660.8 35.2, 354358.3 6689664.7 35.2, 354359.8 6689659.2 35.3, 354328 6689650.7 42.3))
BATIMENT0000000302929141;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.5;28.1;36.6;44.9;29.5;Cadastre;;POLYGON Z ((354289.5 6689737.9 36.6, 354291.8 6689742.4 36.6, 354292.3 6689743.5 36.6, 354304.3 6689737.6 36.6, 354301.4 6689731.8 36.6, 354289.5 6689737.9 36.6))
BATIMENT0000000302928637;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;29.2;34.0;41.5;30.3;Cadastre;;POLYGON Z ((354320.5 6689753 34, 354325.1 6689756.2 34, 354342.3 6689748.2 34, 354340.2 6689743.7 34, 354336.6 6689742.6 34, 354337.3 6689740.2 34, 354334.8 6689739.3 34, 354332 6689734.1 34, 354327.4 6689732.6 34, 354313.7 6689739.7 34, 354320.5 6689753 34))
BATIMENT0000000029198921;Industriel, agricole ou commercial;Annexe;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1958-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;00;00;6.2;27.4;;37.5;29.7;Imagerie aérienne;C 0.3;POLYGON Z ((354311.5 6689737.3 31.6, 354306.8 6689739.3 31.5, 354313.5 6689755.3 31.2, 354318.2 6689753.2 31.2, 354312.9 6689740.8 33.6, 354311.5 6689737.3 31.6))
BATIMENT0000000029198350;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.7;26.5;;40.7;28.8;Imagerie aérienne;;POLYGON Z ((354293.2 6689747.5 31, 354301.2 6689763.7 31.2, 354302.5 6689766.3 31.2, 354309.1 6689763 30.9, 354299.8 6689744.2 30.8, 354293.2 6689747.5 31))
BATIMENT0000000302929140;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.8;27.6;30.5;35.0;28.2;Cadastre;;POLYGON Z ((354297.9 6689765.3 30.5, 354299.1 6689767.9 30.5, 354302.5 6689766.3 30.5, 354301.2 6689763.7 30.5, 354297.9 6689765.3 30.5))
BATIMENT0000000302929079;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;23;8.0;25.8;33.8;37.4;26.6;Cadastre;A 1.0;POLYGON Z ((354263.8 6689770.8 33.8, 354268.6 6689781.2 33.8, 354277.6 6689777 33.8, 354272.5 6689766.6 33.8, 354263.8 6689770.8 33.8))
BATIMENT0000000302928844;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;7.0;35;90;20.8;23.3;44.1;45.5;24.7;Cadastre;C 0.7;POLYGON Z ((354223.3 6689752.6 44.1, 354226.6 6689759.7 44.1, 354224.4 6689760.7 44.1, 354226.1 6689764.2 44.1, 354228.5 6689763.2 44.1, 354231.5 6689769.4 44.1, 354229.9 6689770.2 44.1, 354230.4 6689771.4 44.1, 354235.2 6689769.2 44.1, 354244.5 6689764.8 44.1, 354235.9 6689746.6 44.1, 354223.3 6689752.6 44.1))
BATIMENT0000000302929080;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1857-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.5;26.2;33.7;37.6;27.1;Cadastre;A 1.0;POLYGON Z ((354255 6689752.9 33.7, 354257.4 6689757.6 33.7, 354263.8 6689770.8 33.7, 354272.5 6689766.6 33.7, 354273.7 6689766 33.7, 354269.3 6689757 33.7, 354270.6 6689756.4 33.7, 354268.8 6689752.3 33.7, 354268.4 6689751.4 33.7, 354262.5 6689754.2 33.7, 354261.2 6689751.6 33.7, 354257.7 6689751.3 33.7, 354254.9 6689752.7 33.7, 354255 6689752.9 33.7))
BATIMENT0000000302928846;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;15;20;9.9;23.8;33.7;43.7;25.2;Cadastre;A 1.0;POLYGON Z ((354244.5 6689764.8 33.7, 354235.2 6689769.2 33.7, 354238.6 6689776.6 33.7, 354239.1 6689776.3 33.7, 354245.5 6689773.2 33.7, 354252.6 6689769.9 33.7, 354248.9 6689762.6 33.7, 354244.5 6689764.8 33.7))
BATIMENT0000000302928848;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;20.5;26.0;28.7;23.3;Cadastre;;POLYGON Z ((354199.1 6689776.4 26, 354201.2 6689781.1 26, 354224.5 6689769.8 26, 354222.2 6689765.2 26, 354199.1 6689776.4 26))
BATIMENT0000000302928847;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;10.8;24.5;35.3;38.9;25.6;Cadastre;A 1.0;POLYGON Z ((354245.5 6689773.2 35.3, 354239.1 6689776.3 35.3, 354247.2 6689793.1 35.3, 354254.1 6689789.9 35.3, 354260.6 6689786.7 35.3, 354252.6 6689769.9 35.3, 354245.5 6689773.2 35.3))
BATIMENT0000000302928410;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;13;20;3.6;25.6;29.3;46.4;26.9;Cadastre;A 1.0;POLYGON Z ((354254.6 6689798.8 29.3, 354256.6 6689803 29.3, 354253.5 6689804.6 29.3, 354256.9 6689811.9 29.3, 354264.9 6689828.1 29.3, 354274.6 6689823.5 29.3, 354276.2 6689817.7 29.3, 354264.6 6689793.9 29.3, 354254.6 6689798.8 29.3))
BATIMENT0000000291501496;Indifférenciée;Annexe;;Non;En service;2011-11-16 11:33:40;2019-03-15 08:35:34;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;2.5;24.4;;33.0;24.7;Imagerie aérienne;B 0.2;POLYGON Z ((354212.9 6689812.7 26.9, 354220 6689809.4 26.9, 354218 6689806.5 26.9, 354206.4 6689812 26.9, 354209.8 6689817.4 26.9, 354213.9 6689815.6 26.9, 354212.9 6689812.7 26.9))
BATIMENT0000000302928408;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;20;10;18.4;25.3;43.7;47.3;26.7;Cadastre;A 1.0;POLYGON Z ((354243.9 6689818.1 43.7, 354228.7 6689825.2 43.7, 354232.2 6689832.7 43.7, 354236.3 6689841.5 43.7, 354251.6 6689834.2 43.7, 354264.9 6689828.1 43.7, 354256.9 6689811.9 43.7, 354243.9 6689818.1 43.7))
BATIMENT0000000302928453;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.5;23.5;34.0;36.3;24.7;Cadastre;C 0.6;POLYGON Z ((354199.4 6689829.5 34, 354201.6 6689834.1 34, 354197.5 6689836.1 34, 354199 6689839.2 34, 354200.3 6689841.8 34, 354204.1 6689840 34, 354204.6 6689841 34, 354209.1 6689839 34, 354208.5 6689837.8 34, 354214.6 6689834.9 34, 354209.5 6689824.8 34, 354199.4 6689829.5 34))
BATIMENT0000000302928409;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.4;25.5;34.9;;;Cadastre;;POLYGON Z ((354227.7 6689832 34.9, 354222.4 6689834.7 34.9, 354223.5 6689836.8 34.9, 354228.8 6689834.3 34.9, 354227.7 6689832 34.9))
BATIMENT0000000302929138;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;11.1;;;;Cadastre;;POLYGON Z ((354164.4 6689755.7 -1000, 354165.7 6689756.3 -1000, 354170.2 6689742.7 -1000, 354168.7 6689742.1 -1000, 354164.4 6689755.7 -1000))
BATIMENT0000000302929137;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;11.8;10.1;22.0;24.2;11.5;Cadastre;;POLYGON Z ((354161.9 6689761 22, 354163.5 6689761.7 22, 354165.2 6689758 22, 354163.5 6689757.3 22, 354161.9 6689761 22))
BATIMENT0000000302928448;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.1;9.3;19.4;20.4;9.7;Cadastre;A 0.1;POLYGON Z ((354119.3 6689749.5 19.4, 354117.2 6689748.8 19.4, 354117.9 6689746.8 19.4, 354118.2 6689745.8 19.4, 354109 6689742.8 19.4, 354108.5 6689744.4 19.4, 354106.9 6689743.9 19.4, 354102.2 6689758.2 19.4, 354097.3 6689772.9 19.4, 354098.9 6689773.4 19.4, 354094.8 6689786 19.4, 354095.5 6689786.3 19.4, 354103 6689788.8 19.4, 354103.3 6689787.9 19.4, 354105.9 6689788.8 19.4, 354119.3 6689749.5 19.4))
BATIMENT0000000302929092;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.5;10.0;18.5;30.5;14.2;Cadastre;;POLYGON Z ((354149 6689775.6 18.5, 354155.2 6689779.1 18.5, 354163.9 6689764.1 18.5, 354157.7 6689760.6 18.5, 354149 6689775.6 18.5))
BATIMENT0000000359024359;Indifférenciée;Sportif;;Non;En service;2016-09-09 09:45:11;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.5;10.0;19.5;;;Cadastre;;POLYGON Z ((354125.7 6689797.1 19.5, 354128.5 6689798.2 19.5, 354142.5 6689757.4 19.5, 354119.3 6689749.5 19.5, 354105.9 6689788.8 19.5, 354125.7 6689797.1 19.5))
BATIMENT0000000302929091;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;9.3;;;;Cadastre;;POLYGON Z ((354139.1 6689793.6 -1000, 354145.9 6689797.5 -1000, 354155.5 6689780.6 -1000, 354148.8 6689776.6 -1000, 354139.1 6689793.6 -1000))
BATIMENT0000000302928443;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;9.3;20.0;20.1;9.5;Cadastre;;POLYGON Z ((354124.9 6689800 20, 354128.5 6689798.2 20, 354125.7 6689797.1 20, 354124.9 6689800 20))
BATIMENT0000000302928449;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.4;9.5;29.0;38.0;23.3;Cadastre;C 0.2;POLYGON Z ((354142.2 6689854.3 29, 354141.6 6689854.6 29, 354137.1 6689856.8 29, 354119.3 6689865.3 29, 354116.7 6689859.9 29, 354123 6689856.7 29, 354103.1 6689815.4 29, 354097.1 6689818.4 29, 354088.7 6689822.6 29, 354109.4 6689865.5 29, 354105.3 6689867.6 29, 354108.2 6689873.6 29, 354112.4 6689871.6 29, 354117.1 6689881.2 29, 354133.8 6689873.2 29, 354134.4 6689874.5 29, 354131.9 6689875.7 29, 354134.2 6689880.2 29, 354136.7 6689879 29, 354134.7 6689875 29, 354135.4 6689874.7 29, 354135.8 6689875.5 29, 354139.4 6689873.6 29, 354139 6689872.8 29, 354139.7 6689872.4 29, 354139 6689870.5 29, 354147.4 6689866.4 29, 354147.7 6689866.7 29, 354149.8 6689865.7 29, 354150.2 6689866.5 29, 354155.9 6689863.6 29, 354156.5 6689864.6 29, 354175.1 6689855.4 29, 354175.9 6689855 29, 354175.4 6689854.1 29, 354180.9 6689851.4 29, 354179.5 6689848.1 29, 354177.4 6689844 29, 354171.7 6689846.7 29, 354164.8 6689832.7 29, 354138.1 6689845.9 29, 354139.5 6689848.7 29, 354142.2 6689854.3 29))
BATIMENT0000000302928451;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.3;10.8;25.1;36.1;21.3;Cadastre;;POLYGON Z ((354137.1 6689856.8 25.1, 354141.6 6689854.6 25.1, 354142.2 6689854.3 25.1, 354139.5 6689848.7 25.1, 354123 6689856.7 25.1, 354116.7 6689859.9 25.1, 354119.3 6689865.3 25.1, 354137.1 6689856.8 25.1))
BATIMENT0000000302928452;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;22.8;31.7;40.5;23.9;Cadastre;;POLYGON Z ((354179.6 6689864.8 31.7, 354177.3 6689866 31.7, 354178.3 6689868.2 31.7, 354180.9 6689867 31.7, 354180.1 6689865.4 31.7, 354180.3 6689864.9 31.7, 354182.2 6689863.8 31.7, 354178.9 6689856.6 31.7, 354182.5 6689854.8 31.7, 354180.9 6689851.4 31.7, 354175.4 6689854.1 31.7, 354175.9 6689855 31.7, 354175.1 6689855.4 31.7, 354179.6 6689864.8 31.7))
BATIMENT0000000302929081;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.6;25.5;35.2;37.9;27.4;Cadastre;A 1.0;POLYGON Z ((354273.1 6689790.6 35.2, 354274.2 6689793 35.2, 354282.1 6689789.2 35.2, 354280.9 6689786.8 35.2, 354282 6689786.3 35.2, 354277.6 6689777 35.2, 354268.6 6689781.2 35.2, 354273.1 6689790.6 35.2))
BATIMENT0000000302928633;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.1;27.8;35.9;38.4;28.9;Cadastre;A 1.0;POLYGON Z ((354330.3 6689783.6 35.9, 354328.9 6689783.2 35.9, 354326 6689784.5 35.9, 354325.1 6689786.3 35.9, 354315.9 6689790.8 35.9, 354314.1 6689790.5 35.9, 354310.7 6689792.1 35.9, 354309.8 6689793.7 35.9, 354308.4 6689794.4 35.9, 354308.7 6689795.1 35.9, 354309.6 6689797.2 35.9, 354312.7 6689804.1 35.9, 354337 6689792.5 35.9, 354332.8 6689782.5 35.9, 354330.3 6689783.6 35.9))
BATIMENT0000000302928631;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;27.7;35.3;40.3;28.7;Cadastre;A 1.0;POLYGON Z ((354299.5 6689799.5 35.3, 354303.6 6689808.4 35.3, 354312.7 6689804.1 35.3, 354309.6 6689797.2 35.3, 354308.7 6689795.1 35.3, 354299.5 6689799.5 35.3))
BATIMENT0000000302928632;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;15;20;9.2;26.6;35.9;40.1;28.3;Cadastre;A 1.0;POLYGON Z ((354282.2 6689806.3 35.9, 354287 6689816.2 35.9, 354303.6 6689808.4 35.9, 354299.5 6689799.5 35.9, 354299 6689798.3 35.9, 354282.2 6689806.3 35.9))
BATIMENT0000000302928403;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.9;28.9;37.8;42.4;30.1;Cadastre;C 0.9;POLYGON Z ((354328.6 6689812.5 37.8, 354333.4 6689822.7 37.8, 354336.3 6689821.4 37.8, 354336.6 6689821.9 37.8, 354348 6689816.6 37.8, 354346.9 6689814.2 37.8, 354342.9 6689805.8 37.8, 354328.6 6689812.5 37.8))
BATIMENT0000000029199551;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1974-01-01;;;;BDTopo;2.5;BDTopo;1.5;37.0;7.0;30;20;19.3;28.4;;52.0;29.2;Imagerie aérienne;A 1.0;POLYGON Z ((354320.4 6689818.5 44.8, 354287 6689834.2 44.7, 354288.7 6689836.3 47.7, 354279 6689840.2 35.3, 354283.9 6689849.8 35.3, 354326 6689831.9 42.6, 354320.4 6689818.5 44.8))
BATIMENT0000000302929142;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;6.3;28.8;35.2;39.7;29.7;Cadastre;C 0.3;POLYGON Z ((354334.5 6689852.4 35.2, 354333.5 6689857.7 35.2, 354335 6689861.2 35.2, 354339 6689859.2 35.2, 354338.6 6689858.2 35.2, 354341.5 6689856.7 35.2, 354339.4 6689851.8 35.2, 354336.9 6689850.9 35.2, 354334.5 6689852.4 35.2))
BATIMENT0000000302928922;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;27.6;33.8;36.2;28.1;Cadastre;;POLYGON Z ((354280.8 6689864.9 33.8, 354280.5 6689864.5 33.8, 354278.3 6689865.7 33.8, 354278.4 6689866 33.8, 354276.4 6689867 33.8, 354270.3 6689869.8 33.8, 354273.7 6689876.8 33.8, 354278.1 6689874.7 33.8, 354279.5 6689873.9 33.8, 354283.8 6689871.9 33.8, 354281.7 6689867.4 33.8, 354285.1 6689865.7 33.8, 354284.4 6689864.5 33.8, 354283.2 6689863.7 33.8, 354280.8 6689864.9 33.8))
BATIMENT0000000302928921;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;27.4;31.5;33.5;28.2;Cadastre;;POLYGON Z ((354273.7 6689876.8 31.5, 354275.6 6689880.7 31.5, 354280 6689878.6 31.5, 354278.1 6689874.7 31.5, 354273.7 6689876.8 31.5))
BATIMENT0000000302928393;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1826-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.4;28.3;38.8;41.6;29.5;Cadastre;A 1.0;POLYGON Z ((354334.8 6689874.8 38.8, 354334.3 6689874.2 38.8, 354323.4 6689879.4 38.8, 354328.2 6689889.4 38.8, 354343.1 6689882.2 38.8, 354338.7 6689873.4 38.8, 354338.5 6689873 38.8, 354334.8 6689874.8 38.8))
BATIMENT0000000302928407;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1884-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.9;25.6;34.5;44.0;25.6;Cadastre;B 0.9;POLYGON Z ((354228.8 6689834.3 34.5, 354223.5 6689836.8 34.5, 354227.8 6689845.7 34.5, 354236.3 6689841.5 34.5, 354232.2 6689832.7 34.5, 354228.8 6689834.3 34.5))
BATIMENT0000000302929139;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;04;3.8;24.4;28.3;30.0;25.2;Cadastre;C 0.5;POLYGON Z ((354216.6 6689841.9 28.3, 354219.6 6689847.8 28.3, 354223.5 6689845.9 28.3, 354220.5 6689839.9 28.3, 354216.6 6689841.9 28.3))
BATIMENT0000000302928955;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;;;10.6;27.1;37.7;43.0;27.9;Cadastre;C 0.6;POLYGON Z ((354257.6 6689846.7 37.7, 354261.6 6689854.7 37.7, 354264.1 6689853.5 37.7, 354266.1 6689857.4 37.7, 354268.3 6689861.8 37.7, 354270.6 6689862.5 37.7, 354274.4 6689860.7 37.7, 354271.6 6689854.5 37.7, 354278.5 6689851 37.7, 354273 6689839.4 37.7, 354257.6 6689846.7 37.7))
BATIMENT0000000029198795;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1970-01-01;;;;BDTopo;2.5;BDTopo;1.5;18.0;7.0;30;49;19.4;22.5;;47.3;24.7;Imagerie aérienne;C 0.6;POLYGON Z ((354206.2 6689854.9 41.9, 354200.3 6689841.8 41.1, 354199 6689839.2 41, 354179.5 6689848.1 40.7, 354180.9 6689851.4 40.8, 354182.5 6689854.7 41.1, 354186.9 6689864.1 41.9, 354206.2 6689854.9 41.9))
BATIMENT0000000302928954;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.2;25.6;34.9;38.2;27.0;Cadastre;C 0.3;POLYGON Z ((354242.5 6689853.9 34.9, 354243.9 6689856.8 34.9, 354243.5 6689856.9 34.9, 354244.8 6689859.7 34.9, 354246.8 6689858.9 34.9, 354250.1 6689865.5 34.9, 354255.5 6689862.8 34.9, 354255.8 6689863.2 34.9, 354260.2 6689861.1 34.9, 354258.3 6689856.9 34.9, 354258.6 6689856.5 34.9, 354261.8 6689855.1 34.9, 354261.6 6689854.7 34.9, 354257.6 6689846.7 34.9, 354242.5 6689853.9 34.9))
BATIMENT0000000302929038;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;25.6;30.7;34.2;26.3;Cadastre;;POLYGON Z ((354230 6689859.5 30.7, 354234.4 6689868.6 30.7, 354237.9 6689866.9 30.7, 354237.6 6689866.3 30.7, 354238.9 6689865.6 30.7, 354234.9 6689857.3 30.7, 354230 6689859.5 30.7))
BATIMENT0000000302928873;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;7.0;30;49;12.9;24.7;37.7;46.5;26.2;Cadastre;C 0.6;POLYGON Z ((354214.4 6689864.1 37.7, 354217.3 6689870.4 37.7, 354220.3 6689876.7 37.7, 354225.8 6689888 37.7, 354238.7 6689882.1 37.7, 354227.1 6689857.9 37.7, 354214.4 6689864.1 37.7))
BATIMENT0000000302928871;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;00;00;16.9;23.1;40.0;45.4;25.6;Cadastre;A 1.0;POLYGON Z ((354217.3 6689870.4 40, 354214.4 6689864.1 40, 354200.9 6689870.5 40, 354204.1 6689876.9 40, 354205.6 6689880.2 40, 354206.3 6689879.9 40, 354207.7 6689882.8 40, 354220.3 6689876.7 40, 354217.3 6689870.4 40))
BATIMENT0000000302928869;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;24;20;11.7;23.1;34.8;39.2;25.3;Cadastre;A 1.0;POLYGON Z ((354192.3 6689886.3 34.8, 354195.6 6689884.6 34.8, 354195.8 6689884.9 34.8, 354205.6 6689880.2 34.8, 354204.1 6689876.9 34.8, 354200.9 6689870.5 34.8, 354191.1 6689875.2 34.8, 354192.5 6689877.7 34.8, 354189.1 6689879.4 34.8, 354192.3 6689886.3 34.8))
BATIMENT0000000302928870;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.1;23.7;32.8;36.1;24.6;Cadastre;A 1.0;POLYGON Z ((354173.6 6689883.3 32.8, 354178.3 6689893.2 32.8, 354189.4 6689888.1 32.8, 354191.2 6689891.8 32.8, 354194.2 6689890.4 32.8, 354192.3 6689886.3 32.8, 354189.1 6689879.4 32.8, 354187.7 6689876.7 32.8, 354173.6 6689883.3 32.8))
BATIMENT0000000302928395;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;35;40;10.3;28.1;38.5;38.9;29.7;Cadastre;A 1.0;POLYGON Z ((354318.5 6689878.1 38.5, 354319.8 6689881.2 38.5, 354314.7 6689884 38.5, 354315.4 6689885.3 38.5, 354320 6689893.3 38.5, 354328.2 6689889.4 38.5, 354323.4 6689879.4 38.5, 354321.8 6689876.3 38.5, 354318.5 6689878.1 38.5))
BATIMENT0000000302928397;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;04;5.4;28.0;33.4;38.2;29.3;Cadastre;C 0.4;POLYGON Z ((354312.1 6689886.7 33.4, 354316.5 6689895 33.4, 354320 6689893.3 33.4, 354315.4 6689885.3 33.4, 354312.1 6689886.7 33.4))
BATIMENT0000000302928823;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;28.0;32.0;35.0;28.5;Cadastre;;POLYGON Z ((354291.9 6689892 32, 354281.8 6689896.7 32, 354282.4 6689898 32, 354283 6689899.4 32, 354293.2 6689894.6 32, 354291.9 6689892 32))
BATIMENT0000000302928828;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.6;28.3;34.9;38.9;28.5;Cadastre;C 0.7;POLYGON Z ((354293.9 6689896.1 34.9, 354297.8 6689903.8 34.9, 354313.9 6689896.2 34.9, 354309.7 6689888.2 34.9, 354293.9 6689896.1 34.9))
BATIMENT0000000302928824;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1921-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;8.2;27.6;35.9;37.6;28.4;Cadastre;A 1.0;POLYGON Z ((354287.6 6689908.6 35.9, 354297.8 6689903.8 35.9, 354293.9 6689896.1 35.9, 354293.2 6689894.6 35.9, 354283 6689899.4 35.9, 354287.6 6689908.6 35.9))
BATIMENT0000000302928419;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;23;8.7;29.0;37.7;41.1;29.4;Cadastre;A 1.0;POLYGON Z ((354329.7 6689898.9 37.7, 354332 6689909.5 37.7, 354340.7 6689907.3 37.7, 354341.4 6689909.9 37.7, 354344 6689909.3 37.7, 354343.3 6689905.4 37.7, 354341.1 6689893.4 37.7, 354329.7 6689898.9 37.7))
BATIMENT0000000302928418;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1868-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.7;29.0;38.7;41.4;29.4;Cadastre;A 1.0;POLYGON Z ((354320.5 6689903.1 38.7, 354322.7 6689913.2 38.7, 354332.3 6689911.1 38.7, 354332 6689909.5 38.7, 354329.7 6689898.9 38.7, 354320.5 6689903.1 38.7))
BATIMENT0000000302928821;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;5.2;28.3;33.5;37.0;28.4;Cadastre;A 1.0;POLYGON Z ((354275 6689901.3 33.5, 354274.6 6689900.9 33.5, 354268 6689904 33.5, 354269.2 6689906.5 33.5, 354273.6 6689915.3 33.5, 354287.6 6689908.6 33.5, 354283 6689899.4 33.5, 354282.4 6689898 33.5, 354275 6689901.3 33.5))
BATIMENT0000000302929045;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;28.0;33.0;34.2;29.1;Cadastre;;POLYGON Z ((354299.1 6689917 33, 354305.6 6689915.4 33, 354312.6 6689913.5 33, 354311.1 6689907.1 33, 354311.1 6689907 33, 354297.4 6689913.6 33, 354299.1 6689917 33))
BATIMENT0000000302929044;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;30;90;4.7;28.3;33.0;34.9;29.3;Cadastre;A 0.5;POLYGON Z ((354319.2 6689932.2 33, 354317.6 6689925.7 33, 354315.7 6689926.2 33, 354312.6 6689913.5 33, 354305.6 6689915.4 33, 354308.6 6689927.9 33, 354306.6 6689928.3 33, 354308.2 6689934.9 33, 354319.2 6689932.2 33))
BATIMENT0000000302928454;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:16:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;23.1;33.2;45.4;23.9;Cadastre;;POLYGON Z ((354186.9 6689864.1 33.2, 354182.5 6689854.8 33.2, 354178.9 6689856.6 33.2, 354182.2 6689863.8 33.2, 354180.3 6689864.9 33.2, 354180.1 6689865.4 33.2, 354180.9 6689867 33.2, 354186.9 6689864.1 33.2))
BATIMENT0000000302928872;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;8.2;23.0;31.2;38.2;24.3;Cadastre;A 1.0;POLYGON Z ((354176.3 6689896.5 31.2, 354179.2 6689895 31.2, 354178.3 6689893.2 31.2, 354173.6 6689883.3 31.2, 354170.8 6689884.7 31.2, 354176.3 6689896.5 31.2))
BATIMENT0000000302927369;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;14.9;23.2;29.5;22.2;Cadastre;;POLYGON Z ((354099.8 6689884.3 23.2, 354103.8 6689892.4 23.2, 354108.1 6689901.7 23.2, 354127.2 6689892.5 23.2, 354124.7 6689887.2 23.2, 354112.4 6689893.1 23.2, 354109.8 6689892.6 23.2, 354103.4 6689879.1 23.2, 354102.4 6689879.5 23.2, 354098.4 6689881.4 23.2, 354099.8 6689884.3 23.2))
BATIMENT0000000302928874;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;;;17.4;21.8;39.2;43.6;24.6;Cadastre;A 1.0;POLYGON Z ((354154.7 6689914.7 39.2, 354161.8 6689911.4 39.2, 354163.1 6689913.8 39.2, 354169.6 6689910.7 39.2, 354168.4 6689908.1 39.2, 354174.2 6689905.4 39.2, 354173.3 6689903.6 39.2, 354173.8 6689902.9 39.2, 354178.4 6689900.8 39.2, 354177.6 6689899 39.2, 354176.3 6689896.5 39.2, 354170.8 6689884.7 39.2, 354146 6689896.7 39.2, 354152 6689909.3 39.2, 354154.7 6689914.7 39.2))
BATIMENT0000000302928875;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;5.3;21.9;27.2;39.9;24.8;Cadastre;A 1.0;POLYGON Z ((354119.5 6689909.6 27.2, 354121 6689912.7 27.2, 354126.1 6689922.7 27.2, 354130.4 6689931.7 27.2, 354135.2 6689929.5 27.2, 354136.8 6689932.5 27.2, 354150.7 6689926.2 27.2, 354149.2 6689922.8 27.2, 354157 6689919.1 27.2, 354154.7 6689914.7 27.2, 354152 6689909.3 27.2, 354146 6689896.7 27.2, 354119.5 6689909.6 27.2))
BATIMENT0000000302929164;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDTopo;2.5;BDTopo;1.5;15.0;6.0;00;00;13.4;22.1;;42.3;24.5;Imagerie aérienne;A 1.0;POLYGON Z ((354101.6 6689934.4 35.5, 354126.1 6689922.7 35.5, 354121 6689912.7 35.5, 354096.9 6689924.5 35.5, 354101.6 6689934.4 35.5))
BATIMENT0000000302929149;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.7;23.2;33.0;36.7;24.1;Cadastre;;POLYGON Z ((354159.2 6689926.6 33, 354161 6689930.4 33, 354164.4 6689928.8 33, 354162.6 6689925.1 33, 354159.2 6689926.6 33))
BATIMENT0000000302929152;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;14.6;24.0;38.7;41.7;24.5;Cadastre;;POLYGON Z ((354135.6 6689942.5 38.7, 354136.6 6689944.5 38.7, 354141 6689942.3 38.7, 354140 6689940.4 38.7, 354135.6 6689942.5 38.7))
BATIMENT0000000302928827;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;25.8;34.0;39.0;26.4;Cadastre;A 1.0;POLYGON Z ((354191.2 6689954.5 34, 354186.8 6689945.5 34, 354186.3 6689944.5 34, 354181.6 6689946.6 34, 354179.8 6689945.9 34, 354177.1 6689947.2 34, 354176.6 6689948.8 34, 354171.6 6689951.1 34, 354171.9 6689951.7 34, 354171.6 6689951.9 34, 354176.4 6689961.5 34, 354191.2 6689954.5 34))
BATIMENT0000000302928829;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.3;25.7;33.0;35.7;26.4;Cadastre;A 1.0;POLYGON Z ((354176.4 6689961.5 33, 354171.6 6689951.9 33, 354165.2 6689954.9 33, 354169.7 6689964.7 33, 354176.4 6689961.5 33))
BATIMENT0000000302929041;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;25.9;29.6;32.8;27.0;Cadastre;;POLYGON Z ((354242.5 6689886.4 29.6, 354242.7 6689886.7 29.6, 354244.2 6689889.5 29.6, 354248.9 6689887.4 29.6, 354247.2 6689884 29.6, 354242.5 6689886.4 29.6))
BATIMENT0000000302929040;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;25.9;29.6;32.4;26.5;Cadastre;;POLYGON Z ((354241.1 6689891 29.6, 354242.6 6689890.3 29.6, 354244.2 6689889.5 29.6, 354242.7 6689886.7 29.6, 354239.6 6689888 29.6, 354241.1 6689891 29.6))
BATIMENT0000000302929042;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;05;20;3.6;26.1;29.7;30.7;26.2;Cadastre;C 0.3;POLYGON Z ((354230.6 6689892.4 29.7, 354228.8 6689891.4 29.7, 354226.2 6689892.7 29.7, 354226.8 6689894.1 29.7, 354228.2 6689897.1 29.7, 354237.6 6689892.6 29.7, 354241.1 6689891 29.7, 354239.6 6689888 29.7, 354236.2 6689889.4 29.7, 354234.3 6689888.4 29.7, 354230.9 6689889.9 29.7, 354230.6 6689892.4 29.7))
BATIMENT0000000302928943;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;23.8;32.2;34.8;24.8;Cadastre;;POLYGON Z ((354194.4 6689908.7 32.2, 354186.4 6689912.8 32.2, 354188 6689915.9 32.2, 354192.6 6689913.3 32.2, 354196.1 6689911.7 32.2, 354194.4 6689908.7 32.2))
BATIMENT0000000302928819;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.2;27.0;36.2;39.4;28.2;Cadastre;A 1.0;POLYGON Z ((354258.9 6689911.7 36.2, 354260.4 6689915 36.2, 354257.2 6689916.4 36.2, 354259.8 6689921.6 36.2, 354273.6 6689915.3 36.2, 354269.2 6689906.5 36.2, 354258.9 6689911.7 36.2))
BATIMENT0000000302928944;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.3;24.7;30.0;33.5;25.1;Cadastre;;POLYGON Z ((354199.9 6689919.7 30, 354196.1 6689911.7 30, 354192.6 6689913.3 30, 354196.4 6689921.2 30, 354199.9 6689919.7 30))
BATIMENT0000000302928945;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;5.3;24.5;29.8;31.7;25.1;Cadastre;B 0.3;POLYGON Z ((354188 6689915.9 29.8, 354191.9 6689924 29.8, 354196.6 6689921.7 29.8, 354196.4 6689921.2 29.8, 354192.6 6689913.3 29.8, 354188 6689915.9 29.8))
BATIMENT0000000302928820;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;34;20;6.5;26.6;33.1;37.7;27.3;Cadastre;A 1.0;POLYGON Z ((354248 6689919 33.1, 354247.5 6689918.1 33.1, 354243.9 6689919.8 33.1, 354243.2 6689918.6 33.1, 354231.7 6689924.2 33.1, 354232.6 6689926.1 33.1, 354228.8 6689927.7 33.1, 354232.2 6689934.9 33.1, 354259.8 6689921.6 33.1, 354257.2 6689916.4 33.1, 354256.4 6689914.8 33.1, 354248 6689919 33.1))
BATIMENT0000000302928822;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.7;26.0;35.7;37.7;26.7;Cadastre;A 1.0;POLYGON Z ((354220.9 6689929.8 35.7, 354225.1 6689938.4 35.7, 354232.2 6689934.9 35.7, 354228.8 6689927.7 35.7, 354228.1 6689926.3 35.7, 354220.9 6689929.8 35.7))
BATIMENT0000000302928411;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;12.1;26.8;39.0;42.7;28.8;Cadastre;A 1.0;POLYGON Z ((354272.4 6689930.2 39, 354268.4 6689928.2 39, 354258.8 6689932.8 39, 354262.2 6689939.9 39, 354265 6689938.6 39, 354266.9 6689939.4 39, 354267.9 6689942.5 39, 354269.8 6689942 39, 354270.8 6689945.2 39, 354276.3 6689943.6 39, 354272.4 6689930.2 39))
BATIMENT0000000302927785;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;6.3;31.8;38.2;40.2;32.3;Cadastre;A 1.0;POLYGON Z ((354430.9 6689869.4 38.2, 354424.4 6689870 38.2, 354424.9 6689877.7 38.2, 354431.6 6689877.2 38.2, 354430.9 6689869.4 38.2))
BATIMENT0000000302927789;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;6.9;32.0;39.0;40.9;32.3;Cadastre;A 1.0;POLYGON Z ((354425.6 6689885.5 39, 354432.2 6689884.9 39, 354431.6 6689877.2 39, 354424.9 6689877.7 39, 354425.6 6689885.5 39))
BATIMENT0000000302927769;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;31.0;35.0;35.5;31.8;Cadastre;;POLYGON Z ((354405.8 6689884.4 35, 354406.1 6689886.4 35, 354412.6 6689885.9 35, 354412.3 6689882.7 35, 354405.7 6689883.3 35, 354405.8 6689884.4 35))
BATIMENT0000000302927774;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.3;31.0;34.3;36.2;31.8;Cadastre;A 1.0;POLYGON Z ((354406.4 6689889.4 34.3, 354412.9 6689888.7 34.3, 354412.6 6689885.9 34.3, 354406.1 6689886.4 34.3, 354406.4 6689889.4 34.3))
BATIMENT0000000302927790;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;13;6.7;31.9;38.7;40.4;32.3;Cadastre;A 1.0;POLYGON Z ((354423.4 6689885.8 38.7, 354423.9 6689890.1 38.7, 354425.8 6689890.1 38.7, 354426.1 6689892.9 38.7, 354428.7 6689892.8 38.7, 354432.9 6689892.3 38.7, 354432.2 6689884.9 38.7, 354425.6 6689885.5 38.7, 354423.4 6689885.8 38.7))
BATIMENT0000000302928457;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;31.0;36.2;42.6;32.4;Cadastre;;POLYGON Z ((354435.6 6689887 36.2, 354436.1 6689892 36.2, 354437.7 6689891.8 36.2, 354440.7 6689891.5 36.2, 354440.6 6689886.4 36.2, 354435.6 6689887 36.2))
BATIMENT0000000302928458;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;5.2;31.0;36.2;40.7;32.4;Cadastre;C 0.4;POLYGON Z ((354438.7 6689901.6 36.2, 354447.3 6689900.9 36.2, 354446.7 6689892.2 36.2, 354454.3 6689891.4 36.2, 354454.4 6689885.2 36.2, 354445.4 6689885.9 36.2, 354440.6 6689886.4 36.2, 354440.7 6689891.5 36.2, 354437.7 6689891.8 36.2, 354438.7 6689901.6 36.2))
BATIMENT0000000302927791;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;23;9.6;31.0;40.6;42.7;32.2;Cadastre;A 1.0;POLYGON Z ((354419.4 6689893.7 40.6, 354420.3 6689903.2 40.6, 354429.6 6689902.4 40.6, 354428.7 6689892.8 40.6, 354426.1 6689892.9 40.6, 354419.4 6689893.7 40.6))
BATIMENT0000000302927776;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;31.3;35.6;39.3;32.0;Cadastre;;POLYGON Z ((354405.6 6689908.2 35.6, 354417.7 6689907 35.6, 354417.5 6689904.4 35.6, 354413.6 6689904.9 35.6, 354413.5 6689904.1 35.6, 354404.6 6689905 35.6, 354404.9 6689908.3 35.6, 354405.6 6689908.2 35.6))
BATIMENT0000000302927799;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;9.1;31.0;40.1;43.4;32.3;Cadastre;A 1.0;POLYGON Z ((354421.6 6689915.3 40.1, 354432.3 6689914.3 40.1, 354431.2 6689902.3 40.1, 354429.6 6689902.4 40.1, 354420.3 6689903.2 40.1, 354421.6 6689915.3 40.1))
BATIMENT0000000302928217;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1892-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.1;32.0;40.1;44.4;32.3;Cadastre;A 1.0;POLYGON Z ((354513.5 6689881.4 40.1, 354523.1 6689883.5 40.1, 354525.5 6689874.2 40.1, 354515.7 6689872 40.1, 354513.5 6689881.4 40.1))
BATIMENT0000000302927817;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.7;32.0;41.7;44.6;32.5;Cadastre;A 1.0;POLYGON Z ((354489.4 6689877.1 41.7, 354490.5 6689880.8 41.7, 354492.8 6689881.5 41.7, 354490.8 6689889.5 41.7, 354501.8 6689892.3 41.7, 354505.1 6689878.8 41.7, 354492.3 6689877.5 41.7, 354489.4 6689877.1 41.7))
BATIMENT0000000302928219;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1892-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.7;32.0;39.7;41.4;32.5;Cadastre;A 1.0;POLYGON Z ((354510.8 6689891 39.7, 354515.8 6689892.4 39.7, 354516.5 6689889.6 39.7, 354521.4 6689890.8 39.7, 354522.3 6689887.1 39.7, 354526.4 6689888 39.7, 354526.7 6689886.9 39.7, 354528.2 6689887.3 39.7, 354528.7 6689884.8 39.7, 354523.1 6689883.5 39.7, 354513.5 6689881.4 39.7, 354510.8 6689891 39.7))
BATIMENT0000000302928232;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;32.0;35.9;36.7;32.4;Cadastre;;POLYGON Z ((354531.5 6689896 35.9, 354534.4 6689896.7 35.9, 354535.2 6689893.1 35.9, 354536.5 6689887.9 35.9, 354533.4 6689887.1 35.9, 354531.5 6689896 35.9))
BATIMENT0000000302928221;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;4.4;32.1;36.5;39.2;32.4;Cadastre;A 1.0;POLYGON Z ((354510.1 6689893.9 36.5, 354515.9 6689895.5 36.5, 354516.6 6689892.6 36.5, 354515.8 6689892.4 36.5, 354510.8 6689891 36.5, 354510.1 6689893.9 36.5))
BATIMENT0000000302928231;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;30;20;3.1;32.0;35.2;44.3;32.3;Cadastre;A 1.0;POLYGON Z ((354550.1 6689891.5 35.2, 354549.3 6689891.2 35.2, 354541.3 6689889.2 35.2, 354538.2 6689888.3 35.2, 354537.8 6689890.1 35.2, 354537.1 6689890 35.2, 354536.5 6689893.3 35.2, 354535.2 6689893.1 35.2, 354534.4 6689896.7 35.2, 354534.1 6689897.9 35.2, 354533.4 6689900.9 35.2, 354548.4 6689904.7 35.2, 354558.3 6689907.2 35.2, 354559 6689905.8 35.2, 354559.6 6689893.8 35.2, 354550.1 6689891.5 35.2))
BATIMENT0000000302927818;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.6;32.0;41.6;44.8;32.5;Cadastre;A 1.0;POLYGON Z ((354489.1 6689896.6 41.6, 354487.3 6689904.4 41.6, 354498.1 6689907.2 41.6, 354501.8 6689892.3 41.6, 354490.8 6689889.5 41.6, 354489.1 6689896.6 41.6))
BATIMENT0000000302927819;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;32.0;37.2;40.5;32.3;Cadastre;;POLYGON Z ((354487.2 6689896.1 37.2, 354485.2 6689903.9 37.2, 354487.3 6689904.4 37.2, 354489.1 6689896.6 37.2, 354487.2 6689896.1 37.2))
BATIMENT0000000302928222;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;23;9.5;32.1;41.7;44.7;32.5;Cadastre;A 1.0;POLYGON Z ((354507.1 6689906.2 41.7, 354518 6689908.6 41.7, 354520.8 6689896.7 41.7, 354515.9 6689895.5 41.7, 354510.1 6689893.9 41.7, 354507.1 6689906.2 41.7))
BATIMENT0000000302927820;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;9.7;32.0;41.7;44.4;32.6;Cadastre;A 1.0;POLYGON Z ((354486.8 6689906.1 41.7, 354485 6689905.6 41.7, 354484.4 6689908.4 41.7, 354486.2 6689908.9 41.7, 354484.2 6689916.9 41.7, 354483.3 6689920.5 41.7, 354494.1 6689923.2 41.7, 354498.1 6689907.2 41.7, 354487.3 6689904.4 41.7, 354486.8 6689906.1 41.7))
BATIMENT0000000302927771;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;10;20;16.8;29.7;46.5;50.4;31.5;Cadastre;C 0.4;POLYGON Z ((354369.9 6689901.6 46.5, 354361.3 6689900.2 46.5, 354359.2 6689912.7 46.5, 354367.9 6689913.9 46.5, 354368.3 6689912.1 46.5, 354372 6689912.6 46.5, 354399.2 6689909.2 46.5, 354397.7 6689897.6 46.5, 354369.9 6689901.6 46.5))
BATIMENT0000000302927773;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;13.1;29.7;42.8;47.4;30.3;Cadastre;A 1.0;POLYGON Z ((354358.2 6689919 42.8, 354367.7 6689920.2 42.8, 354368.7 6689914.1 42.8, 354367.9 6689913.9 42.8, 354359.2 6689912.7 42.8, 354358.2 6689919 42.8))
BATIMENT0000000302927778;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;11.0;29.7;40.7;42.5;30.5;Cadastre;A 1.0;POLYGON Z ((354357.2 6689925.9 40.7, 354366.6 6689927.1 40.7, 354367.7 6689920.2 40.7, 354358.2 6689919 40.7, 354357.2 6689925.9 40.7))
BATIMENT0000000302928365;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;9.5;29.6;39.1;43.2;30.1;Cadastre;A 1.0;POLYGON Z ((354346.2 6689921.1 39.1, 354335.6 6689922.1 39.1, 354334.1 6689922.4 39.1, 354335.1 6689931.7 39.1, 354344.7 6689931 39.1, 354346.2 6689921.1 39.1))
BATIMENT0000000302927793;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;10.0;29.7;39.7;42.9;30.6;Cadastre;A 1.0;POLYGON Z ((354356.2 6689932.9 39.7, 354366 6689934.5 39.7, 354367 6689928.4 39.7, 354367.2 6689927.3 39.7, 354366.6 6689927.1 39.7, 354357.2 6689925.9 39.7, 354356.2 6689932.9 39.7))
BATIMENT0000000302928437;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.5;31.0;40.5;42.5;32.0;Cadastre;A 1.0;POLYGON Z ((354405.6 6689929.7 40.5, 354397 6689932.3 40.5, 354398.1 6689937.7 40.5, 354407.4 6689935.2 40.5, 354408.9 6689934.7 40.5, 354407.9 6689926.4 40.5, 354407.7 6689925.1 40.5, 354405.1 6689925.3 40.5, 354405.6 6689929.7 40.5))
BATIMENT0000000302927779;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;30.2;33.1;36.7;30.9;Cadastre;;POLYGON Z ((354369.3 6689935.1 33.1, 354370.2 6689929 33.1, 354367 6689928.4 33.1, 354366 6689934.5 33.1, 354368.2 6689934.9 33.1, 354369.3 6689935.1 33.1))
BATIMENT0000000302928436;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.7;31.0;40.7;43.5;31.8;Cadastre;A 1.0;POLYGON Z ((354397 6689932.3 40.7, 354396.7 6689931.4 40.7, 354387.9 6689933.8 40.7, 354387 6689930.7 40.7, 354384.5 6689931.3 40.7, 354384.9 6689936.6 40.7, 354385.7 6689941.2 40.7, 354389 6689940.3 40.7, 354398.1 6689937.7 40.7, 354397 6689932.3 40.7))
BATIMENT0000000302927780;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.5;29.4;39.0;43.1;30.9;Cadastre;A 1.0;POLYGON Z ((354355.3 6689938 39, 354370.5 6689940.7 39, 354371 6689940.8 39, 354371.4 6689938 39, 354367.8 6689937.4 39, 354368.2 6689934.9 39, 354366 6689934.5 39, 354356.2 6689932.9 39, 354355.3 6689938 39))
BATIMENT0000000302928435;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;31.6;38.2;41.2;32.0;Cadastre;;POLYGON Z ((354398.5 6689943 38.2, 354404.3 6689941.5 38.2, 354403.8 6689938.6 38.2, 354407.9 6689937.4 38.2, 354407.4 6689935.2 38.2, 354398.1 6689937.7 38.2, 354398.5 6689943 38.2))
BATIMENT0000000302928223;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;29;5.4;32.2;37.7;44.5;32.5;Cadastre;A 1.0;POLYGON Z ((354513.7 6689918.8 37.7, 354515.6 6689919.1 37.7, 354517.7 6689910.8 37.7, 354506.6 6689908.1 37.7, 354503.1 6689922.3 37.7, 354512.4 6689924.5 37.7, 354513.7 6689918.8 37.7))
BATIMENT0000000302927821;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;32.0;36.5;40.5;32.2;Cadastre;;POLYGON Z ((354479 6689915.5 36.5, 354478.2 6689919.1 36.5, 354479.5 6689919.5 36.5, 354483.3 6689920.5 36.5, 354484.2 6689916.9 36.5, 354479 6689915.5 36.5))
BATIMENT0000000302928234;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.5;32.1;40.6;43.3;32.3;Cadastre;A 1.0;POLYGON Z ((354540.4 6689922.1 40.6, 354549.1 6689926.2 40.6, 354553 6689918.2 40.6, 354544.1 6689914.3 40.6, 354540.4 6689922.1 40.6))
BATIMENT0000000302928148;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;50;20;2.6;32.0;34.6;35.9;32.4;Cadastre;C 0.4;POLYGON Z ((354533.6 6689918.6 34.6, 354530 6689917.1 34.6, 354528.1 6689923.6 34.6, 354530.9 6689925 34.6, 354533.6 6689918.6 34.6))
BATIMENT0000000302928224;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.0;32.4;42.4;44.9;32.5;Cadastre;A 1.0;POLYGON Z ((354501.6 6689928.2 42.4, 354510.9 6689930.4 42.4, 354511.8 6689927.3 42.4, 354515 6689928.2 42.4, 354516 6689927.3 42.4, 354516.6 6689925.5 42.4, 354512.4 6689924.5 42.4, 354503.1 6689922.3 42.4, 354501.6 6689928.2 42.4))
BATIMENT0000000302927822;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.8;31.9;41.7;44.5;32.6;Cadastre;A 1.0;POLYGON Z ((354478.3 6689924.9 41.7, 354479.2 6689925.1 41.7, 354478 6689930.2 41.7, 354482.5 6689931.5 41.7, 354491.5 6689933.7 41.7, 354494.1 6689923.2 41.7, 354483.3 6689920.5 41.7, 354479.5 6689919.5 41.7, 354478.3 6689924.9 41.7))
BATIMENT0000000302928147;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;32.0;34.5;36.5;32.5;Cadastre;;POLYGON Z ((354526.3 6689929.2 34.5, 354528.5 6689930.3 34.5, 354530.9 6689925 34.5, 354528.1 6689923.6 34.5, 354526.3 6689929.2 34.5))
BATIMENT0000000302928235;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;7.9;32.1;40.0;42.1;32.3;Cadastre;C 1.0;POLYGON Z ((354537 6689928.4 40, 354537.6 6689928.6 40, 354546.1 6689932.7 40, 354549.1 6689926.2 40, 354540.4 6689922.1 40, 354537 6689928.4 40))
BATIMENT0000000302928236;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;32.1;39.7;42.0;32.5;Cadastre;A 1.0;POLYGON Z ((354543.5 6689937.9 39.7, 354546.1 6689932.7 39.7, 354537.6 6689928.6 39.7, 354537 6689928.4 39.7, 354534.2 6689927.1 39.7, 354531.8 6689932.3 39.7, 354534.5 6689933.6 39.7, 354543.5 6689937.9 39.7))
BATIMENT0000000302928225;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;32.0;40.3;44.2;32.7;Cadastre;A 1.0;POLYGON Z ((354499 6689938 40.3, 354503.3 6689939.1 40.3, 354510.6 6689940.9 40.3, 354511.6 6689937.2 40.3, 354509.5 6689936.6 40.3, 354510.9 6689930.4 40.3, 354501.6 6689928.2 40.3, 354499 6689938 40.3))
BATIMENT0000000302927777;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;8.0;29.7;37.7;40.0;32.3;Cadastre;A 1.0;POLYGON Z ((354405.8 6689910.1 37.7, 354409.7 6689909.6 37.7, 354410 6689911.5 37.7, 354418 6689910.8 37.7, 354417.7 6689907 37.7, 354405.6 6689908.2 37.7, 354405.8 6689910.1 37.7))
BATIMENT0000000302927806;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;9.0;31.0;40.0;43.4;32.2;Cadastre;A 1.0;POLYGON Z ((354423 6689927.7 40, 354427.5 6689927.2 40, 354433.4 6689926.4 40, 354432.3 6689914.3 40, 354421.6 6689915.3 40, 354423 6689927.7 40))
BATIMENT0000000302928439;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;31.7;35.7;38.2;32.2;Cadastre;;POLYGON Z ((354407.2 6689920.8 35.7, 354404.7 6689921 35.7, 354405.1 6689925.3 35.7, 354407.7 6689925.1 35.7, 354407.2 6689920.8 35.7))
BATIMENT0000000302927807;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;03;02;6.8;31.0;37.8;41.7;32.2;Cadastre;A 1.0;POLYGON Z ((354427.7 6689930.7 37.8, 354434.2 6689930 37.8, 354433.9 6689926.4 37.8, 354433.4 6689926.4 37.8, 354427.5 6689927.2 37.8, 354427.7 6689930.7 37.8))
BATIMENT0000000302928438;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;23;10.2;31.0;41.2;44.2;32.2;Cadastre;A 1.0;POLYGON Z ((354420.5 6689933 41.2, 354419.7 6689925.2 41.2, 354407.9 6689926.4 41.2, 354408.9 6689934.7 41.2, 354420.5 6689933 41.2))
BATIMENT0000000302927808;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;4.7;31.0;35.7;37.1;32.3;Cadastre;A 1.0;POLYGON Z ((354428.2 6689934.3 35.7, 354434.6 6689933.7 35.7, 354434.5 6689933.2 35.7, 354434.2 6689930 35.7, 354427.7 6689930.7 35.7, 354428.2 6689934.3 35.7))
BATIMENT0000000302927815;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;32.1;35.3;44.0;32.4;Cadastre;;POLYGON Z ((354454.3 6689935.5 35.3, 354454.2 6689930.5 35.3, 354449.8 6689931 35.3, 354449.7 6689931.7 35.3, 354434.5 6689933.2 35.3, 354434.6 6689933.7 35.3, 354434.9 6689937.5 35.3, 354454.3 6689935.5 35.3))
BATIMENT0000000302927809;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;10;10;4.3;31.0;35.3;40.5;32.4;Cadastre;B 0.1;POLYGON Z ((354428.6 6689938 35.3, 354434.9 6689937.5 35.3, 354434.6 6689933.7 35.3, 354428.2 6689934.3 35.3, 354428.6 6689938 35.3))
BATIMENT0000000302928404;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;12;6.7;31.0;37.7;41.7;32.4;Cadastre;B 0.2;POLYGON Z ((354441.9 6689948.1 37.7, 354441.4 6689944 37.7, 354435.4 6689944.6 37.7, 354435.2 6689943.6 37.7, 354423.7 6689944.7 37.7, 354424.3 6689949.7 37.7, 354434.3 6689948.8 37.7, 354441.9 6689948.1 37.7))
BATIMENT0000000302929155;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.5;32.1;34.7;36.0;32.4;Cadastre;;POLYGON Z ((354448.5 6689947.3 34.7, 354449 6689950.5 34.7, 354453.1 6689950.1 34.7, 354453.2 6689946.8 34.7, 354448.5 6689947.3 34.7))
BATIMENT0000000302928237;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.6;32.1;39.7;42.7;32.5;Cadastre;A 1.0;POLYGON Z ((354531.8 6689939.4 39.7, 354540.7 6689943.7 39.7, 354543.5 6689937.9 39.7, 354534.5 6689933.6 39.7, 354531.8 6689939.4 39.7))
BATIMENT0000000302928238;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;20;7.7;32.1;39.8;42.3;32.6;Cadastre;A 1.0;POLYGON Z ((354528.7 6689946.4 39.8, 354538.3 6689948.9 39.8, 354540.7 6689943.7 39.8, 354531.8 6689939.4 39.8, 354528.7 6689946.4 39.8))
BATIMENT0000000302928226;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.7;32.1;38.8;42.7;32.7;Cadastre;A 1.0;POLYGON Z ((354496.1 6689950.2 38.8, 354505.4 6689952.6 38.8, 354507.9 6689942.4 38.8, 354502.9 6689941 38.8, 354503.3 6689939.1 38.8, 354499 6689938 38.8, 354496.1 6689950.2 38.8))
BATIMENT0000000302928239;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.9;32.1;41.0;44.1;32.7;Cadastre;A 1.0;POLYGON Z ((354527.6 6689946.1 41, 354525.4 6689955.8 41, 354533.9 6689957.9 41, 354538.3 6689948.9 41, 354528.7 6689946.4 41, 354527.6 6689946.1 41))
BATIMENT0000000302928227;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.2;32.1;39.3;43.2;32.8;Cadastre;A 1.0;POLYGON Z ((354493.9 6689959.1 39.3, 354503.1 6689961.3 39.3, 354504.7 6689955.7 39.3, 354507.9 6689956.5 39.3, 354508.8 6689953.4 39.3, 354505.4 6689952.6 39.3, 354496.1 6689950.2 39.3, 354493.9 6689959.1 39.3))
BATIMENT0000000302928143;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;5.1;32.0;37.1;39.9;32.5;Cadastre;C 0.8;POLYGON Z ((354541.1 6689962 37.1, 354553.4 6689966 37.1, 354553.9 6689964.3 37.1, 354549.8 6689962.8 37.1, 354550.6 6689960.2 37.1, 354555.3 6689950 37.1, 354548.5 6689946.6 37.1, 354541.1 6689962 37.1))
BATIMENT0000000302928240;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;5.9;32.1;38.0;41.7;32.8;Cadastre;A 1.0;POLYGON Z ((354524.9 6689957.3 38, 354522.2 6689959.5 38, 354515.5 6689960.6 38, 354515.6 6689962.7 38, 354516.4 6689967.1 38, 354527.9 6689964.7 38, 354532.1 6689961.7 38, 354533.9 6689957.9 38, 354525.4 6689955.8 38, 354524.9 6689957.3 38))
BATIMENT0000000302928220;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;32.4;34.7;36.2;32.7;Cadastre;;POLYGON Z ((354506.3 6689961.6 34.7, 354503.5 6689961.5 34.7, 354502.9 6689964.3 34.7, 354505.5 6689965.1 34.7, 354506.3 6689961.6 34.7))
BATIMENT0000000302928228;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.4;32.1;38.5;40.5;32.6;Cadastre;A 0.9;POLYGON Z ((354491.8 6689967.8 38.5, 354491.8 6689968.1 38.5, 354493.4 6689969.8 38.5, 354505.8 6689968.4 38.5, 354506.1 6689968.2 38.5, 354505.5 6689965.1 38.5, 354502.9 6689964.3 38.5, 354503.5 6689961.5 38.5, 354503.1 6689961.3 38.5, 354493.9 6689959.1 38.5, 354491.8 6689967.8 38.5))
BATIMENT0000000302928241;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.4;32.1;36.5;;;Cadastre;;POLYGON Z ((354512.5 6689962.7 36.5, 354512.8 6689964.9 36.5, 354514.1 6689964.7 36.5, 354514.5 6689967.4 36.5, 354516.4 6689967.1 36.5, 354515.6 6689962.7 36.5, 354512.5 6689962.7 36.5))
BATIMENT0000000302928948;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;29;9.4;31.0;40.4;43.8;32.4;Cadastre;A 1.0;POLYGON Z ((354421.2 6689954 40.4, 354422.2 6689953.8 40.4, 354422.6 6689953.8 40.4, 354421.9 6689947.1 40.4, 354409.1 6689948.5 40.4, 354409.8 6689955.2 40.4, 354419.7 6689954.1 40.4, 354420.2 6689954.1 40.4, 354421.2 6689954 40.4))
BATIMENT0000000302928405;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;90;6.5;31.0;37.5;39.9;32.4;Cadastre;A 1.0;POLYGON Z ((354424.3 6689949.7 37.5, 354424.6 6689953.5 37.5, 354424.7 6689954.2 37.5, 354425.9 6689954.7 37.5, 354426.7 6689954.7 37.5, 354426.9 6689956.8 37.5, 354431.9 6689956.5 37.5, 354432 6689957.9 37.5, 354434.7 6689957.7 37.5, 354434.7 6689956.3 37.5, 354434.3 6689948.8 37.5, 354424.3 6689949.7 37.5))
BATIMENT0000000302927823;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.2;32.0;42.2;45.4;32.8;Cadastre;C 0.1;POLYGON Z ((354482 6689933.7 42.2, 354481.5 6689933.6 42.2, 354479.9 6689940.1 42.2, 354480.4 6689940.2 42.2, 354479.4 6689944.4 42.2, 354477.7 6689945.4 42.2, 354477.5 6689945.6 42.2, 354477.2 6689946.1 42.2, 354477 6689946.4 42.2, 354476.9 6689946.7 42.2, 354476.8 6689947 42.2, 354476.8 6689947.3 42.2, 354476.8 6689947.7 42.2, 354476.7 6689948 42.2, 354476.8 6689948.3 42.2, 354476.8 6689948.6 42.2, 354476.9 6689948.9 42.2, 354477 6689949.2 42.2, 354477.1 6689949.5 42.2, 354477.3 6689949.8 42.2, 354477.4 6689950 42.2, 354477.6 6689950.3 42.2, 354477.8 6689950.5 42.2, 354474.4 6689963.2 42.2, 354471.6 6689963.8 42.2, 354471.5 6689963 42.2, 354454.4 6689966 42.2, 354454.3 6689977.1 42.2, 354479.8 6689972.9 42.2, 354482.2 6689971.3 42.2, 354491.5 6689933.7 42.2, 354482.5 6689931.5 42.2, 354482 6689933.7 42.2))
BATIMENT0000000302928949;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;7.3;31.0;38.3;40.5;32.4;Cadastre;A 1.0;POLYGON Z ((354409.8 6689955.2 38.3, 354410.5 6689960.2 38.3, 354410.6 6689961.4 38.3, 354411 6689964.5 38.3, 354413 6689964.2 38.3, 354412.7 6689961.4 38.3, 354412.5 6689959.9 38.3, 354420.3 6689958.9 38.3, 354419.7 6689954.1 38.3, 354409.8 6689955.2 38.3))
BATIMENT0000000302928406;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;32.1;37.7;40.0;32.4;Cadastre;;POLYGON Z ((354432 6689957.9 37.7, 354430 6689958 37.7, 354430.4 6689963.3 37.7, 354435 6689963.1 37.7, 354434.7 6689957.7 37.7, 354432 6689957.9 37.7))
BATIMENT0000000302927824;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;8.4;32.0;40.4;44.0;32.4;Cadastre;A 1.0;POLYGON Z ((354454.4 6689965.7 40.4, 354448.9 6689966.6 40.4, 354448.8 6689965.3 40.4, 354443.8 6689965.9 40.4, 354443.9 6689970 40.4, 354444.1 6689978.7 40.4, 354454.3 6689977.1 40.4, 354454.4 6689966 40.4, 354454.4 6689965.7 40.4))
BATIMENT0000000302927825;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;32.0;41.4;43.2;32.5;Cadastre;A 1.0;POLYGON Z ((354436.5 6689971.1 41.4, 354436.8 6689980 41.4, 354444.1 6689978.7 41.4, 354443.9 6689970 41.4, 354436.5 6689971.1 41.4))
BATIMENT0000000302927826;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.2;31.5;48.7;51.0;32.6;Cadastre;;POLYGON Z ((354436.4 6689969.1 48.7, 354411.8 6689971.4 48.7, 354413.2 6689982.2 48.7, 354425.4 6689982 48.7, 354436.8 6689980 48.7, 354436.5 6689971.1 48.7, 354436.4 6689969.1 48.7))
BATIMENT0000000302927827;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;23;9.6;31.9;41.5;48.5;32.3;Cadastre;A 1.0;POLYGON Z ((354400.6 6689972.4 41.5, 354400.9 6689978.4 41.5, 354406.9 6689977.8 41.5, 354407.2 6689982 41.5, 354413.2 6689982.2 41.5, 354411.8 6689971.4 41.5, 354400.6 6689972.4 41.5))
BATIMENT0000000302928423;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.0;31.9;40.9;43.0;32.5;Cadastre;B 0.6;POLYGON Z ((354478.4 6689983.2 40.9, 354476.2 6689981.7 40.9, 354469.5 6689982.9 40.9, 354467.9 6689989.5 40.9, 354476.2 6689991.8 40.9, 354478.4 6689983.2 40.9))
BATIMENT0000000302927792;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;5.6;29.5;35.2;42.7;31.0;Cadastre;A 1.0;POLYGON Z ((354354.2 6689944.8 35.2, 354364.2 6689946.4 35.2, 354369.5 6689947.2 35.2, 354370.5 6689940.7 35.2, 354355.3 6689938 35.2, 354354.2 6689944.8 35.2))
BATIMENT0000000302927800;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;8.6;29.7;38.3;41.3;30.9;Cadastre;C 0.8;POLYGON Z ((354352.9 6689954.4 38.3, 354363 6689956.2 38.3, 354366.5 6689956.7 38.3, 354367 6689953.4 38.3, 354363.3 6689952.7 38.3, 354364.2 6689946.4 38.3, 354354.2 6689944.8 38.3, 354352.9 6689954.4 38.3))
BATIMENT0000000029198291;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:37;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.2;30.0;;39.7;31.4;Imagerie aérienne;;POLYGON Z ((354391 6689961.1 34.2, 354391.2 6689952.9 34.1, 354382.3 6689952.6 32.8, 354382.3 6689960.9 33.9, 354391 6689961.1 34.2))
BATIMENT0000000302927801;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.7;29.7;37.4;40.8;30.8;Cadastre;A 1.0;POLYGON Z ((354351.3 6689964.6 37.4, 354361.4 6689966.2 37.4, 354363 6689956.2 37.4, 354352.9 6689954.4 37.4, 354351.3 6689964.6 37.4))
BATIMENT0000000302927829;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;31.1;34.4;34.7;31.4;Cadastre;;POLYGON Z ((354400.1 6689966.9 34.4, 354393.2 6689967.5 34.4, 354393.3 6689968.8 34.4, 354400.2 6689968.4 34.4, 354400.1 6689966.9 34.4))
BATIMENT0000000302927810;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.9;29.7;37.6;41.2;30.7;Cadastre;A 1.0;POLYGON Z ((354350.1 6689973.6 37.6, 354352.4 6689974.1 37.6, 354360.1 6689975.2 37.6, 354361.4 6689966.2 37.6, 354351.3 6689964.6 37.6, 354350.1 6689973.6 37.6))
BATIMENT0000000302927828;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.7;32.0;39.7;;;Cadastre;A 1.0;POLYGON Z ((354400.9 6689978.4 39.7, 354400.6 6689972.4 39.7, 354400.2 6689968.4 39.7, 354393.3 6689968.8 39.7, 354391.1 6689968.9 39.7, 354391.3 6689971.2 39.7, 354391.8 6689979.9 39.7, 354392 6689982.6 39.7, 354401 6689981.8 39.7, 354400.9 6689978.4 39.7))
BATIMENT0000000302927816;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1897-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;7.9;29.7;37.6;40.4;30.7;Cadastre;A 1.0;POLYGON Z ((354351.4 6689979.9 37.6, 354351.1 6689979.8 37.6, 354350.1 6689986.1 37.6, 354361.7 6689987.7 37.6, 354363.7 6689975.8 37.6, 354360.1 6689975.2 37.6, 354352.4 6689974.1 37.6, 354351.4 6689979.9 37.6))
BATIMENT0000000302927834;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;23;5.7;32.0;37.7;;;Cadastre;A 1.0;POLYGON Z ((354381.8 6689976.6 37.7, 354371.5 6689977.2 37.7, 354371.6 6689981.7 37.7, 354373.3 6689981.6 37.7, 354373.7 6689989.6 37.7, 354382.3 6689990.8 37.7, 354382 6689980.6 37.7, 354381.8 6689976.6 37.7))
BATIMENT0000000302927830;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.7;31.0;41.7;44.6;31.4;Cadastre;A 1.0;POLYGON Z ((354382 6689980.6 41.7, 354382.3 6689990.8 41.7, 354392.6 6689992.4 41.7, 354392.4 6689990.7 41.7, 354392.7 6689990.5 41.7, 354392 6689982.6 41.7, 354391.8 6689979.9 41.7, 354382 6689980.6 41.7))
BATIMENT0000000302928242;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.4;32.1;36.5;;;Cadastre;A 0.4;POLYGON Z ((354510.3 6689962.7 36.5, 354511.2 6689968.1 36.5, 354514.5 6689967.4 36.5, 354514.1 6689964.7 36.5, 354512.8 6689964.9 36.5, 354512.5 6689962.7 36.5, 354510.3 6689962.7 36.5))
BATIMENT0000000302928142;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;90;8.3;32.0;40.3;42.0;32.5;Cadastre;B 0.8;POLYGON Z ((354547.8 6689976 40.3, 354551.2 6689967.5 40.3, 354542.2 6689964.2 40.3, 354538.7 6689972.9 40.3, 354546.9 6689975.7 40.3, 354547.8 6689976 40.3))
BATIMENT0000000302928213;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;20;7.0;32.0;39.0;40.5;32.6;Cadastre;C 0.5;POLYGON Z ((354530.7 6689977.1 39, 354531.2 6689972 39, 354518.6 6689974.2 39, 354519.4 6689979.2 39, 354530.7 6689977.1 39))
BATIMENT0000000302928214;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;32.0;38.7;40.5;32.5;Cadastre;;POLYGON Z ((354515.5 6689974.5 38.7, 354516.6 6689980.5 38.7, 354519.5 6689980.2 38.7, 354519.4 6689979.2 38.7, 354518.6 6689974.2 38.7, 354515.5 6689974.5 38.7))
BATIMENT0000000302928141;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;40;10.3;32.0;42.3;42.9;32.5;Cadastre;A 1.0;POLYGON Z ((354537.2 6689972.4 42.3, 354536.1 6689976.3 42.3, 354535 6689984.6 42.3, 354544.6 6689987.4 42.3, 354546.1 6689982.5 42.3, 354545.2 6689982.3 42.3, 354546.9 6689975.7 42.3, 354538.7 6689972.9 42.3, 354537.2 6689972.4 42.3))
BATIMENT0000000302928160;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;32.0;40.2;43.5;32.5;Cadastre;A 1.0;POLYGON Z ((354495.2 6689978.6 40.2, 354497.1 6689988.4 40.2, 354502.9 6689987.4 40.2, 354502.9 6689987 40.2, 354506.6 6689986.3 40.2, 354505.3 6689976.9 40.2, 354495.2 6689978.6 40.2))
BATIMENT0000000302928161;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;4.5;32.2;36.7;39.9;32.5;Cadastre;A 1.0;POLYGON Z ((354506.6 6689986.3 36.7, 354507.4 6689991.8 36.7, 354512.7 6689990.8 36.7, 354520 6689989.7 36.7, 354519.5 6689986.5 36.7, 354518.2 6689986.7 36.7, 354518 6689985.8 36.7, 354512 6689986.9 36.7, 354510.2 6689976.1 36.7, 354505.3 6689976.9 36.7, 354506.6 6689986.3 36.7))
BATIMENT0000000302928159;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1943-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.8;32.0;39.8;42.9;32.4;Cadastre;A 1.0;POLYGON Z ((354490.3 6689979.5 39.8, 354489.2 6689984.5 39.8, 354491.4 6689985.1 39.8, 354492.2 6689989.7 39.8, 354492.4 6689991.2 39.8, 354497.3 6689990.1 39.8, 354497.1 6689988.4 39.8, 354495.2 6689978.6 39.8, 354490.3 6689979.5 39.8))
BATIMENT0000000302928163;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;01;3.1;32.2;35.3;37.2;32.5;Cadastre;C 0.4;POLYGON Z ((354519.2 6689985.1 35.3, 354519.5 6689986.5 35.3, 354520 6689989.7 35.3, 354528.5 6689988.2 35.3, 354529 6689983.5 35.3, 354519.2 6689985.1 35.3))
BATIMENT0000000302928140;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;9.6;32.1;41.7;45.2;32.5;Cadastre;A 1.0;POLYGON Z ((354534.1 6689992.3 41.7, 354533.6 6689996.7 41.7, 354545.3 6689997.2 41.7, 354546.8 6689997.3 41.7, 354549.6 6689997.5 41.7, 354550.7 6689989.2 41.7, 354544.6 6689987.4 41.7, 354535 6689984.6 41.7, 354534.1 6689992.3 41.7))
BATIMENT0000000302928424;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;04;2.7;32.0;34.7;35.1;32.3;Cadastre;B 0.3;POLYGON Z ((354462.4 6689989.6 34.7, 354461.7 6689984 34.7, 354452.5 6689985.5 34.7, 354453.2 6689991 34.7, 354462.4 6689989.6 34.7))
BATIMENT0000000302928425;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;00;00;2.7;32.0;34.7;34.8;32.2;Cadastre;C 0.1;POLYGON Z ((354449.4 6689985.9 34.7, 354450.2 6689991.7 34.7, 354453.3 6689991.3 34.7, 354453.2 6689991 34.7, 354452.5 6689985.5 34.7, 354449.4 6689985.9 34.7))
BATIMENT0000000302928426;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.7;32.0;34.7;35.5;32.2;Cadastre;A 1.0;POLYGON Z ((354446.6 6689986.4 34.7, 354445.9 6689992.5 34.7, 354450.2 6689991.7 34.7, 354449.4 6689985.9 34.7, 354446.6 6689986.4 34.7))
BATIMENT0000000302928427;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.4;30.7;40.1;42.4;32.4;Cadastre;A 1.0;POLYGON Z ((354436.3 6689988.2 40.1, 354437.8 6689997.1 40.1, 354437.8 6689997.5 40.1, 354444.3 6689996.3 40.1, 354444.7 6689995.7 40.1, 354444.5 6689994.4 40.1, 354445.7 6689994.3 40.1, 354445.9 6689992.5 40.1, 354446.6 6689986.4 40.1, 354436.3 6689988.2 40.1))
BATIMENT0000000302928428;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.9;31.0;39.9;43.0;32.4;Cadastre;A 1.0;POLYGON Z ((354426.3 6689989.9 39.9, 354427.7 6689998.6 39.9, 354432.8 6689997.8 39.9, 354437.8 6689997.1 39.9, 354436.3 6689988.2 39.9, 354426.3 6689989.9 39.9))
BATIMENT0000000302928422;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.3;31.9;40.2;43.1;32.4;Cadastre;C 0.9;POLYGON Z ((354466.5 6689989 40.2, 354463 6689989.5 40.2, 354461.2 6689997.5 40.2, 354466.9 6689998.7 40.2, 354474.1 6690000.3 40.2, 354476.2 6689991.8 40.2, 354467.9 6689989.5 40.2, 354466.5 6689989 40.2))
BATIMENT0000000302928430;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.3;30.7;40.0;42.7;31.7;Cadastre;A 1.0;POLYGON Z ((354426.2 6689999.8 40, 354425.1 6689990 40, 354418.4 6689990.2 40, 354419.9 6690000.3 40, 354426.2 6689999.8 40))
BATIMENT0000000302928431;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;9.5;30.7;40.2;42.6;31.7;Cadastre;A 1.0;POLYGON Z ((354413.7 6689990.3 40.2, 354414.5 6689998.3 40.2, 354414.7 6690000.8 40.2, 354419.9 6690000.3 40.2, 354418.4 6689990.2 40.2, 354413.7 6689990.3 40.2))
BATIMENT0000000302928433;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;9.0;30.7;39.7;42.7;31.6;Cadastre;A 1.0;POLYGON Z ((354401.1 6689990.4 39.7, 354403 6690000.1 39.7, 354405.7 6689999.9 39.7, 354406.1 6690003.4 39.7, 354409.3 6690003 39.7, 354407.8 6689990.3 39.7, 354401.1 6689990.4 39.7))
BATIMENT0000000302928432;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.1;30.7;39.8;43.2;31.7;Cadastre;A 1.0;POLYGON Z ((354414.7 6690000.8 39.8, 354414.5 6689998.3 39.8, 354413.7 6689990.3 39.8, 354407.8 6689990.3 39.8, 354409.3 6690003 39.8, 354411.7 6690002.7 39.8, 354411.9 6690004.3 39.8, 354415.1 6690003.8 39.8, 354414.7 6690000.8 39.8))
BATIMENT0000000302904702;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;7.7;11.3;12.8;9.1;Cadastre;;POLYGON Z ((353982.6 6689789 11.3, 353983.7 6689790.2 11.3, 353985.2 6689788.9 11.3, 353986.9 6689788.7 11.3, 353987.7 6689788 11.3, 353986.2 6689786.2 11.3, 353985.8 6689785.8 11.3, 353982.6 6689789 11.3))
BATIMENT0000000302904631;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;00;00;10.8;5.6;16.4;20.4;7.8;Cadastre;C 0.6;POLYGON Z ((354015.5 6689782 16.4, 354006.4 6689788.3 16.4, 354006 6689787.8 16.4, 354002.9 6689790.1 16.4, 354003.3 6689790.8 16.4, 353988 6689801.7 16.4, 353987.1 6689802.3 16.4, 353988.3 6689803.8 16.4, 353990.7 6689806.4 16.4, 353993.9 6689804.2 16.4, 354000 6689805.1 16.4, 354003.5 6689802.7 16.4, 354003.9 6689802.9 16.4, 354027.1 6689786.6 16.4, 354028 6689781.7 16.4, 354025.1 6689777.7 16.4, 354020.6 6689781 16.4, 354019 6689778.6 16.4, 354015.1 6689781.4 16.4, 354015.5 6689782 16.4))
BATIMENT0000000302904624;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;5.5;8.3;13.8;16.0;10.8;Cadastre;A 1.0;POLYGON Z ((353971.9 6689787.4 13.8, 353965.2 6689793.3 13.8, 353969.7 6689798.4 13.8, 353976.5 6689792.7 13.8, 353971.9 6689787.4 13.8))
BATIMENT0000000302904501;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1977-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.6;10.7;14.3;;;Cadastre;C 0.3;POLYGON Z ((353951 6689796 14.3, 353950.1 6689796.9 14.3, 353950.5 6689797.3 14.3, 353951.2 6689797.8 14.3, 353952.1 6689798.4 14.3, 353953.6 6689799 14.3, 353954.5 6689799.3 14.3, 353955.7 6689799.5 14.3, 353956.8 6689799.6 14.3, 353958 6689799.5 14.3, 353959.2 6689799.3 14.3, 353960.4 6689799 14.3, 353961.4 6689798.5 14.3, 353962.6 6689797.8 14.3, 353962.3 6689797.5 14.3, 353962 6689797.8 14.3, 353959.1 6689794.4 14.3, 353956.5 6689791.3 14.3, 353951 6689796 14.3))
BATIMENT0000000302904626;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;30;20;6.6;8.6;15.2;19.5;10.3;Cadastre;A 1.0;POLYGON Z ((353981.2 6689798 15.2, 353976.5 6689792.7 15.2, 353969.7 6689798.4 15.2, 353974.4 6689803.9 15.2, 353975.9 6689802.7 15.2, 353981.2 6689798 15.2))
BATIMENT0000000302904630;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;7.1;16.2;20.1;9.1;Cadastre;;POLYGON Z ((353983.4 6689796.2 16.2, 353982 6689797.4 16.2, 353985.3 6689801.1 16.2, 353984.1 6689802.2 16.2, 353986.7 6689805.2 16.2, 353988.3 6689803.8 16.2, 353987.1 6689802.3 16.2, 353988 6689801.7 16.2, 353983.4 6689796.2 16.2))
BATIMENT0000000302904629;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;13.2;7.2;20.5;22.2;9.9;Cadastre;C 0.1;POLYGON Z ((353981.2 6689798 20.5, 353975.9 6689802.7 20.5, 353981.8 6689809.5 20.5, 353986.7 6689805.2 20.5, 353984.1 6689802.2 20.5, 353985.3 6689801.1 20.5, 353982 6689797.4 20.5, 353981.2 6689798 20.5))
BATIMENT0000000302905451;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1977-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;50;20;7.9;8.2;16.1;16.5;10.0;Cadastre;C 0.4;POLYGON Z ((353950.8 6689812.3 16.1, 353958.8 6689821.7 16.1, 353967 6689814.5 16.1, 353958.9 6689805.2 16.1, 353950.8 6689812.3 16.1))
BATIMENT0000000302902803;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;6.9;6.0;12.9;17.2;6.5;Cadastre;C 0.4;POLYGON Z ((353963.9 6689839.4 12.9, 353954.3 6689848.1 12.9, 353957.1 6689851 12.9, 353959.7 6689848.7 12.9, 353962.6 6689851.8 12.9, 353965.8 6689849.2 12.9, 353968.4 6689852 12.9, 353972.1 6689848.6 12.9, 353963.9 6689839.4 12.9))
BATIMENT0000000302906051;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;7.5;5.5;13.0;16.7;6.5;Cadastre;;POLYGON Z ((353949.1 6689861.1 13, 353954 6689866.5 13, 353958.1 6689862.5 13, 353956.1 6689860.4 13, 353953.7 6689862.4 13, 353951 6689859.5 13, 353949.1 6689861.1 13))
BATIMENT0000000302902796;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;9.0;13.6;;;Cadastre;;POLYGON Z ((353917.3 6689825 13.6, 353919.6 6689827.4 13.6, 353924 6689823.9 13.6, 353921.8 6689821.2 13.6, 353917.3 6689825 13.6))
BATIMENT0000000302902802;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;50;20;9.4;6.2;15.6;19.3;9.1;Cadastre;A 1.0;POLYGON Z ((353945.2 6689818.1 15.6, 353942.7 6689820.2 15.6, 353941.2 6689821.7 15.6, 353941.7 6689822.4 15.6, 353943 6689824.1 15.6, 353943.1 6689824.3 15.6, 353943.3 6689824.6 15.6, 353943.4 6689824.9 15.6, 353943.5 6689825.5 15.6, 353943.6 6689825.8 15.6, 353943.6 6689826.1 15.6, 353943.5 6689826.7 15.6, 353943.5 6689827 15.6, 353943.4 6689827.3 15.6, 353943.3 6689827.6 15.6, 353943.2 6689827.8 15.6, 353943 6689828.1 15.6, 353942.9 6689828.4 15.6, 353942.7 6689828.6 15.6, 353942.3 6689829.1 15.6, 353942.1 6689829.4 15.6, 353941.9 6689829.6 15.6, 353941.6 6689829.7 15.6, 353941.4 6689829.9 15.6, 353941 6689830 15.6, 353933.9 6689834.9 15.6, 353936.1 6689837.5 15.6, 353938.2 6689835.5 15.6, 353951.6 6689850.3 15.6, 353954.3 6689848.1 15.6, 353963.9 6689839.4 15.6, 353945.2 6689818.1 15.6))
BATIMENT0000000302906113;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;0.0;00;00;6.4;11.0;17.4;;;Cadastre;C 0.2;POLYGON Z ((353925.3 6689833.9 17.4, 353921.6 6689829.8 17.4, 353905.1 6689844 17.4, 353908.9 6689848.2 17.4, 353925.3 6689833.9 17.4))
BATIMENT0000000302906111;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.1;9.6;31.7;33.0;13.0;Cadastre;;POLYGON Z ((353894.4 6689853.6 31.7, 353898.3 6689857.7 31.7, 353907.7 6689849.3 31.7, 353908.9 6689848.2 31.7, 353905.1 6689844 31.7, 353897.6 6689835.6 31.7, 353892.0022898072 6689840.536162624 31.7, 353892.0022898072 6689851.048590436 31.7, 353894.4 6689853.6 31.7))
BATIMENT0000000302906116;Industriel, agricole ou commercial;Industriel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;0.0;00;00;6.4;11.0;17.4;26.7;14.6;Cadastre;C 0.5;MULTIPOLYGON Z (((353894.4 6689853.6 17.4, 353892.0022898072 6689851.048590436 17.4, 353892.0022898072 6689855.811680953 17.4, 353894.4 6689853.6 17.4)), ((353897.6 6689835.6 17.4, 353905.1 6689844 17.4, 353921.6 6689829.8 17.4, 353921 6689829.1 17.4, 353919.6 6689827.4 17.4, 353917.3 6689825 17.4, 353913.8 6689821.1 17.4, 353898.9 6689834.1 17.4, 353892.0022898072 6689825.688158301 17.4, 353892.0022898072 6689840.536162624 17.4, 353897.6 6689835.6 17.4)))
BATIMENT0000000302906112;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;9.2;19.0;29.7;12.4;Cadastre;;POLYGON Z ((353898.3 6689857.7 19, 353894.4 6689853.6 19, 353892.0022898072 6689855.811680953 19, 353892.0022898072 6689863.217002317 19, 353898.3 6689857.7 19))
BATIMENT0000000302906117;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 17:38:43;2018-09-18 13:31:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.2;6.8;27.0;32.4;10.0;Cadastre;;POLYGON Z ((353914.4 6689876.2 27, 353924.1 6689867.8 27, 353907.7 6689849.3 27, 353898.3 6689857.7 27, 353914.4 6689876.2 27))
BATIMENT0000000302905512;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2023-01-31 17:32:40;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;30;20;24.9;10.2;35.1;37.4;18.3;Cadastre;A 1.0;POLYGON Z ((353939.1 6689961.6 35.1, 353929.5 6689967.6 35.1, 353934 6689972.6 35.1, 353942.5 6689982 35.1, 353957.3 6689975 35.1, 353946.7 6689957.6 35.1, 353939.1 6689961.6 35.1))
BATIMENT0000000302906087;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;51.0;6.0;00;00;14.2;7.7;21.9;32.2;17.4;Cadastre;C 0.1;POLYGON Z ((353896.7 6690002.2 21.9, 353895.2 6690003.8 21.9, 353898 6690006.9 21.9, 353896.8 6690008.5 21.9, 353902.5 6690014.1 21.9, 353909.7 6690006.1 21.9, 353911.1 6690008.9 21.9, 353912.7 6690009.4 21.9, 353911.8 6690013.8 21.9, 353923 6690021.2 21.9, 353925.6 6690022.1 21.9, 353930.3 6690000.3 21.9, 353923.7 6689987.9 21.9, 353904.3 6689997.9 21.9, 353902.7 6689993.9 21.9, 353905.2 6689991.1 21.9, 353897.8 6689984.3 21.9, 353907.9 6689973.1 21.9, 353898.8 6689964.8 21.9, 353892.0022898072 6689972.362452589 21.9, 353892.0022898072 6689997.847709674 21.9, 353896.7 6690002.2 21.9))
BATIMENT0000000302906086;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1978-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;00;00;20.8;15.4;36.2;37.8;18.9;Cadastre;C 0.6;POLYGON Z ((353930.3 6690000.3 36.2, 353925.6 6690022.1 36.2, 353938.8 6690026.7 36.2, 353939.4 6690023.3 36.2, 353939 6690023.1 36.2, 353944.4 6689998.1 36.2, 353937.4 6689984.7 36.2, 353942.5 6689982 36.2, 353934 6689972.6 36.2, 353923.2 6689978 36.2, 353925.1 6689981.4 36.2, 353923.6 6689982.2 36.2, 353924 6689983.3 36.2, 353922.1 6689984.5 36.2, 353923.7 6689987.9 36.2, 353930.3 6690000.3 36.2))
BATIMENT0000000302927372;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;23;12.9;17.7;30.7;34.7;20.9;Cadastre;A 1.0;POLYGON Z ((354084.2 6689902.5 30.7, 354076.1 6689906.4 30.7, 354080.3 6689914.9 30.7, 354088.4 6689911.1 30.7, 354084.2 6689902.5 30.7))
BATIMENT0000000302927373;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;5.0;00;00;21.6;14.8;36.5;38.7;20.7;Cadastre;A 1.0;POLYGON Z ((354044.9 6689912.1 36.5, 354045.4 6689913.2 36.5, 354053 6689928.3 36.5, 354060.3 6689924.6 36.5, 354074.4 6689917.8 36.5, 354076.3 6689916.9 36.5, 354080.3 6689914.9 36.5, 354076.1 6689906.4 36.5, 354075.1 6689904.3 36.5, 354074.1 6689902.6 36.5, 354072.7 6689899.8 36.5, 354072.3 6689899 36.5, 354044.9 6689912.1 36.5))
BATIMENT0000000302927374;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;6.0;00;00;20.3;14.3;34.7;42.8;19.8;Cadastre;A 1.0;POLYGON Z ((354036.9 6689912.4 34.7, 354036.2 6689911.2 34.7, 354035.6 6689910.4 34.7, 354035.4 6689910.4 34.7, 354035.2 6689910.4 34.7, 354035 6689910.4 34.7, 354034.9 6689910.4 34.7, 354034.7 6689910.5 34.7, 354034.4 6689910.6 34.7, 354034.2 6689910.7 34.7, 354033.9 6689910.9 34.7, 354033.8 6689911 34.7, 354033.7 6689911.2 34.7, 354033.6 6689911.3 34.7, 354033.4 6689911.6 34.7, 354033.3 6689911.8 34.7, 354033.2 6689912.1 34.7, 354033.8 6689913.6 34.7, 354032.6 6689914.1 34.7, 354030.2 6689913.2 34.7, 354029.3 6689913.1 34.7, 354028.4 6689913 34.7, 354027.5 6689913 34.7, 354026.6 6689913 34.7, 354025.6 6689913.2 34.7, 354024.7 6689913.4 34.7, 354023.9 6689913.7 34.7, 354023 6689914.1 34.7, 354022.4 6689914.7 34.7, 354021.8 6689915.3 34.7, 354021.3 6689916 34.7, 354020.8 6689916.7 34.7, 354020.4 6689917.5 34.7, 354020 6689918.3 34.7, 354019.8 6689919.1 34.7, 354019.6 6689919.9 34.7, 354019.4 6689920.8 34.7, 354016.8 6689922 34.7, 354026.1 6689941.6 34.7, 354053 6689928.3 34.7, 354045.4 6689913.2 34.7, 354044.9 6689912.1 34.7, 354043.3 6689908.9 34.7, 354036.9 6689912.4 34.7))
BATIMENT0000000302928462;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.8;20.8;37.6;42.2;23.8;Cadastre;;POLYGON Z ((354096.9 6689924.5 37.6, 354093 6689926.4 37.6, 354095.8 6689932.1 37.6, 354099.4 6689939.5 37.6, 354103.1 6689937.7 37.6, 354101.6 6689934.4 37.6, 354096.9 6689924.5 37.6))
BATIMENT0000000302928460;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;50;30;16.9;20.7;37.7;39.6;24.1;Cadastre;A 1.0;POLYGON Z ((354093.6 6689949.2 37.7, 354099.5 6689946.3 37.7, 354097.8 6689942.8 37.7, 354097.2 6689941.5 37.7, 354099.8 6689940.3 37.7, 354099.5 6689939.6 37.7, 354099.4 6689939.5 37.7, 354095.8 6689932.1 37.7, 354093 6689926.4 37.7, 354078.1 6689933.7 37.7, 354081 6689939.3 37.7, 354083.2 6689944 37.7, 354084.9 6689947.5 37.7, 354091.4 6689944.5 37.7, 354092 6689945.9 37.7, 354093.6 6689949.2 37.7))
BATIMENT0000000302928463;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;23.2;30.7;32.2;24.0;Cadastre;;POLYGON Z ((354099.4 6689939.5 30.7, 354099.5 6689939.6 30.7, 354099.8 6689940.3 30.7, 354100.1 6689940.8 30.7, 354103.8 6689939.2 30.7, 354103.1 6689937.7 30.7, 354099.4 6689939.5 30.7))
BATIMENT0000000302928464;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;23.1;30.8;32.0;23.9;Cadastre;;POLYGON Z ((354100.4 6689941.6 30.8, 354100.4 6689941.5 30.8, 354100.1 6689940.8 30.8, 354099.8 6689940.3 30.8, 354097.2 6689941.5 30.8, 354097.8 6689942.8 30.8, 354100.4 6689941.6 30.8))
BATIMENT0000000302928459;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;13.6;20.3;34.0;38.2;23.8;Cadastre;A 1.0;POLYGON Z ((354066.6 6689939.2 34, 354071.6 6689949.7 34, 354083.2 6689944 34, 354081 6689939.3 34, 354078.1 6689933.7 34, 354066.6 6689939.2 34))
BATIMENT0000000302928461;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;23.5;32.5;37.7;24.1;Cadastre;;POLYGON Z ((354092 6689945.9 32.5, 354091.4 6689944.5 32.5, 354084.9 6689947.5 32.5, 354085.6 6689948.9 32.5, 354092 6689945.9 32.5))
BATIMENT0000000302928465;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;6.0;00;00;16.7;19.7;36.5;40.3;23.7;Cadastre;A 1.0;POLYGON Z ((354045.7 6689969.3 36.5, 354066.8 6689959 36.5, 354068.6 6689962.8 36.5, 354073.5 6689960.4 36.5, 354073.6 6689960.4 36.5, 354063.8 6689940.7 36.5, 354051.8 6689946.3 36.5, 354038 6689953.1 36.5, 354040.7 6689959 36.5, 354045.7 6689969.3 36.5))
BATIMENT0000000302905509;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;34.0;6.0;30;49;17.1;13.3;30.5;41.5;19.0;Cadastre;A 1.0;POLYGON Z ((353984.8 6689932.4 30.5, 353984.9 6689934.3 30.5, 353985.5 6689951.1 30.5, 353984.8 6689951.4 30.5, 353988.6 6689959.8 30.5, 354026.1 6689941.6 30.5, 354016.8 6689922 30.5, 354014.6 6689917.5 30.5, 353984.8 6689932.4 30.5))
BATIMENT0000000302905510;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;8.0;30;20;24.6;9.6;34.2;37.4;18.1;Cadastre;A 1.0;POLYGON Z ((353962.6 6689945 34.2, 353964.6 6689948.9 34.2, 353973.9 6689967 34.2, 353988.6 6689959.8 34.2, 353984.8 6689951.4 34.2, 353985.5 6689951.1 34.2, 353984.9 6689934.3 34.2, 353962.6 6689945 34.2))
BATIMENT0000000302905511;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;7.0;14;20;25.5;9.5;35.1;39.9;18.0;Cadastre;A 1.0;POLYGON Z ((353946.7 6689957.6 35.1, 353957.3 6689975 35.1, 353973.9 6689967 35.1, 353964.6 6689948.9 35.1, 353946.7 6689957.6 35.1))
BATIMENT0000000302928466;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.4;18.8;31.2;34.1;22.5;Cadastre;A 1.0;POLYGON Z ((354012.3 6689965.6 31.2, 354015.1 6689971.5 31.2, 354017.4 6689970.9 31.2, 354019.3 6689975.1 31.2, 354029.8 6689969.9 31.2, 354029.2 6689968.4 31.2, 354025 6689959.5 31.2, 354012.3 6689965.6 31.2))
BATIMENT0000000302904705;Indifférenciée;Annexe;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.2;18.2;34.4;37.1;21.7;Cadastre;C 0.5;POLYGON Z ((354001 6689978.3 34.4, 354003.5 6689983.8 34.4, 354004.8 6689986.7 34.4, 354011.1 6689983.4 34.4, 354011.6 6689984.8 34.4, 354015 6689983.3 34.4, 354012.1 6689977.1 34.4, 354007.3 6689967 34.4, 353997.8 6689971.5 34.4, 354001 6689978.3 34.4))
BATIMENT0000000302904703;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.6;17.8;30.5;34.5;21.7;Cadastre;A 1.0;POLYGON Z ((353990.1 6689975.2 30.5, 353997.2 6689989.9 30.5, 354004.8 6689986.7 30.5, 354003.5 6689983.8 30.5, 354001 6689978.3 30.5, 353997.8 6689971.5 30.5, 353990.1 6689975.2 30.5))
BATIMENT0000000302904704;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1918-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;14;23;11.9;17.5;29.5;33.9;21.3;Cadastre;A 1.0;POLYGON Z ((353986.7 6689991.6 29.5, 353988.1 6689993.7 29.5, 353989.6 6689993.3 29.5, 353989.9 6689993.6 29.5, 353994 6689991.5 29.5, 353994.8 6689991.8 29.5, 353997.5 6689990.6 29.5, 353997.2 6689989.9 29.5, 353990.1 6689975.2 29.5, 353980.7 6689979.7 29.5, 353986.7 6689991.6 29.5))
BATIMENT0000000302904706;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 17:38:43;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;11.2;17.1;28.4;37.2;19.6;Cadastre;C 0.8;POLYGON Z ((353965.8 6689987 28.4, 353962.1 6690005.3 28.4, 353967.4 6690006.2 28.4, 353968.5 6690001.1 28.4, 353967.3 6689997.7 28.4, 353981.7 6689990.8 28.4, 353983.1 6689993.8 28.4, 353986.7 6689991.6 28.4, 353980.7 6689979.7 28.4, 353965.8 6689987 28.4))
BATIMENT0000000302929147;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;21.2;;;;Cadastre;;POLYGON Z ((354014.5 6689994 -1000, 354009.2 6689996.3 -1000, 354010.3 6689998.7 -1000, 354012.3 6690002.9 -1000, 354017.5 6690000.5 -1000, 354016.6 6689998.4 -1000, 354015.6 6689996.3 -1000, 354014.5 6689994 -1000))
BATIMENT0000000302906064;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 17:38:43;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;19.5;;;;Cadastre;;POLYGON Z ((353988 6690000.7 -1000, 353990.4 6690005.5 -1000, 353993.1 6690004.1 -1000, 353990.7 6689999.4 -1000, 353988 6690000.7 -1000))
BATIMENT0000000302928469;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;20.6;34.2;37.0;22.1;Cadastre;;POLYGON Z ((354039.8 6689960.8 34.2, 354039.3 6689959.8 34.2, 354037.8 6689960.6 34.2, 354038.3 6689961.5 34.2, 354039.8 6689960.8 34.2))
BATIMENT0000000302928468;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;11.9;19.5;31.4;34.3;22.6;Cadastre;A 1.0;POLYGON Z ((354038.3 6689961.5 31.4, 354037.8 6689960.6 31.4, 354039.3 6689959.8 31.4, 354040.7 6689959 31.4, 354038 6689953.1 31.4, 354025 6689959.5 31.4, 354029.2 6689968.4 31.4, 354039.3 6689963.5 31.4, 354038.3 6689961.5 31.4))
BATIMENT0000000302929151;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.4;24.0;30.5;33.4;24.6;Cadastre;;POLYGON Z ((354095 6689962.6 30.5, 354095.9 6689964.1 30.5, 354098.4 6689963.1 30.5, 354097.7 6689961.4 30.5, 354095 6689962.6 30.5))
BATIMENT0000000302929150;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.9;23.8;28.7;33.0;24.7;Cadastre;;POLYGON Z ((354078.2 6689967.3 28.7, 354079.5 6689970.1 28.7, 354088.7 6689965.8 28.7, 354091.1 6689964.6 28.7, 354089.6 6689961.8 28.7, 354078.2 6689967.3 28.7))
BATIMENT0000000302928467;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;21.7;25.0;30.5;22.8;Cadastre;;POLYGON Z ((354029.8 6689969.9 25, 354030.8 6689971.6 25, 354039.1 6689967.6 25, 354038.6 6689966.6 25, 354040.4 6689965.8 25, 354039.3 6689963.5 25, 354029.2 6689968.4 25, 354029.8 6689969.9 25))
BATIMENT0000000302927328;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;24.6;27.4;28.7;25.3;Cadastre;;POLYGON Z ((354066.7 6689984.6 27.4, 354069.5 6689990.7 27.4, 354071.3 6689989.8 27.4, 354068.5 6689983.6 27.4, 354066.7 6689984.6 27.4))
BATIMENT0000000302927329;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.8;25.2;34.0;36.9;26.1;Cadastre;A 1.0;POLYGON Z ((354091.4 6689995.7 34, 354092.2 6689997.6 34, 354095.9 6690005.2 34, 354105.6 6689998.8 34, 354101.6 6689990.9 34, 354100.1 6689987.9 34, 354099.3 6689986 34, 354099.2 6689986 34, 354096 6689987.6 34, 354095.3 6689990 34, 354096.8 6689993.1 34, 354091.4 6689995.7 34))
BATIMENT0000000302927325;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;24.2;27.5;35.5;25.3;Cadastre;;POLYGON Z ((354051.9 6689984.1 27.5, 354039.1 6689990.6 27.5, 354051.7 6690015.8 27.5, 354056.3 6690013.7 27.5, 354046.3 6689992.6 27.5, 354067.7 6689982 27.5, 354065.6 6689977.3 27.5, 354051.9 6689984.1 27.5))
BATIMENT0000000302927326;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;9.5;24.8;34.4;39.1;25.9;Cadastre;A 1.0;POLYGON Z ((354090.3 6689998.5 34.4, 354089.2 6689996.5 34.4, 354076.9 6690001.9 34.4, 354082.4 6690013.7 34.4, 354095.9 6690005.2 34.4, 354092.2 6689997.6 34.4, 354090.3 6689998.5 34.4))
BATIMENT0000000302934007;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;24.9;36.7;40.5;25.3;Cadastre;;POLYGON Z ((354061.2 6690007.2 36.7, 354063.9 6690012.7 36.7, 354065.2 6690012.1 36.7, 354062.6 6690006.5 36.7, 354061.2 6690007.2 36.7))
BATIMENT0000000302934009;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;00;00;13.5;24.7;38.3;41.6;25.7;Cadastre;A 1.0;POLYGON Z ((354062.6 6690006.5 38.3, 354065.2 6690012.1 38.3, 354068.8 6690019.9 38.3, 354076.6 6690016.1 38.3, 354077.1 6690016.5 38.3, 354082.4 6690013.7 38.3, 354076.9 6690001.9 38.3, 354076.2 6690000.3 38.3, 354062.6 6690006.5 38.3))
BATIMENT0000000302927327;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;3.5;22.6;26.1;30.6;25.6;Cadastre;C 0.1;POLYGON Z ((354031.2 6689999.5 26.1, 354026.2 6690001.8 26.1, 354028.7 6690007.3 26.1, 354036.1 6690022.8 26.1, 354041.3 6690020.6 26.1, 354031.2 6689999.5 26.1))
BATIMENT0000000302934013;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;24.8;34.5;36.2;25.2;Cadastre;;POLYGON Z ((354057.4 6690014.6 34.5, 354058 6690015.6 34.5, 354059.1 6690015.1 34.5, 354058.6 6690014 34.5, 354057.4 6690014.6 34.5))
BATIMENT0000000302934100;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.3;24.9;37.2;37.6;26.2;Cadastre;;POLYGON Z ((354101.4 6690014.4 37.2, 354101.3 6690013.6 37.2, 354101.2 6690013.6 37.2, 354101 6690013.6 37.2, 354100.7 6690013.7 37.2, 354100.5 6690013.8 37.2, 354100.3 6690013.8 37.2, 354100.2 6690013.8 37.2, 354099.8 6690014 37.2, 354099.1 6690014.3 37.2, 354098.7 6690014.4 37.2, 354098.5 6690014.6 37.2, 354098.4 6690014.6 37.2, 354098.2 6690014.7 37.2, 354097.2 6690015.3 37.2, 354097.1 6690015.4 37.2, 354096.8 6690015.6 37.2, 354096.5 6690015.9 37.2, 354096.1 6690016.2 37.2, 354095.8 6690016.6 37.2, 354095.4 6690016.9 37.2, 354095.2 6690017.3 37.2, 354095.6 6690017.9 37.2, 354101.4 6690014.4 37.2))
BATIMENT0000000302934008;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;00;00;13.1;24.8;37.9;40.5;25.4;Cadastre;C 0.7;POLYGON Z ((354061.4 6690014 37.9, 354059.7 6690010.9 37.9, 354057.7 6690012 37.9, 354058.6 6690014 37.9, 354059.1 6690015.1 37.9, 354058 6690015.6 37.9, 354057.4 6690014.6 37.9, 354056.4 6690015.1 37.9, 354056.7 6690016.1 37.9, 354052.7 6690018 37.9, 354052 6690016.4 37.9, 354048.9 6690018 37.9, 354049.6 6690019.5 37.9, 354053.7 6690028.4 37.9, 354069.3 6690021.2 37.9, 354068.8 6690019.9 37.9, 354065.2 6690012.1 37.9, 354063.9 6690012.7 37.9, 354061.4 6690014 37.9))
BATIMENT0000000302934010;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;25.0;34.0;37.7;25.5;Cadastre;;POLYGON Z ((354037.3 6690025.1 34, 354049.6 6690019.5 34, 354048.9 6690018 34, 354049 6690017 34, 354048.2 6690015.2 34, 354045.4 6690016.7 34, 354046 6690018.3 34, 354041.3 6690020.6 34, 354036.1 6690022.8 34, 354037.3 6690025.1 34))
BATIMENT0000000302934011;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;24.5;39.0;40.9;25.3;Cadastre;;POLYGON Z ((354041.6 6690034.1 39, 354053.7 6690028.4 39, 354049.6 6690019.5 39, 354037.3 6690025.1 39, 354041.6 6690034.1 39))
BATIMENT0000000302934098;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;25.4;37.9;39.0;26.2;Cadastre;;POLYGON Z ((354094 6690025.6 37.9, 354093.1 6690025.7 37.9, 354093.2 6690025.9 37.9, 354093.3 6690026.4 37.9, 354093.4 6690026.9 37.9, 354093.6 6690027.3 37.9, 354093.8 6690027.8 37.9, 354094 6690028.2 37.9, 354094.2 6690028.6 37.9, 354094.5 6690029 37.9, 354094.7 6690029.4 37.9, 354095 6690029.8 37.9, 354095.3 6690030.2 37.9, 354095.6 6690030.5 37.9, 354096 6690030.9 37.9, 354096.3 6690031.2 37.9, 354096.7 6690031.5 37.9, 354096.9 6690031.7 37.9, 354097.3 6690031.4 37.9, 354094 6690025.6 37.9))
BATIMENT0000000302934012;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.2;24.2;33.5;39.0;25.4;Cadastre;C 0.9;POLYGON Z ((354029.1 6690025.8 33.5, 354033 6690037.1 33.5, 354041.6 6690034.1 33.5, 354037.3 6690025.1 33.5, 354036.1 6690022.8 33.5, 354029.1 6690025.8 33.5))
BATIMENT0000000302934014;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;23;9.5;23.3;32.8;36.0;25.0;Cadastre;C 0.9;POLYGON Z ((354023.8 6690027.7 32.8, 354024.1 6690028.8 32.8, 354020.4 6690030.2 32.8, 354023.5 6690040.3 32.8, 354033 6690037.1 32.8, 354029.1 6690025.8 32.8, 354023.8 6690027.7 32.8))
BATIMENT0000000302934015;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.5;22.6;26.1;27.1;24.1;Cadastre;C 0.2;POLYGON Z ((354026.2 6690001.8 26.1, 354023.2 6690003.3 26.1, 354025.6 6690008.7 26.1, 354028.7 6690007.3 26.1, 354026.2 6690001.8 26.1))
BATIMENT0000000302934017;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.2;22.6;25.8;27.0;23.8;Cadastre;C 0.3;POLYGON Z ((354018.2 6690005.7 25.8, 354020.5 6690011 25.8, 354023.3 6690009.6 25.8, 354025.6 6690008.7 25.8, 354023.2 6690003.3 25.8, 354018.2 6690005.7 25.8))
BATIMENT0000000302919116;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;02;09;4.5;22.2;26.7;29.7;23.1;Cadastre;C 0.3;POLYGON Z ((353996.5 6690010.6 26.7, 353997.8 6690013.4 26.7, 353998.3 6690014 26.7, 354002.7 6690011.8 26.7, 354001 6690008.5 26.7, 353996.5 6690010.6 26.7))
BATIMENT0000000302919114;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;21.4;;;;Cadastre;;POLYGON Z ((353993.6 6690012.3 -1000, 353995.1 6690014.8 -1000, 353997.8 6690013.4 -1000, 353996.5 6690010.6 -1000, 353993.6 6690012.3 -1000))
BATIMENT0000000302935047;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.7;22.4;31.1;33.6;24.0;Cadastre;C 0.3;POLYGON Z ((354003 6690017 31.1, 354003.4 6690018.3 31.1, 354000.4 6690019.8 31.1, 354001.3 6690024.1 31.1, 354015.7 6690017.3 31.1, 354013.3 6690012 31.1, 354003 6690017 31.1))
BATIMENT0000000302919117;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;20.8;;;;Cadastre;;POLYGON Z ((353967.1 6690022.4 -1000, 353967.4 6690020.9 -1000, 353964.8 6690020.4 -1000, 353964.7 6690021 -1000, 353964.2 6690023.3 -1000, 353967.1 6690022.4 -1000))
BATIMENT0000000302919115;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:28:24;2022-07-30 23:16:38;1925-01-01;;;;BDParcellaire;5.0;Pas de Z;9999.0;0.0;1.0;01;02;;20.8;;;;Cadastre;C 0.2;POLYGON Z ((353959.2 6690019.9 -1000, 353958.2 6690025.3 -1000, 353964.2 6690023.3 -1000, 353964.7 6690021 -1000, 353959.2 6690019.9 -1000))
BATIMENT0000000302934016;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;50;20;7.5;23.3;30.9;35.1;24.2;Cadastre;A 1.0;POLYGON Z ((354016.5 6690031.6 30.9, 354017 6690033.5 30.9, 354011.6 6690035.4 30.9, 354003.8 6690037.3 30.9, 354005.5 6690045.5 30.9, 354023.5 6690040.3 30.9, 354020.4 6690030.2 30.9, 354016.5 6690031.6 30.9))
BATIMENT0000000302918464;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;21.7;28.5;29.9;23.6;Cadastre;;POLYGON Z ((353982.1 6690039.3 28.5, 353982.2 6690041.5 28.5, 353991.1 6690039.3 28.5, 353990.6 6690037.1 28.5, 353982.1 6690039.3 28.5))
BATIMENT0000000302918463;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.4;22.3;29.7;34.5;23.8;Cadastre;A 0.8;POLYGON Z ((353990.1 6690033.8 29.7, 353990.6 6690037.1 29.7, 353991.1 6690039.3 29.7, 353992.8 6690048.7 29.7, 353998.7 6690047.2 29.7, 353997.1 6690038.6 29.7, 353999.1 6690038.3 29.7, 353998.3 6690034.1 29.7, 353997.8 6690032 29.7, 353990.1 6690033.8 29.7))
BATIMENT0000000302918508;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:28:24;2023-01-31 17:32:48;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.8;9.4;19.2;41.2;15.4;Cadastre;C 0.2;POLYGON Z ((353893.5 6690026.3 19.2, 353898.4 6690023 19.2, 353892.0022898072 6690016.885732664 19.2, 353892.0022898072 6690024.862198215 19.2, 353893.5 6690026.3 19.2))
BATIMENT0000000302918506;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;35;30;19.0;16.1;35.1;37.8;20.2;Cadastre;A 1.0;POLYGON Z ((353917.8 6690047.8 35.1, 353903.4 6690050.7 35.1, 353912.6 6690062.5 35.1, 353913.3 6690062.3 35.1, 353914.3 6690068.1 35.1, 353925.3 6690065.2 35.1, 353926.4 6690058.9 35.1, 353927.4 6690053.1 35.1, 353931.5 6690053.6 35.1, 353933.3 6690053.8 35.1, 353938.8 6690026.7 35.1, 353925.6 6690022.1 35.1, 353923 6690021.2 35.1, 353917.8 6690047.8 35.1))
BATIMENT0000000302918507;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;3.0;10;20;6.1;15.5;21.6;29.0;19.3;Cadastre;A 1.0;POLYGON Z ((353895.2 6690054.8 21.6, 353896.1 6690056 21.6, 353894.6 6690057 21.6, 353892.0022898072 6690059.189498591 21.6, 353892.0022898072 6690066.643685149 21.6, 353894 6690065.1 21.6, 353899.8 6690072.5 21.6, 353906.8 6690070 21.6, 353914.3 6690068.1 21.6, 353913.3 6690062.3 21.6, 353912.6 6690062.5 21.6, 353909.6 6690063 21.6, 353892.4 6690041 21.6, 353892.4 6690040.9 21.6, 353894.2 6690039.6 21.6, 353893.9 6690038.8 21.6, 353894.4 6690038.4 21.6, 353892.0022898072 6690035.228834907 21.6, 353892.0022898072 6690050.735114162 21.6, 353895.2 6690054.8 21.6))
BATIMENT0000000302918510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;16.1;22.7;24.7;16.7;Cadastre;;POLYGON Z ((353893.6 6690056.1 22.7, 353894.6 6690057 22.7, 353896.1 6690056 22.7, 353895.2 6690054.8 22.7, 353893.6 6690056.1 22.7))
BATIMENT0000000302918509;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;35;20;7.9;19.7;27.7;32.0;20.3;Cadastre;A 1.0;POLYGON Z ((353925.3 6690065.2 27.7, 353935 6690062.7 27.7, 353936.1 6690061.6 27.7, 353937.5 6690054.5 27.7, 353933.3 6690053.8 27.7, 353931.5 6690053.6 27.7, 353931.3 6690056.4 27.7, 353930 6690057.2 27.7, 353929 6690058.5 27.7, 353926.4 6690058.9 27.7, 353925.3 6690065.2 27.7))
BATIMENT0000000302918728;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;30;49;18.1;20.1;38.3;39.5;24.3;Cadastre;C 0.4;POLYGON Z ((353956.8 6690088 38.3, 353953.5 6690073 38.3, 353953.4 6690072.8 38.3, 353936.2 6690076.5 38.3, 353939.4 6690091.9 38.3, 353956.8 6690088 38.3))
BATIMENT0000000302918729;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;34.0;6.0;50;20;11.1;19.6;30.8;41.3;24.2;Cadastre;A 0.5;POLYGON Z ((353913.3 6690081.9 30.8, 353915.8 6690089 30.8, 353918.6 6690096.6 30.8, 353921.7 6690095.9 30.8, 353926.5 6690109 30.8, 353942.4 6690105.9 30.8, 353939.4 6690091.9 30.8, 353936.2 6690076.5 30.8, 353913.3 6690081.9 30.8))
BATIMENT0000000302918730;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;13;9.8;20.2;30.0;38.8;23.5;Cadastre;A 1.0;POLYGON Z ((353908.6 6690091.9 30, 353913.5 6690103.7 30, 353915.1 6690103 30, 353913.7 6690099.3 30, 353917.3 6690097.9 30, 353918.5 6690101.5 30, 353920.2 6690100.8 30, 353918.6 6690096.6 30, 353915.8 6690089 30, 353908.6 6690091.9 30))
BATIMENT0000002011295361;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:32:49;2013-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;25.0;7.0;00;00;21.4;17.6;;39.0;23.1;Imagerie aérienne;A 1.0;POLYGON Z ((353893.7 6690112.9 38.4, 353897 6690111.9 38.4, 353893.9 6690103.2 38.5, 353903.5 6690099.4 38.6, 353903 6690098 38.6, 353908.3 6690095.9 38.6, 353905.3 6690087.7 39, 353904.6 6690085.8 36.2, 353902.8 6690081.6 21.7, 353892.0022898072 6690086.093457037 21.7, 353892.0022898072 6690113.668011754 38.4, 353893.7 6690112.9 38.4))
BATIMENT0000000302919132;Indifférenciée;Annexe;;Oui;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;3.9;21.2;25.2;27.5;24.2;Cadastre;A 0.1;POLYGON Z ((353924.5 6690116.8 25.2, 353925.9 6690120.1 25.2, 353943.3 6690116.1 25.2, 353942.6 6690112.7 25.2, 353924.5 6690116.8 25.2))
BATIMENT0000000302934026;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1978-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;10.4;24.8;35.2;43.0;25.9;Cadastre;A 1.0;POLYGON Z ((354069.2 6690055 35.2, 354074.9 6690054.9 35.2, 354083.8 6690054.8 35.2, 354084 6690037.3 35.2, 354070 6690037.3 35.2, 354067.9 6690038.3 35.2, 354068.8 6690050.2 35.2, 354069.2 6690055 35.2))
BATIMENT0000000302934024;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;17.3;24.6;42.0;44.4;25.9;Cadastre;A 1.0;POLYGON Z ((354050.9 6690045.7 42, 354054.6 6690055 42, 354055.1 6690056.2 42, 354068.8 6690050.2 42, 354067.9 6690038.3 42, 354050.9 6690045.7 42))
BATIMENT0000000302934025;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.7;24.4;37.2;42.7;26.0;Cadastre;A 1.0;POLYGON Z ((354044.5 6690048.7 37.2, 354044.5 6690058.3 37.2, 354044.9 6690058.7 37.2, 354045.5 6690058.9 37.2, 354054.6 6690055 37.2, 354050.9 6690045.7 37.2, 354044.5 6690048.7 37.2))
BATIMENT0000000302934027;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;9.0;24.4;33.4;34.7;25.9;Cadastre;A 1.0;POLYGON Z ((354043.3 6690064.3 33.4, 354043.3 6690049.2 33.4, 354033.2 6690053.6 33.4, 354033.2 6690062.5 33.4, 354037.2 6690062.4 33.4, 354037.3 6690064.5 33.4, 354043.3 6690064.3 33.4))
BATIMENT0000000302934028;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;50;20;9.4;24.4;33.8;36.7;25.2;Cadastre;A 1.0;POLYGON Z ((354023.8 6690056 33.8, 354023.7 6690062.5 33.8, 354026.3 6690062.5 33.8, 354029.2 6690062.5 33.8, 354029.3 6690064.8 33.8, 354033.2 6690065 33.8, 354033.3 6690064.6 33.8, 354033.2 6690062.5 33.8, 354033.2 6690053.6 33.8, 354023.8 6690056 33.8))
BATIMENT0000000302934035;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;24.8;30.0;32.7;25.4;Cadastre;;POLYGON Z ((354037.3 6690064.5 30, 354037.2 6690062.4 30, 354033.2 6690062.5 30, 354033.3 6690064.6 30, 354037.3 6690064.5 30))
BATIMENT0000000302935211;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.5;24.9;34.4;37.0;26.6;Cadastre;A 1.0;POLYGON Z ((354083.4 6690061.8 34.4, 354077.3 6690061.5 34.4, 354077.3 6690062.8 34.4, 354075 6690062.6 34.4, 354072.9 6690062.6 34.4, 354072.1 6690074.9 34.4, 354082.3 6690075.6 34.4, 354083.4 6690061.8 34.4))
BATIMENT0000000302935209;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;8.3;24.9;33.2;36.1;26.4;Cadastre;A 1.0;POLYGON Z ((354070.3 6690074.8 33.2, 354069.8 6690084.2 33.2, 354070.4 6690084.3 33.2, 354081.6 6690085.1 33.2, 354082.3 6690075.6 33.2, 354072.1 6690074.9 33.2, 354070.3 6690074.8 33.2))
BATIMENT0000000029199111;Indifférenciée;Annexe;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1953-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;00;00;2.8;25.7;;32.5;26.2;Imagerie aérienne;B 0.3;POLYGON Z ((354062.9 6690081.1 28.3, 354060.7 6690080.6 28.3, 354042.4 6690087.4 28.3, 354043.4 6690094.9 28.3, 354047.6 6690094.7 28.3, 354052.4 6690089.8 28.5, 354053.9 6690091 28.5, 354056 6690088.6 28.5, 354057.4 6690089.7 28.5, 354059.5 6690087.6 28.5, 354060.8 6690088.5 28.5, 354063.1 6690086 28.5, 354064.1 6690087 28.5, 354066.7 6690084.3 28.3, 354062.9 6690081.1 28.3))
BATIMENT0000000302935208;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.8;24.8;33.6;37.7;25.9;Cadastre;A 1.0;POLYGON Z ((354070.2 6690085.8 33.6, 354071.8 6690086 33.6, 354071.7 6690087.1 33.6, 354071.5 6690091.8 33.6, 354076 6690092.1 33.6, 354077.8 6690091.1 33.6, 354081.1 6690091.3 33.6, 354081.6 6690085.1 33.6, 354070.4 6690084.3 33.6, 354070.2 6690085.8 33.6))
BATIMENT0000000302918462;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;7.6;22.6;30.2;33.0;23.8;Cadastre;A 1.0;POLYGON Z ((353997.1 6690038.6 30.2, 353998.7 6690047.2 30.2, 354005.5 6690045.5 30.2, 354003.8 6690037.3 30.2, 353999.1 6690038.3 30.2, 353997.1 6690038.6 30.2))
BATIMENT0000000302918465;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;22.3;29.6;32.5;23.5;Cadastre;A 1.0;POLYGON Z ((353981.6 6690041.5 29.6, 353981.4 6690051.6 29.6, 353992.8 6690048.7 29.6, 353991.1 6690039.3 29.6, 353982.2 6690041.5 29.6, 353981.6 6690041.5 29.6))
BATIMENT0000000302918466;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;7.0;05;02;16.7;20.0;36.7;42.3;22.5;Cadastre;A 1.0;POLYGON Z ((353974.9 6690053.1 36.7, 353978.9 6690052.1 36.7, 353979.4 6690048.8 36.7, 353980.8 6690039.6 36.7, 353957.1 6690036.2 36.7, 353956.9 6690037.1 36.7, 353953.2 6690055.8 36.7, 353955.4 6690058.1 36.7, 353964.6 6690055.7 36.7, 353974.9 6690053.1 36.7))
BATIMENT0000000302934029;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;23.1;33.2;35.0;23.5;Cadastre;;POLYGON Z ((354009.7 6690053.4 33.2, 354008.8 6690053.6 33.2, 354009.4 6690056 33.2, 354014 6690055.2 33.2, 354013.6 6690054.8 33.2, 354013.6 6690054.2 33.2, 354013.8 6690053.9 33.2, 354014.1 6690053.7 33.2, 354013.5 6690052.5 33.2, 354009.7 6690053.4 33.2))
BATIMENT0000000302934034;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.0;24.4;34.4;;;Cadastre;;POLYGON Z ((354018.9 6690054.7 34.4, 354018.9 6690054.8 34.4, 354019.4 6690057.1 34.4, 354022.9 6690056.2 34.4, 354022.3 6690053.8 34.4, 354018.9 6690054.7 34.4))
BATIMENT0000000302918731;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;90;23;9.2;21.5;30.7;36.6;24.5;Cadastre;A 1.0;POLYGON Z ((353983.8 6690068.2 30.7, 353983.6 6690066.5 30.7, 353987.4 6690065.8 30.7, 353985.9 6690058.4 30.7, 353969 6690062.7 30.7, 353970.8 6690071.2 30.7, 353983.8 6690068.2 30.7))
BATIMENT0000000302918727;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;20;90;12.2;21.0;33.2;36.7;24.3;Cadastre;C 0.1;POLYGON Z ((353956.4 6690065.8 33.2, 353957.8 6690072 33.2, 353958.3 6690074.2 33.2, 353970.8 6690071.2 33.2, 353969 6690062.7 33.2, 353956.4 6690065.8 33.2))
BATIMENT0000000302918726;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;20.4;29.3;35.0;24.0;Cadastre;;POLYGON Z ((353953.5 6690073 29.3, 353957.8 6690072 29.3, 353956.4 6690065.8 29.3, 353952.2 6690067 29.3, 353953.4 6690072.8 29.3, 353953.5 6690073 29.3))
BATIMENT0000000302934036;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;23.8;27.5;34.0;25.3;Cadastre;;POLYGON Z ((354023.6 6690068.1 27.5, 354023.5 6690076.9 27.5, 354026.7 6690076 27.5, 354026.3 6690062.5 27.5, 354023.7 6690062.5 27.5, 354023.6 6690068.1 27.5))
BATIMENT0000000302918980;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;5.0;00;00;10.5;23.9;34.4;38.7;25.2;Cadastre;A 1.0;POLYGON Z ((354018.5 6690053.8 34.4, 354018.3 6690053.4 34.4, 354017.8 6690053.1 34.4, 354017.1 6690053.1 34.4, 354014.1 6690053.7 34.4, 354013.8 6690053.9 34.4, 354013.6 6690054.2 34.4, 354013.6 6690054.8 34.4, 354014 6690055.2 34.4, 354009.4 6690056 34.4, 354008.8 6690053.6 34.4, 354004 6690054.8 34.4, 353999.2 6690056 34.4, 353998 6690058.1 34.4, 354004.5 6690089.4 34.4, 354005.7 6690094.9 34.4, 354008.6 6690108.5 34.4, 354017.2 6690106.7 34.4, 354017 6690105.9 34.4, 354017.4 6690105.8 34.4, 354020.7 6690104.9 34.4, 354019.9 6690101.6 34.4, 354018.5 6690095.1 34.4, 354020.2 6690094.8 34.4, 354019 6690089.4 34.4, 354017.5 6690089.7 34.4, 354015.7 6690081.5 34.4, 354013.2 6690070.5 34.4, 354023.6 6690068.1 34.4, 354023.7 6690062.5 34.4, 354023.8 6690056 34.4, 354022.9 6690056.2 34.4, 354019.4 6690057.1 34.4, 354018.9 6690054.8 34.4, 354018.9 6690054.7 34.4, 354018.5 6690053.8 34.4))
BATIMENT0000000302931396;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;17.6;6.1;23.7;29.7;6.7;Cadastre;C 0.9;POLYGON Z ((355325.9 6689305.3 23.7, 355335.5 6689311.1 23.7, 355342.4 6689313.9 23.7, 355343.9 6689311.1 23.7, 355345.1 6689311.7 23.7, 355343.6 6689314.5 23.7, 355357.6 6689322.4 23.7, 355359.4 6689318.9 23.7, 355338.3 6689304.6 23.7, 355328.4 6689300 23.7, 355326.3 6689304.1 23.7, 355325.9 6689305.3 23.7), (355336.8 6689307.1 23.7, 355338.4 6689307.7 23.7, 355337.7 6689309.2 23.7, 355336.1 6689308.6 23.7, 355336.8 6689307.1 23.7))
BATIMENT0000000302931408;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.2;5.9;25.2;27.4;8.5;Cadastre;;POLYGON Z ((355303.9 6689324.3 25.2, 355306.5 6689318.8 25.2, 355304.8 6689317.9 25.2, 355306.5 6689314.2 25.2, 355308.8 6689309.2 25.2, 355306.6 6689307.7 25.2, 355305.9 6689308.9 25.2, 355299.4 6689322.2 25.2, 355303.9 6689324.3 25.2))
BATIMENT0000000302931402;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;12;20;19.3;5.7;25.0;29.0;6.7;Cadastre;A 1.0;POLYGON Z ((355357.6 6689322.4 25, 355343.6 6689314.5 25, 355342.4 6689313.9 25, 355335.5 6689311.1 25, 355325.9 6689305.3 25, 355322.8 6689311.2 25, 355321 6689314.7 25, 355324.5 6689316.6 25, 355323.3 6689318.6 25, 355326.5 6689320.6 25, 355327.1 6689319.8 25, 355328.7 6689320.6 25, 355326.5 6689324.4 25, 355328.9 6689325.2 25, 355329.5 6689324.1 25, 355331.9 6689318.2 25, 355341 6689320.9 25, 355354.6 6689328.4 25, 355357.6 6689322.4 25))
BATIMENT0000000302931409;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.6;6.5;25.2;28.1;8.4;Cadastre;;POLYGON Z ((355306.5 6689314.2 25.2, 355304.8 6689317.9 25.2, 355306.5 6689318.8 25.2, 355303.9 6689324.3 25.2, 355305.8 6689325.1 25.2, 355308.3 6689319.7 25.2, 355309.7 6689320.2 25.2, 355311.5 6689316.4 25.2, 355306.5 6689314.2 25.2))
BATIMENT0000000302931407;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;20.1;5.5;25.7;28.1;8.3;Cadastre;A 1.0;POLYGON Z ((355318.9 6689331.2 25.7, 355321.6 6689325.4 25.7, 355318.3 6689323.9 25.7, 355319.8 6689320.5 25.7, 355320.5 6689320.8 25.7, 355321.5 6689318.1 25.7, 355321.3 6689317.2 25.7, 355313.5 6689312.3 25.7, 355311.5 6689316.4 25.7, 355309.7 6689320.2 25.7, 355308.3 6689319.7 25.7, 355305.8 6689325.1 25.7, 355318.9 6689331.2 25.7))
BATIMENT0000000302931411;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;23;20;21.1;5.9;27.0;29.5;7.1;Cadastre;A 1.0;POLYGON Z ((355354.6 6689328.4 27, 355341 6689320.9 27, 355331.9 6689318.2 27, 355329.5 6689324.1 27, 355334.2 6689325.9 27, 355334.7 6689324.6 27, 355338.8 6689326.1 27, 355338.3 6689327.5 27, 355342.5 6689329.2 27, 355347.5 6689331.1 27, 355346.6 6689333.3 27, 355351.1 6689335.2 27, 355354.6 6689328.4 27))
BATIMENT0000000302931412;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;00;00;20.8;5.9;26.7;28.3;8.2;Cadastre;A 1.0;POLYGON Z ((355339.5 6689340.6 26.7, 355343.1 6689331.8 26.7, 355341.6 6689331.2 26.7, 355342.5 6689329.2 26.7, 355338.3 6689327.5 26.7, 355337.4 6689327.2 26.7, 355336.6 6689329.3 26.7, 355334.5 6689328.4 26.7, 355335.2 6689326.4 26.7, 355334.2 6689325.9 26.7, 355329.5 6689324.1 26.7, 355328.9 6689325.2 26.7, 355327.8 6689328.8 26.7, 355326 6689328 26.7, 355326.1 6689327.7 26.7, 355321.6 6689325.4 26.7, 355318.9 6689331.2 26.7, 355339.5 6689340.6 26.7))
BATIMENT0000000302931413;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;5.0;;;17.6;7.1;24.7;28.3;7.8;Cadastre;A 1.0;POLYGON Z ((355345.2 6689343.3 24.7, 355347.1 6689342.9 24.7, 355351.1 6689335.2 24.7, 355346.6 6689333.3 24.7, 355343.1 6689331.8 24.7, 355339.5 6689340.6 24.7, 355345.2 6689343.3 24.7))
BATIMENT0000000302930951;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.0;6.6;24.6;26.2;7.0;Cadastre;;POLYGON Z ((355402.9 6689350 24.6, 355405 6689346.3 24.6, 355403.6 6689345.6 24.6, 355401.4 6689349.2 24.6, 355402.9 6689350 24.6))
BATIMENT0000000302930400;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;;;16.6;7.1;23.7;29.0;8.7;Cadastre;A 1.0;POLYGON Z ((355293.9 6689355.8 23.7, 355293.8 6689356 23.7, 355298.7 6689359.2 23.7, 355302.8 6689352.3 23.7, 355303.6 6689350.9 23.7, 355311 6689338.5 23.7, 355306.2 6689336.4 23.7, 355300.7 6689344.5 23.7, 355302.7 6689345.6 23.7, 355300.8 6689349.5 23.7, 355298 6689348.1 23.7, 355293.9 6689355.8 23.7))
BATIMENT0000000302931248;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;15.8;7.3;23.2;25.1;8.0;Cadastre;C 0.3;POLYGON Z ((355461.5 6689335 23.2, 355454 6689333.3 23.2, 355449.6 6689332.5 23.2, 355449.2 6689334.6 23.2, 355451.2 6689335 23.2, 355450.5 6689337.3 23.2, 355453.8 6689338.1 23.2, 355460.6 6689339.8 23.2, 355461.5 6689335 23.2))
BATIMENT0000000302931247;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;12;20;14.0;7.9;21.9;25.6;8.0;Cadastre;A 1.0;POLYGON Z ((355445.9 6689345.8 21.9, 355448.6 6689336.8 21.9, 355449.2 6689334.6 21.9, 355449.6 6689332.5 21.9, 355450.2 6689329.8 21.9, 355450.4 6689328.2 21.9, 355444.6 6689327.1 21.9, 355442.4 6689336.6 21.9, 355443.2 6689336.8 21.9, 355441.8 6689344.1 21.9, 355445.9 6689345.8 21.9))
BATIMENT0000000302930919;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;7.0;10;20;18.9;8.0;26.9;33.0;8.8;Cadastre;C 0.7;POLYGON Z ((355461.7 6689350.5 26.9, 355474.7 6689355.2 26.9, 355485.3 6689327.1 26.9, 355468.3 6689323.4 26.9, 355461.7 6689350.5 26.9))
BATIMENT0000000302931251;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;7.6;19.7;24.7;8.0;Cadastre;;POLYGON Z ((355460.6 6689339.8 19.7, 355453.8 6689338.1 19.7, 355452.6 6689343 19.7, 355459.5 6689344.8 19.7, 355460.6 6689339.8 19.7))
BATIMENT0000000302931250;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;12.9;7.9;20.8;26.0;8.0;Cadastre;A 1.0;POLYGON Z ((355450.9 6689348 20.8, 355450.8 6689348.7 20.8, 355458.4 6689350.8 20.8, 355459.5 6689344.8 20.8, 355452.6 6689343 20.8, 355453.8 6689338.1 20.8, 355450.5 6689337.3 20.8, 355448.6 6689336.8 20.8, 355445.9 6689345.8 20.8, 355450.9 6689348 20.8))
BATIMENT0000000302930943;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;7.0;10;20;19.8;6.6;26.5;28.1;7.4;Cadastre;B 0.3;POLYGON Z ((355428 6689343.9 26.5, 355412.8 6689338.2 26.5, 355404.7 6689350.7 26.5, 355411 6689352.6 26.5, 355412.1 6689350.8 26.5, 355413.1 6689349 26.5, 355423.9 6689353.4 26.5, 355428 6689344.2 26.5, 355428 6689343.9 26.5))
BATIMENT0000000302930942;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;20;20;16.2;7.6;23.8;;;Cadastre;A 1.0;POLYGON Z ((355428 6689344.2 23.8, 355423.9 6689353.4 23.8, 355425.9 6689354.2 23.8, 355426.2 6689355.3 23.8, 355425.3 6689357.2 23.8, 355426.1 6689357.6 23.8, 355429.8 6689359.4 23.8, 355434.6 6689346.6 23.8, 355428 6689344.2 23.8))
BATIMENT0000000302930947;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.0;6.6;24.6;;;Cadastre;;POLYGON Z ((355409.1 6689356 24.6, 355412.8 6689358.2 24.6, 355415.9 6689352.6 24.6, 355412.1 6689350.8 24.6, 355411 6689352.6 24.6, 355409.1 6689356 24.6))
BATIMENT0000000302930939;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;00;00;16.4;7.5;23.9;;;Cadastre;A 1.0;POLYGON Z ((355437.4 6689352.4 23.9, 355438.8 6689348.1 23.9, 355434.6 6689346.6 23.9, 355429.8 6689359.4 23.9, 355428.8 6689362 23.9, 355433.3 6689363.2 23.9, 355434.4 6689361.6 23.9, 355434.9 6689360.1 23.9, 355435.2 6689359.1 23.9, 355432.9 6689358.5 23.9, 355434.3 6689354.6 23.9, 355436.4 6689355.3 23.9, 355437.4 6689352.4 23.9))
BATIMENT0000000302930937;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;00;00;16.4;7.3;23.7;25.8;7.6;Cadastre;A 1.0;POLYGON Z ((355437.4 6689352.4 23.7, 355436.4 6689355.3 23.7, 355435.2 6689359.1 23.7, 355435.9 6689359.3 23.7, 355442.5 6689361.8 23.7, 355442.5 6689361.4 23.7, 355442.7 6689360.1 23.7, 355443.2 6689360.2 23.7, 355445.1 6689355 23.7, 355445.9 6689350.8 23.7, 355438.8 6689348.1 23.7, 355437.4 6689352.4 23.7))
BATIMENT0000000302930953;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;20.7;6.7;27.5;29.1;7.7;Cadastre;A 1.0;POLYGON Z ((355401.3 6689333.9 27.5, 355400.3 6689334.3 27.5, 355386.8 6689360.9 27.5, 355387.3 6689362.5 27.5, 355391.9 6689364.7 27.5, 355401.4 6689349.2 27.5, 355403.6 6689345.6 27.5, 355409 6689336.7 27.5, 355401.3 6689333.9 27.5))
BATIMENT0000000302930401;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;17.6;6.9;24.5;30.5;8.3;Cadastre;A 0.7;POLYGON Z ((355302.8 6689352.3 24.5, 355298.7 6689359.2 24.5, 355304.9 6689363.2 24.5, 355305 6689362.9 24.5, 355310.7 6689351.6 24.5, 355316.1 6689340.8 24.5, 355311 6689338.5 24.5, 355303.6 6689350.9 24.5, 355302.8 6689352.3 24.5), (355306.5 6689350.2 24.5, 355309.3 6689351.1 24.5, 355307.5 6689354.5 24.5, 355304.9 6689353.3 24.5, 355306.5 6689350.2 24.5))
BATIMENT0000000302930952;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;10;18.2;6.7;24.9;27.0;7.5;Cadastre;A 1.0;POLYGON Z ((355396.3 6689366.8 24.9, 355400.4 6689358.7 24.9, 355403.8 6689352.1 24.9, 355404.7 6689350.7 24.9, 355412.8 6689338.2 24.9, 355409 6689336.7 24.9, 355403.6 6689345.6 24.9, 355405 6689346.3 24.9, 355402.9 6689350 24.9, 355401.4 6689349.2 24.9, 355391.9 6689364.7 24.9, 355396.3 6689366.8 24.9))
BATIMENT0000000302930405;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;19.4;6.7;26.1;28.9;8.0;Cadastre;A 1.0;POLYGON Z ((355329.4 6689352.8 26.1, 355329.6 6689352.7 26.1, 355332.1 6689348.1 26.1, 355323.4 6689344.1 26.1, 355317.9 6689355 26.1, 355319.7 6689355.9 26.1, 355318.9 6689357.9 26.1, 355325.1 6689360.9 26.1, 355329.4 6689352.8 26.1))
BATIMENT0000000302930402;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;12;10;18.1;6.9;25.0;30.1;8.1;Cadastre;A 1.0;POLYGON Z ((355308.4 6689365.2 25, 355313.7 6689354.8 25, 355312.6 6689354.3 25, 355314.3 6689351.2 25, 355315.3 6689351.7 25, 355320.1 6689342.6 25, 355316.1 6689340.8 25, 355310.7 6689351.6 25, 355305 6689362.9 25, 355308.4 6689365.2 25))
BATIMENT0000000302931216;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.6;7.0;23.6;28.2;8.1;Cadastre;A 1.0;POLYGON Z ((355342.2 6689353.8 23.6, 355341 6689352.1 23.6, 355334.5 6689349.1 23.6, 355331.1 6689355.5 23.6, 355341.3 6689358.1 23.6, 355342.2 6689353.8 23.6))
BATIMENT0000000302930403;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;12;20;17.8;6.9;24.7;30.0;8.0;Cadastre;A 1.0;POLYGON Z ((355311.9 6689367.4 24.7, 355317.9 6689355 24.7, 355323.4 6689344.1 24.7, 355320.1 6689342.6 24.7, 355315.3 6689351.7 24.7, 355316.4 6689352.3 24.7, 355315 6689355.4 24.7, 355313.7 6689354.8 24.7, 355308.4 6689365.2 24.7, 355311.9 6689367.4 24.7))
BATIMENT0000000302930944;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.4;6.7;25.1;;;Cadastre;;POLYGON Z ((355400.4 6689358.7 25.1, 355402.1 6689359.6 25.1, 355405.4 6689352.8 25.1, 355403.8 6689352.1 25.1, 355400.4 6689358.7 25.1))
BATIMENT0000000302930949;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;12;20;18.7;6.6;25.3;25.4;7.2;Cadastre;A 1.0;POLYGON Z ((355406.4 6689371.7 25.3, 355411.3 6689364.1 25.3, 355407.1 6689362 25.3, 355408.8 6689357.6 25.3, 355409.1 6689356 25.3, 355411 6689352.6 25.3, 355404.7 6689350.7 25.3, 355403.8 6689352.1 25.3, 355405.4 6689352.8 25.3, 355402.1 6689359.6 25.3, 355400.4 6689358.7 25.3, 355396.3 6689366.8 25.3, 355406.4 6689371.7 25.3))
BATIMENT0000000302930404;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;00;00;15.0;7.0;22.0;26.0;7.6;Cadastre;A 1.0;POLYGON Z ((355321.3 6689368.3 22, 355325.1 6689360.9 22, 355318.9 6689357.9 22, 355319.7 6689355.9 22, 355317.9 6689355 22, 355311.9 6689367.4 22, 355321.3 6689368.3 22))
BATIMENT0000000302930950;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.1;7.2;24.3;;;Cadastre;;POLYGON Z ((355425.3 6689357.2 24.3, 355426.2 6689355.3 24.3, 355425.9 6689354.2 24.3, 355423.9 6689353.4 24.3, 355422.7 6689356 24.3, 355425.3 6689357.2 24.3))
BATIMENT0000000302930938;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.0;6.5;21.5;22.5;6.9;Cadastre;;POLYGON Z ((355436.4 6689355.3 21.5, 355434.3 6689354.6 21.5, 355432.9 6689358.5 21.5, 355435.2 6689359.1 21.5, 355436.4 6689355.3 21.5))
BATIMENT0000000302930933;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;10;20;16.3;7.0;23.3;26.8;8.1;Cadastre;A 1.0;POLYGON Z ((355456.1 6689354.4 23.3, 355446.5 6689351 23.3, 355445.9 6689350.8 23.3, 355445.1 6689355 23.3, 355443.2 6689360.2 23.3, 355442.7 6689360.1 23.3, 355442.5 6689361.4 23.3, 355445.4 6689362 23.3, 355445.1 6689363.7 23.3, 355442.2 6689363.2 23.3, 355441.8 6689365.8 23.3, 355454 6689367.4 23.3, 355456.1 6689354.4 23.3))
BATIMENT0000000302930948;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.1;6.6;22.7;23.5;6.8;Cadastre;;POLYGON Z ((355408.8 6689357.6 22.7, 355407.1 6689362 22.7, 355411.3 6689364.1 22.7, 355410.3 6689360.8 22.7, 355412.1 6689359.6 22.7, 355412.8 6689358.2 22.7, 355409.1 6689356 22.7, 355408.8 6689357.6 22.7))
BATIMENT0000000302930929;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;90;90;18.9;7.9;26.8;31.5;8.7;Cadastre;A 1.0;POLYGON Z ((355472.6 6689361.7 26.8, 355460.5 6689357.1 26.8, 355459.1 6689366.2 26.8, 355469.6 6689369.7 26.8, 355472.6 6689361.7 26.8))
BATIMENT0000000302930946;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.5;6.5;23.0;25.4;7.1;Cadastre;A 1.0;POLYGON Z ((355411.8 6689374.3 23, 355417.4 6689365 23, 355415.1 6689363.4 23, 355416.8 6689360.2 23, 355419.5 6689361.5 23, 355422.7 6689356 23, 355415.9 6689352.6 23, 355412.8 6689358.2 23, 355412.1 6689359.6 23, 355410.3 6689360.8 23, 355411.3 6689364.1 23, 355406.4 6689371.7 23, 355411.8 6689374.3 23))
BATIMENT0000000302930945;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1871-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;10;20;18.4;6.8;25.2;27.2;7.0;Cadastre;A 1.0;POLYGON Z ((355417.4 6689377 25.2, 355426.1 6689357.6 25.2, 355425.3 6689357.2 25.2, 355422.7 6689356 25.2, 355419.5 6689361.5 25.2, 355417.4 6689365 25.2, 355411.8 6689374.3 25.2, 355417.4 6689377 25.2))
BATIMENT0000000302930941;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;20.7;6.5;27.2;29.5;7.0;Cadastre;A 1.0;POLYGON Z ((355424.6 6689380.4 27.2, 355426.8 6689367.1 27.2, 355428.8 6689362 27.2, 355429.8 6689359.4 27.2, 355426.1 6689357.6 27.2, 355417.4 6689377 27.2, 355424.6 6689380.4 27.2))
BATIMENT0000000302930935;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;6.9;26.5;30.0;7.3;Cadastre;;POLYGON Z ((355448.5 6689370.6 26.5, 355448.8 6689368.3 26.5, 355446.1 6689367.9 26.5, 355445.7 6689370.2 26.5, 355448.5 6689370.6 26.5))
BATIMENT0000000302930940;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;16.7;6.5;23.2;26.7;7.1;Cadastre;A 1.0;POLYGON Z ((355427.9 6689382 23.2, 355430.6 6689367 23.2, 355433.3 6689363.2 23.2, 355428.8 6689362 23.2, 355426.8 6689367.1 23.2, 355424.6 6689380.4 23.2, 355427.9 6689382 23.2))
BATIMENT0000000302931258;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;;;11.6;8.2;19.8;28.4;10.6;Cadastre;A 1.0;POLYGON Z ((355558.8 6689334.5 19.8, 355558.7 6689335.1 19.8, 355557.6 6689350.7 19.8, 355554.8 6689350.5 19.8, 355554.8 6689352.3 19.8, 355555.9 6689352.3 19.8, 355555.3 6689355 19.8, 355548.3 6689354.4 19.8, 355547.9 6689358.9 19.8, 355547.8 6689361.2 19.8, 355550.4 6689361.5 19.8, 355555.2 6689363.8 19.8, 355555.2 6689364.1 19.8, 355557.5 6689365.2 19.8, 355557.5 6689365 19.8, 355572.6 6689372.2 19.8, 355579.5 6689363.9 19.8, 355574.6 6689360.2 19.8, 355576.2 6689358 19.8, 355571.4 6689355.2 19.8, 355569.2 6689353.8 19.8, 355567.3 6689357.4 19.8, 355563.6 6689356.5 19.8, 355565.7 6689347.1 19.8, 355569.3 6689347.8 19.8, 355569.6 6689346.9 19.8, 355572.2 6689337.8 19.8, 355558.8 6689334.5 19.8))
BATIMENT0000000302930957;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.2;8.0;25.2;27.3;9.0;Cadastre;;POLYGON Z ((355495.7 6689357.4 25.2, 355496.6 6689357.5 25.2, 355496.9 6689353.4 25.2, 355494.7 6689353.3 25.2, 355494.5 6689357.4 25.2, 355495.7 6689357.4 25.2))
BATIMENT0000000302930955;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;10;20;17.3;8.0;25.3;30.0;9.6;Cadastre;A 1.0;POLYGON Z ((355506 6689370.5 25.3, 355507.6 6689347 25.3, 355501 6689346.6 25.3, 355500.9 6689348.3 25.3, 355498.1 6689348.1 25.3, 355498.2 6689346.5 25.3, 355495 6689346.3 25.3, 355492.8 6689352.3 25.3, 355492.5 6689353.2 25.3, 355494.7 6689353.3 25.3, 355496.9 6689353.4 25.3, 355496.6 6689357.5 25.3, 355495.7 6689357.4 25.3, 355495.1 6689370 25.3, 355506 6689370.5 25.3))
BATIMENT0000000302931263;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;18.1;8.0;26.1;30.0;10.7;Cadastre;A 1.0;POLYGON Z ((355513 6689361.9 26.1, 355525.5 6689362.5 26.1, 355525.5 6689363.1 26.1, 355529.5 6689363.4 26.1, 355529.5 6689362 26.1, 355525.6 6689361.7 26.1, 355525.7 6689357.5 26.1, 355525.8 6689355.3 26.1, 355518.9 6689355.1 26.1, 355513.4 6689354.9 26.1, 355513 6689361.9 26.1))
BATIMENT0000000302930959;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;17.1;8.0;25.1;29.0;9.3;Cadastre;A 1.0;POLYGON Z ((355483.5 6689360.3 25.1, 355495.1 6689370 25.1, 355495.7 6689357.4 25.1, 355494.5 6689357.4 25.1, 355493 6689357.4 25.1, 355493 6689357.2 25.1, 355493 6689357.1 25.1, 355493 6689357 25.1, 355492.9 6689356.9 25.1, 355492.7 6689356.8 25.1, 355492.7 6689356.7 25.1, 355492.5 6689356.7 25.1, 355492.4 6689356.7 25.1, 355492.3 6689356.7 25.1, 355492.2 6689356.7 25.1, 355492.1 6689356.8 25.1, 355492 6689356.9 25.1, 355492 6689357 25.1, 355491.9 6689357 25.1, 355491.9 6689357.2 25.1, 355491.9 6689357.3 25.1, 355490.9 6689357.3 25.1, 355492.5 6689353.2 25.1, 355492.8 6689352.3 25.1, 355487.3 6689350.2 25.1, 355483.5 6689360.3 25.1))
BATIMENT0000000302931265;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;14.7;9.4;24.1;30.0;10.8;Cadastre;A 1.0;POLYGON Z ((355512.6 6689371.5 24.1, 355521.5 6689372 24.1, 355521.5 6689371.7 24.1, 355524.9 6689371.9 24.1, 355524.9 6689372.2 24.1, 355529.2 6689372.5 24.1, 355529.5 6689363.4 24.1, 355525.5 6689363.1 24.1, 355525.5 6689362.5 24.1, 355513 6689361.9 24.1, 355512.6 6689371.5 24.1))
BATIMENT0000000302931255;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.0;9.5;19.5;27.0;10.6;Cadastre;A 1.0;POLYGON Z ((355546.2 6689378.4 19.5, 355546 6689380.7 19.5, 355554.6 6689381.4 19.5, 355554.6 6689381 19.5, 355555.2 6689364.1 19.5, 355555.2 6689363.8 19.5, 355550.4 6689361.5 19.5, 355547.8 6689361.2 19.5, 355546.2 6689378.4 19.5))
BATIMENT0000000302931257;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.4;8.3;16.8;18.2;9.8;Cadastre;A 1.0;POLYGON Z ((355562.6 6689384.8 16.8, 355573.4 6689373 16.8, 355573.4 6689372.8 16.8, 355572.6 6689372.2 16.8, 355557.5 6689365 16.8, 355557.5 6689365.2 16.8, 355556.9 6689368.6 16.8, 355564.8 6689372.7 16.8, 355557.1 6689381.8 16.8, 355557 6689382 16.8, 355561.9 6689384.5 16.8, 355562.6 6689384.8 16.8))
BATIMENT0000000302930836;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;10;20;17.1;7.8;24.9;28.3;9.3;Cadastre;A 1.0;POLYGON Z ((355469.1 6689398.5 24.9, 355470.5 6689401.2 24.9, 355477 6689404.3 24.9, 355489.8 6689396.6 24.9, 355491.1 6689374.8 24.9, 355481.9 6689367.4 24.9, 355480.6 6689367.9 24.9, 355469.1 6689398.5 24.9), (355480.9 6689387.1 24.9, 355484.3 6689387.3 24.9, 355484 6689391.4 24.9, 355480.7 6689391.2 24.9, 355480.9 6689387.1 24.9))
BATIMENT0000000302930394;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;8.6;24.7;26.4;9.1;Cadastre;;POLYGON Z ((355567.3 6689386.8 24.7, 355572.6 6689390.5 24.7, 355573.9 6689386.3 24.7, 355569.5 6689384.1 24.7, 355567.3 6689386.8 24.7))
BATIMENT0000000302931217;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;21.4;6.6;28.0;30.4;8.0;Cadastre;A 1.0;POLYGON Z ((355328 6689363 28, 355325.6 6689369.8 28, 355338.6 6689369.7 28, 355341.3 6689358.1 28, 355331.1 6689355.5 28, 355328 6689363 28))
BATIMENT0000000302931218;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;7.0;00;00;22.3;6.6;29.0;30.5;7.7;Cadastre;C 1.0;POLYGON Z ((355325.6 6689369.8 29, 355325.7 6689372.1 29, 355325.7 6689384.7 29, 355332 6689384.9 29, 355335.3 6689385.1 29, 355338.6 6689369.7 29, 355325.6 6689369.8 29))
BATIMENT0000000302931656;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;19.3;6.9;26.2;28.2;7.8;Cadastre;C 0.3;POLYGON Z ((355383 6689373.1 26.2, 355381.1 6689385 26.2, 355382.3 6689386.7 26.2, 355383.4 6689386.7 26.2, 355383.4 6689386.5 26.2, 355409.1 6689386.6 26.2, 355409.2 6689386.9 26.2, 355410.2 6689386.8 26.2, 355410 6689384.2 26.2, 355384.5 6689372 26.2, 355383 6689373.1 26.2))
BATIMENT0000000302931045;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;12;20;18.3;6.8;25.2;28.3;7.2;Cadastre;A 1.0;POLYGON Z ((355334.1 6689393.1 25.2, 355333.1 6689392.1 25.2, 355325.5 6689391.9 25.2, 355325.4 6689393.8 25.2, 355325.3 6689395.7 25.2, 355333.1 6689397.4 25.2, 355334.1 6689393.1 25.2))
BATIMENT0000000302931043;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;;;14.9;7.0;22.0;24.4;7.3;Cadastre;A 1.0;POLYGON Z ((355315.8 6689393.8 22, 355314.7 6689395.3 22, 355313.9 6689401.5 22, 355319.7 6689402.7 22, 355320 6689393.8 22, 355315.8 6689393.8 22))
BATIMENT0000000302931042;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;;;14.2;7.0;21.2;27.2;7.2;Cadastre;A 1.0;POLYGON Z ((355320 6689393.8 21.2, 355319.7 6689402.7 21.2, 355313.9 6689401.5 21.2, 355312.5 6689412.5 21.2, 355329.4 6689414.6 21.2, 355333.1 6689397.4 21.2, 355325.3 6689395.7 21.2, 355325.4 6689393.8 21.2, 355320 6689393.8 21.2))
BATIMENT0000000302931532;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;10;20;18.3;6.6;24.9;28.7;7.3;Cadastre;A 1.0;POLYGON Z ((355380.9 6689391.5 24.9, 355379.2 6689392.6 24.9, 355374.3 6689418.2 24.9, 355377.7 6689417.3 24.9, 355378.1 6689416.5 24.9, 355383 6689415.6 24.9, 355383.2 6689410.7 24.9, 355382.6 6689410.8 24.9, 355383 6689409 24.9, 355392.1 6689406.2 24.9, 355390.4 6689391.6 24.9, 355380.9 6689391.5 24.9))
BATIMENT0000000302931531;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;6.0;10;20;19.3;6.8;26.1;29.8;7.1;Cadastre;A 1.0;POLYGON Z ((355390.4 6689391.6 26.1, 355392.1 6689406.2 26.1, 355392.2 6689408.8 26.1, 355390.9 6689409.1 26.1, 355393.2 6689418.3 26.1, 355396.9 6689417.2 26.1, 355397 6689417.6 26.1, 355404.3 6689415.9 26.1, 355401.5 6689407.3 26.1, 355402.4 6689405.7 26.1, 355406.1 6689405.8 26.1, 355406.2 6689391.7 26.1, 355390.4 6689391.6 26.1))
BATIMENT0000000302931530;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.2;6.4;22.7;28.2;7.2;Cadastre;C 0.3;POLYGON Z ((355413.8 6689419.1 22.7, 355414.1 6689419.1 22.7, 355413.2 6689414.6 22.7, 355409 6689415.9 22.7, 355406.4 6689406.8 22.7, 355401.5 6689407.3 22.7, 355404.3 6689415.9 22.7, 355404.5 6689416.7 22.7, 355397.1 6689418.4 22.7, 355397 6689417.6 22.7, 355396.9 6689417.2 22.7, 355393.2 6689418.3 22.7, 355390.9 6689409.1 22.7, 355383.2 6689410.7 22.7, 355383 6689415.6 22.7, 355384.2 6689415.8 22.7, 355384 6689416.9 22.7, 355389.4 6689415.7 22.7, 355390.4 6689422 22.7, 355411.8 6689417.8 22.7, 355412.2 6689419.8 22.7, 355413.9 6689419.5 22.7, 355413.8 6689419.1 22.7))
BATIMENT0000000302931044;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;20;20;13.4;7.8;21.2;;;Cadastre;A 1.0;POLYGON Z ((355311.9 6689417.2 21.2, 355328.5 6689418.8 21.2, 355329.4 6689414.6 21.2, 355312.5 6689412.5 21.2, 355311.9 6689417.2 21.2))
BATIMENT0000000302930936;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;6.0;20;20;18.2;7.0;25.2;28.2;7.3;Cadastre;A 1.0;POLYGON Z ((355435.1 6689385.5 25.2, 355436.4 6689375.9 25.2, 355437.4 6689371.1 25.2, 355439.1 6689371.2 25.2, 355439.6 6689369.4 25.2, 355441.2 6689369.6 25.2, 355441.8 6689365.8 25.2, 355442.2 6689363.2 25.2, 355435.8 6689362 25.2, 355436.2 6689360.6 25.2, 355434.9 6689360.1 25.2, 355434.4 6689361.6 25.2, 355433.3 6689363.2 25.2, 355430.6 6689367 25.2, 355427.9 6689382 25.2, 355435.1 6689385.5 25.2))
BATIMENT0000000302930930;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;10;20;21.9;7.5;29.5;32.0;8.5;Cadastre;A 1.0;POLYGON Z ((355457.3 6689377.1 29.5, 355465.7 6689380.2 29.5, 355469.6 6689369.7 29.5, 355459.1 6689366.2 29.5, 355457.3 6689377.1 29.5))
BATIMENT0000000302930932;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;20.6;6.8;27.5;30.7;7.8;Cadastre;A 1.0;POLYGON Z ((355439.6 6689369.4 27.5, 355439.1 6689371.2 27.5, 355437.4 6689371.1 27.5, 355436.4 6689375.9 27.5, 355435.1 6689385.5 27.5, 355439.3 6689387.4 27.5, 355440.5 6689379.7 27.5, 355437.7 6689379.2 27.5, 355438.2 6689376.1 27.5, 355441 6689376.5 27.5, 355441.6 6689372.8 27.5, 355452.6 6689376.5 27.5, 355454 6689367.4 27.5, 355441.8 6689365.8 27.5, 355441.2 6689369.6 27.5, 355439.6 6689369.4 27.5), (355446.1 6689367.9 27.5, 355448.8 6689368.3 27.5, 355448.5 6689370.6 27.5, 355445.7 6689370.2 27.5, 355446.1 6689367.9 27.5))
BATIMENT0000000302930934;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;10;20;17.6;7.0;24.6;28.7;7.8;Cadastre;C 0.9;POLYGON Z ((355439.3 6689387.4 24.6, 355450 6689392.2 24.6, 355452.6 6689376.5 24.6, 355441.6 6689372.8 24.6, 355441 6689376.5 24.6, 355440.5 6689379.7 24.6, 355439.3 6689387.4 24.6))
BATIMENT0000000302930931;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;6.0;;;19.7;7.4;27.1;30.6;8.5;Cadastre;A 1.0;POLYGON Z ((355454.3 6689395 27.1, 355457.6 6689396.5 27.1, 355459.9 6689395.5 27.1, 355465.7 6689380.2 27.1, 355457.3 6689377.1 27.1, 355454.3 6689395 27.1))
BATIMENT0000000302931526;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;20;20;20.8;7.1;27.9;33.2;7.5;Cadastre;A 1.0;POLYGON Z ((355425.4 6689391.9 27.9, 355422.8 6689391.9 27.9, 355421.5 6689400.2 27.9, 355421.8 6689404.4 27.9, 355433.5 6689406.3 27.9, 355433.7 6689395.9 27.9, 355425.4 6689391.9 27.9))
BATIMENT0000000302931523;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;10;20;20.8;7.1;27.9;31.5;7.6;Cadastre;A 1.0;POLYGON Z ((355433.7 6689395.9 27.9, 355433.5 6689406.3 27.9, 355433.4 6689407.6 27.9, 355434.3 6689407.7 27.9, 355434.5 6689409.6 27.9, 355439.5 6689408.7 27.9, 355441.4 6689408.4 27.9, 355441.5 6689404.8 27.9, 355439.5 6689404.5 27.9, 355439.7 6689398.7 27.9, 355433.7 6689395.9 27.9))
BATIMENT0000000302931528;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;6.0;20;20;19.3;7.0;26.3;30.2;7.4;Cadastre;A 1.0;POLYGON Z ((355406.6 6689405.8 26.3, 355406.4 6689406.8 26.3, 355409 6689415.9 26.3, 355413.2 6689414.6 26.3, 355421 6689412.3 26.3, 355419.5 6689405.9 26.3, 355421.8 6689405.5 26.3, 355421.8 6689404.4 26.3, 355421.5 6689400.2 26.3, 355422.8 6689391.9 26.3, 355406.2 6689391.7 26.3, 355406.1 6689405.8 26.3, 355406.6 6689405.8 26.3), (355410.2 6689403.3 26.3, 355415.2 6689403.5 26.3, 355415.5 6689407.3 26.3, 355409.6 6689407.3 26.3, 355409.6 6689406.9 26.3, 355410.1 6689406.4 26.3, 355410.2 6689406.3 26.3, 355410.2 6689406.2 26.3, 355410.2 6689406.1 26.3, 355410.2 6689406 26.3, 355410.2 6689405.9 26.3, 355410.2 6689405.8 26.3, 355410.2 6689403.3 26.3))
BATIMENT0000000302931522;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;12;20;21.4;7.1;28.5;32.5;8.4;Cadastre;A 1.0;POLYGON Z ((355454.4 6689407.7 28.5, 355453.1 6689405 28.5, 355439.7 6689398.7 28.5, 355439.5 6689404.5 28.5, 355441.5 6689404.8 28.5, 355441.4 6689408.4 28.5, 355443.2 6689408 28.5, 355444.5 6689415.6 28.5, 355448.8 6689414.6 28.5, 355452.8 6689415.3 28.5, 355454.4 6689407.7 28.5))
BATIMENT0000000302931524;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;20;20;21.5;7.4;29.0;31.7;7.9;Cadastre;A 1.0;POLYGON Z ((355445.9 6689421.5 29, 355444.5 6689415.6 29, 355443.2 6689408 29, 355441.4 6689408.4 29, 355439.5 6689408.7 29, 355442.1 6689422.7 29, 355445.9 6689421.5 29))
BATIMENT0000000302931256;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;2014-02-27 11:47:02;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.6;8.0;22.6;;;Cadastre;;POLYGON Z ((355529 6689377.1 22.6, 355517.5 6689376.2 22.6, 355517.3 6689378.3 22.6, 355512.3 6689378.1 22.6, 355512.3 6689378.4 22.6, 355511.8 6689378.4 22.6, 355511.7 6689379.5 22.6, 355512 6689379.5 22.6, 355511.9 6689381.8 22.6, 355511.5 6689381.8 22.6, 355511.4 6689382.9 22.6, 355511.8 6689382.9 22.6, 355511.6 6689384.6 22.6, 355510.6 6689384.5 22.6, 355510.4 6689385.7 22.6, 355509.8 6689385.7 22.6, 355509.6 6689388.9 22.6, 355510.3 6689389 22.6, 355510.2 6689390 22.6, 355511.3 6689390.1 22.6, 355511.2 6689391.6 22.6, 355510.9 6689391.6 22.6, 355510.8 6689392.7 22.6, 355511.1 6689392.7 22.6, 355511 6689394.9 22.6, 355510.7 6689394.9 22.6, 355510.6 6689396.2 22.6, 355510.9 6689396.2 22.6, 355510.9 6689396.3 22.6, 355516.2 6689396.8 22.6, 355516.1 6689399.3 22.6, 355536.4 6689400.8 22.6, 355539.9 6689400.3 22.6, 355542.6 6689400 22.6, 355543.3 6689399.8 22.6, 355545.2 6689398.7 22.6, 355545.8 6689397.8 22.6, 355546 6689397.4 22.6, 355546 6689397.1 22.6, 355546.1 6689396.5 22.6, 355546 6689395.9 22.6, 355545.6 6689395.1 22.6, 355546.6 6689395.1 22.6, 355546.6 6689396.1 22.6, 355547.4 6689396 22.6, 355547.5 6689395.1 22.6, 355550.4 6689395.1 22.6, 355550.7 6689396 22.6, 355551.5 6689395.8 22.6, 355551.2 6689394.8 22.6, 355553.8 6689392.5 22.6, 355554.6 6689393 22.6, 355554.1 6689384.8 22.6, 355543.3 6689382.9 22.6, 355543.3 6689378.1 22.6, 355529 6689377.1 22.6))
BATIMENT0000000302930393;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;14.9;8.5;23.4;26.0;9.2;Cadastre;A 1.0;POLYGON Z ((355560.8 6689393.9 23.4, 355560.9 6689394.1 23.4, 355570.3 6689397.8 23.4, 355572.1 6689392.1 23.4, 355572.6 6689390.5 23.4, 355567.3 6689386.8 23.4, 355560.8 6689393.9 23.4))
BATIMENT0000000302931289;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.5;9.7;21.2;23.4;10.3;Cadastre;;POLYGON Z ((355543.3 6689403.7 21.2, 355547.6 6689414.7 21.2, 355547.8 6689414.7 21.2, 355552.5 6689416 21.2, 355556.2 6689417 21.2, 355559.4 6689418 21.2, 355561.8 6689418.8 21.2, 355563.8 6689412.6 21.2, 355561.5 6689411.8 21.2, 355564.4 6689402.7 21.2, 355555.8 6689399.9 21.2, 355553.5 6689400.3 21.2, 355543.3 6689403.7 21.2))
BATIMENT0000000302931270;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;9.6;16.2;26.1;10.0;Cadastre;;POLYGON Z ((355523.4 6689404 16.2, 355523.2 6689404 16.2, 355513.7 6689403.3 16.2, 355513.4 6689407.8 16.2, 355512 6689407.7 16.2, 355508.7 6689410.7 16.2, 355507.5 6689415.2 16.2, 355509.4 6689415.8 16.2, 355509.7 6689412.4 16.2, 355513.3 6689409.1 16.2, 355520.3 6689409.6 16.2, 355522.8 6689409.8 16.2, 355524.6 6689409.9 16.2, 355535.6 6689410.8 16.2, 355536 6689404.9 16.2, 355523.4 6689404 16.2))
BATIMENT0000000302931032;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;20;20;19.7;8.0;27.7;31.2;9.8;Cadastre;C 0.4;POLYGON Z ((355486.7 6689406.8 27.7, 355487 6689410 27.7, 355502.3 6689417 27.7, 355502.9 6689416.5 27.7, 355503.8 6689403.9 27.7, 355492.9 6689402.9 27.7, 355486.7 6689406.8 27.7))
BATIMENT0000000302931274;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.9;9.6;23.5;25.0;10.5;Cadastre;A 1.0;POLYGON Z ((355541 6689404.5 23.5, 355541.4 6689417.4 23.5, 355544 6689418.1 23.5, 355543.7 6689416.1 23.5, 355547.9 6689415.5 23.5, 355547.6 6689414.7 23.5, 355543.3 6689403.7 23.5, 355541 6689404.5 23.5))
BATIMENT0000000302931273;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;;;15.9;9.6;25.5;27.6;10.4;Cadastre;A 1.0;POLYGON Z ((355536 6689404.9 25.5, 355535.6 6689410.8 25.5, 355536.1 6689410.8 25.5, 355535.9 6689417.3 25.5, 355537 6689417.4 25.5, 355536.9 6689418.7 25.5, 355540.6 6689420.1 25.5, 355541.4 6689417.4 25.5, 355541 6689404.5 25.5, 355540.9 6689404.6 25.5, 355536 6689404.9 25.5), (355540.5 6689415.4 25.5, 355540.5 6689417.4 25.5, 355538.4 6689417.4 25.5, 355538.4 6689415.4 25.5, 355540.5 6689415.4 25.5), (355539.7 6689418.4 25.5, 355539.4 6689419.2 25.5, 355537.8 6689418.7 25.5, 355538 6689418.1 25.5, 355539.7 6689418.4 25.5))
BATIMENT0000000302931272;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;34;20;20.6;9.7;30.4;31.7;10.3;Cadastre;A 1.0;POLYGON Z ((355524.6 6689409.9 30.4, 355522.8 6689409.8 30.4, 355520.3 6689409.6 30.4, 355513.3 6689409.1 30.4, 355509.7 6689412.4 30.4, 355509.4 6689415.8 30.4, 355516.2 6689417.7 30.4, 355517.3 6689415.1 30.4, 355520.4 6689415.4 30.4, 355522.4 6689415.6 30.4, 355525.2 6689415.8 30.4, 355526.5 6689416.3 30.4, 355527.7 6689416.6 30.4, 355527.8 6689415 30.4, 355531.4 6689415.2 30.4, 355531.3 6689417.9 30.4, 355531.4 6689418 30.4, 355535.5 6689419.3 30.4, 355535.9 6689417.3 30.4, 355536.1 6689410.8 30.4, 355535.6 6689410.8 30.4, 355524.6 6689409.9 30.4))
BATIMENT0000000302931286;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;6.0;19;20;14.2;9.7;23.9;27.5;10.8;Cadastre;A 1.0;POLYGON Z ((355578.6 6689407.3 23.9, 355564.4 6689402.7 23.9, 355561.5 6689411.8 23.9, 355563.8 6689412.6 23.9, 355566.7 6689413.6 23.9, 355562.4 6689424.6 23.9, 355565.6 6689425.6 23.9, 355570.3 6689427.6 23.9, 355570 6689428.3 23.9, 355573.9 6689429.8 23.9, 355574.1 6689428.8 23.9, 355575.1 6689424.3 23.9, 355573.2 6689423.8 23.9, 355574 6689420.6 23.9, 355572.1 6689420.2 23.9, 355573 6689415.7 23.9, 355575.8 6689416.3 23.9, 355575.5 6689417.8 23.9, 355576.4 6689418.1 23.9, 355577 6689415.6 23.9, 355576.8 6689414.7 23.9, 355578.4 6689408.3 23.9, 355578.6 6689407.3 23.9))
BATIMENT0000000302931269;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;18.6;9.6;28.2;31.4;10.0;Cadastre;A 1.0;POLYGON Z ((355507.5 6689415.2 28.2, 355506.2 6689419.6 28.2, 355514.1 6689423.2 28.2, 355516.2 6689417.7 28.2, 355509.4 6689415.8 28.2, 355507.5 6689415.2 28.2))
BATIMENT0000000302931521;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;21.3;7.3;28.6;30.6;7.5;Cadastre;A 1.0;POLYGON Z ((355436.8 6689424.3 28.6, 355434.5 6689409.6 28.6, 355434.3 6689407.7 28.6, 355433.4 6689407.6 28.6, 355427.9 6689406.6 28.6, 355432.5 6689425.6 28.6, 355436.8 6689424.3 28.6))
BATIMENT0000000302931520;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;10;20;18.8;7.0;25.8;30.9;7.7;Cadastre;A 1.0;POLYGON Z ((355442.1 6689422.7 25.8, 355439.5 6689408.7 25.8, 355434.5 6689409.6 25.8, 355436.8 6689424.3 25.8, 355442.1 6689422.7 25.8))
BATIMENT0000000302931525;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1750-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;18.0;7.1;25.1;29.7;7.4;Cadastre;A 1.0;POLYGON Z ((355432.5 6689425.6 25.1, 355427.9 6689406.6 25.1, 355421.8 6689405.5 25.1, 355419.5 6689405.9 25.1, 355421 6689412.3 25.1, 355424.7 6689427.9 25.1, 355432.5 6689425.6 25.1))
BATIMENT0000000302931533;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1747-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;12;20;14.1;7.6;21.7;32.9;8.1;Cadastre;A 1.0;POLYGON Z ((355451.6 6689419.8 21.7, 355451.9 6689419.5 21.7, 355452.8 6689415.3 21.7, 355448.8 6689414.6 21.7, 355444.5 6689415.6 21.7, 355445.9 6689421.5 21.7, 355451.6 6689419.8 21.7))
BATIMENT0000000302931527;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;10;20;17.7;7.1;24.8;27.6;7.3;Cadastre;A 1.0;POLYGON Z ((355419.9 6689429.4 24.8, 355424.7 6689427.9 24.8, 355421 6689412.3 24.8, 355413.2 6689414.6 24.8, 355414.1 6689419.1 24.8, 355416.5 6689418.5 24.8, 355419.5 6689429.4 24.8, 355419.9 6689429.4 24.8))
BATIMENT0000000302931674;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;30;20;19.9;7.0;26.9;30.5;9.8;Cadastre;A 1.0;POLYGON Z ((355474 6689414.7 26.9, 355468.9 6689417.2 26.9, 355466 6689428.6 26.9, 355470.8 6689429.2 26.9, 355474.1 6689428.9 26.9, 355481.5 6689430.4 26.9, 355482.4 6689430.6 26.9, 355485.1 6689420 26.9, 355474 6689414.7 26.9))
BATIMENT0000000302931673;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;20.3;8.4;28.7;30.5;10.3;Cadastre;A 1.0;POLYGON Z ((355463.1 6689438.9 28.7, 355463.1 6689439.2 28.7, 355476 6689441.8 28.7, 355477.6 6689434.4 28.7, 355480.1 6689435 28.7, 355481.5 6689430.4 28.7, 355474.1 6689428.9 28.7, 355470.8 6689429.2 28.7, 355466 6689428.6 28.7, 355463.1 6689438.9 28.7))
BATIMENT0000000302931676;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.0;8.1;24.2;29.5;10.3;Cadastre;A 1.0;POLYGON Z ((355459.3 6689437.7 24.2, 355457.3 6689447.4 24.2, 355473.9 6689450.3 24.2, 355475.5 6689442.9 24.2, 355475.9 6689442.9 24.2, 355476 6689441.8 24.2, 355463.1 6689439.2 24.2, 355463.1 6689438.9 24.2, 355459.3 6689437.7 24.2))
BATIMENT0000000302931442;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;7.8;10.7;10.9;8.3;Cadastre;;POLYGON Z ((355445.5 6689451.2 10.7, 355446.4 6689451.3 10.7, 355446.5 6689450.8 10.7, 355445.7 6689450.6 10.7, 355445.5 6689451.2 10.7))
BATIMENT0000000302931445;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.8;6.6;13.5;20.5;6.9;Cadastre;A 1.0;POLYGON Z ((355416.8 6689452.3 13.5, 355416.6 6689451.7 13.5, 355415.6 6689452 13.5, 355415.7 6689452.3 13.5, 355412.2 6689453 13.5, 355413.1 6689457.9 13.5, 355417.2 6689457 13.5, 355416.8 6689452.3 13.5))
BATIMENT0000000302931276;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;10.0;14.6;15.1;10.8;Cadastre;;POLYGON Z ((355557.3 6689422.7 14.6, 355559.4 6689418 14.6, 355556.2 6689417 14.6, 355554.1 6689421.5 14.6, 355557.3 6689422.7 14.6))
BATIMENT0000000302931271;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;;;19.5;9.6;29.1;30.2;10.1;Cadastre;A 1.0;POLYGON Z ((355517.7 6689425 29.1, 355520.4 6689418.6 29.1, 355519.2 6689418.1 29.1, 355520.4 6689415.4 29.1, 355517.3 6689415.1 29.1, 355516.2 6689417.7 29.1, 355514.1 6689423.2 29.1, 355517.7 6689425 29.1))
BATIMENT0000000302931284;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;19.8;9.6;29.4;31.7;10.2;Cadastre;;POLYGON Z ((355518.5 6689425.3 29.4, 355522.4 6689415.6 29.4, 355520.4 6689415.4 29.4, 355519.2 6689418.1 29.4, 355520.4 6689418.6 29.4, 355517.7 6689425 29.4, 355518.5 6689425.3 29.4))
BATIMENT0000000302931283;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;20;20;20.8;9.6;30.4;32.2;10.2;Cadastre;A 1.0;POLYGON Z ((355523.1 6689427.5 30.4, 355523.7 6689425.9 30.4, 355526.5 6689416.3 30.4, 355525.2 6689415.8 30.4, 355522.4 6689415.6 30.4, 355518.5 6689425.3 30.4, 355523.1 6689427.5 30.4))
BATIMENT0000000302931282;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.3;10.3;21.7;24.5;10.7;Cadastre;;POLYGON Z ((355570.3 6689427.6 21.7, 355565.6 6689425.6 21.7, 355565.1 6689426.7 21.7, 355569.7 6689428.8 21.7, 355570 6689428.3 21.7, 355570.3 6689427.6 21.7))
BATIMENT0000000302931677;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;20;18.0;9.2;27.2;32.3;10.2;Cadastre;C 0.4;POLYGON Z ((355495.3 6689422.6 27.2, 355485.6 6689418.1 27.2, 355485.1 6689420 27.2, 355482.4 6689430.6 27.2, 355481.5 6689430.4 27.2, 355480.1 6689435 27.2, 355481.6 6689435.3 27.2, 355481.2 6689438.5 27.2, 355485.9 6689439.3 27.2, 355488.7 6689439.2 27.2, 355489 6689436.9 27.2, 355490.6 6689436.8 27.2, 355491.7 6689433.5 27.2, 355492.4 6689433.3 27.2, 355493.3 6689430 27.2, 355493.6 6689430.1 27.2, 355494.9 6689424.8 27.2, 355495.3 6689422.6 27.2))
BATIMENT0000000302931679;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;00;00;10.0;9.6;19.7;29.6;10.1;Cadastre;A 1.0;POLYGON Z ((355497.6 6689425.9 19.7, 355494.9 6689424.8 19.7, 355493.6 6689430.1 19.7, 355493.3 6689430 19.7, 355492.4 6689433.3 19.7, 355491.7 6689433.5 19.7, 355490.6 6689436.8 19.7, 355489 6689436.9 19.7, 355488.7 6689439.2 19.7, 355496.7 6689439.6 19.7, 355497.6 6689425.9 19.7))
BATIMENT0000000302931275;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;30;20;17.4;10.1;27.5;35.5;10.8;Cadastre;C 0.7;POLYGON Z ((355524 6689426 27.5, 355579 6689451.4 27.5, 355579.4 6689451.6 27.5, 355582.3 6689444.9 27.5, 355583.6 6689442.1 27.5, 355587.5 6689432.7 27.5, 355589.4 6689433.3 27.5, 355589.6 6689431.8 27.5, 355590 6689430.3 27.5, 355582.5 6689429.1 27.5, 355582.1 6689431.4 27.5, 355583.3 6689431.9 27.5, 355582.1 6689434.5 27.5, 355573.9 6689430.9 27.5, 355572.2 6689430.3 27.5, 355570.6 6689433.8 27.5, 355571.8 6689434.4 27.5, 355571.1 6689435.9 27.5, 355567.6 6689434.3 27.5, 355568.2 6689433.1 27.5, 355566.9 6689432.5 27.5, 355566.3 6689433.7 27.5, 355561.8 6689431.7 27.5, 355563.7 6689427.3 27.5, 355559.5 6689425.4 27.5, 355557.3 6689429.8 27.5, 355554.6 6689428.5 27.5, 355557.3 6689422.7 27.5, 355554.1 6689421.5 27.5, 355544 6689418.1 27.5, 355541.4 6689417.4 27.5, 355540.6 6689420.1 27.5, 355540.3 6689421 27.5, 355535.5 6689419.3 27.5, 355531.4 6689418 27.5, 355531.3 6689417.9 27.5, 355527.7 6689416.6 27.5, 355526.5 6689416.3 27.5, 355523.7 6689425.9 27.5, 355524 6689426 27.5), (355544.8 6689420.2 27.5, 355553.2 6689423.4 27.5, 355551.5 6689427.1 27.5, 355545.8 6689424.4 27.5, 355546.3 6689423.3 27.5, 355545 6689422.6 27.5, 355544.5 6689423.8 27.5, 355543.4 6689423.3 27.5, 355544.8 6689420.2 27.5))
BATIMENT0000000302931678;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.3;9.9;26.2;28.6;10.2;Cadastre;;POLYGON Z ((355496.7 6689439.6 26.2, 355488.7 6689439.2 26.2, 355485.9 6689439.3 26.2, 355485.5 6689443.5 26.2, 355496.5 6689444.2 26.2, 355496.7 6689439.6 26.2))
BATIMENT0000000302931675;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;;;9.9;8.3;18.2;29.6;10.4;Cadastre;A 1.0;POLYGON Z ((355473.9 6689450.3 18.2, 355469.7 6689467.4 18.2, 355472.2 6689467.6 18.2, 355478 6689467.8 18.2, 355483 6689468.1 18.2, 355495.1 6689468.7 18.2, 355496.5 6689444.2 18.2, 355485.5 6689443.5 18.2, 355475.9 6689442.9 18.2, 355475.5 6689442.9 18.2, 355473.9 6689450.3 18.2), (355476.8 6689455.8 18.2, 355483.8 6689456.1 18.2, 355483.6 6689461.1 18.2, 355476.5 6689460.8 18.2, 355476.8 6689455.8 18.2))
BATIMENT0000000302928108;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;29.0;31.6;32.5;29.0;Cadastre;;POLYGON Z ((354651 6689292.9 31.6, 354653.3 6689298.8 31.6, 354654.9 6689302.8 31.6, 354661.3 6689300.2 31.6, 354660 6689297 31.6, 354659.8 6689297.1 31.6, 354657.1 6689290.5 31.6, 354656.3 6689290.9 31.6, 354651 6689292.9 31.6))
BATIMENT0000000302928114;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;00;00;22.6;27.5;50.2;52.1;29.0;Cadastre;A 1.0;POLYGON Z ((354676.5 6689311 50.2, 354691.7 6689301.5 50.2, 354690.5 6689298.7 50.2, 354684.7 6689284.6 50.2, 354675 6689290.7 50.2, 354677.3 6689296.2 50.2, 354671.9 6689299.7 50.2, 354672.4 6689300.9 50.2, 354674.2 6689305.3 50.2, 354676.5 6689311 50.2))
BATIMENT0000000302928111;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;7.0;10;20;22.4;28.5;51.0;55.0;29.0;Cadastre;A 1.0;POLYGON Z ((354641.9 6689288.3 51, 354632.7 6689287.3 51, 354630.7 6689291.6 51, 354632.6 6689305.1 51, 354636.9 6689310.2 51, 354644.9 6689303.7 51, 354642.5 6689300.8 51, 354641.4 6689293.1 51, 354641.8 6689292 51, 354642.4 6689288.5 51, 354641.9 6689288.3 51))
BATIMENT0000000302928113;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;7.0;10;20;21.6;28.5;50.2;52.1;29.1;Cadastre;B 0.8;POLYGON Z ((354676.5 6689311 50.2, 354674.2 6689305.3 50.2, 354672.4 6689300.9 50.2, 354656.9 6689307.4 50.2, 354657 6689307.6 50.2, 354658.4 6689311.2 50.2, 354662.2 6689320.3 50.2, 354676.5 6689311 50.2))
BATIMENT0000000302928112;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;8.0;15;20;22.5;28.7;51.3;54.9;29.4;Cadastre;A 1.0;POLYGON Z ((354649.3 6689325.3 51.3, 354653.4 6689325.9 51.3, 354662.2 6689320.3 51.3, 354658.4 6689311.2 51.3, 354653.5 6689314.3 51.3, 354644.9 6689303.7 51.3, 354636.9 6689310.2 51.3, 354649.3 6689325.3 51.3))
BATIMENT0000000302929180;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;6.0;;;18.9;28.3;47.2;52.1;29.3;Cadastre;C 0.7;POLYGON Z ((354686.4 6689332.4 47.2, 354692.2 6689328.8 47.2, 354690.4 6689326 47.2, 354695.3 6689323 47.2, 354697.1 6689325.4 47.2, 354700.5 6689323.4 47.2, 354700.6 6689323.2 47.2, 354700.7 6689323 47.2, 354700.8 6689322.8 47.2, 354700.9 6689322.7 47.2, 354701 6689322.3 47.2, 354701 6689321.9 47.2, 354701 6689321.7 47.2, 354700.8 6689321 47.2, 354700.7 6689320.8 47.2, 354700.5 6689320.5 47.2, 354699.8 6689319.5 47.2, 354702.7 6689317.8 47.2, 354703.6 6689319.3 47.2, 354703.7 6689319.4 47.2, 354703.8 6689319.6 47.2, 354703.9 6689319.7 47.2, 354704.1 6689319.9 47.2, 354704.3 6689320 47.2, 354704.5 6689320.1 47.2, 354704.8 6689320.1 47.2, 354704.9 6689320.1 47.2, 354705.1 6689320.1 47.2, 354705.3 6689320 47.2, 354705.5 6689320 47.2, 354705.7 6689320 47.2, 354706 6689319.9 47.2, 354706.2 6689319.8 47.2, 354706.3 6689319.7 47.2, 354706.6 6689319.5 47.2, 354706.7 6689319.4 47.2, 354706.9 6689319.3 47.2, 354709.2 6689317.8 47.2, 354704.5 6689307.5 47.2, 354703.6 6689307.9 47.2, 354702.7 6689305.6 47.2, 354680.3 6689320 47.2, 354684.4 6689329 47.2, 354686.4 6689332.4 47.2))
BATIMENT0000000302928323;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;30;40;12.9;30.0;42.9;;;Cadastre;C 0.1;POLYGON Z ((354634 6689321.9 42.9, 354627.1 6689313.7 42.9, 354620.6 6689314.6 42.9, 354618.8 6689318.7 42.9, 354624.5 6689320.9 42.9, 354628.8 6689326 42.9, 354634 6689321.9 42.9))
BATIMENT0000000302929179;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;6.0;;;5.9;28.3;34.2;39.7;29.0;Cadastre;C 0.3;POLYGON Z ((354693.8 6689330.4 34.2, 354695.5 6689332.1 34.2, 354696.1 6689332.7 34.2, 354696.6 6689333 34.2, 354697.1 6689333.4 34.2, 354697.6 6689333.7 34.2, 354698.1 6689333.9 34.2, 354698.7 6689334.2 34.2, 354699.3 6689334.5 34.2, 354699.8 6689334.8 34.2, 354700 6689334.8 34.2, 354700.5 6689335.1 34.2, 354701.5 6689335.4 34.2, 354702.5 6689335.7 34.2, 354704.7 6689336.1 34.2, 354705.8 6689336.2 34.2, 354706.8 6689336.4 34.2, 354709.2 6689336.3 34.2, 354709.4 6689336.2 34.2, 354710.8 6689336 34.2, 354713.7 6689335.2 34.2, 354715.1 6689334.7 34.2, 354716.6 6689334.3 34.2, 354714.1 6689328.7 34.2, 354713.2 6689329.2 34.2, 354712.2 6689329.6 34.2, 354711.3 6689329.9 34.2, 354710.3 6689330.2 34.2, 354709.3 6689330.3 34.2, 354708 6689330.3 34.2, 354706.7 6689330.3 34.2, 354705.5 6689330.1 34.2, 354704.2 6689329.9 34.2, 354703 6689329.6 34.2, 354702.2 6689329.2 34.2, 354701.4 6689328.8 34.2, 354700.6 6689328.4 34.2, 354699.9 6689327.9 34.2, 354699.2 6689327.4 34.2, 354697.1 6689325.4 34.2, 354695.3 6689323 34.2, 354690.4 6689326 34.2, 354692.2 6689328.8 34.2, 354693.8 6689330.4 34.2))
BATIMENT0000000302928050;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;;;11.9;27.6;39.5;48.0;29.7;Cadastre;A 1.0;POLYGON Z ((354658 6689334.3 39.5, 354657.8 6689335.2 39.5, 354663.6 6689342 39.5, 354671.2 6689336.2 39.5, 354671.1 6689336 39.5, 354673.9 6689334 39.5, 354674 6689333.8 39.5, 354674.1 6689333.7 39.5, 354674.2 6689333.6 39.5, 354674.3 6689333.3 39.5, 354674.3 6689333 39.5, 354674.3 6689332.9 39.5, 354674.3 6689332.6 39.5, 354675.1 6689332.1 39.5, 354676.7 6689331 39.5, 354678 6689333.1 39.5, 354684.4 6689329 39.5, 354680.3 6689320 39.5, 354658 6689334.3 39.5))
BATIMENT0000000302928324;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;7.0;35;20;20.4;30.0;50.4;;;Cadastre;A 1.0;POLYGON Z ((354628.8 6689326 50.4, 354632.2 6689330.3 50.4, 354631.4 6689330.8 50.4, 354624.8 6689335.2 50.4, 354624.3 6689335.5 50.4, 354626.8 6689342 50.4, 354627.5 6689341.9 50.4, 354638.1 6689335.6 50.4, 354640.2 6689334.1 50.4, 354640.4 6689333.9 50.4, 354640.5 6689333.7 50.4, 354640.6 6689333.5 50.4, 354640.8 6689333.3 50.4, 354640.9 6689333 50.4, 354640.9 6689332.8 50.4, 354641 6689332.3 50.4, 354641 6689332 50.4, 354641 6689331.8 50.4, 354641 6689331.3 50.4, 354641 6689330.9 50.4, 354641 6689330.4 50.4, 354640.8 6689330 50.4, 354634 6689321.9 50.4, 354628.8 6689326 50.4))
BATIMENT0000000302929182;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;27.4;44.5;56.2;28.3;Cadastre;;POLYGON Z ((354754 6689316.6 44.5, 354769.3 6689309.5 44.5, 354769 6689307.3 44.5, 354763.9 6689293.8 44.5, 354748.4 6689298.5 44.5, 354753.9 6689316.5 44.5, 354754 6689316.6 44.5))
BATIMENT0000000302929181;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;37.0;8.0;00;00;18.2;27.5;45.7;55.5;29.0;Cadastre;C 0.6;POLYGON Z ((354704.5 6689307.5 45.7, 354709.2 6689317.8 45.7, 354714.1 6689328.7 45.7, 354716.6 6689334.3 45.7, 354716.9 6689334.8 45.7, 354720.4 6689333 45.7, 354714.7 6689319.9 45.7, 354730.2 6689313.4 45.7, 354735.6 6689325.5 45.7, 354738.2 6689324.2 45.7, 354738.2 6689323.9 45.7, 354734.2 6689313.5 45.7, 354728.4 6689298.7 45.7, 354726.7 6689293.7 45.7, 354722.8 6689295.2 45.7, 354723.3 6689296.2 45.7, 354720.4 6689297.5 45.7, 354719.8 6689296.4 45.7, 354717 6689296.6 45.7, 354717.7 6689298.7 45.7, 354706.8 6689303.4 45.7, 354706.9 6689303.8 45.7, 354702.7 6689305.6 45.7, 354703.6 6689307.9 45.7, 354704.5 6689307.5 45.7))
BATIMENT0000000302929244;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.0;28.2;35.2;41.0;29.0;Cadastre;C 0.4;POLYGON Z ((354735.6 6689325.5 35.2, 354730.2 6689313.4 35.2, 354714.7 6689319.9 35.2, 354720.4 6689333 35.2, 354735.6 6689325.5 35.2))
BATIMENT0000000302929213;Indifférenciée;Annexe;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;00;00;5.8;27.8;33.7;42.0;29.2;Cadastre;C 0.1;POLYGON Z ((354721.4 6689345 33.7, 354775.5 6689320.2 33.7, 354770.8 6689308.8 33.7, 354769.3 6689309.5 33.7, 354754 6689316.6 33.7, 354738.2 6689323.9 33.7, 354738.2 6689324.2 33.7, 354735.6 6689325.5 33.7, 354720.4 6689333 33.7, 354716.9 6689334.8 33.7, 354721.4 6689345 33.7))
BATIMENT0000000302928064;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;12.9;27.7;40.7;47.3;28.5;Cadastre;A 1.0;POLYGON Z ((354800.7 6689335.8 40.7, 354793.2 6689324.5 40.7, 354787.7 6689324.5 40.7, 354778.6 6689327.6 40.7, 354776.4 6689328.5 40.7, 354786.3 6689345.6 40.7, 354800.7 6689335.8 40.7))
BATIMENT0000000302929212;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;28.2;35.9;36.2;29.5;Cadastre;;POLYGON Z ((354724 6689350.5 35.9, 354725.2 6689350.9 35.9, 354724.9 6689351.6 35.9, 354726.9 6689352.5 35.9, 354727.2 6689351.8 35.9, 354728.2 6689352.1 35.9, 354751.1 6689340.7 35.9, 354754.8 6689339.3 35.9, 354757.5 6689337.8 35.9, 354765.9 6689333.2 35.9, 354765.9 6689333 35.9, 354776.4 6689328.5 35.9, 354778.6 6689327.6 35.9, 354775.5 6689320.2 35.9, 354721.4 6689345 35.9, 354723.3 6689349.2 35.9, 354724 6689350.5 35.9))
BATIMENT0000000302928065;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;;;6.3;28.2;34.5;42.7;28.8;Cadastre;A 1.0;POLYGON Z ((354786.3 6689345.6 34.5, 354776.4 6689328.5 34.5, 354765.9 6689333 34.5, 354765.9 6689333.2 34.5, 354778.2 6689350.9 34.5, 354786.3 6689345.6 34.5))
BATIMENT0000000302928066;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;24;6.8;28.4;35.2;41.2;28.9;Cadastre;A 1.0;POLYGON Z ((354778.2 6689350.9 35.2, 354765.9 6689333.2 35.2, 354757.5 6689337.8 35.2, 354770.3 6689356.2 35.2, 354778.2 6689350.9 35.2))
BATIMENT0000000302928059;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;00;00;9.2;28.5;37.7;40.1;29.1;Cadastre;C 0.5;POLYGON Z ((354748 6689352.2 37.7, 354749.9 6689350.9 37.7, 354755.2 6689347 37.7, 354751.2 6689341.2 37.7, 354740.4 6689347 37.7, 354744.9 6689353.7 37.7, 354747.6 6689351.6 37.7, 354748 6689352.2 37.7))
BATIMENT0000000302928067;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;12.6;27.3;39.9;42.0;28.9;Cadastre;A 1.0;POLYGON Z ((354770.3 6689356.2 39.9, 354757.5 6689337.8 39.9, 354754.8 6689339.3 39.9, 354751.2 6689341.2 39.9, 354755.2 6689347 39.9, 354757.9 6689350.6 39.9, 354764.6 6689360.1 39.9, 354770.3 6689356.2 39.9))
BATIMENT0000000302928008;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1902-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;28.9;39.0;41.1;29.8;Cadastre;A 1.0;POLYGON Z ((354608.4 6689310.2 39, 354598 6689305.4 39, 354593.2 6689307.2 39, 354595.6 6689313.4 39, 354595.4 6689313.9 39, 354596.2 6689315.9 39, 354594.2 6689316.7 39, 354595.4 6689319.3 39, 354597.6 6689318.4 39, 354601.2 6689327 39, 354608.4 6689310.2 39))
BATIMENT0000000302928322;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;14.8;28.9;43.8;46.7;29.6;Cadastre;A 1.0;POLYGON Z ((354613.1 6689331.9 43.8, 354612.8 6689331.8 43.8, 354608.2 6689342.3 43.8, 354610.5 6689345.4 43.8, 354626.8 6689342 43.8, 354624.3 6689335.5 43.8, 354624.8 6689335.2 43.8, 354622.6 6689330.9 43.8, 354624.9 6689329.5 43.8, 354625.2 6689329.8 43.8, 354628.7 6689327.4 43.8, 354631.4 6689330.8 43.8, 354632.2 6689330.3 43.8, 354628.8 6689326 43.8, 354624.5 6689320.9 43.8, 354618.8 6689318.7 43.8, 354613.1 6689331.9 43.8))
BATIMENT0000000302928013;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;19.5;28.9;48.5;51.1;29.7;Cadastre;A 1.0;POLYGON Z ((354580.4 6689335.2 48.5, 354581.7 6689350.3 48.5, 354583.5 6689350.1 48.5, 354591.9 6689348.5 48.5, 354597.7 6689335 48.5, 354582.1 6689328 48.5, 354580 6689329.5 48.5, 354580.4 6689335.2 48.5), (354582.3 6689331.3 48.5, 354585.5 6689332.7 48.5, 354586 6689334 48.5, 354585.1 6689336.6 48.5, 354584.1 6689337 48.5, 354583.4 6689334 48.5, 354581.8 6689332.5 48.5, 354582.3 6689331.3 48.5))
BATIMENT0000000302928014;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;16.3;29.4;45.7;49.5;29.9;Cadastre;C 0.5;POLYGON Z ((354581.7 6689350.3 45.7, 354580.4 6689335.2 45.7, 354575.2 6689335.7 45.7, 354575.3 6689337.8 45.7, 354569.8 6689338.3 45.7, 354569.7 6689336.6 45.7, 354569.1 6689336.7 45.7, 354569 6689336.4 45.7, 354563.3 6689336.9 45.7, 354563.2 6689337.3 45.7, 354560.3 6689337.5 45.7, 354560 6689337.7 45.7, 354560.1 6689339.2 45.7, 354557.1 6689339.5 45.7, 354556.9 6689336.1 45.7, 354556.4 6689335 45.7, 354555.5 6689334.7 45.7, 354553.7 6689335.3 45.7, 354554.9 6689339.1 45.7, 354557.8 6689347.4 45.7, 354558.4 6689352.2 45.7, 354581.7 6689350.3 45.7))
BATIMENT0000000302928083;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;12;20;16.8;29.2;46.1;46.9;30.1;Cadastre;C 0.9;POLYGON Z ((354592 6689371.7 46.1, 354592 6689370.9 46.1, 354593.4 6689362 46.1, 354585.5 6689360.3 46.1, 354574.4 6689361 46.1, 354577.5 6689374.6 46.1, 354592 6689371.7 46.1))
BATIMENT0000000302928082;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;12.8;28.8;41.6;44.2;30.1;Cadastre;A 1.0;POLYGON Z ((354554.4 6689362.5 41.6, 354554.7 6689378.5 41.6, 354567.7 6689377.8 41.6, 354569.2 6689377.6 41.6, 354577.7 6689375.5 41.6, 354577.5 6689374.6 41.6, 354574.4 6689361 41.6, 354554.4 6689362.5 41.6))
BATIMENT0000000302928085;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;12.4;28.8;41.2;45.0;30.2;Cadastre;A 1.0;POLYGON Z ((354596.3 6689371.9 41.2, 354595.7 6689376.7 41.2, 354605 6689378.4 41.2, 354606.1 6689373.2 41.2, 354608.1 6689373.6 41.2, 354609.7 6689364.9 41.2, 354593.4 6689362 41.2, 354592 6689370.9 41.2, 354596.3 6689371.9 41.2))
BATIMENT0000000302928094;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.5;28.8;39.3;42.8;31.0;Cadastre;C 0.8;POLYGON Z ((354607.1 6689378.6 39.3, 354623.9 6689381.4 39.3, 354623.4 6689367.2 39.3, 354609.7 6689364.9 39.3, 354608.1 6689373.6 39.3, 354607.1 6689378.6 39.3))
BATIMENT0000000302928093;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;29.8;33.5;37.5;30.8;Cadastre;;POLYGON Z ((354606.9 6689379.9 33.5, 354604.5 6689379.3 33.5, 354604.5 6689380.3 33.5, 354598.6 6689381.3 33.5, 354598.4 6689380.2 33.5, 354596.2 6689380.5 33.5, 354597.5 6689385.7 33.5, 354606 6689384.2 33.5, 354606.9 6689379.9 33.5))
BATIMENT0000000302928090;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;12;20;9.1;29.6;38.7;41.0;30.2;Cadastre;C 0.6;POLYGON Z ((354595.8 6689378.3 38.7, 354579 6689381.9 38.7, 354580.3 6689387 38.7, 354584.2 6689386 38.7, 354584.9 6689388.3 38.7, 354589.1 6689387.4 38.7, 354589.5 6689389 38.7, 354591.9 6689388.5 38.7, 354591.6 6689387 38.7, 354597.5 6689385.7 38.7, 354596.2 6689380.5 38.7, 354595.8 6689378.3 38.7))
BATIMENT0000000302928049;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;29.7;34.8;;;Cadastre;;POLYGON Z ((354684.4 6689329 34.8, 354678 6689333.1 34.8, 354672 6689337.1 34.8, 354675.9 6689341.6 34.8, 354679.6 6689338.2 34.8, 354682.7 6689341.9 34.8, 354679.2 6689345.2 34.8, 354683.5 6689349.2 34.8, 354686.6 6689345 34.8, 354696.1 6689332.7 34.8, 354695.5 6689332.1 34.8, 354693.8 6689330.4 34.8, 354692.2 6689328.8 34.8, 354686.4 6689332.4 34.8, 354684.4 6689329 34.8))
BATIMENT0000000327814959;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2013-09-26 18:22:47;2018-09-18 13:36:37;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;5.0;29.3;;37.1;29.6;Imagerie aérienne;;POLYGON Z ((354697.7 6689350.8 34.3, 354699.3 6689351.2 34.3, 354700.9 6689351.7 34.3, 354705 6689352.7 34.3, 354707 6689353 34.3, 354708.2 6689352.6 34.3, 354716.7 6689351.7 34.3, 354719.9 6689350.5 34.3, 354723.3 6689349.2 34.3, 354721.4 6689345 34.3, 354716.9 6689334.8 34.3, 354716.6 6689334.3 34.3, 354715.1 6689334.7 34.3, 354713.7 6689335.2 34.3, 354710.8 6689336 34.3, 354709.4 6689336.2 34.3, 354709.2 6689336.3 34.3, 354706.8 6689336.4 34.3, 354705.8 6689336.2 34.3, 354704.7 6689336.1 34.3, 354702.5 6689335.7 34.3, 354701.5 6689335.4 34.3, 354700.5 6689335.1 34.3, 354700 6689334.8 34.3, 354699.8 6689334.8 34.3, 354699.3 6689334.5 34.3, 354698.7 6689334.2 34.3, 354698.1 6689333.9 34.3, 354697.6 6689333.7 34.3, 354697.1 6689333.4 34.3, 354696.6 6689333 34.3, 354696.1 6689332.7 34.3, 354686.6 6689345 34.3, 354689 6689346.6 34.3, 354691.7 6689348.2 34.3, 354693.4 6689349.4 34.3, 354697.7 6689350.8 34.3))
BATIMENT0000000302928051;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;8.0;13;20;26.0;27.3;53.3;56.4;29.8;Cadastre;A 1.0;POLYGON Z ((354670.3 6689349.9 53.3, 354675 6689354.9 53.3, 354677.5 6689356.9 53.3, 354683.5 6689349.2 53.3, 354679.2 6689345.2 53.3, 354682.7 6689341.9 53.3, 354679.6 6689338.2 53.3, 354675.9 6689341.6 53.3, 354672 6689337.1 53.3, 354671.2 6689336.2 53.3, 354663.6 6689342 53.3, 354670.3 6689349.9 53.3))
BATIMENT0000000302928052;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;29.3;34.1;49.7;29.7;Cadastre;;POLYGON Z ((354693.4 6689349.4 34.1, 354691.7 6689348.2 34.1, 354689 6689346.6 34.1, 354686.6 6689345 34.1, 354683.5 6689349.2 34.1, 354685.2 6689350.3 34.1, 354686.9 6689351.4 34.1, 354689 6689352.6 34.1, 354691.4 6689353.8 34.1, 354693.4 6689349.4 34.1))
BATIMENT0000000302929012;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;29;20;11.5;29.6;41.1;42.9;30.0;Cadastre;A 1.0;POLYGON Z ((354663.7 6689365.1 41.1, 354666.5 6689360.8 41.1, 354650.6 6689341.2 41.1, 354650.2 6689340.9 41.1, 354649.5 6689340.9 41.1, 354640.3 6689346 41.1, 354646.1 6689353.5 41.1, 354646.5 6689355.5 41.1, 354649.5 6689356.3 41.1, 354654.7 6689363.3 41.1, 354663.7 6689365.1 41.1))
BATIMENT0000000302928054;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;29.2;34.3;51.7;29.6;Cadastre;;POLYGON Z ((354702.5 6689357.2 34.3, 354700.9 6689351.7 34.3, 354699.3 6689351.2 34.3, 354697.7 6689350.8 34.3, 354696.2 6689355.7 34.3, 354699 6689356.5 34.3, 354700.7 6689357 34.3, 354702.5 6689357.2 34.3))
BATIMENT0000000302929013;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;16.6;29.3;46.0;47.5;30.0;Cadastre;A 1.0;POLYGON Z ((354632.8 6689350.5 46, 354635.9 6689360.1 46, 354654.7 6689363.3 46, 354649.5 6689356.3 46, 354646.5 6689355.5 46, 354646.1 6689353.5 46, 354640.3 6689346 46, 354632.8 6689350.5 46))
BATIMENT0000000302929014;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;10;20;12.9;30.1;43.0;;;Cadastre;A 1.0;POLYGON Z ((354619.4 6689352.9 43, 354618.6 6689353.4 43, 354618.7 6689356.4 43, 354635.9 6689360.1 43, 354632.8 6689350.5 43, 354619.4 6689352.9 43))
BATIMENT0000000302928053;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;00;00;24.6;29.3;54.0;56.1;30.0;Cadastre;B 0.7;POLYGON Z ((354680.7 6689359.3 54, 354688.8 6689363.5 54, 354696.2 6689366 54, 354704.5 6689367.4 54, 354705.9 6689357.6 54, 354702.5 6689357.2 54, 354700.7 6689357 54, 354699 6689356.5 54, 354696.2 6689355.7 54, 354697.7 6689350.8 54, 354696.2 6689350.3 54, 354694.6 6689349.8 54, 354693.4 6689349.4 54, 354691.4 6689353.8 54, 354689 6689352.6 54, 354686.9 6689351.4 54, 354685.2 6689350.3 54, 354683.5 6689349.2 54, 354677.5 6689356.9 54, 354680.7 6689359.3 54))
BATIMENT0000000302927756;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;29;20;13.2;29.6;42.9;45.7;30.2;Cadastre;A 1.0;POLYGON Z ((354640.5 6689370.1 42.9, 354639.4 6689377 42.9, 354638.1 6689377.4 42.9, 354640 6689381.1 42.9, 354643 6689381.6 42.9, 354646.6 6689382.2 42.9, 354652.3 6689383.2 42.9, 354657.1 6689384.1 42.9, 354657.7 6689380.9 42.9, 354657.3 6689380.7 42.9, 354658.6 6689373.5 42.9, 354640.5 6689370.1 42.9))
BATIMENT0000000302928063;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;29.2;33.7;35.7;29.5;Cadastre;;POLYGON Z ((354725.7 6689356.3 33.7, 354725.7 6689355.4 33.7, 354725.9 6689354.7 33.7, 354724 6689350.5 33.7, 354723.3 6689349.2 33.7, 354719.9 6689350.5 33.7, 354719.1 6689355.3 33.7, 354725.7 6689356.3 33.7))
BATIMENT0000000302928058;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;29.1;36.5;41.2;29.5;Cadastre;;POLYGON Z ((354738 6689357.5 36.5, 354739.1 6689357.7 36.5, 354734.2 6689350.3 36.5, 354725.9 6689354.7 36.5, 354725.7 6689355.4 36.5, 354738 6689357.5 36.5))
BATIMENT0000000302928061;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;00;00;11.9;27.9;39.8;42.1;28.9;Cadastre;C 0.8;POLYGON Z ((354764.6 6689360.1 39.8, 354757.9 6689350.6 39.8, 354754.1 6689353.3 39.8, 354753.7 6689353 39.8, 354752.3 6689354.1 39.8, 354759.1 6689363.8 39.8, 354764.6 6689360.1 39.8))
BATIMENT0000000302928057;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;25;29;13.0;27.3;40.3;42.6;29.3;Cadastre;A 1.0;POLYGON Z ((354753.8 6689367.3 40.3, 354744.9 6689353.7 40.3, 354740.4 6689347 40.3, 354734.2 6689350.3 40.3, 354739.1 6689357.7 40.3, 354742.7 6689363.3 40.3, 354748 6689371.1 40.3, 354753.8 6689367.3 40.3))
BATIMENT0000000302928060;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;10.5;28.6;39.2;42.5;29.0;Cadastre;A 1.0;POLYGON Z ((354759.1 6689363.8 39.2, 354752.3 6689354.1 39.2, 354749.9 6689350.9 39.2, 354748 6689352.2 39.2, 354747.6 6689351.6 39.2, 354744.9 6689353.7 39.2, 354753.8 6689367.3 39.2, 354759.1 6689363.8 39.2))
BATIMENT0000000302928055;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;20;20;17.6;29.1;46.7;55.8;29.7;Cadastre;C 0.7;POLYGON Z ((354723.6 6689370.2 46.7, 354725.7 6689356.3 46.7, 354719.1 6689355.3 46.7, 354719.9 6689350.5 46.7, 354716.7 6689351.7 46.7, 354708.2 6689352.6 46.7, 354705.9 6689357.6 46.7, 354704.5 6689367.4 46.7, 354723.6 6689370.2 46.7))
BATIMENT0000000302928062;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.8;29.0;41.8;45.7;29.4;Cadastre;;POLYGON Z ((354737.2 6689362.4 41.8, 354742.7 6689363.3 41.8, 354739.1 6689357.7 41.8, 354738 6689357.5 41.8, 354737.2 6689362.4 41.8))
BATIMENT0000000302928056;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;20;20;21.9;29.0;51.0;55.9;29.7;Cadastre;B 0.3;POLYGON Z ((354744.6 6689373.3 51, 354748 6689371.1 51, 354742.7 6689363.3 51, 354737.2 6689362.4 51, 354738 6689357.5 51, 354725.7 6689355.4 51, 354725.7 6689356.3 51, 354723.6 6689370.2 51, 354744.6 6689373.3 51))
BATIMENT0000000302928326;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;;;17.0;28.5;45.5;48.6;29.1;Cadastre;A 1.0;POLYGON Z ((354786.2 6689355.3 45.5, 354774.8 6689362.9 45.5, 354774.7 6689363.2 45.5, 354765.6 6689369.2 45.5, 354769.5 6689374.8 45.5, 354770.3 6689375.9 45.5, 354770.1 6689377.5 45.5, 354769.1 6689383.7 45.5, 354785.6 6689386.7 45.5, 354789.4 6689383.9 45.5, 354789.6 6689384.2 45.5, 354800.3 6689376.8 45.5, 354800.2 6689376.6 45.5, 354797.6 6689372.5 45.5, 354797.9 6689372.2 45.5, 354794.7 6689367.2 45.5, 354794.2 6689367.5 45.5, 354792.1 6689364.1 45.5, 354786.3 6689355.4 45.5, 354786.2 6689355.3 45.5), (354786.7 6689367.6 45.5, 354789.2 6689371.3 45.5, 354781.6 6689376.5 45.5, 354775.3 6689375.7 45.5, 354775.3 6689375.1 45.5, 354786.7 6689367.6 45.5))
BATIMENT0000000302928325;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;14.6;28.8;43.5;46.0;29.5;Cadastre;A 1.0;POLYGON Z ((354750.8 6689379 43.5, 354751 6689380.4 43.5, 354769.1 6689383.7 43.5, 354770.1 6689377.5 43.5, 354769.1 6689377.3 43.5, 354769.5 6689374.8 43.5, 354765.6 6689369.2 43.5, 354750.8 6689379 43.5))
BATIMENT0000000302927761;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;;8.7;30.0;38.7;41.6;30.2;Cadastre;A 1.0;POLYGON Z ((354627.2 6689367.9 38.7, 354627.7 6689388.6 38.7, 354638.4 6689388.6 38.7, 354644.2 6689385.7 38.7, 354645.2 6689385.2 38.7, 354646.9 6689382.7 38.7, 354646.6 6689382.2 38.7, 354643 6689381.6 38.7, 354641.3 6689383.4 38.7, 354640 6689381.1 38.7, 354638.1 6689377.4 38.7, 354639.4 6689377 38.7, 354640.5 6689370.1 38.7, 354627.2 6689367.9 38.7))
BATIMENT0000000302927757;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;29.9;39.0;43.7;30.3;Cadastre;;POLYGON Z ((354644.5 6689386.8 39, 354649.8 6689386.5 39, 354652.1 6689385.1 39, 354652.3 6689383.2 39, 354646.6 6689382.2 39, 354646.9 6689382.7 39, 354645.2 6689385.2 39, 354644.2 6689385.7 39, 354644.5 6689386.8 39))
BATIMENT0000000302927760;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;12;10;17.1;30.0;47.1;50.7;30.8;Cadastre;A 1.0;POLYGON Z ((354658.6 6689373.5 47.1, 354657.3 6689380.7 47.1, 354657.7 6689380.9 47.1, 354657.1 6689384.1 47.1, 354664.3 6689394.6 47.1, 354667.1 6689392.9 47.1, 354670.9 6689398.4 47.1, 354674.6 6689395.5 47.1, 354675.5 6689389.1 47.1, 354670.5 6689388.1 47.1, 354673 6689376.2 47.1, 354658.6 6689373.5 47.1))
BATIMENT0000000302928077;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;29.9;32.7;36.7;30.8;Cadastre;;POLYGON Z ((354624.1 6689384.9 32.7, 354618.2 6689396 32.7, 354624.4 6689397.1 32.7, 354624.1 6689384.9 32.7))
BATIMENT0000000302927755;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;29.8;33.3;38.3;30.4;Cadastre;;POLYGON Z ((354638 6689394.5 33.3, 354641.3 6689394.5 33.3, 354640.2 6689392.5 33.3, 354638.4 6689388.6 33.3, 354627.7 6689388.6 33.3, 354627.8 6689394.4 33.3, 354638 6689394.5 33.3))
BATIMENT0000000302927758;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.9;31.0;36.9;38.6;31.0;Cadastre;;POLYGON Z ((354668.2 6689400.3 36.9, 354668.6 6689400 36.9, 354670.9 6689398.4 36.9, 354667.1 6689392.9 36.9, 354664.3 6689394.6 36.9, 354668.2 6689400.3 36.9))
BATIMENT0000000302927751;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;00;00;4.3;29.9;34.3;40.4;31.4;Cadastre;A 1.0;POLYGON Z ((354657.1 6689384.1 34.3, 354652.3 6689383.2 34.3, 354652.1 6689385.1 34.3, 354649.8 6689386.5 34.3, 354644.5 6689386.8 34.3, 354644.2 6689385.7 34.3, 354638.4 6689388.6 34.3, 354640.2 6689392.5 34.3, 354641.3 6689394.5 34.3, 354643.5 6689398.7 34.3, 354646.4 6689404.3 34.3, 354647.8 6689407.2 34.3, 354650.8 6689413 34.3, 354660.4 6689406 34.3, 354661.9 6689404.8 34.3, 354668.2 6689400.3 34.3, 354664.3 6689394.6 34.3, 354657.1 6689384.1 34.3))
BATIMENT0000000302927752;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;00;00;3.4;29.6;33.1;51.0;31.4;Cadastre;A 1.0;POLYGON Z ((354670.5 6689388.1 33.1, 354675.5 6689389.1 33.1, 354674.6 6689395.5 33.1, 354670.9 6689398.4 33.1, 354668.6 6689400 33.1, 354668.2 6689400.3 33.1, 354661.9 6689404.8 33.1, 354660.4 6689406 33.1, 354650.8 6689413 33.1, 354654 6689419.2 33.1, 354657.8 6689423.6 33.1, 354664.6 6689418.7 33.1, 354667.9 6689416.4 33.1, 354674.3 6689411.9 33.1, 354682.9 6689405.8 33.1, 354685.4 6689404.1 33.1, 354696.1 6689396.5 33.1, 354687.5 6689386.2 33.1, 354680.4 6689377.6 33.1, 354673 6689376.2 33.1, 354670.5 6689388.1 33.1))
BATIMENT0000000302927750;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.8;30.1;32.9;36.2;30.7;Cadastre;B 0.6;POLYGON Z ((354630.9 6689411.7 32.9, 354632.5 6689411 32.9, 354632.7 6689410.9 32.9, 354633.2 6689410.7 32.9, 354633.9 6689410.4 32.9, 354637.2 6689408.8 32.9, 354639.7 6689407.5 32.9, 354644.6 6689405.2 32.9, 354646.4 6689404.3 32.9, 354643.5 6689398.7 32.9, 354640.3 6689400.3 32.9, 354631.2 6689404.8 32.9, 354629.9 6689405.4 32.9, 354628.1 6689406.3 32.9, 354630.9 6689411.7 32.9))
BATIMENT0000000302927759;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;29.9;35.7;37.6;30.7;Cadastre;;POLYGON Z ((354646.4 6689404.3 35.7, 354644.6 6689405.2 35.7, 354646.1 6689407.9 35.7, 354647.8 6689407.2 35.7, 354646.4 6689404.3 35.7))
BATIMENT0000000302928091;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;30.0;33.9;35.9;30.9;Cadastre;;POLYGON Z ((354598.4 6689390.8 33.9, 354598.8 6689393.2 33.9, 354599.1 6689394.1 33.9, 354603.9 6689393.1 33.9, 354603 6689388.6 33.9, 354605.2 6689387.8 33.9, 354605.9 6689386.8 33.9, 354606 6689384.2 33.9, 354597.5 6689385.7 33.9, 354598.4 6689390.8 33.9))
BATIMENT0000000302928092;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;29.9;33.1;35.9;30.8;Cadastre;;POLYGON Z ((354594.2 6689391.3 33.1, 354594.8 6689394.2 33.1, 354598.8 6689393.2 33.1, 354598.4 6689390.8 33.1, 354594.2 6689391.3 33.1))
BATIMENT0000000302929185;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.6;29.7;33.3;37.7;30.8;Cadastre;C 0.3;POLYGON Z ((354570.1 6689386 33.3, 354570.1 6689391.9 33.3, 354571.5 6689391.9 33.3, 354571.4 6689398.8 33.3, 354576.8 6689397.5 33.3, 354578.7 6689405.8 33.3, 354580 6689405.6 33.3, 354581.5 6689412.5 33.3, 354584.8 6689411.9 33.3, 354584.8 6689410.8 33.3, 354585 6689409.4 33.3, 354586.2 6689409.2 33.3, 354586.3 6689408.9 33.3, 354586.4 6689408.3 33.3, 354586.5 6689408 33.3, 354586.7 6689407.7 33.3, 354586.8 6689407.4 33.3, 354587.1 6689406.9 33.3, 354587.3 6689406.6 33.3, 354587.5 6689406.4 33.3, 354587.7 6689406.2 33.3, 354588 6689406 33.3, 354588.2 6689405.8 33.3, 354588.4 6689405.6 33.3, 354588.7 6689405.4 33.3, 354589 6689405.2 33.3, 354589.5 6689404.9 33.3, 354589.8 6689404.8 33.3, 354590.4 6689404.6 33.3, 354590.7 6689404.6 33.3, 354591.3 6689404.5 33.3, 354592 6689404.5 33.3, 354592.6 6689404.5 33.3, 354592.9 6689404.6 33.3, 354593.2 6689404.7 33.3, 354593.5 6689404.8 33.3, 354593.8 6689404.9 33.3, 354594.1 6689405 33.3, 354594.4 6689405.1 33.3, 354594.6 6689405.3 33.3, 354594.9 6689405.5 33.3, 354595.4 6689405.8 33.3, 354595.6 6689406 33.3, 354595.8 6689406.3 33.3, 354595.1 6689407.4 33.3, 354595.8 6689407.8 33.3, 354596.6 6689409 33.3, 354601.2 6689406.7 33.3, 354598.6 6689394.4 33.3, 354582.8 6689398 33.3, 354582.3 6689396.6 33.3, 354581.7 6689393.2 33.3, 354580.9 6689389.2 33.3, 354580.3 6689387 33.3, 354579 6689381.9 33.3, 354577.7 6689375.5 33.3, 354569.2 6689377.6 33.3, 354568.9 6689386 33.3, 354570.1 6689386 33.3))
BATIMENT0000000302928078;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;8.3;30.1;38.4;40.8;31.2;Cadastre;A 1.0;POLYGON Z ((354613 6689394.8 38.4, 354612.8 6689397.6 38.4, 354613.5 6689397.7 38.4, 354613.5 6689399.3 38.4, 354614.1 6689399.5 38.4, 354614.6 6689406.5 38.4, 354624.6 6689406.2 38.4, 354624.4 6689397.1 38.4, 354618.2 6689396 38.4, 354613 6689394.8 38.4))
BATIMENT0000000302929245;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;00;00;15.1;29.3;44.4;49.1;29.9;Cadastre;C 0.3;POLYGON Z ((354589.9 6689423.8 44.4, 354581.3 6689413.6 44.4, 354580.5 6689413.8 44.4, 354580.3 6689412.8 44.4, 354581.5 6689412.5 44.4, 354580 6689405.6 44.4, 354578.7 6689405.8 44.4, 354576.8 6689397.5 44.4, 354571.4 6689398.8 44.4, 354571.5 6689391.9 44.4, 354570.1 6689391.9 44.4, 354570.1 6689386 44.4, 354568.9 6689386 44.4, 354569.2 6689377.6 44.4, 354567.7 6689377.8 44.4, 354554.7 6689378.5 44.4, 354554.9 6689398.7 44.4, 354564.8 6689398.3 44.4, 354566.5 6689405.8 44.4, 354567.3 6689408.9 44.4, 354568.6 6689415.4 44.4, 354568.8 6689416.5 44.4, 354562.2 6689417.5 44.4, 354576.2 6689434.3 44.4, 354580.2 6689431 44.4, 354578.8 6689429.5 44.4, 354581.1 6689427.4 44.4, 354582.6 6689429.1 44.4, 354582.8 6689429.3 44.4, 354585.8 6689426.8 44.4, 354587 6689426 44.4, 354589.9 6689423.8 44.4))
BATIMENT0000000302928084;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;29.5;32.0;32.9;30.0;Cadastre;;POLYGON Z ((354595.1 6689407.4 32, 354595.8 6689406.3 32, 354595.6 6689406 32, 354595.4 6689405.8 32, 354594.9 6689405.5 32, 354594.6 6689405.3 32, 354594.4 6689405.1 32, 354594.1 6689405 32, 354593.8 6689404.9 32, 354593.5 6689404.8 32, 354593.2 6689404.7 32, 354592.9 6689404.6 32, 354592.6 6689404.5 32, 354592 6689404.5 32, 354591.3 6689404.5 32, 354590.7 6689404.6 32, 354590.4 6689404.6 32, 354589.8 6689404.8 32, 354589.5 6689404.9 32, 354589 6689405.2 32, 354588.7 6689405.4 32, 354588.4 6689405.6 32, 354588.2 6689405.8 32, 354588 6689406 32, 354587.7 6689406.2 32, 354587.5 6689406.4 32, 354587.3 6689406.6 32, 354587.1 6689406.9 32, 354586.8 6689407.4 32, 354586.7 6689407.7 32, 354586.5 6689408 32, 354586.4 6689408.3 32, 354586.3 6689408.9 32, 354586.2 6689409.2 32, 354595.1 6689407.4 32))
BATIMENT0000000302928096;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;5.0;00;00;16.1;29.3;45.4;47.6;29.6;Cadastre;C 0.9;POLYGON Z ((354564.8 6689398.3 45.4, 354554.9 6689398.7 45.4, 354555.1 6689409.3 45.4, 354562.2 6689417.5 45.4, 354568.8 6689416.5 45.4, 354568.6 6689415.4 45.4, 354567.3 6689408.9 45.4, 354565.9 6689409.4 45.4, 354564.2 6689407.2 45.4, 354566.5 6689405.8 45.4, 354564.8 6689398.3 45.4))
BATIMENT0000000302928079;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;26;90;8.4;30.1;38.5;41.1;31.1;Cadastre;A 1.0;POLYGON Z ((354612.1 6689406.7 38.5, 354612.1 6689411 38.5, 354615.4 6689411 38.5, 354615.8 6689416.6 38.5, 354624.9 6689416.6 38.5, 354624.6 6689406.2 38.5, 354614.6 6689406.5 38.5, 354612.1 6689406.7 38.5))
BATIMENT0000000302928243;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;30.0;32.7;35.7;31.0;Cadastre;;POLYGON Z ((354600.9 6689418.7 32.7, 354603.2 6689423.1 32.7, 354606.8 6689421.6 32.7, 354604.7 6689416.7 32.7, 354600.9 6689418.7 32.7))
BATIMENT0000000302928080;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;90;8.4;30.0;38.4;41.3;31.2;Cadastre;A 1.0;POLYGON Z ((354614.3 6689416.7 38.4, 354614.7 6689432.5 38.4, 354615.4 6689432.4 38.4, 354618.8 6689430.4 38.4, 354619.6 6689430.1 38.4, 354621.1 6689428.1 38.4, 354620.8 6689425.5 38.4, 354620.5 6689422.2 38.4, 354625 6689420.2 38.4, 354624.9 6689416.6 38.4, 354615.8 6689416.6 38.4, 354614.3 6689416.7 38.4))
BATIMENT0000000302929016;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;12.9;30.1;43.0;;;Cadastre;B 0.7;POLYGON Z ((354740.8 6689388.9 43, 354739.5 6689399.2 43, 354742.5 6689399.7 43, 354742.5 6689400.4 43, 354743.2 6689400.9 43, 354744 6689400.6 43, 354744.1 6689399.9 43, 354748.2 6689400.5 43, 354750.4 6689400.9 43, 354753.4 6689399.9 43, 354755 6689391.5 43, 354740.8 6689388.9 43))
BATIMENT0000000302929019;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;11.5;29.1;40.7;44.2;29.9;Cadastre;A 1.0;POLYGON Z ((354731.2 6689387.1 40.7, 354729.6 6689396.2 40.7, 354728.9 6689400.5 40.7, 354738.6 6689405.8 40.7, 354738.9 6689405.4 40.7, 354739.2 6689402.2 40.7, 354739.5 6689399.2 40.7, 354740.8 6689388.9 40.7, 354731.2 6689387.1 40.7))
BATIMENT0000000302929022;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;16.0;29.6;45.7;49.8;30.1;Cadastre;A 1.0;POLYGON Z ((354728.9 6689396.1 45.7, 354714.4 6689393.8 45.7, 354709.8 6689397.5 45.7, 354709.8 6689398.1 45.7, 354718.9 6689408.8 45.7, 354728.9 6689400.5 45.7, 354729.6 6689396.2 45.7, 354728.9 6689396.1 45.7))
BATIMENT0000000302929021;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1796-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;15.3;28.9;44.2;47.2;29.3;Cadastre;A 1.0;POLYGON Z ((354775.6 6689399.1 44.2, 354772.5 6689394.6 44.2, 354755 6689391.5 44.2, 354753.4 6689399.9 44.2, 354758.2 6689401.1 44.2, 354757.8 6689402.4 44.2, 354755.6 6689402.5 44.2, 354754.3 6689403.8 44.2, 354760.7 6689411.5 44.2, 354775.6 6689399.1 44.2))
BATIMENT0000000302929015;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;29.0;39.2;42.6;29.7;Cadastre;;POLYGON Z ((354738.9 6689405.4 39.2, 354744 6689404.3 39.2, 354749.2 6689403.3 39.2, 354749.9 6689403.1 39.2, 354749.5 6689401.7 39.2, 354739.2 6689402.2 39.2, 354738.9 6689405.4 39.2))
BATIMENT0000000302929017;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.4;29.0;39.5;42.8;29.3;Cadastre;A 0.4;POLYGON Z ((354745.7 6689407.5 39.5, 354749.7 6689404.7 39.5, 354749.2 6689403.3 39.5, 354744 6689404.3 39.5, 354745.7 6689407.5 39.5))
BATIMENT0000000302929020;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;13.6;30.1;43.7;;;Cadastre;A 0.6;POLYGON Z ((354760.7 6689411.5 43.7, 354754.3 6689403.8 43.7, 354753 6689402.4 43.7, 354751.2 6689402.8 43.7, 354752.7 6689405 43.7, 354751.9 6689405.7 43.7, 354751.2 6689404.9 43.7, 354741.3 6689413.1 43.7, 354739.7 6689411.1 43.7, 354741.6 6689409.4 43.7, 354738.6 6689405.8 43.7, 354734.4 6689409.3 43.7, 354736.2 6689411.6 43.7, 354739.1 6689415 43.7, 354739.4 6689414.7 43.7, 354746.8 6689423.1 43.7, 354760.7 6689411.5 43.7))
BATIMENT0000000302929018;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;12;20;19.1;29.3;48.5;50.8;30.2;Cadastre;A 1.0;POLYGON Z ((354737.5 6689430.9 48.5, 354746.8 6689423.1 48.5, 354739.4 6689414.7 48.5, 354739.1 6689415 48.5, 354736.2 6689411.6 48.5, 354735 6689412.7 48.5, 354731.8 6689409.1 48.5, 354733 6689408 48.5, 354733.9 6689408.8 48.5, 354734.4 6689409.3 48.5, 354738.6 6689405.8 48.5, 354728.9 6689400.5 48.5, 354718.9 6689408.8 48.5, 354737.5 6689430.9 48.5))
BATIMENT0000000302928350;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;16.3;28.6;45.0;47.9;29.3;Cadastre;A 1.0;POLYGON Z ((354793.5 6689424.3 45, 354790.5 6689420.1 45, 354776 6689432.1 45, 354779.6 6689436.2 45, 354781 6689435 45, 354782.6 6689437.1 45, 354781.8 6689438.8 45, 354784.7 6689439.3 45, 354790.4 6689440.2 45, 354793.5 6689424.3 45))
BATIMENT0000000302927749;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;10;16.8;29.5;46.3;48.4;30.1;Cadastre;C 0.7;POLYGON Z ((354730.1 6689437.1 46.3, 354717.7 6689422.1 46.3, 354713.1 6689426.3 46.3, 354715.8 6689429.4 46.3, 354717.6 6689431.4 46.3, 354715.5 6689432.6 46.3, 354713.8 6689431 46.3, 354710.5 6689433.9 46.3, 354709.3 6689435.1 46.3, 354710.8 6689437.1 46.3, 354708.8 6689438.4 46.3, 354708.3 6689438.2 46.3, 354704 6689442 46.3, 354704.1 6689442.5 46.3, 354701.4 6689444.7 46.3, 354698.6 6689441.7 46.3, 354696 6689443.8 46.3, 354706.9 6689456.8 46.3, 354730.1 6689437.1 46.3))
BATIMENT0000000302927753;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;10;18.4;29.6;48.0;51.1;30.3;Cadastre;A 1.0;POLYGON Z ((354696.1 6689396.5 48, 354685.4 6689404.1 48, 354710.5 6689433.9 48, 354713.8 6689431 48, 354715.8 6689429.4 48, 354713.1 6689426.3 48, 354717.7 6689422.1 48, 354696.1 6689396.5 48))
BATIMENT0000000302929227;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;30.5;34.7;37.7;30.5;Cadastre;;POLYGON Z ((354642.5 6689434.8 34.7, 354646 6689433.2 34.7, 354646.8 6689434 34.7, 354657.1 6689428.6 34.7, 354647.5 6689410.2 34.7, 354635.7 6689416.2 34.7, 354633.4 6689417.4 34.7, 354642.5 6689434.8 34.7))
BATIMENT0000000302929226;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;30.5;34.7;41.4;30.5;Cadastre;;POLYGON Z ((354632.8 6689421.3 34.7, 354633.8 6689425.7 34.7, 354636 6689425.2 34.7, 354641.1 6689444 34.7, 354646.4 6689442.7 34.7, 354648.4 6689440.8 34.7, 354646.8 6689434 34.7, 354646 6689433.2 34.7, 354642.5 6689434.8 34.7, 354633.4 6689417.4 34.7, 354635.7 6689416.2 34.7, 354633.2 6689410.7 34.7, 354632.7 6689410.9 34.7, 354632.5 6689411 34.7, 354630.9 6689411.7 34.7, 354628.3 6689412.8 34.7, 354628.5 6689419.8 34.7, 354632.8 6689421.3 34.7))
BATIMENT0000000302927748;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.4;30.0;36.4;39.5;30.0;Cadastre;A 1.0;POLYGON Z ((354696 6689443.8 36.4, 354698.6 6689441.7 36.4, 354704.6 6689436.9 36.4, 354690.1 6689420.4 36.4, 354687.9 6689422.3 36.4, 354685.9 6689424 36.4, 354683.5 6689425.9 36.4, 354681.9 6689427.3 36.4, 354696 6689443.8 36.4))
BATIMENT0000000302928081;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;30.2;33.3;33.5;30.8;Cadastre;;POLYGON Z ((354625 6689428.1 33.3, 354621.9 6689428.7 33.3, 354620.7 6689430.7 33.3, 354621.3 6689433.5 33.3, 354622.2 6689437.2 33.3, 354625.4 6689436.5 33.3, 354624.7 6689432.4 33.3, 354626.8 6689431.8 33.3, 354625.9 6689427.8 33.3, 354625 6689428.1 33.3))
BATIMENT0000000302927743;Indifférenciée;Religieux;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.6;30.3;36.9;42.1;30.8;Cadastre;C 0.4;POLYGON Z ((354630.9 6689426.5 36.9, 354634.3 6689438.6 36.9, 354623.2 6689441.2 36.9, 354624.3 6689446.8 36.9, 354626.1 6689455.4 36.9, 354642.8 6689451.5 36.9, 354641.8 6689447.2 36.9, 354641.1 6689444 36.9, 354636 6689425.2 36.9, 354633.8 6689425.7 36.9, 354630.9 6689426.5 36.9))
BATIMENT0000000302927744;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;10.2;29.7;40.0;49.0;30.4;Cadastre;A 1.0;POLYGON Z ((354680.7 6689435.3 40, 354683.1 6689435.5 40, 354688.9 6689442.6 40, 354679.8 6689450.3 40, 354684.8 6689456.3 40, 354694.1 6689467.4 40, 354706.9 6689456.8 40, 354696 6689443.8 40, 354681.9 6689427.3 40, 354675.8 6689432.4 40, 354669.2 6689437.9 40, 354672.7 6689442 40, 354680.7 6689435.3 40))
BATIMENT0000000302929176;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;30.0;34.3;47.2;30.9;Cadastre;;POLYGON Z ((354643 6689452.6 34.3, 354660.9 6689474 34.3, 354661.9 6689475.2 34.3, 354684.8 6689456.3 34.3, 354679.8 6689450.3 34.3, 354672.7 6689442 34.3, 354669.2 6689437.9 34.3, 354661.7 6689428.7 34.3, 354648.4 6689440.8 34.3, 354646.4 6689442.7 34.3, 354641.8 6689447.2 34.3, 354642.8 6689451.5 34.3, 354643 6689452.6 34.3))
BATIMENT0000000302927747;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.4;30.4;35.8;39.2;30.9;Cadastre;C 0.4;POLYGON Z ((354621.1 6689447.7 35.8, 354621.6 6689450.6 35.8, 354620.7 6689451.1 35.8, 354622.3 6689458.3 35.8, 354625.8 6689457.6 35.8, 354626.7 6689457 35.8, 354626.1 6689455.4 35.8, 354624.3 6689446.8 35.8, 354621.1 6689447.7 35.8))
BATIMENT0000000302927746;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;30.4;38.7;46.6;31.4;Cadastre;;POLYGON Z ((354627.6 6689464.8 38.7, 354630.8 6689462.1 38.7, 354626.7 6689457 38.7, 354625.8 6689457.6 38.7, 354622.3 6689458.3 38.7, 354627.6 6689464.8 38.7))
BATIMENT0000000302928352;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.1;28.4;43.5;47.4;29.6;Cadastre;;POLYGON Z ((354753.8 6689450.8 43.5, 354766.4 6689465.9 43.5, 354775.2 6689458.5 43.5, 354775.7 6689454.6 43.5, 354774.3 6689454.6 43.5, 354773.2 6689454.9 43.5, 354772.4 6689455.2 43.5, 354770.6 6689456.6 43.5, 354767.8 6689453.4 43.5, 354767.9 6689451.6 43.5, 354771.1 6689449.2 43.5, 354772.2 6689450.1 43.5, 354776.3 6689450.9 43.5, 354776.8 6689447.4 43.5, 354779 6689445.7 43.5, 354780.8 6689441.3 43.5, 354777.6 6689437.8 43.5, 354779.6 6689436.2 43.5, 354776 6689432.1 43.5, 354753.8 6689450.8 43.5))
BATIMENT0000000302928349;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;23;11.9;28.7;40.7;43.4;29.3;Cadastre;A 1.0;POLYGON Z ((354790.4 6689440.2 40.7, 354784.7 6689439.3 40.7, 354783.7 6689441.7 40.7, 354780.8 6689441.3 40.7, 354779 6689445.7 40.7, 354776.8 6689447.4 40.7, 354776.3 6689450.9 40.7, 354778.2 6689451.3 40.7, 354777.5 6689454.9 40.7, 354775.7 6689454.6 40.7, 354775.2 6689458.5 40.7, 354786.3 6689460.7 40.7, 354790.4 6689440.2 40.7))
BATIMENT0000000302928351;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;28.8;39.0;39.3;29.0;Cadastre;;POLYGON Z ((354775.9 6689453.6 39, 354776.7 6689453.7 39, 354777.1 6689452.2 39, 354776.1 6689452.1 39, 354775.9 6689453.6 39))
BATIMENT0000000302928353;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1825-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;15.9;27.0;42.9;46.1;29.5;Cadastre;A 1.0;POLYGON Z ((354778.8 6689481 42.9, 354779.7 6689480.3 42.9, 354780.6 6689479.8 42.9, 354781.7 6689479.4 42.9, 354782.6 6689479.2 42.9, 354786.3 6689460.7 42.9, 354775.2 6689458.5 42.9, 354766.4 6689465.9 42.9, 354778.8 6689481 42.9), (354776.2 6689462.5 42.9, 354779 6689463.1 42.9, 354778.7 6689465.7 42.9, 354777.2 6689465.4 42.9, 354776.9 6689464.7 42.9, 354776.4 6689464.2 42.9, 354775.8 6689464 42.9, 354776.2 6689462.5 42.9))
BATIMENT0000000302928291;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;12;20;12.6;29.0;41.7;43.5;29.7;Cadastre;A 1.0;POLYGON Z ((354747.4 6689457.4 41.7, 354746.1 6689457.4 41.7, 354731.7 6689470 41.7, 354742.3 6689483 41.7, 354746.9 6689479.1 41.7, 354747.6 6689478.6 41.7, 354746.5 6689477.3 41.7, 354745.1 6689478.6 41.7, 354743.2 6689476.1 41.7, 354751.3 6689469.3 41.7, 354752.2 6689470.3 41.7, 354749.2 6689472.9 41.7, 354751.2 6689475.2 41.7, 354751.5 6689475.1 41.7, 354757.7 6689470.1 41.7, 354747.4 6689457.4 41.7))
BATIMENT0000000302928292;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;16.7;28.7;45.5;47.5;29.5;Cadastre;A 1.0;POLYGON Z ((354752.5 6689495 45.5, 354767.7 6689482.2 45.5, 354757.7 6689470.1 45.5, 354751.5 6689475.1 45.5, 354754 6689478 45.5, 354753.7 6689478.7 45.5, 354753.7 6689480.2 45.5, 354755.3 6689481.6 45.5, 354756.8 6689482.5 45.5, 354757.5 6689481.6 45.5, 354758.3 6689482.7 45.5, 354754.6 6689485.9 45.5, 354753.9 6689485.4 45.5, 354752.7 6689484.9 45.5, 354752.2 6689485.4 45.5, 354746.9 6689479.1 45.5, 354742.3 6689483 45.5, 354742.5 6689483.4 45.5, 354746.8 6689488.2 45.5, 354752.5 6689495 45.5))
BATIMENT0000000302928290;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;00;00;15.7;29.3;45.0;46.7;30.5;Cadastre;A 1.0;POLYGON Z ((354716.7 6689482.4 45, 354727.9 6689495.7 45, 354731.1 6689493 45, 354728.5 6689489.8 45, 354732.1 6689486.5 45, 354734 6689489 45, 354736.1 6689486.9 45, 354734.8 6689485.2 45, 354734.9 6689484 45, 354737.1 6689482.1 45, 354740.2 6689485.5 45, 354742.5 6689483.4 45, 354742.3 6689483 45, 354731.7 6689470 45, 354716.7 6689482.4 45))
BATIMENT0000000302928294;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;29.2;44.4;46.7;29.6;Cadastre;;POLYGON Z ((354744 6689490.5 44.4, 354746.8 6689488.2 44.4, 354742.5 6689483.4 44.4, 354740.2 6689485.5 44.4, 354744 6689490.5 44.4))
BATIMENT0000000302928295;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;29.6;35.4;38.2;30.4;Cadastre;;POLYGON Z ((354735.2 6689498 35.4, 354731.1 6689493 35.4, 354727.9 6689495.7 35.4, 354732 6689500.7 35.4, 354735.2 6689498 35.4))
BATIMENT0000000302928296;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;14.6;28.6;43.2;45.6;30.1;Cadastre;A 1.0;POLYGON Z ((354761.8 6689506 43.2, 354767 6689512.1 43.2, 354774.8 6689496.8 43.2, 354774.2 6689494.9 43.2, 354773.8 6689493.4 43.2, 354773.7 6689493.1 43.2, 354773.7 6689492.3 43.2, 354773.7 6689491.3 43.2, 354773.6 6689491 43.2, 354773.7 6689490.8 43.2, 354773.7 6689490.6 43.2, 354773.8 6689490.2 43.2, 354773.8 6689490 43.2, 354773.8 6689489.8 43.2, 354773.7 6689489.6 43.2, 354773.6 6689489.4 43.2, 354767.7 6689482.2 43.2, 354752.5 6689495 43.2, 354761.8 6689506 43.2), (354762.8 6689494.7 43.2, 354763.8 6689494.9 43.2, 354764.4 6689494.8 43.2, 354766.1 6689496.7 43.2, 354765.4 6689497.7 43.2, 354765.4 6689498.3 43.2, 354764.6 6689499.1 43.2, 354765.4 6689500.1 43.2, 354762.5 6689502.4 43.2, 354761.7 6689501.2 43.2, 354758.9 6689498 43.2, 354762.8 6689494.7 43.2))
BATIMENT0000000302931469;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;;;12.1;15.1;27.2;35.3;16.9;Cadastre;A 1.0;POLYGON Z ((355075.5 6689374.4 27.2, 355077.8 6689348.8 27.2, 355076.3 6689348.4 27.2, 355070.7 6689347.1 27.2, 355068.9 6689346.7 27.2, 355063.4 6689362.8 27.2, 355063.8 6689363 27.2, 355061.2 6689372.5 27.2, 355075.5 6689374.4 27.2))
BATIMENT0000000302931477;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;7.0;50;20;11.1;14.3;25.5;34.8;15.8;Cadastre;A 1.0;POLYGON Z ((355088.6 6689376.5 25.5, 355096.4 6689368 25.5, 355092.2 6689365.2 25.5, 355089.5 6689365.7 25.5, 355090.1 6689359.2 25.5, 355090.7 6689351.8 25.5, 355078.9 6689349 25.5, 355077.8 6689348.8 25.5, 355075.5 6689374.4 25.5, 355088.6 6689376.5 25.5))
BATIMENT0000000302931470;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.7;14.9;32.6;36.6;18.0;Cadastre;A 1.0;POLYGON Z ((355061.2 6689372.5 32.6, 355063.8 6689363 32.6, 355063.4 6689362.8 32.6, 355046.9 6689356.7 32.6, 355045.6 6689361.4 32.6, 355045.3 6689361.4 32.6, 355044.9 6689362.9 32.6, 355044.6 6689363 32.6, 355042.7 6689369.7 32.6, 355061.2 6689372.5 32.6))
BATIMENT0000000302931838;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.1;16.5;22.6;25.0;17.6;Cadastre;C 0.6;POLYGON Z ((355055.6 6689401.7 22.6, 355058.5 6689384.1 22.6, 355047.8 6689382.5 22.6, 355045.3 6689400.5 22.6, 355055.6 6689401.7 22.6))
BATIMENT0000000302930895;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.3;15.5;22.8;23.2;16.5;Cadastre;A 1.0;POLYGON Z ((355063.5 6689395.2 22.8, 355076 6689397 22.8, 355078.6 6689397.3 22.8, 355079.5 6689390.3 22.8, 355064.5 6689388.1 22.8, 355063.5 6689395.2 22.8))
BATIMENT0000000302931671;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;8.2;14.3;22.5;23.5;15.3;Cadastre;A 1.0;POLYGON Z ((355086.1 6689398.4 22.5, 355105 6689401.2 22.5, 355106 6689394.1 22.5, 355095.7 6689392.6 22.5, 355087.1 6689391.4 22.5, 355086.1 6689398.4 22.5))
BATIMENT0000000302931839;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;7.0;13;30;8.3;14.3;22.6;39.8;19.6;Cadastre;C 0.4;POLYGON Z ((355035.1 6689397.8 22.6, 355034.4 6689403.4 22.6, 355036.4 6689405 22.6, 355036.2 6689407.3 22.6, 355035.1 6689408.4 22.6, 355039.9 6689414.1 22.6, 355066.2 6689418.8 22.6, 355068.7 6689416 22.6, 355071 6689416.1 22.6, 355072.1 6689417.5 22.6, 355072.1 6689418.7 22.6, 355074.8 6689419.9 22.6, 355092.6 6689423.2 22.6, 355094.2 6689420.9 22.6, 355095.1 6689420.5 22.6, 355096.8 6689420.6 22.6, 355098.2 6689422.2 22.6, 355099.1 6689424.5 22.6, 355144.8 6689432.4 22.6, 355145.5 6689429 22.6, 355126.1 6689390.6 22.6, 355117.3 6689396.6 22.6, 355115.7 6689405.7 22.6, 355115.3 6689405.6 22.6, 355114.9 6689405.5 22.6, 355114.4 6689405.5 22.6, 355114 6689405.5 22.6, 355113.5 6689405.6 22.6, 355113.1 6689405.6 22.6, 355112.7 6689405.7 22.6, 355112.3 6689405.9 22.6, 355111.9 6689406 22.6, 355111.5 6689406.1 22.6, 355110.8 6689406.5 22.6, 355110.5 6689406.8 22.6, 355110.2 6689407 22.6, 355109.9 6689407.3 22.6, 355109.7 6689407.6 22.6, 355109.1 6689408.4 22.6, 355108.8 6689408.9 22.6, 355108.5 6689409.4 22.6, 355108.3 6689410 22.6, 355108.1 6689410.5 22.6, 355108 6689411.1 22.6, 355055.6 6689401.7 22.6, 355045.3 6689400.5 22.6, 355047.8 6689382.5 22.6, 355026.3 6689379.4 22.6, 355024.3 6689396 22.6, 355024.4 6689396.1 22.6, 355035.1 6689397.8 22.6))
BATIMENT0000000302931837;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;13;30;25.6;16.0;41.6;47.9;20.2;Cadastre;C 0.6;POLYGON Z ((355024.4 6689412 41.6, 355025.3 6689412.6 41.6, 355026.1 6689413.2 41.6, 355027.1 6689414 41.6, 355027.8 6689414.8 41.6, 355028.5 6689415.6 41.6, 355029.1 6689416.5 41.6, 355029.6 6689417.4 41.6, 355030 6689418.1 41.6, 355030.3 6689418.6 41.6, 355030.7 6689419.5 41.6, 355031.1 6689420.3 41.6, 355031.2 6689420.7 41.6, 355031.4 6689421.2 41.6, 355031.7 6689422.1 41.6, 355031.9 6689423 41.6, 355142.9 6689442.7 41.6, 355144.8 6689432.4 41.6, 355099.1 6689424.5 41.6, 355098.2 6689422.2 41.6, 355096.8 6689420.6 41.6, 355095.1 6689420.5 41.6, 355094.2 6689420.9 41.6, 355092.6 6689423.2 41.6, 355074.8 6689419.9 41.6, 355072.1 6689418.7 41.6, 355072.1 6689417.5 41.6, 355071 6689416.1 41.6, 355068.7 6689416 41.6, 355066.2 6689418.8 41.6, 355039.9 6689414.1 41.6, 355035.1 6689408.4 41.6, 355036.2 6689407.3 41.6, 355036.4 6689405 41.6, 355034.4 6689403.4 41.6, 355035.1 6689397.8 41.6, 355024.4 6689396.1 41.6, 355024.3 6689396 41.6, 355022.6 6689411.1 41.6, 355023.5 6689411.5 41.6, 355024.4 6689412 41.6))
BATIMENT0000000302931827;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;27.3;19.1;46.5;47.5;20.4;Cadastre;;POLYGON Z ((355035 6689471.2 46.5, 355038.8 6689468.7 46.5, 355038.4 6689467.6 46.5, 355041.5 6689465.5 46.5, 355045.3 6689460.7 46.5, 355054.1 6689461.6 46.5, 355053.3 6689465.4 46.5, 355059.9 6689466.4 46.5, 355062.1 6689454.4 46.5, 355035.9 6689449.9 46.5, 355035.6 6689450.7 46.5, 355035.3 6689451.6 46.5, 355034.9 6689452.5 46.5, 355034.5 6689453.3 46.5, 355034.1 6689454.2 46.5, 355033.3 6689455.7 46.5, 355032.4 6689457.1 46.5, 355031.3 6689458.5 46.5, 355030.1 6689459.7 46.5, 355028.9 6689460.9 46.5, 355028.2 6689461.4 46.5, 355035 6689471.2 46.5))
BATIMENT0000000302931829;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;25.1;17.6;42.7;44.0;19.3;Cadastre;;POLYGON Z ((355082 6689470.4 42.7, 355082.5 6689468.1 42.7, 355084.2 6689458.2 42.7, 355062.1 6689454.4 42.7, 355059.9 6689466.4 42.7, 355082 6689470.4 42.7))
BATIMENT0000000302931488;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1872-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;10;20;13.2;7.0;20.2;22.4;8.7;Cadastre;A 1.0;POLYGON Z ((355307.2 6689408.4 20.2, 355307.6 6689398.7 20.2, 355306 6689398.9 20.2, 355302.7 6689399.5 20.2, 355289.7 6689401.2 20.2, 355284.3 6689401.9 20.2, 355280.5 6689402.5 20.2, 355280.3 6689411.3 20.2, 355296 6689409.6 20.2, 355306.3 6689408.6 20.2, 355307.2 6689408.4 20.2))
BATIMENT0000000302930979;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;00;00;16.2;9.4;25.7;26.9;11.7;Cadastre;A 1.0;POLYGON Z ((355204.9 6689403.9 25.7, 355202.5 6689404 25.7, 355202.3 6689414.8 25.7, 355204.8 6689414.8 25.7, 355206.8 6689414.9 25.7, 355206.8 6689415.2 25.7, 355219.4 6689415.4 25.7, 355219.3 6689410.1 25.7, 355219.8 6689409.8 25.7, 355220.4 6689409.8 25.7, 355219.8 6689403.6 25.7, 355219.3 6689403.6 25.7, 355204.8 6689403.5 25.7, 355204.9 6689403.9 25.7))
BATIMENT0000000302931489;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;10;20;12.8;6.9;19.7;24.2;7.6;Cadastre;A 1.0;POLYGON Z ((355304.5 6689410.1 19.7, 355306.3 6689408.6 19.7, 355296 6689409.6 19.7, 355296.1 6689413.4 19.7, 355304 6689413.1 19.7, 355304.5 6689410.1 19.7))
BATIMENT0000000302931851;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;26.7;10.1;36.8;;;Cadastre;;POLYGON Z ((355229.6 6689420.4 36.8, 355229.7 6689428.7 36.8, 355228.5 6689428.8 36.8, 355228.5 6689429.1 36.8, 355239.4 6689428.9 36.8, 355239.7 6689442.6 36.8, 355241.6 6689444.5 36.8, 355243.7 6689444.8 36.8, 355245.4 6689444.8 36.8, 355247.3 6689444.4 36.8, 355249.2 6689442.9 36.8, 355249.6 6689428.7 36.8, 355261.2 6689428.4 36.8, 355261.2 6689428.1 36.8, 355259.7 6689428 36.8, 355259.6 6689419.9 36.8, 355261 6689419.9 36.8, 355261 6689418.7 36.8, 355259.2 6689418.8 36.8, 355259.1 6689417.2 36.8, 355249.6 6689417.5 36.8, 355250.5 6689389 36.8, 355249 6689389 36.8, 355248.9 6689386.9 36.8, 355249.3 6689386.8 36.8, 355249.4 6689386.3 36.8, 355250.4 6689386.1 36.8, 355250.3 6689385.1 36.8, 355249.4 6689385 36.8, 355249.4 6689384.5 36.8, 355248.9 6689384.4 36.8, 355248.9 6689383.7 36.8, 355247.9 6689383.7 36.8, 355247.9 6689384.6 36.8, 355247.5 6689384.5 36.8, 355245.8 6689386 36.8, 355245.8 6689386.9 36.8, 355242.1 6689387 36.8, 355242.2 6689386.3 36.8, 355240.9 6689384.7 36.8, 355240.5 6689384.7 36.8, 355240.6 6689383.9 36.8, 355239.5 6689383.9 36.8, 355239.5 6689384.7 36.8, 355238.8 6689384.7 36.8, 355238.9 6689385.4 36.8, 355237.8 6689385.4 36.8, 355237.9 6689386.4 36.8, 355238.7 6689386.4 36.8, 355238.8 6689387.1 36.8, 355239.3 6689387 36.8, 355239.3 6689389.2 36.8, 355237.7 6689389.2 36.8, 355237.9 6689394.6 36.8, 355238.8 6689394.7 36.8, 355239.3 6689417.5 36.8, 355230.1 6689417.4 36.8, 355230.2 6689419.3 36.8, 355228.4 6689419.5 36.8, 355228.5 6689420.5 36.8, 355229.6 6689420.4 36.8))
BATIMENT0000000302931490;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.8;6.8;23.7;25.7;8.3;Cadastre;A 1.0;POLYGON Z ((355304 6689413.1 23.7, 355296.1 6689413.4 23.7, 355290.3 6689413.6 23.7, 355290.1 6689420.5 23.7, 355302.9 6689421.9 23.7, 355304 6689413.1 23.7))
BATIMENT0000000302931491;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;;;19.8;7.4;27.2;29.4;10.6;Cadastre;C 0.2;POLYGON Z ((355270.5 6689418.2 27.2, 355273 6689421.5 27.2, 355285.2 6689424.8 27.2, 355285.5 6689419.9 27.2, 355285.7 6689413.9 27.2, 355280.2 6689414 27.2, 355270.4 6689414.5 27.2, 355270.5 6689418.2 27.2))
BATIMENT0000000302931492;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;15.3;7.4;22.8;24.7;9.9;Cadastre;A 1.0;POLYGON Z ((355300.9 6689429 22.8, 355302.3 6689427.4 22.8, 355302.9 6689421.9 22.8, 355290.1 6689420.5 22.8, 355285.5 6689419.9 22.8, 355285.2 6689424.8 22.8, 355300.9 6689429 22.8))
BATIMENT0000000302930901;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;15.1;7.9;23.0;31.5;11.0;Cadastre;A 1.0;POLYGON Z ((355301.3 6689438.5 23, 355300.1 6689436.7 23, 355274.1 6689429.9 23, 355270.9 6689432.6 23, 355270.9 6689438.3 23, 355284.3 6689440.7 23, 355285.9 6689440.9 23, 355290.9 6689441.9 23, 355290.2 6689447.5 23, 355292.8 6689447.9 23, 355299.8 6689449.2 23, 355301.3 6689438.5 23))
BATIMENT0000000302930902;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.2;9.4;22.6;33.5;11.0;Cadastre;;POLYGON Z ((355290.2 6689447.5 22.6, 355290.9 6689441.9 22.6, 355285.9 6689440.9 22.6, 355285.2 6689446.6 22.6, 355290.2 6689447.5 22.6))
BATIMENT0000000302931267;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;20;30;19.5;9.4;29.0;31.9;14.2;Cadastre;C 0.6;POLYGON Z ((355204.9 6689453.8 29, 355220 6689456.6 29, 355219.9 6689435.5 29, 355204.8 6689435.2 29, 355204.9 6689453.8 29))
BATIMENT0000000302931220;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;5.0;;;17.3;9.3;26.6;30.1;10.2;Cadastre;A 1.0;POLYGON Z ((355152.7 6689362.5 26.6, 355147.1 6689374.6 26.6, 355152.1 6689379.9 26.6, 355152.2 6689379.8 26.6, 355160.7 6689388.8 26.6, 355160.7 6689389.1 26.6, 355165.9 6689394.4 26.6, 355167.1 6689393.3 26.6, 355173.4 6689378.2 26.6, 355167.3 6689375.6 26.6, 355169.7 6689369.8 26.6, 355152.7 6689362.5 26.6))
BATIMENT0000000302930831;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;;;18.5;13.6;32.2;35.6;15.2;Cadastre;A 1.0;POLYGON Z ((355127.8 6689389.5 32.2, 355115.2 6689364.4 32.2, 355114.3 6689364.1 32.2, 355096.3 6689382.8 32.2, 355097.8 6689384.3 32.2, 355100.9 6689387.5 32.2, 355107.9 6689380.3 32.2, 355110.2 6689384.9 32.2, 355108.8 6689385.7 32.2, 355108.4 6689386.6 32.2, 355110.4 6689390.5 32.2, 355111.1 6689390.9 32.2, 355111.5 6689390.7 32.2, 355112.1 6689391.6 32.2, 355113.3 6689391 32.2, 355116.4 6689397 32.2, 355116.5 6689397.1 32.2, 355117.3 6689396.6 32.2, 355126.1 6689390.6 32.2, 355127.8 6689389.5 32.2))
BATIMENT0000000302931222;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.5;11.1;21.6;;;Cadastre;;POLYGON Z ((355170.8 6689392.5 21.6, 355172.3 6689393.1 21.6, 355175.9 6689384.8 21.6, 355176.9 6689382.5 21.6, 355175.4 6689381.9 21.6, 355174.5 6689384.2 21.6, 355170.8 6689392.5 21.6))
BATIMENT0000000302931001;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;;;23.9;9.5;33.5;37.1;15.0;Cadastre;C 0.4;POLYGON Z ((355133.3 6689377.9 33.5, 355139.4 6689389.4 33.5, 355139.1 6689389.5 33.5, 355142.1 6689395 33.5, 355142.3 6689395 33.5, 355152.1 6689409.1 33.5, 355162.3 6689398.9 33.5, 355153.9 6689389.7 33.5, 355153.9 6689389.5 33.5, 355150 6689385.3 33.5, 355149.9 6689385.4 33.5, 355142.9 6689377.9 33.5, 355139 6689371 33.5, 355130.5 6689375.5 33.5, 355133.3 6689377.9 33.5))
BATIMENT0000000302931219;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1805-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;;;9.9;11.1;21.0;;;Cadastre;A 1.0;POLYGON Z ((355165.9 6689394.4 21, 355173.9 6689403.1 21, 355175.7 6689402.9 21, 355184.4 6689382.9 21, 355173.4 6689378.2 21, 355167.1 6689393.3 21, 355165.9 6689394.4 21), (355175.4 6689381.9 21, 355176.9 6689382.5 21, 355175.9 6689384.8 21, 355172.3 6689393.1 21, 355170.8 6689392.5 21, 355174.5 6689384.2 21, 355175.4 6689381.9 21))
BATIMENT0000000302931002;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;19.2;10.0;29.2;33.8;15.5;Cadastre;C 0.9;POLYGON Z ((355161 6689417.5 29.2, 355171.4 6689408.7 29.2, 355162.3 6689398.9 29.2, 355152.1 6689409.1 29.2, 355161 6689417.5 29.2))
BATIMENT0000000302931003;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1974-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;13.8;10.6;24.5;28.0;15.8;Cadastre;A 1.0;POLYGON Z ((355167 6689423 24.5, 355172.7 6689410 24.5, 355171.4 6689408.7 24.5, 355161 6689417.5 24.5, 355167 6689423 24.5))
BATIMENT0000000302931214;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;;;13.0;9.7;22.7;36.2;16.2;Cadastre;A 1.0;POLYGON Z ((355166.6 6689446.9 22.7, 355195.8 6689452.2 22.7, 355195.8 6689435.3 22.7, 355177.7 6689415.6 22.7, 355176.9 6689415.3 22.7, 355169.4 6689432.6 22.7, 355166.6 6689446.9 22.7), (355181.3 6689430 22.7, 355183.2 6689430.8 22.7, 355181.6 6689434.6 22.7, 355183 6689437.4 22.7, 355187.5 6689438.2 22.7, 355187.1 6689440.2 22.7, 355177.6 6689438.5 22.7, 355181.3 6689430 22.7))
BATIMENT0000000029192227;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:45:40;;;;;BDTopo;2.5;BDTopo;1.5;;;;;3.4;15.6;;23.5;16.2;Imagerie aérienne;;POLYGON Z ((355156.3 6689442.9 18.9, 355158.9 6689442.5 18.9, 355160.9 6689441 18.9, 355161.8 6689438.5 18.9, 355161.3 6689435.9 18.7, 355159.5 6689434.1 18.6, 355158.4 6689431.9 17.8, 355154 6689432.3 17.8, 355153.7 6689435 18.6, 355152.4 6689437.1 18.8, 355152.5 6689439.8 19, 355154.1 6689442.1 18.9, 355156.3 6689442.9 18.9))
BATIMENT0000000302930889;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;22.2;16.5;38.7;42.2;17.4;Cadastre;A 1.0;POLYGON Z ((355139.5 6689495.3 38.7, 355139.7 6689494.9 38.7, 355141 6689490.9 38.7, 355146.1 6689489.1 38.7, 355147 6689489.8 38.7, 355157.2 6689488.6 38.7, 355155.5 6689471.1 38.7, 355140.3 6689468.3 38.7, 355131.8 6689492.9 38.7, 355139.5 6689495.3 38.7), (355144.2 6689477.9 38.7, 355145.6 6689478.9 38.7, 355145.7 6689482.1 38.7, 355143.8 6689484.1 38.7, 355141.9 6689484 38.7, 355142 6689483.6 38.7, 355141.8 6689483.1 38.7, 355141 6689482.6 38.7, 355139.3 6689482.1 38.7, 355140.4 6689478.8 38.7, 355144.2 6689477.9 38.7))
BATIMENT0000000302931852;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.5;10.1;25.6;;;Cadastre;;POLYGON Z ((355230.4 6689429.8 25.6, 355230.5 6689434 25.6, 355229 6689434.1 25.6, 355229 6689435.1 25.6, 355230.4 6689435.1 25.6, 355230.5 6689439.2 25.6, 355229.2 6689439.2 25.6, 355229.2 6689440.2 25.6, 355230.5 6689440.3 25.6, 355230.6 6689442.5 25.6, 355231.2 6689442.4 25.6, 355231.2 6689444.5 25.6, 355230.5 6689444.5 25.6, 355230.4 6689445.1 25.6, 355229.7 6689445 25.6, 355229.8 6689445.9 25.6, 355230.3 6689445.9 25.6, 355230.1 6689448.2 25.6, 355229.4 6689448.2 25.6, 355229.4 6689449.2 25.6, 355230.2 6689449.1 25.6, 355231.3 6689450.5 25.6, 355230.9 6689451.3 25.6, 355231.5 6689451.7 25.6, 355232 6689451.2 25.6, 355234.2 6689451.7 25.6, 355233.6 6689452.3 25.6, 355234.6 6689453.1 25.6, 355235.1 6689452.6 25.6, 355235.8 6689454.4 25.6, 355235.2 6689455.2 25.6, 355235.9 6689455.8 25.6, 355236.5 6689455.3 25.6, 355238 6689456.2 25.6, 355238 6689457 25.6, 355238.9 6689457.1 25.6, 355238.9 6689456.5 25.6, 355240.4 6689455.9 25.6, 355241.4 6689457 25.6, 355240.9 6689456.9 25.6, 355240.9 6689457.9 25.6, 355241.7 6689458 25.6, 355241.8 6689460 25.6, 355241 6689460.1 25.6, 355241.1 6689460.8 25.6, 355241.9 6689460.8 25.6, 355242 6689462.9 25.6, 355241.1 6689463.5 25.6, 355241.8 6689464.2 25.6, 355242.5 6689463.8 25.6, 355243.6 6689465 25.6, 355243.4 6689466.1 25.6, 355244.3 6689466.3 25.6, 355244.6 6689465.5 25.6, 355246.5 6689465.4 25.6, 355246.8 6689466.2 25.6, 355247.7 6689465.8 25.6, 355247.4 6689465.2 25.6, 355248.7 6689463.9 25.6, 355249.6 6689464.2 25.6, 355250 6689463.5 25.6, 355249.2 6689463.2 25.6, 355249.2 6689460.7 25.6, 355249.9 6689460.7 25.6, 355249.9 6689459.8 25.6, 355249.2 6689459.7 25.6, 355249.2 6689457.7 25.6, 355249.7 6689457.6 25.6, 355249.9 6689456.8 25.6, 355249.4 6689456.7 25.6, 355249.9 6689455.4 25.6, 355252.2 6689456.1 25.6, 355252.2 6689456.8 25.6, 355253.1 6689456.7 25.6, 355253.1 6689455.7 25.6, 355254.3 6689454.7 25.6, 355255.1 6689455.2 25.6, 355255.5 6689454.3 25.6, 355254.9 6689454 25.6, 355255.5 6689452 25.6, 355256.1 6689452.4 25.6, 355256.8 6689451.7 25.6, 355256.4 6689451.3 25.6, 355258.4 6689450.3 25.6, 355258.9 6689451 25.6, 355259.7 6689450.4 25.6, 355259.2 6689449.6 25.6, 355260.1 6689448.1 25.6, 355261.1 6689448.1 25.6, 355261.1 6689447 25.6, 355260.1 6689447 25.6, 355260 6689444.9 25.6, 355260.6 6689445 25.6, 355260.6 6689444.1 25.6, 355259.7 6689444.1 25.6, 355259.6 6689439.6 25.6, 355260.9 6689439.5 25.6, 355260.8 6689438.5 25.6, 355259.5 6689438.5 25.6, 355259.5 6689434.5 25.6, 355260.7 6689434.5 25.6, 355260.7 6689433.6 25.6, 355259.4 6689433.6 25.6, 355259.4 6689429.4 25.6, 355261.3 6689429.4 25.6, 355261.2 6689428.4 25.6, 355249.6 6689428.7 25.6, 355249.2 6689442.9 25.6, 355247.3 6689444.4 25.6, 355245.4 6689444.8 25.6, 355243.7 6689444.8 25.6, 355241.6 6689444.5 25.6, 355239.7 6689442.6 25.6, 355239.4 6689428.9 25.6, 355228.5 6689429.1 25.6, 355228.5 6689429.9 25.6, 355230.4 6689429.8 25.6))
BATIMENT0000000302931855;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;00;00;12.7;9.5;22.2;34.0;11.1;Cadastre;C 0.1;POLYGON Z ((355291.3 6689455.5 22.2, 355292.8 6689447.9 22.2, 355290.2 6689447.5 22.2, 355285.2 6689446.6 22.2, 355285.9 6689440.9 22.2, 355284.3 6689440.7 22.2, 355283.9 6689446.6 22.2, 355281.4 6689446.4 22.2, 355280.8 6689454.4 22.2, 355291.3 6689455.5 22.2))
BATIMENT0000000302931856;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;12;10;26.9;8.8;35.7;38.4;11.4;Cadastre;C 0.4;POLYGON Z ((355297 6689469 35.7, 355299.8 6689449.2 35.7, 355292.8 6689447.9 35.7, 355291.3 6689455.5 35.7, 355280.8 6689454.4 35.7, 355281.4 6689446.4 35.7, 355283.9 6689446.6 35.7, 355284.3 6689440.7 35.7, 355270.9 6689438.3 35.7, 355271.2 6689464.7 35.7, 355297 6689469 35.7))
BATIMENT0000000302931706;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;9.5;17.4;21.7;12.8;Cadastre;;POLYGON Z ((355211 6689483.4 17.4, 355211.1 6689489.8 17.4, 355213.4 6689489.9 17.4, 355213.4 6689480.8 17.4, 355211 6689483.4 17.4))
BATIMENT0000000302930628;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;13.0;11.6;24.6;33.7;13.0;Cadastre;A 1.0;POLYGON Z ((355249.6 6689477.9 24.6, 355250 6689499 24.6, 355254.7 6689500.2 24.6, 355256.7 6689496.1 24.6, 355254.5 6689495.2 24.6, 355260.5 6689487.6 24.6, 355253.3 6689481.4 24.6, 355253.2 6689477.8 24.6, 355249.6 6689477.9 24.6))
BATIMENT0000000302930629;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;7.0;10;20;19.8;10.0;29.8;34.4;13.6;Cadastre;A 0.9;POLYGON Z ((355253.3 6689481.4 29.8, 355260.5 6689487.6 29.8, 355254.5 6689495.2 29.8, 355256.7 6689496.1 29.8, 355254.7 6689500.2 29.8, 355250 6689499 29.8, 355250.2 6689506.8 29.8, 355250.2 6689510.9 29.8, 355255.3 6689513.3 29.8, 355255.6 6689512.7 29.8, 355257.1 6689513.5 29.8, 355256 6689515.5 29.8, 355255.8 6689516 29.8, 355269.8 6689523.4 29.8, 355272.2 6689519.2 29.8, 355274 6689516.1 29.8, 355272.5 6689515.1 29.8, 355289.4 6689490.8 29.8, 355289.8 6689490.9 29.8, 355295.2 6689483.8 29.8, 355295 6689482.9 29.8, 355273.2 6689479.3 29.8, 355263.6 6689477.8 29.8, 355253.2 6689477.8 29.8, 355253.3 6689481.4 29.8), (355260 6689508.3 29.8, 355262.6 6689509.8 29.8, 355261.9 6689511 29.8, 355259.2 6689509.6 29.8, 355259.5 6689509 29.8, 355260 6689508.3 29.8))
BATIMENT0000000302931694;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;24.3;10.1;34.5;37.5;18.4;Cadastre;A 1.0;POLYGON Z ((355169 6689499.5 34.5, 355170.2 6689511.8 34.5, 355171.6 6689511.7 34.5, 355180.7 6689510.7 34.5, 355184.1 6689510.2 34.5, 355183.9 6689508.6 34.5, 355183.8 6689507.9 34.5, 355186.6 6689507.6 34.5, 355186.8 6689510 34.5, 355187.3 6689509.9 34.5, 355196.3 6689508.8 34.5, 355196.2 6689496 34.5, 355169 6689499.5 34.5), (355181.8 6689499.7 34.5, 355182.8 6689500.3 34.5, 355185.1 6689500 34.5, 355186.5 6689499.8 34.5, 355186.8 6689502.9 34.5, 355182.2 6689503.4 34.5, 355181.8 6689499.7 34.5))
BATIMENT0000000302931707;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.8;10.5;24.4;29.5;15.6;Cadastre;C 0.2;POLYGON Z ((355230.3 6689478.3 24.4, 355225.1 6689478.3 24.4, 355225 6689479 24.4, 355221.1 6689479 24.4, 355221.1 6689478.2 24.4, 355215.6 6689478.3 24.4, 355213.4 6689480.8 24.4, 355213.4 6689489.9 24.4, 355211.1 6689489.8 24.4, 355210.4 6689489.9 24.4, 355210.4 6689491.4 24.4, 355210.7 6689491.4 24.4, 355210.7 6689493.1 24.4, 355210.4 6689493.1 24.4, 355210.4 6689494.8 24.4, 355210.7 6689494.7 24.4, 355210.7 6689495.5 24.4, 355211.2 6689495.4 24.4, 355211.4 6689499.7 24.4, 355210.8 6689499.7 24.4, 355210.8 6689501.1 24.4, 355211.3 6689501.1 24.4, 355211.4 6689505.3 24.4, 355210.9 6689505.2 24.4, 355210.9 6689506.6 24.4, 355211.4 6689506.6 24.4, 355211.4 6689511 24.4, 355211 6689511 24.4, 355210.9 6689512.4 24.4, 355211.4 6689512.5 24.4, 355211.6 6689517.1 24.4, 355211.1 6689517.1 24.4, 355211.2 6689518.1 24.4, 355211.6 6689518 24.4, 355211.7 6689522.5 24.4, 355211.2 6689522.5 24.4, 355211.3 6689523.6 24.4, 355211.7 6689523.6 24.4, 355211.8 6689528.3 24.4, 355211.4 6689528.3 24.4, 355211.4 6689529.3 24.4, 355211.8 6689529.4 24.4, 355212 6689533.8 24.4, 355211.5 6689533.8 24.4, 355211.6 6689535 24.4, 355211.9 6689534.9 24.4, 355212 6689539.2 24.4, 355211.7 6689539.3 24.4, 355211.7 6689540.6 24.4, 355212 6689540.6 24.4, 355212.2 6689545.2 24.4, 355211.7 6689545.2 24.4, 355211.8 6689545.7 24.4, 355211.4 6689545.7 24.4, 355211.5 6689547.2 24.4, 355211.8 6689547.2 24.4, 355211.8 6689548.9 24.4, 355211.4 6689548.9 24.4, 355211.5 6689550 24.4, 355215.1 6689550 24.4, 355220.2 6689549.8 24.4, 355220.3 6689550.5 24.4, 355227.6 6689550.2 24.4, 355227.6 6689549.5 24.4, 355236.4 6689549.4 24.4, 355236.5 6689549.3 24.4, 355236.5 6689545.4 24.4, 355236.2 6689545.1 24.4, 355235.9 6689521.9 24.4, 355235.7 6689522 24.4, 355235.5 6689517.5 24.4, 355235.9 6689517.5 24.4, 355235.6 6689494.1 24.4, 355235.9 6689494 24.4, 355235.8 6689489.6 24.4, 355235 6689489.6 24.4, 355235 6689483.3 24.4, 355231.1 6689478.9 24.4, 355230.3 6689478.3 24.4))
BATIMENT0000000302930631;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;15.5;12.3;27.9;31.7;14.1;Cadastre;A 1.0;POLYGON Z ((355250.4 6689520.7 27.9, 355267 6689528.5 27.9, 355269.8 6689523.4 27.9, 355255.8 6689516 27.9, 355256 6689515.5 27.9, 355250.3 6689512.7 27.9, 355250.4 6689517.8 27.9, 355250.4 6689520.7 27.9))
BATIMENT0000000302930632;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;16.2;12.9;29.2;31.5;14.5;Cadastre;A 1.0;POLYGON Z ((355250.6 6689527.5 29.2, 355264 6689533.9 29.2, 355267 6689528.5 29.2, 355250.4 6689520.7 29.2, 355250.6 6689527.5 29.2))
BATIMENT0000000302931828;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;13;30;13.4;19.2;32.7;43.0;20.3;Cadastre;C 0.5;POLYGON Z ((355046.2 6689487.2 32.7, 355057.7 6689478.9 32.7, 355059.9 6689466.4 32.7, 355053.3 6689465.4 32.7, 355054.1 6689461.6 32.7, 355045.3 6689460.7 32.7, 355041.5 6689465.5 32.7, 355038.4 6689467.6 32.7, 355038.8 6689468.7 32.7, 355035 6689471.2 32.7, 355046.2 6689487.2 32.7))
BATIMENT0000000302931831;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;23.5;16.7;40.2;42.2;18.3;Cadastre;;POLYGON Z ((355091.2 6689469.9 40.2, 355092.2 6689471.3 40.2, 355094.8 6689471.5 40.2, 355095.7 6689470.5 40.2, 355111.8 6689473.7 40.2, 355110.6 6689479.9 40.2, 355108.6 6689483.9 40.2, 355109.9 6689484.6 40.2, 355109.3 6689485.9 40.2, 355110.1 6689486.5 40.2, 355109.2 6689488.3 40.2, 355109.3 6689489.3 40.2, 355111.6 6689490.8 40.2, 355114.3 6689490.6 40.2, 355114.8 6689488.3 40.2, 355120.1 6689489.7 40.2, 355122.5 6689483 40.2, 355123 6689481.5 40.2, 355123.8 6689477.9 40.2, 355125.7 6689467.8 40.2, 355126.1 6689465.6 40.2, 355084.2 6689458.2 40.2, 355082.5 6689468.1 40.2, 355082.6 6689468.1 40.2, 355091.2 6689469.9 40.2))
BATIMENT0000000302931830;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;;;6.9;16.3;23.3;36.2;19.5;Cadastre;C 0.1;POLYGON Z ((355070.1 6689496.8 23.3, 355070.7 6689497.7 23.3, 355078.2 6689492.5 23.3, 355082 6689470.4 23.3, 355059.9 6689466.4 23.3, 355057.7 6689478.9 23.3, 355070.1 6689496.8 23.3))
BATIMENT0000000302931832;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;12;30;10.0;15.9;25.9;36.8;17.8;Cadastre;C 0.5;POLYGON Z ((355114.8 6689504.7 25.9, 355120.1 6689489.7 25.9, 355114.8 6689488.3 25.9, 355114.3 6689490.6 25.9, 355111.6 6689490.8 25.9, 355109.3 6689489.3 25.9, 355109.2 6689488.3 25.9, 355110.1 6689486.5 25.9, 355109.3 6689485.9 25.9, 355109.9 6689484.6 25.9, 355108.6 6689483.9 25.9, 355110.6 6689479.9 25.9, 355111.8 6689473.7 25.9, 355095.7 6689470.5 25.9, 355094.8 6689471.5 25.9, 355092.2 6689471.3 25.9, 355091.2 6689469.9 25.9, 355082.6 6689468.1 25.9, 355082.5 6689468.1 25.9, 355082 6689470.4 25.9, 355078.2 6689492.5 25.9, 355114.8 6689504.7 25.9))
BATIMENT0000000302930641;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;20;30;8.7;17.1;25.8;38.0;20.0;Cadastre;A 1.0;POLYGON Z ((355058.6 6689505.1 25.8, 355066.7 6689499.2 25.8, 355070.1 6689496.8 25.8, 355057.7 6689478.9 25.8, 355046.2 6689487.2 25.8, 355058.6 6689505.1 25.8))
BATIMENT0000000302930642;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;5.0;10;30;19.4;16.8;36.2;37.7;19.8;Cadastre;A 1.0;POLYGON Z ((355073 6689525.5 36.2, 355081 6689519.8 36.2, 355066.7 6689499.2 36.2, 355058.6 6689505.1 36.2, 355073 6689525.5 36.2))
BATIMENT0000000302930202;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;30;30;16.1;20.7;36.8;;;Cadastre;B 0.6;POLYGON Z ((355041.9 6689502.7 36.8, 355029.7 6689511.2 36.8, 355033 6689516.1 36.8, 355036.6 6689513.6 36.8, 355038.6 6689516.4 36.8, 355037.6 6689517.1 36.8, 355038 6689517.8 36.8, 355037.8 6689517.9 36.8, 355039.5 6689520.3 36.8, 355039.7 6689520.1 36.8, 355041.8 6689523.2 36.8, 355042.8 6689522.5 36.8, 355044.6 6689525.2 36.8, 355053.4 6689519 36.8, 355041.9 6689502.7 36.8))
BATIMENT0000000302930643;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1700-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;17.1;15.9;33.1;35.7;17.6;Cadastre;A 1.0;POLYGON Z ((355095.4 6689503 33.1, 355084.9 6689521.1 33.1, 355096.2 6689527.8 33.1, 355098.5 6689524 33.1, 355097.8 6689523.5 33.1, 355100 6689519.7 33.1, 355102.8 6689521.3 33.1, 355106.4 6689515.5 33.1, 355113.8 6689520.4 33.1, 355119.9 6689511.3 33.1, 355110.9 6689508.1 33.1, 355103.2 6689505.5 33.1, 355095.4 6689503 33.1))
BATIMENT0000000302931833;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;16.0;24.2;33.9;18.2;Cadastre;;POLYGON Z ((355096.3 6689536.9 24.2, 355100.4 6689533.8 24.2, 355096.2 6689527.8 24.2, 355084.9 6689521.1 24.2, 355096.3 6689536.9 24.2))
BATIMENT0000000302930203;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.4;19.0;22.5;36.0;19.8;Cadastre;C 0.2;POLYGON Z ((355038 6689529.7 22.5, 355033.3 6689533 22.5, 355037 6689535.7 22.5, 355038.7 6689536.9 22.5, 355045.7 6689532 22.5, 355044.9 6689530.8 22.5, 355047.2 6689529.1 22.5, 355044.6 6689525.2 22.5, 355038 6689529.7 22.5))
BATIMENT0000000302931692;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;22.7;11.3;34.0;37.9;17.9;Cadastre;C 0.7;POLYGON Z ((355166.3 6689473.1 34, 355166.6 6689473.2 34, 355168.5 6689493.5 34, 355168.3 6689493.6 34, 355169 6689499.5 34, 355196.2 6689496 34, 355196 6689486.2 34, 355196.2 6689486 34, 355196 6689478.9 34, 355195.8 6689468.9 34, 355190.1 6689467.9 34, 355190.1 6689468.1 34, 355174.7 6689465.5 34, 355174.7 6689465.3 34, 355168.8 6689464.3 34, 355165.7 6689467.3 34, 355166.3 6689473.1 34), (355185.5 6689477.4 34, 355186.8 6689490.7 34, 355179.5 6689491.3 34, 355178.5 6689477.9 34, 355185.5 6689477.4 34))
BATIMENT0000000302931693;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;15.1;24.0;30.2;17.5;Cadastre;;POLYGON Z ((355179.5 6689491.3 24, 355186.8 6689490.7 24, 355185.5 6689477.4 24, 355178.5 6689477.9 24, 355179.5 6689491.3 24))
BATIMENT0000000302930890;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;20;20;22.7;17.2;40.0;43.0;18.2;Cadastre;A 1.0;POLYGON Z ((355157.2 6689488.6 40, 355147 6689489.8 40, 355146.6 6689491 40, 355145.3 6689491.3 40, 355146 6689497.7 40, 355145.5 6689499.2 40, 355144.5 6689499.3 40, 355143.6 6689499.1 40, 355142.3 6689499.5 40, 355141.6 6689499.1 40, 355141.7 6689501 40, 355140.4 6689501.1 40, 355140.7 6689503.5 40, 355158.3 6689501.1 40, 355157.2 6689488.6 40))
BATIMENT0000000302930891;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;22.1;17.1;39.2;41.9;18.1;Cadastre;A 1.0;POLYGON Z ((355128.1 6689503.2 39.2, 355129.3 6689505 39.2, 355137 6689504 39.2, 355140.7 6689503.5 39.2, 355140.4 6689501.1 39.2, 355141.7 6689501 39.2, 355141.6 6689499.1 39.2, 355139.8 6689499.2 39.2, 355139.8 6689499.5 39.2, 355138.1 6689499.6 39.2, 355139.5 6689495.3 39.2, 355131.8 6689492.9 39.2, 355128.1 6689503.2 39.2))
BATIMENT0000000302930892;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1859-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;21.4;17.8;39.2;42.0;18.6;Cadastre;A 1.0;POLYGON Z ((355158.3 6689501.1 39.2, 355140.7 6689503.5 39.2, 355137 6689504 39.2, 355139.6 6689508.1 39.2, 355142.3 6689507.7 39.2, 355145.5 6689507.4 39.2, 355147 6689506.4 39.2, 355148 6689507.5 39.2, 355147.7 6689507.7 39.2, 355147.6 6689507.8 39.2, 355147.5 6689507.9 39.2, 355147.4 6689508 39.2, 355147.2 6689508.2 39.2, 355147 6689508.4 39.2, 355147 6689508.6 39.2, 355146.9 6689508.7 39.2, 355146.8 6689509 39.2, 355146.8 6689509.3 39.2, 355146.8 6689509.5 39.2, 355146.8 6689509.8 39.2, 355146.9 6689510.3 39.2, 355147 6689510.6 39.2, 355147 6689510.8 39.2, 355146.4 6689511.8 39.2, 355147.6 6689512.9 39.2, 355148.5 6689512.8 39.2, 355149.1 6689516.9 39.2, 355150.1 6689517.7 39.2, 355159.9 6689516.4 39.2, 355158.3 6689501.1 39.2))
BATIMENT0000000302931695;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.8;16.3;37.2;37.7;18.4;Cadastre;;POLYGON Z ((355170.3 6689512.4 37.2, 355171.7 6689512.3 37.2, 355171.6 6689511.7 37.2, 355170.2 6689511.8 37.2, 355170.3 6689512.4 37.2))
BATIMENT0000000302930893;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;20;20;21.6;17.6;39.2;41.8;18.7;Cadastre;A 1.0;POLYGON Z ((355142.9 6689526.6 39.2, 355148.9 6689522.1 39.2, 355142.3 6689512.1 39.2, 355142.8 6689511.7 39.2, 355142.8 6689511.6 39.2, 355142.9 6689511.5 39.2, 355142.9 6689511.4 39.2, 355142.9 6689511.3 39.2, 355143 6689511.2 39.2, 355143 6689510.9 39.2, 355142.9 6689510.8 39.2, 355142.9 6689510.6 39.2, 355142.8 6689510.4 39.2, 355142.7 6689510.2 39.2, 355142.6 6689510.1 39.2, 355142.5 6689509.9 39.2, 355142.3 6689509.8 39.2, 355142.2 6689509.8 39.2, 355142.1 6689509.8 39.2, 355141.9 6689509.7 39.2, 355141.8 6689509.7 39.2, 355141.6 6689509.7 39.2, 355141.5 6689509.8 39.2, 355141.3 6689509.8 39.2, 355141.2 6689509.8 39.2, 355141.1 6689509.9 39.2, 355140.9 6689510.1 39.2, 355139.6 6689508.1 39.2, 355137 6689504 39.2, 355129.3 6689505 39.2, 355142.9 6689526.6 39.2))
BATIMENT0000000302930652;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.6;18.0;26.6;28.4;18.2;Cadastre;;POLYGON Z ((355124.4 6689512.8 26.6, 355123.2 6689512.4 26.6, 355116.8 6689522.5 26.6, 355118.5 6689523.6 26.6, 355118.7 6689523.4 26.6, 355125.7 6689527.9 26.6, 355131.1 6689522.8 26.6, 355124.4 6689512.8 26.6))
BATIMENT0000000302930894;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;20;20;20.3;17.0;37.3;42.4;19.4;Cadastre;A 1.0;POLYGON Z ((355152 6689540.7 37.3, 355162.1 6689539.3 37.3, 355159.9 6689516.4 37.3, 355150.1 6689517.7 37.3, 355150.6 6689521.5 37.3, 355152 6689522.8 37.3, 355151.4 6689523.6 37.3, 355149.9 6689523.5 37.3, 355148.9 6689522.1 37.3, 355142.9 6689526.6 37.3, 355152 6689540.7 37.3))
BATIMENT0000000302930651;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;00;00;12.0;17.3;29.4;37.7;18.4;Cadastre;A 1.0;POLYGON Z ((355131.2 6689522.7 29.4, 355131.1 6689522.8 29.4, 355125.7 6689527.9 29.4, 355119.4 6689533.8 29.4, 355124.4 6689536.9 29.4, 355125.3 6689537.4 29.4, 355134.8 6689527.9 29.4, 355131.2 6689522.7 29.4))
BATIMENT0000000302931834;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.4;16.6;36.0;37.3;20.2;Cadastre;;POLYGON Z ((355086.4 6689544.8 36, 355094.2 6689538.6 36, 355096.3 6689536.9 36, 355084.9 6689521.1 36, 355082.1 6689519 36, 355081 6689519.8 36, 355073 6689525.5 36, 355086.4 6689544.8 36))
BATIMENT0000000302930204;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;30;30;15.9;20.6;36.5;;;Cadastre;A 1.0;POLYGON Z ((355051.6 6689535.2 36.5, 355050.4 6689536.1 36.5, 355053.3 6689540.3 36.5, 355054.5 6689539.5 36.5, 355061.4 6689549.4 36.5, 355070.3 6689543 36.5, 355053.4 6689519 36.5, 355044.6 6689525.2 36.5, 355047.2 6689529.1 36.5, 355051.6 6689535.2 36.5))
BATIMENT0000000302930645;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;00;00;18.9;17.5;36.4;37.3;20.5;Cadastre;A 1.0;POLYGON Z ((355096.5 6689556 36.4, 355103.8 6689549.4 36.4, 355094.2 6689538.6 36.4, 355086.4 6689544.8 36.4, 355096.5 6689556 36.4))
BATIMENT0000000302930205;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;30;30;15.8;20.6;36.4;;;Cadastre;C 1.0;POLYGON Z ((355070.3 6689543 36.4, 355061.4 6689549.4 36.4, 355060.6 6689550 36.4, 355064.7 6689556 36.4, 355065.7 6689555.4 36.4, 355067.5 6689557.9 36.4, 355068.5 6689557.3 36.4, 355076.2 6689551.6 36.4, 355070.3 6689543 36.4))
BATIMENT0000000302930206;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.9;21.0;22.9;;;Cadastre;C 0.3;POLYGON Z ((355034.8 6689549 22.9, 355044 6689559.1 22.9, 355044.3 6689559.2 22.9, 355049.2 6689555.8 22.9, 355038.4 6689543.7 22.9, 355034.8 6689549 22.9))
BATIMENT0000000302930217;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.6;21.0;22.6;;;Cadastre;C 0.5;POLYGON Z ((355044.3 6689559.2 22.6, 355049.8 6689562.5 22.6, 355059.9 6689555.5 22.6, 355057.6 6689552.1 22.6, 355057.5 6689552.2 22.6, 355056.5 6689550.8 22.6, 355049.2 6689555.8 22.6, 355044.3 6689559.2 22.6))
BATIMENT0000000302930647;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;20.8;15.8;36.6;38.7;20.7;Cadastre;A 1.0;POLYGON Z ((355106.6 6689567.2 36.6, 355113.8 6689560.6 36.6, 355103.8 6689549.4 36.6, 355096.5 6689556 36.6, 355106.6 6689567.2 36.6))
BATIMENT0000000302930207;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;00;00;15.4;21.1;36.5;;;Cadastre;C 0.7;POLYGON Z ((355079.2 6689555.8 36.5, 355076.2 6689551.6 36.5, 355068.5 6689557.3 36.5, 355079.4 6689569.5 36.5, 355086.1 6689563.3 36.5, 355079.2 6689555.8 36.5))
BATIMENT0000000302931874;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;19.9;24.4;25.2;21.8;Cadastre;;POLYGON Z ((355041.1 6689569.6 24.4, 355043.1 6689568.4 24.4, 355054.6 6689580.6 24.4, 355059.7 6689572 24.4, 355055.3 6689567 24.4, 355049.8 6689562.5 24.4, 355044.3 6689559.2 24.4, 355044 6689559.1 24.4, 355034.8 6689549 24.4, 355034.1 6689550 24.4, 355029.6 6689556.9 24.4, 355041.1 6689569.6 24.4))
BATIMENT0000000302930213;Indifférenciée;Sportif;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;1.5;21.6;23.1;;;Cadastre;C 0.4;POLYGON Z ((355059.7 6689572 23.1, 355063.3 6689576.2 23.1, 355072.2 6689568.7 23.1, 355068.7 6689564.2 23.1, 355059.7 6689572 23.1))
BATIMENT0000000302931840;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;30;20;11.1;10.4;21.5;26.9;13.2;Cadastre;C 0.5;POLYGON Z ((355189.4 6689530.2 21.5, 355191 6689544.7 21.5, 355197.3 6689546.8 21.5, 355196.3 6689508.8 21.5, 355187.3 6689509.9 21.5, 355188.6 6689521.8 21.5, 355189.4 6689530.2 21.5))
BATIMENT0000000302931841;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;30;20;26.9;10.9;37.8;41.0;19.7;Cadastre;C 0.7;POLYGON Z ((355175.3 6689547.3 37.8, 355179 6689551.8 37.8, 355198.4 6689556.1 37.8, 355197.3 6689546.8 37.8, 355191 6689544.7 37.8, 355185.4 6689543.6 37.8, 355184.8 6689539.3 37.8, 355183.7 6689539.4 37.8, 355183 6689531.1 37.8, 355189.4 6689530.2 37.8, 355188.6 6689521.8 37.8, 355182.9 6689522.4 37.8, 355182.6 6689519.1 37.8, 355181.7 6689519.2 37.8, 355180.7 6689510.7 37.8, 355171.6 6689511.7 37.8, 355171.7 6689512.3 37.8, 355175.3 6689547.3 37.8))
BATIMENT0000000302930633;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;20;20;14.9;13.5;28.5;32.6;15.0;Cadastre;A 1.0;POLYGON Z ((355260.6 6689542.7 28.5, 355263.5 6689535.5 28.5, 355250.6 6689529.2 28.5, 355250.8 6689537.6 28.5, 355259.5 6689542.1 28.5, 355260.6 6689542.7 28.5))
BATIMENT0000000302930634;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1851-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;16.7;14.2;31.0;32.9;15.4;Cadastre;A 1.0;POLYGON Z ((355251 6689546.5 31, 355256.8 6689547.9 31, 355259.5 6689542.1 31, 355250.8 6689537.6 31, 355251 6689546.5 31))
BATIMENT0000000302930359;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;19.9;6.9;26.8;30.5;14.0;Cadastre;C 0.2;POLYGON Z ((355303.2 6689521 26.8, 355302.2 6689523 26.8, 355299.3 6689521.5 26.8, 355300.2 6689519.6 26.8, 355299.2 6689519.1 26.8, 355274.4 6689548.8 26.8, 355270.7 6689553.1 26.8, 355267.2 6689557.3 26.8, 355270.8 6689560.2 26.8, 355271.5 6689560.8 26.8, 355269.8 6689562.8 26.8, 355264.5 6689561.3 26.8, 355264 6689561.2 26.8, 355262.8 6689562.7 26.8, 355259.4 6689566.7 26.8, 355259.7 6689567 26.8, 355259.3 6689567.4 26.8, 355260.5 6689571.2 26.8, 355261.1 6689571.3 26.8, 355261 6689571.7 26.8, 355264.7 6689572.5 26.8, 355268.3 6689573.4 26.8, 355282.2 6689576.6 26.8, 355291.1 6689578.6 26.8, 355291.4 6689577.2 26.8, 355292 6689577.3 26.8, 355293.9 6689569 26.8, 355295.8 6689560.1 26.8, 355293.7 6689560.4 26.8, 355294.4 6689557.1 26.8, 355296 6689556.9 26.8, 355296.2 6689553.7 26.8, 355295.2 6689553.5 26.8, 355296.1 6689549.4 26.8, 355298 6689549.8 26.8, 355299.2 6689544.2 26.8, 355299.5 6689543.1 26.8, 355298.8 6689543 26.8, 355299.3 6689540.7 26.8, 355300 6689540.9 26.8, 355304.2 6689521.5 26.8, 355303.2 6689521 26.8))
BATIMENT0000000291501499;Monument;Indifférencié;;Non;En service;2011-11-16 11:33:40;2012-06-19 19:09:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.7;12.7;;;;Imagerie aérienne;;POLYGON Z ((355249.6 6689552.6 16.4, 355243.3 6689551.2 16.2, 355241 6689554.3 16.2, 355239.5 6689557.4 16.2, 355238.9 6689559.5 16.2, 355239.4 6689561.9 16.2, 355241 6689564.2 16.2, 355246.9 6689565.1 16.2, 355249.2 6689563.4 16.2, 355251.8 6689560.6 16.2, 355254.9 6689556.5 16.4, 355249.6 6689552.6 16.4))
BATIMENT0000000302931700;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;7.0;12;20;21.9;10.0;32.0;35.7;15.3;Cadastre;A 1.0;POLYGON Z ((355253.1 6689604.3 32, 355253.1 6689604.5 32, 355253.1 6689604.8 32, 355253.2 6689605.1 32, 355253.3 6689605.3 32, 355253.3 6689605.6 32, 355253.4 6689605.7 32, 355253.5 6689606 32, 355253.7 6689606.3 32, 355253.8 6689606.4 32, 355254 6689606.6 32, 355254.2 6689606.9 32, 355254.4 6689607.1 32, 355254.6 6689607.3 32, 355254.9 6689607.4 32, 355255.2 6689607.6 32, 355255.5 6689607.7 32, 355258.7 6689603.3 32, 355260.2 6689602.6 32, 355261.5 6689599.2 32, 355264.2 6689591.8 32, 355267.6 6689583.2 32, 355254.9 6689580 32, 355251.5 6689582.3 32, 355250.5 6689589.5 32, 355243.9 6689597.3 32, 355253.1 6689604.3 32))
BATIMENT0000002011295314;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:48:59;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;19.3;7.2;;32.6;14.3;Imagerie aérienne;C 0.3;POLYGON Z ((355291.2 6689588.6 26.4, 355273.3 6689584.6 26.4, 355271.3 6689596.1 26.4, 355274 6689596.6 26.4, 355270.8 6689610.5 22.1, 355272.2 6689610.6 22.1, 355270.8 6689617.9 26.5, 355272.3 6689619.1 26.5, 355285.2 6689621.6 26.5, 355291.2 6689588.6 26.4))
BATIMENT0000000302931698;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;23.1;9.7;32.9;34.5;15.2;Cadastre;A 1.0;POLYGON Z ((355244.7 6689621.8 32.9, 355250.4 6689614.4 32.9, 355255.2 6689607.6 32.9, 355254.9 6689607.4 32.9, 355254.6 6689607.3 32.9, 355254.4 6689607.1 32.9, 355254.2 6689606.9 32.9, 355254 6689606.6 32.9, 355253.8 6689606.4 32.9, 355253.7 6689606.3 32.9, 355253.5 6689606 32.9, 355253.4 6689605.7 32.9, 355253.3 6689605.6 32.9, 355253.3 6689605.3 32.9, 355253.2 6689605.1 32.9, 355253.1 6689604.8 32.9, 355253.1 6689604.5 32.9, 355253.1 6689604.3 32.9, 355243.9 6689597.3 32.9, 355233.6 6689609.2 32.9, 355244.7 6689621.8 32.9))
BATIMENT0000000302931696;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;19.1;9.3;28.4;31.6;10.4;Cadastre;C 0.6;POLYGON Z ((355249.5 6689626.2 28.4, 355256.4 6689616.4 28.4, 355257.9 6689614 28.4, 355255.9 6689612.8 28.4, 355253.1 6689616.2 28.4, 355250.4 6689614.4 28.4, 355244.7 6689621.8 28.4, 355249.5 6689626.2 28.4))
BATIMENT0000000302930650;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;11.1;16.5;27.6;28.8;17.9;Cadastre;A 1.0;POLYGON Z ((355110.5 6689536.6 27.6, 355115.8 6689539.6 27.6, 355119.4 6689533.8 27.6, 355125.7 6689527.9 27.6, 355118.7 6689523.4 27.6, 355118.5 6689523.6 27.6, 355110.5 6689536.6 27.6))
BATIMENT0000000302930653;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;12;16.4;18.4;34.8;39.9;19.5;Cadastre;A 1.0;POLYGON Z ((355134.8 6689527.9 34.8, 355125.3 6689537.4 34.8, 355124.4 6689536.9 34.8, 355123.1 6689538.4 34.8, 355132.6 6689551.9 34.8, 355134.3 6689550.2 34.8, 355136.3 6689553.2 34.8, 355136.5 6689553.1 34.8, 355136.7 6689553.3 34.8, 355146.9 6689545.4 34.8, 355134.8 6689527.9 34.8))
BATIMENT0000000302930648;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;16.0;19.2;25.0;17.8;Cadastre;A 1.0;POLYGON Z ((355107.6 6689541.3 19.2, 355119.8 6689555 19.2, 355123.7 6689551.5 19.2, 355115.8 6689539.6 19.2, 355110.5 6689536.6 19.2, 355107.6 6689541.3 19.2))
BATIMENT0000000302930649;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;18.4;25.6;31.7;20.1;Cadastre;;POLYGON Z ((355132.6 6689551.9 25.6, 355123.1 6689538.4 25.6, 355124.4 6689536.9 25.6, 355119.4 6689533.8 25.6, 355115.8 6689539.6 25.6, 355123.7 6689551.5 25.6, 355119.8 6689555 25.6, 355115.5 6689559 25.6, 355122.1 6689566.4 25.6, 355127.2 6689561.7 25.6, 355127.9 6689562.4 25.6, 355131.2 6689558.7 25.6, 355128.6 6689555.9 25.6, 355129 6689555.4 25.6, 355132.6 6689551.9 25.6))
BATIMENT0000000302930656;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;15.8;18.4;34.2;36.7;20.6;Cadastre;A 1.0;POLYGON Z ((355154.9 6689557.1 34.2, 355146.9 6689545.4 34.2, 355136.7 6689553.3 34.2, 355136.5 6689553.1 34.2, 355136.3 6689553.2 34.2, 355133.5 6689556.3 34.2, 355143.6 6689568 34.2, 355154.9 6689557.1 34.2))
BATIMENT0000000302930654;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;12;20;18.2;18.4;36.6;40.0;20.8;Cadastre;A 1.0;POLYGON Z ((355143.6 6689568 36.6, 355133.5 6689556.3 36.6, 355131.2 6689558.7 36.6, 355127.9 6689562.4 36.6, 355137.8 6689573.6 36.6, 355143.6 6689568 36.6))
BATIMENT0000000302931836;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;6.0;;;21.1;16.8;38.0;38.9;21.1;Cadastre;A 1.0;POLYGON Z ((355122.1 6689566.4 38, 355115.5 6689559 38, 355113.8 6689560.6 38, 355106.6 6689567.2 38, 355113.3 6689574.6 38, 355122.1 6689566.4 38))
BATIMENT0000000302930655;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;19.4;18.5;37.9;39.1;21.5;Cadastre;A 1.0;POLYGON Z ((355124.1 6689586.5 37.9, 355137.8 6689573.6 37.9, 355127.9 6689562.4 37.9, 355127.2 6689561.7 37.9, 355122.1 6689566.4 37.9, 355113.3 6689574.6 37.9, 355124.1 6689586.5 37.9))
BATIMENT0000000302930739;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;7.0;;;24.5;14.2;38.7;40.2;20.2;Cadastre;A 0.4;POLYGON Z ((355196.6 6689604.6 38.7, 355202.7 6689597.4 38.7, 355198.8 6689569.4 38.7, 355170.5 6689562.6 38.7, 355159.1 6689573.8 38.7, 355159.5 6689574.3 38.7, 355166.8 6689581.7 38.7, 355175 6689573.4 38.7, 355175.5 6689571.8 38.7, 355180.2 6689572.9 38.7, 355179.8 6689575.6 38.7, 355189.5 6689578.1 38.7, 355191.4 6689591 38.7, 355193.9 6689590.6 38.7, 355194.3 6689593.7 38.7, 355192.9 6689595.1 38.7, 355191.8 6689593.9 38.7, 355191.1 6689594.8 38.7, 355192 6689595.9 38.7, 355187.6 6689600.3 38.7, 355186.5 6689599.3 38.7, 355185.1 6689600.7 38.7, 355184.3 6689599.7 38.7, 355175.5 6689608.5 38.7, 355183.6 6689617.2 38.7, 355196.6 6689604.6 38.7))
BATIMENT0000000302930740;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;20.1;18.6;38.7;41.6;21.0;Cadastre;C 0.2;POLYGON Z ((355163.7 6689623.5 38.7, 355165.1 6689622.2 38.7, 355171 6689623.1 38.7, 355176 6689621.2 38.7, 355177.6 6689622.9 38.7, 355183.6 6689617.2 38.7, 355175.5 6689608.5 38.7, 355184.3 6689599.7 38.7, 355183.7 6689599 38.7, 355166.8 6689581.7 38.7, 355159.5 6689574.3 38.7, 355152.8 6689581 38.7, 355150.1 6689583.6 38.7, 355147.2 6689586.5 38.7, 355146.8 6689586.2 38.7, 355136.8 6689595.9 38.7, 355163.7 6689623.5 38.7))
BATIMENT0000000302930212;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;20;30;16.5;20.6;37.1;39.7;20.8;Cadastre;A 1.0;POLYGON Z ((355080.9 6689573 37.1, 355088.3 6689581.5 37.1, 355089 6689580.8 37.1, 355090.6 6689582.4 37.1, 355094.6 6689579.8 37.1, 355098.6 6689576.9 37.1, 355086.1 6689563.3 37.1, 355079.4 6689569.5 37.1, 355079.1 6689569.8 37.1, 355079.3 6689570.2 37.1, 355076.9 6689572.5 37.1, 355079 6689574.8 37.1, 355080.9 6689573 37.1))
BATIMENT0000000302931873;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.0;21.0;23.0;;;Cadastre;;POLYGON Z ((355074.1 6689593.6 23, 355086.1 6689582.6 23, 355079 6689574.8 23, 355076.9 6689572.5 23, 355072.8 6689568.1 23, 355072.2 6689568.7 23, 355063.3 6689576.2 23, 355062.3 6689580.9 23, 355074.1 6689593.6 23))
BATIMENT0000000302930218;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;17.3;20.6;37.9;40.5;22.0;Cadastre;A 1.0;POLYGON Z ((355114.8 6689594.6 37.9, 355101.5 6689580.1 37.9, 355094.3 6689585.1 37.9, 355108.7 6689600.6 37.9, 355114.8 6689594.6 37.9))
BATIMENT0000000302931871;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;20.1;25.1;26.8;22.2;Cadastre;;POLYGON Z ((355073 6689592.8 25.1, 355074.1 6689593.6 25.1, 355062.3 6689580.9 25.1, 355063.3 6689576.2 25.1, 355059.7 6689572 25.1, 355054.6 6689580.6 25.1, 355036.3 6689597.7 25.1, 355050.7 6689612.3 25.1, 355073 6689592.8 25.1))
BATIMENT0000000302930216;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;10;20;16.7;20.8;37.5;40.3;22.0;Cadastre;A 1.0;POLYGON Z ((355108.7 6689600.6 37.5, 355094.3 6689585.1 37.5, 355087.8 6689589.3 37.5, 355102.7 6689606.3 37.5, 355108.7 6689600.6 37.5))
BATIMENT0000000302931872;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;20.2;26.7;33.0;22.2;Cadastre;;POLYGON Z ((355074.7 6689597.2 26.7, 355076.5 6689596.2 26.7, 355074.1 6689593.6 26.7, 355073 6689592.8 26.7, 355050.7 6689612.3 26.7, 355060.4 6689606.2 26.7, 355074.7 6689597.2 26.7))
BATIMENT0000000302930215;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;15.6;21.2;36.8;40.5;22.4;Cadastre;A 1.0;POLYGON Z ((355076.5 6689596.2 36.8, 355074.7 6689597.2 36.8, 355078.7 6689602.1 36.8, 355083.4 6689607.5 36.8, 355091.6 6689617.1 36.8, 355102.7 6689606.3 36.8, 355087.8 6689589.3 36.8, 355076.5 6689596.2 36.8), (355086.9 6689596.5 36.8, 355090.3 6689600.2 36.8, 355086 6689604 36.8, 355082.7 6689600.2 36.8, 355086.9 6689596.5 36.8))
BATIMENT0000000302930208;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;20;15.3;20.6;35.9;41.0;22.6;Cadastre;A 1.0;POLYGON Z ((355091.6 6689617.1 35.9, 355083.4 6689607.5 35.9, 355080.9 6689609.8 35.9, 355083.2 6689612.6 35.9, 355078.2 6689617.2 35.9, 355071.2 6689609 35.9, 355078.7 6689602.1 35.9, 355074.7 6689597.2 35.9, 355060.4 6689606.2 35.9, 355066.5 6689613.1 35.9, 355080.3 6689627.9 35.9, 355091.6 6689617.1 35.9))
BATIMENT0000000302931819;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;20.6;25.4;35.3;22.7;Cadastre;;POLYGON Z ((355060.7 6689617.4 25.4, 355062.5 6689616.8 25.4, 355063.1 6689616.2 25.4, 355063.8 6689615.6 25.4, 355066.5 6689613.1 25.4, 355060.4 6689606.2 25.4, 355050.7 6689612.3 25.4, 355057.9 6689620 25.4, 355060.7 6689617.4 25.4))
BATIMENT0000000302930211;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.8;21.7;34.5;35.0;22.3;Cadastre;;POLYGON Z ((355064.2 6689617.5 34.5, 355065 6689616.9 34.5, 355063.8 6689615.6 34.5, 355063.1 6689616.2 34.5, 355064.2 6689617.5 34.5))
BATIMENT0000000302927613;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;35;90;21.7;24.8;46.5;50.7;26.2;Cadastre;A 1.0;POLYGON Z ((354919.6 6689428.5 46.5, 354895.2 6689424.2 46.5, 354893.5 6689433.6 46.5, 354904.5 6689435.5 46.5, 354903.7 6689439.6 46.5, 354911.1 6689440.9 46.5, 354912 6689441.1 46.5, 354918.1 6689442.1 46.5, 354919.1 6689434.3 46.5, 354919.9 6689428.8 46.5, 354919.9 6689428.5 46.5, 354919.6 6689428.5 46.5))
BATIMENT0000000302927626;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.3;23.7;43.1;43.5;24.2;Cadastre;;POLYGON Z ((354932.5 6689436.4 43.1, 354937.6 6689437.1 43.1, 354938.4 6689432.7 43.1, 354933.5 6689431.8 43.1, 354932.5 6689436.4 43.1))
BATIMENT0000000302927644;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.2;26.6;28.8;30.9;26.9;Cadastre;A 1.0;POLYGON Z ((354878.8 6689439.2 28.8, 354878.2 6689442.8 28.8, 354883.6 6689443.7 28.8, 354884.2 6689440.2 28.8, 354878.8 6689439.2 28.8))
BATIMENT0000000302927622;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;24.8;31.2;41.2;25.3;Cadastre;;POLYGON Z ((354911.1 6689440.9 31.2, 354910.3 6689444.9 31.2, 354911.4 6689445.1 31.2, 354912 6689441.1 31.2, 354911.1 6689440.9 31.2))
BATIMENT0000000302927618;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;20;20;17.5;23.3;40.9;45.9;26.0;Cadastre;A 0.8;POLYGON Z ((354919.9 6689428.8 40.9, 354924.3 6689429.5 40.9, 354923.6 6689434.9 40.9, 354919.1 6689434.3 40.9, 354918.1 6689442.1 40.9, 354917.8 6689444.1 40.9, 354922 6689444.6 40.9, 354921.7 6689446.9 40.9, 354919.9 6689460 40.9, 354919.5 6689463.8 40.9, 354924.1 6689464.5 40.9, 354924.5 6689460.9 40.9, 354927.8 6689461.2 40.9, 354928.2 6689461.9 40.9, 354928.5 6689462.3 40.9, 354928.2 6689463.2 40.9, 354929.4 6689463.4 40.9, 354929.2 6689465.1 40.9, 354932.2 6689465.4 40.9, 354932.3 6689463.9 40.9, 354933.2 6689463.9 40.9, 354933.3 6689462.8 40.9, 354934.5 6689462 40.9, 354938.4 6689462.6 40.9, 354937.8 6689466.1 40.9, 354943.5 6689466.9 40.9, 354945.4 6689456.5 40.9, 354935.9 6689455.1 40.9, 354926.7 6689453.8 40.9, 354928.2 6689445 40.9, 354937.4 6689446.3 40.9, 354946.8 6689447.8 40.9, 354950.6 6689426.2 40.9, 354920.8 6689421 40.9, 354919.9 6689428.5 40.9, 354919.9 6689428.8 40.9), (354938.4 6689432.7 40.9, 354937.6 6689437.1 40.9, 354932.5 6689436.4 40.9, 354933.5 6689431.8 40.9, 354938.4 6689432.7 40.9))
BATIMENT0000000302927623;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;24.5;36.3;44.7;25.3;Cadastre;;POLYGON Z ((354918.1 6689442.1 36.3, 354912 6689441.1 36.3, 354911.4 6689445.1 36.3, 354921.7 6689446.9 36.3, 354922 6689444.6 36.3, 354917.8 6689444.1 36.3, 354918.1 6689442.1 36.3))
BATIMENT0000000302927643;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.1;26.0;29.1;30.5;26.8;Cadastre;A 1.0;POLYGON Z ((354877.6 6689446 29.1, 354883.1 6689447 29.1, 354883.6 6689443.7 29.1, 354878.2 6689442.8 29.1, 354877.6 6689446 29.1))
BATIMENT0000000302927629;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;24.9;28.2;29.4;26.8;Cadastre;;POLYGON Z ((354910.3 6689444.9 28.2, 354899.5 6689442.9 28.2, 354899 6689445.5 28.2, 354911 6689447.5 28.2, 354911.4 6689445.1 28.2, 354910.3 6689444.9 28.2))
BATIMENT0000000302927642;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;26.0;29.1;30.7;26.9;Cadastre;;POLYGON Z ((354886.8 6689454.3 29.1, 354889.2 6689441 29.1, 354884.2 6689440.2 29.1, 354883.6 6689443.7 29.1, 354883.1 6689447 29.1, 354882.5 6689450.2 29.1, 354881.9 6689453.5 29.1, 354886.8 6689454.3 29.1))
BATIMENT0000000302927641;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.1;26.0;29.1;30.0;26.8;Cadastre;A 1.0;POLYGON Z ((354877.1 6689449.1 29.1, 354882.5 6689450.2 29.1, 354883.1 6689447 29.1, 354877.6 6689446 29.1, 354877.1 6689449.1 29.1))
BATIMENT0000000302927610;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;27.7;43.4;44.2;28.0;Cadastre;;POLYGON Z ((354847.5 6689419.6 43.4, 354842.7 6689418.8 43.4, 354843.4 6689420.7 43.4, 354843.7 6689420.5 43.4, 354847.3 6689421 43.4, 354847.5 6689419.6 43.4))
BATIMENT0000000302927611;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.2;27.4;41.7;44.4;28.0;Cadastre;;POLYGON Z ((354842.6 6689426.6 41.7, 354856.4 6689428.7 41.7, 354856.6 6689427.7 41.7, 354859.6 6689428.1 41.7, 354860.4 6689424.4 41.7, 354857.3 6689423.9 41.7, 354857.4 6689422.9 41.7, 354847.3 6689421.3 41.7, 354847.3 6689421 41.7, 354843.7 6689420.5 41.7, 354843.4 6689420.7 41.7, 354843.2 6689420.9 41.7, 354842.2 6689426.5 41.7, 354842.6 6689426.6 41.7))
BATIMENT0000000302927605;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;17.6;27.0;44.7;47.9;28.0;Cadastre;C 0.7;POLYGON Z ((354845.7 6689433.7 44.7, 354844.6 6689439.3 44.7, 354844.1 6689443 44.7, 354849.7 6689443.9 44.7, 354850.8 6689437.1 44.7, 354860.1 6689438.8 44.7, 354859 6689445.5 44.7, 354864.7 6689446.5 44.7, 354866 6689437.1 44.7, 354866.4 6689433.3 44.7, 354866.1 6689433.3 44.7, 354861.9 6689432.9 44.7, 354861.9 6689432.1 44.7, 354863.2 6689432.2 44.7, 354865 6689431 44.7, 354865.1 6689431 44.7, 354865.6 6689428.3 44.7, 354864.5 6689426.9 44.7, 354863.5 6689426.7 44.7, 354863.8 6689425.4 44.7, 354868.7 6689426.1 44.7, 354868.7 6689425.8 44.7, 354869.1 6689425.9 44.7, 354870.2 6689419.8 44.7, 354871.6 6689412.3 44.7, 354849.4 6689408.4 44.7, 354847.5 6689419.6 44.7, 354847.3 6689421 44.7, 354847.3 6689421.3 44.7, 354857.4 6689422.9 44.7, 354857.3 6689423.9 44.7, 354860.4 6689424.4 44.7, 354859.6 6689428.1 44.7, 354856.6 6689427.7 44.7, 354856.4 6689428.7 44.7, 354842.6 6689426.6 44.7, 354841.3 6689433.2 44.7, 354845.7 6689433.7 44.7))
BATIMENT0000000302927606;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.3;27.1;44.4;45.7;27.4;Cadastre;;POLYGON Z ((354863.8 6689425.4 44.4, 354863.5 6689426.7 44.4, 354864.5 6689426.9 44.4, 354865.6 6689428.3 44.4, 354865.1 6689431 44.4, 354865 6689431 44.4, 354863.2 6689432.2 44.4, 354861.9 6689432.1 44.4, 354861.9 6689432.9 44.4, 354866.1 6689433.3 44.4, 354867.4 6689429.7 44.4, 354868.7 6689426.1 44.4, 354863.8 6689425.4 44.4))
BATIMENT0000000302927601;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;8.6;27.5;36.2;43.2;28.5;Cadastre;C 0.2;POLYGON Z ((354824.3 6689436.3 36.2, 354833.1 6689437.5 36.2, 354833.2 6689437.8 36.2, 354844.6 6689439.3 36.2, 354845.7 6689433.7 36.2, 354841.3 6689433.2 36.2, 354828.7 6689431.8 36.2, 354828.9 6689431 36.2, 354827 6689430.2 36.2, 354824.6 6689435.4 36.2, 354824.3 6689436.3 36.2))
BATIMENT0000000302927607;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.3;27.2;36.6;43.5;27.7;Cadastre;;POLYGON Z ((354849.7 6689443.9 36.6, 354859 6689445.5 36.6, 354860.1 6689438.8 36.6, 354850.8 6689437.1 36.6, 354849.7 6689443.9 36.6))
BATIMENT0000000302927609;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;26.7;29.6;38.5;27.5;Cadastre;A 1.0;POLYGON Z ((354864.7 6689446.5 29.6, 354864.1 6689450.4 29.6, 354869 6689451.2 29.6, 354869.8 6689451.4 29.6, 354872.2 6689438.1 29.6, 354866 6689437.1 29.6, 354864.7 6689446.5 29.6))
BATIMENT0000000302927603;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;12;20;18.5;28.5;47.1;49.9;29.5;Cadastre;A 1.0;POLYGON Z ((354793.2 6689469.1 47.1, 354804.5 6689471.5 47.1, 354804.6 6689470.9 47.1, 354805.3 6689471.6 47.1, 354807.4 6689472 47.1, 354808 6689473.8 47.1, 354809.6 6689471.7 47.1, 354812.7 6689472.1 47.1, 354816 6689457.8 47.1, 354813.8 6689457.3 47.1, 354812 6689464.7 47.1, 354809.4 6689464.1 47.1, 354809.1 6689464.4 47.1, 354808.6 6689464.9 47.1, 354808.1 6689466.5 47.1, 354807.2 6689466.3 47.1, 354813.8 6689434 47.1, 354814.6 6689434.5 47.1, 354815.4 6689435.6 47.1, 354821.3 6689439.5 47.1, 354822.8 6689439.5 47.1, 354824.3 6689436.3 47.1, 354824.6 6689435.4 47.1, 354815.4 6689429 47.1, 354814.7 6689429.3 47.1, 354811.4 6689428.5 47.1, 354811.6 6689426.2 47.1, 354807.4 6689422.7 47.1, 354802.8 6689421.5 47.1, 354793.2 6689469.1 47.1))
BATIMENT0000000302927639;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;24.4;29.5;32.0;27.6;Cadastre;;POLYGON Z ((354869.8 6689451.4 29.5, 354869 6689451.2 29.5, 354863.9 6689474.8 29.5, 354869.5 6689476.1 29.5, 354874.5 6689452.3 29.5, 354869.8 6689451.4 29.5))
BATIMENT0000000302929221;Chapelle;Indifférencié;;Non;En service;2012-06-19 19:00:51;2012-10-24 11:02:07;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;27.2;41.3;;;Cadastre;;POLYGON Z ((354829.6 6689491.8 41.3, 354830.6 6689487.7 41.3, 354832.6 6689478.9 41.3, 354828.4 6689478.1 41.3, 354829.8 6689474.2 41.3, 354833.1 6689460.2 41.3, 354837.1 6689461.2 41.3, 354838.9 6689460.1 41.3, 354839.4 6689458 41.3, 354840.4 6689457.2 41.3, 354840.9 6689455.6 41.3, 354840.2 6689454.5 41.3, 354840.7 6689452.6 41.3, 354839.4 6689450.7 41.3, 354839.9 6689448.5 41.3, 354836.7 6689447.7 41.3, 354836.1 6689449.7 41.3, 354834.9 6689449.3 41.3, 354834.7 6689447.8 41.3, 354834.7 6689447.1 41.3, 354835.6 6689446.8 41.3, 354836 6689447 41.3, 354836.3 6689446.5 41.3, 354835.9 6689446.3 41.3, 354836.1 6689445.3 41.3, 354836.6 6689445.1 41.3, 354836.4 6689444.6 41.3, 354836 6689444.7 41.3, 354835.5 6689443.7 41.3, 354835.7 6689443.5 41.3, 354835.2 6689443 41.3, 354835 6689443.4 41.3, 354833.8 6689443.3 41.3, 354833.9 6689442.9 41.3, 354833.2 6689442.9 41.3, 354833.2 6689443.4 41.3, 354832.3 6689443.7 41.3, 354831.6 6689443.4 41.3, 354830.9 6689442.9 41.3, 354830.6 6689442.4 41.3, 354830.9 6689441.7 41.3, 354831.3 6689441.7 41.3, 354831.3 6689441.2 41.3, 354831 6689441 41.3, 354831.2 6689440.1 41.3, 354831.6 6689439.9 41.3, 354831.5 6689439.4 41.3, 354831 6689439.6 41.3, 354830.5 6689438.7 41.3, 354830.6 6689438.3 41.3, 354830.1 6689438 41.3, 354830 6689438.3 41.3, 354829.4 6689438.1 41.3, 354828.9 6689438.1 41.3, 354828.7 6689437.6 41.3, 354828.2 6689437.8 41.3, 354828.4 6689438.2 41.3, 354827.9 6689438.4 41.3, 354827.4 6689438 41.3, 354827 6689438.8 41.3, 354827.4 6689439 41.3, 354827.1 6689439.7 41.3, 354826.5 6689439.6 41.3, 354826.4 6689440 41.3, 354826.8 6689440.3 41.3, 354826.6 6689441.6 41.3, 354826.3 6689441.7 41.3, 354826.2 6689441.3 41.3, 354824.5 6689441.5 41.3, 354824.6 6689442 41.3, 354824.3 6689442.1 41.3, 354823.6 6689441.1 41.3, 354823.8 6689440.7 41.3, 354823.3 6689440.4 41.3, 354823.1 6689440.8 41.3, 354822.3 6689440.5 41.3, 354822.1 6689440.2 41.3, 354821.5 6689440.2 41.3, 354821.6 6689440.5 41.3, 354820.7 6689441.2 41.3, 354820.3 6689440.7 41.3, 354820.1 6689441.2 41.3, 354820.5 6689441.6 41.3, 354820.2 6689442.6 41.3, 354819.6 6689442.5 41.3, 354819.5 6689443.1 41.3, 354820.3 6689443.2 41.3, 354820.9 6689444.3 41.3, 354820.5 6689444.4 41.3, 354818.8 6689442.7 41.3, 354818 6689448.7 41.3, 354816 6689457.8 41.3, 354812.7 6689472.1 41.3, 354809.6 6689471.7 41.3, 354808 6689473.8 41.3, 354805 6689486.3 41.3, 354829.6 6689491.8 41.3))
BATIMENT0000000302927570;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;;;20.2;19.3;39.5;48.2;22.1;Cadastre;C 0.1;POLYGON Z ((354999.7 6689384.4 39.5, 355002.3 6689384.8 39.5, 355002.2 6689385.9 39.5, 355002.6 6689386.4 39.5, 355002.7 6689386.6 39.5, 355002.9 6689386.8 39.5, 355003.2 6689387.1 39.5, 355003.5 6689387.3 39.5, 355003.9 6689387.4 39.5, 355004 6689387.5 39.5, 355004.4 6689387.5 39.5, 355004.4 6689388 39.5, 355003.2 6689397.3 39.5, 355002.9 6689399.5 39.5, 355002.7 6689399.6 39.5, 355002.5 6689399.6 39.5, 355002.3 6689399.7 39.5, 355002.1 6689399.7 39.5, 355001.8 6689399.9 39.5, 355001.6 6689400 39.5, 355001.4 6689400.1 39.5, 355001.1 6689400.3 39.5, 355000.9 6689400.5 39.5, 355000.8 6689400.6 39.5, 355000.5 6689400.9 39.5, 355000.4 6689401.2 39.5, 355000.3 6689401.7 39.5, 355000.3 6689402.3 39.5, 355000.4 6689402.6 39.5, 355000.4 6689402.9 39.5, 355000.5 6689403.4 39.5, 355000.6 6689403.7 39.5, 355000.8 6689404.2 39.5, 354996.7 6689407.3 39.5, 354982.8 6689405 39.5, 354982.9 6689403.6 39.5, 354978.7 6689402.8 39.5, 354977.1 6689409.9 39.5, 354974.1 6689409.4 39.5, 354973.5 6689412.5 39.5, 354974.3 6689412.6 39.5, 354974.8 6689412.7 39.5, 355000 6689417.1 39.5, 355000.3 6689416.6 39.5, 355000.6 6689416 39.5, 355001 6689415.5 39.5, 355001.4 6689415 39.5, 355001.8 6689414.5 39.5, 355002.4 6689413.9 39.5, 355002.9 6689413.4 39.5, 355004.3 6689412.3 39.5, 355005.2 6689411.7 39.5, 355006.2 6689411 39.5, 355006.8 6689410.7 39.5, 355008 6689410.1 39.5, 355008.9 6689409.7 39.5, 355009.2 6689409.6 39.5, 355009.8 6689409.4 39.5, 355010.8 6689409.1 39.5, 355014.7 6689377.6 39.5, 355001 6689375.7 39.5, 354999.7 6689384.4 39.5))
BATIMENT0000000302927568;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;;;25.5;21.7;47.2;48.4;23.3;Cadastre;A 1.0;POLYGON Z ((354955.1 6689417 47.2, 354972.8 6689420 47.2, 354974.3 6689412.6 47.2, 354973.5 6689412.5 47.2, 354974.1 6689409.4 47.2, 354957.2 6689406.5 47.2, 354955.1 6689417 47.2))
BATIMENT0000000302927636;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;7.0;30;30;20.1;20.8;41.0;48.8;22.3;Cadastre;A 1.0;POLYGON Z ((354969.6 6689441.4 41, 354969.3 6689441.4 41, 354962.2 6689466.9 41, 354983.3 6689471.1 41, 354993.2 6689456.7 41, 354992.4 6689455.7 41, 354991.8 6689454.6 41, 354991.1 6689453.5 41, 354990.6 6689452.4 41, 354990 6689451.3 41, 354989.4 6689449.9 41, 354988.9 6689448.4 41, 354988.5 6689446.9 41, 354988.4 6689446.6 41, 354988.2 6689445.4 41, 354988.1 6689445.3 41, 354988 6689443.9 41, 354987.9 6689442.3 41, 354987.9 6689441.7 41, 354988 6689440.5 41, 354970.6 6689437.5 41, 354969.6 6689441.4 41))
BATIMENT0000000302927628;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;6.0;;;13.8;21.3;35.2;50.0;23.5;Cadastre;A 1.0;POLYGON Z ((354966.5 6689495.4 35.2, 354966.1 6689495.1 35.2, 354967.4 6689490 35.2, 354969.6 6689490.9 35.2, 354983.3 6689471.1 35.2, 354962.2 6689466.9 35.2, 354969.3 6689441.4 35.2, 354969.6 6689441.4 35.2, 354970.6 6689437.5 35.2, 354972.4 6689430.1 35.2, 354950.6 6689426.2 35.2, 354946.8 6689447.8 35.2, 354945.4 6689456.5 35.2, 354943.5 6689466.9 35.2, 354938.9 6689492.7 35.2, 354953.1 6689494.9 35.2, 354954.8 6689495.1 35.2, 354955.1 6689494.8 35.2, 354955.6 6689494.9 35.2, 354965.5 6689496.8 35.2, 354966.5 6689495.4 35.2))
BATIMENT0000000302929173;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;25.7;20.6;46.3;47.0;20.8;Cadastre;;POLYGON Z ((354998.2 6689479.9 46.3, 355000.8 6689481.1 46.3, 355003.8 6689476.4 46.3, 355013.2 6689478.3 46.3, 355017.2 6689484.8 46.3, 355024.9 6689478.4 46.3, 355016 6689465.6 46.3, 355014.3 6689465.8 46.3, 355010.4 6689465.6 46.3, 355007.7 6689465.1 46.3, 355005.1 6689464.3 46.3, 355002.1 6689463 46.3, 354992.5 6689476.9 46.3, 354997.7 6689480.5 46.3, 354998.2 6689479.9 46.3))
BATIMENT0000000302929174;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.3;20.6;35.9;39.7;20.7;Cadastre;C 0.1;POLYGON Z ((355013.3 6689491.1 35.9, 355021 6689498.8 35.9, 355029.7 6689511.2 35.9, 355041.9 6689502.7 35.9, 355024.9 6689478.4 35.9, 355017.2 6689484.8 35.9, 355013.2 6689478.3 35.9, 355003.8 6689476.4 35.9, 355000.8 6689481.1 35.9, 354998.2 6689479.9 35.9, 354997.7 6689480.5 35.9, 355013.3 6689491.1 35.9))
BATIMENT0000000302927638;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.6;21.9;35.5;36.7;22.5;Cadastre;;POLYGON Z ((354945.8 6689501.3 35.5, 354945.7 6689502.2 35.5, 354949 6689500.8 35.5, 354950.5 6689501.8 35.5, 354951.5 6689500.4 35.5, 354950.2 6689499.6 35.5, 354948.3 6689500.3 35.5, 354945.8 6689501.3 35.5))
BATIMENT0000000302927543;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.9;20.6;28.5;30.9;22.0;Cadastre;A 1.0;POLYGON Z ((355019.6 6689523.4 28.5, 355022.9 6689518.6 28.5, 355014.5 6689512.7 28.5, 355014.8 6689512.1 28.5, 355008.8 6689507.8 28.5, 355015.5 6689498.5 28.5, 355011.2 6689493.6 28.5, 354993.1 6689480.9 28.5, 354992.9 6689481.1 28.5, 354990.7 6689479.5 28.5, 354979.6 6689495.6 28.5, 355014 6689519.5 28.5, 355019.6 6689523.4 28.5))
BATIMENT0000000302927637;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;15;20;17.9;20.2;38.1;42.5;23.0;Cadastre;A 1.0;POLYGON Z ((354936.2 6689510.9 38.1, 354949.8 6689513.9 38.1, 354955.2 6689511.8 38.1, 354958.9 6689506.4 38.1, 354965.5 6689496.8 38.1, 354955.6 6689494.9 38.1, 354955.1 6689494.8 38.1, 354954.8 6689495.1 38.1, 354953.1 6689494.9 38.1, 354938.9 6689492.7 38.1, 354935.7 6689510.9 38.1, 354936.2 6689510.9 38.1), (354950.2 6689499.6 38.1, 354951.5 6689500.4 38.1, 354950.5 6689501.8 38.1, 354949 6689500.8 38.1, 354945.7 6689502.2 38.1, 354945.8 6689501.3 38.1, 354948.3 6689500.3 38.1, 354950.2 6689499.6 38.1))
BATIMENT0000000302927541;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.2;19.7;31.9;36.6;22.4;Cadastre;C 0.1;POLYGON Z ((354976.7 6689499.9 31.9, 354977.8 6689500.8 31.9, 354978 6689500.6 31.9, 354979.9 6689501.9 31.9, 354979.8 6689502.2 31.9, 354980.5 6689502.6 31.9, 354981.2 6689501.5 31.9, 354981.8 6689501 31.9, 354983 6689501 31.9, 354983.9 6689501.4 31.9, 354984.6 6689502.5 31.9, 354984.4 6689503.3 31.9, 354984.6 6689503.4 31.9, 354976 6689516.1 31.9, 354975.8 6689515.9 31.9, 354974.7 6689516.6 31.9, 354973.3 6689516 31.9, 354972.7 6689515 31.9, 354972.6 6689514.2 31.9, 354973.6 6689512.5 31.9, 354973 6689512.1 31.9, 354972.8 6689512.3 31.9, 354970.9 6689510.9 31.9, 354971 6689510.7 31.9, 354969.7 6689509.8 31.9, 354966.8 6689514.1 31.9, 354975.7 6689520.2 31.9, 355001.3 6689537.7 31.9, 355007.1 6689529.3 31.9, 355008.4 6689527.5 31.9, 355014 6689519.5 31.9, 354979.6 6689495.6 31.9, 354976.7 6689499.9 31.9))
BATIMENT0000000302927634;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.3;24.6;28.9;31.2;26.9;Cadastre;B 0.2;POLYGON Z ((354897.2 6689456.2 28.9, 354899 6689445.5 28.9, 354899.5 6689442.9 28.9, 354894.6 6689442 28.9, 354892.4 6689455.3 28.9, 354897.2 6689456.2 28.9))
BATIMENT0000000302927640;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.1;26.6;31.7;38.0;26.9;Cadastre;A 1.0;POLYGON Z ((354876.4 6689452.5 31.7, 354881.9 6689453.5 31.7, 354882.5 6689450.2 31.7, 354877.1 6689449.1 31.7, 354876.4 6689452.5 31.7))
BATIMENT0000000302927627;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.4;23.2;41.7;49.5;24.0;Cadastre;;POLYGON Z ((354946.8 6689447.8 41.7, 354937.4 6689446.3 41.7, 354935.9 6689455.1 41.7, 354945.4 6689456.5 41.7, 354946.8 6689447.8 41.7))
BATIMENT0000000302927615;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.2;24.8;30.0;33.8;26.8;Cadastre;A 1.0;POLYGON Z ((354919.9 6689460 30, 354921.7 6689446.9 30, 354911.4 6689445.1 30, 354911 6689447.5 30, 354899 6689445.5 30, 354897.2 6689456.2 30, 354915.1 6689459.2 30, 354919.9 6689460 30))
BATIMENT0000000302927625;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;23.8;38.0;40.2;25.2;Cadastre;;POLYGON Z ((354924.1 6689464.5 38, 354926.2 6689464.7 38, 354929.2 6689465.1 38, 354929.4 6689463.4 38, 354928.2 6689463.2 38, 354928.5 6689462.3 38, 354928.2 6689461.9 38, 354927.8 6689461.2 38, 354924.5 6689460.9 38, 354924.1 6689464.5 38))
BATIMENT0000000302927624;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;23.6;39.0;40.2;23.9;Cadastre;;POLYGON Z ((354937.8 6689466.1 39, 354938.4 6689462.6 39, 354934.5 6689462 39, 354933.3 6689462.8 39, 354933.2 6689463.9 39, 354932.3 6689463.9 39, 354932.2 6689465.4 39, 354932.5 6689465.5 39, 354935.5 6689465.9 39, 354936.7 6689466 39, 354937.8 6689466.1 39))
BATIMENT0000000302927620;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;23.6;34.7;35.0;23.7;Cadastre;;POLYGON Z ((354936.7 6689466 34.7, 354935.5 6689465.9 34.7, 354935.5 6689466.6 34.7, 354936.4 6689466.6 34.7, 354936.7 6689466 34.7))
BATIMENT0000000302927632;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.9;23.7;29.7;36.7;24.8;Cadastre;B 1.0;POLYGON Z ((354925.6 6689469.1 29.7, 354928.8 6689469.5 29.7, 354929.2 6689465.1 29.7, 354926.2 6689464.7 29.7, 354925.6 6689469.1 29.7))
BATIMENT0000000302927633;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.4;23.6;33.0;37.4;24.2;Cadastre;B 1.0;POLYGON Z ((354929.2 6689465.1 33, 354928.8 6689469.5 33, 354932 6689470.1 33, 354932.5 6689465.5 33, 354932.2 6689465.4 33, 354929.2 6689465.1 33))
BATIMENT0000000302927616;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.2;24.0;28.2;35.0;25.9;Cadastre;A 1.0;POLYGON Z ((354917.4 6689479.5 28.2, 354920 6689479.8 28.2, 354920.5 6689476.7 28.2, 354920.7 6689473.6 28.2, 354921.1 6689470.7 28.2, 354925.3 6689471.4 28.2, 354925.6 6689469.1 28.2, 354926.2 6689464.7 28.2, 354924.1 6689464.5 28.2, 354919.5 6689463.8 28.2, 354917.4 6689479.5 28.2))
BATIMENT0000000302927608;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;12;20;18.0;28.4;46.5;50.0;29.5;Cadastre;A 1.0;POLYGON Z ((354790.9 6689480.4 46.5, 354791.6 6689480.8 46.5, 354792.2 6689481.2 46.5, 354792.5 6689481.4 46.5, 354792.8 6689481.6 46.5, 354793.3 6689482.1 46.5, 354793.9 6689482.6 46.5, 354794.1 6689482.9 46.5, 354794.4 6689483.2 46.5, 354794.6 6689483.5 46.5, 354794.8 6689483.8 46.5, 354795 6689484.2 46.5, 354798.6 6689484.9 46.5, 354803.5 6689478.6 46.5, 354802.9 6689478.1 46.5, 354803.1 6689477.7 46.5, 354804.5 6689471.5 46.5, 354793.2 6689469.1 46.5, 354790.9 6689480.4 46.5))
BATIMENT0000000302929219;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;27.2;41.3;46.1;29.5;Cadastre;;POLYGON Z ((354805 6689486.3 41.3, 354808 6689473.8 41.3, 354804.2 6689478.6 41.3, 354803.8 6689478.3 41.3, 354803.5 6689478.6 41.3, 354798.6 6689484.9 41.3, 354805 6689486.3 41.3))
BATIMENT0000000302929220;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;43.0;5.0;00;00;16.4;26.2;42.7;47.9;27.8;Cadastre;C 0.4;POLYGON Z ((354832.6 6689478.9 42.7, 354830.6 6689487.7 42.7, 354859.8 6689494.1 42.7, 354862.5 6689481.2 42.7, 354853.5 6689479.2 42.7, 354847.8 6689478 42.7, 354832.8 6689474.7 42.7, 354832.8 6689474.9 42.7, 354829.8 6689474.2 42.7, 354828.4 6689478.1 42.7, 354832.6 6689478.9 42.7))
BATIMENT0000000302927548;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;13.4;25.2;38.6;41.5;27.2;Cadastre;A 1.0;POLYGON Z ((354837.6 6689502.4 38.6, 354830.6 6689513.3 38.6, 354832.2 6689514.5 38.6, 354832.9 6689513.5 38.6, 354832.3 6689513.1 38.6, 354832.9 6689512.2 38.6, 354839.7 6689516.8 38.6, 354839 6689517.7 38.6, 354841.3 6689519.4 38.6, 354839.8 6689521.6 38.6, 354840.8 6689522.3 38.6, 354843.1 6689519.1 38.6, 354844 6689519.7 38.6, 354850.2 6689510.8 38.6, 354837.6 6689502.4 38.6))
BATIMENT0000000302927553;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.2;24.7;37.0;39.1;25.8;Cadastre;C 0.8;POLYGON Z ((354873.9 6689510.5 37, 354873 6689511.7 37, 354869.6 6689509.2 37, 354863.5 6689517.6 37, 354871.4 6689523.1 37, 354872.6 6689521.4 37, 354873.7 6689522 37, 354879.2 6689514.2 37, 354873.9 6689510.5 37))
BATIMENT0000000302927545;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;26.5;30.8;36.2;27.2;Cadastre;;POLYGON Z ((354828.5 6689516.6 30.8, 354830 6689518.4 30.8, 354832.2 6689516.2 30.8, 354829.9 6689514.6 30.8, 354828.5 6689516.6 30.8))
BATIMENT0000000302927551;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;13.5;25.0;38.5;41.6;26.5;Cadastre;A 0.7;POLYGON Z ((354844.8 6689520.3 38.5, 354856.1 6689528 38.5, 354856.3 6689527.7 38.5, 354862.4 6689519.1 38.5, 354850.2 6689510.8 38.5, 354844 6689519.7 38.5, 354844.8 6689520.3 38.5))
BATIMENT0000000302927550;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;25.3;32.2;38.0;26.4;Cadastre;;POLYGON Z ((354842.5 6689523.5 32.2, 354847.2 6689526.8 32.2, 354853.7 6689531.3 32.2, 354856.1 6689528 32.2, 354844.8 6689520.3 32.2, 354842.5 6689523.5 32.2))
BATIMENT0000000302927549;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;24.9;29.6;30.3;26.4;Cadastre;;POLYGON Z ((354847.2 6689526.8 29.6, 354846.4 6689528 29.6, 354847.7 6689529 29.6, 354845.7 6689531.6 29.6, 354847.1 6689532.7 29.6, 354848.9 6689534.9 29.6, 354850.1 6689536.3 29.6, 354852.8 6689532.7 29.6, 354853.7 6689531.3 29.6, 354847.2 6689526.8 29.6))
BATIMENT0000000302927552;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;02;4.9;25.1;30.0;31.4;25.8;Cadastre;C 0.3;POLYGON Z ((354857.3 6689535.3 30, 354858.8 6689536.2 30, 354859.2 6689536.4 30, 354862.5 6689531.9 30, 354856.3 6689527.7 30, 354856.1 6689528 30, 354853.7 6689531.3 30, 354852.8 6689532.7 30, 354857.3 6689535.3 30))
BATIMENT0000000302927630;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.3;23.7;27.0;27.7;25.3;Cadastre;B 1.0;POLYGON Z ((354921.1 6689470.7 27, 354920.7 6689473.6 27, 354925.3 6689474.4 27, 354925.7 6689471.3 27, 354925.3 6689471.4 27, 354921.1 6689470.7 27))
BATIMENT0000000302927631;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;23.5;26.5;28.3;25.1;Cadastre;B 1.0;POLYGON Z ((354920.5 6689476.7 26.5, 354925 6689477.4 26.5, 354925.3 6689474.4 26.5, 354920.7 6689473.6 26.5, 354920.5 6689476.7 26.5))
BATIMENT0000000302927635;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;23.3;26.5;28.9;25.0;Cadastre;B 1.0;POLYGON Z ((354920 6689479.8 26.5, 354924.5 6689480.5 26.5, 354925 6689477.4 26.5, 354920.5 6689476.7 26.5, 354920 6689479.8 26.5))
BATIMENT0000000302927619;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.6;23.3;27.0;35.7;25.3;Cadastre;A 1.0;POLYGON Z ((354917 6689482.4 27, 354924.1 6689483.3 27, 354924.5 6689480.5 27, 354920 6689479.8 27, 354917.4 6689479.5 27, 354917 6689482.4 27))
BATIMENT0000000302927614;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.2;24.0;34.3;39.4;27.5;Cadastre;A 0.3;POLYGON Z ((354914 6689506 34.3, 354914.4 6689506.1 34.3, 354916.9 6689486.4 34.3, 354916.5 6689486.3 34.3, 354917 6689482.4 34.3, 354917.4 6689479.5 34.3, 354919.5 6689463.8 34.3, 354919.9 6689460 34.3, 354915.1 6689459.2 34.3, 354914.5 6689462.4 34.3, 354913.2 6689462.2 34.3, 354911.9 6689469.8 34.3, 354913.1 6689470 34.3, 354910.1 6689485.1 34.3, 354908.8 6689484.7 34.3, 354906.9 6689494.4 34.3, 354875.3 6689487.6 34.3, 354876.1 6689483.4 34.3, 354862.7 6689480.4 34.3, 354862.5 6689481.2 34.3, 354859.8 6689494.1 34.3, 354914 6689506 34.3))
BATIMENT0000000302927617;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;14;20;15.0;22.7;37.7;43.6;25.2;Cadastre;A 1.0;POLYGON Z ((354936.4 6689466.6 37.7, 354933.8 6689481.4 37.7, 354933.6 6689481.3 37.7, 354933.4 6689481.3 37.7, 354933.3 6689481.3 37.7, 354933.2 6689481.3 37.7, 354932.9 6689481.4 37.7, 354932.7 6689481.5 37.7, 354932.3 6689481.7 37.7, 354932.1 6689482 37.7, 354932 6689482.1 37.7, 354931.9 6689482.4 37.7, 354931.8 6689482.5 37.7, 354931.8 6689482.8 37.7, 354931.8 6689482.9 37.7, 354931.8 6689483 37.7, 354931.8 6689483.3 37.7, 354931.8 6689483.4 37.7, 354931.9 6689483.7 37.7, 354932 6689483.8 37.7, 354932.3 6689484.2 37.7, 354932.4 6689484.3 37.7, 354932.6 6689484.4 37.7, 354932.8 6689484.4 37.7, 354933.1 6689484.5 37.7, 354933.3 6689484.5 37.7, 354932.2 6689491.4 37.7, 354934 6689491.6 37.7, 354932.9 6689498.8 37.7, 354933.4 6689500.8 37.7, 354920.1 6689497.8 37.7, 354921 6689489.3 37.7, 354921.6 6689489.3 37.7, 354923.6 6689487.7 37.7, 354924.1 6689483.3 37.7, 354917 6689482.4 37.7, 354916.5 6689486.3 37.7, 354916.9 6689486.4 37.7, 354914.4 6689506.1 37.7, 354913.8 6689510.3 37.7, 354934.9 6689515.1 37.7, 354935.7 6689510.9 37.7, 354938.9 6689492.7 37.7, 354943.5 6689466.9 37.7, 354937.8 6689466.1 37.7, 354936.7 6689466 37.7, 354936.4 6689466.6 37.7))
BATIMENT0000000302927554;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1889-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;00;00;11.1;24.0;35.2;38.7;25.3;Cadastre;B 0.9;POLYGON Z ((354886.2 6689514.3 35.2, 354885.2 6689515.8 35.2, 354881.6 6689513.3 35.2, 354880.4 6689515.1 35.2, 354879.2 6689514.2 35.2, 354873.7 6689522 35.2, 354882.8 6689528.3 35.2, 354886.4 6689523.1 35.2, 354887.6 6689521.3 35.2, 354890.5 6689517.3 35.2, 354886.2 6689514.3 35.2))
BATIMENT0000000302927555;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;17.7;23.1;40.8;43.4;24.4;Cadastre;A 1.0;POLYGON Z ((354893 6689513.4 40.8, 354890.5 6689517.3 40.8, 354887.6 6689521.3 40.8, 354889.9 6689521.8 40.8, 354889.1 6689524.8 40.8, 354891.7 6689526.4 40.8, 354896.1 6689529.1 40.8, 354896.5 6689526.8 40.8, 354901.5 6689527.8 40.8, 354901.3 6689528.5 40.8, 354911.7 6689530.8 40.8, 354914.7 6689518.2 40.8, 354893 6689513.4 40.8))
BATIMENT0000000302927559;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;19.5;22.0;41.6;44.9;23.6;Cadastre;A 1.0;POLYGON Z ((354930.1 6689550.1 41.6, 354945.4 6689527.8 41.6, 354944.3 6689524.7 41.6, 354921.3 6689519.6 41.6, 354914.7 6689518.2 41.6, 354911.7 6689530.8 41.6, 354919.4 6689532.6 41.6, 354921.9 6689529 41.6, 354923.2 6689527.2 41.6, 354923.4 6689527 41.6, 354929 6689528.2 41.6, 354922.3 6689537.6 41.6, 354920.6 6689540 41.6, 354914.9 6689536.3 41.6, 354914 6689537.5 41.6, 354913.1 6689536.9 41.6, 354910.6 6689535.4 41.6, 354910.9 6689534.2 41.6, 354909.7 6689534 41.6, 354907.7 6689534.7 41.6, 354907 6689535.9 41.6, 354909.9 6689537.7 41.6, 354910.1 6689537.8 41.6, 354930.1 6689550.1 41.6))
BATIMENT0000000302927562;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;10;20;7.9;22.8;30.8;35.7;25.2;Cadastre;C 0.4;POLYGON Z ((354874.8 6689540 30.8, 354872 6689544 30.8, 354865.5 6689553.5 30.8, 354870.4 6689556.4 30.8, 354891.7 6689526.4 30.8, 354889.1 6689524.8 30.8, 354886.4 6689523.1 30.8, 354882.8 6689528.3 30.8, 354874.8 6689540 30.8))
BATIMENT0000000302927544;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;12;20;19.6;25.5;45.2;46.1;27.3;Cadastre;B 0.4;POLYGON Z ((354820.2 6689529.8 45.2, 354838.7 6689552 45.2, 354845.8 6689542.1 45.2, 354847.7 6689539.7 45.2, 354845.7 6689537.4 45.2, 354841.8 6689532.5 45.2, 354840.7 6689533.5 45.2, 354834.8 6689526.5 45.2, 354835.9 6689525.6 45.2, 354830 6689518.4 45.2, 354828.5 6689516.6 45.2, 354820.2 6689529.8 45.2))
BATIMENT0000000302927547;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;24.7;30.1;30.7;26.7;Cadastre;;POLYGON Z ((354847.9 6689539.4 30.1, 354850.1 6689536.3 30.1, 354848.9 6689534.9 30.1, 354845.7 6689537.4 30.1, 354847.7 6689539.7 30.1, 354847.9 6689539.4 30.1))
BATIMENT0000000302927567;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;5.3;24.8;30.1;31.6;25.1;Cadastre;B 0.2;POLYGON Z ((354868.1 6689536.1 30.1, 354865.6 6689540.2 30.1, 354872 6689544 30.1, 354874.8 6689540 30.1, 354868.1 6689536.1 30.1))
BATIMENT0000000302928203;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;5.0;;;12.4;26.8;39.2;48.1;29.4;Cadastre;A 0.7;POLYGON Z ((354788 6689558.8 39.2, 354809.4 6689533.5 39.2, 354801 6689523.4 39.2, 354794 6689531.8 39.2, 354791 6689535.4 39.2, 354796 6689539.8 39.2, 354782.8 6689555.7 39.2, 354788 6689558.8 39.2))
BATIMENT0000000302928199;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;7.0;26.8;33.8;43.8;28.4;Cadastre;A 1.0;POLYGON Z ((354797.1 6689564.2 33.8, 354798.2 6689564.7 33.8, 354805 6689555.7 33.8, 354806.7 6689553.7 33.8, 354816.7 6689542.3 33.8, 354809.4 6689533.5 33.8, 354788 6689558.8 33.8, 354797.1 6689564.2 33.8), (354804.7 6689543.4 33.8, 354805.3 6689543.8 33.8, 354804.8 6689545.1 33.8, 354804.5 6689546.3 33.8, 354804.5 6689547.6 33.8, 354803.6 6689548.5 33.8, 354804.6 6689549.3 33.8, 354805.6 6689548.1 33.8, 354806.7 6689547.7 33.8, 354807.4 6689548.5 33.8, 354802.6 6689554.1 33.8, 354802.9 6689554.5 33.8, 354799.8 6689558.1 33.8, 354796.2 6689555.2 33.8, 354802.3 6689547.6 33.8, 354801.8 6689547.1 33.8, 354804.7 6689543.4 33.8))
BATIMENT0000000302928198;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;11.7;26.2;38.0;40.1;28.0;Cadastre;A 1.0;POLYGON Z ((354820.8 6689547.2 38, 354816.7 6689542.3 38, 354806.7 6689553.7 38, 354811.7 6689557.9 38, 354820.8 6689547.2 38))
BATIMENT0000000302928197;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;27.2;35.7;37.2;28.1;Cadastre;;POLYGON Z ((354810 6689559.9 35.7, 354811.7 6689557.9 35.7, 354806.7 6689553.7 35.7, 354805 6689555.7 35.7, 354810 6689559.9 35.7))
BATIMENT0000000302927546;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;7.0;00;00;16.5;24.9;41.4;46.0;26.6;Cadastre;A 1.0;POLYGON Z ((354846.9 6689562.1 41.4, 354849.1 6689564.8 41.4, 354852.7 6689569.2 41.4, 354854.3 6689571.3 41.4, 354857.8 6689575.4 41.4, 354868.1 6689566.7 41.4, 354868.4 6689566.4 41.4, 354855.4 6689550.7 41.4, 354856.5 6689549.8 41.4, 354847.9 6689539.4 41.4, 354847.7 6689539.7 41.4, 354845.8 6689542.1 41.4, 354838.7 6689552 41.4, 354846.9 6689562.1 41.4))
BATIMENT0000000302928196;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.2;25.7;38.0;40.0;27.6;Cadastre;C 0.8;POLYGON Z ((354819.5 6689568.3 38, 354829.2 6689557.3 38, 354820.8 6689547.2 38, 354811.7 6689557.9 38, 354810 6689559.9 38, 354819.5 6689568.3 38))
BATIMENT0000000302928194;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;9.3;25.3;34.7;40.5;27.2;Cadastre;A 1.0;POLYGON Z ((354814.8 6689574 34.7, 354825.3 6689577.6 34.7, 354826.9 6689578.1 34.7, 354836.5 6689566.1 34.7, 354829.2 6689557.3 34.7, 354819.5 6689568.3 34.7, 354814.8 6689574 34.7), (354823.4 6689566.7 34.7, 354827.5 6689570.1 34.7, 354825.2 6689572.6 34.7, 354821.5 6689569.5 34.7, 354823.4 6689566.7 34.7))
BATIMENT0000000302929216;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.4;21.6;36.0;38.9;22.0;Cadastre;;POLYGON Z ((354975.7 6689520.2 36, 354966.8 6689514.1 36, 354953.8 6689533.1 36, 354962.8 6689539.2 36, 354975.7 6689520.2 36))
BATIMENT0000000302930214;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.2;20.9;22.1;;;Cadastre;;POLYGON Z ((355028.5 6689522.8 22.1, 355025.4 6689527.6 22.1, 355033.3 6689533 22.1, 355038 6689529.7 22.1, 355028.5 6689522.8 22.1))
BATIMENT0000000302930209;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.0;18.9;28.0;29.7;19.6;Cadastre;;POLYGON Z ((355008.4 6689527.5 28, 355007.1 6689529.3 28, 355013.4 6689533.6 28, 355014.7 6689531.8 28, 355008.4 6689527.5 28))
BATIMENT0000000302931869;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;18.8;25.7;29.2;19.2;Cadastre;;POLYGON Z ((355025.6 6689546.8 25.7, 355026.9 6689545 25.7, 355030 6689540.5 25.7, 355031.2 6689538.9 25.7, 355016.6 6689528.9 25.7, 355014.7 6689531.8 25.7, 355013.4 6689533.6 25.7, 355011.1 6689536.9 25.7, 355025.6 6689546.8 25.7))
BATIMENT0000000302929218;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.8;21.9;31.7;33.2;22.7;Cadastre;;POLYGON Z ((354991.9 6689559 31.7, 354999.8 6689564.3 31.7, 355002.5 6689560.8 31.7, 355012.9 6689545.6 31.7, 355001.3 6689537.7 31.7, 354975.7 6689520.2 31.7, 354962.8 6689539.2 31.7, 354973.4 6689546.5 31.7, 354991.9 6689559 31.7))
BATIMENT0000000302931870;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;18.8;22.1;24.1;20.7;Cadastre;;POLYGON Z ((355029.4 6689547 22.1, 355034.1 6689550 22.1, 355034.8 6689549 22.1, 355038.4 6689543.7 22.1, 355041.6 6689538.9 22.1, 355038.7 6689536.9 22.1, 355037 6689535.7 22.1, 355032.6 6689542.3 22.1, 355030 6689540.5 22.1, 355026.9 6689545 22.1, 355029.5 6689546.7 22.1, 355029.4 6689547 22.1))
BATIMENT0000000302927542;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;16.9;21.7;38.7;41.4;22.5;Cadastre;C 0.4;POLYGON Z ((354940.8 6689551.6 38.7, 354966.1 6689569 38.7, 354971.4 6689560.9 38.7, 354961.3 6689554.1 38.7, 354963.5 6689551 38.7, 354963.3 6689550.1 38.7, 354961.6 6689548.8 38.7, 354962.9 6689546.9 38.7, 354969.9 6689551.6 38.7, 354973.4 6689546.5 38.7, 354962.8 6689539.2 38.7, 354953.8 6689533.1 38.7, 354940.8 6689551.6 38.7))
BATIMENT0000000302929217;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;21.8;25.2;28.2;22.6;Cadastre;;POLYGON Z ((355002.9 6689566.4 25.2, 355005.4 6689562.7 25.2, 355002.5 6689560.8 25.2, 354999.8 6689564.3 25.2, 355002.9 6689566.4 25.2))
BATIMENT0000000302929215;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1846-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;;;16.1;21.9;38.0;40.7;23.2;Cadastre;C 0.1;POLYGON Z ((354940 6689579.2 38, 354957.1 6689590.9 38, 354960 6689586.6 38, 354956.5 6689584.1 38, 354963.4 6689574.3 38, 354967.7 6689577.1 38, 354970.9 6689572.3 38, 354966.1 6689569 38, 354940.8 6689551.6 38, 354937.9 6689556 38, 354948 6689563.1 38, 354940.8 6689573.4 38, 354930.8 6689566.2 38, 354927.7 6689570.7 38, 354940 6689579.2 38))
BATIMENT0000000302927540;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;22.2;27.4;28.2;22.7;Cadastre;;POLYGON Z ((354996 6689589.5 27.4, 355009 6689570.6 27.4, 355002.9 6689566.4 27.4, 354999.8 6689564.3 27.4, 354991.9 6689559 27.4, 354979.2 6689578.1 27.4, 354985.9 6689582.6 27.4, 354996 6689589.5 27.4))
BATIMENT0000000302927557;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;6.0;10;20;20.3;22.4;42.7;46.5;24.1;Cadastre;C 0.9;POLYGON Z ((354930.1 6689550.1 42.7, 354910.1 6689537.8 42.7, 354909.9 6689537.7 42.7, 354908 6689540.2 42.7, 354904.3 6689537.5 42.7, 354906 6689535.3 42.7, 354897.4 6689529.9 42.7, 354891.3 6689538.3 42.7, 354905.4 6689548 42.7, 354908 6689547.6 42.7, 354908.9 6689546.4 42.7, 354911.5 6689548.1 42.7, 354899.7 6689564.9 42.7, 354897 6689563.1 42.7, 354898 6689561.7 42.7, 354897.6 6689559.4 42.7, 354883.3 6689549.6 42.7, 354876.3 6689559.7 42.7, 354882.4 6689563.3 42.7, 354884.9 6689564.7 42.7, 354887.4 6689561.4 42.7, 354891.6 6689564.2 42.7, 354889.3 6689567.3 42.7, 354893.4 6689569.6 42.7, 354895.1 6689570.6 42.7, 354897.7 6689572.1 42.7, 354910 6689579.3 42.7, 354930.1 6689550.1 42.7))
BATIMENT0000000302927564;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;23.5;36.0;37.2;25.1;Cadastre;;POLYGON Z ((354874.9 6689572 36, 354876 6689573 36, 354876.8 6689572.1 36, 354875.6 6689571.2 36, 354874.9 6689572 36))
BATIMENT0000000302927566;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;22.8;28.4;41.3;25.1;Cadastre;;POLYGON Z ((354875.6 6689571.2 28.4, 354876.8 6689572.1 28.4, 354886 6689578.3 28.4, 354884.8 6689580 28.4, 354887.3 6689581.7 28.4, 354888.7 6689579.8 28.4, 354887 6689578.6 28.4, 354893.4 6689569.6 28.4, 354889.3 6689567.3 28.4, 354884.9 6689564.7 28.4, 354882.4 6689563.3 28.4, 354876.9 6689569.8 28.4, 354875.6 6689571.2 28.4))
BATIMENT0000000302927558;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;00;00;20.7;23.0;43.7;45.8;23.6;Cadastre;A 1.0;POLYGON Z ((354910 6689579.3 43.7, 354897.7 6689572.1 43.7, 354891.6 6689580.5 43.7, 354890.7 6689579.8 43.7, 354891 6689579.3 43.7, 354889.6 6689578.3 43.7, 354895.1 6689570.6 43.7, 354893.4 6689569.6 43.7, 354887 6689578.6 43.7, 354888.7 6689579.8 43.7, 354887.3 6689581.7 43.7, 354887.2 6689582 43.7, 354889 6689583.2 43.7, 354893.2 6689586.1 43.7, 354901.5 6689591.7 43.7, 354910 6689579.3 43.7))
BATIMENT0000000302927561;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.9;23.3;43.2;46.2;23.6;Cadastre;;POLYGON Z ((354885.4 6689582.7 43.2, 354888 6689584.5 43.2, 354886.9 6689586.1 43.2, 354891.2 6689589 43.2, 354893.2 6689586.1 43.2, 354889 6689583.2 43.2, 354887.2 6689582 43.2, 354886.9 6689582.3 43.2, 354886.2 6689581.7 43.2, 354885.4 6689582.7 43.2))
BATIMENT0000000302927538;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;19.1;22.5;41.7;44.0;23.3;Cadastre;A 1.0;POLYGON Z ((354916 6689587.7 41.7, 354943 6689606.4 41.7, 354946.5 6689601.1 41.7, 354931.2 6689590.6 41.7, 354938.7 6689579.6 41.7, 354939.4 6689580.1 41.7, 354940 6689579.2 41.7, 354927.7 6689570.7 41.7, 354916 6689587.7 41.7))
BATIMENT0000000302927563;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;10;20;20.2;23.2;43.5;46.6;23.7;Cadastre;A 1.0;POLYGON Z ((354893 6689604 43.5, 354901.5 6689591.7 43.5, 354893.2 6689586.1 43.5, 354891.2 6689589 43.5, 354886.9 6689586.1 43.5, 354888 6689584.5 43.5, 354885.4 6689582.7 43.5, 354878.1 6689593.6 43.5, 354893 6689604 43.5))
BATIMENT0000000302927539;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;12;20;19.7;23.0;42.8;46.1;23.9;Cadastre;A 1.0;POLYGON Z ((354901 6689609.6 42.8, 354928.7 6689628.6 42.8, 354930 6689626.8 42.8, 354934.8 6689619.7 42.8, 354943.4 6689606.8 42.8, 354943 6689606.4 42.8, 354916 6689587.7 42.8, 354901 6689609.6 42.8), (354922.5 6689598.7 42.8, 354935.9 6689607.6 42.8, 354930.8 6689615.4 42.8, 354920.7 6689608.6 42.8, 354922 6689606.5 42.8, 354923.3 6689606.3 42.8, 354924.5 6689604.4 42.8, 354924.2 6689603.1 42.8, 354921 6689601.2 42.8, 354922.5 6689598.7 42.8))
BATIMENT0000000302927733;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;00;00;18.5;23.5;42.1;44.9;24.8;Cadastre;A 1.0;POLYGON Z ((354922.7 6689636.4 42.1, 354912.4 6689651.8 42.1, 354912.2 6689651.6 42.1, 354904.3 6689663.3 42.1, 354917.7 6689671.1 42.1, 354925.4 6689659.5 42.1, 354926.2 6689658.6 42.1, 354930.3 6689657.4 42.1, 354933.1 6689659 42.1, 354934.2 6689656.5 42.1, 354940.1 6689646.2 42.1, 354922.7 6689636.4 42.1))
BATIMENT0000000302927734;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;12;23;20.4;23.6;44.0;45.6;24.4;Cadastre;A 1.0;POLYGON Z ((354948.6 6689672 44, 354945.3 6689661.4 44, 354950.4 6689652 44, 354940.1 6689646.2 44, 354934.2 6689656.5 44, 354936 6689657.1 44, 354935 6689659.3 44, 354936.1 6689662.9 44, 354934.2 6689663.7 44, 354937.8 6689675.2 44, 354948.6 6689672 44))
BATIMENT0000000302929214;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;20.7;27.9;29.4;23.1;Cadastre;;POLYGON Z ((354957.1 6689590.9 27.9, 354959 6689592.2 27.9, 354967.9 6689598.4 27.9, 354972.9 6689601.7 27.9, 354985.9 6689582.6 27.9, 354979.2 6689578.1 27.9, 354970.9 6689572.3 27.9, 354967.7 6689577.1 27.9, 354963.4 6689574.3 27.9, 354956.5 6689584.1 27.9, 354960 6689586.6 27.9, 354957.1 6689590.9 27.9))
BATIMENT0000000302927537;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;21.6;27.8;30.0;23.6;Cadastre;;POLYGON Z ((354966.6 6689600.9 27.8, 354965.1 6689603.7 27.8, 354980.9 6689612.4 27.8, 354981.3 6689611.9 27.8, 354981 6689611.7 27.8, 354983 6689608.6 27.8, 354980.5 6689606.8 27.8, 354966.6 6689600.9 27.8))
BATIMENT0000000302929242;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.6;21.0;33.6;39.4;24.5;Cadastre;;POLYGON Z ((354937.6 6689631 33.6, 354937.5 6689631.3 33.6, 354940.8 6689633.1 33.6, 354940.9 6689632.9 33.6, 354954.8 6689640.8 33.6, 354954.6 6689641.1 33.6, 354962.7 6689645.6 33.6, 354962.8 6689645.4 33.6, 354976.7 6689653.2 33.6, 354979.8 6689655.1 33.6, 354979.9 6689654.9 33.6, 354987.4 6689659.1 33.6, 355004.7 6689654.2 33.6, 355002.2 6689645.6 33.6, 354988.1 6689649.8 33.6, 354984.2 6689647.5 33.6, 354990.5 6689636.1 33.6, 354991.2 6689636.5 33.6, 354990.7 6689637.3 33.6, 354993.7 6689638.9 33.6, 354999.8 6689637.3 33.6, 354998.4 6689632 33.6, 355007.5 6689626.6 33.6, 355012.5 6689617.3 33.6, 355003.9 6689612.5 33.6, 355005.6 6689609.7 33.6, 355007.2 6689608.2 33.6, 355010.3 6689611.6 33.6, 355011.2 6689612.1 33.6, 355012.4 6689612.2 33.6, 355013.5 6689611.7 33.6, 355014.1 6689611 33.6, 355014.5 6689609.8 33.6, 355014.3 6689608.8 33.6, 355012.7 6689606.9 33.6, 355014.1 6689605.5 33.6, 355015.9 6689607.2 33.6, 355016.2 6689606.9 33.6, 355021.9 6689605.5 33.6, 355021.1 6689602.3 33.6, 355026.7 6689600.9 33.6, 355025.9 6689597.8 33.6, 355030.7 6689593.1 33.6, 355035.5 6689598.3 33.6, 355036.3 6689597.7 33.6, 355054.6 6689580.6 33.6, 355043.1 6689568.4 33.6, 355041.1 6689569.6 33.6, 355038.3 6689572.2 33.6, 355037.8 6689571.7 33.6, 355036.6 6689571.3 33.6, 355035.1 6689571.8 33.6, 355027.7 6689582.1 33.6, 355025.4 6689579.7 33.6, 355026.1 6689578.7 33.6, 355026.5 6689577.1 33.6, 355026.3 6689576.2 33.6, 355025.6 6689574.7 33.6, 355024.6 6689573.9 33.6, 355023.8 6689573.6 33.6, 355022.9 6689573.5 33.6, 355021.3 6689573.8 33.6, 355020.2 6689574.5 33.6, 355019.7 6689575.2 33.6, 355019.2 6689576.4 33.6, 355019.2 6689577.2 33.6, 355019.4 6689578.5 33.6, 355020.1 6689579.6 33.6, 355018.6 6689581 33.6, 355018.1 6689580.7 33.6, 355016.9 6689580.4 33.6, 355015.8 6689580.6 33.6, 355014.8 6689581.3 33.6, 355006.9 6689592.1 33.6, 355004 6689594.8 33.6, 355009.2 6689600.2 33.6, 355007.7 6689601.6 33.6, 355006 6689600.5 33.6, 355003.9 6689600.2 33.6, 355002 6689600.8 33.6, 355000.7 6689601.8 33.6, 355000 6689602.8 33.6, 354999.4 6689604.8 33.6, 354999.6 6689606.4 33.6, 355000.3 6689607.9 33.6, 355001.7 6689609.3 33.6, 355000.9 6689610.7 33.6, 354993.8 6689606.7 33.6, 354988 6689617.2 33.6, 354988.7 6689617.5 33.6, 354974.9 6689642.2 33.6, 354967.2 6689637.9 33.6, 354968 6689636.3 33.6, 354968.2 6689634.8 33.6, 354968 6689633.6 33.6, 354967.3 6689632.2 33.6, 354965.5 6689630.7 33.6, 354963.5 6689630.2 33.6, 354961.9 6689630.4 33.6, 354960.8 6689630.9 33.6, 354959.9 6689631.7 33.6, 354958.9 6689633.1 33.6, 354951.1 6689628.8 33.6, 354965.1 6689603.7 33.6, 354966.6 6689600.9 33.6, 354967.9 6689598.4 33.6, 354959 6689592.2 33.6, 354949.4 6689609.7 33.6, 354948.7 6689609.3 33.6, 354949.2 6689608.5 33.6, 354946.2 6689606.9 33.6, 354944 6689610.9 33.6, 354947 6689612.5 33.6, 354947.4 6689611.8 33.6, 354948.1 6689612.2 33.6, 354941.8 6689623.6 33.6, 354934.8 6689619.7 33.6, 354930 6689626.8 33.6, 354937.6 6689631 33.6))
BATIMENT0000000302930222;Indifférenciée;Industriel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.1;22.7;26.8;38.5;23.3;Cadastre;A 1.0;POLYGON Z ((355034.6 6689647.9 26.8, 355031.4 6689636.6 26.8, 355029.8 6689637.1 26.8, 355028.2 6689630.7 26.8, 355027.5 6689630.9 26.8, 355026.4 6689633.8 26.8, 355026.6 6689634.1 26.8, 355022.6 6689635.1 26.8, 355023.3 6689637.7 26.8, 355022.6 6689637.8 26.8, 355024.2 6689642.6 26.8, 355030.9 6689640.7 26.8, 355033.1 6689648.4 26.8, 355034.6 6689647.9 26.8))
BATIMENT0000000302930221;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;18.5;21.8;40.4;44.1;23.4;Cadastre;A 1.0;POLYGON Z ((355020.8 6689630.2 40.4, 355005.4 6689634.6 40.4, 355008.2 6689644.6 40.4, 355006.7 6689645 40.4, 355009.3 6689655.1 40.4, 355033.1 6689648.4 40.4, 355030.9 6689640.7 40.4, 355024.2 6689642.6 40.4, 355022.6 6689637.8 40.4, 355020.8 6689630.2 40.4))
BATIMENT0000000302927735;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;10;20;19.4;23.5;43.0;45.5;24.4;Cadastre;A 1.0;POLYGON Z ((354967 6689666.7 43, 354967.6 6689661.5 43, 354950.4 6689652 43, 354945.3 6689661.4 43, 354948.6 6689672 43, 354967 6689666.7 43))
BATIMENT0000000302930235;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;17.3;23.3;40.6;43.4;24.3;Cadastre;C 0.7;POLYGON Z ((355012.5 6689669.4 40.6, 355016.7 6689683.2 40.6, 355029.6 6689679.6 40.6, 355030.1 6689681.1 40.6, 355033.7 6689680.1 40.6, 355033.6 6689678.6 40.6, 355040.4 6689676.9 40.6, 355044.8 6689685.1 40.6, 355046.5 6689692.7 40.6, 355052.6 6689688.2 40.6, 355042.2 6689675.7 40.6, 355041.9 6689675.9 40.6, 355036.7 6689669.2 40.6, 355035 6689663.1 40.6, 355012.5 6689669.4 40.6))
BATIMENT0000000302929175;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;10;20;19.9;23.6;43.5;47.0;24.2;Cadastre;C 0.7;POLYGON Z ((354985.6 6689692.9 43.5, 354990.3 6689697.9 43.5, 354992.8 6689696.9 43.5, 354990.6 6689690.4 43.5, 354997.5 6689688.3 43.5, 354997.8 6689689 43.5, 354998.7 6689689.4 43.5, 355002.2 6689688.4 43.5, 355003.1 6689687.8 43.5, 355002.9 6689686.9 43.5, 355010.3 6689684.7 43.5, 355012.5 6689692.2 43.5, 355018.7 6689690.2 43.5, 355016.7 6689683.2 43.5, 355012.5 6689669.4 43.5, 354977.2 6689679.6 43.5, 354978.6 6689685.3 43.5, 354985.6 6689692.9 43.5))
BATIMENT0000000302927725;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;13;10;17.8;23.9;41.7;44.6;24.7;Cadastre;A 1.0;POLYGON Z ((354953.2 6689686.4 41.7, 354953.1 6689687.4 41.7, 354952.7 6689687.5 41.7, 354953.2 6689689.7 41.7, 354964.3 6689700.2 41.7, 354969.5 6689694.6 41.7, 354965.3 6689690.4 41.7, 354966.9 6689689.8 41.7, 354970.7 6689693.4 41.7, 354978.6 6689685.3 41.7, 354977.2 6689679.6 41.7, 354953.2 6689686.4 41.7))
BATIMENT0000000302927726;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;20;20;14.2;23.1;37.3;44.0;25.0;Cadastre;A 1.0;POLYGON Z ((354971.9 6689707.1 37.3, 354980.9 6689697.6 37.3, 354985.6 6689692.9 37.3, 354978.6 6689685.3 37.3, 354970.7 6689693.4 37.3, 354969.5 6689694.6 37.3, 354964.3 6689700.2 37.3, 354971.9 6689707.1 37.3))
BATIMENT0000000302927556;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;14;30;17.0;23.7;40.7;44.5;25.6;Cadastre;A 1.0;POLYGON Z ((354864.6 6689583.6 40.7, 354873.8 6689573.4 40.7, 354874.9 6689572 40.7, 354875.6 6689571.2 40.7, 354876.9 6689569.8 40.7, 354875 6689568 40.7, 354871.9 6689571.1 40.7, 354868.1 6689566.7 40.7, 354857.8 6689575.4 40.7, 354864.6 6689583.6 40.7))
BATIMENT0000000302928192;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;14;20;16.8;24.6;41.5;43.9;26.3;Cadastre;A 1.0;POLYGON Z ((354852 6689584.7 41.5, 354836.5 6689566.1 41.5, 354826.9 6689578.1 41.5, 354825.5 6689583.1 41.5, 354830.4 6689584.1 41.5, 354831.5 6689580.4 41.5, 354832.2 6689579.1 41.5, 354834.2 6689581.3 41.5, 354831.9 6689584.5 41.5, 354841 6689586.8 41.5, 354847.7 6689588.4 41.5, 354852 6689584.7 41.5))
BATIMENT0000000302928193;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.7;26.0;33.8;35.0;27.0;Cadastre;C 0.3;POLYGON Z ((354823.9 6689582.4 33.8, 354825.3 6689577.6 33.8, 354814.8 6689574 33.8, 354813.2 6689580 33.8, 354823.9 6689582.4 33.8))
BATIMENT0000000302927565;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;20.1;23.4;43.5;46.7;24.9;Cadastre;B 0.3;POLYGON Z ((354866 6689585.3 43.5, 354878.1 6689593.6 43.5, 354885.4 6689582.7 43.5, 354886.2 6689581.7 43.5, 354873.8 6689573.4 43.5, 354864.6 6689583.6 43.5, 354866 6689585.3 43.5))
BATIMENT0000002011294418;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;2015-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;5.2;25.7;;32.1;26.5;Imagerie aérienne;C 0.3;POLYGON Z ((354815.2 6689592.2 30.9, 354803.1 6689591.5 30.9, 354799.2 6689597.3 30.9, 354799.1 6689607.4 30.9, 354810.3 6689610.5 30.9, 354820.2 6689608.6 30.9, 354821.9 6689599.8 30.9, 354815.2 6689592.2 30.9))
BATIMENT0000000302928195;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;4.0;00;00;16.5;24.6;41.2;46.5;30.6;Cadastre;C 0.6;POLYGON Z ((354756.1 6689601.5 41.2, 354754 6689610.2 41.2, 354752.9 6689615.6 41.2, 354831.4 6689634.1 41.2, 354841.3 6689619.3 41.2, 354841.6 6689619.4 41.2, 354849.3 6689608.1 41.2, 354849.1 6689607.9 41.2, 354858.9 6689593.2 41.2, 354852 6689584.7 41.2, 354847.7 6689588.4 41.2, 354849.2 6689590.6 41.2, 354847.9 6689592.5 41.2, 354840 6689590.4 41.2, 354841 6689586.8 41.2, 354831.9 6689584.5 41.2, 354830.4 6689584.1 41.2, 354825.5 6689583.1 41.2, 354823.9 6689582.4 41.2, 354813.2 6689580 41.2, 354799 6689576.7 41.2, 354791 6689574.5 41.2, 354785.9 6689573.4 41.2, 354784.8 6689573.1 41.2, 354763.9 6689568.2 41.2, 354762.9 6689573 41.2, 354762.7 6689573.7 41.2, 354775.7 6689576.9 41.2, 354775.6 6689577.3 41.2, 354826.9 6689590 41.2, 354827 6689589.3 41.2, 354831 6689590.4 41.2, 354830.9 6689591 41.2, 354830.6 6689592.6 41.2, 354831.7 6689592.8 41.2, 354832.4 6689593.3 41.2, 354833.1 6689593.7 41.2, 354833.8 6689594.2 41.2, 354834.5 6689594.7 41.2, 354835.1 6689595.3 41.2, 354835.9 6689596 41.2, 354836.5 6689596.8 41.2, 354837.1 6689597.6 41.2, 354837.6 6689598.5 41.2, 354838 6689599.4 41.2, 354838.4 6689600.4 41.2, 354838.6 6689601.4 41.2, 354838.8 6689602.3 41.2, 354838.9 6689603.4 41.2, 354839 6689604.3 41.2, 354838.9 6689605.2 41.2, 354838.8 6689606.1 41.2, 354838.6 6689607.1 41.2, 354838.4 6689608 41.2, 354838.1 6689608.8 41.2, 354837.7 6689609.7 41.2, 354837.2 6689610.5 41.2, 354836.6 6689611.4 41.2, 354836 6689612.2 41.2, 354835.2 6689613 41.2, 354834.5 6689613.7 41.2, 354833.6 6689614.4 41.2, 354832.7 6689615 41.2, 354831.8 6689615.5 41.2, 354830.8 6689616 41.2, 354829.8 6689616.2 41.2, 354828.8 6689616.4 41.2, 354827.8 6689616.5 41.2, 354826.8 6689616.6 41.2, 354825.7 6689616.7 41.2, 354824.9 6689616.5 41.2, 354824.5 6689617.8 41.2, 354756.1 6689601.5 41.2))
BATIMENT0000000302928328;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.0;25.5;42.5;46.2;27.3;Cadastre;C 0.2;POLYGON Z ((354808.6 6689719.2 42.5, 354808.2 6689719.8 42.5, 354823.6 6689730.1 42.5, 354823.7 6689729.5 42.5, 354839.8 6689740 42.5, 354874.4 6689688.7 42.5, 354858.7 6689678.2 42.5, 354861 6689674.8 42.5, 354857.2 6689672 42.5, 354856.7 6689672.6 42.5, 354849.5 6689667.8 42.5, 354850 6689667 42.5, 354845.9 6689664.2 42.5, 354843.5 6689667.6 42.5, 354827.3 6689656.9 42.5, 354792.9 6689708.4 42.5, 354808.6 6689719.2 42.5), (354851.5 6689704.7 42.5, 354838.2 6689724.2 42.5, 354831 6689719.1 42.5, 354844.2 6689699.8 42.5, 354851.5 6689704.7 42.5), (354819 6689703.4 42.5, 354815.9 6689708.6 42.5, 354808.4 6689703.8 42.5, 354811.8 6689698.3 42.5, 354819 6689703.4 42.5))
BATIMENT0000000302929145;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;27.0;;;;Cadastre;;POLYGON Z ((354829.8 6689764 -1000, 354834.6 6689765.6 -1000, 354836.7 6689758.8 -1000, 354831.9 6689757.1 -1000, 354829.8 6689764 -1000))
BATIMENT0000000302927914;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;13.3;26.8;40.1;48.1;27.6;Cadastre;A 1.0;POLYGON Z ((354796.1 6689782.8 40.1, 354798.3 6689771.5 40.1, 354791.9 6689769.9 40.1, 354792.8 6689765.4 40.1, 354796.5 6689766.1 40.1, 354796.1 6689768.6 40.1, 354796.5 6689770 40.1, 354798.6 6689770.3 40.1, 354800.2 6689762.5 40.1, 354789.4 6689759.3 40.1, 354788.6 6689764 40.1, 354787.3 6689770.1 40.1, 354785.4 6689780.8 40.1, 354796.1 6689782.8 40.1))
BATIMENT0000000302927915;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;8.0;34;20;22.4;26.3;48.7;52.2;26.9;Cadastre;A 1.0;POLYGON Z ((354822.4 6689787.7 48.7, 354832.5 6689777.5 48.7, 354830.7 6689772.3 48.7, 354800.2 6689762.5 48.7, 354798.6 6689770.3 48.7, 354798.3 6689771.5 48.7, 354796.1 6689782.8 48.7, 354822.4 6689787.7 48.7))
BATIMENT0000000302927732;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;6.0;10;20;17.5;24.5;42.0;;;Cadastre;A 1.0;POLYGON Z ((354937.8 6689675.2 42, 354934.2 6689663.7 42, 354933.1 6689659 42, 354930.3 6689657.4 42, 354926.2 6689658.6 42, 354925.4 6689659.5 42, 354926.9 6689664.3 42, 354924.3 6689665.3 42, 354924.7 6689667.3 42, 354923.4 6689667.7 42, 354919.9 6689672.6 42, 354927.8 6689678.3 42, 354937.8 6689675.2 42))
BATIMENT0000000302927731;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;;;16.8;24.5;41.3;45.3;25.1;Cadastre;A 1.0;POLYGON Z ((354893.9 6689678.8 41.3, 354911.6 6689694.6 41.3, 354927.8 6689678.3 41.3, 354919.9 6689672.6 41.3, 354916.2 6689676.6 41.3, 354912.9 6689679.9 41.3, 354911.7 6689682.3 41.3, 354910.4 6689681.6 41.3, 354911.1 6689680.6 41.3, 354911.2 6689679.8 41.3, 354909.6 6689678.5 41.3, 354908.8 6689678.6 41.3, 354908.4 6689679.2 41.3, 354906.8 6689678.2 41.3, 354912.9 6689672 41.3, 354916.7 6689674.2 41.3, 354918.6 6689671.6 41.3, 354917.7 6689671.1 41.3, 354904.3 6689663.3 41.3, 354893.9 6689678.8 41.3))
BATIMENT0000000302927671;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;13.8;24.0;37.8;41.4;24.8;Cadastre;A 1.0;POLYGON Z ((354941 6689690.3 37.8, 354939.6 6689690.1 37.8, 354923.3 6689705 37.8, 354923.4 6689706.2 37.8, 354931.2 6689712.9 37.8, 354939.2 6689704.9 37.8, 354943.9 6689700.2 37.8, 354947.6 6689696.6 37.8, 354941 6689690.3 37.8))
BATIMENT0000000302927669;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;13.1;24.0;37.1;40.7;25.1;Cadastre;C 0.6;POLYGON Z ((354939.7 6689720.8 37.1, 354947.4 6689712.4 37.1, 354939.2 6689704.9 37.1, 354931.2 6689712.9 37.1, 354939.7 6689720.8 37.1))
BATIMENT0000000302927667;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;13.5;24.0;37.5;43.5;25.1;Cadastre;B 0.6;POLYGON Z ((354947.6 6689728.1 37.5, 354955.5 6689720.1 37.5, 354947.4 6689712.4 37.5, 354939.7 6689720.8 37.5, 354947.6 6689728.1 37.5))
BATIMENT0000000302927722;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;15.0;24.6;39.7;42.8;25.4;Cadastre;A 1.0;POLYGON Z ((354915.6 6689711 39.7, 354910.9 6689715.9 39.7, 354924.1 6689732.2 39.7, 354925.2 6689730.7 39.7, 354923.8 6689729.2 39.7, 354924.2 6689728.4 39.7, 354929.3 6689733.4 39.7, 354927.2 6689735.8 39.7, 354930.4 6689739.9 39.7, 354937.7 6689731.4 39.7, 354915.6 6689711 39.7))
BATIMENT0000000302927723;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;16.9;24.7;41.7;44.3;25.8;Cadastre;A 1.0;POLYGON Z ((354903.1 6689723.7 41.7, 354921.9 6689750.5 41.7, 354927.4 6689746.8 41.7, 354929.4 6689745.4 41.7, 354932.6 6689743 41.7, 354930.4 6689739.9 41.7, 354927.2 6689735.8 41.7, 354924.1 6689732.2 41.7, 354910.9 6689715.9 41.7, 354903.1 6689723.7 41.7))
BATIMENT0000000302927674;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;10;20;8.0;26.1;34.1;;;Cadastre;A 1.0;POLYGON Z ((354895.2 6689749.1 34.1, 354895.6 6689748.7 34.1, 354898.7 6689753.1 34.1, 354900 6689752.2 34.1, 354909.2 6689745.8 34.1, 354898.9 6689731.2 34.1, 354896.1 6689731.1 34.1, 354887.2 6689740.3 34.1, 354895.2 6689749.1 34.1))
BATIMENT0000000302927721;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;13.3;24.7;38.0;42.9;25.7;Cadastre;A 1.0;POLYGON Z ((354937.7 6689731.4 38, 354930.4 6689739.9 38, 354932.6 6689743 38, 354934.9 6689745.6 38, 354937.1 6689743.7 38, 354938.3 6689745.1 38, 354938.5 6689745.3 38, 354938.9 6689745.4 38, 354939.1 6689745.5 38, 354939.3 6689745.5 38, 354939.5 6689745.5 38, 354939.9 6689745.4 38, 354940.1 6689745.4 38, 354940.3 6689745.4 38, 354940.5 6689745.5 38, 354941 6689746.3 38, 354937.7 6689749.2 38, 354943.9 6689756.9 38, 354947 6689753.6 38, 354949.5 6689750.6 38, 354948.5 6689749.3 38, 354952.3 6689745 38, 354937.7 6689731.4 38))
BATIMENT0000000302927719;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;56;30;13.7;25.2;39.0;40.0;25.9;Cadastre;A 1.0;POLYGON Z ((354921.9 6689750.5 39, 354926.2 6689756.6 39, 354931.2 6689752.8 39, 354930.4 6689751.5 39, 354932.4 6689749.8 39, 354936.1 6689747.2 39, 354934.9 6689745.6 39, 354932.6 6689743 39, 354929.4 6689745.4 39, 354931.1 6689747.9 39, 354929 6689749.4 39, 354927.4 6689746.8 39, 354921.9 6689750.5 39))
BATIMENT0000000302930237;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;22.8;28.2;30.5;24.9;Cadastre;;POLYGON Z ((355023.8 6689707.8 28.2, 355024.8 6689708 28.2, 355026.1 6689709.5 28.2, 355031.4 6689704.5 28.2, 355031.9 6689704.7 28.2, 355045 6689693.7 28.2, 355042.5 6689687.1 28.2, 355019.8 6689694.1 28.2, 355021.9 6689701.3 28.2, 355027.2 6689699.4 28.2, 355028.7 6689701.6 28.2, 355023.7 6689706.4 28.2, 355023.8 6689707.8 28.2))
BATIMENT0000000302927724;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;23.7;35.5;37.7;24.5;Cadastre;;POLYGON Z ((354990.3 6689697.9 35.5, 354991.8 6689699.9 35.5, 354993.8 6689699.6 35.5, 354992.8 6689696.9 35.5, 354990.3 6689697.9 35.5))
BATIMENT0000000302927670;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;24.3;29.0;30.7;24.7;Cadastre;;POLYGON Z ((354947.6 6689696.6 29, 354943.9 6689700.2 29, 354945.1 6689701.2 29, 354945.8 6689700.4 29, 354952.9 6689706.8 29, 354955.5 6689703.8 29, 354947.6 6689696.6 29))
BATIMENT0000000302931818;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;23.7;31.7;36.6;25.1;Cadastre;;POLYGON Z ((355019.8 6689709.3 31.7, 355020.7 6689711.6 31.7, 355021.5 6689713.9 31.7, 355026.1 6689709.5 31.7, 355024.8 6689708 31.7, 355023.8 6689707.8 31.7, 355023.7 6689706.4 31.7, 355021.9 6689701.3 31.7, 355019.8 6689694.1 31.7, 355018.7 6689690.2 31.7, 355012.5 6689692.2 31.7, 355017.7 6689709.6 31.7, 355019.8 6689709.3 31.7))
BATIMENT0000000302927727;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;24.0;32.1;35.5;24.8;Cadastre;;POLYGON Z ((354992.5 6689708.4 32.1, 354996.1 6689704.6 32.1, 354991.8 6689699.9 32.1, 354987.8 6689703.9 32.1, 354992.5 6689708.4 32.1))
BATIMENT0000000302927730;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;13.5;22.9;36.4;40.5;25.1;Cadastre;A 1.0;POLYGON Z ((354983.7 6689718 36.4, 354992.5 6689708.4 36.4, 354987.8 6689703.9 36.4, 354980.9 6689697.6 36.4, 354971.9 6689707.1 36.4, 354983.7 6689718 36.4))
BATIMENT0000000302927668;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;6.4;24.0;30.4;36.2;25.1;Cadastre;B 0.3;POLYGON Z ((354955.5 6689703.8 30.4, 354952.9 6689706.8 30.4, 354952.3 6689707.4 30.4, 354960.3 6689715.3 30.4, 354963.9 6689711.5 30.4, 354955.5 6689703.8 30.4))
BATIMENT0000000302930241;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;1.5;23.9;25.5;36.1;25.3;Cadastre;C 0.3;POLYGON Z ((355005.3 6689714.9 25.5, 355008.4 6689718.2 25.5, 355014 6689713.6 25.5, 355009.1 6689707.7 25.5, 355003.2 6689712.4 25.5, 355005.3 6689714.9 25.5))
BATIMENT0000000302927729;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.3;24.6;40.0;46.2;25.3;Cadastre;;POLYGON Z ((354993.9 6689727.5 40, 355005.3 6689714.9 40, 355003.2 6689712.4 40, 354996.1 6689704.6 40, 354992.5 6689708.4 40, 354983.7 6689718 40, 354993.9 6689727.5 40))
BATIMENT0000000302930238;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;24.3;27.5;30.6;25.6;Cadastre;C 0.3;POLYGON Z ((355020.7 6689711.6 27.5, 355018.7 6689713.3 27.5, 355016.9 6689711.1 27.5, 355014 6689713.6 27.5, 355008.4 6689718.2 27.5, 355011.9 6689722.4 27.5, 355012.9 6689721.8 27.5, 355015 6689720.4 27.5, 355016.9 6689719.1 27.5, 355021.5 6689713.9 27.5, 355020.7 6689711.6 27.5))
BATIMENT0000000302927728;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;25.0;35.2;43.7;25.6;Cadastre;;POLYGON Z ((355004.7 6689737.8 35.2, 355009.5 6689732.6 35.2, 355015.8 6689725.9 35.2, 355012.9 6689721.8 35.2, 355011.9 6689722.4 35.2, 355008.4 6689718.2 35.2, 355005.3 6689714.9 35.2, 354993.9 6689727.5 35.2, 355004.7 6689737.8 35.2))
BATIMENT0000000302927666;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;00;00;16.9;23.8;40.7;44.5;25.6;Cadastre;A 1.0;POLYGON Z ((354960.3 6689715.3 40.7, 354955.5 6689720.1 40.7, 354947.6 6689728.1 40.7, 354969.7 6689748.7 40.7, 354980.3 6689737.8 40.7, 354985.9 6689731.9 40.7, 354963.9 6689711.5 40.7, 354960.3 6689715.3 40.7), (354979.2 6689736.9 40.7, 354976.7 6689739.4 40.7, 354973.7 6689736.7 40.7, 354974.4 6689736.1 40.7, 354975.4 6689735.2 40.7, 354976.4 6689734.2 40.7, 354979.2 6689736.9 40.7), (354969 6689729.4 40.7, 354965.5 6689733.1 40.7, 354963.1 6689730.9 40.7, 354965.7 6689728.2 40.7, 354966 6689728 40.7, 354969.9 6689724 40.7, 354972 6689726.2 40.7, 354969 6689729.4 40.7), (354960.5 6689718.8 40.7, 354962.2 6689720.3 40.7, 354960.6 6689721.9 40.7, 354959.5 6689723 40.7, 354956.8 6689720.6 40.7, 354959.4 6689717.9 40.7, 354960.5 6689718.8 40.7))
BATIMENT0000000302930242;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.1;25.1;47.2;50.9;25.6;Cadastre;;POLYGON Z ((355041.7 6689761.8 47.2, 355047.2 6689756.8 47.2, 355027.9 6689732.3 47.2, 355015 6689720.4 47.2, 355012.9 6689721.8 47.2, 355015.8 6689725.9 47.2, 355009.5 6689732.6 47.2, 355041.7 6689761.8 47.2))
BATIMENT0000000302927664;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;20;20;9.2;24.0;33.2;36.0;25.9;Cadastre;A 1.0;POLYGON Z ((354985.9 6689731.9 33.2, 354980.3 6689737.8 33.2, 354982 6689739.3 33.2, 354989.6 6689746.3 33.2, 354987 6689749 33.2, 354988.4 6689750.4 33.2, 354989.1 6689749.8 33.2, 354996.5 6689741.8 33.2, 354985.9 6689731.9 33.2))
BATIMENT0000000302927663;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;20;20;14.4;25.7;40.1;43.6;25.9;Cadastre;A 1.0;POLYGON Z ((354980.5 6689758.8 40.1, 354983.4 6689755.7 40.1, 354984.4 6689754.8 40.1, 354988 6689750.8 40.1, 354988.4 6689750.4 40.1, 354987 6689749 40.1, 354979.6 6689741.9 40.1, 354982 6689739.3 40.1, 354980.3 6689737.8 40.1, 354969.7 6689748.7 40.1, 354980.5 6689758.8 40.1))
BATIMENT0000000302927661;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;2.0;00;00;9.3;24.0;33.3;45.7;25.9;Cadastre;A 1.0;POLYGON Z ((354996.5 6689741.8 33.3, 354989.1 6689749.8 33.3, 355000 6689760 33.3, 355007.5 6689751.9 33.3, 354996.5 6689741.8 33.3))
BATIMENT0000000302927665;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.2;24.8;40.0;42.5;25.8;Cadastre;;POLYGON Z ((354983.4 6689755.7 40, 354985.1 6689757.3 40, 354985.7 6689756.1 40, 354984.4 6689754.8 40, 354983.4 6689755.7 40))
BATIMENT0000000302927709;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;17.6;25.1;42.7;45.7;26.0;Cadastre;A 1.0;POLYGON Z ((354952.3 6689745 42.7, 354948.5 6689749.3 42.7, 354949.5 6689750.6 42.7, 354947 6689753.6 42.7, 354950.5 6689756.6 42.7, 354946.8 6689760.6 42.7, 354948.9 6689763.1 42.7, 354950.3 6689761.5 42.7, 354950.9 6689762.2 42.7, 354950.5 6689762.6 42.7, 354951.6 6689763.5 42.7, 354951.9 6689763.1 42.7, 354953.3 6689764.8 42.7, 354951.7 6689766.8 42.7, 354953.2 6689768.7 42.7, 354964.4 6689756.4 42.7, 354952.3 6689745 42.7))
BATIMENT0000000302927662;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;00;00;15.9;24.0;39.9;46.4;25.9;Cadastre;A 1.0;POLYGON Z ((354991.9 6689769.1 39.9, 354999 6689761.2 39.9, 354988 6689750.8 39.9, 354984.4 6689754.8 39.9, 354985.7 6689756.1 39.9, 354985.1 6689757.3 39.9, 354983.4 6689755.7 39.9, 354980.5 6689758.8 39.9, 354991.9 6689769.1 39.9))
BATIMENT0000000302927717;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.8;26.2;37.0;41.1;26.2;Cadastre;;POLYGON Z ((354947.9 6689766.7 37, 354949.6 6689768.5 37, 354951.7 6689766.8 37, 354950.2 6689764.8 37, 354947.9 6689766.7 37))
BATIMENT0000000302927673;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;12.5;25.4;38.0;40.7;26.1;Cadastre;A 1.0;POLYGON Z ((354909.2 6689745.8 38, 354900 6689752.2 38, 354898.7 6689753.1 38, 354897.9 6689753.7 38, 354897.7 6689755.1 38, 354901.3 6689760.5 38, 354902.7 6689760.8 38, 354906.3 6689766.1 38, 354917.9 6689758.3 38, 354909.2 6689745.8 38))
BATIMENT0000000302927720;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;23;10.7;25.6;36.3;37.7;26.1;Cadastre;A 1.0;POLYGON Z ((354926.2 6689756.6 36.3, 354930.4 6689762.4 36.3, 354930.7 6689762.2 36.3, 354931.7 6689762.7 36.3, 354934.1 6689757.4 36.3, 354931.2 6689752.8 36.3, 354926.2 6689756.6 36.3))
BATIMENT0000000302927718;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;11.2;25.5;36.7;38.5;26.4;Cadastre;A 1.0;POLYGON Z ((354931.7 6689762.7 36.7, 354931.3 6689763.5 36.7, 354931.2 6689763.6 36.7, 354935.7 6689769.7 36.7, 354946.8 6689760.6 36.7, 354943.9 6689756.9 36.7, 354937.7 6689749.2 36.7, 354936.1 6689747.2 36.7, 354932.4 6689749.8 36.7, 354930.4 6689751.5 36.7, 354931.2 6689752.8 36.7, 354934.1 6689757.4 36.7, 354931.7 6689762.7 36.7))
BATIMENT0000000302927672;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.1;25.5;34.7;37.5;26.0;Cadastre;C 0.5;POLYGON Z ((354908.5 6689768.9 34.7, 354909.7 6689768.2 34.7, 354910.5 6689769 34.7, 354920.6 6689762.2 34.7, 354917.9 6689758.3 34.7, 354906.3 6689766.1 34.7, 354908.5 6689768.9 34.7))
BATIMENT0000000302927708;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;10.0;26.2;36.2;37.2;26.4;Cadastre;A 1.0;POLYGON Z ((354942 6689778.5 36.2, 354945.7 6689775.7 36.2, 354948.6 6689773.4 36.2, 354953.7 6689769.4 36.2, 354953.2 6689768.7 36.2, 354951.7 6689766.8 36.2, 354949.6 6689768.5 36.2, 354947.9 6689766.7 36.2, 354950.2 6689764.8 36.2, 354948.9 6689763.1 36.2, 354946.8 6689760.6 36.2, 354935.7 6689769.7 36.2, 354942 6689778.5 36.2))
BATIMENT0000000302927675;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;8.2;26.4;34.6;;;Cadastre;A 1.0;POLYGON Z ((354887.6 6689773.8 34.6, 354891.1 6689770.1 34.6, 354883.7 6689763.6 34.6, 354874.1 6689770.2 34.6, 354885.3 6689781.5 34.6, 354890 6689776.7 34.6, 354887.6 6689773.8 34.6))
BATIMENT0000000302927681;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.8;25.9;27.7;30.5;26.4;Cadastre;;POLYGON Z ((354909 6689774.8 27.7, 354903.4 6689768 27.7, 354898.1 6689771.7 27.7, 354903.3 6689779 27.7, 354908 6689775.6 27.7, 354909 6689774.8 27.7))
BATIMENT0000000302927692;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;25.9;28.3;30.2;26.5;Cadastre;;POLYGON Z ((354909 6689774.8 28.3, 354908 6689775.6 28.3, 354910.1 6689778.3 28.3, 354911.7 6689776.9 28.3, 354909.8 6689774.4 28.3, 354909 6689774.8 28.3))
BATIMENT0000000302927680;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;26.1;30.5;32.2;26.5;Cadastre;;POLYGON Z ((354906.5 6689781.5 30.5, 354910.1 6689778.3 30.5, 354908 6689775.6 30.5, 354903.3 6689779 30.5, 354905.7 6689782.2 30.5, 354906.5 6689781.5 30.5))
BATIMENT0000000302927677;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;9.7;26.0;35.7;38.4;27.5;Cadastre;C 0.9;POLYGON Z ((354929.6 6689774.9 35.7, 354925.1 6689768.5 35.7, 354908.4 6689783.7 35.7, 354907.5 6689784.5 35.7, 354910.9 6689789.3 35.7, 354911.7 6689789.1 35.7, 354913.6 6689788.8 35.7, 354920 6689783.2 35.7, 354929.6 6689774.9 35.7))
BATIMENT0000000302927706;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;15;20;10.4;25.3;35.7;43.3;26.4;Cadastre;A 1.0;POLYGON Z ((354953.7 6689769.4 35.7, 354961 6689778.4 35.7, 354973.6 6689764.9 35.7, 354964.4 6689756.4 35.7, 354953.2 6689768.7 35.7, 354953.7 6689769.4 35.7), (354961.8 6689765.2 35.7, 354964.3 6689767.4 35.7, 354964 6689767.9 35.7, 354964.7 6689768.4 35.7, 354962.8 6689770.3 35.7, 354959.6 6689767.4 35.7, 354961.8 6689765.2 35.7))
BATIMENT0000000302927660;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;6.0;00;00;20.5;24.0;44.5;47.0;26.1;Cadastre;A 1.0;POLYGON Z ((354999 6689761.2 44.5, 354991.9 6689769.1 44.5, 355006.8 6689782.9 44.5, 355013.4 6689775.7 44.5, 355014.9 6689774.1 44.5, 355016.4 6689772.6 44.5, 355022.3 6689765.8 44.5, 355007.5 6689751.9 44.5, 355000 6689760 44.5, 354999 6689761.2 44.5), (355012.3 6689769.5 44.5, 355010.3 6689772 44.5, 355007 6689768.9 44.5, 355007.2 6689768.6 44.5, 355007.4 6689768.8 44.5, 355008.2 6689768.1 44.5, 355008.7 6689767.8 44.5, 355009 6689766.4 44.5, 355012.3 6689769.5 44.5), (355004.4 6689762.4 44.5, 355005.6 6689763.6 44.5, 355003.7 6689765.8 44.5, 355001.7 6689763.7 44.5, 355003.6 6689761.7 44.5, 355004.4 6689762.4 44.5))
BATIMENT0000000302930230;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;20;8.1;25.2;33.4;38.0;25.9;Cadastre;A 1.0;POLYGON Z ((355022.3 6689765.8 33.4, 355016.4 6689772.6 33.4, 355023.4 6689779.7 33.4, 355024.4 6689778.7 33.4, 355030.1 6689772.9 33.4, 355022.3 6689765.8 33.4))
BATIMENT0000000302927701;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.5;25.5;32.1;38.0;27.0;Cadastre;A 1.0;POLYGON Z ((354973.6 6689764.9 32.1, 354961 6689778.4 32.1, 354966.8 6689785.5 32.1, 354970.7 6689782.4 32.1, 354971.6 6689781.6 32.1, 354975 6689778.8 32.1, 354975.7 6689778.2 32.1, 354977.8 6689780.7 32.1, 354978.5 6689780.9 32.1, 354985 6689775.5 32.1, 354973.6 6689764.9 32.1))
BATIMENT0000000302930231;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.3;25.4;34.7;37.0;25.9;Cadastre;;POLYGON Z ((355023.4 6689779.7 34.7, 355016.4 6689772.6 34.7, 355014.9 6689774.1 34.7, 355013.4 6689775.7 34.7, 355020.6 6689782.5 34.7, 355022 6689781 34.7, 355023.4 6689779.7 34.7))
BATIMENT0000000302927702;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;50;20;8.7;26.5;35.2;36.3;26.7;Cadastre;A 1.0;POLYGON Z ((354949.3 6689788.6 35.2, 354961 6689778.4 35.2, 354953.7 6689769.4 35.2, 354948.6 6689773.4 35.2, 354945.7 6689775.7 35.2, 354942 6689778.5 35.2, 354949.3 6689788.6 35.2))
BATIMENT0000000302927703;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;27.2;34.3;;;Cadastre;;POLYGON Z ((354971.6 6689781.6 34.3, 354972.7 6689782.9 34.3, 354976.2 6689780.2 34.3, 354975 6689778.8 34.3, 354971.6 6689781.6 34.3))
BATIMENT0000000302930233;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;11.5;24.0;35.5;40.1;25.6;Cadastre;A 1.0;POLYGON Z ((355043.5 6689785.2 35.5, 355030.1 6689772.9 35.5, 355024.4 6689778.7 35.5, 355028.1 6689782.2 35.5, 355031.7 6689785.2 35.5, 355037.6 6689790.9 35.5, 355043.5 6689785.2 35.5))
BATIMENT0000000302930232;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;20;20;15.3;24.0;39.3;43.1;25.9;Cadastre;A 1.0;POLYGON Z ((355013.9 6689789.2 39.3, 355020.6 6689782.5 39.3, 355013.4 6689775.7 39.3, 355006.8 6689782.9 39.3, 355013.9 6689789.2 39.3))
BATIMENT0000000302927705;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.0;27.0;33.0;36.6;27.3;Cadastre;A 1.0;POLYGON Z ((354954.5 6689796 33, 354956.7 6689794.1 33, 354957.9 6689793.1 33, 354965.1 6689787 33, 354966.8 6689785.5 33, 354961 6689778.4 33, 354949.3 6689788.6 33, 354954.5 6689796 33))
BATIMENT0000000302927676;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;;;9.9;26.0;36.0;47.7;27.2;Cadastre;A 1.0;POLYGON Z ((354890 6689776.7 36, 354885.3 6689781.5 36, 354896.5 6689792.7 36, 354896.4 6689793 36, 354904 6689790.9 36, 354905.3 6689790.6 36, 354910.9 6689789.3 36, 354907.5 6689784.5 36, 354905.7 6689782.2 36, 354903.3 6689779 36, 354898.1 6689771.7 36, 354896.7 6689770 36, 354890 6689776.7 36))
BATIMENT0000000302927686;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;26.3;30.0;32.2;26.6;Cadastre;;POLYGON Z ((354905.7 6689782.2 30, 354907.5 6689784.5 30, 354908.4 6689783.7 30, 354906.5 6689781.5 30, 354905.7 6689782.2 30))
BATIMENT0000000302927678;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.4;26.5;37.0;39.2;27.5;Cadastre;C 0.3;POLYGON Z ((354936.8 6689784.6 37, 354929.6 6689774.9 37, 354920 6689783.2 37, 354927.4 6689793.8 37, 354926.4 6689794.5 37, 354926.2 6689795.8 37, 354927.1 6689797.1 37, 354927.1 6689797.3 37, 354931.6 6689803.3 37, 354932.6 6689803.4 37, 354933.6 6689802.8 37, 354935 6689804.8 37, 354933.8 6689805.6 37, 354933.6 6689807.2 37, 354934.4 6689808.6 37, 354934.9 6689808.3 37, 354948.1 6689800.6 37, 354936.8 6689784.6 37))
BATIMENT0000000302927679;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;26.8;31.2;37.6;27.5;Cadastre;;POLYGON Z ((354919.3 6689794.3 31.2, 354919 6689795.6 31.2, 354929.9 6689811.3 31.2, 354934.4 6689808.6 31.2, 354933.6 6689807.2 31.2, 354933.8 6689805.6 31.2, 354935 6689804.8 31.2, 354933.6 6689802.8 31.2, 354932.6 6689803.4 31.2, 354931.6 6689803.3 31.2, 354927.1 6689797.3 31.2, 354927.1 6689797.1 31.2, 354926.2 6689795.8 31.2, 354926.4 6689794.5 31.2, 354927.4 6689793.8 31.2, 354920 6689783.2 31.2, 354913.6 6689788.8 31.2, 354919.3 6689794.3 31.2))
BATIMENT0000000302927685;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;18.0;26.7;44.7;47.9;27.7;Cadastre;A 1.0;POLYGON Z ((354890.2 6689799.3 44.7, 354902.4 6689812 44.7, 354906 6689808.3 44.7, 354910.8 6689803.7 44.7, 354904.4 6689797 44.7, 354905.3 6689796.2 44.7, 354904 6689790.9 44.7, 354896.4 6689793 44.7, 354890.2 6689799.3 44.7))
BATIMENT0000000302927683;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;26.8;29.5;33.2;27.7;Cadastre;;POLYGON Z ((354905.3 6689790.6 29.5, 354913 6689801.8 29.5, 354916.6 6689806.5 29.5, 354920.8 6689811.7 29.5, 354925 6689817.4 29.5, 354929.9 6689814 29.5, 354911.7 6689789.1 29.5, 354910.9 6689789.3 29.5, 354905.3 6689790.6 29.5))
BATIMENT0000000302927690;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.6;26.8;36.5;39.0;27.6;Cadastre;C 0.5;POLYGON Z ((354944.4 6689819.5 36.5, 354939.6 6689813 36.5, 354943.8 6689810.3 36.5, 354946.9 6689814 36.5, 354954 6689809 36.5, 354948.1 6689800.6 36.5, 354934.9 6689808.3 36.5, 354946.4 6689824.7 36.5, 354947.1 6689824.1 36.5, 354958.5 6689815.3 36.5, 354955.8 6689811.5 36.5, 354944.4 6689819.5 36.5))
BATIMENT0000000302927684;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;7.8;27.1;35.0;39.7;27.7;Cadastre;A 1.0;POLYGON Z ((354901.6 6689812.5 35, 354914 6689825.8 35, 354925 6689817.4 35, 354920.8 6689811.7 35, 354915.1 6689815.8 35, 354913.9 6689814.4 35, 354912.6 6689815.6 35, 354909.9 6689812.6 35, 354914.7 6689808.2 35, 354910.8 6689803.7 35, 354906 6689808.3 35, 354902.4 6689812 35, 354901.6 6689812.5 35))
BATIMENT0000000302927526;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;23;15.2;26.7;42.0;43.4;27.2;Cadastre;A 1.0;POLYGON Z ((354881.9 6689806.3 42, 354872.9 6689815.3 42, 354877.2 6689822.2 42, 354878.2 6689823.6 42, 354878.2 6689823.8 42, 354879.2 6689822.9 42, 354878.3 6689821.1 42, 354879.8 6689819.1 42, 354880.5 6689820 42, 354879.4 6689821.2 42, 354880.1 6689822 42, 354889.1 6689813.3 42, 354881.9 6689806.3 42))
BATIMENT0000000302927687;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;26.9;31.7;36.7;27.7;Cadastre;;POLYGON Z ((354934.9 6689808.3 31.7, 354934.4 6689808.6 31.7, 354929.9 6689811.3 31.7, 354930.9 6689813.2 31.7, 354940.8 6689827.4 31.7, 354941.5 6689828.3 31.7, 354946.4 6689824.7 31.7, 354934.9 6689808.3 31.7))
BATIMENT0000000302927704;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;26.7;34.2;37.7;27.1;Cadastre;;POLYGON Z ((354967.1 6689789.2 34.2, 354969 6689787.7 34.2, 354966.8 6689785.5 34.2, 354965.1 6689787 34.2, 354967.1 6689789.2 34.2))
BATIMENT0000000302930234;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;10;11.8;25.3;37.2;43.1;26.6;Cadastre;A 1.0;POLYGON Z ((355027 6689801.5 37.2, 355037.6 6689790.9 37.2, 355031.7 6689785.2 37.2, 355029.4 6689787.4 37.2, 355029 6689786.8 37.2, 355027.8 6689787.3 37.2, 355027 6689788.2 37.2, 355024.6 6689785.8 37.2, 355028.1 6689782.2 37.2, 355024.4 6689778.7 37.2, 355023.4 6689779.7 37.2, 355022 6689781 37.2, 355020.6 6689782.5 37.2, 355013.9 6689789.2 37.2, 355027 6689801.5 37.2))
BATIMENT0000000302927713;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;26.7;34.7;39.7;27.3;Cadastre;;POLYGON Z ((354958.7 6689796.9 34.7, 354959.9 6689795.8 34.7, 354957.9 6689793.1 34.7, 354956.7 6689794.1 34.7, 354958.7 6689796.9 34.7))
BATIMENT0000000302927707;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;4.0;10;20;13.0;25.8;38.8;42.6;27.8;Cadastre;A 1.0;POLYGON Z ((354985 6689775.5 38.8, 354978.5 6689780.9 38.8, 354977.8 6689780.7 38.8, 354972.5 6689784.7 38.8, 354970.7 6689782.4 38.8, 354966.8 6689785.5 38.8, 354969 6689787.7 38.8, 354985.9 6689807.5 38.8, 354984.1 6689809 38.8, 354988.2 6689814.8 38.8, 354989.8 6689817 38.8, 354993.8 6689813.8 38.8, 354995.6 6689812.2 38.8, 354989.6 6689804.3 38.8, 354977.5 6689789.1 38.8, 354978.6 6689788.1 38.8, 354981 6689790.8 38.8, 354986.1 6689786.9 38.8, 354993.2 6689793.9 38.8, 354989.1 6689798.7 38.8, 354990.5 6689800.6 38.8, 354989.7 6689801.7 38.8, 354990.9 6689803 38.8, 355002.7 6689791.7 38.8, 354985 6689775.5 38.8))
BATIMENT0000000302927716;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;27.2;32.2;38.7;27.4;Cadastre;;POLYGON Z ((354966.8 6689800.3 32.2, 354969.2 6689803.6 32.2, 354971.1 6689801.9 32.2, 354968.5 6689798.4 32.2, 354966.8 6689800.3 32.2))
BATIMENT0000000302927710;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;4.0;10;20;13.8;25.9;39.8;43.2;27.2;Cadastre;A 1.0;POLYGON Z ((355019.4 6689807.2 39.8, 355002.7 6689791.7 39.8, 354990.9 6689803 39.8, 354989.6 6689804.3 39.8, 354995.6 6689812.2 39.8, 355001.1 6689807.9 39.8, 355001.5 6689807.5 39.8, 355000.1 6689805.8 39.8, 355001.4 6689804.8 39.8, 355006.4 6689809.2 39.8, 355004.1 6689811.5 39.8, 355008.7 6689817.2 39.8, 355019.4 6689807.2 39.8))
BATIMENT0000000302927714;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;11.9;27.2;39.1;42.2;27.8;Cadastre;A 1.0;POLYGON Z ((354959.9 6689795.8 39.1, 354958.7 6689796.9 39.1, 354956.5 6689798.9 39.1, 354972.5 6689821.6 39.1, 354981.2 6689833.6 39.1, 354989.2 6689829.1 39.1, 354982.7 6689819 39.1, 354988.2 6689814.8 39.1, 354984.1 6689809 39.1, 354985.9 6689807.5 39.1, 354969 6689787.7 39.1, 354967.1 6689789.2 39.1, 354959.9 6689795.8 39.1), (354982.1 6689818.8 39.1, 354980.4 6689820.2 39.1, 354977.7 6689816.8 39.1, 354978.7 6689815.9 39.1, 354978 6689814.6 39.1, 354978.9 6689813.8 39.1, 354982.1 6689818.8 39.1), (354974.6 6689811.8 39.1, 354969.2 6689803.6 39.1, 354966.8 6689800.3 39.1, 354968.5 6689798.4 39.1, 354971.7 6689795.8 39.1, 354977.2 6689803 39.1, 354975.7 6689804.7 39.1, 354978.5 6689808.7 39.1, 354974.6 6689811.8 39.1))
BATIMENT0000000302927711;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;11.9;26.3;38.2;41.2;27.4;Cadastre;A 1.0;POLYGON Z ((355005.5 6689820.1 38.2, 355008.7 6689817.2 38.2, 355004.1 6689811.5 38.2, 355001.1 6689807.9 38.2, 354995.6 6689812.2 38.2, 354993.8 6689813.8 38.2, 355000.5 6689822.7 38.2, 355005.5 6689820.1 38.2))
BATIMENT0000000302927712;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;90;20;12.0;26.7;38.7;42.1;27.7;Cadastre;A 1.0;POLYGON Z ((355000.5 6689822.7 38.7, 354993.8 6689813.8 38.7, 354989.8 6689817 38.7, 354995.5 6689825.5 38.7, 355000.5 6689822.7 38.7))
BATIMENT0000000302927715;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;;;10.0;27.2;37.2;42.3;27.8;Cadastre;A 1.0;POLYGON Z ((354995.5 6689825.5 37.2, 354989.8 6689817 37.2, 354988.2 6689814.8 37.2, 354982.7 6689819 37.2, 354989.2 6689829.1 37.2, 354995.5 6689825.5 37.2))
BATIMENT0000000302927990;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;17.7;26.8;44.5;47.4;27.3;Cadastre;A 1.0;POLYGON Z ((354785.7 6689802 44.5, 354791.5 6689807.6 44.5, 354797.4 6689813.3 44.5, 354807.2 6689803.1 44.5, 354798.9 6689794.2 44.5, 354785.1 6689791.9 44.5, 354783.8 6689800 44.5, 354785.7 6689802 44.5), (354795 6689799.5 44.5, 354797.2 6689801.9 44.5, 354795.4 6689803.8 44.5, 354793.1 6689801.3 44.5, 354795 6689799.5 44.5))
BATIMENT0000000302929023;Eglise;Religieux;;Non;En service;2012-06-19 19:00:51;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;29.4;;;;Cadastre;;POLYGON Z ((354827.4 6689833.7 -1000, 354830.6 6689830.4 -1000, 354830.9 6689830.1 -1000, 354819.8 6689819 -1000, 354816.2 6689822.6 -1000, 354816.5 6689823 -1000, 354816.7 6689822.8 -1000, 354827.1 6689832.9 -1000, 354826.9 6689833.2 -1000, 354827.4 6689833.7 -1000))
BATIMENT0000000302927524;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;20;19.0;26.0;45.0;49.6;28.9;Cadastre;A 1.0;POLYGON Z ((354857.2 6689831.1 45, 354865.7 6689841.6 45, 354870.3 6689847 45, 354875.5 6689841.6 45, 354872.5 6689838.4 45, 354870.9 6689838.5 45, 354870.3 6689838.9 45, 354869.1 6689837.9 45, 354875.1 6689831.5 45, 354876.6 6689832.8 45, 354876 6689833.4 45, 354876.1 6689834.7 45, 354879.1 6689837.9 45, 354883.3 6689833.6 45, 354882.5 6689835.8 45, 354883.9 6689837.5 45, 354879.1 6689842.8 45, 354883.4 6689846.5 45, 354888.4 6689839.9 45, 354888.5 6689839.7 45, 354878.2 6689823.8 45, 354878.2 6689823.6 45, 354876.7 6689825 45, 354875.6 6689823.8 45, 354877.2 6689822.2 45, 354872.9 6689815.3 45, 354857.2 6689831.1 45))
BATIMENT0000000302927522;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;30;20;17.7;25.7;43.4;47.7;28.7;Cadastre;A 1.0;POLYGON Z ((354849.5 6689838.9 43.4, 354848 6689847.9 43.4, 354859 6689849.7 43.4, 354859.4 6689847.8 43.4, 354865.7 6689841.6 43.4, 354857.2 6689831.1 43.4, 354849.5 6689838.9 43.4))
BATIMENT0000000302929024;Eglise;Religieux;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;30.0;36.7;;;Cadastre;;POLYGON Z ((354814.3 6689825.3 36.7, 354811.1 6689822.4 36.7, 354795.3 6689839 36.7, 354794.8 6689838.7 36.7, 354785.7 6689848.6 36.7, 354791.3 6689854.1 36.7, 354794.7 6689850.5 36.7, 354801 6689856.4 36.7, 354797.5 6689860.1 36.7, 354802.7 6689865.3 36.7, 354809.6 6689871.6 36.7, 354816.9 6689863.9 36.7, 354808.2 6689854.9 36.7, 354806.6 6689853.5 36.7, 354821.3 6689838.4 36.7, 354821.5 6689838.8 36.7, 354825.2 6689834.8 36.7, 354826.9 6689833.2 36.7, 354827.1 6689832.9 36.7, 354816.7 6689822.8 36.7, 354816.5 6689823 36.7, 354814.3 6689825.3 36.7))
BATIMENT0000000302927521;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;30;12.0;27.9;40.0;45.0;28.8;Cadastre;A 1.0;POLYGON Z ((354847.1 6689853 40, 354858.4 6689855.1 40, 354858.5 6689853.5 40, 354862.1 6689854.1 40, 354862.2 6689855.7 40, 354863.2 6689855 40, 354859.1 6689850.1 40, 354859 6689849.7 40, 354848 6689847.9 40, 354847.1 6689853 40))
BATIMENT0000000302927523;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;5.1;28.2;33.4;46.0;29.5;Cadastre;A 1.0;POLYGON Z ((354845.1 6689865.3 33.4, 354857.3 6689867.9 33.4, 354857.4 6689867 33.4, 354856.5 6689866.7 33.4, 354856.7 6689865.9 33.4, 354861.4 6689867.1 33.4, 354860.8 6689868.9 33.4, 354866 6689870.2 33.4, 354870.7 6689863.7 33.4, 354863.2 6689855 33.4, 354862.2 6689855.7 33.4, 354858.4 6689855.1 33.4, 354847.1 6689853 33.4, 354845.1 6689865.3 33.4))
BATIMENT0000000302927529;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;8.3;28.6;37.0;43.5;29.7;Cadastre;A 1.0;POLYGON Z ((354844.3 6689870.4 37, 354852.1 6689877 37, 354853.5 6689876.4 37, 354861 6689877.1 37, 354866 6689870.2 37, 354860.8 6689868.9 37, 354856.4 6689874.9 37, 354852.5 6689873.2 37, 354853.1 6689870.6 37, 354854.4 6689871.6 37, 354856.5 6689872 37, 354859.2 6689868.6 37, 354857.3 6689867.9 37, 354845.1 6689865.3 37, 354844.3 6689870.4 37))
BATIMENT0000000302928255;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;15.0;28.9;44.0;48.5;29.6;Cadastre;A 1.0;POLYGON Z ((354837.1 6689876.3 44, 354829.7 6689882.6 44, 354833 6689886.5 44, 354830.9 6689889 44, 354832.3 6689890.1 44, 354833.6 6689888.5 44, 354838.9 6689892.8 44, 354841.7 6689891.2 44, 354844 6689889.4 44, 354845.4 6689890.7 44, 354849.1 6689886.4 44, 354837.1 6689876.3 44))
BATIMENT0000000302928256;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;6.0;13;20;19.6;30.4;50.0;;;Cadastre;A 1.0;POLYGON Z ((354823.5 6689888.9 50, 354823.1 6689899.4 50, 354830.5 6689908.6 50, 354841.9 6689900.3 50, 354854.4 6689890.9 50, 354849.1 6689886.4 50, 354845.4 6689890.7 50, 354844 6689889.4 50, 354841.7 6689891.2 50, 354844.3 6689895.1 50, 354841.4 6689897.2 50, 354840.2 6689897 50, 354839.2 6689898.1 50, 354838.2 6689898.2 50, 354836.4 6689897.2 50, 354835.4 6689897.3 50, 354834.9 6689897 50, 354834.1 6689896.2 50, 354832.6 6689894.3 50, 354834.4 6689893.2 50, 354832.3 6689890.1 50, 354830.9 6689889 50, 354833 6689886.5 50, 354829.7 6689882.6 50, 354823.5 6689888.9 50))
BATIMENT0000000302927688;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;4.0;10;20;11.7;26.2;37.9;41.8;27.9;Cadastre;A 1.0;POLYGON Z ((354925.5 6689838 37.9, 354927.2 6689836.7 37.9, 354929.8 6689833.9 37.9, 354921.9 6689825.3 37.9, 354927.7 6689821.2 37.9, 354935.4 6689831.1 37.9, 354940.8 6689827.4 37.9, 354930.9 6689813.2 37.9, 354929.9 6689814 37.9, 354925 6689817.4 37.9, 354914 6689825.8 37.9, 354925.5 6689838 37.9))
BATIMENT0000000302927527;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;00;00;9.3;27.1;36.5;42.0;27.6;Cadastre;A 1.0;POLYGON Z ((354897.5 6689821.9 36.5, 354897.7 6689821.8 36.5, 354889.1 6689813.3 36.5, 354880.1 6689822 36.5, 354879.2 6689822.9 36.5, 354878.2 6689823.8 36.5, 354888.5 6689839.7 36.5, 354893.6 6689832.8 36.5, 354899.8 6689824.1 36.5, 354897.5 6689821.9 36.5))
BATIMENT0000000302927528;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;00;00;12.6;26.1;38.7;42.6;27.8;Cadastre;C 0.2;POLYGON Z ((354899.8 6689824.1 38.7, 354893.6 6689832.8 38.7, 354895.6 6689834.7 38.7, 354894.9 6689835.6 38.7, 354897.2 6689837.9 38.7, 354896.6 6689838.8 38.7, 354898.8 6689840.9 38.7, 354899.2 6689840.4 38.7, 354901.4 6689842.4 38.7, 354901.7 6689841.7 38.7, 354906.3 6689846.1 38.7, 354913.2 6689837.7 38.7, 354899.8 6689824.1 38.7))
BATIMENT0000000302927689;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;20;20;14.8;27.3;42.2;44.1;27.9;Cadastre;A 1.0;POLYGON Z ((354939.7 6689849 42.2, 354942.7 6689846 42.2, 354944.2 6689844.5 42.2, 354949.8 6689839 42.2, 354949.5 6689838.4 42.2, 354941.5 6689828.3 42.2, 354940.8 6689827.4 42.2, 354935.4 6689831.1 42.2, 354938.9 6689836.3 42.2, 354937.4 6689837.6 42.2, 354935 6689835.8 42.2, 354934.8 6689834.6 42.2, 354933.2 6689832.9 42.2, 354931.8 6689832.3 42.2, 354929.8 6689833.9 42.2, 354927.2 6689836.7 42.2, 354939.7 6689849 42.2))
BATIMENT0000000302927535;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;00;00;11.3;26.7;38.0;40.2;28.3;Cadastre;A 1.0;POLYGON Z ((354913.2 6689837.7 38, 354906.3 6689846.1 38, 354903.8 6689849 38, 354902.3 6689852.2 38, 354905.3 6689854 38, 354907.3 6689851.7 38, 354912.6 6689854.8 38, 354913 6689854.4 38, 354919.9 6689844.5 38, 354913.2 6689837.7 38))
BATIMENT0000000302927525;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;27.4;30.2;32.2;28.7;Cadastre;;POLYGON Z ((354883.4 6689846.5 30.2, 354878.6 6689853.1 30.2, 354883.2 6689856.8 30.2, 354893.2 6689843.5 30.2, 354888.5 6689839.7 30.2, 354888.4 6689839.9 30.2, 354883.4 6689846.5 30.2))
BATIMENT0000000302927533;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;12.6;26.6;39.2;43.7;28.1;Cadastre;C 0.3;POLYGON Z ((354930.7 6689854.2 39.2, 354920.2 6689844.4 39.2, 354919.9 6689844.5 39.2, 354913 6689854.4 39.2, 354915.5 6689856.5 39.2, 354915.3 6689857.1 39.2, 354916.8 6689858.6 39.2, 354916.2 6689859.4 39.2, 354918.2 6689861.5 39.2, 354918.8 6689860.6 39.2, 354920.8 6689862.4 39.2, 354918.8 6689864.8 39.2, 354919.6 6689865.2 39.2, 354919.7 6689865 39.2, 354921.7 6689866.6 39.2, 354930.4 6689854.8 39.2, 354930.7 6689854.2 39.2))
BATIMENT0000000302927536;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;27.5;30.4;31.2;28.3;Cadastre;;POLYGON Z ((354890.9 6689855.9 30.4, 354891.3 6689856.3 30.4, 354889.9 6689858.7 30.4, 354894.5 6689862.2 30.4, 354894.7 6689861.8 30.4, 354900 6689865.5 30.4, 354901.9 6689863.1 30.4, 354896.2 6689859.7 30.4, 354902.6 6689850.6 30.4, 354897.7 6689846.7 30.4, 354890.9 6689855.9 30.4))
BATIMENT0000000302929203;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;8.0;30;40;6.2;28.0;34.3;36.2;29.6;Cadastre;C 0.1;POLYGON Z ((354902.1 6689888.4 34.3, 354906 6689883 34.3, 354909.3 6689878.8 34.3, 354902.1 6689872.8 34.3, 354901.6 6689873.2 34.3, 354885.4 6689860.1 34.3, 354885.9 6689859.3 34.3, 354883.2 6689856.8 34.3, 354878.6 6689853.1 34.3, 354877.1 6689855.1 34.3, 354870.7 6689863.7 34.3, 354902.1 6689888.4 34.3))
BATIMENT0000000302927530;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;;;7.3;27.5;34.9;46.3;29.3;Cadastre;A 1.0;POLYGON Z ((354914.7 6689888.9 34.9, 354916.8 6689885.4 34.9, 354920.4 6689887.7 34.9, 354923.5 6689882.6 34.9, 354924.8 6689883.6 34.9, 354925.8 6689882.4 34.9, 354930.8 6689874.8 34.9, 354931.4 6689874.8 34.9, 354938 6689863.8 34.9, 354938.7 6689862.9 34.9, 354930.4 6689854.8 34.9, 354921.7 6689866.6 34.9, 354919.7 6689865 34.9, 354919.6 6689865.2 34.9, 354914.6 6689871.8 34.9, 354909.3 6689878.8 34.9, 354906 6689883 34.9, 354914.7 6689888.9 34.9))
BATIMENT0000000302931820;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;14.8;20.6;35.4;41.1;22.7;Cadastre;B 0.5;POLYGON Z ((355072.7 6689635.3 35.4, 355080.3 6689627.9 35.4, 355066.5 6689613.1 35.4, 355063.8 6689615.6 35.4, 355065 6689616.9 35.4, 355067.9 6689620.1 35.4, 355066.6 6689621.2 35.4, 355062.6 6689616.9 35.4, 355061.6 6689617.8 35.4, 355061.9 6689618.1 35.4, 355058.8 6689621 35.4, 355060.1 6689622.3 35.4, 355072.7 6689635.3 35.4))
BATIMENT0000000302930210;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.6;22.4;39.0;39.7;23.2;Cadastre;;POLYGON Z ((355072.7 6689635.3 39, 355060.1 6689622.3 39, 355041.6 6689628.5 39, 355043.6 6689633.2 39, 355044.2 6689634.6 39, 355048.1 6689644.1 39, 355072.7 6689635.3 39))
BATIMENT0000000302930220;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;7.8;22.4;30.3;40.2;23.3;Cadastre;A 1.0;POLYGON Z ((355039.4 6689620.8 30.3, 355038.9 6689620.1 30.3, 355031.5 6689622 30.3, 355029.3 6689622.7 30.3, 355026.5 6689623.2 30.3, 355026.2 6689623.5 30.3, 355028.2 6689630.7 30.3, 355029.8 6689637.1 30.3, 355031.4 6689636.6 30.3, 355034.6 6689647.9 30.3, 355048.1 6689644.1 30.3, 355044.2 6689634.6 30.3, 355040.7 6689635.7 30.3, 355036.8 6689636.8 30.3, 355036.7 6689635.5 30.3, 355040.4 6689634.1 30.3, 355043.6 6689633.2 30.3, 355041.6 6689628.5 30.3, 355039.4 6689620.8 30.3))
BATIMENT0000000302930219;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.4;22.8;36.3;39.5;23.1;Cadastre;;POLYGON Z ((355040.4 6689634.1 36.3, 355040.7 6689635.7 36.3, 355044.2 6689634.6 36.3, 355043.6 6689633.2 36.3, 355040.4 6689634.1 36.3))
BATIMENT0000000302930245;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;;;11.5;22.8;34.3;46.5;23.5;Cadastre;A 1.0;POLYGON Z ((355068.7 6689653.4 34.3, 355072 6689662.4 34.3, 355084.6 6689680.1 34.3, 355090.9 6689688.2 34.3, 355099.8 6689681.5 34.3, 355098.7 6689679.6 34.3, 355104.4 6689675.8 34.3, 355097 6689665.7 34.3, 355090.5 6689660.8 34.3, 355082.3 6689649.5 34.3, 355068.7 6689653.4 34.3))
BATIMENT0000000302930243;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;16.9;23.0;39.9;43.4;23.5;Cadastre;A 1.0;POLYGON Z ((355055.2 6689657.4 39.9, 355059.1 6689667.5 39.9, 355063 6689673.7 39.9, 355066.4 6689671 39.9, 355066.8 6689670.8 39.9, 355065.4 6689668.6 39.9, 355064.7 6689666.5 39.9, 355069.5 6689665.5 39.9, 355069.6 6689666.7 39.9, 355074.7 6689673.5 39.9, 355070.4 6689676.9 39.9, 355076.7 6689685.7 39.9, 355081.3 6689682.6 39.9, 355084.6 6689680.1 39.9, 355072 6689662.4 39.9, 355068.7 6689653.4 39.9, 355055.2 6689657.4 39.9))
BATIMENT0000000302931822;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;24.9;22.1;47.0;50.8;23.1;Cadastre;;POLYGON Z ((355097 6689665.7 47, 355104.4 6689675.8 47, 355108.3 6689673.3 47, 355109.2 6689674.5 47, 355109.3 6689674.4 47, 355110.8 6689673.4 47, 355115.3 6689679.5 47, 355099.2 6689697.6 47, 355100.8 6689699.6 47, 355108.7 6689708 47, 355132.3 6689681 47, 355132.3 6689680.7 47, 355123.7 6689668.6 47, 355118 6689657.1 47, 355111.5 6689641.2 47, 355082.3 6689649.5 47, 355090.5 6689660.8 47, 355097 6689665.7 47))
BATIMENT0000000302930239;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;15;29;11.1;23.1;34.2;40.9;23.9;Cadastre;A 1.0;POLYGON Z ((355046.1 6689665.2 34.2, 355048.2 6689670.3 34.2, 355048.7 6689671 34.2, 355051.3 6689674.3 34.2, 355063.3 6689690.2 34.2, 355067.8 6689696.1 34.2, 355071.5 6689693.8 34.2, 355071.8 6689691.3 34.2, 355067 6689684.3 34.2, 355067.9 6689683.6 34.2, 355074.4 6689692.4 34.2, 355079 6689689.3 34.2, 355076.7 6689685.7 34.2, 355070.4 6689676.9 34.2, 355066.4 6689671 34.2, 355063 6689673.7 34.2, 355059.1 6689667.5 34.2, 355055.2 6689657.4 34.2, 355044.6 6689660.4 34.2, 355046.1 6689665.2 34.2), (355065.7 6689678.3 34.2, 355061.3 6689681.8 34.2, 355058.6 6689677.5 34.2, 355062.8 6689674.3 34.2, 355065.7 6689678.3 34.2), (355059.4 6689675.5 34.2, 355057.6 6689676.9 34.2, 355054.7 6689673.4 34.2, 355056.4 6689671.4 34.2, 355059.4 6689675.5 34.2))
BATIMENT0000000302930236;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;10;20;14.1;22.8;36.9;39.8;24.2;Cadastre;A 1.0;POLYGON Z ((355036.7 6689669.2 36.9, 355041.9 6689675.9 36.9, 355042.2 6689675.7 36.9, 355052.6 6689688.2 36.9, 355058.2 6689694.9 36.9, 355062.3 6689691.7 36.9, 355061.9 6689691.1 36.9, 355063.3 6689690.2 36.9, 355051.3 6689674.3 36.9, 355047.4 6689677.1 36.9, 355045.9 6689675.9 36.9, 355044.6 6689674.2 36.9, 355048.7 6689671 36.9, 355048.2 6689670.3 36.9, 355046.1 6689665.2 36.9, 355044.6 6689660.4 36.9, 355035 6689663.1 36.9, 355036.7 6689669.2 36.9), (355050.8 6689681.2 36.9, 355057.1 6689688.8 36.9, 355055.5 6689690.2 36.9, 355055 6689688 36.9, 355050.2 6689682 36.9, 355049.8 6689681.9 36.9, 355050.8 6689681.2 36.9))
BATIMENT0000000302931821;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;22.6;33.2;48.5;23.2;Cadastre;;POLYGON Z ((355100.4 6689687.1 33.2, 355095.4 6689692.9 33.2, 355099.2 6689697.6 33.2, 355115.3 6689679.5 33.2, 355110.8 6689673.4 33.2, 355109.3 6689674.4 33.2, 355109.2 6689674.5 33.2, 355110.1 6689675.6 33.2, 355107 6689679.3 33.2, 355100.4 6689687.1 33.2))
BATIMENT0000000302931699;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;13;23;17.9;7.8;25.7;33.2;9.8;Cadastre;A 1.0;POLYGON Z ((355272.6 6689645.9 25.7, 355276.2 6689643.8 25.7, 355281 6689641.8 25.7, 355285.2 6689621.6 25.7, 355272.3 6689619.1 25.7, 355261 6689609.7 25.7, 355257.9 6689614 25.7, 355256.4 6689616.4 25.7, 355258.7 6689617 25.7, 355265 6689621.5 25.7, 355266.6 6689619.6 25.7, 355269.8 6689622.2 25.7, 355269.1 6689624.7 25.7, 355271.9 6689625.4 25.7, 355272.1 6689625.4 25.7, 355272.3 6689625.6 25.7, 355272.4 6689625.8 25.7, 355272.5 6689626 25.7, 355272.5 6689626.1 25.7, 355272.6 6689626.3 25.7, 355272.6 6689627 25.7, 355272.7 6689627.2 25.7, 355272.7 6689627.6 25.7, 355272.7 6689627.8 25.7, 355272.7 6689628 25.7, 355272.7 6689628.2 25.7, 355272.7 6689628.4 25.7, 355272.6 6689628.6 25.7, 355272.5 6689628.8 25.7, 355272.3 6689628.9 25.7, 355272 6689629.1 25.7, 355271.8 6689629.2 25.7, 355271.7 6689629.4 25.7, 355271.5 6689630.7 25.7, 355272.8 6689632.2 25.7, 355271 6689634.3 25.7, 355270.5 6689634 25.7, 355265.4 6689639.8 25.7, 355272.6 6689645.9 25.7))
BATIMENT0000000302931697;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;20.6;8.8;29.4;31.9;10.1;Cadastre;A 1.0;POLYGON Z ((355265.4 6689639.8 29.4, 355270.5 6689634 29.4, 355268.4 6689632.2 29.4, 355268.6 6689630.8 29.4, 355268 6689630.2 29.4, 355267 6689629.6 29.4, 355268 6689624.4 29.4, 355266.7 6689623.9 29.4, 355266.7 6689623.2 29.4, 355265 6689621.5 29.4, 355258.7 6689617 29.4, 355256.4 6689616.4 29.4, 355249.5 6689626.2 29.4, 355265.4 6689639.8 29.4))
BATIMENT0000000302931843;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.8;9.4;25.2;36.1;21.7;Cadastre;C 0.8;POLYGON Z ((355201.1 6689651.9 25.2, 355201.2 6689654.2 25.2, 355205.1 6689657 25.2, 355205.3 6689657.2 25.2, 355205.6 6689656.7 25.2, 355203.9 6689655.3 25.2, 355217.7 6689639 25.2, 355219.7 6689640.7 25.2, 355221.6 6689638.5 25.2, 355238.4 6689653.2 25.2, 355236.4 6689655.1 25.2, 355237.9 6689657 25.2, 355226 6689669.9 25.2, 355257.3 6689661.3 25.2, 355257.6 6689659.9 25.2, 355258 6689657.8 25.2, 355259.2 6689655 25.2, 355259.9 6689653.7 25.2, 355242.9 6689638.7 25.2, 355224.4 6689622.9 25.2, 355217.9 6689617.6 25.2, 355198.4 6689644.2 25.2, 355200.4 6689649 25.2, 355201.1 6689651.9 25.2))
BATIMENT0000000302931842;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;14.5;22.0;36.1;21.7;Cadastre;;POLYGON Z ((355205.3 6689657.2 22, 355223 6689670.7 22, 355226 6689669.9 22, 355237.9 6689657 22, 355236.4 6689655.1 22, 355238.4 6689653.2 22, 355221.6 6689638.5 22, 355219.7 6689640.7 22, 355217.7 6689639 22, 355203.9 6689655.3 22, 355205.6 6689656.7 22, 355205.3 6689657.2 22))
BATIMENT0000000302931746;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1867-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;18.9;7.3;26.2;30.3;10.2;Cadastre;C 0.7;POLYGON Z ((355273.3 6689684.5 26.2, 355269.4 6689681.1 26.2, 355266.2 6689676.9 26.2, 355263.9 6689672 26.2, 355243.8 6689677.5 26.2, 355245.4 6689684.4 26.2, 355246.5 6689688.9 26.2, 355254.6 6689687.1 26.2, 355259.5 6689687.2 26.2, 355259.5 6689696.7 26.2, 355273.4 6689697.3 26.2, 355273.3 6689684.5 26.2))
BATIMENT0000000302931747;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;10.0;9.2;19.2;26.0;19.3;Cadastre;A 1.0;POLYGON Z ((355228.8 6689695.2 19.2, 355234.6 6689695.7 19.2, 355236.8 6689695.9 19.2, 355239 6689695.8 19.2, 355246 6689696.3 19.2, 355246.5 6689688.9 19.2, 355245.4 6689684.4 19.2, 355243.8 6689677.5 19.2, 355227.2 6689681.9 19.2, 355225.5 6689695.1 19.2, 355228.8 6689695.2 19.2))
BATIMENT0000000302931751;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;13.8;22.1;26.7;21.7;Cadastre;;POLYGON Z ((355225.1 6689695.1 22.1, 355227.1 6689679.9 22.1, 355220.1 6689678.9 22.1, 355218 6689694.1 22.1, 355225.1 6689695.1 22.1))
BATIMENT0000000302931748;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;8.1;7.8;16.0;26.1;10.6;Cadastre;C 0.2;POLYGON Z ((355246 6689696.3 16, 355259.5 6689696.7 16, 355259.5 6689687.2 16, 355254.6 6689687.1 16, 355246.5 6689688.9 16, 355246 6689696.3 16))
BATIMENT0000000302931750;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;13.3;20.5;23.7;17.3;Cadastre;;POLYGON Z ((355234.6 6689695.7 20.5, 355234 6689705.2 20.5, 355235.7 6689705.3 20.5, 355236.3 6689705.3 20.5, 355236.8 6689695.9 20.5, 355234.6 6689695.7 20.5))
BATIMENT0000000302931749;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;28.0;5.0;10;20;16.7;6.7;23.5;29.9;16.9;Cadastre;A 1.0;POLYGON Z ((355236.3 6689705.3 23.5, 355235.7 6689705.3 23.5, 355235.4 6689709 23.5, 355237 6689709.1 23.5, 355236.6 6689715.4 23.5, 355247 6689716.5 23.5, 355261.7 6689718 23.5, 355274.9 6689719.3 23.5, 355273.4 6689697.3 23.5, 355259.5 6689696.7 23.5, 355246 6689696.3 23.5, 355239 6689695.8 23.5, 355236.8 6689695.9 23.5, 355236.3 6689705.3 23.5), (355248.3 6689701.5 23.5, 355257.5 6689702.1 23.5, 355257.4 6689703.4 23.5, 355259.2 6689705 23.5, 355260.9 6689705 23.5, 355260.6 6689707.4 23.5, 355259 6689707.5 23.5, 355257.4 6689708.9 23.5, 355257.5 6689710.7 23.5, 355247.8 6689709.8 23.5, 355248.3 6689701.5 23.5))
BATIMENT0000000302930741;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.8;19.9;34.7;36.5;20.2;Cadastre;;POLYGON Z ((355173.2 6689624.8 34.7, 355173.3 6689625.5 34.7, 355174.2 6689625.6 34.7, 355174.1 6689625.2 34.7, 355175.1 6689625.2 34.7, 355177.6 6689622.9 34.7, 355176 6689621.2 34.7, 355171 6689623.1 34.7, 355165.1 6689622.2 34.7, 355163.7 6689623.5 34.7, 355173.2 6689624.8 34.7))
BATIMENT0000000302931049;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;19.9;25.5;26.7;21.8;Cadastre;;POLYGON Z ((355133.7 6689644.4 25.5, 355138.9 6689638.4 25.5, 355131.4 6689631.9 25.5, 355126.2 6689638 25.5, 355133.7 6689644.4 25.5))
BATIMENT0000000302930476;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;27.9;21.8;49.8;51.1;23.9;Cadastre;C 0.5;POLYGON Z ((355181.1 6689783.4 49.8, 355188.1 6689783.5 49.8, 355188.2 6689775.7 49.8, 355191.5 6689775.5 49.8, 355191.7 6689714.2 49.8, 355186.1 6689712.9 49.8, 355180.4 6689711.4 49.8, 355174.9 6689709.7 49.8, 355169.4 6689707.8 49.8, 355164 6689705.7 49.8, 355161.7 6689704.8 49.8, 355159.4 6689703.7 49.8, 355157.2 6689702.4 49.8, 355155.1 6689701.1 49.8, 355153 6689699.7 49.8, 355117.6 6689740.4 49.8, 355119.2 6689741.7 49.8, 355111.2 6689750.8 49.8, 355127.2 6689764.6 49.8, 355147.8 6689782.3 49.8, 355150.1 6689782.2 49.8, 355151.7 6689782.3 49.8, 355146.7 6689778.6 49.8, 355149.6 6689775.5 49.8, 355181 6689775.7 49.8, 355181.1 6689778.7 49.8, 355181.1 6689783.4 49.8))
BATIMENT0000000302930473;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;24.0;23.0;47.0;;;Cadastre;;POLYGON Z ((355153.8 6689780.8 47, 355156.1 6689778.6 47, 355181.1 6689778.7 47, 355181 6689775.7 47, 355149.6 6689775.5 47, 355146.7 6689778.6 47, 355151.7 6689782.3 47, 355155.5 6689782.4 47, 355153.8 6689780.8 47))
BATIMENT0000000302930474;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;24.2;27.9;;;Cadastre;;POLYGON Z ((355155.9 6689782.9 27.9, 355155.5 6689782.4 27.9, 355151.7 6689782.3 27.9, 355152 6689782.9 27.9, 355151.7 6689783.3 27.9, 355120.2 6689819.4 27.9, 355122.1 6689821.2 27.9, 355155.9 6689782.9 27.9))
BATIMENT0000000302931887;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;22.8;27.6;30.1;25.6;Cadastre;;POLYGON Z ((355106.5 6689840 27.6, 355111.2 6689838.3 27.6, 355110.4 6689835.9 27.6, 355112.6 6689835.2 27.6, 355116.5 6689833.9 27.6, 355125.7 6689824.1 27.6, 355122.3 6689821.4 27.6, 355122.1 6689821.2 27.6, 355120.2 6689819.4 27.6, 355151.7 6689783.3 27.6, 355152 6689782.9 27.6, 355151.7 6689782.3 27.6, 355150.1 6689782.2 27.6, 355147.8 6689782.3 27.6, 355127.2 6689764.6 27.6, 355102.5 6689790.9 27.6, 355094.4 6689804.7 27.6, 355100.9 6689823.6 27.6, 355106.5 6689840 27.6))
BATIMENT0000000302930791;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;22.4;26.2;28.6;22.8;Cadastre;;POLYGON Z ((355143 6689817.2 26.2, 355142.5 6689818.1 26.2, 355144.2 6689822.9 26.2, 355152.4 6689820.1 26.2, 355152.6 6689819.3 26.2, 355151.3 6689815.1 26.2, 355149.9 6689814.8 26.2, 355143 6689817.2 26.2))
BATIMENT0000000302930475;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;23.2;25.7;27.0;24.5;Cadastre;;POLYGON Z ((355113.5 6689837.7 25.7, 355112.6 6689835.2 25.7, 355110.4 6689835.9 25.7, 355111.2 6689838.3 25.7, 355113.5 6689837.7 25.7))
BATIMENT0000000302930540;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1917-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;14.3;21.1;35.5;41.2;22.5;Cadastre;A 1.0;POLYGON Z ((355187 6689841.8 35.5, 355189.3 6689841.3 35.5, 355190.2 6689841.2 35.5, 355189.5 6689836.7 35.5, 355183.7 6689838.3 35.5, 355183.3 6689837.8 35.5, 355179.1 6689838.7 35.5, 355178.8 6689837.2 35.5, 355181.6 6689836.6 35.5, 355182.7 6689834.5 35.5, 355182.2 6689830.2 35.5, 355182 6689830.4 35.5, 355168.5 6689833.4 35.5, 355169.8 6689845.2 35.5, 355182.7 6689842.6 35.5, 355187 6689841.8 35.5))
BATIMENT0000000302931727;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;22.0;25.7;29.5;24.2;Cadastre;;POLYGON Z ((355158.9 6689835.8 25.7, 355152.3 6689838.1 25.7, 355152.9 6689840.7 25.7, 355159.2 6689839.8 25.7, 355158.9 6689835.8 25.7))
BATIMENT0000000302931752;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;8.4;18.7;23.5;17.5;Cadastre;;POLYGON Z ((355233.8 6689708.9 18.7, 355233.1 6689715 18.7, 355236.6 6689715.4 18.7, 355237 6689709.1 18.7, 355235.4 6689709 18.7, 355233.8 6689708.9 18.7))
BATIMENT0000000302931754;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;7.8;20.2;22.5;18.0;Cadastre;;POLYGON Z ((355228.2 6689736.4 20.2, 355246.5 6689737.8 20.2, 355246.7 6689730.3 20.2, 355247 6689716.5 20.2, 355236.6 6689715.4 20.2, 355233.1 6689715 20.2, 355230.5 6689714.8 20.2, 355228.2 6689736.4 20.2))
BATIMENT0000000302931753;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;;;14.6;6.2;20.8;26.2;7.5;Cadastre;C 0.5;POLYGON Z ((355261.7 6689718 20.8, 355263.3 6689731.2 20.8, 355264.4 6689743 20.8, 355278.3 6689744.2 20.8, 355274.9 6689719.3 20.8, 355261.7 6689718 20.8))
BATIMENT0000000302930770;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;13.8;10.1;23.9;26.2;14.3;Cadastre;A 1.0;POLYGON Z ((355243.2 6689747.2 23.9, 355242.4 6689753.3 23.9, 355241 6689759.7 23.9, 355243 6689760.1 23.9, 355243.1 6689760.4 23.9, 355249.3 6689760.9 23.9, 355251 6689747.9 23.9, 355243.2 6689747.2 23.9))
BATIMENT0000000302930778;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.5;7.5;14.1;15.7;12.1;Cadastre;A 1.0;POLYGON Z ((355259.7 6689748.7 14.1, 355251 6689747.9 14.1, 355249.3 6689760.9 14.1, 355263.1 6689762.1 14.1, 355263.2 6689757.1 14.1, 355262.3 6689757 14.1, 355262.3 6689753.7 14.1, 355262.4 6689748.9 14.1, 355259.7 6689748.7 14.1))
BATIMENT0000000302930772;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;16.9;6.2;23.2;25.5;7.3;Cadastre;A 1.0;POLYGON Z ((355278.5 6689750.2 23.2, 355268.8 6689749.4 23.2, 355271.5 6689762.2 23.2, 355281 6689759.9 23.2, 355278.5 6689750.2 23.2))
BATIMENT0000000302930771;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;6.5;6.9;13.5;20.0;10.6;Cadastre;A 1.0;POLYGON Z ((355262.4 6689748.9 13.5, 355262.3 6689753.7 13.5, 355263.1 6689753.8 13.5, 355263.3 6689755.4 13.5, 355264.7 6689755.6 13.5, 355264.7 6689757.1 13.5, 355263.2 6689757.1 13.5, 355263.1 6689762.1 13.5, 355269.8 6689762.8 13.5, 355271.5 6689762.2 13.5, 355268.8 6689749.4 13.5, 355262.4 6689748.9 13.5))
BATIMENT0000000302930769;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;00;00;16.3;6.2;22.5;25.3;7.8;Cadastre;A 1.0;POLYGON Z ((355281 6689759.9 22.5, 355271.5 6689762.2 22.5, 355269.8 6689762.8 22.5, 355270.6 6689765.3 22.5, 355273 6689772.4 22.5, 355270.9 6689773.3 22.5, 355272.3 6689777.9 22.5, 355273.5 6689777.9 22.5, 355286.6 6689776.6 22.5, 355281 6689759.9 22.5))
BATIMENT0000000302930760;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;12.8;9.9;22.7;25.0;16.5;Cadastre;A 1.0;POLYGON Z ((355233.7 6689759.2 22.7, 355233.7 6689759.8 22.7, 355234.4 6689759.9 22.7, 355234.3 6689761.6 22.7, 355233.5 6689761.5 22.7, 355233.6 6689773.4 22.7, 355234 6689773.5 22.7, 355234 6689774.4 22.7, 355233.9 6689774.5 22.7, 355233.8 6689774.6 22.7, 355233.7 6689774.7 22.7, 355233.7 6689774.8 22.7, 355233.7 6689774.9 22.7, 355233.6 6689775 22.7, 355233.6 6689775.2 22.7, 355233.7 6689775.4 22.7, 355233.8 6689775.5 22.7, 355233.8 6689775.6 22.7, 355233.9 6689775.6 22.7, 355234 6689775.8 22.7, 355234.2 6689775.8 22.7, 355240.7 6689775.4 22.7, 355240.8 6689778.1 22.7, 355257.3 6689779.7 22.7, 355261.2 6689778.9 22.7, 355261.8 6689771 22.7, 355244.4 6689769.7 22.7, 355242.6 6689767.7 22.7, 355243.1 6689760.4 22.7, 355243 6689760.1 22.7, 355241 6689759.7 22.7, 355233.7 6689759.2 22.7))
BATIMENT0000000302930757;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;7.4;16.2;19.7;12.0;Cadastre;;POLYGON Z ((355261.2 6689778.9 16.2, 355263.7 6689778.9 16.2, 355264.8 6689778.7 16.2, 355265.3 6689771.3 16.2, 355261.8 6689771 16.2, 355261.2 6689778.9 16.2))
BATIMENT0000000302930240;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;23.3;24.7;28.5;23.6;Cadastre;;POLYGON Z ((355076.7 6689685.7 24.7, 355079 6689689.3 24.7, 355083.7 6689686.3 24.7, 355081.3 6689682.6 24.7, 355076.7 6689685.7 24.7))
BATIMENT0000000302931823;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;22.9;28.7;49.7;23.8;Cadastre;;POLYGON Z ((355099.1 6689697.5 28.7, 355095.4 6689692.9 28.7, 355075.7 6689715.5 28.7, 355077.6 6689717.7 28.7, 355073.8 6689721.4 28.7, 355075.8 6689723.9 28.7, 355099.1 6689697.5 28.7))
BATIMENT0000000302931824;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;26.2;23.6;49.8;50.6;24.0;Cadastre;C 0.1;POLYGON Z ((355108.7 6689708 49.8, 355100.8 6689699.6 49.8, 355099.1 6689697.5 49.8, 355075.8 6689723.9 49.8, 355084.8 6689735.4 49.8, 355108.7 6689708 49.8))
BATIMENT0000000302931825;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;23.6;29.8;42.7;25.2;Cadastre;;POLYGON Z ((355050.7 6689752 29.8, 355075.8 6689724 29.8, 355073.8 6689721.4 29.8, 355077.6 6689717.7 29.8, 355075.7 6689715.5 29.8, 355067.2 6689705.4 29.8, 355037 6689740.1 29.8, 355043.7 6689745.7 29.8, 355050.7 6689752 29.8))
BATIMENT0000000302931826;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;25.4;24.4;49.8;51.7;25.0;Cadastre;;POLYGON Z ((355084.8 6689735.4 49.8, 355075.8 6689724 49.8, 355050.7 6689752 49.8, 355061.7 6689762 49.8, 355084.8 6689735.4 49.8))
BATIMENT0000000302930244;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;22.9;24.7;47.7;50.4;25.4;Cadastre;;POLYGON Z ((355052.9 6689772.3 47.7, 355061.7 6689762 47.7, 355050.7 6689752 47.7, 355043.7 6689745.7 47.7, 355037 6689740.1 47.7, 355036.6 6689740.7 47.7, 355027.9 6689732.3 47.7, 355047.2 6689756.8 47.7, 355041.7 6689761.8 47.7, 355052.9 6689772.3 47.7))
BATIMENT0000000302931886;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;25.8;23.5;49.3;50.2;25.5;Cadastre;;POLYGON Z ((355094.4 6689804.7 49.3, 355102.5 6689790.9 49.3, 355127.2 6689764.6 49.3, 355111.2 6689750.8 49.3, 355080.1 6689785.9 49.3, 355091.1 6689795.3 49.3, 355094.4 6689804.7 49.3))
BATIMENT0000000302930472;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;8.0;;;21.9;25.1;47.1;51.5;25.9;Cadastre;A 1.0;POLYGON Z ((355078.8 6689784.7 47.1, 355058 6689808.3 47.1, 355058.2 6689810.5 47.1, 355061.5 6689810.2 47.1, 355066.1 6689814.3 47.1, 355069.5 6689814 47.1, 355079.1 6689802.4 47.1, 355082.6 6689802 47.1, 355082.9 6689804 47.1, 355088.4 6689803.5 47.1, 355088.4 6689805.2 47.1, 355087.4 6689805.6 47.1, 355090.8 6689815.9 47.1, 355090.8 6689817.4 47.1, 355093.3 6689817.6 47.1, 355093 6689822 47.1, 355095.4 6689822.5 47.1, 355096.3 6689825.1 47.1, 355100.9 6689823.6 47.1, 355094.4 6689804.7 47.1, 355091.1 6689795.3 47.1, 355080.1 6689785.9 47.1, 355078.8 6689784.7 47.1))
BATIMENT0000000302930471;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.1;24.6;39.7;49.5;26.0;Cadastre;A 1.0;POLYGON Z ((355058.9 6689824.3 39.7, 355084.9 6689847.6 39.7, 355106.5 6689840 39.7, 355100.9 6689823.6 39.7, 355096.3 6689825.1 39.7, 355088.3 6689828 39.7, 355072.6 6689814 39.7, 355069.5 6689814 39.7, 355066.1 6689814.3 39.7, 355061.5 6689810.2 39.7, 355058.2 6689810.5 39.7, 355058.9 6689824.3 39.7))
BATIMENT0000000302931315;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;00;00;17.2;26.0;43.2;;;Cadastre;A 1.0;POLYGON Z ((355047.7 6689833.9 43.2, 355045.7 6689836.5 43.2, 355046.8 6689839.3 43.2, 355046.3 6689840.4 43.2, 355045.5 6689841.1 43.2, 355043.5 6689842.6 43.2, 355048.5 6689850.2 43.2, 355049 6689850.5 43.2, 355051.3 6689848 43.2, 355052.7 6689849.9 43.2, 355050.1 6689852.6 43.2, 355050.4 6689853.3 43.2, 355049.2 6689854.2 43.2, 355051.6 6689858 43.2, 355051.9 6689857.7 43.2, 355052.5 6689857.1 43.2, 355052.6 6689857 43.2, 355053 6689856.6 43.2, 355053.3 6689856.3 43.2, 355054.1 6689855.5 43.2, 355054.5 6689855.1 43.2, 355054.7 6689854.9 43.2, 355055 6689854.5 43.2, 355055.1 6689854.4 43.2, 355055.2 6689854.3 43.2, 355055.3 6689854.2 43.2, 355061.8 6689846.8 43.2, 355047.7 6689833.9 43.2))
BATIMENT0000000302930758;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;7.3;10.6;21.2;9.2;Cadastre;;POLYGON Z ((355268.1 6689787.6 10.6, 355276.3 6689784 10.6, 355273.5 6689777.9 10.6, 355272.3 6689777.9 10.6, 355264.8 6689778.7 10.6, 355263.7 6689778.9 10.6, 355268.1 6689787.6 10.6))
BATIMENT0000000302930768;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;13.8;6.4;20.2;28.1;8.6;Cadastre;A 0.6;POLYGON Z ((355273.5 6689777.9 20.2, 355276.3 6689784 20.2, 355268.1 6689787.6 20.2, 355270.8 6689793.9 20.2, 355279 6689790.1 20.2, 355289.8 6689785.3 20.2, 355287.8 6689779.6 20.2, 355286.6 6689776.6 20.2, 355273.5 6689777.9 20.2))
BATIMENT0000000302930773;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;9.1;13.1;20.0;14.6;Cadastre;;POLYGON Z ((355241.6 6689786.8 13.1, 355241.7 6689787.2 13.1, 355244.1 6689787.2 13.1, 355245.1 6689792.6 13.1, 355245.8 6689794.5 13.1, 355261.1 6689790.7 13.1, 355257.3 6689779.7 13.1, 355240.8 6689778.1 13.1, 355241.6 6689786.8 13.1))
BATIMENT0000000302930759;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;9.6;8.1;17.7;25.4;11.9;Cadastre;C 0.2;POLYGON Z ((355246.8 6689798.4 17.7, 355252.9 6689798.4 17.7, 355254.5 6689798.5 17.7, 355261.8 6689797.3 17.7, 355270.8 6689793.9 17.7, 355268.1 6689787.6 17.7, 355263.7 6689778.9 17.7, 355261.2 6689778.9 17.7, 355257.3 6689779.7 17.7, 355261.1 6689790.7 17.7, 355245.8 6689794.5 17.7, 355246.8 6689798.4 17.7))
BATIMENT0000000302930774;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;20;10;6.5;11.4;17.9;21.7;15.0;Cadastre;A 1.0;POLYGON Z ((355237 6689786.8 17.9, 355237.1 6689790.1 17.9, 355239.5 6689800.4 17.9, 355244.7 6689798.8 17.9, 355243.7 6689792.9 17.9, 355245.1 6689792.6 17.9, 355244.1 6689787.2 17.9, 355241.7 6689787.2 17.9, 355241.6 6689786.8 17.9, 355237 6689786.8 17.9))
BATIMENT0000000302930761;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;6.5;14.0;17.3;11.7;Cadastre;A 1.0;POLYGON Z ((355254.7 6689821 14, 355262.3 6689818.8 14, 355279.2 6689810.5 14, 355282.5 6689809 14, 355285.1 6689807.9 14, 355299.7 6689801.7 14, 355290.4 6689787 14, 355269.9 6689796.9 14, 355258.1 6689800 14, 355250 6689800.3 14, 355250.3 6689805.8 14, 355250.6 6689805.2 14, 355252.5 6689805.4 14, 355252.9 6689808 14, 355256 6689815.2 14, 355248.9 6689818 14, 355250.3 6689822.1 14, 355254.7 6689821 14))
BATIMENT0000000302930763;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;11.6;5.8;17.4;22.6;7.6;Cadastre;A 1.0;POLYGON Z ((355305.5 6689809.9 17.4, 355299.7 6689801.7 17.4, 355285.1 6689807.9 17.4, 355285.6 6689809.3 17.4, 355283 6689810.4 17.4, 355282.5 6689809 17.4, 355279.2 6689810.5 17.4, 355285.6 6689821.9 17.4, 355291.5 6689817.6 17.4, 355289 6689813.8 17.4, 355290.3 6689813.4 17.4, 355292.8 6689816.8 17.4, 355293.3 6689816.5 17.4, 355296.3 6689820.9 17.4, 355301.9 6689816.7 17.4, 355302.6 6689817.3 17.4, 355307.9 6689813.1 17.4, 355305.5 6689809.9 17.4))
BATIMENT0000000302930764;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;00;00;7.4;8.4;15.8;22.3;13.7;Cadastre;A 1.0;POLYGON Z ((355248.9 6689818 15.8, 355256 6689815.2 15.8, 355252.9 6689808 15.8, 355246.6 6689811 15.8, 355246 6689808.7 15.8, 355245.6 6689808.8 15.8, 355245.4 6689807.5 15.8, 355243.3 6689807.7 15.8, 355243.1 6689806.7 15.8, 355250.3 6689805.8 15.8, 355250 6689800.3 15.8, 355244.1 6689800.6 15.8, 355242.9 6689802.3 15.8, 355241.8 6689809 15.8, 355241 6689811.6 15.8, 355239.3 6689814 15.8, 355240.2 6689815.6 15.8, 355239.6 6689815.9 15.8, 355243.3 6689824.1 15.8, 355247.3 6689823 15.8, 355250.3 6689822.1 15.8, 355248.9 6689818 15.8))
BATIMENT0000000302930766;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;7.4;12.6;16.0;9.3;Cadastre;;POLYGON Z ((355265.3 6689827.3 12.6, 355270.1 6689824.8 12.6, 355268.8 6689822.3 12.6, 355263.1 6689824.7 12.6, 355265.3 6689827.3 12.6))
BATIMENT0000000302930765;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;10.7;9.5;20.2;21.8;12.6;Cadastre;A 1.0;POLYGON Z ((355253.6 6689831.8 20.2, 355258.8 6689827.9 20.2, 355254.7 6689821 20.2, 355250.3 6689822.1 20.2, 355247.3 6689823 20.2, 355253.6 6689831.8 20.2))
BATIMENT0000000302930767;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.7;7.1;11.9;14.5;8.6;Cadastre;C 0.2;POLYGON Z ((355271.5 6689835 11.9, 355275.6 6689832.2 11.9, 355278.7 6689830.4 11.9, 355276.6 6689826.9 11.9, 355273.8 6689822.6 11.9, 355270.1 6689824.8 11.9, 355265.3 6689827.3 11.9, 355271.5 6689835 11.9))
BATIMENT0000000302931892;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;14.9;18.5;25.0;20.8;Cadastre;;POLYGON Z ((355224.7 6689827.3 18.5, 355237.5 6689844 18.5, 355240.8 6689841.3 18.5, 355241.2 6689840.8 18.5, 355241.4 6689840.5 18.5, 355241.5 6689840.3 18.5, 355241.5 6689840.1 18.5, 355241.4 6689839.9 18.5, 355241.3 6689839.7 18.5, 355241.3 6689839.2 18.5, 355241.2 6689839 18.5, 355241.1 6689838.9 18.5, 355240.8 6689838.3 18.5, 355240.3 6689837.4 18.5, 355236.2 6689831.7 18.5, 355226.2 6689818.7 18.5, 355221.5 6689819.8 18.5, 355221.2 6689826.6 18.5, 355224.7 6689827.3 18.5))
BATIMENT0000000302930776;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;7.2;10.7;13.5;8.1;Cadastre;;POLYGON Z ((355273.4 6689837.6 10.7, 355275.5 6689835.4 10.7, 355275.6 6689832.2 10.7, 355271.5 6689835 10.7, 355273.4 6689837.6 10.7))
BATIMENT0000000302930777;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;7.2;11.7;16.5;8.6;Cadastre;;POLYGON Z ((355276.9 6689842.6 11.7, 355279.4 6689840.5 11.7, 355278.8 6689839.6 11.7, 355278.1 6689838.5 11.7, 355277.4 6689837.6 11.7, 355277 6689837 11.7, 355276.2 6689836.2 11.7, 355275.5 6689835.4 11.7, 355273.4 6689837.6 11.7, 355276.9 6689842.6 11.7))
BATIMENT0000000302930775;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;12;20;15.4;6.8;22.2;29.0;8.7;Cadastre;A 1.0;POLYGON Z ((355321.3 6689829.2 22.2, 355307.9 6689813.1 22.2, 355302.6 6689817.3 22.2, 355301.9 6689816.7 22.2, 355296.3 6689820.9 22.2, 355298.3 6689823.2 22.2, 355291.8 6689829.6 22.2, 355291.4 6689829.5 22.2, 355279.4 6689840.5 22.2, 355276.9 6689842.6 22.2, 355284.8 6689852.5 22.2, 355290.5 6689847.1 22.2, 355294 6689842.1 22.2, 355291.7 6689839.4 22.2, 355302.6 6689828.4 22.2, 355307.5 6689833.8 22.2, 355305.6 6689836.3 22.2, 355303.6 6689835.2 22.2, 355288.2 6689856.6 22.2, 355287.2 6689857.6 22.2, 355295 6689866.5 22.2, 355321.3 6689829.2 22.2))
BATIMENT0000000302930762;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;4.0;20;20;9.2;7.3;16.5;23.1;12.0;Cadastre;C 0.6;POLYGON Z ((355287.1 6689873.2 16.5, 355290.4 6689872.9 16.5, 355295 6689866.5 16.5, 355287.2 6689857.6 16.5, 355288.2 6689856.6 16.5, 355284.8 6689852.5 16.5, 355276.9 6689842.6 16.5, 355273.4 6689837.6 16.5, 355271.5 6689835 16.5, 355265.3 6689827.3 16.5, 355263.1 6689824.7 16.5, 355268.8 6689822.3 16.5, 355270.1 6689824.8 16.5, 355273.8 6689822.6 16.5, 355276.6 6689826.9 16.5, 355285.6 6689821.9 16.5, 355279.2 6689810.5 16.5, 355262.3 6689818.8 16.5, 355254.7 6689821 16.5, 355258.8 6689827.9 16.5, 355253.6 6689831.8 16.5, 355287.1 6689873.2 16.5))
BATIMENT0000000302930542;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;20.9;26.5;27.7;22.1;Cadastre;;POLYGON Z ((355188.1 6689848.8 26.5, 355188.2 6689851.4 26.5, 355191.7 6689851.1 26.5, 355191.3 6689849.4 26.5, 355190.9 6689849.5 26.5, 355190.8 6689848.5 26.5, 355188.1 6689848.8 26.5))
BATIMENT0000000302931893;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;18.5;24.4;29.1;21.2;Cadastre;;POLYGON Z ((355226.9 6689846.8 24.4, 355226.7 6689864.3 24.4, 355221.8 6689864.3 24.4, 355220.6 6689865.5 24.4, 355220.7 6689867.7 24.4, 355221.5 6689868.6 24.4, 355219.4 6689871.4 24.4, 355221.9 6689874.1 24.4, 355220 6689876.7 24.4, 355241.1 6689873 24.4, 355240.5 6689866.8 24.4, 355239.7 6689859.1 24.4, 355237.5 6689844 24.4, 355224.7 6689827.3 24.4, 355221.2 6689826.6 24.4, 355219 6689828.6 24.4, 355218.2 6689835.9 24.4, 355226.9 6689846.8 24.4))
BATIMENT0000000302930559;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;11.8;18.5;19.7;18.8;Cadastre;;POLYGON Z ((355253.2 6689849.1 18.5, 355244.8 6689838.8 18.5, 355242.9 6689840.3 18.5, 355240.3 6689837.4 18.5, 355240.8 6689838.3 18.5, 355241.1 6689838.9 18.5, 355241.2 6689839 18.5, 355241.3 6689839.2 18.5, 355241.3 6689839.7 18.5, 355241.4 6689839.9 18.5, 355241.5 6689840.1 18.5, 355241.5 6689840.3 18.5, 355241.4 6689840.5 18.5, 355241.2 6689840.8 18.5, 355240.8 6689841.3 18.5, 355237.5 6689844 18.5, 355239.7 6689859.1 18.5, 355240.5 6689866.8 18.5, 355247.4 6689861.6 18.5, 355247 6689853.6 18.5, 355253.2 6689849.1 18.5))
BATIMENT0000000302931891;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2020-05-29 13:38:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;10.8;12.0;;18.5;Cadastre;;POLYGON Z ((355257.5 6689854.1 12, 355253.2 6689849.1 12, 355247 6689853.6 12, 355247.4 6689861.6 12, 355257.5 6689854.1 12))
BATIMENT0000000302930541;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;13.0;21.9;34.9;38.9;22.5;Cadastre;A 1.0;POLYGON Z ((355170.9 6689852 34.9, 355182.8 6689849.4 34.9, 355187.2 6689848.5 34.9, 355186.8 6689846.6 34.9, 355182.4 6689847.3 34.9, 355182.3 6689845.7 34.9, 355183 6689845.2 34.9, 355182.7 6689842.6 34.9, 355169.8 6689845.2 34.9, 355170.9 6689852 34.9))
BATIMENT0000000302931721;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;22.0;25.0;32.2;24.2;Cadastre;;POLYGON Z ((355155.3 6689862.3 25, 355161.9 6689861.5 25, 355159.2 6689839.8 25, 355152.9 6689840.7 25, 355155.3 6689862.3 25))
BATIMENT0000000302930543;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;15.1;21.1;36.2;39.2;22.5;Cadastre;A 0.9;POLYGON Z ((355172.1 6689863.6 36.2, 355183.3 6689862.2 36.2, 355186 6689861.9 36.2, 355193 6689861.1 36.2, 355194.1 6689861 36.2, 355193 6689853.4 36.2, 355192.5 6689853.5 36.2, 355183.3 6689854.4 36.2, 355182.8 6689849.4 36.2, 355170.9 6689852 36.2, 355172.1 6689863.6 36.2))
BATIMENT0000000291500096;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 11:33:40;2019-07-01 11:18:30;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.6;23.6;;30.7;24.6;Imagerie aérienne;;POLYGON Z ((355154.2 6689861.3 28.2, 355153.4 6689855.1 28.2, 355134.3 6689861.3 27.6, 355136 6689866.7 28.1, 355154.2 6689861.3 28.2))
BATIMENT0000000302930545;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;14.1;21.7;35.9;39.4;22.5;Cadastre;C 0.7;POLYGON Z ((355173 6689870.9 35.9, 355191.5 6689869.7 35.9, 355192.4 6689869.5 35.9, 355192.1 6689866.2 35.9, 355182.9 6689867.1 35.9, 355182.6 6689865.6 35.9, 355183.5 6689865.5 35.9, 355183.3 6689862.2 35.9, 355172.1 6689863.6 35.9, 355173 6689870.9 35.9))
BATIMENT0000000302931722;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:18:30;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;23.6;25.8;27.5;24.4;Cadastre;;POLYGON Z ((355134.3 6689868.6 25.8, 355135.1 6689871.1 25.8, 355145.2 6689868 25.8, 355144.7 6689865.5 25.8, 355134.3 6689868.6 25.8))
BATIMENT0000000302931720;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;20;20;10.1;22.1;32.2;38.2;24.5;Cadastre;C 0.8;POLYGON Z ((355155.4 6689865.7 32.2, 355154.1 6689866.1 32.2, 355153.4 6689864.6 32.2, 355147.9 6689866.4 32.2, 355148.5 6689869.5 32.2, 355134 6689873.3 32.2, 355134.8 6689876.5 32.2, 355139.5 6689875.5 32.2, 355143.3 6689874.1 32.2, 355148.8 6689872.9 32.2, 355151.7 6689872.1 32.2, 355162.6 6689869.1 32.2, 355161.9 6689861.5 32.2, 355155.3 6689862.3 32.2, 355155.4 6689865.7 32.2))
BATIMENT0000000302931724;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;19;23;12.9;23.6;36.5;41.2;24.5;Cadastre;A 1.0;POLYGON Z ((355132.4 6689871.9 36.5, 355131.8 6689869.4 36.5, 355129.6 6689869.9 36.5, 355124.4 6689871.9 36.5, 355125.4 6689874.7 36.5, 355123.4 6689874.9 36.5, 355122.7 6689875.3 36.5, 355122.2 6689875.7 36.5, 355121 6689876 36.5, 355120 6689873.1 36.5, 355108.7 6689876.7 36.5, 355114.4 6689882.1 36.5, 355134.8 6689876.5 36.5, 355134 6689873.3 36.5, 355132.4 6689871.9 36.5))
BATIMENT0000000302930546;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;12.7;21.5;34.2;39.4;22.2;Cadastre;A 1.0;POLYGON Z ((355174.5 6689882.3 34.2, 355188.4 6689879.8 34.2, 355192.2 6689878.8 34.2, 355191.9 6689875.5 34.2, 355185.4 6689876.6 34.2, 355185.2 6689875.2 34.2, 355183.6 6689875.4 34.2, 355183.3 6689873.3 34.2, 355191.6 6689872.1 34.2, 355191.5 6689869.7 34.2, 355173 6689870.9 34.2, 355174.5 6689882.3 34.2))
BATIMENT0000000302931723;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;23.9;29.5;34.5;24.6;Cadastre;;POLYGON Z ((355139.5 6689875.5 29.5, 355140.5 6689879.8 29.5, 355143.4 6689879.1 29.5, 355144.5 6689878.7 29.5, 355143.3 6689874.1 29.5, 355139.5 6689875.5 29.5))
BATIMENT0000000302931313;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;00;00;16.7;26.0;42.7;;;Cadastre;A 1.0;POLYGON Z ((355075.8 6689862.1 42.7, 355076.2 6689860.1 42.7, 355061.8 6689846.8 42.7, 355055.3 6689854.2 42.7, 355055.2 6689854.3 42.7, 355055.1 6689854.4 42.7, 355055 6689854.5 42.7, 355054.7 6689854.9 42.7, 355054.5 6689855.1 42.7, 355054.1 6689855.5 42.7, 355053.3 6689856.3 42.7, 355053 6689856.6 42.7, 355052.6 6689857 42.7, 355052.5 6689857.1 42.7, 355051.9 6689857.7 42.7, 355051.6 6689858 42.7, 355054.2 6689861.9 42.7, 355056.5 6689860.1 42.7, 355059.5 6689857.1 42.7, 355060.8 6689858.5 42.7, 355067.6 6689866.5 42.7, 355075.8 6689862.1 42.7))
BATIMENT0000000302931311;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;25.0;39.0;40.0;25.4;Cadastre;;POLYGON Z ((355057.8 6689861.5 39, 355056.5 6689860.1 39, 355054.2 6689861.9 39, 355055.4 6689863.9 39, 355057.8 6689861.5 39))
BATIMENT0000000302931728;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;30;20;8.0;24.0;32.1;36.8;25.0;Cadastre;C 0.8;POLYGON Z ((355126.9 6689862.3 32.1, 355110.1 6689867.9 32.1, 355108.2 6689862.3 32.1, 355124.7 6689856.5 32.1, 355122.1 6689848.5 32.1, 355091.6 6689859.4 32.1, 355091.3 6689860.4 32.1, 355091.9 6689861.6 32.1, 355108.7 6689876.7 32.1, 355120 6689873.1 32.1, 355124.4 6689871.9 32.1, 355129.6 6689869.9 32.1, 355126.9 6689862.3 32.1))
BATIMENT0000000302931312;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.0;26.0;42.0;;;Cadastre;;POLYGON Z ((355060.2 6689864.3 42, 355061.5 6689863.1 42, 355060.3 6689862 42, 355059.2 6689863.2 42, 355060.2 6689864.3 42))
BATIMENT0000000302931310;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;15.8;26.0;41.8;;;Cadastre;A 1.0;POLYGON Z ((355055.4 6689863.9 41.8, 355057.1 6689866.7 41.8, 355059.7 6689870.9 41.8, 355067.6 6689866.5 41.8, 355060.8 6689858.5 41.8, 355057.8 6689861.5 41.8, 355055.4 6689863.9 41.8), (355060.3 6689862 41.8, 355061.5 6689863.1 41.8, 355060.2 6689864.3 41.8, 355059.2 6689863.2 41.8, 355060.3 6689862 41.8))
BATIMENT0000000302931314;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;4.0;00;00;13.8;26.0;39.8;;;Cadastre;A 1.0;POLYGON Z ((355036.3 6689852.6 39.8, 355035.3 6689853.4 39.8, 355025.2 6689859.4 39.8, 355028.8 6689865.4 39.8, 355029.8 6689865.3 39.8, 355030.7 6689865.3 39.8, 355031.6 6689865.5 39.8, 355032.5 6689865.7 39.8, 355033.8 6689866.1 39.8, 355034.5 6689866.6 39.8, 355035.7 6689867.3 39.8, 355036.1 6689867.8 39.8, 355036.8 6689868.3 39.8, 355037.5 6689869.1 39.8, 355038 6689870 39.8, 355038.7 6689871.6 39.8, 355039.1 6689872.5 39.8, 355039.1 6689873.9 39.8, 355039 6689875.6 39.8, 355038.7 6689877.2 39.8, 355038.1 6689879.1 39.8, 355037.8 6689879.8 39.8, 355039.9 6689883.1 39.8, 355045.8 6689879.7 39.8, 355045.4 6689879 39.8, 355049.8 6689876.5 39.8, 355059.7 6689870.9 39.8, 355057.1 6689866.7 39.8, 355050.2 6689870.7 39.8, 355044.7 6689862.5 39.8, 355038.2 6689851.6 39.8, 355036.3 6689852.6 39.8))
BATIMENT0000000302931759;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;29;20;11.0;24.1;35.1;36.0;26.4;Cadastre;A 1.0;POLYGON Z ((355087.3 6689880.3 35.1, 355088.2 6689879.8 35.1, 355089.3 6689878.6 35.1, 355090.2 6689879.3 35.1, 355091.5 6689880.3 35.1, 355094.5 6689876.9 35.1, 355082.6 6689866 35.1, 355080.8 6689865.9 35.1, 355080.3 6689866.3 35.1, 355085.1 6689876 35.1, 355087.3 6689880.3 35.1))
BATIMENT0000000302931758;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;12.8;24.5;37.3;40.4;26.6;Cadastre;A 1.0;POLYGON Z ((355069.8 6689872 37.3, 355074.7 6689881.2 37.3, 355085.1 6689876 37.3, 355080.3 6689866.3 37.3, 355069.8 6689872 37.3))
BATIMENT0000000302931760;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.6;26.0;37.6;39.9;26.9;Cadastre;;POLYGON Z ((355062.7 6689875.9 37.6, 355052.1 6689881.8 37.6, 355052.3 6689882.2 37.6, 355052.5 6689882.6 37.6, 355057.1 6689890.8 37.6, 355057.3 6689891.1 37.6, 355058.1 6689890.7 37.6, 355057.8 6689890.3 37.6, 355059.9 6689889.1 37.6, 355060.2 6689889.5 37.6, 355060.9 6689889.1 37.6, 355060.7 6689888.6 37.6, 355065.6 6689885.8 37.6, 355065.9 6689886.3 37.6, 355066.9 6689885.7 37.6, 355066.7 6689885.3 37.6, 355071.4 6689882.6 37.6, 355071.6 6689883 37.6, 355072.6 6689882.4 37.6, 355072.4 6689882 37.6, 355074.2 6689881.1 37.6, 355074.4 6689881.5 37.6, 355074.5 6689881.7 37.6, 355074.7 6689881.2 37.6, 355069.8 6689872 37.6, 355062.7 6689875.9 37.6))
BATIMENT0000000302931761;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;;;8.0;24.6;32.6;33.4;27.0;Cadastre;A 1.0;POLYGON Z ((355090.9 6689881.2 32.6, 355088.8 6689882.4 32.6, 355088.5 6689883 32.6, 355086.4 6689884.1 32.6, 355088.1 6689887.5 32.6, 355088.7 6689888.4 32.6, 355090.9 6689887.3 32.6, 355091.7 6689888.6 32.6, 355092.9 6689890.7 32.6, 355094 6689890.3 32.6, 355100.4 6689888.4 32.6, 355103.2 6689884.9 32.6, 355094.5 6689876.9 32.6, 355091.5 6689880.3 32.6, 355090.9 6689881.2 32.6))
BATIMENT0000000302930544;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;21.1;36.2;37.5;22.5;Cadastre;;POLYGON Z ((355186.4 6689864.6 36.2, 355192.3 6689864 36.2, 355193.3 6689863.9 36.2, 355193 6689861.1 36.2, 355186 6689861.9 36.2, 355186.4 6689864.6 36.2))
BATIMENT0000000302931888;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;12.3;18.3;20.4;18.9;Cadastre;;POLYGON Z ((355247.6 6689872.8 18.3, 355247.3 6689861.7 18.3, 355240.5 6689866.8 18.3, 355241.1 6689873 18.3, 355247.6 6689872.8 18.3))
BATIMENT0000000302930555;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.6;8.5;20.2;25.1;12.9;Cadastre;;POLYGON Z ((355266.2 6689864.9 20.2, 355261 6689862.4 20.2, 355257.4 6689866.9 20.2, 355262.8 6689871.6 20.2, 355260.7 6689873.2 20.2, 355258.7 6689876.6 20.2, 355267 6689889.8 20.2, 355276.3 6689883.8 20.2, 355277.6 6689879.3 20.2, 355272.1 6689872.5 20.2, 355270.6 6689872.3 20.2, 355269.3 6689872.5 20.2, 355266.5 6689872.6 20.2, 355266.8 6689869.5 20.2, 355266.9 6689867.9 20.2, 355266.9 6689866.2 20.2, 355266.2 6689864.9 20.2))
BATIMENT0000000302930556;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;11.9;25.7;30.3;21.3;Cadastre;;POLYGON Z ((355248 6689889.5 25.7, 355267 6689889.8 25.7, 355258.7 6689876.6 25.7, 355260.7 6689873.2 25.7, 355262.8 6689871.6 25.7, 355257.4 6689866.9 25.7, 355261 6689862.4 25.7, 355266.2 6689864.9 25.7, 355257.5 6689854.1 25.7, 355247.3 6689861.7 25.7, 355247.6 6689872.8 25.7, 355241.1 6689873 25.7, 355220 6689876.7 25.7, 355217.8 6689878.9 25.7, 355217.7 6689885 25.7, 355218.4 6689886 25.7, 355217.1 6689887.4 25.7, 355215.8 6689886 25.7, 355213.5 6689888.7 25.7, 355213.3 6689896.4 25.7, 355219.7 6689903 25.7, 355226.4 6689903.8 25.7, 355226.6 6689904.1 25.7, 355226.6 6689905.3 25.7, 355228.1 6689905.3 25.7, 355229.2 6689905.8 25.7, 355232.5 6689901.9 25.7, 355234.2 6689902.2 25.7, 355235.6 6689903.1 25.7, 355235.7 6689903.1 25.7, 355236 6689903.1 25.7, 355236.2 6689903 25.7, 355236.5 6689903 25.7, 355236.8 6689902.8 25.7, 355236.9 6689902.7 25.7, 355237.1 6689902.4 25.7, 355237.2 6689902.3 25.7, 355237.2 6689902.2 25.7, 355237.2 6689902.1 25.7, 355237.3 6689901.9 25.7, 355237.3 6689901.7 25.7, 355237.3 6689901.6 25.7, 355237.2 6689901.2 25.7, 355237.2 6689901.1 25.7, 355237.1 6689901 25.7, 355237 6689900.8 25.7, 355236.9 6689900.6 25.7, 355236.7 6689900.4 25.7, 355236.6 6689900.4 25.7, 355236.3 6689900.3 25.7, 355238.4 6689899.4 25.7, 355243.6 6689894.2 25.7, 355248 6689889.5 25.7))
BATIMENT0000000302930547;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;15.8;21.0;36.9;41.0;21.9;Cadastre;A 1.0;POLYGON Z ((355175.5 6689890.9 36.9, 355182.3 6689889.7 36.9, 355186 6689889 36.9, 355188.4 6689888.6 36.9, 355188.4 6689888.3 36.9, 355193.3 6689887.5 36.9, 355194.5 6689887.3 36.9, 355193.8 6689883 36.9, 355189.8 6689883.7 36.9, 355189.2 6689884.1 36.9, 355188.4 6689879.8 36.9, 355174.5 6689882.3 36.9, 355175.5 6689890.9 36.9))
BATIMENT0000000302930538;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;2.9;8.1;11.0;11.3;9.8;Cadastre;A 1.0;POLYGON Z ((355281.1 6689888.6 11, 355279.8 6689889.9 11, 355278.7 6689890.7 11, 355285.2 6689897 11, 355285.3 6689897 11, 355287.6 6689894.7 11, 355281.1 6689888.6 11))
BATIMENT0000000302930548;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;14.2;20.8;35.1;38.2;21.9;Cadastre;A 1.0;POLYGON Z ((355176.7 6689901.5 35.1, 355181 6689902.4 35.1, 355192.4 6689890.4 35.1, 355193.3 6689887.5 35.1, 355188.4 6689888.3 35.1, 355188.4 6689888.6 35.1, 355186 6689889 35.1, 355184 6689891.3 35.1, 355182.4 6689890.7 35.1, 355182.3 6689889.7 35.1, 355175.5 6689890.9 35.1, 355176.7 6689901.5 35.1))
BATIMENT0000000302930536;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;7.9;11.0;11.6;9.0;Cadastre;;POLYGON Z ((355290.5 6689901.9 11, 355292.9 6689899.5 11, 355287.6 6689894.7 11, 355285.3 6689897 11, 355290.5 6689901.9 11))
BATIMENT0000000302930535;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.3;9.0;11.3;;;Cadastre;;POLYGON Z ((355294 6689907.6 11.3, 355300.3 6689901.1 11.3, 355300.1 6689898.6 11.3, 355296.4 6689895.1 11.3, 355293.4 6689898.8 11.3, 355292.9 6689899.5 11.3, 355290.5 6689901.9 11.3, 355288.8 6689903.7 11.3, 355289.2 6689904 11.3, 355294 6689907.6 11.3))
BATIMENT0000000302930531;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;9.6;;;;Cadastre;;POLYGON Z ((355287.7 6689903.1 -1000, 355284.4 6689903.6 -1000, 355284.6 6689904.6 -1000, 355284.6 6689904.8 -1000, 355284.9 6689906.4 -1000, 355286.1 6689906.2 -1000, 355288.1 6689904.2 -1000, 355287.7 6689903.1 -1000))
BATIMENT0000000302927954;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;31.9;36.0;38.0;32.0;Cadastre;;POLYGON Z ((354590.9 6689748.9 36, 354594.9 6689748.5 36, 354594.8 6689747.6 36, 354594.1 6689743.4 36, 354593.9 6689741.5 36, 354590.3 6689741.8 36, 354590.9 6689748.9 36))
BATIMENT0000000302927946;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;31.6;36.4;37.0;31.9;Cadastre;;POLYGON Z ((354578 6689741.9 36.4, 354573.1 6689742.3 36.4, 354574 6689750.9 36.4, 354579 6689750.4 36.4, 354578.7 6689748 36.4, 354578 6689741.9 36.4))
BATIMENT0000000302927944;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;31.7;34.7;36.5;31.9;Cadastre;;POLYGON Z ((354583.4 6689747.5 34.7, 354578.7 6689748 34.7, 354579 6689750.4 34.7, 354581.4 6689750.1 34.7, 354583.5 6689749.8 34.7, 354583.4 6689747.5 34.7))
BATIMENT0000000302927936;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;31.3;35.6;38.2;31.8;Cadastre;;POLYGON Z ((354571.1 6689724.2 35.6, 354570.3 6689718.5 35.6, 354566.5 6689719.1 35.6, 354566.7 6689722.9 35.6, 354572.8 6689780.7 35.6, 354573.2 6689783.5 35.6, 354577.4 6689783.1 35.6, 354576.6 6689776.1 35.6, 354574.7 6689758.1 35.6, 354574 6689750.9 35.6, 354573.1 6689742.3 35.6, 354571.1 6689724.2 35.6))
BATIMENT0000000302927947;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;31.7;34.6;36.7;32.0;Cadastre;B 0.1;POLYGON Z ((354590.9 6689748.9 34.6, 354583.5 6689749.8 34.6, 354581.4 6689750.1 34.6, 354582.4 6689757 34.6, 354583.4 6689756.6 34.6, 354595.7 6689754.9 34.6, 354595.7 6689753.7 34.6, 354594.9 6689748.5 34.6, 354590.9 6689748.9 34.6))
BATIMENT0000000302927953;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;31.5;34.4;36.0;31.9;Cadastre;;POLYGON Z ((354595.7 6689754.9 34.4, 354596.1 6689756.4 34.4, 354604.7 6689755.2 34.4, 354604.4 6689752.6 34.4, 354595.7 6689753.7 34.4, 354595.7 6689754.9 34.4))
BATIMENT0000000302927939;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.2;31.6;35.8;36.8;31.9;Cadastre;A 1.0;POLYGON Z ((354581.4 6689750.1 35.8, 354579 6689750.4 35.8, 354574 6689750.9 35.8, 354574.7 6689758.1 35.8, 354575.8 6689758 35.8, 354580.1 6689762.2 35.8, 354579.7 6689758.1 35.8, 354582.4 6689757 35.8, 354581.4 6689750.1 35.8))
BATIMENT0000000302927940;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.4;31.5;35.0;39.5;31.8;Cadastre;B 0.4;POLYGON Z ((354576.6 6689776.1 35, 354580.1 6689775.6 35, 354579.5 6689770.2 35, 354580.8 6689766.9 35, 354580.1 6689762.2 35, 354575.8 6689758 35, 354574.7 6689758.1 35, 354576.6 6689776.1 35))
BATIMENT0000000302927948;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.1;30.0;36.1;38.4;31.9;Cadastre;A 1.0;POLYGON Z ((354616.5 6689782.1 36.1, 354614.2 6689765.2 36.1, 354597.6 6689767 36.1, 354598.7 6689777.6 36.1, 354611.1 6689776.3 36.1, 354611.8 6689782.8 36.1, 354616.5 6689782.1 36.1))
BATIMENT0000000302927937;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;31.3;35.3;39.5;31.5;Cadastre;;POLYGON Z ((354572.5 6689780.8 35.3, 354571.9 6689781 35.3, 354571.6 6689781.2 35.3, 354571.6 6689781.3 35.3, 354571.4 6689781.4 35.3, 354571.1 6689781.6 35.3, 354570.9 6689781.9 35.3, 354570.6 6689782.3 35.3, 354570.3 6689782.7 35.3, 354570.3 6689782.8 35.3, 354570.1 6689783.1 35.3, 354570 6689783.5 35.3, 354569.9 6689783.9 35.3, 354569.9 6689784.2 35.3, 354569.9 6689784.5 35.3, 354570.1 6689787.3 35.3, 354573.5 6689786.8 35.3, 354573.2 6689783.5 35.3, 354572.8 6689780.7 35.3, 354572.5 6689780.8 35.3))
BATIMENT0000000302927901;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.1;30.3;36.4;39.9;30.9;Cadastre;C 0.1;POLYGON Z ((354657.7 6689762.2 36.4, 354658.4 6689762.3 36.4, 354662.6 6689753.3 36.4, 354657.5 6689750.8 36.4, 354650 6689765.7 36.4, 354655.8 6689766.4 36.4, 354657.7 6689762.2 36.4))
BATIMENT0000000302927904;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;29.0;34.2;37.1;31.3;Cadastre;;POLYGON Z ((354674.5 6689768.4 34.2, 354677.3 6689768.8 34.2, 354687.3 6689769.9 34.2, 354692.1 6689754.8 34.2, 354679.9 6689751.4 34.2, 354674.5 6689768.4 34.2))
BATIMENT0000000302927950;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;21.0;4.0;15;20;8.3;30.0;38.3;44.0;32.2;Cadastre;A 1.0;POLYGON Z ((354634.1 6689777.5 38.3, 354651.5 6689742.3 38.3, 354643.1 6689742.5 38.3, 354639.7 6689742.6 38.3, 354630.3 6689742.9 38.3, 354622.6 6689743.1 38.3, 354620.9 6689743.1 38.3, 354614.8 6689743 38.3, 354615.4 6689748.3 38.3, 354621 6689748 38.3, 354621.1 6689748.6 38.3, 354636 6689748.1 38.3, 354636.1 6689745.8 38.3, 354637.5 6689745.8 38.3, 354637.6 6689747.9 38.3, 354639.2 6689748.8 38.3, 354626.7 6689773.7 38.3, 354627.5 6689774.1 38.3, 354626.9 6689775.2 38.3, 354628.1 6689775.5 38.3, 354627.8 6689776.5 38.3, 354622 6689777.2 38.3, 354622 6689775.1 38.3, 354621.1 6689766.3 38.3, 354623.7 6689765.9 38.3, 354621.7 6689749.7 38.3, 354615.8 6689750.5 38.3, 354619.1 6689775.5 38.3, 354619.3 6689777.6 38.3, 354620 6689781.4 38.3, 354620.3 6689782.5 38.3, 354632.1 6689781.5 38.3, 354634.1 6689777.5 38.3))
BATIMENT0000000302927902;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.4;29.0;37.4;37.9;30.6;Cadastre;A 1.0;POLYGON Z ((354665.9 6689767.5 37.4, 354666.5 6689774.9 37.4, 354669.1 6689774.9 37.4, 354676.9 6689774.4 37.4, 354677.3 6689768.8 37.4, 354674.5 6689768.4 37.4, 354665.9 6689767.5 37.4))
BATIMENT0000000302927903;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;14;20;7.6;28.8;36.5;42.8;30.5;Cadastre;A 1.0;POLYGON Z ((354693.4 6689784.2 36.5, 354692.1 6689770.3 36.5, 354687.3 6689769.9 36.5, 354677.3 6689768.8 36.5, 354676.9 6689774.4 36.5, 354677.6 6689774.3 36.5, 354688.4 6689775.5 36.5, 354688.5 6689777.1 36.5, 354678 6689778.2 36.5, 354678.7 6689785.6 36.5, 354693.4 6689784.2 36.5))
BATIMENT0000000302927899;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;20;20;9.1;29.5;38.7;44.6;30.7;Cadastre;A 1.0;POLYGON Z ((354640.7 6689789.5 38.7, 354667.6 6689786.9 38.7, 354666.5 6689774.9 38.7, 354665.9 6689767.5 38.7, 354655.8 6689766.4 38.7, 354650 6689765.7 38.7, 354639.3 6689787.2 38.7, 354640.7 6689789.5 38.7), (354653.3 6689778.1 38.7, 354661.8 6689778.4 38.7, 354661.9 6689780.2 38.7, 354653.7 6689781 38.7, 354653.3 6689778.1 38.7))
BATIMENT0000000302927900;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;00;00;12.5;29.0;41.5;45.2;30.1;Cadastre;A 1.0;POLYGON Z ((354678.7 6689785.6 41.5, 354678 6689778.2 41.5, 354677.7 6689776.5 41.5, 354669.3 6689777.3 41.5, 354669.1 6689774.9 41.5, 354666.5 6689774.9 41.5, 354667.6 6689786.9 41.5, 354678.7 6689785.6 41.5))
BATIMENT0000000302927961;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;10;20;12.4;30.0;42.4;43.7;30.8;Cadastre;A 1.0;POLYGON Z ((354627.5 6689790.9 42.4, 354632.1 6689781.5 42.4, 354620.3 6689782.5 42.4, 354621.2 6689785.1 42.4, 354623.7 6689784.8 42.4, 354623.9 6689787.1 42.4, 354621.9 6689787.5 42.4, 354623 6689791.3 42.4, 354627.5 6689790.9 42.4))
BATIMENT0000000302927981;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;28.5;36.0;42.2;29.0;Cadastre;;POLYGON Z ((354695.7 6689794.5 36, 354695.3 6689798.5 36, 354697.5 6689798.5 36, 354697.8 6689794.3 36, 354695.7 6689794.5 36))
BATIMENT0000000302929057;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.3;28.7;35.0;39.0;29.1;Cadastre;A 1.0;POLYGON Z ((354685.9 6689811.6 35, 354688.3 6689804 35, 354688.8 6689794.2 35, 354684.4 6689794.6 35, 354684.5 6689811.6 35, 354685.9 6689811.6 35))
BATIMENT0000000302927931;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;31.3;35.8;40.7;31.7;Cadastre;;POLYGON Z ((354554.5 6689786.9 35.8, 354552.7 6689785 35.8, 354551.7 6689784 35.8, 354551.1 6689783.1 35.8, 354550.5 6689782.1 35.8, 354550 6689781 35.8, 354549.5 6689780 35.8, 354549.1 6689778.9 35.8, 354542.1 6689785 35.8, 354546.3 6689790 35.8, 354556.3 6689788.9 35.8, 354554.5 6689786.9 35.8))
BATIMENT0000000302927949;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;30;30;13.0;30.0;43.0;44.2;31.1;Cadastre;A 1.0;POLYGON Z ((354623 6689791.3 43, 354621.9 6689787.5 43, 354621.2 6689785.1 43, 354620.3 6689782.5 43, 354620 6689781.4 43, 354616.5 6689782.1 43, 354611.8 6689782.8 43, 354611.9 6689783.7 43, 354612.7 6689792.3 43, 354623 6689791.3 43))
BATIMENT0000000302927942;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;10.4;30.0;40.4;43.0;31.1;Cadastre;A 1.0;POLYGON Z ((354612.7 6689792.3 40.4, 354611.9 6689783.7 40.4, 354599.9 6689784.5 40.4, 354600.9 6689793.5 40.4, 354612.7 6689792.3 40.4))
BATIMENT0000000302927935;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;16.0;29.0;45.0;49.3;31.8;Cadastre;A 1.0;POLYGON Z ((354600.9 6689793.5 45, 354599.9 6689784.5 45, 354599.5 6689782.9 45, 354585.8 6689784.2 45, 354577.6 6689785.1 45, 354578.8 6689795.8 45, 354600.9 6689793.5 45))
BATIMENT0000000302927934;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.1;29.4;43.5;44.7;31.7;Cadastre;;POLYGON Z ((354556.3 6689788.9 43.5, 354546.3 6689790 43.5, 354546 6689790.2 43.5, 354545.9 6689791.2 43.5, 354546.9 6689800.9 43.5, 354562.6 6689797.7 43.5, 354578.8 6689795.8 43.5, 354577.6 6689785.1 43.5, 354577.4 6689783.1 43.5, 354573.2 6689783.5 43.5, 354573.5 6689786.8 43.5, 354570.1 6689787.3 43.5, 354556.3 6689788.9 43.5))
BATIMENT0000000302927886;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.4;31.6;40.0;44.2;31.7;Cadastre;A 1.0;POLYGON Z ((354572.5 6689806.7 40, 354572 6689817 40, 354579.4 6689817.3 40, 354579.8 6689805.9 40, 354572.5 6689806.7 40))
BATIMENT0000000302927883;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;11.5;31.6;43.1;47.1;31.7;Cadastre;A 1.0;POLYGON Z ((354586 6689805.2 43.1, 354585.3 6689819.5 43.1, 354599 6689820.2 43.1, 354599 6689819.5 43.1, 354599.9 6689803.8 43.1, 354586 6689805.2 43.1))
BATIMENT0000000302927884;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;10.7;31.6;42.3;45.8;32.0;Cadastre;A 1.0;POLYGON Z ((354579.8 6689805.9 42.3, 354579.4 6689817.3 42.3, 354579 6689824.9 42.3, 354582 6689824.9 42.3, 354582.3 6689820.1 42.3, 354585.2 6689820.2 42.3, 354585.3 6689819.5 42.3, 354586 6689805.2 42.3, 354579.8 6689805.9 42.3))
BATIMENT0000000302927885;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;31.7;40.0;43.4;32.0;Cadastre;A 1.0;POLYGON Z ((354571.6 6689827.4 40, 354578.8 6689827.7 40, 354579 6689824.9 40, 354579.4 6689817.3 40, 354572 6689817 40, 354571.6 6689827.4 40))
BATIMENT0000000302927856;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;00;00;10.3;31.9;42.2;43.9;32.0;Cadastre;A 1.0;POLYGON Z ((354557 6689827.4 42.2, 354553.6 6689827.5 42.2, 354552.8 6689827.4 42.2, 354552.3 6689838.7 42.2, 354553.5 6689838.7 42.2, 354555 6689838.7 42.2, 354563.4 6689839.1 42.2, 354564.4 6689821.6 42.2, 354564.4 6689819.1 42.2, 354565.1 6689808 42.2, 354564.2 6689807.7 42.2, 354557.4 6689809.2 42.2, 354557.4 6689819.5 42.2, 354557.3 6689822.1 42.2, 354557 6689827.4 42.2))
BATIMENT0000000302929055;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;5.0;00;00;11.3;28.9;40.2;48.8;29.5;Cadastre;A 1.0;POLYGON Z ((354663.8 6689796.8 40.2, 354666.7 6689808.3 40.2, 354668.1 6689814.5 40.2, 354668.3 6689815 40.2, 354669.2 6689818.7 40.2, 354673.7 6689817.9 40.2, 354674.6 6689817.7 40.2, 354673.4 6689803.1 40.2, 354678.2 6689802.8 40.2, 354679.3 6689816.9 40.2, 354684.3 6689815.9 40.2, 354684.5 6689811.6 40.2, 354684.4 6689794.6 40.2, 354663.8 6689796.8 40.2))
BATIMENT0000000302929051;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;3.0;10;20;10.2;29.5;39.7;41.6;30.8;Cadastre;C 0.9;POLYGON Z ((354646.7 6689815.8 39.7, 354639.4 6689816.4 39.7, 354635.4 6689816.6 39.7, 354635.1 6689814.3 39.7, 354663.9 6689808.9 39.7, 354665.2 6689815 39.7, 354668.1 6689814.5 39.7, 354666.7 6689808.3 39.7, 354663.8 6689796.8 39.7, 354659.3 6689797.3 39.7, 354645.5 6689799.8 39.7, 354645.3 6689798.8 39.7, 354626.9 6689800.8 39.7, 354629.3 6689821.6 39.7, 354639.2 6689821.2 39.7, 354639.2 6689824.4 39.7, 354642.5 6689824.9 39.7, 354642.6 6689821.2 39.7, 354646.3 6689821.1 39.7, 354647.3 6689822.7 39.7, 354648.4 6689822.9 39.7, 354648.8 6689820.9 39.7, 354646.8 6689821 39.7, 354646.8 6689816.4 39.7, 354646.7 6689815.8 39.7))
BATIMENT0000000302927982;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;19;20;10.4;29.0;39.4;;;Cadastre;A 1.0;POLYGON Z ((354710.3 6689822.8 39.4, 354709.7 6689806.4 39.4, 354709.1 6689797.2 39.4, 354711.9 6689796.8 39.4, 354711.6 6689792.9 39.4, 354704.7 6689793.6 39.4, 354703.6 6689793.7 39.4, 354703.2 6689803.5 39.4, 354704.2 6689803.3 39.4, 354704.7 6689803.1 39.4, 354705.8 6689829 39.4, 354710.6 6689829 39.4, 354710.3 6689822.8 39.4))
BATIMENT0000000302927979;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;6.6;27.9;34.5;42.2;29.2;Cadastre;A 1.0;POLYGON Z ((354697.8 6689794.3 34.5, 354697.5 6689798.5 34.5, 354695.5 6689824.3 34.5, 354695.6 6689827.3 34.5, 354695.5 6689829 34.5, 354700.9 6689829 34.5, 354701.9 6689814.9 34.5, 354700.9 6689814.8 34.5, 354701.6 6689803.9 34.5, 354703.2 6689803.5 34.5, 354703.6 6689793.7 34.5, 354697.8 6689794.3 34.5))
BATIMENT0000000302929059;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;6.2;29.8;36.0;;;Cadastre;C 0.1;POLYGON Z ((354664.7 6689815.6 36, 354664.3 6689813.9 36, 354653.2 6689816.1 36, 354653.3 6689820.8 36, 354658.6 6689820.7 36, 354669.4 6689819.9 36, 354669.2 6689818.7 36, 354668.3 6689815 36, 354664.7 6689815.6 36))
BATIMENT0000000302929056;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;28.8;35.1;36.4;29.4;Cadastre;;POLYGON Z ((354684.3 6689815.9 35.1, 354679.3 6689816.9 35.1, 354678.3 6689817.1 35.1, 354681.9 6689819.6 35.1, 354684.3 6689815.9 35.1))
BATIMENT0000000302929050;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;29.3;32.3;33.5;29.8;Cadastre;;POLYGON Z ((354649 6689817 32.3, 354646.8 6689816.4 32.3, 354646.8 6689821 32.3, 354648.8 6689820.9 32.3, 354649 6689817 32.3))
BATIMENT0000000302929061;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;29.4;35.3;36.7;29.8;Cadastre;;POLYGON Z ((354653.3 6689820.8 35.3, 354651.2 6689820.9 35.3, 354651.4 6689825.4 35.3, 354653.3 6689825.3 35.3, 354653.3 6689820.8 35.3))
BATIMENT0000000302929060;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.3;29.7;38.0;39.6;29.7;Cadastre;A 1.0;POLYGON Z ((354681.9 6689819.6 38, 354678.3 6689817.1 38, 354674.6 6689817.7 38, 354673.7 6689817.9 38, 354667.8 6689826.6 38, 354674.5 6689830.8 38, 354681.9 6689819.6 38))
BATIMENT0000000302929058;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;29.9;35.2;37.0;30.5;Cadastre;;POLYGON Z ((354642.9 6689827 35.2, 354643.1 6689825 35.2, 354642.5 6689824.9 35.2, 354639.2 6689824.4 35.2, 354634.7 6689823.8 35.2, 354634.4 6689825.8 35.2, 354642.9 6689827 35.2))
BATIMENT0000000302927908;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:09;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.8;28.0;32.8;37.5;29.8;Cadastre;;POLYGON Z ((354723.7 6689773.6 32.8, 354712.4 6689774.7 32.8, 354712.6 6689776.9 32.8, 354705.9 6689777.6 32.8, 354706.2 6689782.9 32.8, 354737 6689779.6 32.8, 354737 6689773.8 32.8, 354737 6689772 32.8, 354731.7 6689772.4 32.8, 354723.7 6689773.6 32.8))
BATIMENT0000000302927984;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;20;20;16.5;27.6;44.1;45.5;28.4;Cadastre;C 0.8;POLYGON Z ((354749.4 6689793 44.1, 354749.3 6689792.7 44.1, 354731.1 6689794.7 44.1, 354711.9 6689796.8 44.1, 354709.1 6689797.2 44.1, 354709.7 6689806.4 44.1, 354732.5 6689803.9 44.1, 354732.6 6689803.7 44.1, 354749.8 6689801.8 44.1, 354750.2 6689802.4 44.1, 354769.6 6689800 44.1, 354770.7 6689790.5 44.1, 354749.4 6689793 44.1))
BATIMENT0000000302927985;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.6;27.0;32.6;39.4;28.3;Cadastre;A 1.0;POLYGON Z ((354770.8 6689789.4 32.6, 354770.7 6689790.5 32.6, 354769.6 6689800 32.6, 354769.1 6689804.6 32.6, 354769 6689808.4 32.6, 354775.6 6689809.1 32.6, 354775.8 6689806 32.6, 354781.5 6689806.7 32.6, 354785.7 6689802 32.6, 354783.8 6689800 32.6, 354785.1 6689791.9 32.6, 354770.8 6689789.4 32.6))
BATIMENT0000000302927989;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;20;20;2.8;27.4;30.2;37.7;28.6;Cadastre;C 0.1;POLYGON Z ((354765.1 6689818.5 30.2, 354765.6 6689812.6 30.2, 354752.9 6689811.3 30.2, 354752.1 6689812.5 30.2, 354752.2 6689817.1 30.2, 354754.9 6689817.5 30.2, 354765.1 6689818.5 30.2))
BATIMENT0000000302927992;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;27.5;36.7;46.0;28.7;Cadastre;;POLYGON Z ((354768.6 6689812.9 36.7, 354765.6 6689812.6 36.7, 354765.1 6689818.5 36.7, 354768.4 6689818.7 36.7, 354768.6 6689812.9 36.7))
BATIMENT0000000302927991;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;17.6;27.1;44.7;47.0;28.1;Cadastre;A 1.0;POLYGON Z ((354797.4 6689813.3 44.7, 354791.5 6689807.6 44.7, 354790.4 6689808.8 44.7, 354787.7 6689806.3 44.7, 354786.3 6689806 44.7, 354782.3 6689810.6 44.7, 354781.7 6689810.1 44.7, 354779.2 6689812.4 44.7, 354779.4 6689813.1 44.7, 354775.2 6689817.3 44.7, 354784.5 6689826.5 44.7, 354797.4 6689813.3 44.7))
BATIMENT0000000302927988;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;12;20;15.8;27.5;43.4;47.2;29.0;Cadastre;A 1.0;POLYGON Z ((354784.5 6689826.5 43.4, 354775.2 6689817.3 43.4, 354770.2 6689812.5 43.4, 354768.8 6689812.2 43.4, 354768.6 6689812.9 43.4, 354768.4 6689818.7 43.4, 354765.1 6689818.5 43.4, 354754.9 6689817.5 43.4, 354754.6 6689823.6 43.4, 354768.1 6689824.8 43.4, 354768.9 6689826.1 43.4, 354769 6689828.1 43.4, 354767.7 6689829.7 43.4, 354766.4 6689829.7 43.4, 354766 6689831.4 43.4, 354773.2 6689838.1 43.4, 354784.5 6689826.5 43.4))
BATIMENT0000000302927983;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;11.0;28.0;39.1;39.7;29.7;Cadastre;C 0.2;POLYGON Z ((354717.6 6689829.3 39.1, 354742.2 6689829.7 39.1, 354742.4 6689833.5 39.1, 354751.7 6689833.4 39.1, 354751.7 6689829.6 39.1, 354752.1 6689829.6 39.1, 354752.1 6689823.5 39.1, 354710.3 6689822.8 39.1, 354710.6 6689829 39.1, 354717.6 6689829.3 39.1))
BATIMENT0000000302927986;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;7.0;30;20;7.4;28.6;36.0;48.7;29.8;Cadastre;A 1.0;POLYGON Z ((354718.8 6689835.5 36, 354724.2 6689840.8 36, 354729.2 6689845.7 36, 354742 6689858 36, 354747.8 6689864 36, 354764.8 6689846.6 36, 354773.2 6689838.1 36, 354766 6689831.4 36, 354766.4 6689829.7 36, 354752.1 6689829.6 36, 354751.7 6689829.6 36, 354751.7 6689833.4 36, 354742.4 6689833.5 36, 354742.2 6689829.7 36, 354717.6 6689829.3 36, 354718.8 6689835.5 36))
BATIMENT0000000302927987;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.1;29.0;37.1;38.4;29.4;Cadastre;C 0.3;POLYGON Z ((354722.6 6689843.6 37.1, 354714.6 6689852.2 37.1, 354719.1 6689856.7 37.1, 354723.8 6689851.8 37.1, 354727.1 6689848.1 37.1, 354729.2 6689845.7 37.1, 354724.2 6689840.8 37.1, 354722.6 6689843.6 37.1))
BATIMENT0000000302929053;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.8;29.8;37.6;39.5;30.9;Cadastre;A 1.0;POLYGON Z ((354630.4 6689835 37.6, 354632.5 6689835.3 37.6, 354634.4 6689825.8 37.6, 354634.7 6689823.8 37.6, 354639.2 6689824.4 37.6, 354639.2 6689821.2 37.6, 354629.3 6689821.6 37.6, 354628.1 6689827.7 37.6, 354626.8 6689834.9 37.6, 354629.4 6689835.1 37.6, 354630.4 6689835 37.6))
BATIMENT0000000302927978;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;5.0;28.3;33.3;38.9;29.6;Cadastre;A 1.0;POLYGON Z ((354690.1 6689824.1 33.3, 354684.2 6689832.7 33.3, 354689 6689836.2 33.3, 354687.3 6689839.3 33.3, 354688.2 6689840 33.3, 354693.6 6689840.3 33.3, 354693.7 6689836.8 33.3, 354699.5 6689837.1 33.3, 354699.6 6689837.8 33.3, 354703.4 6689837.9 33.3, 354703.7 6689829.2 33.3, 354700.9 6689829 33.3, 354695.5 6689829 33.3, 354695.2 6689830.3 33.3, 354694 6689829.5 33.3, 354694.3 6689827.5 33.3, 354695.6 6689827.3 33.3, 354695.5 6689824.3 33.3, 354690.1 6689824.1 33.3))
BATIMENT0000000302929062;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.1;29.8;37.9;39.6;30.1;Cadastre;A 1.0;POLYGON Z ((354666 6689825.5 37.9, 354660.1 6689834.2 37.9, 354668.4 6689839.9 37.9, 354674.5 6689830.8 37.9, 354667.8 6689826.6 37.9, 354666 6689825.5 37.9))
BATIMENT0000000302929054;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:00:51;2019-07-01 11:18:09;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;30.7;38.5;42.4;31.1;Cadastre;;POLYGON Z ((354625.3 6689841.9 38.5, 354625.3 6689842.6 38.5, 354628 6689843.9 38.5, 354629.4 6689835.1 38.5, 354626.8 6689834.9 38.5, 354625.3 6689841.9 38.5))
BATIMENT0000000302929063;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;29.8;38.0;39.7;30.3;Cadastre;A 1.0;POLYGON Z ((354658.1 6689837.1 38, 354656.9 6689838.9 38, 354656.3 6689837.9 38, 354653.5 6689836.2 38, 354652.2 6689838.4 38, 354654.7 6689840 38, 354664.1 6689846.3 38, 354668.4 6689839.9 38, 354660.1 6689834.2 38, 354658.1 6689837.1 38))
BATIMENT0000000302927976;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;7.2;29.1;36.3;38.7;30.2;Cadastre;A 1.0;POLYGON Z ((354675.6 6689846.1 36.3, 354682.2 6689850.2 36.3, 354684.1 6689851.5 36.3, 354688.6 6689844.5 36.3, 354686.4 6689843 36.3, 354688.2 6689840 36.3, 354687.3 6689839.3 36.3, 354689 6689836.2 36.3, 354684.2 6689832.7 36.3, 354675.6 6689846.1 36.3))
BATIMENT0000000302927980;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;2.7;28.1;30.8;33.5;29.5;Cadastre;C 0.3;POLYGON Z ((354703 6689846.6 30.8, 354707.3 6689846.8 30.8, 354707.2 6689841.8 30.8, 354705.5 6689840.8 30.8, 354705.5 6689838.1 30.8, 354703.4 6689837.9 30.8, 354703 6689846.6 30.8))
BATIMENT0000000302929064;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;40;20;6.2;29.5;35.7;39.8;30.4;Cadastre;A 1.0;POLYGON Z ((354651.3 6689845 35.7, 354650.2 6689844.3 35.7, 354649.4 6689845.6 35.7, 354660 6689852.5 35.7, 354664.1 6689846.3 35.7, 354654.7 6689840 35.7, 354651.3 6689845 35.7))
BATIMENT0000000302929065;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.8;29.5;38.3;40.4;30.4;Cadastre;A 1.0;POLYGON Z ((354648.2 6689847.5 38.3, 354651.2 6689849.5 38.3, 354648 6689854.1 38.3, 354655.6 6689859.1 38.3, 354660 6689852.5 38.3, 354649.4 6689845.6 38.3, 354648.2 6689847.5 38.3))
BATIMENT0000000302927977;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;28.7;31.0;32.3;30.2;Cadastre;;POLYGON Z ((354685.4 6689855.6 31, 354686.9 6689853.4 31, 354684.4 6689851.7 31, 354683.7 6689852.9 31, 354685.1 6689853.6 31, 354685.4 6689855.6 31))
BATIMENT0000000302929052;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-07-01 11:18:09;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;29.8;37.4;40.4;31.6;Cadastre;;POLYGON Z ((354606.5 6689866.4 37.4, 354614.6 6689866.3 37.4, 354615.5 6689861 37.4, 354621.5 6689862.1 37.4, 354622.7 6689855.6 37.4, 354624.2 6689847.9 37.4, 354625.3 6689842.6 37.4, 354625.3 6689841.9 37.4, 354626.8 6689834.9 37.4, 354628.1 6689827.7 37.4, 354629.3 6689821.6 37.4, 354626.9 6689800.8 37.4, 354618 6689801.8 37.4, 354619.6 6689816.3 37.4, 354618.4 6689816.4 37.4, 354618.9 6689820.9 37.4, 354618.4 6689825.9 37.4, 354614.4 6689825.2 37.4, 354606.5 6689866.4 37.4))
BATIMENT0000000302927857;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1918-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.3;32.0;42.3;43.7;32.0;Cadastre;A 1.0;POLYGON Z ((354563.4 6689839.1 42.3, 354555 6689838.7 42.3, 354553.5 6689838.7 42.3, 354553.1 6689846.2 42.3, 354563 6689847.5 42.3, 354563.4 6689839.1 42.3))
BATIMENT0000000302927860;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;10.6;32.0;42.6;46.2;32.0;Cadastre;A 1.0;POLYGON Z ((354552.3 6689846.1 42.6, 354552 6689854.7 42.6, 354557 6689855.6 42.6, 354562.5 6689856.3 42.6, 354563 6689847.5 42.6, 354553.1 6689846.2 42.6, 354552.3 6689846.1 42.6))
BATIMENT0000000302927865;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.3;31.7;41.0;43.7;31.8;Cadastre;A 1.0;POLYGON Z ((354570 6689860.2 41, 354579.1 6689860.5 41, 354579.5 6689854.6 41, 354579.1 6689854.5 41, 354570.4 6689854.1 41, 354570 6689860.2 41))
BATIMENT0000000302927861;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;03;10.4;31.5;42.0;43.7;31.8;Cadastre;C 0.4;POLYGON Z ((354556.8 6689859.4 42, 354562.4 6689860 42, 354562.5 6689856.3 42, 354557 6689855.6 42, 354556.8 6689859.4 42))
BATIMENT0000000302927863;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;31.4;34.5;35.2;31.8;Cadastre;;POLYGON Z ((354596.8 6689855.3 34.5, 354591.4 6689855.1 34.5, 354591.1 6689861 34.5, 354593.7 6689861.3 34.5, 354596.5 6689861.5 34.5, 354596.8 6689855.3 34.5))
BATIMENT0000000302927862;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;31.6;34.7;35.0;31.8;Cadastre;;POLYGON Z ((354584.9 6689860.8 34.7, 354584.7 6689863.3 34.7, 354593.6 6689863.7 34.7, 354593.7 6689861.3 34.7, 354591.1 6689861 34.7, 354584.9 6689860.8 34.7))
BATIMENT0000000302927864;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;4.6;31.4;36.1;44.0;31.9;Cadastre;A 1.0;POLYGON Z ((354569.5 6689870.5 36.1, 354578.8 6689870.7 36.1, 354596.1 6689871.3 36.1, 354596.5 6689861.5 36.1, 354593.7 6689861.3 36.1, 354593.6 6689863.7 36.1, 354593.5 6689865.5 36.1, 354595.1 6689865.9 36.1, 354595 6689867 36.1, 354579.5 6689866.3 36.1, 354579.6 6689863.5 36.1, 354584.8 6689863.8 36.1, 354584.7 6689863.3 36.1, 354584.9 6689860.8 36.1, 354579.1 6689860.5 36.1, 354570 6689860.2 36.1, 354569.5 6689870.5 36.1))
BATIMENT0000000302928229;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;8.6;31.9;40.5;41.8;32.3;Cadastre;A 1.0;POLYGON Z ((354561 6689866.8 40.5, 354550.4 6689865.7 40.5, 354549.8 6689876.5 40.5, 354551.9 6689876.7 40.5, 354551.6 6689882 40.5, 354552.1 6689882.1 40.5, 354560.1 6689884.1 40.5, 354561 6689866.8 40.5))
BATIMENT0000000302927867;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;12.8;31.6;44.4;48.7;32.0;Cadastre;C 0.6;POLYGON Z ((354568.8 6689886.9 44.4, 354577.9 6689887.3 44.4, 354578.8 6689870.7 44.4, 354569.5 6689870.5 44.4, 354568.8 6689886.9 44.4))
BATIMENT0000000302927975;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;30;7.6;29.0;36.6;37.2;30.2;Cadastre;A 1.0;POLYGON Z ((354680.9 6689857.1 36.6, 354683.4 6689858.6 36.6, 354685.4 6689855.6 36.6, 354685.1 6689853.6 36.6, 354683.7 6689852.9 36.6, 354684.4 6689851.7 36.6, 354684.1 6689851.5 36.6, 354682.2 6689850.2 36.6, 354675.6 6689846.1 36.6, 354664 6689863.4 36.6, 354671.6 6689870.8 36.6, 354680.9 6689857.1 36.6))
BATIMENT0000000302929066;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;8.9;29.5;38.4;41.6;30.5;Cadastre;A 1.0;POLYGON Z ((354655.6 6689859.1 38.4, 354648 6689854.1 38.4, 354647.4 6689853.7 38.4, 354641.3 6689862.8 38.4, 354649.7 6689868.1 38.4, 354655.6 6689859.1 38.4))
BATIMENT0000000302929067;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;6.4;29.7;36.2;39.5;30.7;Cadastre;A 1.0;POLYGON Z ((354640.1 6689867.2 36.2, 354647.2 6689871.9 36.2, 354649.7 6689868.1 36.2, 354641.3 6689862.8 36.2, 354640.6 6689863.8 36.2, 354638.4 6689862.3 36.2, 354636.7 6689865 36.2, 354640.1 6689867.2 36.2))
BATIMENT0000000302929068;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.1;29.9;39.0;40.8;31.2;Cadastre;A 1.0;POLYGON Z ((354630.8 6689881.5 39, 354637.8 6689886 39, 354647.2 6689871.9 39, 354640.1 6689867.2 39, 354630.8 6689881.5 39))
BATIMENT0000000302929085;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;6.2;29.5;35.8;40.7;30.3;Cadastre;A 1.0;POLYGON Z ((354663.7 6689877.3 35.8, 354667.5 6689881.2 35.8, 354665.8 6689883.5 35.8, 354668.3 6689885.6 35.8, 354672.2 6689880.4 35.8, 354660.1 6689868.3 35.8, 354659.2 6689868.3 35.8, 354654.6 6689875.3 35.8, 354661.5 6689879.9 35.8, 354663.7 6689877.3 35.8))
BATIMENT0000000302929087;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.9;30.7;38.6;40.7;30.9;Cadastre;A 1.0;POLYGON Z ((354650 6689882.1 38.6, 354656.8 6689886.5 38.6, 354657 6689886.6 38.6, 354659 6689888 38.6, 354663.2 6689881.4 38.6, 354661.5 6689879.9 38.6, 354654.6 6689875.3 38.6, 354650 6689882.1 38.6))
BATIMENT0000000302929146;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.9;29.2;35.2;40.0;29.9;Cadastre;;POLYGON Z ((354686.5 6689885.6 35.2, 354689.5 6689888.5 35.2, 354693.5 6689884 35.2, 354690.6 6689881.3 35.2, 354686.5 6689885.6 35.2))
BATIMENT0000000302929086;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.2;29.7;37.0;40.0;30.6;Cadastre;A 1.0;POLYGON Z ((354665.9 6689888.7 37, 354667.4 6689890 37, 354666.4 6689891 37, 354666.6 6689892.7 37, 354669.3 6689895.7 37, 354669.8 6689895.7 37, 354673.7 6689891.7 37, 354678.6 6689886.8 37, 354672.2 6689880.4 37, 354668.3 6689885.6 37, 354665.9 6689888.7 37))
BATIMENT0000000302929069;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;8.3;29.9;38.2;38.7;31.3;Cadastre;A 1.0;POLYGON Z ((354629.9 6689880.9 38.2, 354623.3 6689890.6 38.2, 354621.4 6689893.5 38.2, 354629.3 6689898.8 38.2, 354630.6 6689896.9 38.2, 354637.8 6689886 38.2, 354630.8 6689881.5 38.2, 354629.9 6689880.9 38.2))
BATIMENT0000000302929089;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.9;30.5;38.4;40.6;30.9;Cadastre;A 1.0;POLYGON Z ((354640.5 6689897.5 38.4, 354647 6689897.9 38.4, 354648.8 6689897.8 38.4, 354649.3 6689897.8 38.4, 354649.8 6689897.1 38.4, 354650.3 6689896.7 38.4, 354650.9 6689896.2 38.4, 354651.3 6689895.7 38.4, 354651.7 6689895.2 38.4, 354652.1 6689894.3 38.4, 354652.3 6689893.5 38.4, 354652.3 6689893.3 38.4, 354653.4 6689891.7 38.4, 354656.8 6689886.5 38.4, 354650 6689882.1 38.4, 354646.4 6689887.5 38.4, 354640 6689897.3 38.4, 354640.5 6689897.5 38.4))
BATIMENT0000000302929074;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;16;20;4.7;30.6;35.3;36.1;31.5;Cadastre;C 0.4;POLYGON Z ((354616.8 6689886.3 35.3, 354619.2 6689874 35.3, 354619.6 6689871.9 35.3, 354615.1 6689871.8 35.3, 354611.5 6689871.7 35.3, 354611.4 6689874.1 35.3, 354612.9 6689874.3 35.3, 354611.7 6689888.4 35.3, 354612.1 6689888.4 35.3, 354613.9 6689888.5 35.3, 354616.3 6689888.6 35.3, 354616.8 6689886.3 35.3))
BATIMENT0000000302927872;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;31.7;35.4;37.3;31.7;Cadastre;;POLYGON Z ((354599.7 6689879 35.4, 354597.8 6689879.1 35.4, 354597.2 6689882.4 35.4, 354595.9 6689882.3 35.4, 354596.1 6689879 35.4, 354595.6 6689878.9 35.4, 354595.7 6689873.8 35.4, 354593.8 6689873.8 35.4, 354593.6 6689879.6 35.4, 354593.5 6689882.7 35.4, 354593.2 6689887.8 35.4, 354599.1 6689888 35.4, 354599.4 6689883.5 35.4, 354599.7 6689879 35.4))
BATIMENT0000000302927875;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;31.6;34.8;34.9;31.7;Cadastre;;POLYGON Z ((354590.7 6689879.4 34.8, 354590.4 6689882.3 34.8, 354593.5 6689882.7 34.8, 354593.6 6689879.6 34.8, 354590.7 6689879.4 34.8))
BATIMENT0000000302927877;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;31.5;34.0;34.6;31.5;Cadastre;;POLYGON Z ((354607 6689881.5 34, 354607 6689883.8 34, 354610.1 6689883.9 34, 354610.3 6689881.6 34, 354607 6689881.5 34))
BATIMENT0000000302927876;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;31.5;35.8;36.6;31.6;Cadastre;;POLYGON Z ((354609.8 6689888.4 35.8, 354610.1 6689883.9 35.8, 354607 6689883.8 35.8, 354607 6689881.5 35.8, 354607.1 6689878.5 35.8, 354605.1 6689878.4 35.8, 354605 6689879 35.8, 354604.4 6689888.1 35.8, 354609.8 6689888.4 35.8))
BATIMENT0000000302927873;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;16;20;4.0;31.7;35.7;;;Cadastre;C 0.4;POLYGON Z ((354602 6689888 35.7, 354604.4 6689888.1 35.7, 354605 6689879 35.7, 354602.4 6689878.8 35.7, 354602.1 6689883.7 35.7, 354599.4 6689883.5 35.7, 354599.1 6689888 35.7, 354602 6689888 35.7))
BATIMENT0000000302927871;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;16;20;3.9;31.7;35.6;36.9;31.7;Cadastre;C 0.5;POLYGON Z ((354590.4 6689882.3 35.6, 354590.7 6689879.4 35.6, 354587.1 6689879.2 35.6, 354586.9 6689882.5 35.6, 354586.6 6689887.6 35.6, 354590.2 6689887.7 35.6, 354593.2 6689887.8 35.6, 354593.5 6689882.7 35.6, 354590.4 6689882.3 35.6))
BATIMENT0000000302927870;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;16;20;3.3;31.5;34.8;36.6;31.8;Cadastre;C 0.5;POLYGON Z ((354584.4 6689882.4 34.8, 354584.5 6689880 34.8, 354581.4 6689879.8 34.8, 354581.3 6689882.3 34.8, 354578.7 6689882.3 34.8, 354578.5 6689887.3 34.8, 354586.6 6689887.6 34.8, 354586.9 6689882.5 34.8, 354584.4 6689882.4 34.8))
BATIMENT0000000302928230;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.6;32.1;40.7;41.4;32.3;Cadastre;A 1.0;POLYGON Z ((354550.1 6689891.5 40.7, 354559.6 6689893.8 40.7, 354560.1 6689884.1 40.7, 354552.1 6689882.1 40.7, 354550.1 6689891.5 40.7))
BATIMENT0000000302929071;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;31.0;34.4;35.7;31.5;Cadastre;;POLYGON Z ((354623.3 6689890.6 34.4, 354616.8 6689886.3 34.4, 354616.3 6689888.6 34.4, 354613.9 6689888.5 34.4, 354621.2 6689893.3 34.4, 354621.4 6689893.5 34.4, 354623.3 6689890.6 34.4))
BATIMENT0000000302927994;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;29.5;33.7;37.9;30.1;Cadastre;;POLYGON Z ((354736.9 6689857.5 33.7, 354733.3 6689861.3 33.7, 354735.6 6689863.7 33.7, 354736.3 6689864.3 33.7, 354739.8 6689860.4 33.7, 354736.9 6689857.5 33.7))
BATIMENT0000000302927993;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;25;23;9.5;29.0;38.5;41.7;30.1;Cadastre;A 1.0;POLYGON Z ((354739.8 6689860.4 38.5, 354736.3 6689864.3 38.5, 354742 6689869.9 38.5, 354747.8 6689864 38.5, 354742 6689858 38.5, 354739.8 6689860.4 38.5))
BATIMENT0000000302928165;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;7.0;50;20;9.0;28.6;37.7;50.4;29.5;Cadastre;A 1.0;POLYGON Z ((354768.9 6689852 37.7, 354750.8 6689870.3 37.7, 354757.3 6689876.8 37.7, 354769.4 6689873.5 37.7, 354776.6 6689871.6 37.7, 354779.9 6689869.2 37.7, 354781.5 6689867.7 37.7, 354768.9 6689852 37.7))
BATIMENT0000000302927995;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.6;29.0;37.6;40.2;30.1;Cadastre;A 1.0;POLYGON Z ((354730.6 6689869 37.6, 354736.7 6689875.3 37.6, 354742 6689869.9 37.6, 354736.3 6689864.3 37.6, 354735.6 6689863.7 37.6, 354730.6 6689869 37.6))
BATIMENT0000000302928185;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;29.5;39.2;42.2;30.7;Cadastre;B 0.8;POLYGON Z ((354710.5 6689883.2 39.2, 354719.3 6689892.1 39.2, 354732.3 6689878.7 39.2, 354728.5 6689874.7 39.2, 354725.5 6689874.9 39.2, 354722 6689871.4 39.2, 354710.5 6689883.2 39.2))
BATIMENT0000000302928166;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;3.0;10;20;6.7;29.0;35.7;44.8;30.1;Cadastre;A 1.0;POLYGON Z ((354757.5 6689877.8 35.7, 354757 6689878.4 35.7, 354756.6 6689878.9 35.7, 354756.2 6689879.5 35.7, 354755.8 6689880.2 35.7, 354755.5 6689880.8 35.7, 354755.1 6689881.6 35.7, 354754.8 6689882.5 35.7, 354754.6 6689883.4 35.7, 354754.5 6689884.3 35.7, 354754.4 6689885.2 35.7, 354754.5 6689886.2 35.7, 354754.9 6689889.7 35.7, 354757.2 6689892.1 35.7, 354762.2 6689897.3 35.7, 354763.3 6689897.4 35.7, 354768.3 6689896.6 35.7, 354766.6 6689881.7 35.7, 354775.5 6689878.6 35.7, 354774.6 6689877 35.7, 354775.4 6689876.8 35.7, 354788.5 6689893.2 35.7, 354791.4 6689896.6 35.7, 354799.6 6689890.3 35.7, 354781.5 6689867.7 35.7, 354779.9 6689869.2 35.7, 354776.6 6689871.6 35.7, 354769.4 6689873.5 35.7, 354757.3 6689876.8 35.7, 354757.5 6689877.8 35.7))
BATIMENT0000000302928167;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.7;29.2;37.0;45.9;30.5;Cadastre;A 1.0;POLYGON Z ((354743.1 6689878.1 37, 354731.4 6689889.8 37, 354735.3 6689893.5 37, 354735.1 6689893.8 37, 354741.7 6689900.1 37, 354741.9 6689900 37, 354745.8 6689903.7 37, 354757.2 6689892.1 37, 354754.9 6689889.7 37, 354743.1 6689878.1 37))
BATIMENT0000000302928168;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;00;00;11.6;29.6;41.2;44.6;30.3;Cadastre;C 0.2;POLYGON Z ((354768.3 6689896.6 41.2, 354763.3 6689897.4 41.2, 354762.6 6689903.9 41.2, 354764.5 6689904.1 41.2, 354768.2 6689904.7 41.2, 354777.5 6689903.3 41.2, 354791.5 6689900.8 41.2, 354793.1 6689899 41.2, 354807 6689916.2 41.2, 354815.2 6689909.8 41.2, 354812.8 6689906.6 41.2, 354813.2 6689906.3 41.2, 354802.4 6689893.3 41.2, 354802 6689893.4 41.2, 354799.6 6689890.3 41.2, 354791.4 6689896.6 41.2, 354788.5 6689893.2 41.2, 354768.3 6689896.6 41.2))
BATIMENT0000000302927764;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;15;40;8.0;31.4;39.4;;;Cadastre;A 1.0;POLYGON Z ((354725.6 6689914.8 39.4, 354728.9 6689912.1 39.4, 354727.9 6689910.9 39.4, 354731.4 6689907.1 39.4, 354723.6 6689899.7 39.4, 354717 6689906.5 39.4, 354724.4 6689913.7 39.4, 354725.6 6689914.8 39.4))
BATIMENT0000000302927762;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;9.7;31.1;40.8;43.9;31.1;Cadastre;A 1.0;POLYGON Z ((354708.4 6689915.2 40.8, 354715.8 6689922.3 40.8, 354724.4 6689913.7 40.8, 354717 6689906.5 40.8, 354708.4 6689915.2 40.8))
BATIMENT0000000302930859;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;20;20;14.2;7.1;21.3;23.9;7.5;Cadastre;A 1.0;POLYGON Z ((355460.8 6689806.7 21.3, 355443.8 6689817.6 21.3, 355441 6689819.4 21.3, 355445.3 6689825.8 21.3, 355446.4 6689825 21.3, 355451.5 6689821.5 21.3, 355450.2 6689819.7 21.3, 355450.3 6689818 21.3, 355452.8 6689816.1 21.3, 355454.5 6689817 21.3, 355455.4 6689818.3 21.3, 355464.6 6689812.7 21.3, 355460.8 6689806.7 21.3))
BATIMENT0000000302930853;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;10.9;7.3;18.2;23.7;7.6;Cadastre;A 1.0;POLYGON Z ((355425.3 6689815.6 18.2, 355424.7 6689815.9 18.2, 355425.7 6689817.3 18.2, 355427.2 6689819.3 18.2, 355428.4 6689818.6 18.2, 355434.4 6689815.4 18.2, 355435.8 6689817.9 18.2, 355430.2 6689821.2 18.2, 355429 6689822 18.2, 355431.4 6689825.4 18.2, 355441 6689819.4 18.2, 355443.8 6689817.6 18.2, 355441.6 6689813.9 18.2, 355444 6689812.7 18.2, 355443.8 6689812.2 18.2, 355442.1 6689809.1 18.2, 355433.2 6689813.3 18.2, 355432.5 6689812.1 18.2, 355431 6689812.8 18.2, 355425.3 6689815.6 18.2))
BATIMENT0000000302930854;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;14;29;11.3;6.8;18.1;24.7;8.0;Cadastre;A 1.0;POLYGON Z ((355419.6 6689827.4 18.1, 355419.4 6689827 18.1, 355418.1 6689828 18.1, 355415.8 6689826 18.1, 355416.4 6689825.5 18.1, 355416.5 6689825.3 18.1, 355416.5 6689825.2 18.1, 355416.5 6689824.9 18.1, 355416.4 6689824.7 18.1, 355416.3 6689824.6 18.1, 355416.2 6689824.4 18.1, 355416.5 6689824 18.1, 355416.6 6689823.4 18.1, 355416.6 6689823.1 18.1, 355416.6 6689822.9 18.1, 355416.5 6689822.6 18.1, 355416.4 6689822.5 18.1, 355416.2 6689822.2 18.1, 355416 6689822 18.1, 355415.9 6689821.9 18.1, 355415.7 6689821.8 18.1, 355415.6 6689821.8 18.1, 355415.4 6689821.7 18.1, 355415.1 6689821.6 18.1, 355415 6689821.6 18.1, 355414.7 6689821.6 18.1, 355414.4 6689821.6 18.1, 355412.2 6689823 18.1, 355409.4 6689820.5 18.1, 355414.2 6689818.3 18.1, 355424.6 6689813.9 18.1, 355425.3 6689815.6 18.1, 355431 6689812.8 18.1, 355427.2 6689805.1 18.1, 355421.3 6689807.7 18.1, 355402.7 6689816.1 18.1, 355397 6689818.7 18.1, 355412 6689831.7 18.1, 355416.1 6689835.1 18.1, 355422.4 6689831.1 18.1, 355431.4 6689825.4 18.1, 355429 6689822 18.1, 355428.6 6689821.3 18.1, 355419.6 6689827.4 18.1))
BATIMENT0000000302930863;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;7.3;13.7;18.0;7.6;Cadastre;;POLYGON Z ((355429 6689822 13.7, 355430.2 6689821.2 13.7, 355428.4 6689818.6 13.7, 355427.2 6689819.3 13.7, 355427.9 6689820.5 13.7, 355428.6 6689821.3 13.7, 355429 6689822 13.7))
BATIMENT0000000302930849;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;14.5;7.0;21.5;23.2;7.6;Cadastre;A 1.0;POLYGON Z ((355464.6 6689812.7 21.5, 355455.4 6689818.3 21.5, 355454.2 6689819.1 21.5, 355456.1 6689822.1 21.5, 355453.2 6689824.1 21.5, 355451.5 6689821.5 21.5, 355446.4 6689825 21.5, 355446.9 6689825.8 21.5, 355443.5 6689828.3 21.5, 355445.8 6689831.3 21.5, 355449.2 6689828.9 21.5, 355452.3 6689833.4 21.5, 355452.8 6689833 21.5, 355456.9 6689829.8 21.5, 355456.3 6689829 21.5, 355468.9 6689819.5 21.5, 355464.6 6689812.7 21.5))
BATIMENT0000000302930848;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;10.9;7.1;18.0;24.0;7.6;Cadastre;A 1.0;POLYGON Z ((355468.9 6689819.5 18, 355456.3 6689829 18, 355456.9 6689829.8 18, 355452.8 6689833 18, 355457 6689838.2 18, 355460.8 6689834.9 18, 355473.1 6689826.4 18, 355468.9 6689819.5 18))
BATIMENT0000000302930852;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;14;29;14.4;6.9;21.3;23.7;7.5;Cadastre;A 1.0;POLYGON Z ((355422.4 6689831.1 21.3, 355416.1 6689835.1 21.3, 355423 6689841.1 21.3, 355442.9 6689827.4 21.3, 355445.3 6689825.8 21.3, 355441 6689819.4 21.3, 355431.4 6689825.4 21.3, 355422.4 6689831.1 21.3), (355434.7 6689826.9 21.3, 355435.3 6689827.9 21.3, 355429.6 6689831.8 21.3, 355428.8 6689830.7 21.3, 355430.9 6689829.3 21.3, 355431 6689829.4 21.3, 355434.7 6689826.9 21.3))
BATIMENT0000000302930851;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;20;20;14.6;6.9;21.5;22.5;7.5;Cadastre;A 1.0;POLYGON Z ((355432.5 6689849 21.5, 355437.5 6689844 21.5, 355439.3 6689843.4 21.5, 355444.4 6689839.5 21.5, 355442.6 6689836.7 21.5, 355438.7 6689838.6 21.5, 355437.7 6689837.1 21.5, 355444.9 6689832.3 21.5, 355448 6689836.7 21.5, 355452.3 6689833.4 21.5, 355449.2 6689828.9 21.5, 355445.8 6689831.3 21.5, 355443.5 6689828.3 21.5, 355442.9 6689827.4 21.5, 355423 6689841.1 21.5, 355432.5 6689849 21.5))
BATIMENT0000000302930847;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1680-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;29;7.4;6.5;14.0;23.0;7.2;Cadastre;A 1.0;POLYGON Z ((355439.5 6689855.1 14, 355450 6689844.3 14, 355451.4 6689843 14, 355447.9 6689839 14, 355442.1 6689843.8 14, 355441 6689845.2 14, 355439.9 6689844.2 14, 355441 6689843.2 14, 355449.7 6689836.3 14, 355453.5 6689841.1 14, 355457 6689838.2 14, 355452.8 6689833 14, 355452.3 6689833.4 14, 355448 6689836.7 14, 355444.4 6689839.5 14, 355439.3 6689843.4 14, 355437.5 6689844 14, 355432.5 6689849 14, 355439.5 6689855.1 14))
BATIMENT0000000302930846;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;9.8;6.6;16.5;23.4;7.5;Cadastre;A 1.0;POLYGON Z ((355457 6689838.2 16.5, 355453.5 6689841.1 16.5, 355451.4 6689843 16.5, 355450 6689844.3 16.5, 355439.5 6689855.1 16.5, 355444.6 6689859.4 16.5, 355448.9 6689863.3 16.5, 355458.3 6689852.1 16.5, 355482.2 6689841 16.5, 355473.1 6689826.4 16.5, 355460.8 6689834.9 16.5, 355457 6689838.2 16.5), (355464.9 6689834.8 16.5, 355465.8 6689836.4 16.5, 355462.8 6689838.1 16.5, 355461.9 6689836.7 16.5, 355464.9 6689834.8 16.5))
BATIMENT0000000302930861;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.4;7.0;21.4;24.1;8.4;Cadastre;;POLYGON Z ((355401.2 6689809.7 21.4, 355398.4 6689810.3 21.4, 355396.2 6689800.7 21.4, 355398 6689800.2 21.4, 355398.8 6689799.1 21.4, 355398.3 6689796.8 21.4, 355397.1 6689796.1 21.4, 355395.2 6689796.5 21.4, 355392.7 6689785.2 21.4, 355385 6689787.6 21.4, 355384.6 6689788.8 21.4, 355390 6689812.3 21.4, 355397 6689818.7 21.4, 355402.7 6689816.1 21.4, 355401.2 6689809.7 21.4))
BATIMENT0000000302930529;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;12.0;6.7;18.7;27.2;7.7;Cadastre;C 0.1;POLYGON Z ((355325.1 6689876.8 18.7, 355321.5 6689873.2 18.7, 355332.5 6689861.6 18.7, 355333.7 6689862.9 18.7, 355332.4 6689864.4 18.7, 355349.9 6689881.2 18.7, 355353 6689878 18.7, 355357.1 6689882 18.7, 355346 6689893.3 18.7, 355354.2 6689901.2 18.7, 355365.2 6689889.9 18.7, 355362.7 6689887.5 18.7, 355364 6689886.3 18.7, 355357.6 6689880.1 18.7, 355365.7 6689871.5 18.7, 355364.4 6689870.3 18.7, 355363.2 6689871.6 18.7, 355360.4 6689868.9 18.7, 355361.1 6689868.2 18.7, 355358.3 6689865.4 18.7, 355356.3 6689865 18.7, 355353.7 6689862.4 18.7, 355353.2 6689860.9 18.7, 355347 6689854.9 18.7, 355345.3 6689854.4 18.7, 355342.9 6689852.1 18.7, 355342.6 6689850.5 18.7, 355339.1 6689847.2 18.7, 355338.6 6689847.7 18.7, 355335.5 6689844.5 18.7, 355332.8 6689847.3 18.7, 355331.4 6689845.9 18.7, 355329.3 6689848.1 18.7, 355328 6689846.9 18.7, 355327.5 6689847.4 18.7, 355327 6689846.6 18.7, 355316.3 6689862.5 18.7, 355317.3 6689863.6 18.7, 355317 6689864 18.7, 355320 6689866.7 18.7, 355315.2 6689871.4 18.7, 355318.3 6689874.3 18.7, 355323.1 6689878.9 18.7, 355325.1 6689876.8 18.7))
BATIMENT0000000302930528;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.0;7.2;19.2;21.8;8.0;Cadastre;A 1.0;POLYGON Z ((355305.5 6689887.9 19.2, 355304.7 6689887 19.2, 355303.2 6689888.5 19.2, 355303.9 6689889.3 19.2, 355302.3 6689891.1 19.2, 355311.9 6689900.4 19.2, 355313.8 6689898.4 19.2, 355314.6 6689899.1 19.2, 355315.9 6689897.7 19.2, 355315.3 6689897 19.2, 355324.7 6689887.1 19.2, 355325.3 6689887.9 19.2, 355327 6689886 19.2, 355326.4 6689885.4 19.2, 355328.1 6689883.7 19.2, 355323.1 6689878.9 19.2, 355318.3 6689874.3 19.2, 355316.6 6689876.1 19.2, 355315.9 6689875.4 19.2, 355314.1 6689877.2 19.2, 355314.9 6689878 19.2, 355305.5 6689887.9 19.2))
BATIMENT0000000314673257;Indifférenciée;Commercial et services;;Non;En service;2012-10-24 17:24:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;15.2;9.2;24.4;;;Cadastre;C 0.4;POLYGON Z ((355366.4 6689888.7 24.4, 355393.1 6689914.9 24.4, 355385.1 6689923.4 24.4, 355396.1 6689933.8 24.4, 355404.2 6689925.4 24.4, 355405.2 6689926.2 24.4, 355405.3 6689928.5 24.4, 355407 6689928.3 24.4, 355416 6689936.6 24.4, 355407.2 6689945.7 24.4, 355420.1 6689959.4 24.4, 355423.1 6689963.9 24.4, 355439.6 6689952.4 24.4, 355437.2 6689948.2 24.4, 355433.4 6689945 24.4, 355435.8 6689942.5 24.4, 355412.2 6689919.3 24.4, 355413.4 6689918 24.4, 355365.7 6689871.5 24.4, 355357.6 6689880.1 24.4, 355364 6689886.3 24.4, 355366.4 6689888.7 24.4))
BATIMENT0000000302930835;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;9.1;13.8;;;Cadastre;;POLYGON Z ((355310 6689931.7 13.8, 355310.3 6689931.7 13.8, 355310.9 6689931.6 13.8, 355311.5 6689931.4 13.8, 355312 6689931.2 13.8, 355312.3 6689931.1 13.8, 355312.5 6689931 13.8, 355313 6689930.6 13.8, 355313.3 6689930.5 13.8, 355313.7 6689930.1 13.8, 355314.1 6689929.7 13.8, 355314.3 6689929.5 13.8, 355314.5 6689929.2 13.8, 355314.7 6689929 13.8, 355314.8 6689928.8 13.8, 355315.1 6689928.3 13.8, 355315.2 6689928 13.8, 355315.4 6689927.7 13.8, 355315.6 6689927.2 13.8, 355315.7 6689926.6 13.8, 355315.8 6689926 13.8, 355315.8 6689925.4 13.8, 355315.8 6689925.2 13.8, 355315.8 6689924.9 13.8, 355315.7 6689924.3 13.8, 355315.7 6689924 13.8, 355315.6 6689923.7 13.8, 355315.5 6689923.4 13.8, 355308.6 6689924.8 13.8, 355309.8 6689931.7 13.8, 355310 6689931.7 13.8))
BATIMENT0000000302930834;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;4.7;9.1;13.8;;;Cadastre;C 0.2;POLYGON Z ((355294.4 6689927.5 13.8, 355295.7 6689934.5 13.8, 355309.8 6689931.7 13.8, 355308.6 6689924.8 13.8, 355294.4 6689927.5 13.8))
BATIMENT0000000029192393;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;;;11.6;9.7;;;;Imagerie aérienne;C 0.2;POLYGON Z ((355376.3 6689952.4 19.9, 355376.3 6689950.9 20, 355380.1 6689951.1 19.8, 355380.3 6689946.8 19.8, 355379 6689946.4 19.9, 355379 6689932.7 20.6, 355375.5 6689929.6 21, 355375.4 6689927.7 21, 355361 6689928.4 21.3, 355357.1 6689928.8 20.4, 355357.2 6689933.1 20.4, 355355.1 6689933.4 20, 355355.7 6689947.7 20, 355357.9 6689947.5 20.9, 355357.2 6689952.1 20.5, 355361.6 6689950.8 20.5, 355361.8 6689953.1 19.9, 355376.3 6689952.4 19.9))
BATIMENT0000000302931862;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.5;8.5;20.1;27.2;18.7;Cadastre;;POLYGON Z ((355245 6689925.6 20.1, 355248 6689925 20.1, 355248.1 6689925 20.1, 355255.4 6689923.6 20.1, 355255.5 6689924.1 20.1, 355256 6689926.4 20.1, 355257.2 6689932.5 20.1, 355261.1 6689952.3 20.1, 355370.7 6689987.4 20.1, 355375.9 6689981.5 20.1, 355373.4 6689979.2 20.1, 355368.4 6689974.6 20.1, 355368.7 6689973.4 20.1, 355361.1 6689966.4 20.1, 355292 6689943.7 20.1, 355284.9 6689906.4 20.1, 355284.6 6689904.8 20.1, 355284.6 6689904.6 20.1, 355284.4 6689903.6 20.1, 355283.5 6689900.1 20.1, 355251.9 6689906 20.1, 355242.3 6689907.8 20.1, 355241.6 6689908 20.1, 355242 6689910.1 20.1, 355245 6689925.6 20.1))
BATIMENT0000000302931860;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:59;;;MSS;MSS:222089;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.2;9.2;24.4;24.5;10.5;Cadastre;;POLYGON Z ((355407.2 6689945.7 24.4, 355387.9 6689965.7 24.4, 355383.4 6689973.2 24.4, 355395.7 6689984.4 24.4, 355399 6689981.1 24.4, 355412.3 6689967 24.4, 355413.7 6689968.3 24.4, 355419.1 6689962.6 24.4, 355418.1 6689961.4 24.4, 355420.1 6689959.4 24.4, 355407.2 6689945.7 24.4))
BATIMENT0000000302931859;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;8.1;14.8;23.2;10.2;Cadastre;;POLYGON Z ((355382.5 6689974.2 14.8, 355383.4 6689973.2 14.8, 355387.9 6689965.7 14.8, 355383.5 6689961.5 14.8, 355374.8 6689970.2 14.8, 355380.6 6689976 14.8, 355382.5 6689974.2 14.8))
BATIMENT0000000302930845;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;20;20;12.9;6.6;19.6;27.7;7.4;Cadastre;A 1.0;POLYGON Z ((355458.3 6689852.1 19.6, 355460.5 6689853.3 19.6, 355464.1 6689855.2 19.6, 355467.6 6689857.1 19.6, 355469.2 6689858 19.6, 355469.6 6689858.3 19.6, 355476.2 6689861.8 19.6, 355487.6 6689847 19.6, 355482.2 6689841 19.6, 355458.3 6689852.1 19.6))
BATIMENT0000000302930850;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.2;6.7;17.0;17.7;7.2;Cadastre;;POLYGON Z ((355464.1 6689855.2 17, 355460.5 6689853.3 17, 355459.3 6689854.6 17, 355462.6 6689856.9 17, 355464.1 6689855.2 17))
BATIMENT0000000302930844;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;11.4;6.3;17.8;20.0;7.2;Cadastre;A 1.0;POLYGON Z ((355456.6 6689869.7 17.8, 355465.2 6689859.8 17.8, 355467.6 6689857.1 17.8, 355464.1 6689855.2 17.8, 355462.6 6689856.9 17.8, 355461.3 6689858.5 17.8, 355460.2 6689857.4 17.8, 355460.8 6689856.6 17.8, 355459.7 6689855.8 17.8, 355459 6689856.5 17.8, 355458.2 6689855.8 17.8, 355459.3 6689854.6 17.8, 355460.5 6689853.3 17.8, 355458.3 6689852.1 17.8, 355448.9 6689863.3 17.8, 355456.6 6689869.7 17.8))
BATIMENT0000000302930843;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;6.2;17.5;24.2;7.2;Cadastre;;POLYGON Z ((355465.2 6689859.8 17.5, 355466.9 6689861.2 17.5, 355467.9 6689860.1 17.5, 355470.7 6689862.2 17.5, 355470.6 6689862.3 17.5, 355473.9 6689863.4 17.5, 355474 6689863.1 17.5, 355474.8 6689863.5 17.5, 355476.5 6689864.2 17.5, 355474.7 6689867.7 17.5, 355477.5 6689870.1 17.5, 355478.1 6689869.4 17.5, 355479.9 6689867.2 17.5, 355481.8 6689864.8 17.5, 355477.5 6689862.6 17.5, 355476.2 6689861.8 17.5, 355469.6 6689858.3 17.5, 355469.2 6689858 17.5, 355467.6 6689857.1 17.5, 355465.2 6689859.8 17.5))
BATIMENT0000000302930842;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;11.9;6.2;18.2;21.4;7.1;Cadastre;A 0.9;POLYGON Z ((355470.9 6689881.7 18.2, 355475.6 6689873.2 18.2, 355476.8 6689871 18.2, 355477.5 6689870.1 18.2, 355474.7 6689867.7 18.2, 355466.9 6689861.2 18.2, 355465.2 6689859.8 18.2, 355456.6 6689869.7 18.2, 355470.9 6689881.7 18.2))
BATIMENT0000000302931600;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;7.8;10.7;11.2;8.2;Cadastre;;POLYGON Z ((355448.9 6689970.6 10.7, 355449.5 6689971.3 10.7, 355450.2 6689970.6 10.7, 355449.8 6689969.9 10.7, 355448.9 6689970.6 10.7))
BATIMENT0000000302931602;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;6.8;7.7;14.5;20.1;9.1;Cadastre;A 1.0;POLYGON Z ((355445.7 6689972.3 14.5, 355443 6689974 14.5, 355447.7 6689980.5 14.5, 355444 6689983.6 14.5, 355447.9 6689988.3 14.5, 355457.5 6689979.5 14.5, 355459.6 6689981.8 14.5, 355465.5 6689970.5 14.5, 355465.1 6689967.1 14.5, 355454.3 6689957 14.5, 355441.5 6689966.7 14.5, 355445.7 6689972.3 14.5), (355451.8 6689968.2 14.5, 355453.5 6689970 14.5, 355454.4 6689970.6 14.5, 355454.1 6689971.6 14.5, 355455.3 6689972.9 14.5, 355449.8 6689977.7 14.5, 355447.5 6689974.6 14.5, 355446.2 6689972.9 14.5, 355448.9 6689970.6 14.5, 355449.8 6689969.9 14.5, 355451.8 6689968.2 14.5))
BATIMENT0000000302931601;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;8.0;13.0;14.0;8.6;Cadastre;;POLYGON Z ((355449.8 6689977.7 13, 355455.3 6689972.9 13, 355454.1 6689971.6 13, 355454.4 6689970.6 13, 355453.5 6689970 13, 355447.5 6689974.6 13, 355449.8 6689977.7 13))
BATIMENT0000000302931604;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.1;7.3;15.4;18.5;8.6;Cadastre;A 1.0;POLYGON Z ((355429 6689976 15.4, 355434.4 6689983.6 15.4, 355438.3 6689988.6 15.4, 355442.5 6689993.2 15.4, 355447.9 6689988.3 15.4, 355444 6689983.6 15.4, 355447.7 6689980.5 15.4, 355443 6689974 15.4, 355445.7 6689972.3 15.4, 355441.5 6689966.7 15.4, 355429 6689976 15.4))
BATIMENT0000000302931608;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;50;20;12.9;8.0;20.9;;;Cadastre;A 1.0;POLYGON Z ((355411.4 6689989.2 20.9, 355410.9 6689992.9 20.9, 355417.6 6690001.3 20.9, 355423.3 6689996.4 20.9, 355424 6689995.6 20.9, 355424.9 6689994.5 20.9, 355422.9 6689992 20.9, 355434.4 6689983.6 20.9, 355429 6689976 20.9, 355411.4 6689989.2 20.9))
BATIMENT0000000302931012;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;6.0;;;17.0;8.4;25.4;30.7;10.2;Cadastre;A 1.0;POLYGON Z ((355526.7 6689827.2 25.4, 355511.4 6689850.8 25.4, 355525 6689857.8 25.4, 355535.3 6689837.7 25.4, 355541.8 6689824.8 25.4, 355532.6 6689819.1 25.4, 355526.7 6689827.2 25.4))
BATIMENT0000000302931173;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;5.0;10;20;15.5;9.0;24.5;28.3;10.1;Cadastre;A 1.0;POLYGON Z ((355538.1 6689864.4 24.5, 355551.9 6689871.5 24.5, 355571.9 6689844.6 24.5, 355572.2 6689844.2 24.5, 355564.2 6689839.7 24.5, 355553.8 6689833.7 24.5, 355538.1 6689864.4 24.5))
BATIMENT0000000302930841;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;10;20;16.1;6.6;22.7;26.1;7.6;Cadastre;A 1.0;POLYGON Z ((355487.6 6689847 22.7, 355476.2 6689861.8 22.7, 355477.5 6689862.6 22.7, 355481.8 6689864.8 22.7, 355492.7 6689870.7 22.7, 355496.4 6689864.4 22.7, 355496.7 6689864.5 22.7, 355501.3 6689856.3 22.7, 355488.3 6689846.2 22.7, 355487.6 6689847 22.7))
BATIMENT0000000302930840;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;15.2;6.5;21.8;24.6;7.6;Cadastre;A 1.0;POLYGON Z ((355470.7 6689882 21.8, 355482.8 6689888.5 21.8, 355487.5 6689880.2 21.8, 355487.1 6689880 21.8, 355492.7 6689870.7 21.8, 355481.8 6689864.8 21.8, 355479.9 6689867.2 21.8, 355478.1 6689869.4 21.8, 355483.3 6689872.3 21.8, 355481.9 6689874.6 21.8, 355479.1 6689872.9 21.8, 355478.1 6689874.6 21.8, 355475.6 6689873.2 21.8, 355470.9 6689881.7 21.8, 355470.7 6689882 21.8))
BATIMENT0000000302930526;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;16.2;7.0;23.2;25.5;9.1;Cadastre;A 1.0;POLYGON Z ((355495.9 6689992.2 23.2, 355484 6689982.2 23.2, 355480.7 6689983 23.2, 355468.2 6690007.3 23.2, 355475.9 6690011.4 23.2, 355476.1 6690011.2 23.2, 355478 6690007.2 23.2, 355480.7 6690008.5 23.2, 355483.4 6690003.4 23.2, 355483.5 6690003.1 23.2, 355481.8 6690002.3 23.2, 355482.9 6690000.1 23.2, 355484.7 6690000.9 23.2, 355484.4 6690001.5 23.2, 355489.5 6690004.1 23.2, 355495.9 6689992.2 23.2))
BATIMENT0000000302944237;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.9;7.0;22.9;23.5;7.3;Cadastre;;POLYGON Z ((355489.5 6690004.1 22.9, 355484.4 6690001.5 22.9, 355483.5 6690003.1 22.9, 355483.4 6690003.4 22.9, 355488.6 6690005.9 22.9, 355489.5 6690004.1 22.9))
BATIMENT0000000302944248;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;6.8;19.0;21.7;7.6;Cadastre;;POLYGON Z ((355521.8 6690016.4 19, 355522.1 6690016.8 19, 355522.3 6690017.2 19, 355522.6 6690017.6 19, 355522.9 6690018 19, 355523.6 6690018.8 19, 355524.9 6690016.4 19, 355520.2 6690012.4 19, 355520.2 6690012.5 19, 355520.4 6690013.4 19, 355520.6 6690013.8 19, 355520.7 6690014.3 19, 355520.9 6690014.7 19, 355521.3 6690015.6 19, 355521.8 6690016.4 19))
BATIMENT0000000302930527;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;7.1;14.0;27.1;10.7;Cadastre;;POLYGON Z ((355502.9 6690022.2 14, 355505.6 6690024.5 14, 355508.1 6690019.9 14, 355518.3 6690028.5 14, 355523.6 6690018.8 14, 355522.9 6690018 14, 355522.6 6690017.6 14, 355522.3 6690017.2 14, 355522.1 6690016.8 14, 355521.8 6690016.4 14, 355521.3 6690015.6 14, 355520.9 6690014.7 14, 355520.7 6690014.3 14, 355520.6 6690013.8 14, 355520.4 6690013.4 14, 355520.2 6690012.5 14, 355520.2 6690012.4 14, 355495.9 6689992.2 14, 355489.5 6690004.1 14, 355488.6 6690005.9 14, 355487 6690008.9 14, 355487 6690009 14, 355491 6690012.3 14, 355489.8 6690013.6 14, 355488.8 6690012.7 14, 355486.8 6690013 14, 355485.3 6690012.2 14, 355485.3 6690012.1 14, 355479.1 6690023.9 14, 355481 6690024.9 14, 355481.6 6690031 14, 355481.3 6690031.7 14, 355481.3 6690031.8 14, 355482.6 6690032.5 14, 355484.6 6690033.5 14, 355497.2 6690040.2 14, 355502.5 6690030.3 14, 355488.3 6690031.8 14, 355487.4 6690023.8 14, 355489.3 6690023.6 14, 355490 6690023.9 14, 355490.5 6690024.1 14, 355491.3 6690024.3 14, 355491.5 6690024.4 14, 355492.1 6690024.5 14, 355492.6 6690024.5 14, 355492.9 6690024.5 14, 355493.4 6690024.6 14, 355493.9 6690024.5 14, 355494.7 6690024.5 14, 355495.2 6690024.4 14, 355495.5 6690024.3 14, 355495.7 6690024.3 14, 355496.3 6690024.1 14, 355496.5 6690024 14, 355497 6690023.9 14, 355497.3 6690023.8 14, 355497.5 6690023.7 14, 355498 6690023.4 14, 355498.4 6690023.2 14, 355498.7 6690023 14, 355499.3 6690022.6 14, 355502.9 6690022.2 14))
BATIMENT0000000302944247;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;6.7;19.5;21.9;7.5;Cadastre;;POLYGON Z ((355524.9 6690016.4 19.5, 355523.6 6690018.8 19.5, 355523.9 6690019.1 19.5, 355524.6 6690019.8 19.5, 355525 6690020.1 19.5, 355525.3 6690020.4 19.5, 355525.7 6690020.7 19.5, 355526.1 6690020.9 19.5, 355527 6690021.4 19.5, 355527.4 6690021.7 19.5, 355528.3 6690022.1 19.5, 355528.7 6690022.3 19.5, 355529.1 6690022.5 19.5, 355529.6 6690022.6 19.5, 355530.5 6690022.9 19.5, 355531 6690023 19.5, 355532 6690023.2 19.5, 355532.4 6690023.2 19.5, 355533.1 6690023.3 19.5, 355524.9 6690016.4 19.5))
BATIMENT0000000302944241;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;7.4;17.7;18.9;10.6;Cadastre;;POLYGON Z ((355480.5 6690036.5 17.7, 355482.6 6690037.4 17.7, 355483.8 6690035.2 17.7, 355481.7 6690034.2 17.7, 355482.6 6690032.5 17.7, 355481.3 6690031.8 17.7, 355481.3 6690031.7 17.7, 355476.3 6690029.1 17.7, 355475.5 6690028.7 17.7, 355474.7 6690030.2 17.7, 355474 6690031.8 17.7, 355473.3 6690033.3 17.7, 355480.5 6690036.5 17.7))
BATIMENT0000000302931603;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;20;20;12.9;8.0;20.9;23.0;9.1;Cadastre;A 1.0;POLYGON Z ((355459.6 6689981.8 20.9, 355457.5 6689979.5 20.9, 355447.9 6689988.3 20.9, 355442.5 6689993.2 20.9, 355441.3 6689994.5 20.9, 355449.4 6690001.9 20.9, 355459.6 6689981.8 20.9))
BATIMENT0000000302931607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;7.5;14.0;15.7;7.9;Cadastre;;POLYGON Z ((355423.3 6689996.4 14, 355423.4 6689997.8 14, 355423.8 6689997.4 14, 355425.9 6689999.9 14, 355427 6689999 14, 355424 6689995.6 14, 355423.3 6689996.4 14))
BATIMENT0000000302931606;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;9.1;7.0;16.2;21.0;8.8;Cadastre;A 1.0;POLYGON Z ((355424.6 6690009.8 16.2, 355431.5 6690004.9 16.2, 355432.5 6690003.9 16.2, 355441.3 6689994.5 16.2, 355442.5 6689993.2 16.2, 355438.3 6689988.6 16.2, 355430.7 6689995.4 16.2, 355427.4 6689992.1 16.2, 355424.9 6689994.5 16.2, 355424 6689995.6 16.2, 355427 6689999 16.2, 355425.9 6689999.9 16.2, 355423.8 6689997.4 16.2, 355423.4 6689997.8 16.2, 355423.3 6689996.4 16.2, 355417.6 6690001.3 16.2, 355424.6 6690009.8 16.2))
BATIMENT0000000302931605;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;20;20;11.8;7.3;19.2;23.0;9.7;Cadastre;A 1.0;POLYGON Z ((355449.4 6690001.9 19.2, 355441.3 6689994.5 19.2, 355432.5 6690003.9 19.2, 355443 6690014.5 19.2, 355449.4 6690001.9 19.2))
BATIMENT0000000302944278;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;10;10;14.0;8.0;22.0;25.4;10.1;Cadastre;A 1.0;POLYGON Z ((355434.9 6690022.5 22, 355435.5 6690022.6 22, 355440.1 6690020.2 22, 355443 6690014.5 22, 355432.5 6690003.9 22, 355431.5 6690004.9 22, 355424.6 6690009.8 22, 355434.9 6690022.5 22))
BATIMENT0000000302944238;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;17.5;7.0;24.5;26.5;10.6;Cadastre;A 1.0;POLYGON Z ((355469.7 6690025.6 24.5, 355475.5 6690028.7 24.5, 355476.3 6690029.1 24.5, 355479.1 6690023.9 24.5, 355485.3 6690012.1 24.5, 355485.3 6690012.2 24.5, 355487 6690009 24.5, 355487 6690008.9 24.5, 355488.6 6690005.9 24.5, 355483.4 6690003.4 24.5, 355480.7 6690008.5 24.5, 355479.5 6690010.8 24.5, 355477.9 6690012.2 24.5, 355476.1 6690011.2 24.5, 355475.9 6690011.4 24.5, 355468.2 6690007.3 24.5, 355461.1 6690021.1 24.5, 355469.7 6690025.6 24.5), (355474.6 6690019.7 24.5, 355475.5 6690017.9 24.5, 355476 6690016.9 24.5, 355478 6690017.9 24.5, 355478.6 6690016.9 24.5, 355479.8 6690017.5 24.5, 355478.3 6690020.4 24.5, 355477.5 6690019.9 24.5, 355476.2 6690022.4 24.5, 355473.8 6690021.2 24.5, 355474.6 6690019.7 24.5))
BATIMENT0000000302944245;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.8;7.8;21.7;23.2;9.5;Cadastre;;POLYGON Z ((355474.6 6690019.7 21.7, 355475.7 6690020.2 21.7, 355476.7 6690018.4 21.7, 355475.5 6690017.9 21.7, 355474.6 6690019.7 21.7))
BATIMENT0000000302944239;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.4;8.6;24.0;26.3;9.7;Cadastre;;POLYGON Z ((355459 6690025.1 24, 355467.8 6690029.6 24, 355467.9 6690029.3 24, 355471.1 6690030.9 24, 355471.1 6690030.6 24, 355471.1 6690030.2 24, 355470.6 6690029.8 24, 355470.6 6690029.4 24, 355468.5 6690028.1 24, 355468.9 6690027.3 24, 355469.7 6690025.6 24, 355461.1 6690021.1 24, 355459 6690025.1 24))
BATIMENT0000000302944243;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;7.5;22.5;26.2;9.4;Cadastre;;POLYGON Z ((355469.7 6690025.6 22.5, 355468.9 6690027.3 22.5, 355474.7 6690030.2 22.5, 355475.5 6690028.7 22.5, 355469.7 6690025.6 22.5))
BATIMENT0000000302944246;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1790-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;10.4;8.0;18.5;24.3;10.2;Cadastre;A 1.0;POLYGON Z ((355478.3 6690040.9 18.5, 355480.5 6690036.5 18.5, 355473.3 6690033.3 18.5, 355474 6690031.8 18.5, 355471.1 6690030.2 18.5, 355471.1 6690030.6 18.5, 355471.1 6690030.9 18.5, 355467.9 6690029.3 18.5, 355467.8 6690029.6 18.5, 355459 6690025.1 18.5, 355456.5 6690030 18.5, 355478.3 6690040.9 18.5), (355466.9 6690031.4 18.5, 355471.7 6690034.1 18.5, 355471.1 6690035 18.5, 355470.3 6690034.1 18.5, 355468.2 6690033 18.5, 355467.1 6690033.1 18.5, 355466.4 6690032.4 18.5, 355466.9 6690031.4 18.5))
BATIMENT0000000302931861;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;63.0;6.0;;;21.7;10.8;32.6;36.7;17.9;Cadastre;C 0.8;POLYGON Z ((355380.6 6689976 32.6, 355376.4 6689980.6 32.6, 355375.9 6689981.5 32.6, 355370.7 6689987.4 32.6, 355261.1 6689952.3 32.6, 355264.4 6689969 32.6, 355270.3 6689971 32.6, 355274.5 6689972.3 32.6, 355340.5 6689994 32.6, 355372.9 6690004.6 32.6, 355373.3 6690003.3 32.6, 355373.9 6690003.5 32.6, 355373.7 6690004.1 32.6, 355374 6690004.5 32.6, 355374.5 6690005.1 32.6, 355375.8 6690005.1 32.6, 355377 6690004.3 32.6, 355377.8 6690003 32.6, 355377.5 6690002.7 32.6, 355377.7 6690002.4 32.6, 355378.3 6690002.9 32.6, 355393.5 6689986.7 32.6, 355394.4 6689985.6 32.6, 355395.7 6689984.4 32.6, 355383.4 6689973.2 32.6, 355382.5 6689974.2 32.6, 355380.6 6689976 32.6))
BATIMENT0000000302944355;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.2;9.8;21.0;25.7;12.9;Cadastre;A 1.0;POLYGON Z ((355404.7 6690054 21, 355406.8 6690050.1 21, 355406.9 6690048.8 21, 355405.2 6690044.7 21, 355379.6 6690055.8 21, 355391.7 6690061.4 21, 355392.4 6690061.6 21, 355396.2 6690063.4 21, 355403.3 6690066.9 21, 355405 6690067.7 21, 355407.3 6690061.5 21, 355409.3 6690055.9 21, 355408.5 6690055.5 21, 355404.7 6690054 21))
BATIMENT0000000302944359;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.3;11.9;17.3;20.2;14.1;Cadastre;C 0.4;POLYGON Z ((355391.7 6690061.4 17.3, 355385.9 6690073.6 17.3, 355389.8 6690083.8 17.3, 355391.6 6690084.4 17.3, 355392.3 6690081.8 17.3, 355393.8 6690078.7 17.3, 355393.5 6690077.6 17.3, 355390.1 6690076 17.3, 355396.2 6690063.4 17.3, 355392.4 6690061.6 17.3, 355391.7 6690061.4 17.3))
BATIMENT0000000302944358;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.1;12.4;20.5;23.7;17.1;Cadastre;A 1.0;POLYGON Z ((355357.1 6690065.6 20.5, 355366.3 6690082.4 20.5, 355373.7 6690079.2 20.5, 355380.1 6690094.7 20.5, 355386 6690092.5 20.5, 355385.9 6690092.2 20.5, 355388.8 6690091.3 20.5, 355388.7 6690090.8 20.5, 355392.1 6690089.8 20.5, 355389.8 6690083.8 20.5, 355385.9 6690073.6 20.5, 355391.7 6690061.4 20.5, 355379.6 6690055.8 20.5, 355357.1 6690065.6 20.5))
BATIMENT0000000302944371;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;00;00;11.5;14.5;26.0;29.8;16.6;Cadastre;A 1.0;POLYGON Z ((355352.9 6690067.4 26, 355332.3 6690076.5 26, 355338.3 6690084.1 26, 355348.7 6690079.8 26, 355350.4 6690082.8 26, 355352.5 6690082 26, 355351.1 6690078.6 26, 355353 6690078 26, 355355.9 6690083.6 26, 355354 6690084.6 26, 355354.5 6690086.2 26, 355361.7 6690083.1 26, 355352.9 6690067.4 26))
BATIMENT0000000302944357;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;14.8;11.8;26.7;30.8;13.7;Cadastre;C 0.9;POLYGON Z ((355412.8 6690071.2 26.7, 355405 6690067.7 26.7, 355403.3 6690066.9 26.7, 355401.7 6690070.1 26.7, 355398.3 6690068.7 26.7, 355394.4 6690076.5 26.7, 355396.1 6690077.5 26.7, 355395.2 6690080.2 26.7, 355396.2 6690080.7 26.7, 355394.1 6690085 26.7, 355391.6 6690084.4 26.7, 355389.8 6690083.8 26.7, 355392.1 6690089.8 26.7, 355405.5 6690085.6 26.7, 355412.8 6690071.2 26.7))
BATIMENT0000000302944370;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;8.2;15.0;23.2;28.9;16.1;Cadastre;A 1.0;POLYGON Z ((355315.5 6690083.8 23.2, 355318.8 6690091.3 23.2, 355320.7 6690095.7 23.2, 355322.5 6690099.6 23.2, 355340.2 6690087 23.2, 355338.3 6690084.1 23.2, 355332.3 6690076.5 23.2, 355315.5 6690083.8 23.2))
BATIMENT0000000302944362;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;30;7.5;14.7;22.2;23.9;17.0;Cadastre;A 1.0;POLYGON Z ((355352.5 6690092.7 22.2, 355354.4 6690096.5 22.2, 355356.3 6690098.8 22.2, 355358 6690099.9 22.2, 355360.2 6690098.8 22.2, 355360.8 6690099.8 22.2, 355369.2 6690097.7 22.2, 355362.4 6690084.4 22.2, 355361.7 6690083.1 22.2, 355354.5 6690086.2 22.2, 355354 6690086.4 22.2, 355352.4 6690088.2 22.2, 355347.6 6690090.7 22.2, 355351 6690093.2 22.2, 355350.9 6690093.4 22.2, 355352.5 6690092.7 22.2))
BATIMENT0000000302944364;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;11.3;14.9;26.2;28.9;16.7;Cadastre;A 1.0;POLYGON Z ((355304.6 6690088.7 26.2, 355312.6 6690107.2 26.2, 355317.2 6690103.9 26.2, 355315.8 6690100.7 26.2, 355312.4 6690094 26.2, 355313.6 6690093.7 26.2, 355314.8 6690096 26.2, 355318.3 6690094.6 26.2, 355317.4 6690092.1 26.2, 355318.8 6690091.3 26.2, 355315.5 6690083.8 26.2, 355304.6 6690088.7 26.2))
BATIMENT0000000302944361;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;10;7.3;12.8;20.2;21.7;16.6;Cadastre;C 0.6;POLYGON Z ((355374.8 6690096.2 20.2, 355360.7 6690101 20.2, 355362.1 6690106.1 20.2, 355384.4 6690098.4 20.2, 355385.8 6690096.5 20.2, 355385.8 6690096 20.2, 355386.9 6690094.8 20.2, 355386 6690092.5 20.2, 355380.1 6690094.7 20.2, 355374.8 6690096.2 20.2))
BATIMENT0000000302944254;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;10;20;14.2;8.6;22.8;24.4;10.2;Cadastre;A 1.0;POLYGON Z ((355453.6 6690035.8 22.8, 355477.4 6690047.9 22.8, 355480.4 6690042 22.8, 355478.3 6690040.9 22.8, 355456.5 6690030 22.8, 355453.6 6690035.8 22.8))
BATIMENT0000000302944356;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;10;20;16.2;9.8;26.0;29.8;11.3;Cadastre;A 1.0;POLYGON Z ((355430.2 6690037 26, 355427.8 6690034.7 26, 355408.6 6690043.2 26, 355412 6690049.4 26, 355413.4 6690048.7 26, 355412.6 6690048 26, 355413.5 6690047.4 26, 355414.3 6690048.2 26, 355418.9 6690046.3 26, 355424.3 6690048.6 26, 355430.2 6690037 26))
BATIMENT0000000302944646;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.2;9.8;22.0;22.9;9.9;Cadastre;;POLYGON Z ((355453.4 6690051.1 22, 355451.4 6690062.9 22, 355451.3 6690063.4 22, 355455 6690064.1 22, 355456.7 6690060.9 22, 355459.9 6690054.4 22, 355453.4 6690051.1 22))
BATIMENT0000000302944644;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;29;20;18.3;9.3;27.7;29.9;10.9;Cadastre;A 1.0;POLYGON Z ((355449.5 6690049.1 27.7, 355446.5 6690049.9 27.7, 355439.3 6690064.2 27.7, 355446.8 6690068 27.7, 355449.5 6690065.5 27.7, 355447.9 6690064.9 27.7, 355446.9 6690064.5 27.7, 355447.3 6690063.6 27.7, 355448.1 6690064 27.7, 355449.1 6690063.7 27.7, 355449.4 6690063.2 27.7, 355449.7 6690062.8 27.7, 355449.4 6690062.1 27.7, 355451.4 6690062.9 27.7, 355453.4 6690051.1 27.7, 355449.5 6690049.1 27.7))
BATIMENT0000000302944354;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;15.6;9.8;25.4;28.7;12.9;Cadastre;A 1.0;POLYGON Z ((355413.4 6690048.7 25.4, 355412 6690049.4 25.4, 355408.5 6690055.5 25.4, 355409.3 6690055.9 25.4, 355407.3 6690061.5 25.4, 355405 6690067.7 25.4, 355412.8 6690071.2 25.4, 355424.3 6690048.6 25.4, 355418.9 6690046.3 25.4, 355414.3 6690048.2 25.4, 355413.4 6690048.7 25.4), (355410.7 6690055.8 25.4, 355411.8 6690056.1 25.4, 355408.1 6690064.4 25.4, 355406.8 6690064 25.4, 355407.4 6690063.2 25.4, 355407.7 6690063.2 25.4, 355410.7 6690055.8 25.4))
BATIMENT0000000302944645;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;9.1;18.0;25.2;10.0;Cadastre;;POLYGON Z ((355451.4 6690062.9 18, 355449.4 6690062.1 18, 355449.7 6690062.8 18, 355449.4 6690063.2 18, 355449.1 6690063.7 18, 355448.1 6690064 18, 355447.3 6690063.6 18, 355446.9 6690064.5 18, 355447.9 6690064.9 18, 355449.5 6690065.5 18, 355449.9 6690065.4 18, 355450.3 6690065.2 18, 355450.9 6690065.2 18, 355451.3 6690063.4 18, 355451.4 6690062.9 18))
BATIMENT0000000302944641;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;12.9;8.2;21.2;23.1;9.6;Cadastre;C 0.8;POLYGON Z ((355472.4 6690060.8 21.2, 355459.9 6690054.4 21.2, 355456.7 6690060.9 21.2, 355464.8 6690064.9 21.2, 355464.6 6690076 21.2, 355472.2 6690076.2 21.2, 355472.4 6690060.8 21.2))
BATIMENT0000000302944649;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.6;9.3;27.0;27.7;10.3;Cadastre;;POLYGON Z ((355441.8 6690071.1 27, 355440.6 6690073 27, 355441.4 6690073.4 27, 355443.1 6690071.7 27, 355441.8 6690071.1 27))
BATIMENT0000000302944640;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;8.5;11.1;13.7;9.4;Cadastre;C 0.5;POLYGON Z ((355460.5 6690076.1 11.1, 355460.5 6690070 11.1, 355454.1 6690069.6 11.1, 355453.4 6690075.9 11.1, 355460.5 6690076.1 11.1))
BATIMENT0000000302944650;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;19.2;9.5;28.7;30.2;12.7;Cadastre;A 1.0;POLYGON Z ((355430.1 6690082.2 28.7, 355435.3 6690080.1 28.7, 355436.1 6690080.5 28.7, 355440.3 6690075.7 28.7, 355439.7 6690075.2 28.7, 355441.4 6690073.4 28.7, 355440.6 6690073 28.7, 355441.8 6690071.1 28.7, 355443.1 6690071.7 28.7, 355446.8 6690068 28.7, 355439.3 6690064.2 28.7, 355430.1 6690082.2 28.7))
BATIMENT0000000302944244;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;7.6;14.0;17.0;10.7;Cadastre;;POLYGON Z ((355482.6 6690032.5 14, 355481.7 6690034.2 14, 355483.8 6690035.2 14, 355484.6 6690033.5 14, 355482.6 6690032.5 14))
BATIMENT0000000302944240;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;7.8;15.0;18.7;10.7;Cadastre;A 1.0;POLYGON Z ((355482.8 6690050.7 15, 355484.9 6690047.1 15, 355489.3 6690038.6 15, 355496.5 6690042.4 15, 355496.7 6690042.5 15, 355497.8 6690040.4 15, 355497.2 6690040.2 15, 355484.6 6690033.5 15, 355483.8 6690035.2 15, 355482.6 6690037.4 15, 355480.4 6690042 15, 355477.4 6690047.9 15, 355482.8 6690050.7 15))
BATIMENT0000000302944253;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;7.9;11.2;13.7;8.7;Cadastre;;POLYGON Z ((355482.5 6690051.2 11.2, 355484 6690052.9 11.2, 355486.7 6690047.9 11.2, 355486.2 6690047.7 11.2, 355484.9 6690047.1 11.2, 355482.8 6690050.7 11.2, 355482.5 6690051.2 11.2))
BATIMENT0000000302944249;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;18.5;6.7;25.2;27.2;7.6;Cadastre;C 0.4;POLYGON Z ((355564.5 6690051.1 25.2, 355561.8 6690048.5 25.2, 355559.1 6690045.9 25.2, 355556.3 6690043.3 25.2, 355553.5 6690040.7 25.2, 355546.2 6690052.9 25.2, 355559.8 6690065.7 25.2, 355567.2 6690053.8 25.2, 355564.5 6690051.1 25.2))
BATIMENT0000000302944242;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;6.9;13.7;26.9;10.7;Cadastre;;POLYGON Z ((355542.6 6690058.9 13.7, 355546.2 6690052.9 13.7, 355553.5 6690040.7 13.7, 355550.6 6690038.2 13.7, 355548.6 6690036.3 13.7, 355544.7 6690032.9 13.7, 355533.1 6690023.3 13.7, 355532.4 6690023.2 13.7, 355532 6690023.2 13.7, 355531 6690023 13.7, 355530.5 6690022.9 13.7, 355529.6 6690022.6 13.7, 355529.1 6690022.5 13.7, 355528.7 6690022.3 13.7, 355528.3 6690022.1 13.7, 355527.4 6690021.7 13.7, 355527 6690021.4 13.7, 355526.1 6690020.9 13.7, 355525.7 6690020.7 13.7, 355525.3 6690020.4 13.7, 355525 6690020.1 13.7, 355524.6 6690019.8 13.7, 355523.9 6690019.1 13.7, 355523.6 6690018.8 13.7, 355518.3 6690028.5 13.7, 355508.1 6690019.9 13.7, 355505.6 6690024.5 13.7, 355511.2 6690029.4 13.7, 355502.5 6690030.3 13.7, 355497.2 6690040.2 13.7, 355497.8 6690040.4 13.7, 355505.9 6690044.7 13.7, 355506.2 6690044.1 13.7, 355515.1 6690048.7 13.7, 355520.8 6690052 13.7, 355506.3 6690078.8 13.7, 355520.6 6690095.4 13.7, 355530.9 6690078.2 13.7, 355524.9 6690071.1 13.7, 355523.2 6690069.1 13.7, 355521.5 6690067.1 13.7, 355523.5 6690060.6 13.7, 355527.1 6690063 13.7, 355526.9 6690063.2 13.7, 355526.8 6690063.5 13.7, 355526.7 6690063.8 13.7, 355526.5 6690064.3 13.7, 355526.4 6690064.7 13.7, 355526.4 6690064.9 13.7, 355526.4 6690065 13.7, 355526.4 6690065.3 13.7, 355526.4 6690065.6 13.7, 355526.4 6690065.7 13.7, 355526.5 6690066 13.7, 355526.5 6690066.1 13.7, 355526.5 6690066.3 13.7, 355526.6 6690066.6 13.7, 355526.7 6690066.7 13.7, 355526.8 6690066.9 13.7, 355527 6690067.3 13.7, 355527.1 6690067.4 13.7, 355527.2 6690067.7 13.7, 355527.4 6690067.8 13.7, 355527.5 6690067.9 13.7, 355527.6 6690068.1 13.7, 355527.9 6690068.3 13.7, 355528.2 6690068.5 13.7, 355534.5 6690072.3 13.7, 355538.9 6690064.9 13.7, 355542.6 6690058.9 13.7))
BATIMENT0000000302944252;Indifférenciée;Annexe;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;2.9;7.8;10.7;15.0;10.7;Cadastre;A 1.0;POLYGON Z ((355507.8 6690062.5 10.7, 355497.7 6690051.1 10.7, 355497 6690051.6 10.7, 355495.1 6690049.4 10.7, 355486.9 6690056.3 10.7, 355506.3 6690078.8 10.7, 355520.8 6690052 10.7, 355515.1 6690048.7 10.7, 355507.8 6690062.5 10.7))
BATIMENT0000000302944250;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.7;6.7;16.5;17.1;7.1;Cadastre;;POLYGON Z ((355523.2 6690069.1 16.5, 355524.9 6690071.1 16.5, 355527.6 6690068.1 16.5, 355527.5 6690067.9 16.5, 355527.4 6690067.8 16.5, 355527.2 6690067.7 16.5, 355527.1 6690067.4 16.5, 355527 6690067.3 16.5, 355526.8 6690066.9 16.5, 355526.7 6690066.7 16.5, 355526.6 6690066.6 16.5, 355526.5 6690066.3 16.5, 355526.5 6690066.1 16.5, 355526.5 6690066 16.5, 355526.4 6690065.7 16.5, 355526.4 6690065.6 16.5, 355523.2 6690069.1 16.5))
BATIMENT0000000302944251;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;4.0;;;10.1;7.5;17.6;22.0;8.5;Cadastre;A 1.0;POLYGON Z ((355534.5 6690072.3 17.6, 355530.9 6690078.2 17.6, 355520.6 6690095.4 17.6, 355531.1 6690107.6 17.6, 355532.4 6690105.8 17.6, 355532 6690105.6 17.6, 355532.6 6690104.5 17.6, 355533.2 6690104.9 17.6, 355535.4 6690101.2 17.6, 355534.8 6690100.9 17.6, 355535.4 6690099.9 17.6, 355535.7 6690100.1 17.6, 355536.3 6690099 17.6, 355536.1 6690098.8 17.6, 355536.7 6690097.9 17.6, 355537 6690098.1 17.6, 355539.2 6690094.6 17.6, 355538.7 6690094.3 17.6, 355539.2 6690093.5 17.6, 355539.5 6690093.7 17.6, 355540.4 6690092.4 17.6, 355540.2 6690092.2 17.6, 355540.7 6690091.3 17.6, 355541.6 6690091.9 17.6, 355543.7 6690088.3 17.6, 355542.8 6690087.8 17.6, 355543.3 6690086.8 17.6, 355543.6 6690087 17.6, 355544.4 6690085.6 17.6, 355544.2 6690085.5 17.6, 355544.7 6690084.6 17.6, 355545.2 6690084.9 17.6, 355547.2 6690081.5 17.6, 355546.7 6690081.2 17.6, 355547.3 6690080.3 17.6, 355547.5 6690080.4 17.6, 355548.3 6690079.2 17.6, 355548 6690079 17.6, 355548.6 6690078.1 17.6, 355549.1 6690078.3 17.6, 355551.2 6690074.9 17.6, 355550.8 6690074.6 17.6, 355551.3 6690073.7 17.6, 355551.5 6690073.9 17.6, 355552.2 6690072.8 17.6, 355538.9 6690064.9 17.6, 355534.5 6690072.3 17.6))
BATIMENT0000000302944690;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;10.7;7.2;17.9;20.9;8.2;Cadastre;A 1.0;POLYGON Z ((355488.3 6690073.5 17.9, 355484.4 6690074.8 17.9, 355484 6690102.3 17.9, 355491.5 6690096.3 17.9, 355491.6 6690096.6 17.9, 355500.8 6690088.1 17.9, 355500.8 6690087.9 17.9, 355488.3 6690073.5 17.9))
BATIMENT0000000302944689;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;14;20;11.0;7.6;18.6;24.6;8.2;Cadastre;A 1.0;POLYGON Z ((355508.3 6690096.3 18.6, 355501 6690087.7 18.6, 355500.8 6690087.9 18.6, 355500.8 6690088.1 18.6, 355491.6 6690096.6 18.6, 355493.4 6690098.4 18.6, 355494.5 6690097.3 18.6, 355496 6690095.9 18.6, 355496.5 6690096.9 18.6, 355498.6 6690099.3 18.6, 355496.4 6690101.4 18.6, 355499.1 6690104.2 18.6, 355501.1 6690102.4 18.6, 355507.9 6690096.4 18.6, 355508 6690096.4 18.6, 355508.3 6690096.3 18.6))
BATIMENT0000000302944642;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;6.9;8.5;15.5;21.2;13.3;Cadastre;A 1.0;POLYGON Z ((355436.1 6690080.5 15.5, 355442.5 6690083.5 15.5, 355430.3 6690107.1 15.5, 355448 6690114 15.5, 355449.7 6690104.9 15.5, 355452.6 6690082.2 15.5, 355453.3 6690076.7 15.5, 355451.2 6690075.7 15.5, 355448.8 6690080.2 15.5, 355445 6690078.1 15.5, 355451 6690066.5 15.5, 355451.2 6690065.8 15.5, 355451.3 6690065.3 15.5, 355450.9 6690065.2 15.5, 355450.3 6690065.2 15.5, 355449.9 6690065.4 15.5, 355449.5 6690065.5 15.5, 355446.8 6690068 15.5, 355443.1 6690071.7 15.5, 355441.4 6690073.4 15.5, 355439.7 6690075.2 15.5, 355440.3 6690075.7 15.5, 355436.1 6690080.5 15.5))
BATIMENT0000000302944639;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;5.0;00;00;11.4;7.5;19.0;24.0;9.4;Cadastre;A 1.0;POLYGON Z ((355464.6 6690076 19, 355464.6 6690076.2 19, 355460.5 6690076.1 19, 355453.4 6690075.9 19, 355453.3 6690076.7 19, 355452.6 6690082.2 19, 355458.9 6690082.2 19, 355457.6 6690092.9 19, 355458 6690092.9 19, 355457.9 6690100.1 19, 355459.9 6690100.2 19, 355459.8 6690106.2 19, 355466.3 6690106.5 19, 355471.8 6690106.8 19, 355472.2 6690076.2 19, 355464.6 6690076 19))
BATIMENT0000000302944647;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;17.7;11.5;29.3;31.9;13.3;Cadastre;A 1.0;POLYGON Z ((355419.5 6690102.9 29.3, 355430.3 6690107.1 29.3, 355442.5 6690083.5 29.3, 355436.1 6690080.5 29.3, 355435.3 6690080.1 29.3, 355430.1 6690082.2 29.3, 355419.5 6690102.9 29.3))
BATIMENT0000000302944651;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;7.9;10.1;16.0;9.1;Cadastre;;POLYGON Z ((355449.7 6690104.9 10.1, 355448 6690114 10.1, 355450.1 6690114.4 10.1, 355451.8 6690105.3 10.1, 355449.7 6690104.9 10.1))
BATIMENT0000000302944643;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;3.0;10;90;6.9;7.2;14.2;18.4;8.4;Cadastre;C 0.8;POLYGON Z ((355452.6 6690114.8 14.2, 355452.1 6690118.3 14.2, 355471.6 6690120.9 14.2, 355471.8 6690106.8 14.2, 355466.3 6690106.5 14.2, 355466 6690113.9 14.2, 355452.7 6690112.2 14.2, 355452.3 6690114.8 14.2, 355452.6 6690114.8 14.2))
BATIMENT0000000302944648;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;8.2;7.7;15.9;26.1;12.5;Cadastre;A 1.0;POLYGON Z ((355413.4 6690114.9 15.9, 355423.4 6690119.8 15.9, 355424.7 6690120.5 15.9, 355424.6 6690120.8 15.9, 355435 6690126.1 15.9, 355462.2 6690140.1 15.9, 355471.3 6690144.7 15.9, 355471.6 6690120.9 15.9, 355452.1 6690118.3 15.9, 355452.6 6690114.8 15.9, 355452.3 6690114.8 15.9, 355450.1 6690114.4 15.9, 355448 6690114 15.9, 355430.3 6690107.1 15.9, 355419.5 6690102.9 15.9, 355413.4 6690114.9 15.9))
BATIMENT0000000302944659;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;20;20;13.9;11.0;25.0;27.6;13.0;Cadastre;A 1.0;POLYGON Z ((355406.2 6690129.1 25, 355415.9 6690134.3 25, 355416 6690134.1 25, 355423.4 6690119.8 25, 355413.4 6690114.9 25, 355406.2 6690129.1 25))
BATIMENT0000000302944652;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;8.7;16.0;19.5;12.4;Cadastre;;POLYGON Z ((355435 6690126.1 16, 355427.7 6690140.4 16, 355431.5 6690142.5 16, 355440.4 6690147.3 16, 355442.2 6690148.2 16, 355446 6690150.3 16, 355454.3 6690154.8 16, 355462.2 6690140.1 16, 355435 6690126.1 16))
BATIMENT0000000302944653;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;13.8;11.4;25.2;27.8;13.5;Cadastre;C 0.6;POLYGON Z ((355396.8 6690147.5 25.2, 355403.4 6690151.2 25.2, 355406.5 6690152.9 25.2, 355406.6 6690152.6 25.2, 355408.5 6690148.9 25.2, 355409 6690149.2 25.2, 355410.2 6690146.8 25.2, 355413.5 6690140.4 25.2, 355413 6690140 25.2, 355413.9 6690138.2 25.2, 355415.2 6690139.8 25.2, 355429.1 6690146.9 25.2, 355429.3 6690146.6 25.2, 355431.5 6690142.5 25.2, 355427.7 6690140.4 25.2, 355416 6690134.1 25.2, 355415.9 6690134.3 25.2, 355406.2 6690129.1 25.2, 355396.8 6690147.5 25.2))
BATIMENT0000000302944656;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;10.0;14.5;17.6;12.9;Cadastre;;POLYGON Z ((355429.3 6690146.6 14.5, 355438.3 6690151.4 14.5, 355440.4 6690147.3 14.5, 355431.5 6690142.5 14.5, 355429.3 6690146.6 14.5))
BATIMENT0000000302944363;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;14.6;21.7;23.9;15.5;Cadastre;A 1.0;POLYGON Z ((355348.2 6690095.6 21.7, 355350.9 6690093.4 21.7, 355351 6690093.2 21.7, 355347.6 6690090.7 21.7, 355340.2 6690087 21.7, 355322.5 6690099.6 21.7, 355317.2 6690103.9 21.7, 355312.6 6690107.2 21.7, 355312.3 6690107.4 21.7, 355316 6690112.3 21.7, 355325.9 6690105.1 21.7, 355328.6 6690103.3 21.7, 355331.8 6690107 21.7, 355333.6 6690110 21.7, 355345.9 6690101.2 21.7, 355349.7 6690098.2 21.7, 355349.9 6690097.4 21.7, 355348.2 6690095.6 21.7))
BATIMENT0000000302944368;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;14.9;21.4;24.2;15.6;Cadastre;;POLYGON Z ((355322.5 6690099.6 21.4, 355320.7 6690095.7 21.4, 355319.4 6690096.8 21.4, 355319.4 6690097.5 21.4, 355317.2 6690099.1 21.4, 355317.5 6690099.6 21.4, 355315.8 6690100.7 21.4, 355317.2 6690103.9 21.4, 355322.5 6690099.6 21.4))
BATIMENT0000000302944360;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;15.0;12.1;27.2;30.0;13.7;Cadastre;C 0.7;POLYGON Z ((355389.4 6690093 27.2, 355387 6690097.5 27.2, 355380.9 6690109.6 27.2, 355390.5 6690115 27.2, 355405.5 6690085.6 27.2, 355392.1 6690089.8 27.2, 355388.7 6690090.8 27.2, 355388.8 6690091.3 27.2, 355389.4 6690093 27.2))
BATIMENT0000000302944369;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;7.7;13.8;21.5;23.5;15.3;Cadastre;A 1.0;POLYGON Z ((355355.3 6690101.1 21.5, 355358.1 6690107.5 21.5, 355362.1 6690106.1 21.5, 355360.7 6690101 21.5, 355355.3 6690101.1 21.5))
BATIMENT0000000302944366;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;10.7;13.7;24.5;27.9;15.4;Cadastre;A 1.0;POLYGON Z ((355349.9 6690097.4 24.5, 355349.7 6690098.2 24.5, 355345.9 6690101.2 24.5, 355353.7 6690111.1 24.5, 355356 6690114.3 24.5, 355348.9 6690120.2 24.5, 355350.9 6690123 24.5, 355352.7 6690122.3 24.5, 355354 6690124.5 24.5, 355349.6 6690128.7 24.5, 355353.5 6690130.5 24.5, 355358.6 6690122.6 24.5, 355359.5 6690123.2 24.5, 355355.9 6690128.8 24.5, 355358.7 6690131 24.5, 355364 6690120.6 24.5, 355366.7 6690121.7 24.5, 355369.9 6690116.6 24.5, 355369.1 6690115 24.5, 355363.2 6690118 24.5, 355360 6690111.3 24.5, 355358.1 6690107.5 24.5, 355355.3 6690101.1 24.5, 355355 6690100.6 24.5, 355353.3 6690099.3 24.5, 355352 6690097.8 24.5, 355351.3 6690096.5 24.5, 355349.9 6690097.4 24.5))
BATIMENT0000000302944384;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;13.3;21.5;23.0;13.7;Cadastre;;POLYGON Z ((355368.1 6690128.1 21.5, 355369.3 6690128.6 21.5, 355370.7 6690125.9 21.5, 355369.6 6690125.4 21.5, 355368.1 6690128.1 21.5))
BATIMENT0000000302944377;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;10;20;9.2;14.7;23.9;27.4;17.3;Cadastre;A 1.0;POLYGON Z ((355333.8 6690132.5 23.9, 355328.3 6690136.9 23.9, 355327.9 6690137.3 23.9, 355328.5 6690137.9 23.9, 355332.4 6690142.4 23.9, 355334.4 6690140.8 23.9, 355334.8 6690140.5 23.9, 355340.5 6690135.9 23.9, 355345.3 6690131.8 23.9, 355346.3 6690132.5 23.9, 355355.5 6690137.2 23.9, 355358.7 6690131 23.9, 355355.9 6690128.8 23.9, 355354.3 6690131.3 23.9, 355353.5 6690130.5 23.9, 355349.6 6690128.7 23.9, 355354 6690124.5 23.9, 355352.7 6690122.3 23.9, 355350.9 6690123 23.9, 355348.9 6690120.2 23.9, 355341.9 6690126.1 23.9, 355339 6690122.7 23.9, 355338.8 6690122.7 23.9, 355335.9 6690119.1 23.9, 355333.4 6690121.1 23.9, 355330 6690117.2 23.9, 355325.2 6690121 23.9, 355333.8 6690132.5 23.9), (355339.3 6690129.3 23.9, 355340.1 6690130.3 23.9, 355337.4 6690132.3 23.9, 355336.6 6690131.3 23.9, 355339.3 6690129.3 23.9))
BATIMENT0000000302944378;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;;;8.3;13.1;21.4;27.8;15.0;Cadastre;A 1.0;POLYGON Z ((355362 6690140.6 21.4, 355362.9 6690138.4 21.4, 355360.1 6690137 21.4, 355366.4 6690123.9 21.4, 355369.6 6690125.4 21.4, 355370.7 6690125.9 21.4, 355369.3 6690128.6 21.4, 355363.2 6690141.2 21.4, 355365.7 6690142.6 21.4, 355374.2 6690146.9 21.4, 355388.7 6690118.5 21.4, 355376.5 6690113.5 21.4, 355373.3 6690113.3 21.4, 355371.2 6690117.4 21.4, 355369.9 6690116.6 21.4, 355366.7 6690121.7 21.4, 355364 6690120.6 21.4, 355358.7 6690131 21.4, 355355.5 6690137.2 21.4, 355360.4 6690139.8 21.4, 355362 6690140.6 21.4))
BATIMENT0000000302944379;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;15.2;26.0;28.8;15.7;Cadastre;;POLYGON Z ((355343.4 6690137.6 26, 355346.3 6690132.5 26, 355345.3 6690131.8 26, 355340.5 6690135.9 26, 355343.4 6690137.6 26))
BATIMENT0000000302944373;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;00;00;6.9;15.9;22.8;27.5;26.2;Cadastre;A 1.0;POLYGON Z ((355301 6690143 22.8, 355311.5 6690151.6 22.8, 355328.5 6690137.9 22.8, 355327.9 6690137.3 22.8, 355328.3 6690136.9 22.8, 355319.5 6690125.5 22.8, 355316.4 6690127.8 22.8, 355313.8 6690124.5 22.8, 355296.1 6690137.6 22.8, 355301 6690143 22.8))
BATIMENT0000000302927869;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;31.5;38.8;39.4;31.6;Cadastre;;POLYGON Z ((354598.6 6689893.3 38.8, 354602 6689888 38.8, 354599.1 6689888 38.8, 354593.2 6689887.8 38.8, 354590.2 6689887.7 38.8, 354596.6 6689892 38.8, 354598.6 6689893.3 38.8))
BATIMENT0000000302929209;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.2;31.7;34.9;44.0;31.7;Cadastre;C 0.4;POLYGON Z ((354581.9 6689892.5 34.9, 354582.7 6689892.6 34.9, 354587.6 6689892.7 34.9, 354589.7 6689894.2 34.9, 354588.5 6689896.3 34.9, 354587.6 6689898 34.9, 354591.8 6689898.7 34.9, 354592.7 6689894.5 34.9, 354592.8 6689891.1 34.9, 354585.4 6689887.8 34.9, 354581.8 6689888 34.9, 354581.6 6689892.4 34.9, 354581.9 6689892.5 34.9))
BATIMENT0000000302929210;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;10;20;10.9;31.6;42.5;52.2;32.0;Cadastre;C 0.5;POLYGON Z ((354573.6 6689903.1 42.5, 354578.5 6689906.2 42.5, 354585.6 6689910.8 42.5, 354592.5 6689899 42.5, 354596.6 6689892 42.5, 354590.2 6689887.7 42.5, 354586.6 6689887.6 42.5, 354578.5 6689887.3 42.5, 354577.9 6689887.3 42.5, 354568.8 6689886.9 42.5, 354568.4 6689894.9 42.5, 354568.2 6689902.7 42.5, 354573.6 6689903.1 42.5), (354579.4 6689895.5 42.5, 354579.5 6689892.7 42.5, 354582.5 6689893 42.5, 354582.6 6689892.6 42.5, 354582.7 6689892.6 42.5, 354581.9 6689892.5 42.5, 354581.6 6689892.4 42.5, 354581.8 6689888 42.5, 354585.4 6689887.8 42.5, 354592.8 6689891.1 42.5, 354592.7 6689894.5 42.5, 354591.8 6689898.7 42.5, 354587.6 6689898 42.5, 354584.6 6689903.7 42.5, 354581.2 6689903.5 42.5, 354579.6 6689902.7 42.5, 354579.8 6689899.5 42.5, 354579.1 6689899.2 42.5, 354579.4 6689895.5 42.5))
BATIMENT0000000302929073;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1869-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.5;29.8;39.3;43.0;31.6;Cadastre;C 0.7;POLYGON Z ((354605 6689898.2 39.3, 354602.2 6689902.5 39.3, 354603.3 6689903.4 39.3, 354597.4 6689912.8 39.3, 354606.4 6689918.9 39.3, 354612.6 6689909.5 39.3, 354611 6689908.3 39.3, 354613.8 6689904.2 39.3, 354605 6689898.2 39.3))
BATIMENT0000000302927868;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.2;31.7;41.0;51.2;32.1;Cadastre;A 1.0;POLYGON Z ((354567.9 6689907 41, 354565.8 6689911.5 41, 354574.1 6689915.5 41, 354578.5 6689906.2 41, 354573.6 6689903.1 41, 354568.2 6689902.7 41, 354567.9 6689907 41))
BATIMENT0000000302929072;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.3;30.3;33.7;39.2;31.0;Cadastre;C 0.4;POLYGON Z ((354614.3 6689910.9 33.7, 354619.2 6689914.2 33.7, 354622.1 6689909.7 33.7, 354617.2 6689906.5 33.7, 354614.3 6689910.9 33.7))
BATIMENT0000000302928233;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;9.0;32.1;41.1;42.7;32.2;Cadastre;A 1.0;POLYGON Z ((354558.3 6689907.2 41.1, 354548.4 6689904.7 41.1, 354544.1 6689914.3 41.1, 354553 6689918.2 41.1, 354558.3 6689907.2 41.1))
BATIMENT0000000302927874;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;9.3;31.7;41.0;43.7;32.1;Cadastre;A 1.0;POLYGON Z ((354561.6 6689920.6 41, 354569.9 6689924.4 41, 354574.1 6689915.5 41, 354565.8 6689911.5 41, 354561.6 6689920.6 41))
BATIMENT0000000302927878;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;8.6;31.6;40.2;43.0;32.2;Cadastre;A 1.0;POLYGON Z ((354557.4 6689929.5 40.2, 354565.5 6689933.6 40.2, 354569.9 6689924.4 40.2, 354561.6 6689920.6 40.2, 354557.4 6689929.5 40.2))
BATIMENT0000000302929161;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;6.1;30.8;36.9;42.2;31.5;Cadastre;B 0.4;POLYGON Z ((354603 6689927.2 36.9, 354608.4 6689930.5 36.9, 354610.5 6689927.4 36.9, 354604.9 6689923.9 36.9, 354603 6689927.2 36.9))
BATIMENT0000000302929088;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;8.3;30.7;39.0;;;Cadastre;A 1.0;POLYGON Z ((354675.3 6689892.9 39, 354676 6689892.4 39, 354680.3 6689897.2 39, 354682 6689897.2 39, 354682.1 6689890.5 39, 354678.6 6689886.8 39, 354673.7 6689891.7 39, 354675.3 6689892.9 39))
BATIMENT0000000302928144;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.2;29.8;34.1;40.2;30.3;Cadastre;B 0.4;POLYGON Z ((354712.6 6689898.9 34.1, 354710.1 6689896.4 34.1, 354707.4 6689896.5 34.1, 354705.5 6689894.2 34.1, 354706.7 6689893 34.1, 354704 6689890.7 34.1, 354700.8 6689894 34.1, 354709 6689902.5 34.1, 354712.6 6689898.9 34.1))
BATIMENT0000000302928145;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;9.0;30.1;39.1;41.1;30.3;Cadastre;C 0.5;POLYGON Z ((354698.8 6689892.6 39.1, 354694.5 6689896.7 39.1, 354704.9 6689906.7 39.1, 354709 6689902.5 39.1, 354700.8 6689894 39.1, 354698.8 6689892.6 39.1))
BATIMENT0000000302929070;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1974-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;34;20;8.8;29.8;38.6;42.9;31.2;Cadastre;A 1.0;POLYGON Z ((354617.2 6689906.5 38.6, 354622.1 6689909.7 38.6, 354629.3 6689898.8 38.6, 354621.4 6689893.5 38.6, 354621.2 6689893.3 38.6, 354613.8 6689904.2 38.6, 354617.2 6689906.5 38.6))
BATIMENT0000000302929090;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;5.5;30.1;35.7;39.1;30.8;Cadastre;A 1.0;POLYGON Z ((354648.8 6689897.8 35.7, 354647 6689897.9 35.7, 354640.5 6689897.5 35.7, 354640 6689897.3 35.7, 354634.3 6689906.1 35.7, 354639.1 6689907 35.7, 354647.1 6689908.2 35.7, 354648.8 6689897.8 35.7))
BATIMENT0000000302928212;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.7;30.8;38.5;;;Cadastre;A 1.0;POLYGON Z ((354680.1 6689915.2 38.5, 354689.9 6689915.5 38.5, 354690.7 6689902 38.5, 354681 6689901.6 38.5, 354680.1 6689915.2 38.5))
BATIMENT0000000302929160;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.3;30.7;39.1;41.0;31.0;Cadastre;;POLYGON Z ((354649.8 6689917.1 39.1, 354653.8 6689917.5 39.1, 354654.4 6689911.8 39.1, 354650.5 6689911.3 39.1, 354649.8 6689917.1 39.1))
BATIMENT0000000302927763;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;30;20;8.0;30.2;38.3;43.0;31.0;Cadastre;A 1.0;POLYGON Z ((354698.2 6689925.9 38.3, 354712.7 6689927.9 38.3, 354713 6689924.2 38.3, 354714 6689924.2 38.3, 354715.8 6689922.3 38.3, 354708.4 6689915.2 38.3, 354698.2 6689925.9 38.3))
BATIMENT0000000302927853;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1841-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.0;30.6;38.6;40.5;31.1;Cadastre;A 1.0;POLYGON Z ((354691.3 6689921.7 38.6, 354676.5 6689920.1 38.6, 354676 6689925.3 38.6, 354678.7 6689925.6 38.6, 354677.5 6689938.2 38.6, 354676.9 6689938.1 38.6, 354676.6 6689938.7 38.6, 354689.3 6689940.1 38.6, 354691.3 6689921.7 38.6))
BATIMENT0000000029197679;Indifférenciée;Résidentiel;Annexe;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1892-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;10;20;9.5;32.0;;44.1;32.1;Imagerie aérienne;A 1.0;POLYGON Z ((354649.6 6689946.7 37.3, 354652.5 6689931 41.5, 354631.4 6689928.5 38.1, 354629.2 6689944.8 37.3, 354649.6 6689946.7 37.3))
BATIMENT0000000302928215;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;90;20;8.3;32.0;40.3;44.1;32.1;Cadastre;B 0.7;POLYGON Z ((354587.2 6689924.6 40.3, 354589 6689925.7 40.3, 354583.5 6689934.5 40.3, 354592.7 6689940 40.3, 354599.1 6689930.4 40.3, 354598.8 6689930.2 40.3, 354601.5 6689925.9 40.3, 354590.8 6689918.5 40.3, 354587.2 6689924.6 40.3))
BATIMENT0000000302927879;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;8.1;31.6;39.7;42.2;32.3;Cadastre;A 1.0;POLYGON Z ((354552.9 6689939.3 39.7, 354555.7 6689940.1 39.7, 354561.8 6689942 39.7, 354562.4 6689942.2 39.7, 354566.1 6689933.9 39.7, 354565.5 6689933.6 39.7, 354557.4 6689929.5 39.7, 354552.9 6689939.3 39.7))
BATIMENT0000000302927837;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;6.0;30;10;19.2;31.7;50.9;;;Cadastre;A 1.0;POLYGON Z ((354618.7 6689949.7 50.9, 354619.8 6689950 50.9, 354626 6689940.2 50.9, 354625.7 6689939.8 50.9, 354628.6 6689935 50.9, 354627.4 6689934.3 50.9, 354629.7 6689930.7 50.9, 354628.9 6689930.1 50.9, 354630.5 6689927.5 50.9, 354622.5 6689925.4 50.9, 354608.2 6689946.8 50.9, 354610.9 6689948.3 50.9, 354614.6 6689949.1 50.9, 354618.7 6689949.7 50.9))
BATIMENT0000000302927880;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;04;02;4.3;32.1;36.5;41.5;32.3;Cadastre;C 0.5;POLYGON Z ((354554.8 6689943.7 36.5, 354560.9 6689945.6 36.5, 354561.8 6689942 36.5, 354555.7 6689940.1 36.5, 354554.8 6689943.7 36.5))
BATIMENT0000000302928138;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;01;4.5;32.0;36.5;39.6;32.3;Cadastre;C 0.3;POLYGON Z ((354564.4 6689951.1 36.5, 354569 6689952.5 36.5, 354571.4 6689945 36.5, 354570.2 6689944.6 36.5, 354566.8 6689943.5 36.5, 354564.4 6689951.1 36.5))
BATIMENT0000000302927838;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;9.0;31.0;40.0;48.2;31.5;Cadastre;C 0.8;POLYGON Z ((354604.3 6689952.9 40, 354600.9 6689961.5 40, 354609.8 6689963 40, 354614.6 6689949.1 40, 354610.9 6689948.3 40, 354608.2 6689946.8 40, 354604.3 6689952.9 40))
BATIMENT0000000302927891;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.0;32.0;42.0;44.5;32.3;Cadastre;C 1.0;POLYGON Z ((354591.5 6689973.1 42, 354592 6689969.6 42, 354589.8 6689969.3 42, 354590.6 6689964.4 42, 354592.7 6689965.3 42, 354593.9 6689958.5 42, 354590.9 6689958.2 42, 354591.5 6689953.2 42, 354584.9 6689951.8 42, 354584.1 6689957.2 42, 354581.1 6689956.8 42, 354578.7 6689970.9 42, 354588.7 6689972.6 42, 354591.5 6689973.1 42))
BATIMENT0000000302929158;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;03;04;2.2;32.0;34.2;36.2;32.3;Cadastre;B 0.3;POLYGON Z ((354554.9 6689970.4 34.2, 354559.8 6689971.8 34.2, 354560.5 6689968.3 34.2, 354558.5 6689967.7 34.2, 354555.9 6689966.9 34.2, 354554.9 6689970.4 34.2))
BATIMENT0000000302927839;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;31.1;39.0;41.4;32.1;Cadastre;A 1.0;POLYGON Z ((354598.2 6689978.5 39, 354607.4 6689980.1 39, 354610.3 6689963.1 39, 354609.8 6689963 39, 354600.9 6689961.5 39, 354598.2 6689978.5 39))
BATIMENT0000000302927890;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;90;20;8.2;32.0;40.2;42.8;32.0;Cadastre;A 1.0;POLYGON Z ((354577.6 6689978.8 40.2, 354578.1 6689979.3 40.2, 354577.3 6689984.4 40.2, 354578.9 6689984.8 40.2, 354589 6689986.3 40.2, 354590.2 6689979.3 40.2, 354587.6 6689979 40.2, 354588.7 6689972.6 40.2, 354578.7 6689970.9 40.2, 354577.6 6689978.8 40.2))
BATIMENT0000002275363184;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.4;31.2;;;;Imagerie aérienne;;POLYGON Z ((354767.7 6689944.4 42.8, 354767.7 6689947.8 45.1, 354766.2 6689947.9 45.2, 354760.8 6689949.8 45.6, 354756.2 6689949.1 38.2, 354752.3 6689955.8 38.2, 354756.7 6689956.1 46.6, 354756.7 6689957.7 46.6, 354762.7 6689957.8 46.4, 354762.6 6689960.4 46.4, 354774.4 6689960.8 46.4, 354774.3 6689958.5 46.4, 354776.3 6689958.8 46.4, 354776.3 6689960 46.4, 354783.3 6689960.4 46.4, 354783.4 6689959.2 46.4, 354790.5 6689959.5 46.4, 354790.6 6689960.6 46.4, 354809.8 6689961.6 46.4, 354813 6689960.4 46.4, 354825 6689951 46.3, 354818.1 6689943 46.3, 354816.7 6689941.6 43, 354812.6 6689944.8 46.5, 354812 6689944.1 46.5, 354809.6 6689945.9 46.5, 354808.8 6689944.6 44.6, 354791.6 6689944.2 44.3, 354791.3 6689946.7 46.5, 354779.9 6689946.8 46.5, 354779.9 6689943.7 44.5, 354779.5 6689934.9 39.2, 354780.5 6689934.9 39.1, 354777.5 6689903.3 39, 354768.2 6689904.7 39, 354764.5 6689904.1 39, 354763.4 6689904 37.9, 354767.7 6689944.4 42.8))
BATIMENT0000000302929248;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;;;11.5;31.4;42.9;47.4;31.5;Cadastre;C 0.6;POLYGON Z ((354702.5 6689957.9 42.9, 354702.3 6689959.3 42.9, 354709.1 6689959.7 42.9, 354709.5 6689956.2 42.9, 354711.7 6689938.9 42.9, 354740.3 6689942.8 42.9, 354740.2 6689935 42.9, 354713.5 6689930.8 42.9, 354713.7 6689928.3 42.9, 354712.7 6689927.9 42.9, 354698.2 6689925.9 42.9, 354694.9 6689957.4 42.9, 354702.5 6689957.9 42.9), (354703.1 6689947.9 42.9, 354708.8 6689948.8 42.9, 354708 6689956.1 42.9, 354702.1 6689955.3 42.9, 354703.1 6689947.9 42.9))
BATIMENT0000000302928175;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;7.2;30.9;38.2;39.4;31.7;Cadastre;C 0.2;POLYGON Z ((354749.3 6689955.6 38.2, 354752.3 6689955.8 38.2, 354756.2 6689949.1 38.2, 354757.3 6689933.1 38.2, 354751.4 6689932.4 38.2, 354749.3 6689955.6 38.2))
BATIMENT0000000302929246;Eglise;Religieux;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.5;31.4;42.9;;;Cadastre;;POLYGON Z ((354699.9 6689967.5 42.9, 354707.8 6689969 42.9, 354707.6 6689971.4 42.9, 354708.7 6689971.7 42.9, 354708.7 6689972.5 42.9, 354717.7 6689973.6 42.9, 354718.1 6689969.5 42.9, 354724.3 6689970 42.9, 354724.6 6689962.6 42.9, 354720.2 6689961.8 42.9, 354720.6 6689957.8 42.9, 354709.5 6689956.2 42.9, 354709.1 6689959.7 42.9, 354702.3 6689959.3 42.9, 354702.5 6689957.9 42.9, 354694.9 6689957.4 42.9, 354693.9 6689966.9 42.9, 354699.9 6689967.5 42.9))
BATIMENT0000000302929249;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;31.2;34.6;41.5;32.2;Cadastre;;POLYGON Z ((354723.6 6689974.3 34.6, 354724.2 6689971.7 34.6, 354724.7 6689971.8 34.6, 354725.5 6689973.1 34.6, 354726.3 6689972.7 34.6, 354726.1 6689971.7 34.6, 354727.6 6689962.1 34.6, 354727 6689961.2 34.6, 354725.6 6689960.9 34.6, 354725.9 6689958.6 34.6, 354720.6 6689957.8 34.6, 354720.2 6689961.8 34.6, 354724.6 6689962.6 34.6, 354724.3 6689970 34.6, 354718.1 6689969.5 34.6, 354717.7 6689973.6 34.6, 354723.6 6689974.3 34.6))
BATIMENT0000002011294410;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:40:56;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;1.0;00;00;4.0;31.3;;35.6;32.6;Imagerie aérienne;C 0.8;POLYGON Z ((354723 6689978.1 35.3, 354716.9 6689977.3 35.3, 354715.2 6689993.3 35.3, 354716.7 6689993.6 35.3, 354716.3 6689997.2 35.3, 354720.8 6689997.8 35.3, 354721.3 6689994.3 35.3, 354726 6689994.8 35.3, 354726.4 6689990.3 35.3, 354717.3 6689989.3 35.3, 354717.7 6689986.7 35.3, 354721.9 6689987.1 35.3, 354723 6689978.1 35.3))
BATIMENT0000000302928177;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;31.3;37.5;38.0;31.8;Cadastre;;POLYGON Z ((354756.9 6689999 37.5, 354760.5 6689999 37.5, 354760.7 6689999 37.5, 354760.6 6689994.2 37.5, 354756.9 6689994.2 37.5, 354756.9 6689999 37.5))
BATIMENT0000000302929211;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;31.3;38.0;42.0;32.6;Cadastre;C 0.1;POLYGON Z ((354742.7 6690009.6 38, 354745.4 6690009.7 38, 354750 6690009.8 38, 354773.5 6690009.2 38, 354773.3 6689998.8 38, 354760.7 6689999 38, 354760.5 6689999 38, 354756.9 6689999 38, 354756.9 6689994.2 38, 354748.2 6689994.2 38, 354744.3 6689994.2 38, 354738.5 6689994.2 38, 354738.4 6689999.2 38, 354738.3 6690003.8 38, 354738.2 6690005.1 38, 354742.7 6690009.6 38))
BATIMENT0000000302936932;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;7.0;00;00;18.7;31.3;50.0;54.4;33.8;Cadastre;C 0.8;POLYGON Z ((354730.7 6690036.5 50, 354781.6 6690034.9 50, 354781.7 6690028.3 50, 354781.8 6690024.2 50, 354781.9 6690020.9 50, 354782 6690018.1 50, 354775.1 6690018.2 50, 354774.8 6690018.2 50, 354774.8 6690016 50, 354773.6 6690016 50, 354773.5 6690009.2 50, 354750 6690009.8 50, 354750.1 6690012.2 50, 354750.3 6690018.2 50, 354745.3 6690018.3 50, 354743.7 6690018.4 50, 354743.8 6690023.5 50, 354741.5 6690023.6 50, 354736.9 6690023.7 50, 354733.2 6690023.8 50, 354731.5 6690020.4 50, 354731.3 6690020.5 50, 354731 6690020.7 50, 354728.9 6690021.6 50, 354725.1 6690023.5 50, 354726 6690025.7 50, 354730.7 6690036.5 50))
BATIMENT0000000302934070;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;12.6;32.8;45.5;50.2;33.6;Cadastre;A 1.0;POLYGON Z ((354720.6 6690026.1 45.5, 354720.4 6690025.4 45.5, 354717.8 6690025.4 45.5, 354717.8 6690028.5 45.5, 354717.9 6690037 45.5, 354730.7 6690036.5 45.5, 354726 6690025.7 45.5, 354720.6 6690026.1 45.5))
BATIMENT0000000302927852;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;7.2;30.8;38.0;40.5;31.3;Cadastre;A 1.0;POLYGON Z ((354676.2 6689945.8 38, 354674.2 6689945.6 38, 354673.8 6689949.1 38, 354681.5 6689950 38, 354688.1 6689950.6 38, 354689.3 6689940.1 38, 354676.6 6689938.7 38, 354676.2 6689945.8 38))
BATIMENT0000000302927836;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.4;31.1;38.5;41.2;31.5;Cadastre;;POLYGON Z ((354628 6689947.3 38.5, 354628.8 6689943.8 38.5, 354629.1 6689942.1 38.5, 354628.3 6689941.8 38.5, 354623.7 6689950.6 38.5, 354627.2 6689951.4 38.5, 354628 6689947.3 38.5))
BATIMENT0000000302927835;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.9;32.0;37.9;39.5;32.1;Cadastre;;POLYGON Z ((354618.1 6689954.1 37.9, 354619.6 6689956.2 37.9, 354623.1 6689956.8 37.9, 354622.6 6689961.2 37.9, 354625.3 6689961.8 37.9, 354627.2 6689951.4 37.9, 354623.7 6689950.6 37.9, 354619.8 6689950 37.9, 354618.7 6689949.7 37.9, 354618.1 6689954.1 37.9))
BATIMENT0000000302927854;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;9.3;31.1;40.5;42.4;32.0;Cadastre;A 1.0;POLYGON Z ((354681.4 6689951.1 40.5, 354678.8 6689950.8 40.5, 354677.2 6689952.1 40.5, 354676.8 6689954.9 40.5, 354677.9 6689956.7 40.5, 354678.2 6689957 40.5, 354677.1 6689966.6 40.5, 354675.1 6689968.1 40.5, 354674.8 6689971.2 40.5, 354675.8 6689972.8 40.5, 354676.4 6689972.9 40.5, 354676.2 6689974.5 40.5, 354678.6 6689974.9 40.5, 354685.5 6689975.7 40.5, 354688.1 6689950.6 40.5, 354681.5 6689950 40.5, 354681.4 6689951.1 40.5))
BATIMENT0000000302929247;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.5;31.4;42.9;45.4;31.8;Cadastre;;POLYGON Z ((354700.3 6689973.5 42.9, 354700.6 6689969.5 42.9, 354699.8 6689969.5 42.9, 354699.9 6689967.5 42.9, 354693.9 6689966.9 42.9, 354693.3 6689972.8 42.9, 354700.3 6689973.5 42.9))
BATIMENT0000000302927855;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;8.0;31.6;39.7;40.1;32.0;Cadastre;C 0.1;POLYGON Z ((354677.6 6689984.7 39.7, 354684.5 6689985.4 39.7, 354685.5 6689975.7 39.7, 354678.6 6689974.9 39.7, 354677.6 6689984.7 39.7))
BATIMENT0000000302927765;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;00;00;9.7;31.6;41.3;45.4;32.3;Cadastre;C 0.7;POLYGON Z ((354690.9 6689996 41.3, 354703.9 6689997.4 41.3, 354704.2 6689994.2 41.3, 354705.4 6689994.3 41.3, 354705.3 6689995 41.3, 354707.7 6689995.3 41.3, 354708.2 6689991.4 41.3, 354705.8 6689991.1 41.3, 354705.7 6689991.6 41.3, 354704.5 6689991.6 41.3, 354706.5 6689974.3 41.3, 354700.3 6689973.5 41.3, 354693.3 6689972.8 41.3, 354690.9 6689996 41.3))
BATIMENT0000000302934046;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;10.4;32.2;42.7;45.0;33.0;Cadastre;C 0.8;POLYGON Z ((354704.6 6690017.3 42.7, 354705.2 6690017.3 42.7, 354706.8 6690005.2 42.7, 354706.1 6690005.1 42.7, 354706.5 6690001.7 42.7, 354690.4 6690000.3 42.7, 354690.1 6690003.9 42.7, 354695.6 6690004.5 42.7, 354695.7 6690003.9 42.7, 354697.4 6690004.2 42.7, 354695.8 6690015.4 42.7, 354696.2 6690015.8 42.7, 354696 6690018.9 42.7, 354703.2 6690019.8 42.7, 354704.6 6690019.9 42.7, 354704.6 6690017.3 42.7))
BATIMENT0000000302934786;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;00;00;9.8;32.6;42.4;;;Cadastre;C 0.2;POLYGON Z ((354635.2 6690014.5 42.4, 354647.6 6690015.9 42.4, 354647.2 6690019.6 42.4, 354651.8 6690020 42.4, 354652.2 6690016.4 42.4, 354653.4 6690016.6 42.4, 354654.8 6690003.4 42.4, 354636.7 6690001.5 42.4, 354635.2 6690014.5 42.4))
BATIMENT0000000302934048;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.4;32.4;35.9;39.0;32.9;Cadastre;C 0.4;POLYGON Z ((354694.6 6690015.2 35.9, 354688.9 6690014.3 35.9, 354688.6 6690018.1 35.9, 354693.8 6690018.6 35.9, 354694.6 6690015.2 35.9))
BATIMENT0000000302927840;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;7.8;31.4;39.2;43.2;32.5;Cadastre;A 1.0;POLYGON Z ((354596.7 6689988.3 39.2, 354606.1 6689990.1 39.2, 354606.6 6689990 39.2, 354608.4 6689980.2 39.2, 354607.4 6689980.1 39.2, 354598.2 6689978.5 39.2, 354596.7 6689988.3 39.2))
BATIMENT0000000302927889;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;10.9;31.5;42.4;44.1;32.5;Cadastre;A 1.0;POLYGON Z ((354589 6689986.3 42.4, 354578.9 6689984.8 42.4, 354577.3 6689984.4 42.4, 354576.1 6689984.2 42.4, 354575.4 6689988.3 42.4, 354573 6689990.7 42.4, 354572.4 6689994.5 42.4, 354573.9 6689997.3 42.4, 354573.4 6690000.3 42.4, 354575.5 6690000.6 42.4, 354576.2 6690000.7 42.4, 354586.4 6690002.3 42.4, 354589 6689986.3 42.4))
BATIMENT0000000302927841;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;24;7.4;31.5;39.0;41.4;32.4;Cadastre;A 1.0;POLYGON Z ((354595 6689998.6 39, 354603.7 6690000.1 39, 354604.5 6690000.2 39, 354606.1 6689990.1 39, 354596.7 6689988.3 39, 354595 6689998.6 39))
BATIMENT0000000302929159;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.2;31.9;35.2;39.2;32.7;Cadastre;;POLYGON Z ((354616.6 6690002.2 35.2, 354618.5 6690002.4 35.2, 354619.9 6689992.2 35.2, 354617.9 6689991.9 35.2, 354616.6 6690002.2 35.2))
BATIMENT0000000302927842;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.6;31.6;39.2;41.5;32.2;Cadastre;A 1.0;POLYGON Z ((354593.5 6690008.2 39.2, 354602.3 6690009.7 39.2, 354603.7 6690000.1 39.2, 354595 6689998.6 39.2, 354593.5 6690008.2 39.2))
BATIMENT0000000302934052;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.5;31.7;40.2;42.5;32.5;Cadastre;A 1.0;POLYGON Z ((354576.2 6690000.7 40.2, 354575.5 6690000.6 40.2, 354575.2 6690005.2 40.2, 354573.8 6690005.9 40.2, 354572.7 6690012.6 40.2, 354573.7 6690012.9 40.2, 354575.3 6690013.3 40.2, 354579.2 6690013.9 40.2, 354584.6 6690014.5 40.2, 354586.4 6690002.3 40.2, 354576.2 6690000.7 40.2))
BATIMENT0000000302935325;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;1.0;2.0;10;20;2.5;32.1;34.6;36.0;32.6;Cadastre;C 0.1;POLYGON Z ((354622.7 6690013.6 34.6, 354623.6 6690007.5 34.6, 354617.9 6690006.7 34.6, 354617.3 6690012.3 34.6, 354617.2 6690013 34.6, 354622.7 6690013.6 34.6))
BATIMENT0000000302935324;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;32.2;34.8;35.4;32.6;Cadastre;;POLYGON Z ((354613.5 6690015.1 34.8, 354616.8 6690015.6 34.8, 354617.2 6690013 34.8, 354617.3 6690012.3 34.8, 354614 6690011.8 34.8, 354613.5 6690015.1 34.8))
BATIMENT0000000302935330;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;32.1;35.0;41.0;32.9;Cadastre;;POLYGON Z ((354553.3 6690017.3 35, 354553.3 6690017.9 35, 354556.2 6690018.3 35, 354557.4 6690010.4 35, 354554.5 6690009.9 35, 354553.3 6690017.3 35))
BATIMENT0000000302934051;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;6.4;31.8;38.2;43.2;32.3;Cadastre;A 1.0;POLYGON Z ((354606.5 6690010.4 38.2, 354602.8 6690009.7 38.2, 354602.3 6690009.7 38.2, 354593.5 6690008.2 38.2, 354591.9 6690018.2 38.2, 354599.4 6690019.5 38.2, 354601 6690019.8 38.2, 354604.9 6690020.4 38.2, 354606.5 6690010.4 38.2))
BATIMENT0000000302935329;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;1.0;1.0;90;90;2.5;32.3;34.9;35.1;32.8;Cadastre;C 0.1;POLYGON Z ((354679.2 6690016.2 34.9, 354672.6 6690015.4 34.9, 354671.9 6690021.8 34.9, 354674.4 6690022.2 34.9, 354678.5 6690022.4 34.9, 354679.2 6690016.2 34.9))
BATIMENT0000000302934047;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;32.4;35.1;37.5;32.9;Cadastre;B 0.3;POLYGON Z ((354694.8 6690022.8 35.1, 354694.8 6690018.7 35.1, 354693.8 6690018.6 35.1, 354688.6 6690018.1 35.1, 354688.1 6690022.1 35.1, 354694.8 6690022.8 35.1))
BATIMENT0000000302934045;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;31.7;35.5;37.2;33.0;Cadastre;;POLYGON Z ((354703.3 6690023.3 35.5, 354708.6 6690023.9 35.5, 354708.5 6690020.5 35.5, 354704.6 6690019.9 35.5, 354703.2 6690019.8 35.5, 354703.3 6690023.3 35.5))
BATIMENT0000000302935328;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;53;09;2.4;32.7;35.1;35.3;32.9;Cadastre;C 0.4;POLYGON Z ((354673.8 6690028.3 35.1, 354678 6690028.6 35.1, 354678.5 6690022.4 35.1, 354674.4 6690022.2 35.1, 354673.8 6690028.3 35.1))
BATIMENT0000000302934763;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;30;8.3;32.7;41.0;44.3;33.0;Cadastre;C 0.5;POLYGON Z ((354663.2 6690028.7 41, 354662.2 6690028.7 41, 354662.2 6690024.7 41, 354655.6 6690024.8 41, 354655.7 6690028.7 41, 354656 6690039.3 41, 354669.1 6690039 41, 354668.5 6690034.4 41, 354663.4 6690034.4 41, 354663.2 6690028.7 41))
BATIMENT0000000302934073;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;23;7.8;32.7;40.5;46.2;33.5;Cadastre;B 0.9;POLYGON Z ((354685.3 6690038.1 40.5, 354702.3 6690037.5 40.5, 354702.2 6690032.1 40.5, 354697.8 6690032.2 40.5, 354697.5 6690029.3 40.5, 354697.3 6690027.3 40.5, 354686.6 6690026.4 40.5, 354686.5 6690026.4 40.5, 354685.3 6690038.1 40.5))
BATIMENT0000000302934072;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;5.2;33.0;38.2;41.2;33.5;Cadastre;A 1.0;POLYGON Z ((354707.9 6690028.5 38.2, 354703.8 6690028 38.2, 354703.7 6690028.4 38.2, 354702.3 6690028.5 38.2, 354702.2 6690028.5 38.2, 354702.2 6690029.1 38.2, 354702.2 6690032.1 38.2, 354702.3 6690037.5 38.2, 354708.1 6690037.3 38.2, 354707.9 6690028.5 38.2))
BATIMENT0000000302934762;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.0;32.6;42.7;45.1;32.9;Cadastre;A 1.0;POLYGON Z ((354656 6690039.3 42.7, 354655.7 6690028.7 42.7, 354645.4 6690029.2 42.7, 354645.8 6690039.8 42.7, 354656 6690039.3 42.7))
BATIMENT0000000302934761;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;10.3;32.4;42.7;45.3;33.0;Cadastre;A 1.0;POLYGON Z ((354645.3 6690028.6 42.7, 354635.5 6690029 42.7, 354635.4 6690040.1 42.7, 354645.8 6690039.8 42.7, 354645.4 6690029.2 42.7, 354645.3 6690028.6 42.7))
BATIMENT0000000302934631;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;32.9;47.9;51.6;33.5;Cadastre;;POLYGON Z ((354687.1 6690049.9 47.9, 354688.1 6690058.8 47.9, 354691.9 6690058.7 47.9, 354690.7 6690049.7 47.9, 354687.1 6690049.9 47.9))
BATIMENT0000000302934053;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;23;4.4;32.2;36.6;40.4;32.4;Cadastre;A 1.0;POLYGON Z ((354573.5 6690021.4 36.6, 354574 6690021.5 36.6, 354583 6690023.2 36.6, 354584.6 6690014.5 36.6, 354579.2 6690013.9 36.6, 354575.3 6690013.3 36.6, 354573.7 6690012.9 36.6, 354572.2 6690021.1 36.6, 354573.5 6690021.4 36.6))
BATIMENT0000000302934050;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1917-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.7;31.9;38.7;41.9;32.4;Cadastre;C 0.9;POLYGON Z ((354589.3 6690034.1 38.7, 354596.7 6690035.2 38.7, 354599.4 6690019.5 38.7, 354591.9 6690018.2 38.7, 354589.3 6690034.1 38.7))
BATIMENT0000000302934054;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;5.9;32.0;37.9;40.9;32.5;Cadastre;C 1.0;POLYGON Z ((354574 6690021.5 37.9, 354573.5 6690021.4 37.9, 354572.7 6690025.9 37.9, 354575.8 6690026.6 37.9, 354574.1 6690035.6 37.9, 354575.2 6690035.8 37.9, 354574.2 6690041.5 37.9, 354579.9 6690041.4 37.9, 354583 6690023.2 37.9, 354574 6690021.5 37.9))
BATIMENT0000000302935242;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;9.2;32.0;41.2;48.9;32.6;Cadastre;A 1.0;POLYGON Z ((354564.2 6690041.8 41.2, 354564.4 6690035.5 41.2, 354563.9 6690026.4 41.2, 354553.2 6690026.9 41.2, 354552 6690035.9 41.2, 354551.2 6690042.3 41.2, 354564.2 6690041.8 41.2))
BATIMENT0000000302935238;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.5;33.0;37.5;;;Cadastre;C 0.6;POLYGON Z ((354619.1 6690040.1 37.5, 354618.7 6690031.9 37.5, 354614.5 6690031.4 37.5, 354614.2 6690033.2 37.5, 354613.3 6690040.3 37.5, 354619.1 6690040.1 37.5))
BATIMENT0000000302935239;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.8;32.2;38.0;46.2;32.7;Cadastre;C 0.4;POLYGON Z ((354609.5 6690032.6 38, 354608.2 6690040.4 38, 354613.3 6690040.3 38, 354614.2 6690033.2 38, 354609.5 6690032.6 38))
BATIMENT0000000302934049;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;20;2.2;32.9;35.1;;;Cadastre;A 1.0;POLYGON Z ((354588.3 6690041 35.1, 354604.6 6690040.6 35.1, 354604.9 6690038.4 35.1, 354601.2 6690037.9 35.1, 354601.3 6690037 35.1, 354595.5 6690036.2 35.1, 354595.4 6690037 35.1, 354589 6690036.1 35.1, 354588.3 6690041 35.1))
BATIMENT0000000302935243;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;3.7;32.0;35.7;42.5;32.5;Cadastre;C 0.5;POLYGON Z ((354569.2 6690041.6 35.7, 354569.2 6690035.7 35.7, 354564.4 6690035.5 35.7, 354564.2 6690041.8 35.7, 354569.2 6690041.6 35.7))
BATIMENT0000000302934637;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;30;20;21.6;32.3;54.0;56.7;33.0;Cadastre;C 0.7;POLYGON Z ((354607.1 6690052.4 54, 354607.5 6690062.4 54, 354628.7 6690061.8 54, 354628.1 6690051.7 54, 354607.1 6690052.4 54))
BATIMENT0000000302934711;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;6.7;33.0;39.7;46.0;33.1;Cadastre;C 0.7;POLYGON Z ((354598.7 6690063 39.7, 354598.4 6690052.7 39.7, 354586.5 6690052.9 39.7, 354586.7 6690062.9 39.7, 354598.7 6690063 39.7))
BATIMENT0000000302934071;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.2;32.9;40.2;43.7;33.5;Cadastre;A 1.0;POLYGON Z ((354707.9 6690028.5 40.2, 354708.1 6690037.3 40.2, 354717.9 6690037 40.2, 354717.8 6690028.5 40.2, 354707.9 6690028.5 40.2))
BATIMENT0000000302934713;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;13;20;10.2;33.2;43.5;44.3;33.5;Cadastre;A 1.0;POLYGON Z ((354760.9 6690048.2 43.5, 354761.9 6690057.4 43.5, 354763.5 6690057.4 43.5, 354766.2 6690057.2 43.5, 354765.5 6690048 43.5, 354760.9 6690048.2 43.5))
BATIMENT0000000302934715;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.8;34.7;42.5;;;Cadastre;A 1.0;POLYGON Z ((354756.2 6690048.4 42.5, 354757.3 6690057.8 42.5, 354761.9 6690057.4 42.5, 354760.9 6690048.2 42.5, 354756.2 6690048.4 42.5))
BATIMENT0000000302934714;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;10;6.3;33.1;39.5;43.6;33.5;Cadastre;A 1.0;POLYGON Z ((354768.9 6690054.2 39.5, 354772.2 6690054.1 39.5, 354772.4 6690047.8 39.5, 354765.5 6690048 39.5, 354766.2 6690057.2 39.5, 354766.5 6690060.7 39.5, 354768.6 6690059.8 39.5, 354768.3 6690056.3 39.5, 354769.2 6690056.1 39.5, 354768.9 6690054.2 39.5))
BATIMENT0000000302934725;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;11.0;33.2;44.2;47.1;33.7;Cadastre;A 1.0;POLYGON Z ((354750.7 6690048.8 44.2, 354749.5 6690049.6 44.2, 354748.7 6690050.3 44.2, 354753.2 6690059.2 44.2, 354754.4 6690061.4 44.2, 354755.1 6690061 44.2, 354755.5 6690060.3 44.2, 354755.4 6690059.4 44.2, 354756.4 6690058.8 44.2, 354756.7 6690061.8 44.2, 354757.7 6690061.4 44.2, 354757.3 6690057.8 44.2, 354756.2 6690048.4 44.2, 354750.7 6690048.8 44.2))
BATIMENT0000000302934746;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1944-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;20;8.6;34.6;43.2;;;Cadastre;A 1.0;POLYGON Z ((354743.6 6690056.3 43.2, 354747.6 6690059.9 43.2, 354749.4 6690061.5 43.2, 354749.8 6690061.9 43.2, 354750.7 6690060.8 43.2, 354751.8 6690060 43.2, 354753.2 6690059.2 43.2, 354748.7 6690050.3 43.2, 354743.6 6690056.3 43.2))
BATIMENT0000000302934717;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;33.2;36.2;38.0;33.4;Cadastre;;POLYGON Z ((354772.2 6690056.1 36.2, 354769.2 6690056.1 36.2, 354768.3 6690056.3 36.2, 354768.6 6690059.8 36.2, 354772.1 6690058.8 36.2, 354772.2 6690056.1 36.2))
BATIMENT0000000302934638;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;35;40;11.5;33.2;44.7;45.8;33.7;Cadastre;A 1.0;POLYGON Z ((354718.4 6690068.2 44.7, 354725.7 6690058.9 44.7, 354725.6 6690048.7 44.7, 354711.1 6690049.2 44.7, 354711.2 6690052.7 44.7, 354714 6690064.7 44.7, 354718.4 6690068.2 44.7))
BATIMENT0000000302934547;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.1;32.9;43.1;46.5;33.7;Cadastre;A 1.0;POLYGON Z ((354782 6690046.4 43.1, 354781.3 6690072.9 43.1, 354792.5 6690073.3 43.1, 354799.6 6690073.5 43.1, 354799.3 6690062.8 43.1, 354799.2 6690058 43.1, 354799 6690045.8 43.1, 354782 6690046.4 43.1))
BATIMENT0000000302934716;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;34.7;40.5;;;Cadastre;;POLYGON Z ((354763.5 6690057.4 40.5, 354763.6 6690058.9 40.5, 354762 6690059 40.5, 354762.5 6690062.5 40.5, 354763.5 6690062.1 40.5, 354766.3 6690060.9 40.5, 354766.5 6690060.7 40.5, 354766.2 6690057.2 40.5, 354763.5 6690057.4 40.5))
BATIMENT0000000302934745;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.6;33.3;39.0;42.8;33.8;Cadastre;A 1.0;POLYGON Z ((354742.6 6690055.5 39, 354737.7 6690061.6 39, 354742.6 6690065.6 39, 354747.6 6690059.9 39, 354743.6 6690056.3 39, 354742.6 6690055.5 39))
BATIMENT0000000302934741;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;33.3;38.2;42.7;33.7;Cadastre;;POLYGON Z ((354754.4 6690061.4 38.2, 354753.2 6690059.2 38.2, 354751.8 6690060 38.2, 354750.7 6690060.8 38.2, 354749.8 6690061.9 38.2, 354751.7 6690063.4 38.2, 354754.4 6690061.4 38.2))
BATIMENT0000000302934743;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;34.7;38.2;;;Cadastre;;POLYGON Z ((354756.7 6690061.8 38.2, 354754.9 6690062.5 38.2, 354756.2 6690065 38.2, 354757.4 6690064.5 38.2, 354758 6690064.3 38.2, 354757.7 6690061.4 38.2, 354756.7 6690061.8 38.2))
BATIMENT0000000302934744;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;34.2;40.3;;;Cadastre;;POLYGON Z ((354747.6 6690059.9 40.3, 354742.6 6690065.6 40.3, 354742.3 6690066 40.3, 354742.9 6690066.5 40.3, 354744.2 6690067.4 40.3, 354749.4 6690061.5 40.3, 354747.6 6690059.9 40.3))
BATIMENT0000000302934718;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;10;5.4;33.2;38.7;42.3;33.7;Cadastre;A 1.0;POLYGON Z ((354772.1 6690058.8 38.7, 354768.6 6690059.8 38.7, 354766.5 6690060.7 38.7, 354766.3 6690060.9 38.7, 354763.5 6690062.1 38.7, 354763.6 6690065.2 38.7, 354766.4 6690065.2 38.7, 354766.5 6690067.1 38.7, 354763.5 6690067 38.7, 354763.4 6690070 38.7, 354766 6690070.1 38.7, 354771.7 6690070.2 38.7, 354772.1 6690058.8 38.7))
BATIMENT0000000302934719;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.3;33.4;40.7;41.8;33.6;Cadastre;;POLYGON Z ((354763.6 6690065.2 40.7, 354763.5 6690067 40.7, 354766.5 6690067.1 40.7, 354766.4 6690065.2 40.7, 354763.6 6690065.2 40.7))
BATIMENT0000000302934724;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.5;33.8;41.3;43.1;34.0;Cadastre;A 1.0;POLYGON Z ((354733.2 6690067.3 41.3, 354734 6690068 41.3, 354734.4 6690067.6 41.3, 354738.2 6690070.8 41.3, 354742.3 6690066 41.3, 354742.6 6690065.6 41.3, 354737.7 6690061.6 41.3, 354733.2 6690067.3 41.3))
BATIMENT0000000302934742;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;33.4;35.8;39.0;33.7;Cadastre;;POLYGON Z ((354754.1 6690069.7 35.8, 354756.7 6690067 35.8, 354757.9 6690066.2 35.8, 354757.4 6690064.5 35.8, 354756.2 6690065 35.8, 354754.5 6690065.7 35.8, 354750.7 6690069.7 35.8, 354754.1 6690069.7 35.8))
BATIMENT0000000302934723;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;33.4;37.2;38.2;34.0;Cadastre;;POLYGON Z ((354740.1 6690072.3 37.2, 354742.7 6690069.3 37.2, 354744.2 6690067.4 37.2, 354742.9 6690066.5 37.2, 354738.8 6690071.2 37.2, 354740.1 6690072.3 37.2))
BATIMENT0000000302934720;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;14;10;6.4;33.5;39.9;42.8;34.2;Cadastre;A 1.0;POLYGON Z ((354771.7 6690070.2 39.9, 354766 6690070.1 39.9, 354766 6690073.5 39.9, 354758.3 6690073.6 39.9, 354758.3 6690069.9 39.9, 354754.1 6690069.7 39.9, 354750.7 6690069.7 39.9, 354744.5 6690076 39.9, 354740.7 6690080.2 39.9, 354752.9 6690080.5 39.9, 354761 6690080.9 39.9, 354771.4 6690081.2 39.9, 354771.7 6690070.2 39.9))
BATIMENT0000000302927693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;00;00;9.9;27.3;37.3;40.2;27.7;Cadastre;A 1.0;POLYGON Z ((354955 6689835.4 37.3, 354956.5 6689834.6 37.3, 354958.5 6689837.1 37.3, 354962.1 6689834.9 37.3, 354958.9 6689830 37.3, 354962.8 6689827.2 37.3, 354965.6 6689825.4 37.3, 354958.5 6689815.3 37.3, 354947.1 6689824.1 37.3, 354955 6689835.4 37.3))
BATIMENT0000000302927694;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;;;5.4;27.3;32.7;36.2;27.7;Cadastre;A 1.0;POLYGON Z ((354965.6 6689825.4 32.7, 354962.8 6689827.2 32.7, 354966.3 6689832.4 32.7, 354969.1 6689830.4 32.7, 354965.6 6689825.4 32.7))
BATIMENT0000000302927695;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;26.6;34.6;37.6;27.7;Cadastre;;POLYGON Z ((354973.5 6689837.6 34.6, 354973.8 6689836.9 34.6, 354969.1 6689830.4 34.6, 354966.3 6689832.4 34.6, 354962.8 6689827.2 34.6, 354958.9 6689830 34.6, 354962.1 6689834.9 34.6, 354966.4 6689841.7 34.6, 354973.5 6689837.6 34.6))
BATIMENT0000000302927691;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;9.4;26.5;35.9;38.6;27.6;Cadastre;A 1.0;POLYGON Z ((354966.4 6689841.7 35.9, 354962.1 6689834.9 35.9, 354958.5 6689837.1 35.9, 354956.5 6689834.6 35.9, 354955 6689835.4 35.9, 354949.5 6689838.4 35.9, 354949.8 6689839 35.9, 354957.6 6689848.3 35.9, 354966.4 6689841.7 35.9))
BATIMENT0000000302931316;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;18.2;26.0;44.2;;;Cadastre;A 1.0;POLYGON Z ((355040.3 6689826.9 44.2, 355038.6 6689825.4 44.2, 355032.3 6689825 44.2, 355015 6689842.3 44.2, 355025.2 6689859.4 44.2, 355035.3 6689853.4 44.2, 355034 6689851.4 44.2, 355032.8 6689851.1 44.2, 355030.8 6689847.6 44.2, 355038.8 6689840.5 44.2, 355042.7 6689842.9 44.2, 355043.5 6689842.6 44.2, 355045.5 6689841.1 44.2, 355046.3 6689840.4 44.2, 355046.8 6689839.3 44.2, 355045.7 6689836.5 44.2, 355047.7 6689833.9 44.2, 355040.3 6689826.9 44.2))
BATIMENT0000000302927696;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;10.6;26.7;37.3;41.3;28.4;Cadastre;A 1.0;POLYGON Z ((354943.7 6689853.2 37.3, 354943.4 6689853.8 37.3, 354947.7 6689857 37.3, 354957.6 6689848.3 37.3, 354949.8 6689839 37.3, 354944.2 6689844.5 37.3, 354946.4 6689847.9 37.3, 354945.9 6689848.9 37.3, 354942.7 6689846 37.3, 354939.7 6689849 37.3, 354943.7 6689853.2 37.3))
BATIMENT0000000302931317;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.8;25.6;38.5;40.0;26.3;Cadastre;;POLYGON Z ((355035.3 6689853.4 38.5, 355036.3 6689852.6 38.5, 355035.4 6689851.7 38.5, 355034 6689851.4 38.5, 355035.3 6689853.4 38.5))
BATIMENT0000000302929208;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;32.0;10.0;00;00;35.9;26.6;62.5;65.6;30.0;Cadastre;C 0.5;POLYGON Z ((354939.3 6689881.8 62.5, 354955 6689894.6 62.5, 354952.3 6689905.6 62.5, 354964.2 6689908.7 62.5, 354966.9 6689898.6 62.5, 354966.8 6689896.6 62.5, 354967.4 6689896.5 62.5, 354967.2 6689894 62.5, 354967 6689892.8 62.5, 354966.8 6689891.7 62.5, 354966.4 6689890.6 62.5, 354966 6689889.5 62.5, 354965.5 6689888.5 62.5, 354964.9 6689887.5 62.5, 354964.3 6689886.6 62.5, 354963.5 6689885.7 62.5, 354962.7 6689884.9 62.5, 354961.8 6689884.1 62.5, 354947.6 6689871.9 62.5, 354947.3 6689872.2 62.5, 354938 6689863.8 62.5, 354931.4 6689874.8 62.5, 354939.3 6689881.8 62.5))
BATIMENT0000000302927697;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;35.0;7.0;10;20;16.0;26.7;42.7;48.4;28.9;Cadastre;A 1.0;POLYGON Z ((355021.5 6689868 42.7, 355012.1 6689852.7 42.7, 355008.1 6689855.7 42.7, 355003.8 6689852.1 42.7, 355001.4 6689854.6 42.7, 354999 6689859.3 42.7, 354996.6 6689865.7 42.7, 354984.3 6689919.2 42.7, 354994.3 6689921.6 42.7, 354995.4 6689921.9 42.7, 354995.5 6689921.5 42.7, 355008.2 6689868.4 42.7, 355020.6 6689871.6 42.7, 355021.5 6689868 42.7))
BATIMENT0000000302931777;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;;;4.0;27.3;31.4;40.2;28.4;Cadastre;A 1.0;POLYGON Z ((355021.1 6689931.3 31.4, 355023.5 6689936.7 31.4, 355029.4 6689950.3 31.4, 355048.2 6689942.8 31.4, 355043.6 6689931.6 31.4, 355039.4 6689923.4 31.4, 355038 6689920 31.4, 355031 6689923.4 31.4, 355034.2 6689930.9 31.4, 355030.7 6689932.4 31.4, 355027.6 6689925.1 31.4, 355020.1 6689928.7 31.4, 355021.1 6689931.3 31.4))
BATIMENT0000000302927531;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;27.8;30.6;35.7;28.6;Cadastre;;POLYGON Z ((354909.3 6689878.8 30.6, 354914.6 6689871.8 30.6, 354910.1 6689868.5 30.6, 354906.9 6689872.3 30.6, 354903.8 6689870.4 30.6, 354902.1 6689872.8 30.6, 354909.3 6689878.8 30.6))
BATIMENT0000000302929207;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;28.3;37.2;60.0;28.9;Cadastre;;POLYGON Z ((354933.6 6689888 37.2, 354939.3 6689881.8 37.2, 354931.4 6689874.8 37.2, 354930.8 6689874.8 37.2, 354925.8 6689882.4 37.2, 354933.6 6689888 37.2))
BATIMENT0000000302929204;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;8.0;30;40;21.7;28.9;50.7;51.5;30.8;Cadastre;C 0.6;POLYGON Z ((354891.3 6689903.1 50.7, 354893.2 6689900.5 50.7, 354895.1 6689897.1 50.7, 354895.6 6689897.5 50.7, 354899.9 6689891.5 50.7, 354902.1 6689888.4 50.7, 354870.7 6689863.7 50.7, 354866 6689870.2 50.7, 354861 6689877.1 50.7, 354891.3 6689903.1 50.7))
BATIMENT0000000302927534;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;2.1;28.5;30.7;35.0;29.9;Cadastre;C 0.2;POLYGON Z ((354920.1 6689892.6 30.7, 354925.2 6689883.9 30.7, 354924.8 6689883.6 30.7, 354923.5 6689882.6 30.7, 354920.4 6689887.7 30.7, 354916.8 6689885.4 30.7, 354914.7 6689888.9 30.7, 354920.1 6689892.6 30.7))
BATIMENT0000000302927532;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.7;30.0;50.8;51.5;30.8;Cadastre;;POLYGON Z ((354893.2 6689900.5 50.8, 354891.3 6689903.1 50.8, 354891.7 6689903.4 50.8, 354893.2 6689900.5 50.8))
BATIMENT0000000302929205;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;8.0;00;00;23.2;27.3;50.5;55.5;31.4;Cadastre;C 0.2;POLYGON Z ((354903.3 6689918.2 50.5, 354912 6689910.7 50.5, 354914.4 6689908.3 50.5, 354916 6689906.8 50.5, 354912.9 6689902.9 50.5, 354912.1 6689903.5 50.5, 354904.5 6689893.9 50.5, 354902.8 6689895.2 50.5, 354902.1 6689894.3 50.5, 354905 6689892.1 50.5, 354902.1 6689888.4 50.5, 354899.9 6689891.5 50.5, 354895.6 6689897.5 50.5, 354895.1 6689897.1 50.5, 354893.2 6689900.5 50.5, 354891.7 6689903.4 50.5, 354903.3 6689918.2 50.5))
BATIMENT0000000302928268;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;30.8;34.4;38.9;31.2;Cadastre;;POLYGON Z ((354889.2 6689920.2 34.4, 354884.9 6689924.1 34.4, 354885.1 6689924.3 34.4, 354887.3 6689926.7 34.4, 354892 6689922.6 34.4, 354889.2 6689920.2 34.4))
BATIMENT0000000302929206;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;32.5;29.3;61.8;64.5;31.2;Cadastre;C 0.4;POLYGON Z ((354929.6 6689951.7 61.8, 354955.5 6689946.4 61.8, 354955.8 6689945.6 61.8, 354956.9 6689942.1 61.8, 354959.1 6689931.9 61.8, 354964.2 6689908.7 61.8, 354952.3 6689905.6 61.8, 354951.9 6689905.6 61.8, 354950.3 6689912.8 61.8, 354945 6689911.6 61.8, 354940.4 6689932.5 61.8, 354936 6689931.5 61.8, 354935.6 6689933.5 61.8, 354928.3 6689924.7 61.8, 354929.4 6689923.9 61.8, 354916 6689906.8 61.8, 354914.4 6689908.3 61.8, 354912 6689910.7 61.8, 354903.3 6689918.2 61.8, 354929.6 6689951.7 61.8))
BATIMENT0000000302928269;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.5;30.9;35.4;38.7;31.3;Cadastre;A 1.0;POLYGON Z ((354907.2 6689939.2 35.4, 354902.5 6689934.3 35.4, 354902.8 6689933.8 35.4, 354897.7 6689927.4 35.4, 354892 6689922.6 35.4, 354887.3 6689926.7 35.4, 354896.4 6689938.1 35.4, 354903.4 6689946 35.4, 354907.2 6689939.2 35.4))
BATIMENT0000000302928265;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;18.3;30.9;49.2;52.9;31.2;Cadastre;A 1.0;POLYGON Z ((354903.2 6689946.7 49.2, 354903.4 6689946 49.2, 354896.4 6689938.1 49.2, 354888.8 6689944.4 49.2, 354891.3 6689947.4 49.2, 354888.8 6689954.4 49.2, 354887.7 6689954.2 49.2, 354886.2 6689958.6 49.2, 354886.5 6689958.6 49.2, 354897.4 6689962 49.2, 354903.2 6689946.7 49.2))
BATIMENT0000000302928261;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;10.2;29.6;39.8;49.7;30.5;Cadastre;A 1.0;POLYGON Z ((354854.4 6689890.9 39.8, 354841.9 6689900.3 39.8, 354844.7 6689903.6 39.8, 354845.2 6689904.3 39.8, 354857.8 6689893.7 39.8, 354854.4 6689890.9 39.8))
BATIMENT0000000302928258;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;12;20;8.2;29.8;38.0;41.7;31.0;Cadastre;A 1.0;POLYGON Z ((354857.8 6689893.7 38, 354845.2 6689904.3 38, 354847.4 6689907.4 38, 354849.5 6689910.1 38, 354853.6 6689906.3 38, 354855.8 6689904.4 38, 354862.7 6689897.8 38, 354857.8 6689893.7 38))
BATIMENT0000000302928259;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;6.0;00;00;16.3;30.1;46.4;49.7;31.1;Cadastre;A 1.0;POLYGON Z ((354862.7 6689897.8 46.4, 354855.8 6689904.4 46.4, 354853.6 6689906.3 46.4, 354868.3 6689918.7 46.4, 354877.8 6689910.6 46.4, 354862.7 6689897.8 46.4))
BATIMENT0000000302928257;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;19.3;29.8;49.2;51.9;31.0;Cadastre;A 1.0;POLYGON Z ((354839.2 6689919.5 49.2, 354849 6689910.5 49.2, 354849.5 6689910.1 49.2, 354847.4 6689907.4 49.2, 354844.6 6689909.5 49.2, 354841.8 6689905.9 49.2, 354844.7 6689903.6 49.2, 354841.9 6689900.3 49.2, 354830.5 6689908.6 49.2, 354839.2 6689919.5 49.2))
BATIMENT0000000302928262;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;30.4;46.4;49.4;31.1;Cadastre;;POLYGON Z ((354868.5 6689918.8 46.4, 354878 6689910.8 46.4, 354877.8 6689910.6 46.4, 354868.3 6689918.7 46.4, 354868.5 6689918.8 46.4))
BATIMENT0000000302928180;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.3;31.0;33.3;;;Cadastre;;POLYGON Z ((354800.2 6689923 33.3, 354805 6689919 33.3, 354806 6689918.2 33.3, 354804 6689916 33.3, 354803.2 6689916.6 33.3, 354801.1 6689914.3 33.3, 354795 6689919.2 33.3, 354797.9 6689920.2 33.3, 354800.2 6689923 33.3))
BATIMENT0000000302928260;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;56;10;6.7;30.5;37.2;45.7;31.1;Cadastre;A 1.0;POLYGON Z ((354850.6 6689933.8 37.2, 354859.6 6689926.5 37.2, 354856.5 6689922.6 37.2, 354857.9 6689921.5 37.2, 354849 6689910.5 37.2, 354839.2 6689919.5 37.2, 354850.6 6689933.8 37.2))
BATIMENT0000000302928179;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;31.0;33.4;;;Cadastre;;POLYGON Z ((354808.2 6689932.7 33.4, 354808.8 6689932.5 33.4, 354811.6 6689930.8 33.4, 354812.5 6689930 33.4, 354812.8 6689928.9 33.4, 354812.3 6689927.8 33.4, 354805 6689919 33.4, 354800.2 6689923 33.4, 354808.2 6689932.7 33.4))
BATIMENT0000000302928169;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;12;20;12.2;30.2;42.4;45.0;31.0;Cadastre;C 0.7;POLYGON Z ((354807.7 6689916.8 42.4, 354828.4 6689942.5 42.4, 354833.2 6689932 42.4, 354815.2 6689909.8 42.4, 354807 6689916.2 42.4, 354807.7 6689916.8 42.4))
BATIMENT0000000302928263;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;00;00;17.4;30.7;48.2;51.3;31.5;Cadastre;C 0.6;POLYGON Z ((354876.3 6689931.5 48.2, 354876.5 6689931.7 48.2, 354885.1 6689924.3 48.2, 354884.9 6689924.1 48.2, 354889.2 6689920.2 48.2, 354885.2 6689916.8 48.2, 354878 6689910.8 48.2, 354868.5 6689918.8 48.2, 354870.5 6689920.2 48.2, 354872.2 6689922 48.2, 354870.5 6689923.5 48.2, 354873.5 6689926.9 48.2, 354866.9 6689932.5 48.2, 354864.1 6689929.3 48.2, 354862.9 6689930.3 48.2, 354859.6 6689926.5 48.2, 354850.6 6689933.8 48.2, 354860 6689945.5 48.2, 354876.3 6689931.5 48.2))
BATIMENT0000000302927698;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;10;20;12.2;28.7;41.0;44.5;30.0;Cadastre;C 0.6;POLYGON Z ((354983.2 6689922.7 41, 354977.3 6689950.3 41, 354976.7 6689953.4 41, 354979 6689954.1 41, 354978.8 6689955.4 41, 354985.1 6689957.8 41, 354992.7 6689937 41, 355001.7 6689940 41, 355004.2 6689932.9 41, 355001.2 6689931.8 41, 355001.7 6689930.2 41, 354994.1 6689927.4 41, 354995.4 6689921.9 41, 354994.3 6689921.6 41, 354984.3 6689919.2 41, 354983.2 6689922.7 41))
BATIMENT0000000302931756;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;10;20;13.2;27.8;41.0;44.2;29.9;Cadastre;C 0.7;POLYGON Z ((355023.1 6689943.3 41, 355021.4 6689940.7 41, 355018.4 6689936.2 41, 355015.2 6689935.2 41, 355014.7 6689936.8 41, 355011.6 6689935.8 41, 355009.2 6689943 41, 355017.9 6689946.2 41, 355010.8 6689966.9 41, 355018.3 6689969.5 41, 355020.1 6689968.2 41, 355032.8 6689958.6 41, 355023.1 6689943.3 41))
BATIMENT0000000302927519;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;29.9;46.0;46.5;30.1;Cadastre;;POLYGON Z ((354988.6 6689979.8 46, 354988.8 6689979.1 46, 354987.3 6689978.1 46, 354987.7 6689978.9 46, 354988.6 6689979.8 46))
BATIMENT0000000302931757;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;14.9;26.0;40.9;41.9;30.0;Cadastre;A 1.0;POLYGON Z ((355026.5 6689976.6 40.9, 355026.1 6689977.2 40.9, 355026 6689977.5 40.9, 355025.8 6689978.2 40.9, 355025.9 6689978.7 40.9, 355026.2 6689979.3 40.9, 355026.6 6689979.7 40.9, 355027.3 6689980 40.9, 355028.3 6689980 40.9, 355028.8 6689979.7 40.9, 355031 6689982.6 40.9, 355018.5 6689991.7 40.9, 355013.8 6689985.5 40.9, 355011.9 6689987.8 40.9, 355009.8 6689990.8 40.9, 355007.6 6689994.6 40.9, 355005.2 6689999.9 40.9, 355003.1 6690007.2 40.9, 355002.2 6690012.6 40.9, 355007.4 6690014.6 40.9, 355007.7 6690014.4 40.9, 355030.3 6689997.4 40.9, 355033.5 6689995 40.9, 355038.3 6689990.8 40.9, 355037.7 6689989.8 40.9, 355041.8 6689986.8 40.9, 355042.6 6689987.7 40.9, 355052.6 6689980.4 40.9, 355049 6689975.5 40.9, 355049.5 6689974.9 40.9, 355049.7 6689974.4 40.9, 355049.8 6689973.6 40.9, 355048.7 6689972.1 40.9, 355047.7 6689972.1 40.9, 355046.2 6689972.3 40.9, 355043.6 6689969.2 40.9, 355041.6 6689966.3 40.9, 355039.8 6689967.5 40.9, 355037.9 6689965.5 40.9, 355035.4 6689962 40.9, 355033.8 6689960.1 40.9, 355032.8 6689958.6 40.9, 355020.1 6689968.2 40.9, 355026.5 6689976.6 40.9))
BATIMENT0000000302927520;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;17.0;29.8;46.8;48.9;30.4;Cadastre;C 0.2;POLYGON Z ((355002 6689976.5 46.8, 354998.9 6689975.3 46.8, 354999.1 6689974.5 46.8, 354993.5 6689972.2 46.8, 354994.1 6689970.1 46.8, 354992.1 6689969.7 46.8, 354991.3 6689969.6 46.8, 354990.7 6689969.5 46.8, 354989.6 6689970.1 46.8, 354988.5 6689970.7 46.8, 354987.5 6689971.5 46.8, 354986.8 6689972.2 46.8, 354986.3 6689973.4 46.8, 354986 6689974.5 46.8, 354986 6689975.3 46.8, 354986.5 6689976.6 46.8, 354987.2 6689977.5 46.8, 354987.3 6689978.1 46.8, 354988.8 6689979.1 46.8, 354988.6 6689979.8 46.8, 354971.2 6690027.4 46.8, 354983.1 6690031.2 46.8, 354994.5 6690022.8 46.8, 354990.6 6690017.2 46.8, 354989.2 6690018.3 46.8, 354986.8 6690017.4 46.8, 354992.3 6690002.8 46.8, 354993.1 6690003 46.8, 354993.8 6690001.1 46.8, 354993.1 6690000.7 46.8, 354997.5 6689989.4 46.8, 354998 6689989.4 46.8, 354998.8 6689987.3 46.8, 354998.2 6689987.1 46.8, 355002 6689976.5 46.8))
BATIMENT0000000302944279;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;28.1;38.8;41.2;29.9;Cadastre;;POLYGON Z ((355002.4 6690018.1 38.8, 355007.4 6690014.6 38.8, 355002.2 6690012.6 38.8, 355002.4 6690018.1 38.8))
BATIMENT0000000302944121;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;12.8;27.1;40.0;42.2;29.2;Cadastre;A 1.0;POLYGON Z ((355028.4 6690017.1 40, 355028.6 6690017.5 40, 355032.6 6690025.7 40, 355035.9 6690024.3 40, 355037.6 6690023.5 40, 355033.1 6690013.7 40, 355028.4 6690017.1 40))
BATIMENT0000000302944127;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.0;28.4;34.4;38.2;30.1;Cadastre;;POLYGON Z ((355007.5 6690039.9 34.4, 355013.7 6690048.2 34.4, 355019.9 6690047.3 34.4, 355020.7 6690047.2 34.4, 355014.5 6690039.1 34.4, 355012.5 6690036.3 34.4, 355007.5 6690039.9 34.4))
BATIMENT0000000302934527;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.9;28.4;36.3;42.7;30.3;Cadastre;;POLYGON Z ((354998.9 6690039.8 36.3, 355006.4 6690049.3 36.3, 355008.2 6690059.9 36.3, 354997.4 6690061.8 36.3, 354998.1 6690067.7 36.3, 355007.1 6690066.1 36.3, 355010.1 6690065.6 36.3, 355011.2 6690065.4 36.3, 355015.9 6690064.6 36.3, 355018.5 6690064.2 36.3, 355022.4 6690063.5 36.3, 355022.1 6690060.5 36.3, 355037.7 6690057.6 36.3, 355036 6690047.9 36.3, 355020.3 6690050.5 36.3, 355019.9 6690047.3 36.3, 355013.7 6690048.2 36.3, 355007.5 6690039.9 36.3, 355012.5 6690036.3 36.3, 355014.5 6690039.1 36.3, 355030.5 6690027.5 36.3, 355043.5 6690044.9 36.3, 355046.7 6690042.1 36.3, 355038.8 6690025.7 36.3, 355036.8 6690026.5 36.3, 355035.9 6690024.3 36.3, 355032.6 6690025.7 36.3, 355028.6 6690017.5 36.3, 354998.9 6690039.8 36.3))
BATIMENT0000000302935248;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;9.0;29.9;38.9;44.9;31.1;Cadastre;A 1.0;POLYGON Z ((354973.1 6690059.5 38.9, 354974.1 6690059.8 38.9, 354976.1 6690060.5 38.9, 354979.1 6690053.7 38.9, 354978.9 6690052.3 38.9, 354979.4 6690052.1 38.9, 354979.2 6690049.9 38.9, 354965.6 6690044.7 38.9, 354963.7 6690046.7 38.9, 354960.8 6690054.8 38.9, 354972.8 6690059.4 38.9, 354973.1 6690059.5 38.9))
BATIMENT0000000302928264;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:56;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.3;31.0;47.3;50.9;31.5;Cadastre;A 1.0;POLYGON Z ((354871 6689959.2 47.3, 354878.9 6689952.6 47.3, 354883.1 6689949.2 47.3, 354887.5 6689945.5 47.3, 354876.5 6689931.7 47.3, 354876.3 6689931.5 47.3, 354860 6689945.5 47.3, 354860.2 6689945.7 47.3, 354871 6689959.2 47.3))
BATIMENT0000002275363047;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:02:40;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;18.2;31.9;;;;Imagerie aérienne;;POLYGON Z ((354828.4 6689942.5 42.4, 354827.6 6689944.2 43, 354831.2 6689948.8 43, 354827.7 6689951.5 43, 354831.2 6689956.5 43.1, 354832.8 6689955.4 43.1, 354836.8 6689960.6 44.4, 354833.5 6689963 45.8, 354827.8 6689968 45.8, 354828.1 6689969.1 45.8, 354827.3 6689977.1 45.8, 354822.4 6689976.8 45.6, 354822.4 6689977.3 45.6, 354794.8 6689976.4 44.7, 354794.5 6689979.8 47.3, 354791.3 6689979.8 47.3, 354786.6 6689979.3 43.4, 354786.5 6689980.6 43.4, 354783.8 6689980.4 43.4, 354783.5 6689984.9 43.7, 354785.7 6689985.1 46.5, 354784.9 6690002.7 46.5, 354797.7 6690002.5 46.2, 354798.4 6689992 46.2, 354804.7 6689992.3 46.4, 354816.3 6689992.9 46.4, 354816.3 6689991.1 46.4, 354826.7 6689991.4 46.5, 354826.6 6689992.8 49.5, 354839.9 6689993.7 49.5, 354841.8 6689993.5 50.1, 354842.6 6689985.9 44.8, 354843.2 6689976.2 44.8, 354854.3 6689967.1 42.2, 354854.4 6689965.6 42.2, 354858.6 6689964.6 42.2, 354859.2 6689964.1 42.6, 354859.2 6689963.1 42.6, 354856.5 6689959.9 42.6, 354855.9 6689960.3 44.7, 354844.3 6689945.5 44.7, 354840.6 6689941.1 44.7, 354841.3 6689940.6 42.2, 354838.9 6689937.8 42.2, 354838.4 6689938.1 42.2, 354833.2 6689932 42.4, 354828.4 6689942.5 42.4))
BATIMENT0000000302928176;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;00;00;11.0;31.1;42.2;46.2;32.3;Cadastre;A 1.0;POLYGON Z ((354860.2 6689979.5 42.2, 354858.4 6689980.9 42.2, 354858.6 6689973.9 42.2, 354865.1 6689972.8 42.2, 354858.6 6689964.6 42.2, 354854.4 6689965.6 42.2, 354853.9 6689973.6 42.2, 354853.3 6689986.2 42.2, 354858.5 6689986.3 42.2, 354859.3 6689985.8 42.2, 354859.3 6689983.2 42.2, 354858.2 6689983.2 42.2, 354858.3 6689982.8 42.2, 354861.1 6689980.8 42.2, 354862.9 6689983.1 42.2, 354869.6 6689978 42.2, 354866.7 6689974.5 42.2, 354860.2 6689979.5 42.2))
BATIMENT0000000302928173;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;14.6;31.6;46.3;48.4;32.3;Cadastre;C 0.9;POLYGON Z ((354869.6 6689978 46.3, 354862.9 6689983.1 46.3, 354860.6 6689984.9 46.3, 354870 6689996.6 46.3, 354879.2 6689990 46.3, 354869.6 6689978 46.3))
BATIMENT0000000302928178;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;00;00;8.6;30.8;39.4;42.6;32.7;Cadastre;C 0.5;POLYGON Z ((354852 6690018.1 39.4, 354853.6 6690018.3 39.4, 354856.4 6690018.5 39.4, 354856.5 6690012 39.4, 354867.1 6690003 39.4, 354865 6690000.4 39.4, 354857.3 6690005.8 39.4, 354858.5 6689986.3 39.4, 354853.3 6689986.2 39.4, 354852.3 6690009.7 39.4, 354852 6690018.1 39.4))
BATIMENT0000000302928172;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;32.0;5.0;14;23;15.4;31.7;47.2;49.8;32.5;Cadastre;A 1.0;POLYGON Z ((354871.7 6690032 47.2, 354884.4 6689997 47.2, 354879.2 6689990 47.2, 354870 6689996.6 47.2, 354872 6689998.6 47.2, 354867.6 6690010.3 47.2, 354863 6690008.7 47.2, 354858.5 6690021 47.2, 354853.2 6690021 47.2, 354853 6690026.1 47.2, 354851.4 6690026.2 47.2, 354851.2 6690032.3 47.2, 354871.7 6690032 47.2))
BATIMENT0000000302928171;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:00:51;2019-11-08 14:46:54;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;18.8;30.6;49.5;53.8;33.5;Cadastre;C 0.1;POLYGON Z ((354825 6690015.1 49.5, 354829.5 6690015.6 49.5, 354829.5 6690018 49.5, 354818.9 6690017.9 49.5, 354818.8 6690015.4 49.5, 354813.3 6690015.6 49.5, 354813.7 6690023.3 49.5, 354813.8 6690027.4 49.5, 354814 6690033.7 49.5, 354851.2 6690032.3 49.5, 354851.4 6690026.2 49.5, 354853 6690026.1 49.5, 354853.2 6690021 49.5, 354853.6 6690018.3 49.5, 354852 6690018.1 49.5, 354849.8 6690018.3 49.5, 354849.8 6690017.2 49.5, 354838.8 6690017.3 49.5, 354839.9 6689993.7 49.5, 354825.1 6689992.7 49.5, 354825 6690015.1 49.5))
BATIMENT0000000302934542;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;12.0;34.0;46.0;;;Cadastre;A 0.8;POLYGON Z ((354812.3 6690045.6 46, 354812.4 6690056.7 46, 354829.2 6690056.3 46, 354828.8 6690045 46, 354812.3 6690045.6 46))
BATIMENT0000000302934544;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;13;20;13.7;32.7;46.5;48.6;33.2;Cadastre;A 1.0;POLYGON Z ((354799 6690045.8 46.5, 354799.2 6690058 46.5, 354812.4 6690057.7 46.5, 354812.4 6690056.7 46.5, 354812.3 6690045.6 46.5, 354799 6690045.8 46.5))
BATIMENT0000000302934541;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.6;32.5;42.2;47.7;32.9;Cadastre;A 1.0;POLYGON Z ((354828.8 6690045 42.2, 354829.2 6690056.3 42.2, 354829.3 6690059.3 42.2, 354834.8 6690059 42.2, 354834.3 6690045 42.2, 354828.8 6690045 42.2))
BATIMENT0000000302928266;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1908-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;7.0;13;20;19.3;31.1;50.4;53.8;31.8;Cadastre;A 1.0;POLYGON Z ((354886.8 6689978.9 50.4, 354891.8 6689978.3 50.4, 354897.4 6689962 50.4, 354886.5 6689958.6 50.4, 354885.8 6689960.2 50.4, 354883.9 6689959.5 50.4, 354878.9 6689952.6 50.4, 354871 6689959.2 50.4, 354886.8 6689978.9 50.4))
BATIMENT0000000302934517;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;15.0;31.2;46.2;49.0;31.9;Cadastre;B 0.3;POLYGON Z ((354937.1 6690121.5 46.2, 354943.2 6690123.5 46.2, 354942.9 6690124.7 46.2, 354945.5 6690125.5 46.2, 354945.9 6690125.7 46.2, 354948.5 6690118.6 46.2, 354939.4 6690115.1 46.2, 354937.1 6690121.5 46.2))
BATIMENT0000000302934523;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.7;31.2;46.0;47.5;31.9;Cadastre;;POLYGON Z ((354936.3 6690123.7 46, 354945 6690126.8 46, 354945.5 6690125.5 46, 354942.9 6690124.7 46, 354943.2 6690123.5 46, 354937.1 6690121.5 46, 354936.3 6690123.7 46))
BATIMENT0000000302934518;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;00;00;6.1;31.1;37.2;47.2;32.2;Cadastre;C 0.2;POLYGON Z ((354934.2 6690129 37.2, 354942.9 6690131.7 37.2, 354939.2 6690141.3 37.2, 354939.7 6690141.5 37.2, 354939.3 6690142.7 37.2, 354942.4 6690142.6 37.2, 354944.5 6690136.4 37.2, 354946.6 6690128.3 37.2, 354944.8 6690127.7 37.2, 354945 6690126.8 37.2, 354936.3 6690123.7 37.2, 354934.2 6690129 37.2))
BATIMENT0000000302934525;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;13.1;31.3;44.5;48.5;32.5;Cadastre;A 1.0;POLYGON Z ((354930.8 6690138.9 44.5, 354939.2 6690141.3 44.5, 354942.9 6690131.7 44.5, 354934.2 6690129 44.5, 354930.8 6690138.9 44.5))
BATIMENT0000000302934524;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.6;31.6;39.2;46.2;32.6;Cadastre;A 1.0;POLYGON Z ((354929.6 6690142 39.2, 354930.5 6690142.9 39.2, 354939.3 6690142.7 39.2, 354939.7 6690141.5 39.2, 354939.2 6690141.3 39.2, 354930.8 6690138.9 39.2, 354929.6 6690142 39.2))
BATIMENT0000000302934621;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;31.0;37.0;41.5;33.4;Cadastre;;POLYGON Z ((354947.6 6690161.5 37, 354948.8 6690152.1 37, 354945 6690152.2 37, 354943.6 6690161.6 37, 354947.6 6690161.5 37))
BATIMENT0000000302934707;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;12.5;33.4;45.9;49.6;34.3;Cadastre;C 0.6;POLYGON Z ((354913.4 6690154.3 45.9, 354913 6690153.2 45.9, 354912.7 6690152.3 45.9, 354908.4 6690150.4 45.9, 354908.6 6690149.5 45.9, 354906.6 6690148.6 45.9, 354906.7 6690148.1 45.9, 354900.4 6690145.4 45.9, 354900.2 6690145.8 45.9, 354898.5 6690145.1 45.9, 354898.1 6690146 45.9, 354893.8 6690144.2 45.9, 354892.2 6690145 45.9, 354881.7 6690169 45.9, 354888.3 6690171.9 45.9, 354895.3 6690156.6 45.9, 354901.9 6690159.5 45.9, 354901.4 6690161 45.9, 354909.2 6690163.6 45.9, 354913.4 6690154.3 45.9))
BATIMENT0000000302934615;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;4.0;10;20;11.1;32.1;43.2;46.5;33.5;Cadastre;A 1.0;POLYGON Z ((354925.3 6690153 43.2, 354924.5 6690153.7 43.2, 354918.1 6690168.3 43.2, 354930.2 6690172 43.2, 354931.3 6690168.9 43.2, 354932.3 6690166.7 43.2, 354929.9 6690165.3 43.2, 354931.6 6690161.2 43.2, 354934.9 6690162.2 43.2, 354934.7 6690163.5 43.2, 354934.4 6690165.5 43.2, 354933.9 6690166.9 43.2, 354936.5 6690167.6 43.2, 354935.9 6690170.7 43.2, 354935.9 6690173.6 43.2, 354939.5 6690174.8 43.2, 354941.8 6690174.9 43.2, 354943.6 6690161.6 43.2, 354945 6690152.2 43.2, 354925.3 6690153 43.2))
BATIMENT0000000302934620;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.9;32.7;43.6;44.0;33.1;Cadastre;;POLYGON Z ((354934.7 6690163.5 43.6, 354933.6 6690163.2 43.6, 354933.3 6690165.3 43.6, 354934.4 6690165.5 43.6, 354934.7 6690163.5 43.6))
BATIMENT0000000302934543;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;00;00;14.3;32.3;46.7;50.6;33.1;Cadastre;A 1.0;POLYGON Z ((354834.8 6690059 46.7, 354834.8 6690065.2 46.7, 354834.9 6690066.6 46.7, 354836.2 6690066.6 46.7, 354836.4 6690065.3 46.7, 354836.9 6690065.3 46.7, 354837.4 6690064.3 46.7, 354837.6 6690061.2 46.7, 354842.6 6690061.1 46.7, 354842.6 6690064.4 46.7, 354841.9 6690065.4 46.7, 354841.9 6690069 46.7, 354841.8 6690069.5 46.7, 354840.8 6690070.6 46.7, 354837.9 6690070.8 46.7, 354837.9 6690073.1 46.7, 354845.2 6690072.5 46.7, 354845.3 6690068 46.7, 354845.1 6690057 46.7, 354845.2 6690044.7 46.7, 354834.3 6690045 46.7, 354834.8 6690059 46.7))
BATIMENT0000000302934546;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;36.0;6.0;00;00;15.5;32.3;47.8;50.5;33.3;Cadastre;A 1.0;POLYGON Z ((354866.7 6690047.1 47.8, 354861.9 6690044.6 47.8, 354861.9 6690043.8 47.8, 354848.1 6690044.6 47.8, 354845.2 6690044.7 47.8, 354845.1 6690057 47.8, 354845.3 6690068 47.8, 354845.2 6690072.5 47.8, 354845.2 6690079.1 47.8, 354846.4 6690080.8 47.8, 354847.5 6690082.4 47.8, 354851.9 6690087.5 47.8, 354858.5 6690069.7 47.8, 354856.4 6690069.4 47.8, 354856.9 6690067.7 47.8, 354858.9 6690068.2 47.8, 354866.7 6690047.1 47.8))
BATIMENT0000000302934548;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;33.1;37.5;42.2;33.3;Cadastre;;POLYGON Z ((354802.2 6690062.8 37.5, 354799.3 6690062.8 37.5, 354799.6 6690073.5 37.5, 354801.5 6690073.5 37.5, 354802.4 6690073.5 37.5, 354802.2 6690062.8 37.5))
BATIMENT0000000302934550;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;32.7;36.6;39.9;33.6;Cadastre;;POLYGON Z ((354829.4 6690063 36.6, 354812.6 6690063.5 36.6, 354812.8 6690073.7 36.6, 354813.6 6690074 36.6, 354818.4 6690074 36.6, 354826.5 6690074.1 36.6, 354829.7 6690073.8 36.6, 354829.6 6690069.3 36.6, 354829.4 6690063 36.6))
BATIMENT0000000302934555;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;32.7;47.7;49.2;32.9;Cadastre;;POLYGON Z ((354856.4 6690069.4 47.7, 354858.5 6690069.7 47.7, 354858.9 6690068.2 47.7, 354856.9 6690067.7 47.7, 354856.4 6690069.4 47.7))
BATIMENT0000000302934551;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;32.5;35.6;38.0;33.2;Cadastre;;POLYGON Z ((354834.9 6690069 35.6, 354829.6 6690069.3 35.6, 354829.7 6690073.8 35.6, 354835 6690073.4 35.6, 354834.9 6690069 35.6))
BATIMENT0000000302934545;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;32.7;40.7;44.2;33.5;Cadastre;;POLYGON Z ((354835 6690073.4 40.7, 354829.7 6690073.8 40.7, 354826.5 6690074.1 40.7, 354831 6690079.9 40.7, 354845.2 6690079.1 40.7, 354845.2 6690072.5 40.7, 354837.9 6690073.1 40.7, 354835 6690073.4 40.7))
BATIMENT0000000302934570;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;35.0;37.4;;;Cadastre;;POLYGON Z ((354815.4 6690078.7 37.4, 354817.7 6690077.9 37.4, 354818.4 6690076.6 37.4, 354818.4 6690074 37.4, 354813.6 6690074 37.4, 354815.4 6690078.7 37.4))
BATIMENT0000000302934549;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;33.1;42.2;47.3;33.7;Cadastre;;POLYGON Z ((354807.1 6690073.7 42.2, 354802.4 6690073.5 42.2, 354801.5 6690073.5 42.2, 354801.4 6690085.2 42.2, 354807.1 6690085.3 42.2, 354807.1 6690073.7 42.2))
BATIMENT0000000302934552;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.1;33.1;45.2;47.4;33.6;Cadastre;A 0.2;POLYGON Z ((354846.4 6690080.8 45.2, 354840.8 6690085.2 45.2, 354842 6690086.7 45.2, 354841.3 6690087.3 45.2, 354840 6690085.2 45.2, 354838.6 6690085.2 45.2, 354836.3 6690086.8 45.2, 354838.4 6690089.8 45.2, 354845.3 6690098.5 45.2, 354854.6 6690091.3 45.2, 354851.9 6690087.5 45.2, 354847.5 6690082.4 45.2, 354846.4 6690080.8 45.2))
BATIMENT0000000302935246;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;00;00;10.4;30.5;40.9;42.7;30.8;Cadastre;A 1.0;POLYGON Z ((354986.2 6690051.5 40.9, 354979.4 6690052.1 40.9, 354978.9 6690052.3 40.9, 354979.1 6690053.7 40.9, 354976.1 6690060.5 40.9, 354980.8 6690062.5 40.9, 354981.2 6690061.7 40.9, 354987.4 6690061.7 40.9, 354986.2 6690051.5 40.9))
BATIMENT0000000302944115;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.0;28.4;34.4;36.0;30.1;Cadastre;;POLYGON Z ((355037.8 6690058.7 34.4, 355032.3 6690059.7 34.4, 355031.3 6690060.7 34.4, 355031.4 6690062.2 34.4, 355038.2 6690061 34.4, 355037.9 6690059.1 34.4, 355037.8 6690058.7 34.4))
BATIMENT0000000302944117;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;28.2;32.2;35.2;30.0;Cadastre;;POLYGON Z ((355027.1 6690065.2 32.2, 355031.4 6690064.5 32.2, 355031.2 6690062.2 32.2, 355025.5 6690063 32.2, 355025.4 6690064.4 32.2, 355027.1 6690065.2 32.2))
BATIMENT0000000302935247;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;4.0;23;20;10.7;30.2;40.9;42.5;31.2;Cadastre;A 1.0;POLYGON Z ((354955.2 6690070.1 40.9, 354968.9 6690074.3 40.9, 354969.1 6690073.2 40.9, 354967.4 6690072.9 40.9, 354968.2 6690068.9 40.9, 354967.3 6690068.4 40.9, 354970.2 6690061.3 40.9, 354972.1 6690061.7 40.9, 354972.8 6690059.4 40.9, 354960.8 6690054.8 40.9, 354955.2 6690070.1 40.9))
BATIMENT0000000302944119;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.7;28.4;41.1;44.5;29.5;Cadastre;;POLYGON Z ((355010.1 6690065.6 41.1, 355007.1 6690066.1 41.1, 355007.5 6690069.1 41.1, 355010.5 6690068.6 41.1, 355010.4 6690067.7 41.1, 355010.1 6690065.6 41.1))
BATIMENT0000000302944120;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;20;20;11.2;28.5;39.7;44.6;29.9;Cadastre;C 0.6;POLYGON Z ((355026.6 6690073.3 39.7, 355026.1 6690068.9 39.7, 355025.4 6690064.4 39.7, 355025.5 6690063 39.7, 355022.4 6690063.5 39.7, 355018.5 6690064.2 39.7, 355018.8 6690066.1 39.7, 355016.2 6690066.5 39.7, 355015.9 6690064.6 39.7, 355011.2 6690065.4 39.7, 355011.6 6690067.6 39.7, 355010.4 6690067.7 39.7, 355010.5 6690068.6 39.7, 355011.2 6690075 39.7, 355026.6 6690073.3 39.7))
BATIMENT0000000302944126;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;28.0;30.0;32.0;29.3;Cadastre;;POLYGON Z ((355029 6690073 30, 355028.3 6690068.6 30, 355026.1 6690068.9 30, 355026.6 6690073.3 30, 355029 6690073 30))
BATIMENT0000000302934528;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;14.7;29.0;43.8;45.6;29.9;Cadastre;A 1.0;POLYGON Z ((355007.5 6690069.1 43.8, 355007.1 6690066.1 43.8, 354998.1 6690067.7 43.8, 354999.3 6690076.3 43.8, 355011.2 6690075 43.8, 355010.5 6690068.6 43.8, 355007.5 6690069.1 43.8))
BATIMENT0000000302935250;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;00;00;16.1;30.8;46.9;47.5;31.3;Cadastre;A 1.0;POLYGON Z ((354952 6690079.1 46.9, 354954.2 6690079.8 46.9, 354965.3 6690082.8 46.9, 354966.7 6690082.3 46.9, 354967.3 6690080 46.9, 354968.9 6690074.3 46.9, 354955.2 6690070.1 46.9, 354952 6690079.1 46.9))
BATIMENT0000000302935245;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;64.0;5.0;00;00;12.9;29.7;42.7;45.3;32.1;Cadastre;A 1.0;POLYGON Z ((354974.7 6690068 42.7, 354979.6 6690095 42.7, 354988 6690095.2 42.7, 354987.4 6690090.3 42.7, 354990.9 6690089.9 42.7, 354987.4 6690061.7 42.7, 354981.2 6690061.7 42.7, 354980.8 6690062.5 42.7, 354976.1 6690060.5 42.7, 354974.1 6690059.8 42.7, 354973.1 6690059.5 42.7, 354974.7 6690068 42.7))
BATIMENT0000000302944192;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.2;30.1;43.3;;;Cadastre;;POLYGON Z ((355013.6 6690082.8 43.3, 355012.4 6690082.9 43.3, 355009.4 6690083.3 43.3, 355013.9 6690084.6 43.3, 355013.6 6690082.8 43.3))
BATIMENT0000000302944190;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.2;30.1;43.3;43.5;30.3;Cadastre;;POLYGON Z ((355021.3 6690084 43.3, 355017.3 6690084.3 43.3, 355017.7 6690088.6 43.3, 355021.7 6690088.3 43.3, 355021.3 6690084 43.3))
BATIMENT0000000302934513;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;4.0;;;10.0;31.0;41.0;43.7;31.6;Cadastre;A 1.0;POLYGON Z ((354961 6690088.2 41, 354960.6 6690085.6 41, 354953.6 6690084.1 41, 354950.7 6690083.4 41, 354948.8 6690088.7 41, 354952.4 6690090.1 41, 354952.6 6690092.1 41, 354953.9 6690092.2 41, 354956.1 6690102.3 41, 354963.2 6690101 41, 354961 6690088.2 41))
BATIMENT0000000302935377;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;30.0;5.0;00;00;12.5;30.1;42.6;44.0;31.9;Cadastre;A 1.0;POLYGON Z ((355010.1 6690110.5 42.6, 355015.8 6690109.2 42.6, 355020.1 6690108.2 42.6, 355020.5 6690108.1 42.6, 355019.4 6690098.3 42.6, 355024.6 6690097.7 42.6, 355024.8 6690098.9 42.6, 355028.6 6690098.5 42.6, 355028.5 6690098.1 42.6, 355030.1 6690097.9 42.6, 355030.2 6690099.1 42.6, 355033.6 6690098.8 42.6, 355033.5 6690098 42.6, 355037.6 6690097.6 42.6, 355037.5 6690096.6 42.6, 355042.7 6690096.1 42.6, 355042.3 6690092.2 42.6, 355042 6690089.5 42.6, 355041.9 6690088.4 42.6, 355041.4 6690083.6 42.6, 355036.4 6690084.1 42.6, 355036.6 6690086.8 42.6, 355036.2 6690087 42.6, 355035.5 6690087.3 42.6, 355035.2 6690087.4 42.6, 355035 6690087.5 42.6, 355034.9 6690087.5 42.6, 355034.2 6690087.7 42.6, 355033.6 6690088 42.6, 355033.1 6690088.1 42.6, 355032.7 6690088.2 42.6, 355032.4 6690088.3 42.6, 355031.7 6690088.4 42.6, 355031.6 6690088.5 42.6, 355030.9 6690088.6 42.6, 355030.7 6690088.6 42.6, 355030.2 6690088.7 42.6, 355030 6690088.7 42.6, 355029.4 6690088.8 42.6, 355029.2 6690088.8 42.6, 355028.9 6690088.8 42.6, 355028.3 6690088.9 42.6, 355028.2 6690088.9 42.6, 355027.8 6690088.9 42.6, 355027.1 6690088.9 42.6, 355027 6690088.9 42.6, 355026.8 6690088.9 42.6, 355026.4 6690088.9 42.6, 355026.1 6690088.9 42.6, 355025.8 6690088.9 42.6, 355024.4 6690088.7 42.6, 355023.4 6690088.6 42.6, 355022.7 6690088.5 42.6, 355022.5 6690088.4 42.6, 355022.2 6690088.4 42.6, 355021.7 6690088.3 42.6, 355017.7 6690088.6 42.6, 355017.3 6690084.3 42.6, 355013.9 6690084.6 42.6, 355009.4 6690083.3 42.6, 355000.1 6690084.4 42.6, 355003.6 6690112 42.6, 355010.1 6690110.5 42.6))
BATIMENT0000000302935249;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;3.5;29.4;33.0;40.0;32.0;Cadastre;A 1.0;POLYGON Z ((354988.3 6690102.7 33, 354988.6 6690110.4 33, 354993.3 6690110.2 33, 354990.9 6690089.9 33, 354987.4 6690090.3 33, 354988 6690095.2 33, 354988.3 6690102.7 33))
BATIMENT0000000302934514;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;00;00;17.1;31.3;48.5;51.9;31.8;Cadastre;C 0.7;POLYGON Z ((354963.8 6690104.1 48.5, 354963.2 6690101 48.5, 354956.1 6690102.3 48.5, 354953.9 6690092.2 48.5, 354952.6 6690092.1 48.5, 354952.4 6690090.1 48.5, 354948.8 6690088.7 48.5, 354939.4 6690115.1 48.5, 354948.5 6690118.6 48.5, 354952.8 6690119.3 48.5, 354956.6 6690118.5 48.5, 354956.2 6690114.9 48.5, 354960.2 6690114.1 48.5, 354963.8 6690104.1 48.5))
BATIMENT0000000302944817;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.2;29.3;37.6;43.4;31.1;Cadastre;;POLYGON Z ((355028.2 6690109.3 37.6, 355033.9 6690104 37.6, 355027.5 6690105.5 37.6, 355028.2 6690109.3 37.6))
BATIMENT0000000302935252;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.4;31.2;36.6;37.4;31.9;Cadastre;C 0.2;POLYGON Z ((354988.3 6690102.7 36.6, 354983.5 6690103 36.6, 354983.4 6690102.2 36.6, 354972.4 6690103 36.6, 354972.9 6690111.4 36.6, 354980.8 6690110.9 36.6, 354988.6 6690110.4 36.6, 354988.3 6690102.7 36.6))
BATIMENT0000000302935251;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1845-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;9.4;30.5;39.9;40.7;31.5;Cadastre;C 0.7;POLYGON Z ((354980.8 6690110.9 39.9, 354981.1 6690115.7 39.9, 354993.9 6690114.6 39.9, 354993.3 6690110.2 39.9, 354988.6 6690110.4 39.9, 354980.8 6690110.9 39.9))
BATIMENT0000000302934519;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1845-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;6.3;31.0;37.3;38.1;31.8;Cadastre;C 0.5;POLYGON Z ((354963 6690116.4 37.3, 354963.8 6690116.6 37.3, 354968.8 6690116.2 37.3, 354968.6 6690114.4 37.3, 354969.8 6690114.1 37.3, 354969.6 6690112.6 37.3, 354965.5 6690112.9 37.3, 354962.9 6690113.6 37.3, 354963 6690116.4 37.3))
BATIMENT0000000302934571;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;33.3;37.4;41.5;33.9;Cadastre;;POLYGON Z ((354807.1 6690085.3 37.4, 354801.4 6690085.2 37.4, 354801.5 6690088.1 37.4, 354803.2 6690088.3 37.4, 354802.9 6690091.2 37.4, 354802.9 6690096.5 37.4, 354806.4 6690096.4 37.4, 354807.1 6690085.3 37.4))
BATIMENT0000000302934564;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.5;33.5;37.1;39.7;33.9;Cadastre;A 0.5;POLYGON Z ((354799.7 6690096.4 37.1, 354802.9 6690096.5 37.1, 354802.9 6690091.2 37.1, 354792 6690090.7 37.1, 354791.7 6690096.2 37.1, 354794.9 6690096.4 37.1, 354799.7 6690096.4 37.1))
BATIMENT0000000302934557;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1919-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.6;33.5;42.2;43.7;34.0;Cadastre;A 1.0;POLYGON Z ((354806.4 6690096.4 42.2, 354802.9 6690096.5 42.2, 354799.7 6690096.4 42.2, 354799.2 6690103.3 42.2, 354799.8 6690103.4 42.2, 354805.7 6690103.4 42.2, 354806.4 6690096.4 42.2))
BATIMENT0000000302934553;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;15.1;33.3;48.4;51.3;33.8;Cadastre;A 1.0;POLYGON Z ((354845.3 6690098.5 48.4, 354838.4 6690089.8 48.4, 354823.7 6690101.2 48.4, 354830.4 6690110.1 48.4, 354845.3 6690098.5 48.4))
BATIMENT0000000302934554;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;7.2;33.5;40.8;51.2;33.9;Cadastre;A 1.0;POLYGON Z ((354811.3 6690110.9 40.8, 354818 6690119.8 40.8, 354822.6 6690116.2 40.8, 354824 6690115.3 40.8, 354830.4 6690110.1 40.8, 354823.7 6690101.2 40.8, 354820.7 6690103.6 40.8, 354820.4 6690103.4 40.8, 354816.8 6690106.1 40.8, 354817 6690106.5 40.8, 354816 6690107.2 40.8, 354814.3 6690108.4 40.8, 354810.9 6690103.4 40.8, 354812.7 6690086.1 40.8, 354807.1 6690085.3 40.8, 354806.4 6690096.4 40.8, 354805.7 6690103.4 40.8, 354811.3 6690110.9 40.8))
BATIMENT0000000302934558;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;35.0;39.2;;;Cadastre;;POLYGON Z ((354805.7 6690103.4 39.2, 354799.8 6690103.4 39.2, 354799.8 6690105.9 39.2, 354798.1 6690105.9 39.2, 354797.9 6690111.6 39.2, 354800 6690111.6 39.2, 354805.7 6690103.4 39.2))
BATIMENT0000000302934567;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;33.8;36.6;37.2;34.1;Cadastre;;POLYGON Z ((354790.1 6690112.8 36.6, 354791.3 6690112.8 36.6, 354791.1 6690111.6 36.6, 354790.1 6690111.5 36.6, 354790.1 6690112.8 36.6))
BATIMENT0000000302934566;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;35.0;38.0;;;Cadastre;;POLYGON Z ((354792.1 6690112.8 38, 354794.4 6690112.8 38, 354794.5 6690111.7 38, 354792.1 6690111.7 38, 354792.1 6690112.8 38))
BATIMENT0000000302934561;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;33.8;38.0;38.9;34.0;Cadastre;;POLYGON Z ((354800 6690111.6 38, 354797.9 6690111.6 38, 354795.6 6690111.6 38, 354797.8 6690114.6 38, 354800 6690111.6 38))
BATIMENT0000000302934556;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;9.5;33.7;43.2;48.6;34.4;Cadastre;A 1.0;POLYGON Z ((354795.6 6690126 43.2, 354801 6690133.1 43.2, 354818 6690119.8 43.2, 354811.3 6690110.9 43.2, 354805.7 6690103.4 43.2, 354800 6690111.6 43.2, 354797.8 6690114.6 43.2, 354794.6 6690119.5 43.2, 354793.1 6690121.6 43.2, 354792.5 6690122.2 43.2, 354791.8 6690125.4 43.2, 354791.8 6690126 43.2, 354794.3 6690124.5 43.2, 354795.6 6690126 43.2), (354799.3 6690116.4 43.2, 354800.9 6690118.3 43.2, 354801.6 6690117.3 43.2, 354804 6690120.1 43.2, 354803 6690121 43.2, 354802.1 6690119.9 43.2, 354801 6690119.9 43.2, 354800.3 6690120.6 43.2, 354797.8 6690117.7 43.2, 354799.3 6690116.4 43.2))
BATIMENT0000000302931725;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;14.4;22.1;36.5;44.1;24.6;Cadastre;A 1.0;POLYGON Z ((355162.6 6689869.1 36.5, 355151.7 6689872.1 36.5, 355152 6689874.7 36.5, 355153.3 6689875.6 36.5, 355153.9 6689878.8 36.5, 355152.1 6689879.5 36.5, 355151.2 6689877 36.5, 355150.1 6689877.4 36.5, 355148.8 6689872.9 36.5, 355143.3 6689874.1 36.5, 355144.5 6689878.7 36.5, 355143.4 6689879.1 36.5, 355144.2 6689882.1 36.5, 355138.8 6689883.8 36.5, 355138 6689880.6 36.5, 355133.6 6689881.8 36.5, 355134.8 6689886.7 36.5, 355139.9 6689885.4 36.5, 355142.3 6689884.8 36.5, 355142.8 6689885.6 36.5, 355143.3 6689885.3 36.5, 355146.4 6689884.4 36.5, 355148.4 6689883.8 36.5, 355164 6689879.9 36.5, 355162.6 6689869.1 36.5))
BATIMENT0000000302931726;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;15.2;23.5;38.7;41.7;24.6;Cadastre;A 1.0;POLYGON Z ((355114.4 6689882.1 38.7, 355124.4 6689891.4 38.7, 355133.3 6689887.8 38.7, 355133.8 6689887.1 38.7, 355134.8 6689886.7 38.7, 355133.6 6689881.8 38.7, 355138 6689880.6 38.7, 355140.5 6689879.8 38.7, 355139.5 6689875.5 38.7, 355134.8 6689876.5 38.7, 355114.4 6689882.1 38.7), (355130.6 6689879 38.7, 355131.8 6689882.8 38.7, 355131.2 6689883.8 38.7, 355127.7 6689884.7 38.7, 355126.7 6689881.8 38.7, 355128.5 6689880.4 38.7, 355128.4 6689879.5 38.7, 355130.6 6689879 38.7))
BATIMENT0000000302931732;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;23.0;37.0;40.4;24.1;Cadastre;;POLYGON Z ((355144 6689888.5 37, 355144.7 6689888.4 37, 355145.8 6689888.1 37, 355145.7 6689886.7 37, 355146.7 6689886.3 37, 355146.4 6689884.4 37, 355143.3 6689885.3 37, 355144 6689888.5 37))
BATIMENT0000000302931729;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;7.0;12;20;20.7;21.9;42.7;45.2;23.6;Cadastre;A 0.6;POLYGON Z ((355164 6689879.9 42.7, 355148.4 6689883.8 42.7, 355150.1 6689894.8 42.7, 355165.5 6689892.6 42.7, 355164 6689879.9 42.7))
BATIMENT0000000302931733;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;00;00;16.8;23.2;40.0;43.6;24.4;Cadastre;A 1.0;POLYGON Z ((355138 6689903.8 40, 355139.9 6689901.5 40, 355144.5 6689900.1 40, 355142.4 6689898.4 40, 355146 6689894.4 40, 355145.9 6689894 40, 355144.7 6689888.4 40, 355144 6689888.5 40, 355143.3 6689885.3 40, 355142.8 6689885.6 40, 355140.9 6689887.9 40, 355139.7 6689887 40, 355139.9 6689886.5 40, 355140 6689886.2 40, 355139.9 6689885.4 40, 355134.8 6689886.7 40, 355133.8 6689887.1 40, 355133.3 6689887.8 40, 355124.4 6689891.4 40, 355138 6689903.8 40))
BATIMENT0000000302931730;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.1;23.0;38.2;40.0;23.4;Cadastre;;POLYGON Z ((355146 6689894.4 38.2, 355146.7 6689895.6 38.2, 355148.2 6689895.3 38.2, 355147.8 6689893.5 38.2, 355145.9 6689894 38.2, 355146 6689894.4 38.2))
BATIMENT0000000302931731;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;30;20;16.7;22.0;38.7;42.7;23.4;Cadastre;A 1.0;POLYGON Z ((355165.5 6689892.6 38.7, 355150.1 6689894.8 38.7, 355148.2 6689895.3 38.7, 355146.7 6689895.6 38.7, 355147.4 6689899.5 38.7, 355152.3 6689899.1 38.7, 355152.5 6689900.2 38.7, 355166 6689898.9 38.7, 355165.5 6689892.6 38.7))
BATIMENT0000000302931735;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;10;20;19.3;21.9;41.3;43.6;23.1;Cadastre;A 1.0;POLYGON Z ((355166 6689898.9 41.3, 355152.5 6689900.2 41.3, 355151.8 6689900.8 41.3, 355152.1 6689903.5 41.3, 355151.5 6689903.6 41.3, 355151.6 6689904.7 41.3, 355153.6 6689906.5 41.3, 355156.7 6689906.4 41.3, 355160.4 6689905.9 41.3, 355166.9 6689905.1 41.3, 355166 6689898.9 41.3))
BATIMENT0000000302931765;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;34;30;16.6;23.5;40.2;41.4;26.6;Cadastre;A 1.0;POLYGON Z ((355109.7 6689901.6 40.2, 355117.4 6689909.8 40.2, 355121.2 6689907.4 40.2, 355124.8 6689904.8 40.2, 355115.1 6689896.1 40.2, 355105 6689899.7 40.2, 355106.2 6689903.8 40.2, 355109.7 6689901.6 40.2))
BATIMENT0000000302931734;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;16.1;22.8;38.9;41.4;23.4;Cadastre;A 1.0;POLYGON Z ((355146.6 6689911.6 38.9, 355150.6 6689906.9 38.9, 355153.6 6689906.5 38.9, 355151.6 6689904.7 38.9, 355146.7 6689899.8 38.9, 355144.5 6689900.1 38.9, 355139.9 6689901.5 38.9, 355138 6689903.8 38.9, 355146.6 6689911.6 38.9))
BATIMENT0000000302931762;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;2.0;00;00;11.4;27.0;38.4;43.2;27.6;Cadastre;C 0.9;POLYGON Z ((355035.8 6689891.3 38.4, 355050.1 6689898.6 38.4, 355052.8 6689893.2 38.4, 355057.1 6689890.8 38.4, 355052.5 6689882.6 38.4, 355052.3 6689882.2 38.4, 355035.8 6689891.3 38.4))
BATIMENT0000000302931763;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;00;00;12.4;23.8;36.2;39.0;26.8;Cadastre;A 1.0;POLYGON Z ((355103.2 6689884.9 36.2, 355100.4 6689888.4 36.2, 355105 6689899.7 36.2, 355115.1 6689896.1 36.2, 355103.2 6689884.9 36.2))
BATIMENT0000000302931781;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;00;00;13.9;26.4;40.3;44.3;27.2;Cadastre;C 0.8;POLYGON Z ((355089.2 6689929.5 40.3, 355084.9 6689920.6 40.3, 355078.5 6689906 40.3, 355082.5 6689898.4 40.3, 355072.2 6689893 40.3, 355068.4 6689900.3 40.3, 355065.4 6689906 40.3, 355079 6689937.7 40.3, 355079 6689937.9 40.3, 355081.2 6689937.6 40.3, 355081.5 6689938.3 40.3, 355084.6 6689937 40.3, 355085 6689936.8 40.3, 355089.3 6689935 40.3, 355088 6689932.1 40.3, 355088.8 6689929.6 40.3, 355089.2 6689929.5 40.3))
BATIMENT0000000302931778;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;2006-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;00;00;12.2;26.0;38.3;41.5;26.9;Cadastre;C 0.5;POLYGON Z ((355111.6 6689921.9 38.3, 355108.8 6689915.9 38.3, 355107.1 6689908.5 38.3, 355101.1 6689911.2 38.3, 355101.8 6689912.8 38.3, 355084.9 6689920.6 38.3, 355089.2 6689929.5 38.3, 355107.8 6689921 38.3, 355109.7 6689923.9 38.3, 355111.8 6689922.9 38.3, 355111.6 6689921.9 38.3))
BATIMENT0000000302931764;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.1;26.8;41.0;46.5;28.2;Cadastre;;POLYGON Z ((355029.8 6689903 41, 355031.9 6689907.3 41, 355032.3 6689908.1 41, 355036.3 6689906.3 41, 355042.3 6689909.7 41, 355042.6 6689910.4 41, 355049 6689925.5 41, 355042.8 6689929.5 41, 355043.6 6689931.6 41, 355048.2 6689942.8 41, 355053.6 6689940.6 41, 355057.6 6689947 41, 355064.7 6689944.1 41, 355066 6689943.5 41, 355063.9 6689938.6 41, 355064.4 6689937.4 41, 355062.2 6689932.3 41, 355062.7 6689931.2 41, 355058.2 6689920.8 41, 355062.3 6689919.1 41, 355056 6689904.4 41, 355054.5 6689900.9 41, 355050.1 6689898.6 41, 355035.8 6689891.3 41, 355029.8 6689903 41))
BATIMENT0000000302931769;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;25.2;28.6;31.5;26.5;Cadastre;;POLYGON Z ((355107.8 6689922.8 28.6, 355107.4 6689922.2 28.6, 355106.7 6689922.1 28.6, 355106.2 6689922.6 28.6, 355106 6689923.3 28.6, 355106.8 6689924.5 28.6, 355107.4 6689925.3 28.6, 355104.7 6689927.3 28.6, 355110 6689937.3 28.6, 355113.2 6689935.7 28.6, 355110.3 6689930.2 28.6, 355109.7 6689930.4 28.6, 355108.6 6689927.9 28.6, 355113.3 6689925.6 28.6, 355111.8 6689922.9 28.6, 355109.7 6689923.9 28.6, 355107.8 6689922.8 28.6))
BATIMENT0000000302931779;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.6;25.2;39.8;40.9;27.0;Cadastre;;POLYGON Z ((355088 6689932.1 39.8, 355089.3 6689935 39.8, 355090.8 6689934.4 39.8, 355088.8 6689929.6 39.8, 355088 6689932.1 39.8))
BATIMENT0000000302931780;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;20;20;9.1;25.3;34.5;38.5;26.9;Cadastre;C 0.1;POLYGON Z ((355090.8 6689934.4 34.5, 355089.3 6689935 34.5, 355085 6689936.8 34.5, 355084.6 6689937 34.5, 355084.9 6689937.7 34.5, 355085.2 6689938.3 34.5, 355086.9 6689937.7 34.5, 355090.8 6689945.8 34.5, 355091.5 6689945.7 34.5, 355092.9 6689947.9 34.5, 355097 6689946 34.5, 355094.8 6689941.5 34.5, 355090.8 6689934.4 34.5))
BATIMENT0000000302931774;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;22.0;5.0;00;00;13.1;24.0;37.1;43.7;26.7;Cadastre;A 1.0;POLYGON Z ((355116.3 6689952 37.1, 355110.7 6689941.9 37.1, 355103 6689945.6 37.1, 355101.6 6689943.1 37.1, 355102.1 6689941.8 37.1, 355108.8 6689938.2 37.1, 355104.4 6689929.6 37.1, 355097.7 6689932.4 37.1, 355101.2 6689938 37.1, 355094.8 6689941.5 37.1, 355097 6689946 37.1, 355097.6 6689947.2 37.1, 355102.7 6689958.2 37.1, 355116.3 6689952 37.1))
BATIMENT0000000302931775;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.9;26.4;42.3;44.4;26.9;Cadastre;;POLYGON Z ((355059.4 6689949.8 42.3, 355065.9 6689946.9 42.3, 355064.7 6689944.1 42.3, 355057.6 6689947 42.3, 355059.4 6689949.8 42.3))
BATIMENT0000000302931736;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1836-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;15.1;21.8;37.0;39.6;23.1;Cadastre;A 1.0;POLYGON Z ((355160.7 6689908.8 37, 355158.9 6689909.1 37, 355156.7 6689906.4 37, 355153.6 6689906.5 37, 355150.6 6689906.9 37, 355146.6 6689911.6 37, 355160.4 6689924.5 37, 355169.4 6689923.7 37, 355166.9 6689905.1 37, 355160.4 6689905.9 37, 355160.7 6689908.8 37), (355163 6689911.7 37, 355163.2 6689914.1 37, 355161.5 6689914.2 37, 355161.2 6689911.8 37, 355163 6689911.7 37))
BATIMENT0000000302931766;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.3;23.1;39.5;41.5;26.0;Cadastre;A 1.0;POLYGON Z ((355122.9 6689910.7 39.5, 355124.9 6689914.6 39.5, 355122 6689916.5 39.5, 355125.2 6689923 39.5, 355127.5 6689920.4 39.5, 355132.5 6689924.7 39.5, 355132.9 6689925 39.5, 355139.2 6689918.2 39.5, 355124.8 6689904.8 39.5, 355121.2 6689907.4 39.5, 355122.9 6689910.7 39.5))
BATIMENT0000000302931767;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;9.8;23.5;33.3;38.5;26.3;Cadastre;A 1.0;POLYGON Z ((355119.2 6689913 33.3, 355120.3 6689915.4 33.3, 355118.7 6689916.4 33.3, 355119.4 6689917.5 33.3, 355111.6 6689921.9 33.3, 355111.8 6689922.9 33.3, 355113.3 6689925.6 33.3, 355117 6689933.3 33.3, 355118.3 6689932.5 33.3, 355117.4 6689931.2 33.3, 355126.7 6689926.6 33.3, 355125.2 6689923 33.3, 355122 6689916.5 33.3, 355124.9 6689914.6 33.3, 355122.9 6689910.7 33.3, 355119.2 6689913 33.3))
BATIMENT0000000302931770;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;00;00;13.6;22.3;35.9;38.5;24.4;Cadastre;A 1.0;POLYGON Z ((355152.8 6689930.9 35.9, 355139.2 6689918.2 35.9, 355132.9 6689925 35.9, 355138.7 6689930.5 35.9, 355146.4 6689937.7 35.9, 355152.8 6689930.9 35.9))
BATIMENT0000000302931771;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;24.2;30.0;31.5;25.3;Cadastre;;POLYGON Z ((355128.5 6689930.3 30, 355129.5 6689932 30, 355132.1 6689930.9 30, 355130.9 6689928.5 30, 355128.3 6689929.6 30, 355128.5 6689930.3 30))
BATIMENT0000000302931772;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;24.6;29.0;32.0;25.3;Cadastre;;POLYGON Z ((355129.7 6689932.6 29, 355129.5 6689932 29, 355128.5 6689930.3 29, 355126.4 6689931.3 29, 355127.8 6689933.8 29, 355129.7 6689932.6 29))
BATIMENT0000000302931782;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;20;20;11.8;22.7;34.5;38.0;24.9;Cadastre;A 0.9;POLYGON Z ((355135.5 6689945.4 34.5, 355142.6 6689941.8 34.5, 355146.4 6689937.7 34.5, 355138.7 6689930.5 34.5, 355138.2 6689931.2 34.5, 355131 6689935.2 34.5, 355135.1 6689944.4 34.5, 355135.5 6689945.4 34.5))
BATIMENT0000000302931768;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;3.0;50;20;9.9;23.2;33.1;36.3;25.5;Cadastre;A 1.0;POLYGON Z ((355118.7 6689936.5 33.1, 355125.1 6689949.9 33.1, 355135.1 6689944.4 33.1, 355131 6689935.2 33.1, 355129.7 6689932.6 33.1, 355127.8 6689933.8 33.1, 355121.3 6689937.7 33.1, 355118.3 6689932.5 33.1, 355117 6689933.3 33.1, 355118.7 6689936.5 33.1))
BATIMENT0000000302931773;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;00;00;8.8;23.2;32.0;37.1;25.3;Cadastre;C 0.9;POLYGON Z ((355111.7 6689940.1 32, 355117.7 6689951.3 32, 355118.6 6689953.3 32, 355125.1 6689949.9 32, 355118.7 6689936.5 32, 355111.7 6689940.1 32))
BATIMENT0000000302930264;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;14;20;15.7;24.2;40.0;42.6;24.8;Cadastre;A 1.0;POLYGON Z ((355123.2 6689971.5 40, 355123.4 6689969.9 40, 355119.8 6689964.7 40, 355119.3 6689964.6 40, 355118.7 6689963.2 40, 355109.9 6689967.3 40, 355114 6689975.7 40, 355123.2 6689971.5 40))
BATIMENT0000000302930534;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;15.5;21.4;21.6;16.6;Cadastre;;POLYGON Z ((355241.6 6689908 21.4, 355240.3 6689908.4 21.4, 355240.8 6689910.4 21.4, 355242 6689910.1 21.4, 355241.6 6689908 21.4))
BATIMENT0000000302930532;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;16.1;20.0;21.7;18.2;Cadastre;;POLYGON Z ((355257.2 6689932.5 20, 355256 6689926.4 20, 355249.3 6689928.5 20, 355249.5 6689929.2 20, 355250.5 6689932.2 20, 355251.1 6689933.4 20, 355257.2 6689932.5 20))
BATIMENT0000000302930833;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;9.2;;;;Cadastre;;POLYGON Z ((355289.8 6689929.9 -1000, 355290.3 6689933.2 -1000, 355294.4 6689932.6 -1000, 355293.8 6689929.2 -1000, 355289.8 6689929.9 -1000))
BATIMENT0000000302930539;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;16.9;20.0;26.2;18.3;Cadastre;;POLYGON Z ((355243.7 6689933.1 20, 355244.1 6689937 20, 355250.7 6689936.4 20, 355251.1 6689933.4 20, 355250.5 6689932.2 20, 355243.7 6689933.1 20))
BATIMENT0000000302931136;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;5.0;12;20;17.4;18.6;36.0;39.5;20.1;Cadastre;A 1.0;POLYGON Z ((355233.7 6689949.6 36, 355233.3 6689948.4 36, 355235.5 6689946.6 36, 355233.9 6689936 36, 355220 6689951.1 36, 355221.5 6689955.1 36, 355235.5 6689959.6 36, 355237.1 6689954.8 36, 355236.1 6689949.3 36, 355233.7 6689949.6 36))
BATIMENT0000000302931137;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.4;17.5;30.0;34.0;19.3;Cadastre;C 0.5;POLYGON Z ((355255.5 6689966.2 30, 355256.2 6689963.5 30, 355255.7 6689960.8 30, 355253.6 6689960 30, 355254.4 6689956.3 30, 355254 6689954.7 30, 355248.9 6689953 30, 355248.9 6689952.7 30, 355249 6689952.3 30, 355249 6689952.2 30, 355248.9 6689952 30, 355248.9 6689951.7 30, 355248.8 6689951.6 30, 355248.7 6689951.4 30, 355248.7 6689951.3 30, 355248.5 6689951 30, 355248.3 6689950.9 30, 355248.2 6689950.8 30, 355248.1 6689950.7 30, 355247.8 6689950.6 30, 355247.5 6689950.5 30, 355247.2 6689950.5 30, 355247 6689950.5 30, 355246.7 6689950.5 30, 355246.5 6689950.5 30, 355246.4 6689950.6 30, 355246.1 6689950.7 30, 355245.9 6689950.9 30, 355245.6 6689951.2 30, 355245.5 6689951.4 30, 355245.4 6689951.6 30, 355245.3 6689951.9 30, 355236.8 6689948.9 30, 355236.1 6689949.3 30, 355237.1 6689954.8 30, 355235.5 6689959.6 30, 355255.5 6689966.2 30))
BATIMENT0000000302931812;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;18.7;21.7;40.2;19.7;Cadastre;;POLYGON Z ((355220.9 6689971.3 21.7, 355232.2 6689974.9 21.7, 355233.5 6689970.7 21.7, 355222.2 6689967.1 21.7, 355220.9 6689971.3 21.7))
BATIMENT0000000302931071;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;11.9;19.0;30.9;33.9;21.2;Cadastre;C 0.8;POLYGON Z ((355210.8 6689987.6 30.9, 355211.7 6689979.9 30.9, 355206.9 6689979.4 30.9, 355203.2 6689978.5 30.9, 355202.5 6689977.1 30.9, 355201.8 6689976.7 30.9, 355203 6689965.9 30.9, 355203.7 6689965.6 30.9, 355204.3 6689964.7 30.9, 355209.4 6689965.7 30.9, 355214.5 6689967.6 30.9, 355215.6 6689965 30.9, 355216.7 6689962.6 30.9, 355197.2 6689955.7 30.9, 355196.7 6689956.1 30.9, 355194.1 6689982.8 30.9, 355206.2 6689987 30.9, 355210.8 6689987.6 30.9))
BATIMENT0000000302931069;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;23;12.8;15.4;28.2;30.9;18.8;Cadastre;C 0.3;POLYGON Z ((355253.6 6689987.4 28.2, 355252.1 6689991.6 28.2, 355254.9 6689992.9 28.2, 355256.5 6689989.8 28.2, 355260.6 6689979.4 28.2, 355245.7 6689974.5 28.2, 355241.1 6689982.5 28.2, 355253.6 6689987.4 28.2))
BATIMENT0000000302931070;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;90;20;11.7;19.7;31.5;34.7;21.0;Cadastre;A 1.0;POLYGON Z ((355193.8 6689987.6 31.5, 355205.6 6689988.8 31.5, 355206.1 6689988.9 31.5, 355206.2 6689987 31.5, 355194.1 6689982.8 31.5, 355193.8 6689987.6 31.5))
BATIMENT0000000302931784;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.4;26.4;29.8;30.5;27.0;Cadastre;C 0.2;POLYGON Z ((355083.1 6689943.3 29.8, 355080.4 6689944.7 29.8, 355075.1 6689947.3 29.8, 355072.6 6689948.5 29.8, 355073.9 6689951 29.8, 355074.7 6689952.4 29.8, 355088.8 6689945.4 29.8, 355086.7 6689941.6 29.8, 355086.6 6689941.7 29.8, 355083.1 6689943.3 29.8))
BATIMENT0000000302931785;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;26.1;31.2;34.4;27.0;Cadastre;;POLYGON Z ((355071.5 6689949 31.2, 355072.6 6689948.5 31.2, 355071.4 6689946 31.2, 355070 6689946.8 31.2, 355071.5 6689949 31.2))
BATIMENT0000000302931783;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;15;20;16.6;25.8;42.5;44.5;27.0;Cadastre;A 1.0;POLYGON Z ((355067.1 6689962.5 42.5, 355073 6689959.5 42.5, 355071.5 6689957 42.5, 355073.2 6689956.2 42.5, 355073.7 6689955.2 42.5, 355072.5 6689952.5 42.5, 355072.9 6689951.2 42.5, 355071.5 6689949 42.5, 355070 6689946.8 42.5, 355067.8 6689946.2 42.5, 355065.9 6689946.9 42.5, 355059.4 6689949.8 42.5, 355067.1 6689962.5 42.5))
BATIMENT0000000302931776;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;12;20;18.2;25.0;43.2;45.8;26.2;Cadastre;C 0.8;POLYGON Z ((355073.1 6689972.1 43.2, 355102.7 6689958.2 43.2, 355097.6 6689947.2 43.2, 355083.3 6689954.3 43.2, 355073 6689959.5 43.2, 355067.1 6689962.5 43.2, 355073.1 6689972.1 43.2))
BATIMENT0000000302930263;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;16.1;24.6;40.7;43.2;25.1;Cadastre;A 1.0;POLYGON Z ((355114 6689975.7 40.7, 355109.9 6689967.3 40.7, 355102.3 6689970.7 40.7, 355106.6 6689979.2 40.7, 355114 6689975.7 40.7))
BATIMENT0000000302930260;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;16.1;24.9;41.0;42.8;25.8;Cadastre;A 1.0;POLYGON Z ((355099 6689982.7 41, 355106.6 6689979.2 41, 355102.3 6689970.7 41, 355093.2 6689975 41, 355098 6689986.1 41, 355100.1 6689985.1 41, 355099 6689982.7 41))
BATIMENT0000000302930261;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;24.3;26.9;30.0;25.1;Cadastre;;POLYGON Z ((355105.4 6689983.8 26.9, 355106.6 6689987 26.9, 355111.9 6689984.7 26.9, 355114.4 6689983.6 26.9, 355113.4 6689980.3 26.9, 355105.4 6689983.8 26.9))
BATIMENT0000000302930259;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;00;00;11.0;25.4;36.4;42.9;26.2;Cadastre;A 1.0;POLYGON Z ((355071.8 6689985 36.4, 355077.6 6689996.5 36.4, 355088.9 6689990.8 36.4, 355089.5 6689991.6 36.4, 355092.4 6689990.3 36.4, 355092 6689989.4 36.4, 355096.6 6689987.2 36.4, 355097.3 6689988.2 36.4, 355096.6 6689989.8 36.4, 355097.7 6689992.6 36.4, 355079.5 6690000.9 36.4, 355080.9 6690004.2 36.4, 355095.8 6689997.3 36.4, 355101.2 6689994.8 36.4, 355098 6689986.1 36.4, 355093.2 6689975 36.4, 355071.8 6689985 36.4))
BATIMENT0000000302930258;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;15.5;25.9;41.5;44.6;26.7;Cadastre;A 1.0;POLYGON Z ((355060.1 6689993.5 41.5, 355064.2 6690004.7 41.5, 355069.8 6690001.1 41.5, 355077.6 6689996.5 41.5, 355071.8 6689985 41.5, 355060.1 6689993.5 41.5))
BATIMENT0000000302930257;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.4;24.5;30.0;33.0;26.5;Cadastre;A 1.0;POLYGON Z ((355109.7 6689999.5 30, 355103.6 6689983.8 30, 355103.1 6689983.8 30, 355100.1 6689985.1 30, 355098 6689986.1 30, 355101.2 6689994.8 30, 355105.8 6690009.7 30, 355111.8 6690007.8 30, 355109.7 6689999.5 30))
BATIMENT0000000302930266;Eglise;Religieux;;Non;En service;2012-06-19 19:09:03;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;18.2;23.4;41.6;;;Cadastre;;POLYGON Z ((355154.5 6689996.9 41.6, 355156 6689997.7 41.6, 355156.7 6689996.9 41.6, 355157.4 6689996.4 41.6, 355157.2 6689995.5 41.6, 355161.8 6689990.2 41.6, 355162.9 6689989.8 41.6, 355164.7 6689987.8 41.6, 355164.5 6689987.2 41.6, 355164 6689987.6 41.6, 355163.4 6689986.5 41.6, 355164.3 6689985.5 41.6, 355164.8 6689985.5 41.6, 355165.7 6689984.6 41.6, 355165.5 6689984.2 41.6, 355166 6689983.7 41.6, 355166.5 6689983.9 41.6, 355168 6689982.6 41.6, 355168 6689981.8 41.6, 355168.7 6689980.8 41.6, 355168.3 6689980.2 41.6, 355170.6 6689978 41.6, 355170.9 6689978.3 41.6, 355171.6 6689977.4 41.6, 355171.5 6689976.7 41.6, 355173.5 6689974.7 41.6, 355173.7 6689975.1 41.6, 355174.8 6689974 41.6, 355174.5 6689973.5 41.6, 355176.6 6689971.5 41.6, 355176.9 6689971.9 41.6, 355177.5 6689971.3 41.6, 355178.6 6689971.3 41.6, 355179 6689971.8 41.6, 355179.5 6689971.2 41.6, 355179.4 6689970.4 41.6, 355180.3 6689970.2 41.6, 355180.8 6689969.5 41.6, 355180.2 6689969 41.6, 355180.4 6689968.3 41.6, 355180.9 6689968 41.6, 355180.8 6689967.3 41.6, 355180.4 6689967.1 41.6, 355179.8 6689966 41.6, 355180.5 6689965.5 41.6, 355180.4 6689964.6 41.6, 355180.2 6689964.2 41.6, 355179.8 6689964.3 41.6, 355178.5 6689963.5 41.6, 355178.4 6689963.1 41.6, 355176.2 6689961.4 41.6, 355175.5 6689961.6 41.6, 355173.7 6689960 41.6, 355173.7 6689958.7 41.6, 355172.8 6689958.1 41.6, 355172.5 6689958.2 41.6, 355170.9 6689956.8 41.6, 355170.3 6689957.1 41.6, 355166.5 6689953.4 41.6, 355166.8 6689953.1 41.6, 355165.6 6689952.1 41.6, 355165.7 6689951.5 41.6, 355164.8 6689950.7 41.6, 355163.4 6689950.5 41.6, 355163.4 6689950.9 41.6, 355161.7 6689949.4 41.6, 355162 6689948.7 41.6, 355161.4 6689947.7 41.6, 355158.7 6689945.3 41.6, 355158.3 6689945.3 41.6, 355157.6 6689944.7 41.6, 355157 6689944.9 41.6, 355156.6 6689945.5 41.6, 355156.2 6689945.3 41.6, 355155.4 6689946.2 41.6, 355155 6689945.9 41.6, 355154.2 6689946.5 41.6, 355153.6 6689946 41.6, 355153.1 6689946.5 41.6, 355153.2 6689946.8 41.6, 355151.5 6689948.7 41.6, 355152 6689949.5 41.6, 355150 6689951.5 41.6, 355149.4 6689951 41.6, 355148.3 6689952.1 41.6, 355148.7 6689952.6 41.6, 355147 6689954.9 41.6, 355146.3 6689954.7 41.6, 355145.5 6689955.3 41.6, 355145.9 6689955.8 41.6, 355143.7 6689958.1 41.6, 355143.5 6689957.7 41.6, 355142.4 6689958.9 41.6, 355142.7 6689959.4 41.6, 355141.2 6689961 41.6, 355140.8 6689960.7 41.6, 355140.4 6689961.1 41.6, 355140.2 6689961 41.6, 355138.9 6689962.2 41.6, 355139.2 6689962.8 41.6, 355137.7 6689964.3 41.6, 355136.2 6689963.7 41.6, 355135 6689964.4 41.6, 355135 6689965.6 41.6, 355129.7 6689971.1 41.6, 355129 6689971.1 41.6, 355128.2 6689972.1 41.6, 355128.3 6689973.1 41.6, 355129.1 6689973.6 41.6, 355128 6689975.1 41.6, 355127.5 6689975 41.6, 355126.4 6689976.3 41.6, 355126.5 6689976.6 41.6, 355126.1 6689977.1 41.6, 355126.7 6689977.9 41.6, 355127.4 6689977.5 41.6, 355127.9 6689978.3 41.6, 355125.9 6689980 41.6, 355124.6 6689978.6 41.6, 355123.9 6689979.4 41.6, 355125.4 6689980.8 41.6, 355124.7 6689983.1 41.6, 355123.9 6689983.2 41.6, 355123.8 6689984.1 41.6, 355124.5 6689984.2 41.6, 355124.4 6689986.5 41.6, 355123.5 6689986.9 41.6, 355123.8 6689987.9 41.6, 355124.8 6689987.6 41.6, 355126.2 6689989.6 41.6, 355125.8 6689990.2 41.6, 355126.5 6689990.8 41.6, 355127 6689990.3 41.6, 355128.1 6689991 41.6, 355128.1 6689991.6 41.6, 355128.9 6689992.7 41.6, 355127.6 6689993.5 41.6, 355127.1 6689993 41.6, 355125.5 6689994.6 41.6, 355126.1 6689995.1 41.6, 355124.9 6689996.1 41.6, 355124.5 6689995.8 41.6, 355123.6 6689996.6 41.6, 355124 6689997.4 41.6, 355122.6 6689999.2 41.6, 355122.2 6689999.2 41.6, 355121.9 6689999.8 41.6, 355122.5 6690000.1 41.6, 355123 6690002.4 41.6, 355122.6 6690002.7 41.6, 355123.3 6690003.5 41.6, 355123.7 6690003.2 41.6, 355125.4 6690004.8 41.6, 355125.2 6690005.2 41.6, 355126.2 6690005.8 41.6, 355126.2 6690005.3 41.6, 355128.5 6690005.5 41.6, 355128.5 6690006 41.6, 355129.5 6690005.9 41.6, 355129.3 6690005.2 41.6, 355131.2 6690004.2 41.6, 355131.8 6690004.4 41.6, 355132.2 6690003.9 41.6, 355131.9 6690003.5 41.6, 355133.2 6690001.9 41.6, 355133.8 6690002.5 41.6, 355135.3 6690000.8 41.6, 355134.8 6690000.2 41.6, 355135.2 6689999.2 41.6, 355136 6689999.1 41.6, 355136.5 6689999.5 41.6, 355137.1 6689999 41.6, 355138 6690000.6 41.6, 355137.7 6690001 41.6, 355138.3 6690001.6 41.6, 355138.8 6690001.3 41.6, 355140.7 6690002.2 41.6, 355140.7 6690003.4 41.6, 355141.9 6690003.5 41.6, 355141.9 6690002.6 41.6, 355142.8 6690002.6 41.6, 355144.1 6690002.3 41.6, 355144.3 6690002.8 41.6, 355145.2 6690002.6 41.6, 355145.1 6690001.9 41.6, 355146.1 6690001.7 41.6, 355147.2 6690001.3 41.6, 355148.8 6690003 41.6, 355149.6 6690002.5 41.6, 355148.2 6690000.9 41.6, 355150.1 6689998.7 41.6, 355150.5 6689999.2 41.6, 355150 6690000 41.6, 355150.6 6690000.3 41.6, 355151.1 6689999.8 41.6, 355151.5 6689999.9 41.6, 355153.1 6689998.4 41.6, 355154.5 6689996.9 41.6))
BATIMENT0000000302930265;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;24.2;26.0;30.0;24.7;Cadastre;;POLYGON Z ((355117.3 6689978.4 26, 355116.4 6689980.2 26, 355119.1 6689989.9 26, 355122.8 6689988.9 26, 355119.1 6689977.5 26, 355117.3 6689978.4 26))
BATIMENT0000000302944143;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;20;30;9.0;20.4;29.5;33.3;21.6;Cadastre;A 1.0;POLYGON Z ((355183.4 6690004.7 29.5, 355177.6 6690004.2 29.5, 355177.5 6690003.8 29.5, 355165.1 6690002.7 29.5, 355164 6690014.8 29.5, 355164.2 6690015.5 29.5, 355164.7 6690016 29.5, 355170.2 6690016.6 29.5, 355170.2 6690015.1 29.5, 355172.4 6690015.4 29.5, 355172 6690020.8 29.5, 355176.4 6690021.2 29.5, 355181.6 6690021.8 29.5, 355183.4 6690004.7 29.5))
BATIMENT0000000302930262;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;9.9;21.3;31.3;36.4;24.0;Cadastre;A 1.0;POLYGON Z ((355147.8 6690004.2 31.3, 355148.2 6690004.2 31.3, 355148.3 6690009 31.3, 355145.7 6690011 31.3, 355142.3 6690010.6 31.3, 355142.3 6690009.4 31.3, 355140.8 6690008.2 31.3, 355134.5 6690008 31.3, 355138 6690022.4 31.3, 355148 6690023 31.3, 355147.8 6690027.9 31.3, 355152.2 6690028.5 31.3, 355152.8 6690018.7 31.3, 355153.5 6689999 31.3, 355153.1 6689998.4 31.3, 355151.5 6689999.9 31.3, 355151.1 6689999.8 31.3, 355150.6 6690000.3 31.3, 355150 6690000 31.3, 355150.5 6689999.2 31.3, 355150.1 6689998.7 31.3, 355148.2 6690000.9 31.3, 355149.6 6690002.5 31.3, 355148.8 6690003 31.3, 355147.2 6690001.3 31.3, 355146.1 6690001.7 31.3, 355147.8 6690004.2 31.3))
BATIMENT0000000302944135;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;5.8;24.3;30.2;33.0;26.5;Cadastre;A 1.0;POLYGON Z ((355113.3 6690031.7 30.2, 355113.8 6690033.5 30.2, 355117.8 6690032.7 30.2, 355111.8 6690007.8 30.2, 355105.8 6690009.7 30.2, 355106.2 6690011 30.2, 355111.7 6690031.9 30.2, 355113.3 6690031.7 30.2))
BATIMENT0000000029191979;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2012-06-19 19:54:10;;;;;BDTopo;2.5;BDTopo;1.5;;;;;1.3;24.4;;;;Imagerie aérienne;;POLYGON Z ((355138 6690027.2 25.7, 355136.7 6690021.1 25.7, 355131.4 6690022.3 25.2, 355133 6690027.9 24.8, 355138 6690027.2 25.7))
BATIMENT0000000302944142;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;6.0;20.5;26.6;33.5;23.3;Cadastre;A 1.0;POLYGON Z ((355152.1 6690035.5 26.6, 355170.2 6690037.5 26.6, 355170.3 6690038.1 26.6, 355171.3 6690038.2 26.6, 355174.5 6690038.8 26.6, 355174.8 6690037 26.6, 355180.2 6690037.4 26.6, 355181.6 6690021.8 26.6, 355176.4 6690021.2 26.6, 355176.1 6690025.2 26.6, 355174.5 6690025 26.6, 355174.1 6690029.7 26.6, 355175.6 6690029.9 26.6, 355175.3 6690032.8 26.6, 355157.4 6690030.3 26.6, 355157.6 6690019.2 26.6, 355152.8 6690018.7 26.6, 355152.2 6690028.5 26.6, 355152.1 6690035.5 26.6))
BATIMENT0000000302944136;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;24.1;28.7;33.7;24.6;Cadastre;;POLYGON Z ((355122.8 6690029.9 28.7, 355121.1 6690028.6 28.7, 355119.4 6690029 28.7, 355120.6 6690034.8 28.7, 355124.1 6690034.2 28.7, 355122.8 6690029.9 28.7))
BATIMENT0000000302944132;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1740-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;10;20;8.1;23.3;31.5;35.1;25.0;Cadastre;C 0.3;POLYGON Z ((355140.7 6690040.3 31.5, 355139.4 6690035.1 31.5, 355133.8 6690035.9 31.5, 355133.2 6690032.6 31.5, 355124.1 6690034.2 31.5, 355120.6 6690034.8 31.5, 355118.2 6690035.1 31.5, 355118.8 6690039.3 31.5, 355113.4 6690040.1 31.5, 355113.7 6690044.7 31.5, 355114.4 6690044.6 31.5, 355124 6690043.1 31.5, 355138.6 6690040.6 31.5, 355140.7 6690040.3 31.5))
BATIMENT0000000302944145;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;21.2;28.0;32.5;21.5;Cadastre;;POLYGON Z ((355170.3 6690046.8 28, 355170.6 6690042.2 28, 355170.2 6690042.1 28, 355170 6690039.4 28, 355168.3 6690039.6 28, 355168.5 6690046.4 28, 355168.6 6690047 28, 355170.3 6690046.8 28))
BATIMENT0000000302930255;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;13.3;26.4;39.7;42.4;27.9;Cadastre;C 0.9;POLYGON Z ((355051.1 6690012.6 39.7, 355051.9 6690013.5 39.7, 355054.2 6690012.3 39.7, 355053.6 6690011.1 39.7, 355059.9 6690007.3 39.7, 355057.9 6690002.2 39.7, 355054.9 6689997.8 39.7, 355044.3 6690005.9 39.7, 355049.1 6690013.8 39.7, 355051.1 6690012.6 39.7))
BATIMENT0000000302944123;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;12.4;26.8;39.2;41.4;28.3;Cadastre;C 0.6;POLYGON Z ((355061.5 6690012 39.2, 355048.5 6690018.7 39.2, 355047.5 6690016.6 39.2, 355045.2 6690017.6 39.2, 355049.3 6690025.4 39.2, 355058.8 6690020.5 39.2, 355064.1 6690017.8 39.2, 355061.5 6690012 39.2))
BATIMENT0000000302944129;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;26.6;29.2;35.0;28.1;Cadastre;A 1.0;POLYGON Z ((355058.8 6690020.5 29.2, 355059.6 6690022.1 29.2, 355062 6690027 29.2, 355066.8 6690024.7 29.2, 355064.1 6690017.8 29.2, 355058.8 6690020.5 29.2))
BATIMENT0000000302944122;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;10;20;11.0;27.0;38.0;42.0;29.7;Cadastre;A 1.0;POLYGON Z ((355044.1 6690005.7 38, 355040.3 6690008.5 38, 355040 6690008.2 38, 355033.1 6690013.7 38, 355037.6 6690023.5 38, 355038.8 6690025.7 38, 355046.7 6690042.1 38, 355057 6690040 38, 355049.3 6690025.4 38, 355045.2 6690017.6 38, 355044.6 6690016.7 38, 355049.1 6690013.8 38, 355044.3 6690005.9 38, 355044.1 6690005.7 38), (355050.4 6690034.9 38, 355046 6690037.1 38, 355045.2 6690035.1 38, 355049.7 6690033.3 38, 355050.4 6690034.9 38), (355040.5 6690025.4 38, 355038.5 6690021.9 38, 355044.3 6690017.3 38, 355046.8 6690023.3 38, 355040.5 6690025.4 38))
BATIMENT0000000302930256;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;4.0;;;4.9;25.3;30.2;42.5;27.6;Cadastre;A 1.0;POLYGON Z ((355112.5 6690034.9 30.2, 355111.7 6690031.9 30.2, 355106.2 6690011 30.2, 355101.5 6690012.5 30.2, 355095.8 6689997.3 30.2, 355080.9 6690004.2 30.2, 355079.5 6690000.9 30.2, 355077.6 6689996.5 30.2, 355069.8 6690001.1 30.2, 355064.2 6690004.7 30.2, 355069.5 6690019.1 30.2, 355070.7 6690021.2 30.2, 355073 6690022.6 30.2, 355080.3 6690041.9 30.2, 355076.5 6690043.5 30.2, 355078.6 6690049.5 30.2, 355080 6690053.2 30.2, 355080.9 6690053 30.2, 355086.3 6690051.6 30.2, 355090.3 6690050.5 30.2, 355093 6690049.9 30.2, 355096.9 6690048.9 30.2, 355113.7 6690044.7 30.2, 355113.4 6690040.1 30.2, 355112.5 6690034.9 30.2))
BATIMENT0000000302944124;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;9.5;27.6;37.2;40.7;29.7;Cadastre;A 1.0;POLYGON Z ((355061.6 6690029.4 37.2, 355058.2 6690023 37.2, 355059.6 6690022.1 37.2, 355058.8 6690020.5 37.2, 355049.3 6690025.4 37.2, 355057 6690040 37.2, 355064.8 6690035.9 37.2, 355061.6 6690029.4 37.2))
BATIMENT0000000302944125;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.6;26.8;32.5;35.1;29.7;Cadastre;A 1.0;POLYGON Z ((355070.3 6690033.4 32.5, 355064.8 6690035.9 32.5, 355057 6690040 32.5, 355060.9 6690047.4 32.5, 355061.5 6690047.2 32.5, 355062.3 6690049.2 32.5, 355069.1 6690046.5 32.5, 355074.5 6690044.3 32.5, 355070.3 6690033.4 32.5))
BATIMENT0000000302944134;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;00;00;7.8;24.4;32.2;36.2;25.7;Cadastre;C 0.3;POLYGON Z ((355113.7 6690044.7 32.2, 355096.9 6690048.9 32.2, 355098.8 6690065.4 32.2, 355105.1 6690064.7 32.2, 355104.4 6690060.2 32.2, 355102.8 6690060.5 32.2, 355102.2 6690056.8 32.2, 355100.7 6690056.7 32.2, 355100.2 6690054.8 32.2, 355115.5 6690051.3 32.2, 355114.4 6690044.6 32.2, 355113.7 6690044.7 32.2))
BATIMENT0000000302944128;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;50;20;7.8;26.1;34.0;40.0;29.3;Cadastre;A 1.0;POLYGON Z ((355074.5 6690044.3 34, 355069.1 6690046.5 34, 355072.8 6690055.5 34, 355054.1 6690058.5 34, 355055.1 6690070.2 34, 355079 6690067.5 34, 355078.5 6690061.9 34, 355077.7 6690054.6 34, 355076.1 6690050.3 34, 355078.6 6690049.5 34, 355076.5 6690043.5 34, 355074.5 6690044.3 34))
BATIMENT0000000302944131;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;29;20;10.2;25.0;35.2;36.9;26.7;Cadastre;A 1.0;POLYGON Z ((355098.8 6690065.4 35.2, 355096.9 6690048.9 35.2, 355093 6690049.9 35.2, 355093.4 6690054.7 35.2, 355092.2 6690054.4 35.2, 355091.2 6690054.9 35.2, 355090.3 6690050.5 35.2, 355086.3 6690051.6 35.2, 355087.6 6690066.6 35.2, 355098.8 6690065.4 35.2))
BATIMENT0000000302931067;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;9.9;16.3;26.2;28.4;19.6;Cadastre;A 1.0;POLYGON Z ((355275.8 6689995.9 26.2, 355275.5 6689996.9 26.2, 355275.8 6689997.8 26.2, 355276.8 6689998.2 26.2, 355277.4 6689997.8 26.2, 355277.9 6689996.6 26.2, 355282.4 6689997.9 26.2, 355286 6689987.7 26.2, 355275.8 6689984.3 26.2, 355269.3 6689993.6 26.2, 355275.8 6689995.9 26.2))
BATIMENT0000000302931066;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;20;20;14.7;15.7;30.5;34.4;19.9;Cadastre;A 1.0;POLYGON Z ((355309.6 6689998.7 30.5, 355309.5 6689995.4 30.5, 355289.3 6689988.7 30.5, 355285.6 6689999.7 30.5, 355287.1 6690003.4 30.5, 355289.1 6690008 30.5, 355309.6 6689998.7 30.5))
BATIMENT0000000302931068;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;4.0;;;10.9;18.1;29.0;34.6;21.0;Cadastre;A 1.0;POLYGON Z ((355191.8 6690009.1 29, 355203.8 6690011.1 29, 355204.8 6689996.9 29, 355208.9 6689997.2 29, 355209.2 6689993.4 29, 355205.2 6689993.1 29, 355205.6 6689988.8 29, 355193.8 6689987.6 29, 355191.8 6690009.1 29))
BATIMENT0000000302931065;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;23;6.2;14.9;21.1;30.1;19.9;Cadastre;A 0.6;POLYGON Z ((355269.3 6689993.6 21.1, 355275.8 6689984.3 21.1, 355260.6 6689979.4 21.1, 355256.5 6689989.8 21.1, 355254.9 6689992.9 21.1, 355258.1 6689994.4 21.1, 355259.6 6689992.3 21.1, 355260.3 6689992.7 21.1, 355248.1 6690010.4 21.1, 355245.8 6690008.4 21.1, 355243.2 6690012.3 21.1, 355251.5 6690019.5 21.1, 355267.6 6689996.1 21.1, 355269.3 6689993.6 21.1))
BATIMENT0000000302931061;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;16.0;20.5;23.7;17.8;Cadastre;;POLYGON Z ((355230.2 6690001.6 20.5, 355234.2 6690004.9 20.5, 355235.8 6690002.2 20.5, 355233.7 6690000.6 20.5, 355235.6 6689997.4 20.5, 355236.5 6689995.8 20.5, 355234.1 6689994.5 20.5, 355230.2 6690001.6 20.5))
BATIMENT0000000302931062;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;16.0;21.2;25.7;17.4;Cadastre;;POLYGON Z ((355237.7 6689998.7 21.2, 355235.6 6689997.4 21.2, 355233.7 6690000.6 21.2, 355235.8 6690002.2 21.2, 355237.7 6689998.7 21.2))
BATIMENT0000000302931815;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.2;14.5;15.7;18.2;15.9;Cadastre;;POLYGON Z ((355247.2 6690005.9 15.7, 355248.4 6690006.7 15.7, 355249.4 6690005.4 15.7, 355249.9 6690005.7 15.7, 355252.4 6690001.4 15.7, 355250.6 6690000.2 15.7, 355247.2 6690005.9 15.7))
BATIMENT0000000302931063;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;11.0;15.9;27.0;34.7;18.9;Cadastre;A 1.0;POLYGON Z ((355234.2 6690004.9 27, 355230.2 6690001.6 27, 355234.1 6689994.5 27, 355235.8 6689991.5 27, 355230.2 6689988.6 27, 355224.7 6689998 27, 355224.1 6689998.6 27, 355223 6689997.5 27, 355214.9 6690005.8 27, 355216.2 6690007 27, 355215.3 6690008 27, 355237.1 6690030.6 27, 355254.8 6690023.1 27, 355254.1 6690022.4 27, 355251.5 6690019.5 27, 355243.2 6690012.3 27, 355234.2 6690004.9 27))
BATIMENT0000000302944276;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.5;17.0;30.5;34.8;21.0;Cadastre;C 0.2;POLYGON Z ((355198 6690047.7 30.5, 355198.1 6690046.4 30.5, 355202.2 6690044.4 30.5, 355203.2 6690044.8 30.5, 355227.1 6690034.4 30.5, 355227.8 6690034.8 30.5, 355235.4 6690031.4 30.5, 355218 6690013.7 30.5, 355212.5 6690012.7 30.5, 355203.8 6690011.1 30.5, 355191.8 6690009.1 30.5, 355187.5 6690052.6 30.5, 355198 6690047.7 30.5), (355202 6690020 30.5, 355215.3 6690022.2 30.5, 355219.4 6690025.9 30.5, 355218.4 6690027.1 30.5, 355217.3 6690027.2 30.5, 355216.4 6690028.6 30.5, 355200.7 6690035.6 30.5, 355202 6690020 30.5))
BATIMENT0000000302944759;Industriel, agricole ou commercial;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.4;16.8;22.2;27.0;20.5;Cadastre;C 0.2;POLYGON Z ((355346 6690022 22.2, 355344.1 6690017.7 22.2, 355325.7 6690010.8 22.2, 355209.3 6690061.9 22.2, 355212.5 6690069.3 22.2, 355326 6690019.6 22.2, 355329.3 6690018.2 22.2, 355336.8 6690021.1 22.2, 355338.6 6690025.4 22.2, 355335.7 6690032.7 22.2, 355334.9 6690033.1 22.2, 355218.8 6690084.1 22.2, 355222.2 6690091.4 22.2, 355338.9 6690040.1 22.2, 355346 6690022 22.2))
BATIMENT0000000302944144;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;21.3;29.7;31.4;21.6;Cadastre;;POLYGON Z ((355166.2 6690046.4 29.7, 355166.3 6690048.1 29.7, 355168.6 6690048 29.7, 355168.6 6690047 29.7, 355168.5 6690046.4 29.7, 355166.2 6690046.4 29.7))
BATIMENT0000000302944146;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;21.5;28.7;31.7;21.7;Cadastre;;POLYGON Z ((355164.5 6690048.2 28.7, 355164.3 6690046.5 28.7, 355162.8 6690046.5 28.7, 355163 6690048.3 28.7, 355164.5 6690048.2 28.7))
BATIMENT0000000302944139;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;00;00;4.4;21.3;25.7;33.9;23.3;Cadastre;A 1.0;POLYGON Z ((355170.3 6690038.1 25.7, 355170.2 6690037.5 25.7, 355152.1 6690035.5 25.7, 355153.2 6690050.2 25.7, 355153.6 6690059.5 25.7, 355163.1 6690058.4 25.7, 355163 6690048.3 25.7, 355161 6690048.5 25.7, 355160.7 6690045.8 25.7, 355158.8 6690045.9 25.7, 355158.4 6690046.7 25.7, 355157.9 6690046.8 25.7, 355157.2 6690042.2 25.7, 355166.8 6690043.9 25.7, 355166.2 6690046.4 25.7, 355168.5 6690046.4 25.7, 355168.3 6690039.6 25.7, 355170 6690039.4 25.7, 355170.3 6690038.1 25.7))
BATIMENT0000000302944141;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;50;20;11.8;20.9;32.7;36.5;21.8;Cadastre;A 1.0;POLYGON Z ((355177.9 6690056.7 32.7, 355180.2 6690037.4 32.7, 355174.8 6690037 32.7, 355174.5 6690038.8 32.7, 355171.3 6690038.2 32.7, 355171.1 6690039.2 32.7, 355172.1 6690039.4 32.7, 355171.8 6690039.7 32.7, 355172.6 6690039.8 32.7, 355172 6690046.7 32.7, 355171.3 6690046.8 32.7, 355170.8 6690047.7 32.7, 355168.6 6690048 32.7, 355166.3 6690048.1 32.7, 355164.5 6690048.2 32.7, 355163 6690048.3 32.7, 355163.1 6690058.4 32.7, 355177.9 6690056.7 32.7))
BATIMENT0000000302944137;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;30;20;6.0;22.9;29.0;32.7;24.1;Cadastre;A 1.0;POLYGON Z ((355140.4 6690051.1 29, 355129 6690053.1 29, 355128.3 6690049.6 29, 355127.8 6690049.6 29, 355127.5 6690047.7 29, 355137.7 6690045.9 29, 355138.4 6690049.5 29, 355140.1 6690049.2 29, 355138.6 6690040.6 29, 355124 6690043.1 29, 355127.8 6690062.3 29, 355142 6690060.6 29, 355140.5 6690051.8 29, 355140.4 6690051.1 29))
BATIMENT0000000302944133;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1881-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;8.3;23.4;31.7;34.3;24.8;Cadastre;A 1.0;POLYGON Z ((355114.4 6690044.6 31.7, 355115.5 6690051.3 31.7, 355116 6690055.5 31.7, 355117.6 6690063.3 31.7, 355127.8 6690062.3 31.7, 355124 6690043.1 31.7, 355114.4 6690044.6 31.7))
BATIMENT0000000302944138;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1855-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.3;22.2;31.5;33.0;23.2;Cadastre;A 1.0;POLYGON Z ((355140.5 6690051.8 31.5, 355142 6690060.6 31.5, 355153.6 6690059.5 31.5, 355153.2 6690050.2 31.5, 355140.5 6690051.8 31.5))
BATIMENT0000000302944140;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;11.8;24.0;35.8;38.4;24.7;Cadastre;C 0.7;POLYGON Z ((355109.3 6690056.4 35.8, 355109.4 6690056.8 35.8, 355108 6690057 35.8, 355108.3 6690058.9 35.8, 355107.5 6690059.2 35.8, 355107.9 6690064.4 35.8, 355117.6 6690063.3 35.8, 355116 6690055.5 35.8, 355109.3 6690056.4 35.8))
BATIMENT0000000302944236;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;21.6;24.5;26.5;22.1;Cadastre;;POLYGON Z ((355158.2 6690075.9 24.5, 355161.8 6690075.5 24.5, 355161.3 6690071.6 24.5, 355157.8 6690072 24.5, 355158.2 6690075.9 24.5))
BATIMENT0000000302944233;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;20;20;10.2;21.4;31.7;37.3;22.2;Cadastre;A 1.0;POLYGON Z ((355177.4 6690065.1 31.7, 355157.1 6690067.3 31.7, 355157.8 6690072 31.7, 355161.3 6690071.6 31.7, 355161.8 6690075.5 31.7, 355164.6 6690075.2 31.7, 355164.7 6690076.4 31.7, 355161.6 6690076.7 31.7, 355161.9 6690079.8 31.7, 355164.1 6690079.6 31.7, 355164.2 6690080.4 31.7, 355165.2 6690080.3 31.7, 355165.4 6690082.4 31.7, 355163.5 6690082.7 31.7, 355163.5 6690080.7 31.7, 355162.1 6690080.7 31.7, 355158.8 6690081 31.7, 355159.3 6690085.3 31.7, 355175.5 6690084.9 31.7, 355177.4 6690065.1 31.7))
BATIMENT0000000302944760;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.8;15.3;26.1;29.9;20.8;Cadastre;C 0.2;POLYGON Z ((355208.5 6690071.1 26.1, 355204.5 6690072.8 26.1, 355201.9 6690079.9 26.1, 355203.7 6690084.5 26.1, 355211.1 6690087.3 26.1, 355215 6690085.8 26.1, 355218.8 6690084.1 26.1, 355334.9 6690033.1 26.1, 355335.7 6690032.7 26.1, 355338.6 6690025.4 26.1, 355336.8 6690021.1 26.1, 355329.3 6690018.2 26.1, 355326 6690019.6 26.1, 355212.5 6690069.3 26.1, 355208.5 6690071.1 26.1))
BATIMENT0000000302944758;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;20.3;24.9;36.2;21.0;Cadastre;;POLYGON Z ((355215 6690085.8 24.9, 355211.1 6690087.3 24.9, 355203.7 6690084.5 24.9, 355201.9 6690079.9 24.9, 355204.5 6690072.8 24.9, 355208.5 6690071.1 24.9, 355212.5 6690069.3 24.9, 355209.3 6690061.9 24.9, 355205.6 6690063.6 24.9, 355201.6 6690065.2 24.9, 355194.6 6690083.4 24.9, 355196.5 6690087.6 24.9, 355214.6 6690094.8 24.9, 355218.3 6690093.1 24.9, 355222.2 6690091.4 24.9, 355218.8 6690084.1 24.9, 355215 6690085.8 24.9))
BATIMENT0000000302944367;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;4.0;00;00;9.1;15.3;24.5;32.4;17.9;Cadastre;A 1.0;POLYGON Z ((355291.6 6690094.4 24.5, 355296.7 6690105.5 24.5, 355298.3 6690108.9 24.5, 355301.4 6690115.4 24.5, 355312.3 6690107.4 24.5, 355312.6 6690107.2 24.5, 355304.6 6690088.7 24.5, 355291.6 6690094.4 24.5))
BATIMENT0000000302944375;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.7;17.2;28.0;31.0;18.5;Cadastre;A 0.2;POLYGON Z ((355277.9 6690100.5 28, 355280.8 6690107.1 28, 355281.5 6690108.3 28, 355287.6 6690105.9 28, 355287.4 6690107.2 28, 355289 6690109.9 28, 355289.8 6690109.9 28, 355293.2 6690108 28, 355292.8 6690107.5 28, 355296.7 6690105.5 28, 355291.6 6690094.4 28, 355277.9 6690100.5 28))
BATIMENT0000000302944382;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;4.0;;;11.9;17.8;29.7;30.0;19.5;Cadastre;A 0.2;POLYGON Z ((355267.4 6690105.3 29.7, 355270.9 6690111.6 29.7, 355280.8 6690107.1 29.7, 355277.9 6690100.5 29.7, 355267.4 6690105.3 29.7))
BATIMENT0000000302944376;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;16.9;22.5;25.0;19.1;Cadastre;;POLYGON Z ((355291.3 6690113.4 22.5, 355298.3 6690108.9 22.5, 355296.7 6690105.5 22.5, 355292.8 6690107.5 22.5, 355293.2 6690108 22.5, 355289.8 6690109.9 22.5, 355291.3 6690113.4 22.5))
BATIMENT0000000302944374;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;18.5;23.5;25.9;22.5;Cadastre;;POLYGON Z ((355282.4 6690110 23.5, 355272.4 6690115 23.5, 355276.4 6690122.9 23.5, 355285.9 6690116.9 23.5, 355282.4 6690110 23.5))
BATIMENT0000000302944372;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;16.8;23.9;25.7;25.3;Cadastre;A 0.2;POLYGON Z ((355285.9 6690116.9 23.9, 355276.4 6690122.9 23.9, 355279.5 6690129.3 23.9, 355280.2 6690128.7 23.9, 355301.4 6690115.4 23.9, 355298.3 6690108.9 23.9, 355291.3 6690113.4 23.9, 355285.9 6690116.9 23.9))
BATIMENT0000000302944402;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.7;18.0;34.7;37.0;23.1;Cadastre;;POLYGON Z ((355260.8 6690135.1 34.7, 355268.2 6690131.7 34.7, 355264.3 6690122.4 34.7, 355265 6690122.1 34.7, 355263.3 6690118 34.7, 355262.5 6690118.3 34.7, 355258.5 6690109 34.7, 355251 6690112.2 34.7, 355250.9 6690112.3 34.7, 355260.8 6690135.1 34.7))
BATIMENT0000000302944365;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2020-05-29 13:38:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.8;14.9;23.8;;26.3;Cadastre;A 1.0;POLYGON Z ((355286.3 6690134.5 23.8, 355286.9 6690134.2 23.8, 355287.7 6690134.5 23.8, 355289.2 6690133.7 23.8, 355289.3 6690132.4 23.8, 355290.5 6690131.5 23.8, 355296.1 6690137.6 23.8, 355313.8 6690124.5 23.8, 355321 6690119.2 23.8, 355316 6690112.3 23.8, 355312.3 6690107.4 23.8, 355301.4 6690115.4 23.8, 355280.2 6690128.7 23.8, 355286.3 6690134.5 23.8))
BATIMENT0000000302944130;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;20;20;10.9;25.6;36.5;38.3;27.5;Cadastre;A 1.0;POLYGON Z ((355087.6 6690066.6 36.5, 355086.3 6690051.6 36.5, 355080.9 6690053 36.5, 355081.6 6690061.7 36.5, 355078.5 6690061.9 36.5, 355079 6690067.5 36.5, 355087.6 6690066.6 36.5))
BATIMENT0000000302944116;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:18:51;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;29.1;32.8;33.2;29.9;Cadastre;;POLYGON Z ((355038.2 6690061 32.8, 355039.5 6690060.8 32.8, 355042.3 6690060.4 32.8, 355042 6690058.4 32.8, 355037.9 6690059.1 32.8, 355038.2 6690061 32.8))
BATIMENT0000000302944118;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;4.0;20;20;5.7;28.4;34.1;36.5;30.0;Cadastre;C 0.1;POLYGON Z ((355032.2 6690072.7 34.1, 355040.3 6690071.8 34.1, 355039.5 6690060.8 34.1, 355038.2 6690061 34.1, 355031.4 6690062.2 34.1, 355031.2 6690062.2 34.1, 355031.4 6690064.5 34.1, 355032.2 6690072.7 34.1))
BATIMENT0000000302944210;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;01;5.9;26.0;32.0;35.0;27.1;Cadastre;A 0.1;POLYGON Z ((355075.4 6690076.2 32, 355075.5 6690077.7 32, 355077.7 6690077.5 32, 355077.7 6690075.9 32, 355075.4 6690076.2 32))
BATIMENT0000000302944815;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;01;5.3;26.6;32.0;33.7;27.8;Cadastre;A 0.1;POLYGON Z ((355060 6690076.7 32, 355060.3 6690078.3 32, 355062.6 6690078.2 32, 355062.4 6690076.5 32, 355060 6690076.7 32))
BATIMENT0000000302944211;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;12;20;11.5;24.6;36.2;38.9;26.1;Cadastre;B 0.4;POLYGON Z ((355092 6690074.4 36.2, 355092.7 6690084.6 36.2, 355092.8 6690084.9 36.2, 355105.4 6690083.5 36.2, 355105.8 6690087 36.2, 355107.4 6690086.6 36.2, 355106.8 6690072.8 36.2, 355092 6690074.4 36.2))
BATIMENT0000000302944207;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;00;00;9.7;25.2;35.0;37.4;28.9;Cadastre;A 1.0;POLYGON Z ((355077.7 6690075.9 35, 355077.7 6690077.5 35, 355078.6 6690086.4 35, 355092.7 6690084.6 35, 355092 6690074.4 35, 355077.7 6690075.9 35))
BATIMENT0000000302944191;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;00;00;13.8;29.0;42.8;43.5;29.3;Cadastre;A 0.4;POLYGON Z ((355042 6690089.5 42.8, 355042.3 6690092.2 42.8, 355042.7 6690096.1 42.8, 355042.9 6690098.1 42.8, 355059.7 6690096.3 42.8, 355058.2 6690081.7 42.8, 355041.4 6690083.6 42.8, 355041.9 6690088.4 42.8, 355042 6690089.5 42.8))
BATIMENT0000000302944208;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;25.5;29.4;30.9;28.7;Cadastre;;POLYGON Z ((355100.3 6690105.4 29.4, 355099.5 6690089.9 29.4, 355098.7 6690090 29.4, 355098.1 6690085.3 29.4, 355095.3 6690085.7 29.4, 355095.7 6690090.2 29.4, 355093.1 6690090.5 29.4, 355093.5 6690097.8 29.4, 355093.9 6690106 29.4, 355100.3 6690105.4 29.4))
BATIMENT0000000302944204;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;16;29;6.9;25.9;32.9;34.9;29.9;Cadastre;A 1.0;POLYGON Z ((355093.5 6690097.8 32.9, 355083.9 6690098.8 32.9, 355083.8 6690095.4 32.9, 355086 6690095.1 32.9, 355085.1 6690087.5 32.9, 355078.8 6690088.2 32.9, 355079.1 6690092.1 32.9, 355080.7 6690106.8 32.9, 355093.9 6690106 32.9, 355093.5 6690097.8 32.9))
BATIMENT0000000302944229;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;14.7;22.8;37.5;41.0;24.3;Cadastre;B 0.8;POLYGON Z ((355131.7 6690070.1 37.5, 355131.8 6690074.1 37.5, 355131.8 6690082.1 37.5, 355139.3 6690081.9 37.5, 355138.8 6690069.3 37.5, 355131.7 6690070.1 37.5))
BATIMENT0000000302944234;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.9;21.9;27.8;29.6;23.0;Cadastre;A 1.0;POLYGON Z ((355148.5 6690068.2 27.8, 355149.6 6690079.7 27.8, 355149.7 6690081.7 27.8, 355150.2 6690085.7 27.8, 355159.3 6690085.3 27.8, 355158.8 6690081 27.8, 355158.3 6690077 27.8, 355158.2 6690075.9 27.8, 355157.8 6690072 27.8, 355157.1 6690067.3 27.8, 355148.5 6690068.2 27.8))
BATIMENT0000000302944231;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;19;20;8.7;22.4;31.2;41.5;23.9;Cadastre;A 1.0;POLYGON Z ((355138.8 6690069.3 31.2, 355139.3 6690081.9 31.2, 355139.3 6690084.5 31.2, 355139.5 6690086.2 31.2, 355150.2 6690085.7 31.2, 355149.7 6690081.7 31.2, 355145.7 6690082 31.2, 355145.8 6690082.6 31.2, 355140.5 6690082.8 31.2, 355141.3 6690080.2 31.2, 355149.6 6690079.7 31.2, 355148.5 6690068.2 31.2, 355138.8 6690069.3 31.2))
BATIMENT0000000302944235;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;21.6;24.0;26.2;22.2;Cadastre;;POLYGON Z ((355158.8 6690081 24, 355162.1 6690080.7 24, 355161.9 6690079.8 24, 355161.6 6690076.7 24, 355158.3 6690077 24, 355158.8 6690081 24))
BATIMENT0000000302944220;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;50;20;18.4;23.5;42.0;45.2;25.8;Cadastre;A 1.0;POLYGON Z ((355119.3 6690075.2 42, 355119.6 6690089.6 42, 355131.9 6690088.9 42, 355131.8 6690082.1 42, 355131.8 6690074.1 42, 355119.3 6690075.2 42))
BATIMENT0000000302944212;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;30;20;10.5;24.2;34.7;39.9;26.1;Cadastre;C 0.7;POLYGON Z ((355106.8 6690072.8 34.7, 355107.4 6690086.6 34.7, 355107.6 6690089.5 34.7, 355109.5 6690089.5 34.7, 355109.7 6690089.3 34.7, 355112.6 6690088.9 34.7, 355112.5 6690085 34.7, 355109.5 6690085 34.7, 355109.3 6690083.2 34.7, 355117.3 6690082.6 34.7, 355117.2 6690084.6 34.7, 355114.3 6690084.9 34.7, 355114.9 6690088.9 34.7, 355116.6 6690088.9 34.7, 355116.7 6690094.9 34.7, 355118.4 6690094.8 34.7, 355119.7 6690094.8 34.7, 355119.6 6690089.6 34.7, 355119.3 6690075.2 34.7, 355119.2 6690071.4 34.7, 355106.8 6690072.8 34.7))
BATIMENT0000000302944230;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;23.5;27.2;29.5;24.6;Cadastre;;POLYGON Z ((355136.8 6690084.7 27.2, 355137.2 6690095.4 27.2, 355139.7 6690095.3 27.2, 355139.5 6690086.2 27.2, 355139.3 6690084.5 27.2, 355136.8 6690084.7 27.2))
BATIMENT0000000302944232;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;;;7.7;21.9;29.7;35.1;24.6;Cadastre;A 1.0;POLYGON Z ((355150.2 6690085.7 29.7, 355139.5 6690086.2 29.7, 355139.7 6690095.3 29.7, 355139.8 6690097.1 29.7, 355139.9 6690102.7 29.7, 355152.3 6690101.9 29.7, 355157.3 6690101.6 29.7, 355161.3 6690101.3 29.7, 355168.4 6690100.7 29.7, 355173.9 6690102.3 29.7, 355175.5 6690084.9 29.7, 355159.3 6690085.3 29.7, 355150.2 6690085.7 29.7), (355164.6 6690091.9 29.7, 355164.2 6690095.2 29.7, 355155.1 6690095.8 29.7, 355155 6690092.4 29.7, 355164.6 6690091.9 29.7))
BATIMENT0000000302944213;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;25.3;29.5;30.5;26.0;Cadastre;;POLYGON Z ((355119.7 6690094.8 29.5, 355118.4 6690094.8 29.5, 355118.5 6690097.5 29.5, 355119.7 6690097.4 29.5, 355119.7 6690094.8 29.5))
BATIMENT0000000302944226;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.3;24.2;30.5;31.9;25.5;Cadastre;B 0.3;POLYGON Z ((355132.2 6690097.7 30.5, 355132.3 6690103.3 30.5, 355134.1 6690103.2 30.5, 355137.8 6690103 30.5, 355139.9 6690102.7 30.5, 355139.8 6690097.1 30.5, 355132.2 6690097.7 30.5))
BATIMENT0000000302944205;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;6.7;28.2;35.0;39.3;29.5;Cadastre;A 0.5;POLYGON Z ((355076.4 6690092.6 35, 355076.3 6690094.9 35, 355072.6 6690095.5 35, 355072.4 6690094.6 35, 355070.4 6690095 35, 355070.5 6690095.6 35, 355063.2 6690096.4 35, 355064.2 6690105.3 35, 355067.1 6690105.1 35, 355067.1 6690105.5 35, 355077.4 6690104.5 35, 355077.6 6690107 35, 355078.1 6690107 35, 355080.7 6690106.8 35, 355079.1 6690092.1 35, 355076.4 6690092.6 35))
BATIMENT0000000302944199;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;28.5;31.9;34.0;28.9;Cadastre;;POLYGON Z ((355060.8 6690104.4 31.9, 355056.5 6690108.1 31.9, 355061.2 6690107.7 31.9, 355060.8 6690104.4 31.9))
BATIMENT0000000302944209;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;28.8;30.5;32.2;29.2;Cadastre;;POLYGON Z ((355072.8 6690107.4 30.5, 355072.9 6690109.4 30.5, 355078.2 6690109 30.5, 355078.1 6690107 30.5, 355077.6 6690107 30.5, 355072.8 6690107.4 30.5))
BATIMENT0000000302944201;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.1;28.6;32.7;34.0;29.0;Cadastre;A 1.0;POLYGON Z ((355061.4 6690110.7 32.7, 355061.2 6690107.7 32.7, 355056.5 6690108.1 32.7, 355055.6 6690108.3 32.7, 355055.9 6690112.3 32.7, 355060.6 6690111.3 32.7, 355061.4 6690110.7 32.7))
BATIMENT0000000302944198;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1883-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;4.0;28.5;32.5;35.4;29.3;Cadastre;C 0.4;POLYGON Z ((355052.4 6690108.6 32.5, 355053.3 6690126.1 32.5, 355055.5 6690127.8 32.5, 355057 6690127.8 32.5, 355055.9 6690112.3 32.5, 355055.6 6690108.3 32.5, 355052.4 6690108.6 32.5))
BATIMENT0000000302944203;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;;;5.4;25.5;31.0;34.2;30.0;Cadastre;A 1.0;POLYGON Z ((355087.8 6690137.9 31, 355087 6690127.8 31, 355090.4 6690127.5 31, 355091.1 6690137.8 31, 355095.5 6690137.7 31, 355095.1 6690129.4 31, 355094.7 6690120.3 31, 355093.9 6690106 31, 355080.7 6690106.8 31, 355082.3 6690122.3 31, 355083.2 6690138 31, 355087.8 6690137.9 31))
BATIMENT0000000302944196;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1883-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;5.8;26.9;32.7;45.4;30.8;Cadastre;C 0.6;POLYGON Z ((355057.8 6690138.8 32.7, 355057.1 6690129.2 32.7, 355052.6 6690129.4 32.7, 355052.3 6690126.1 32.7, 355048.8 6690126.3 32.7, 355048.5 6690122.6 32.7, 355049.3 6690122.5 32.7, 355048.6 6690114.6 32.7, 355047.2 6690114.6 32.7, 355046.8 6690109.2 32.7, 355044.1 6690109.4 32.7, 355045.1 6690119.5 32.7, 355047.1 6690139.2 32.7, 355057.8 6690138.8 32.7))
BATIMENT0000000302944206;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;8.7;25.5;34.2;36.4;28.6;Cadastre;A 0.5;POLYGON Z ((355104.7 6690128.7 34.2, 355104 6690119.8 34.2, 355094.7 6690120.3 34.2, 355095.1 6690129.4 34.2, 355104.7 6690128.7 34.2))
BATIMENT0000000302944200;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1888-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;15;20;9.2;26.4;35.7;43.5;29.8;Cadastre;A 1.0;POLYGON Z ((355072.8 6690138.4 35.7, 355072 6690122.5 35.7, 355070.7 6690112.3 35.7, 355066.5 6690111.1 35.7, 355069.5 6690127.3 35.7, 355060.5 6690127.9 35.7, 355060.4 6690119.8 35.7, 355061.8 6690115.2 35.7, 355060.6 6690111.3 35.7, 355055.9 6690112.3 35.7, 355057 6690127.8 35.7, 355057.1 6690129.2 35.7, 355057.8 6690138.8 35.7, 355072.8 6690138.4 35.7))
BATIMENT0000000302944202;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;35;20;14.7;25.8;40.5;43.4;29.5;Cadastre;A 0.4;POLYGON Z ((355083.2 6690138 40.5, 355082.3 6690122.3 40.5, 355072 6690122.5 40.5, 355072.8 6690138.4 40.5, 355083.2 6690138 40.5))
BATIMENT0000000302944214;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;1.0;00;00;2.5;25.2;27.7;31.4;26.4;Cadastre;C 0.3;POLYGON Z ((355119.7 6690104.1 27.7, 355119.8 6690100.8 27.7, 355119.7 6690097.4 27.7, 355118.5 6690097.5 27.7, 355118.6 6690100.2 27.7, 355109.4 6690100.6 27.7, 355109.3 6690098.1 27.7, 355108 6690098.2 27.7, 355107.9 6690098.2 27.7, 355108.1 6690101.5 27.7, 355108.1 6690105 27.7, 355115.6 6690104.4 27.7, 355119.7 6690104.1 27.7))
BATIMENT0000000302944219;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;24.5;27.5;31.2;25.6;Cadastre;;POLYGON Z ((355134.3 6690105.8 27.5, 355134.1 6690103.2 27.5, 355132.3 6690103.3 27.5, 355129.6 6690103.6 27.5, 355129.8 6690106.1 27.5, 355134.3 6690105.8 27.5))
BATIMENT0000000302944227;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.6;23.4;31.0;32.6;24.8;Cadastre;A 1.0;POLYGON Z ((355140.1 6690109.6 31, 355140.2 6690109.6 31, 355141.4 6690109.5 31, 355141.4 6690108.4 31, 355152.4 6690107.9 31, 355152.3 6690104.3 31, 355152.3 6690101.9 31, 355139.9 6690102.7 31, 355140.1 6690109.6 31))
BATIMENT0000000302944228;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;22.3;30.7;33.2;24.1;Cadastre;;POLYGON Z ((355155.3 6690104.1 30.7, 355155.3 6690103.1 30.7, 355157.2 6690103 30.7, 355156.7 6690110.3 30.7, 355158.1 6690108.9 30.7, 355158.7 6690103.3 30.7, 355161.1 6690103.3 30.7, 355161.3 6690101.3 30.7, 355157.3 6690101.6 30.7, 355152.3 6690101.9 30.7, 355152.3 6690104.3 30.7, 355155.3 6690104.1 30.7))
BATIMENT0000000302944215;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;25.1;29.4;32.5;26.5;Cadastre;;POLYGON Z ((355108.5 6690112.7 29.4, 355115.6 6690112.4 29.4, 355115.6 6690104.4 29.4, 355108.1 6690105 29.4, 355108.5 6690112.7 29.4))
BATIMENT0000000302944222;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1855-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;20;13.1;22.2;35.4;39.0;23.9;Cadastre;A 1.0;POLYGON Z ((355173.9 6690102.3 35.4, 355168.4 6690100.7 35.4, 355161.3 6690101.3 35.4, 355161.1 6690103.3 35.4, 355159.9 6690114.4 35.4, 355156.5 6690114.4 35.4, 355156.2 6690117.5 35.4, 355157.7 6690117.5 35.4, 355159.5 6690117.4 35.4, 355167 6690117.2 35.4, 355167.3 6690116.8 35.4, 355172.5 6690117.5 35.4, 355173.9 6690102.3 35.4))
BATIMENT0000000302944225;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;24.2;28.5;29.4;24.6;Cadastre;;POLYGON Z ((355142.5 6690117.9 28.5, 355142.4 6690115.7 28.5, 355140.3 6690115.8 28.5, 355140.4 6690118 28.5, 355142.5 6690117.9 28.5))
BATIMENT0000000302944216;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;2.0;10;20;6.8;24.6;31.5;35.2;25.8;Cadastre;A 1.0;POLYGON Z ((355116.1 6690123.1 31.5, 355116.6 6690137 31.5, 355130.3 6690136.6 31.5, 355130.3 6690129.1 31.5, 355130.2 6690126 31.5, 355119.2 6690126.4 31.5, 355119.2 6690124.7 31.5, 355122.6 6690124.6 31.5, 355122.2 6690111.4 31.5, 355129.9 6690110.9 31.5, 355129.8 6690106.1 31.5, 355129.6 6690103.6 31.5, 355119.7 6690104.1 31.5, 355115.6 6690104.4 31.5, 355115.6 6690112.4 31.5, 355116.1 6690123.1 31.5))
BATIMENT0000000302944224;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;23.1;28.1;34.5;24.8;Cadastre;;POLYGON Z ((355156.5 6690128.2 28.1, 355157.7 6690117.5 28.1, 355156.2 6690117.5 28.1, 355142.5 6690117.9 28.1, 355140.4 6690118 28.1, 355140.4 6690128.6 28.1, 355156.5 6690128.2 28.1))
BATIMENT0000000302944221;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;16.6;22.6;39.2;42.0;24.7;Cadastre;C 0.9;POLYGON Z ((355140.4 6690128.6 39.2, 355140.5 6690136.2 39.2, 355169.4 6690135.3 39.2, 355170.9 6690133.8 39.2, 355172.5 6690117.5 39.2, 355167.3 6690116.8 39.2, 355167 6690117.2 39.2, 355159.5 6690117.4 39.2, 355158.9 6690128.2 39.2, 355156.5 6690128.2 39.2, 355140.4 6690128.6 39.2))
BATIMENT0000000302944217;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;34;20;8.4;24.7;33.2;36.3;25.8;Cadastre;B 1.0;POLYGON Z ((355108.9 6690123.7 33.2, 355109.1 6690137.2 33.2, 355116.6 6690137 33.2, 355116.1 6690123.1 33.2, 355108.9 6690123.7 33.2))
BATIMENT0000000302944218;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;50;20;9.2;24.1;33.3;37.2;25.0;Cadastre;A 1.0;POLYGON Z ((355140.5 6690136.2 33.3, 355140.4 6690128.6 33.3, 355131.9 6690129 33.3, 355131.8 6690126 33.3, 355130.2 6690126 33.3, 355130.3 6690129.1 33.3, 355130.3 6690136.6 33.3, 355140.5 6690136.2 33.3))
BATIMENT0000000302944184;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;10;20;9.8;24.4;34.2;35.7;25.9;Cadastre;A 1.0;POLYGON Z ((355114 6690146.6 34.2, 355112.3 6690155.2 34.2, 355112.2 6690155.4 34.2, 355129.1 6690155.2 34.2, 355130.6 6690146 34.2, 355114 6690146.6 34.2))
BATIMENT0000000302944180;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;00;00;8.6;24.0;32.7;41.5;26.7;Cadastre;A 1.0;POLYGON Z ((355143.4 6690163.2 32.7, 355144.3 6690163.3 32.7, 355144.8 6690154.9 32.7, 355144.5 6690145.5 32.7, 355137.1 6690145.8 32.7, 355136 6690145.8 32.7, 355130.6 6690146 32.7, 355129.1 6690155.2 32.7, 355128.2 6690160.6 32.7, 355128 6690161.9 32.7, 355143.4 6690163.2 32.7))
BATIMENT0000000302944172;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;10;30;11.9;23.2;35.2;42.5;26.2;Cadastre;A 1.0;POLYGON Z ((355144.8 6690154.9 35.2, 355144.3 6690163.3 35.2, 355149 6690163.8 35.2, 355154.3 6690164.3 35.2, 355158.4 6690164.7 35.2, 355161.1 6690164.8 35.2, 355159.8 6690145 35.2, 355144.5 6690145.5 35.2, 355144.8 6690154.9 35.2), (355153.3 6690155.5 35.2, 355153.4 6690159.4 35.2, 355153.9 6690159.8 35.2, 355158 6690159.5 35.2, 355158.1 6690160.7 35.2, 355147 6690161.1 35.2, 355147 6690160 35.2, 355151.1 6690159.8 35.2, 355151.4 6690159.5 35.2, 355151.3 6690155.7 35.2, 355153.3 6690155.5 35.2))
BATIMENT0000000302944182;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;15;20;8.1;23.1;31.2;36.0;24.0;Cadastre;A 1.0;POLYGON Z ((355161.1 6690164.8 31.2, 355158.4 6690164.7 31.2, 355158.4 6690169.6 31.2, 355161.4 6690169.5 31.2, 355165.5 6690168.8 31.2, 355172.3 6690168 31.2, 355170.9 6690145.8 31.2, 355169.8 6690144.7 31.2, 355159.8 6690145 31.2, 355161.1 6690164.8 31.2), (355164.4 6690156.1 31.2, 355165.1 6690164.1 31.2, 355163.5 6690164.3 31.2, 355162.8 6690156.4 31.2, 355164.4 6690156.1 31.2))
BATIMENT0000000302944185;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;25.4;28.5;28.8;26.7;Cadastre;;POLYGON Z ((355128.2 6690160.6 28.5, 355125.8 6690160.5 28.5, 355125.7 6690161.7 28.5, 355128 6690161.9 28.5, 355128.2 6690160.6 28.5))
BATIMENT0000000302944181;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;23.5;26.9;28.7;24.0;Cadastre;;POLYGON Z ((355158.4 6690164.7 26.9, 355154.3 6690164.3 26.9, 355154.2 6690169.5 26.9, 355156.5 6690169.5 26.9, 355158.4 6690169.6 26.9, 355158.4 6690164.7 26.9))
BATIMENT0000000302944187;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.9;23.5;32.5;34.2;24.7;Cadastre;A 1.0;POLYGON Z ((355160.8 6690175.8 32.5, 355163.2 6690175.7 32.5, 355163.2 6690174.7 32.5, 355164.6 6690174.5 32.5, 355164.8 6690176.3 32.5, 355173.1 6690175.8 32.5, 355172.3 6690168 32.5, 355165.5 6690168.8 32.5, 355165.6 6690171.1 32.5, 355161.7 6690171.3 32.5, 355160.8 6690171.5 32.5, 355160.8 6690175.3 32.5, 355160.8 6690175.8 32.5))
BATIMENT0000000302944186;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;23.4;27.7;29.0;24.7;Cadastre;;POLYGON Z ((355156.5 6690173.4 27.7, 355156.5 6690174.7 27.7, 355157 6690175.4 27.7, 355160.8 6690175.3 27.7, 355160.8 6690171.5 27.7, 355161.7 6690171.3 27.7, 355161.4 6690169.5 27.7, 355158.4 6690169.6 27.7, 355156.5 6690169.5 27.7, 355156.5 6690173.4 27.7))
BATIMENT0000000302944223;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;25.0;29.6;30.7;25.9;Cadastre;;POLYGON Z ((355105.6 6690133.3 29.6, 355104.9 6690133.9 29.6, 355105 6690135.2 29.6, 355106 6690136.1 29.6, 355106.9 6690136 29.6, 355107.9 6690135.3 29.6, 355107.9 6690134 29.6, 355106.9 6690133.1 29.6, 355105.6 6690133.3 29.6))
BATIMENT0000000302944159;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;00;00;9.4;25.9;35.4;39.9;28.3;Cadastre;A 1.0;POLYGON Z ((355072.8 6690160.5 35.4, 355073.6 6690160.5 35.4, 355075.6 6690160.7 35.4, 355080.1 6690161 35.4, 355081.4 6690147.7 35.4, 355076.9 6690147.8 35.4, 355068.3 6690148.1 35.4, 355068.3 6690150.2 35.4, 355068.4 6690155.5 35.4, 355068.2 6690162 35.4, 355072.4 6690162.1 35.4, 355072.8 6690160.5 35.4))
BATIMENT0000000302944157;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;90;20;9.2;25.5;34.7;40.1;28.5;Cadastre;A 1.0;POLYGON Z ((355090.5 6690147.4 34.7, 355081.4 6690147.7 34.7, 355080.1 6690161 34.7, 355079.8 6690162.8 34.7, 355090.5 6690162.5 34.7, 355090.6 6690160.9 34.7, 355090.7 6690159.9 34.7, 355090.6 6690156.7 34.7, 355090.6 6690156.2 34.7, 355090.5 6690147.4 34.7))
BATIMENT0000000302944168;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;12.7;27.0;39.7;42.8;28.8;Cadastre;A 1.0;POLYGON Z ((355029.8 6690149.4 39.7, 355029.8 6690156.6 39.7, 355029.9 6690160.2 39.7, 355044.2 6690159.4 39.7, 355044.1 6690160.9 39.7, 355041.9 6690161.1 39.7, 355041.9 6690162.4 39.7, 355045.8 6690162.5 39.7, 355045.8 6690148.8 39.7, 355029.8 6690149.4 39.7))
BATIMENT0000000302944161;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;00;00;4.4;25.2;29.6;36.5;28.5;Cadastre;A 1.0;POLYGON Z ((355095.8 6690147.2 29.6, 355095.9 6690151.1 29.6, 355094.5 6690151 29.6, 355094.4 6690157.2 29.6, 355093.2 6690157.3 29.6, 355093 6690156.1 29.6, 355090.6 6690156.2 29.6, 355090.6 6690156.7 29.6, 355090.7 6690159.9 29.6, 355090.6 6690160.9 29.6, 355090.5 6690162.5 29.6, 355090.5 6690165.3 29.6, 355093.7 6690165.2 29.6, 355095.6 6690165.1 29.6, 355096 6690165.1 29.6, 355095.8 6690157.1 29.6, 355098.2 6690157.1 29.6, 355098.2 6690154.9 29.6, 355101.6 6690154.7 29.6, 355101.3 6690147 29.6, 355095.8 6690147.2 29.6))
BATIMENT0000000302944170;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;10;20;13.1;25.0;38.2;41.2;28.5;Cadastre;A 1.0;POLYGON Z ((355101.3 6690147 38.2, 355101.6 6690154.7 38.2, 355102 6690165 38.2, 355098.2 6690165 38.2, 355098.3 6690169 38.2, 355104.6 6690168.8 38.2, 355104.9 6690165.7 38.2, 355109.3 6690165.6 38.2, 355109.8 6690165.6 38.2, 355110.8 6690161.3 38.2, 355111.7 6690157.5 38.2, 355108.7 6690157.9 38.2, 355108.6 6690155.1 38.2, 355112.2 6690155.4 38.2, 355112.3 6690155.2 38.2, 355114 6690146.6 38.2, 355101.3 6690147 38.2))
BATIMENT0000000302944162;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;20;20;12.8;25.1;37.9;41.4;29.1;Cadastre;A 1.0;POLYGON Z ((355045.8 6690162.5 37.9, 355045.6 6690170.2 37.9, 355065.8 6690169.6 37.9, 355066.4 6690148.2 37.9, 355045.8 6690148.8 37.9, 355045.8 6690162.5 37.9), (355061 6690155.7 37.9, 355061 6690162.5 37.9, 355052.2 6690162.8 37.9, 355052.1 6690155.9 37.9, 355061 6690155.7 37.9))
BATIMENT0000000302944158;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;26.6;35.5;37.7;28.5;Cadastre;;POLYGON Z ((355075.6 6690160.7 35.5, 355073.6 6690160.5 35.5, 355072.8 6690160.5 35.5, 355072.4 6690162.1 35.5, 355072.5 6690162.5 35.5, 355073.9 6690162.6 35.5, 355079.8 6690162.8 35.5, 355080.1 6690161 35.5, 355075.6 6690160.7 35.5))
BATIMENT0000000302944160;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;4.0;10;20;13.3;26.4;39.7;43.1;28.8;Cadastre;A 1.0;POLYGON Z ((355073.4 6690167.5 39.7, 355073.8 6690168 39.7, 355074.1 6690168 39.7, 355074 6690169 39.7, 355069.1 6690169 39.7, 355069.3 6690165 39.7, 355068.6 6690164.4 39.7, 355066.7 6690164.4 39.7, 355067.1 6690148.1 39.7, 355066.4 6690148.2 39.7, 355065.8 6690169.6 39.7, 355065.7 6690172.5 39.7, 355065.7 6690175.6 39.7, 355065.7 6690181.1 39.7, 355078.3 6690180.3 39.7, 355079.5 6690167.6 39.7, 355079.8 6690162.8 39.7, 355073.9 6690162.6 39.7, 355073.4 6690167.5 39.7))
BATIMENT0000000302944169;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;26.5;30.5;31.2;28.6;Cadastre;;POLYGON Z ((355093.7 6690165.2 30.5, 355093.5 6690167 30.5, 355093.5 6690169.1 30.5, 355095.8 6690169 30.5, 355095.6 6690165.1 30.5, 355093.7 6690165.2 30.5))
BATIMENT0000000302944163;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.3;27.1;35.4;38.5;30.2;Cadastre;A 1.0;POLYGON Z ((355036.6 6690173.5 35.4, 355043.1 6690173.9 35.4, 355042.8 6690178.1 35.4, 355045 6690177.8 35.4, 355045.3 6690175 35.4, 355045.4 6690173.5 35.4, 355045.6 6690170.2 35.4, 355045.8 6690162.5 35.4, 355041.9 6690162.4 35.4, 355041.9 6690163.8 35.4, 355043.1 6690163.8 35.4, 355043 6690165 35.4, 355043.5 6690165 35.4, 355043.3 6690167.8 35.4, 355032.8 6690167.2 35.4, 355032.8 6690162.3 35.4, 355030.5 6690162.2 35.4, 355030.4 6690167.1 35.4, 355030.3 6690173 35.4, 355036.6 6690173.5 35.4))
BATIMENT0000000302944164;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;12;5.6;27.1;32.7;34.0;29.0;Cadastre;C 0.9;POLYGON Z ((355088.4 6690180 32.7, 355088.4 6690179.5 32.7, 355088.3 6690176.5 32.7, 355083.9 6690176.3 32.7, 355084.4 6690167.5 32.7, 355079.5 6690167.6 32.7, 355078.3 6690180.3 32.7, 355088.4 6690180 32.7))
BATIMENT0000000302944183;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;27.3;30.2;35.9;28.7;Cadastre;A 1.0;POLYGON Z ((355096 6690172.7 30.2, 355096.2 6690179.1 30.2, 355106.5 6690178.6 30.2, 355107.8 6690172 30.2, 355096 6690172.7 30.2))
BATIMENT0000000302944189;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;27.5;30.3;30.9;28.9;Cadastre;C 0.3;POLYGON Z ((355091.3 6690173.1 30.3, 355091.7 6690179.2 30.3, 355096.2 6690179.1 30.3, 355096 6690172.7 30.3, 355091.3 6690173.1 30.3))
BATIMENT0000000302944166;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.7;28.2;32.0;39.2;28.6;Cadastre;A 1.0;POLYGON Z ((355065.7 6690181.1 32, 355065.7 6690175.6 32, 355060.7 6690175.6 32, 355060.7 6690181.3 32, 355065.7 6690181.1 32))
BATIMENT0000000302944175;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;5.4;27.1;32.5;33.5;28.8;Cadastre;A 1.0;POLYGON Z ((355060.7 6690181.3 32.5, 355060.7 6690175.6 32.5, 355057.4 6690175.5 32.5, 355057.3 6690177.7 32.5, 355057.2 6690181.7 32.5, 355060.7 6690181.3 32.5))
BATIMENT0000000302944165;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;20;20;8.6;28.5;37.2;38.8;29.6;Cadastre;A 1.0;POLYGON Z ((355057.2 6690181.7 37.2, 355057.3 6690177.7 37.2, 355050 6690177.7 37.2, 355049.7 6690175.1 37.2, 355045.3 6690175 37.2, 355045 6690177.8 37.2, 355044.7 6690180.4 37.2, 355043.1 6690181 37.2, 355043.1 6690182.1 37.2, 355037.8 6690183.9 37.2, 355037.8 6690184.6 37.2, 355037.4 6690184.8 37.2, 355038.4 6690187.7 37.2, 355044.2 6690185.8 37.2, 355057.2 6690181.7 37.2))
BATIMENT0000000302944790;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;30.0;33.2;;;Cadastre;;POLYGON Z ((355071.2 6690190.3 33.2, 355070.4 6690188.9 33.2, 355069.7 6690188.6 33.2, 355068.9 6690188.7 33.2, 355069 6690187.9 33.2, 355068.7 6690187.6 33.2, 355068.2 6690187.9 33.2, 355068.2 6690188.6 33.2, 355066.8 6690189 33.2, 355066.4 6690188.6 33.2, 355066 6690188.8 33.2, 355066.3 6690189.4 33.2, 355065.3 6690190.3 33.2, 355064.9 6690190.1 33.2, 355064.8 6690190.7 33.2, 355065.3 6690190.9 33.2, 355065.3 6690191.3 33.2, 355065.8 6690193.2 33.2, 355071.7 6690191 33.2, 355071.2 6690190.3 33.2))
BATIMENT0000000302944779;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;28.6;31.7;;;Cadastre;;POLYGON Z ((355078.3 6690189.3 31.7, 355078.5 6690192.5 31.7, 355088.6 6690191.9 31.7, 355088.4 6690188.8 31.7, 355078.3 6690189.3 31.7))
BATIMENT0000000302944740;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;10;6.6;28.6;35.2;38.7;29.3;Cadastre;C 0.8;POLYGON Z ((355049.5 6690201.4 35.2, 355050.3 6690200 35.2, 355049.8 6690198.5 35.2, 355055.6 6690196.5 35.2, 355054.5 6690193.3 35.2, 355050.1 6690191.5 35.2, 355044.2 6690193.4 35.2, 355047.4 6690202.2 35.2, 355049.5 6690201.4 35.2))
BATIMENT0000000302944171;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;72.0;4.0;00;00;8.1;25.1;33.2;40.6;28.5;Cadastre;C 0.6;POLYGON Z ((355110.8 6690161.3 33.2, 355109.8 6690165.6 33.2, 355109.3 6690165.6 33.2, 355107.8 6690172 33.2, 355106.5 6690178.6 33.2, 355106.4 6690179 33.2, 355124.7 6690177.9 33.2, 355129.5 6690177.4 33.2, 355129.7 6690177.7 33.2, 355129.9 6690177.9 33.2, 355129.9 6690178 33.2, 355130.3 6690178.4 33.2, 355131.1 6690179.2 33.2, 355131.5 6690179.6 33.2, 355131.8 6690179.8 33.2, 355131.9 6690179.9 33.2, 355142.2 6690182.9 33.2, 355142.7 6690183 33.2, 355151.5 6690185.7 33.2, 355153.7 6690184.2 33.2, 355155.4 6690178.2 33.2, 355150 6690176.5 33.2, 355149.7 6690173.4 33.2, 355146.4 6690172.5 33.2, 355149 6690163.8 33.2, 355144.3 6690163.3 33.2, 355143.4 6690163.2 33.2, 355128 6690161.9 33.2, 355125.7 6690161.7 33.2, 355110.8 6690161.3 33.2))
BATIMENT0000000302944188;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;25.5;31.8;;;Cadastre;;POLYGON Z ((355163.7 6690176.4 31.8, 355164 6690182.7 31.8, 355164.4 6690183.6 31.8, 355164.7 6690183.7 31.8, 355164.7 6690187.2 31.8, 355165.8 6690189.5 31.8, 355165.9 6690190.2 31.8, 355171.2 6690191.8 31.8, 355174 6690189.9 31.8, 355173.1 6690175.8 31.8, 355164.8 6690176.3 31.8, 355163.7 6690176.4 31.8))
BATIMENT0000000302944747;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.2;26.7;34.9;37.4;27.6;Cadastre;A 1.0;POLYGON Z ((355132.3 6690188.3 34.9, 355130.3 6690196.7 34.9, 355137.3 6690198.7 34.9, 355140 6690190.7 34.9, 355132.3 6690188.3 34.9))
BATIMENT0000000302944746;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;40;20;7.6;26.3;33.9;34.4;27.6;Cadastre;A 1.0;POLYGON Z ((355146.1 6690201.4 33.9, 355148.7 6690193.4 33.9, 355140 6690190.7 33.9, 355137.3 6690198.7 33.9, 355146.1 6690201.4 33.9))
BATIMENT0000000302944742;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;00;00;7.3;26.7;34.0;34.3;27.9;Cadastre;A 1.0;POLYGON Z ((355145.1 6690213.1 34, 355146.9 6690213.3 34, 355148.5 6690213.5 34, 355149.1 6690201.8 34, 355153 6690202.2 34, 355152.5 6690214 34, 355153.8 6690214.1 34, 355156.6 6690214.5 34, 355156.8 6690212.9 34, 355157.9 6690196.3 34, 355148.7 6690193.4 34, 355146.1 6690201.4 34, 355145.6 6690202.8 34, 355145.4 6690209.5 34, 355145.1 6690213.1 34))
BATIMENT0000000302944749;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.2;26.3;32.5;34.2;27.7;Cadastre;A 1.0;POLYGON Z ((355166.5 6690212.2 32.5, 355175.7 6690211.4 32.5, 355174.9 6690201.6 32.5, 355165.4 6690198.6 32.5, 355166.5 6690212.2 32.5))
BATIMENT0000000302944537;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;27.2;32.0;35.2;27.8;Cadastre;;POLYGON Z ((355129.8 6690202.7 32, 355122.9 6690205 32, 355124.3 6690208.7 32, 355131 6690206.3 32, 355129.8 6690202.7 32))
BATIMENT0000000302944536;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;6.2;28.8;35.0;;;Cadastre;A 1.0;POLYGON Z ((355127.9 6690218.3 35, 355133.6 6690216.1 35, 355131.5 6690210.3 35, 355135.5 6690209 35, 355134.2 6690205.2 35, 355131 6690206.3 35, 355124.3 6690208.7 35, 355127.9 6690218.3 35))
BATIMENT0000000302944744;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;26.7;;;;Cadastre;;POLYGON Z ((355140.9 6690211.2 -1000, 355141.9 6690214.2 -1000, 355145.1 6690213.1 -1000, 355145.4 6690209.5 -1000, 355141.9 6690210.8 -1000, 355140.9 6690211.2 -1000))
BATIMENT0000000302944743;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;27.6;30.9;31.7;27.9;Cadastre;;POLYGON Z ((355164.5 6690213.8 30.9, 355164.1 6690212.2 30.9, 355156.8 6690212.9 30.9, 355156.6 6690214.5 30.9, 355164.5 6690213.8 30.9))
BATIMENT0000000302944396;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.9;19.5;34.4;36.0;23.7;Cadastre;;POLYGON Z ((355261.5 6690136.8 34.4, 355260.8 6690135.1 34.4, 355250.9 6690112.3 34.4, 355248.5 6690113.5 34.4, 355246.3 6690114.4 34.4, 355256.6 6690139 34.4, 355261.5 6690136.8 34.4))
BATIMENT0000000302944397;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;23.4;33.7;34.1;24.3;Cadastre;;POLYGON Z ((355222.8 6690146.9 33.7, 355222.5 6690145.7 33.7, 355216.7 6690147.5 33.7, 355217.1 6690148.9 33.7, 355222.8 6690146.9 33.7))
BATIMENT0000000302944395;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.2;22.4;37.6;39.2;23.5;Cadastre;;POLYGON Z ((355179.5 6690143.4 37.6, 355180.4 6690154.4 37.6, 355180.7 6690157.7 37.6, 355186.7 6690157.5 37.6, 355187.3 6690153.9 37.6, 355189.1 6690153.4 37.6, 355188.4 6690139.6 37.6, 355179.5 6690143.4 37.6))
BATIMENT0000000302944392;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;14.4;21.5;36.0;41.3;28.3;Cadastre;C 0.6;POLYGON Z ((355201.2 6690134.1 36, 355188.4 6690139.6 36, 355189.1 6690153.4 36, 355187.3 6690153.9 36, 355186.7 6690157.5 36, 355188.2 6690185.2 36, 355194.9 6690188.3 36, 355198.7 6690190 36, 355200.7 6690191 36, 355204.1 6690185.1 36, 355199.2 6690182 36, 355200 6690180.7 36, 355223.6 6690196.2 36, 355220.5 6690200.8 36, 355226.6 6690205.5 36, 355226.3 6690206 36, 355230.3 6690208.2 36, 355232.8 6690204.3 36, 355234.3 6690204.9 36, 355235.2 6690203.9 36, 355238.2 6690205.9 36, 355237.3 6690207.3 36, 355238.9 6690208.2 36, 355236.5 6690211.7 36, 355242.6 6690215.3 36, 355248.5 6690218.5 36, 355253.8 6690211.1 36, 355265.6 6690193.9 36, 355261.3 6690190.9 36, 355260.2 6690192.4 36, 355258.4 6690191.2 36, 355257.5 6690191.6 36, 355253.9 6690192.2 36, 355253.5 6690191.6 36, 355252.7 6690192 36, 355253 6690192.6 36, 355247.2 6690199.9 36, 355246.8 6690199.5 36, 355246.4 6690199.9 36, 355244.3 6690198.5 36, 355244.4 6690198.1 36, 355239.3 6690194.5 36, 355239 6690194.6 36, 355235.5 6690192.1 36, 355235.5 6690192.2 36, 355229.2 6690187.9 36, 355233.2 6690182.2 36, 355240.5 6690187 36, 355247.8 6690176.8 36, 355246.4 6690175.7 36, 355261.3 6690155.3 36, 355261.9 6690154.4 36, 355258.2 6690151.7 36, 355254.5 6690148.9 36, 355226.9 6690186.2 36, 355216.1 6690178.9 36, 355215.3 6690149.5 36, 355217.1 6690148.9 36, 355216.7 6690147.5 36, 355222.5 6690145.7 36, 355223 6690145.6 36, 355219.7 6690135 36, 355239 6690126.8 36, 355241.2 6690127.5 36, 355247.9 6690142.8 36, 355256.6 6690139 36, 355246.3 6690114.4 36, 355215 6690128 36, 355201.2 6690134.1 36), (355205.7 6690156.2 36, 355206.4 6690170.4 36, 355194.1 6690170.9 36, 355193 6690158 36, 355205.7 6690156.2 36))
BATIMENT0000000302944394;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;12;20;12.9;23.3;36.3;37.7;25.2;Cadastre;A 1.0;POLYGON Z ((355182.7 6690182.9 36.3, 355188.2 6690185.2 36.3, 355186.7 6690157.5 36.3, 355180.7 6690157.7 36.3, 355182.7 6690182.9 36.3))
BATIMENT0000000302944399;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;00;00;7.7;23.5;31.3;41.3;27.8;Cadastre;A 1.0;POLYGON Z ((355184.8 6690215.1 31.3, 355193.5 6690214.6 31.3, 355196.1 6690215.2 31.3, 355196.1 6690210.3 31.3, 355197 6690210.1 31.3, 355197 6690204.6 31.3, 355196 6690204.6 31.3, 355195.8 6690203.5 31.3, 355196.6 6690203.3 31.3, 355196.5 6690200.6 31.3, 355195.6 6690200.4 31.3, 355195.3 6690196 31.3, 355202 6690195.6 31.3, 355202.3 6690200.2 31.3, 355217.8 6690206.7 31.3, 355212.3 6690217.8 31.3, 355214.6 6690218.5 31.3, 355217.8 6690220.1 31.3, 355221.3 6690213.2 31.3, 355225.2 6690205.4 31.3, 355226.3 6690206 31.3, 355226.6 6690205.5 31.3, 355220.5 6690200.8 31.3, 355219.4 6690201.8 31.3, 355200.7 6690191 31.3, 355198.7 6690190 31.3, 355198.4 6690192.4 31.3, 355195.2 6690192.4 31.3, 355194.9 6690188.3 31.3, 355188.2 6690185.2 31.3, 355182.7 6690182.9 31.3, 355184.8 6690215.1 31.3))
BATIMENT0000000302945718;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2022-07-30 23:16:38;2002-01-01;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;2.0;2.0;00;00;;22.6;;;;Cadastre;C 0.2;POLYGON Z ((355231.6 6690220.6 -1000, 355241 6690218.7 -1000, 355242.6 6690215.3 -1000, 355236.5 6690211.7 -1000, 355230.3 6690208.2 -1000, 355226.3 6690206 -1000, 355225.2 6690205.4 -1000, 355221.3 6690213.2 -1000, 355217.8 6690220.1 -1000, 355218.1 6690220.5 -1000, 355218.3 6690221 -1000, 355218.5 6690221.5 -1000, 355218.7 6690222 -1000, 355218.8 6690222.5 -1000, 355218.9 6690223.1 -1000, 355218.9 6690223.6 -1000, 355218.9 6690224.1 -1000, 355218.8 6690225.2 -1000, 355218.8 6690225.7 -1000, 355218.6 6690226.2 -1000, 355218.5 6690226.7 -1000, 355218.2 6690227.1 -1000, 355218 6690227.6 -1000, 355217.7 6690228 -1000, 355217.4 6690228.4 -1000, 355217 6690228.8 -1000, 355216.6 6690229.1 -1000, 355216.2 6690229.4 -1000, 355225.8 6690227 -1000, 355222.3 6690216.4 -1000, 355231.6 6690220.6 -1000))
BATIMENT0000000302944391;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;00;00;13.4;24.8;38.2;41.7;25.5;Cadastre;A 1.0;POLYGON Z ((355185.4 6690225.1 38.2, 355197.8 6690221.4 38.2, 355197.7 6690215.8 38.2, 355196.1 6690215.2 38.2, 355193.5 6690214.6 38.2, 355184.8 6690215.1 38.2, 355185.4 6690225.1 38.2))
BATIMENT0000000302944385;Chapelle;Indifférencié;;Non;En service;2012-06-19 19:54:10;2014-08-11 18:58:35;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.1;24.8;41.9;;;Cadastre;;POLYGON Z ((355186.4 6690238.2 41.9, 355193.8 6690236.3 41.9, 355207.1 6690232.1 41.9, 355216.2 6690229.4 41.9, 355216.6 6690229.1 41.9, 355217 6690228.8 41.9, 355217.4 6690228.4 41.9, 355217.7 6690228 41.9, 355218 6690227.6 41.9, 355218.2 6690227.1 41.9, 355218.5 6690226.7 41.9, 355218.6 6690226.2 41.9, 355218.8 6690225.7 41.9, 355218.8 6690225.2 41.9, 355218.9 6690224.1 41.9, 355218.9 6690223.6 41.9, 355218.9 6690223.1 41.9, 355218.8 6690222.5 41.9, 355218.7 6690222 41.9, 355218.5 6690221.5 41.9, 355218.3 6690221 41.9, 355218.1 6690220.5 41.9, 355217.8 6690220.1 41.9, 355214.6 6690218.5 41.9, 355212.3 6690217.8 41.9, 355211.2 6690217.8 41.9, 355206.6 6690219.1 41.9, 355197.8 6690221.4 41.9, 355185.4 6690225.1 41.9, 355186.4 6690238.2 41.9))
BATIMENT0000000302944398;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;26.6;37.7;42.3;26.9;Cadastre;;POLYGON Z ((355207.4 6690286.4 37.7, 355209.8 6690285.8 37.7, 355206.4 6690273.6 37.7, 355203.9 6690274.5 37.7, 355207.4 6690286.4 37.7))
BATIMENT0000000302944738;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;28.9;38.6;41.9;29.8;Cadastre;A 1.0;POLYGON Z ((355034.7 6690196.6 38.6, 355035.5 6690198.8 38.6, 355038 6690205.6 38.6, 355047.4 6690202.2 38.6, 355044.2 6690193.4 38.6, 355034.7 6690196.6 38.6))
BATIMENT0000000302944788;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1984-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;3.6;29.7;33.3;;;Cadastre;A 1.0;POLYGON Z ((355065.8 6690193.2 33.3, 355065.2 6690193.5 33.3, 355074.4 6690217.9 33.3, 355079.4 6690216 33.3, 355081.2 6690221 33.3, 355082.5 6690224.2 33.3, 355083.8 6690227.5 33.3, 355084.7 6690227.2 33.3, 355092 6690224.3 33.3, 355095.3 6690223 33.3, 355110.2 6690217.2 33.3, 355112.2 6690216.6 33.3, 355116.1 6690215 33.3, 355113.5 6690208.2 33.3, 355101 6690213 33.3, 355098.2 6690205 33.3, 355101.8 6690203.7 33.3, 355098.9 6690196.5 33.3, 355082.7 6690202.5 33.3, 355082.8 6690203.1 33.3, 355078 6690204.9 33.3, 355072.6 6690190.7 33.3, 355071.7 6690191 33.3, 355065.8 6690193.2 33.3), (355089.5 6690208.5 33.3, 355092.7 6690216.3 33.3, 355086.9 6690218.6 33.3, 355083.7 6690210.9 33.3, 355089.5 6690208.5 33.3))
BATIMENT0000000302944772;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.8;29.9;35.7;39.1;30.2;Cadastre;C 0.3;POLYGON Z ((355063.4 6690215.2 35.7, 355058.1 6690217.3 35.7, 355058.6 6690218.8 35.7, 355054.6 6690220.3 35.7, 355055.3 6690222.3 35.7, 355057.2 6690221.6 35.7, 355064.7 6690219 35.7, 355063.4 6690215.2 35.7))
BATIMENT0000000302944789;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.8;29.3;32.1;;;Cadastre;A 1.0;POLYGON Z ((355081.2 6690221 32.1, 355076.3 6690223 32.1, 355077.7 6690226.1 32.1, 355082.5 6690224.2 32.1, 355081.2 6690221 32.1))
BATIMENT0000000302944771;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;8.6;28.8;37.5;39.5;30.2;Cadastre;A 1.0;POLYGON Z ((355058.3 6690224.8 37.5, 355055.8 6690225.7 37.5, 355054.8 6690227.8 37.5, 355055.7 6690230.2 37.5, 355059.8 6690228.6 37.5, 355067.2 6690225.6 37.5, 355064.7 6690219 37.5, 355057.2 6690221.6 37.5, 355058.3 6690224.8 37.5))
BATIMENT0000000302944787;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;28.7;33.3;;;Cadastre;;POLYGON Z ((355085.1 6690228.3 33.3, 355092.5 6690225.4 33.3, 355092 6690224.3 33.3, 355084.7 6690227.2 33.3, 355085.1 6690228.3 33.3))
BATIMENT0000000302944786;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;29.3;32.6;;;Cadastre;;POLYGON Z ((355078.8 6690229.4 32.6, 355083.8 6690227.5 32.6, 355082.5 6690224.2 32.6, 355077.7 6690226.1 32.6, 355078.8 6690229.4 32.6))
BATIMENT0000000302944770;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;00;00;8.6;28.8;37.5;42.5;29.6;Cadastre;A 1.0;POLYGON Z ((355062.3 6690235 37.5, 355069.6 6690232.1 37.5, 355067.2 6690225.6 37.5, 355059.8 6690228.6 37.5, 355062.3 6690235 37.5))
BATIMENT0000000302944785;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;5.1;29.7;34.8;;;Cadastre;A 1.0;POLYGON Z ((355090.6 6690235.5 34.8, 355096.5 6690233.2 34.8, 355094.4 6690227.3 34.8, 355093.3 6690227.7 34.8, 355092.5 6690225.4 34.8, 355085.1 6690228.3 34.8, 355084.7 6690227.2 34.8, 355083.8 6690227.5 34.8, 355078.8 6690229.4 34.8, 355082.4 6690238.7 34.8, 355090.6 6690235.5 34.8))
BATIMENT0000000302944769;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;24;20;10.0;28.9;39.0;42.4;29.7;Cadastre;B 0.6;POLYGON Z ((355064.8 6690241.6 39, 355067.2 6690240.8 39, 355072.2 6690238.8 39, 355069.6 6690232.1 39, 355062.3 6690235 39, 355064.8 6690241.6 39))
BATIMENT0000000302934515;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;90;12.7;30.7;43.4;46.6;31.7;Cadastre;C 0.3;POLYGON Z ((354962.1 6690121.7 43.4, 354963.2 6690121.6 43.4, 354964.1 6690121 43.4, 354964 6690118.7 43.4, 354962.9 6690118.2 43.4, 354961.9 6690118.4 43.4, 354961.6 6690113.8 43.4, 354960.2 6690114.1 43.4, 354956.2 6690114.9 43.4, 354956.6 6690118.5 43.4, 354957.4 6690127.5 43.4, 354962.7 6690127 43.4, 354962.1 6690121.7 43.4))
BATIMENT0000000302944197;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;30.8;33.7;35.7;31.4;Cadastre;;POLYGON Z ((355018.9 6690120.2 33.7, 355015.3 6690124.7 33.7, 355019.7 6690124.2 33.7, 355019.3 6690119.7 33.7, 355018.9 6690120.2 33.7))
BATIMENT0000000302934516;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;6.5;31.0;37.5;41.5;31.5;Cadastre;B 0.4;POLYGON Z ((354953.4 6690128.4 37.5, 354957.6 6690129 37.5, 354957.4 6690127.5 37.5, 354956.6 6690118.5 37.5, 354952.8 6690119.3 37.5, 354953.4 6690128.4 37.5))
BATIMENT0000000302944193;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1864-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;28.5;36.0;41.2;31.9;Cadastre;C 0.8;POLYGON Z ((355007.1 6690140.4 36, 355014.3 6690140.2 36, 355012.5 6690132.2 36, 355011.9 6690128.7 36, 355015.3 6690124.7 36, 355018.9 6690120.2 36, 355006.5 6690121.5 36, 355006.5 6690120.3 36, 355007.5 6690120.1 36, 355007.5 6690118.9 36, 355011.3 6690118.3 36, 355010.1 6690110.5 36, 355003.6 6690112 36, 355007.1 6690140.4 36))
BATIMENT0000000302944194;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;00;00;7.6;27.4;35.0;41.8;31.1;Cadastre;A 1.0;POLYGON Z ((355047.1 6690139.2 35, 355045.1 6690119.5 35, 355041.2 6690120 35, 355042.4 6690132.8 35, 355024.7 6690133.3 35, 355023.9 6690127.6 35, 355023.2 6690127.7 35, 355021.9 6690117.1 35, 355019.3 6690119.7 35, 355019.7 6690124.2 35, 355020.6 6690132 35, 355021.4 6690140 35, 355047.1 6690139.2 35))
BATIMENT0000000302934526;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;8.3;28.9;37.2;46.3;30.0;Cadastre;A 1.0;POLYGON Z ((354994.9 6690141.1 37.2, 354996.6 6690138.4 37.2, 354995.8 6690131.8 37.2, 354995.5 6690129 37.2, 354995.1 6690125.4 37.2, 354989.5 6690125.4 37.2, 354986.5 6690125.5 37.2, 354983.8 6690125.5 37.2, 354983.9 6690129.1 37.2, 354988.4 6690129.3 37.2, 354988.4 6690132.1 37.2, 354974.5 6690132.5 37.2, 354975.1 6690141.6 37.2, 354994.9 6690141.1 37.2))
BATIMENT0000000302934521;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.1;30.8;36.0;43.7;31.5;Cadastre;C 0.2;POLYGON Z ((354949.4 6690131.9 36, 354949.9 6690140.9 36, 354958.4 6690134.2 36, 354957.6 6690129 36, 354953.4 6690128.4 36, 354949.4 6690131.9 36))
BATIMENT0000000302934520;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.5;30.2;42.7;46.0;31.5;Cadastre;A 1.0;POLYGON Z ((354949.1 6690141.6 42.7, 354949.1 6690142.4 42.7, 354967.1 6690141.9 42.7, 354967.1 6690135.6 42.7, 354966.8 6690134.5 42.7, 354965.9 6690134.4 42.7, 354965.7 6690133.5 42.7, 354964 6690133.5 42.7, 354962.7 6690127 42.7, 354957.4 6690127.5 42.7, 354957.6 6690129 42.7, 354958.4 6690134.2 42.7, 354949.9 6690140.9 42.7, 354949.1 6690141.6 42.7))
BATIMENT0000000302944195;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;00;00;13.2;28.0;41.2;43.6;30.8;Cadastre;A 0.8;POLYGON Z ((355021.4 6690140 41.2, 355020.6 6690132 41.2, 355012.5 6690132.2 41.2, 355014.3 6690140.2 41.2, 355021.4 6690140 41.2))
BATIMENT0000000302934522;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.5;31.0;35.5;;;Cadastre;A 1.0;POLYGON Z ((354972.7 6690141.7 35.5, 354972.8 6690135.6 35.5, 354967.1 6690135.6 35.5, 354967.1 6690141.9 35.5, 354972.7 6690141.7 35.5))
BATIMENT0000000302944179;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1888-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.0;27.6;37.6;40.2;28.8;Cadastre;A 1.0;POLYGON Z ((355022.2 6690149.6 37.6, 355023.2 6690160.1 37.6, 355024.8 6690160.1 37.6, 355024.8 6690156.9 37.6, 355029.8 6690156.6 37.6, 355029.8 6690149.4 37.6, 355022.2 6690149.6 37.6))
BATIMENT0000000302934599;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1897-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.4;27.1;37.5;42.0;31.5;Cadastre;A 1.0;POLYGON Z ((354990.8 6690150.7 37.5, 354991.1 6690161.6 37.5, 354998.6 6690161.1 37.5, 354998.4 6690150.4 37.5, 354990.8 6690150.7 37.5))
BATIMENT0000000302935285;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;7.2;32.3;39.5;40.4;33.1;Cadastre;A 1.0;POLYGON Z ((354949.8 6690151 39.5, 354950 6690161.8 39.5, 354960.2 6690161.4 39.5, 354959.8 6690150.7 39.5, 354949.8 6690151 39.5))
BATIMENT0000000302934600;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;8.9;29.2;38.2;43.3;33.4;Cadastre;A 1.0;POLYGON Z ((354976.1 6690151.3 38.2, 354976.2 6690162.9 38.2, 354981 6690163.2 38.2, 354980.8 6690157.8 38.2, 354985.6 6690157.4 38.2, 354985.6 6690158.3 38.2, 354986.2 6690158.6 38.2, 354986.7 6690158.6 38.2, 354987.4 6690160 38.2, 354985.7 6690159.9 38.2, 354983.3 6690158.5 38.2, 354982.1 6690158.6 38.2, 354982.5 6690162 38.2, 354991.1 6690161.6 38.2, 354990.8 6690150.7 38.2, 354976.1 6690151.3 38.2))
BATIMENT0000000302934590;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;10.1;28.3;38.5;42.8;31.2;Cadastre;A 0.6;POLYGON Z ((354998.4 6690150.4 38.5, 354998.6 6690161.1 38.5, 354998.6 6690164.3 38.5, 354998.6 6690165.6 38.5, 355000.1 6690165.6 38.5, 355000 6690164.7 38.5, 355000.8 6690164.6 38.5, 355000.8 6690165.3 38.5, 355002.7 6690165.1 38.5, 355002.5 6690161.5 38.5, 355007 6690161 38.5, 355006.6 6690150.2 38.5, 354998.4 6690150.4 38.5))
BATIMENT0000000302934607;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.6;30.0;40.7;43.6;33.4;Cadastre;A 1.0;POLYGON Z ((354967.1 6690151.5 40.7, 354967.4 6690166.7 40.7, 354967.6 6690166.7 40.7, 354976.2 6690166.4 40.7, 354976.2 6690162.9 40.7, 354976.1 6690151.3 40.7, 354967.1 6690151.5 40.7))
BATIMENT0000000302944178;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;29.1;33.6;33.7;31.2;Cadastre;;POLYGON Z ((355005.4 6690164.5 33.6, 355005.6 6690166.3 33.6, 355007.1 6690166.1 33.6, 355007.1 6690164.3 33.6, 355005.4 6690164.5 33.6))
BATIMENT0000000302944177;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.6;27.1;33.7;35.6;31.2;Cadastre;A 1.0;POLYGON Z ((355006.6 6690150.2 33.7, 355007 6690161 33.7, 355007.1 6690164.3 33.7, 355007.1 6690166.1 33.7, 355007.4 6690173.7 33.7, 355007.7 6690182.3 33.7, 355024.5 6690179.8 33.7, 355024.5 6690178.9 33.7, 355023.8 6690166.9 33.7, 355023.4 6690162.2 33.7, 355023.2 6690160.1 33.7, 355022.2 6690149.6 33.7, 355006.6 6690150.2 33.7))
BATIMENT0000000302934614;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;32.3;34.5;35.7;33.4;Cadastre;;POLYGON Z ((354967.6 6690166.7 34.5, 354967.7 6690169.7 34.5, 354971.6 6690169.5 34.5, 354971.8 6690172.1 34.5, 354976.3 6690172 34.5, 354976.2 6690166.4 34.5, 354967.6 6690166.7 34.5))
BATIMENT0000000302944167;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;29.5;33.5;38.2;30.3;Cadastre;;POLYGON Z ((355026.1 6690179.1 33.5, 355026.4 6690177.9 33.5, 355029 6690177.9 33.5, 355029.3 6690173.1 33.5, 355030.3 6690173 33.5, 355030.4 6690167.1 33.5, 355023.8 6690166.9 33.5, 355024.5 6690178.9 33.5, 355026.1 6690179.1 33.5))
BATIMENT0000000302934706;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;;;12.8;32.8;45.6;47.6;34.1;Cadastre;A 1.0;POLYGON Z ((354896.9 6690172.5 45.6, 354905 6690173.1 45.6, 354909.2 6690163.6 45.6, 354901.4 6690161 45.6, 354896.9 6690172.5 45.6))
BATIMENT0000000302934616;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;32.8;36.0;41.2;33.5;Cadastre;;POLYGON Z ((354935.9 6690173.6 36, 354935.9 6690170.7 36, 354931.3 6690168.9 36, 354930.2 6690172 36, 354935.9 6690173.6 36))
BATIMENT0000000302934612;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.0;33.2;41.2;41.7;33.3;Cadastre;;POLYGON Z ((354923.9 6690175.3 41.2, 354922.3 6690174.9 41.2, 354921.9 6690175.7 41.2, 354923.7 6690176.3 41.2, 354923.9 6690175.3 41.2))
BATIMENT0000000302934613;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;33.1;36.7;40.5;33.5;Cadastre;;POLYGON Z ((354939.3 6690176.1 36.7, 354932.9 6690174.3 36.7, 354930.8 6690174.2 36.7, 354929.5 6690178 36.7, 354937.2 6690179.5 36.7, 354940.9 6690179.6 36.7, 354941.4 6690176.1 36.7, 354939.3 6690176.1 36.7))
BATIMENT0000000302934611;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;7.7;33.0;40.7;44.1;33.8;Cadastre;A 1.0;POLYGON Z ((354912 6690182.4 40.7, 354924.6 6690185.7 40.7, 354928 6690185.9 40.7, 354931.3 6690186.1 40.7, 354940.3 6690186.5 40.7, 354940.8 6690180.6 40.7, 354939.4 6690180.6 40.7, 354939.3 6690181.5 40.7, 354931 6690181.1 40.7, 354928.7 6690180.4 40.7, 354928.1 6690182.4 40.7, 354924.6 6690182.4 40.7, 354925.6 6690176.9 40.7, 354923.7 6690176.3 40.7, 354921.9 6690175.7 40.7, 354922.3 6690174.9 40.7, 354923.9 6690175.3 40.7, 354928.3 6690176.3 40.7, 354930.2 6690172 40.7, 354918.1 6690168.3 40.7, 354912 6690182.4 40.7))
BATIMENT0000000302934618;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.1;32.9;34.0;36.0;33.5;Cadastre;;POLYGON Z ((354944 6690180 34, 354944.6 6690176.5 34, 354941.4 6690176.1 34, 354940.9 6690179.6 34, 354942 6690179.8 34, 354944 6690180 34))
BATIMENT0000000302934619;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;10;20;6.6;32.8;39.4;40.8;33.5;Cadastre;A 0.4;POLYGON Z ((354947.5 6690176.6 39.4, 354947 6690181.1 39.4, 354941.9 6690180.9 39.4, 354942 6690179.8 39.4, 354940.9 6690179.6 39.4, 354940.8 6690180.6 39.4, 354940.3 6690186.5 39.4, 354948.5 6690187 39.4, 354949.4 6690187 39.4, 354950.2 6690176.8 39.4, 354947.5 6690176.6 39.4))
BATIMENT0000000302934617;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;32.9;39.7;41.3;33.7;Cadastre;;POLYGON Z ((354934.4 6690191.8 39.7, 354934.6 6690191.4 39.7, 354948.4 6690192 39.7, 354948.5 6690187 39.7, 354940.3 6690186.5 39.7, 354931.3 6690186.1 39.7, 354930.5 6690191.5 39.7, 354934.4 6690191.8 39.7))
BATIMENT0000000302934610;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;10.5;33.2;43.7;48.0;33.8;Cadastre;C 0.6;POLYGON Z ((354907.7 6690192.2 43.7, 354918.2 6690196.6 43.7, 354922.2 6690187.7 43.7, 354925.2 6690188.7 43.7, 354924.1 6690192.4 43.7, 354926.4 6690193 43.7, 354928 6690185.9 43.7, 354924.6 6690185.7 43.7, 354912 6690182.4 43.7, 354907.7 6690192.2 43.7))
BATIMENT0000000302934609;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;33.5;38.8;41.2;33.8;Cadastre;;POLYGON Z ((354930.5 6690191.5 38.8, 354931.3 6690186.1 38.8, 354928 6690185.9 38.8, 354926.4 6690193 38.8, 354926.1 6690194.6 38.8, 354926.1 6690194.9 38.8, 354929.8 6690195.3 38.8, 354930.5 6690191.5 38.8))
BATIMENT0000000302935348;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.0;30.9;33.0;33.1;31.5;Cadastre;;POLYGON Z ((354998.1 6690174.9 33, 354998 6690172.7 33, 354997.6 6690172.6 33, 354994.2 6690172.5 33, 354994.4 6690175.2 33, 354998.1 6690174.9 33))
BATIMENT0000000302934588;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;30.6;34.5;36.5;31.2;Cadastre;;POLYGON Z ((355003.1 6690173.7 34.5, 355003.4 6690181.3 34.5, 354999.6 6690181.3 34.5, 354999.8 6690186.4 34.5, 354999.8 6690187.7 34.5, 355007.9 6690187.5 34.5, 355007.7 6690182.3 34.5, 355007.4 6690173.7 34.5, 355003.1 6690173.7 34.5))
BATIMENT0000000302934622;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;40;5.3;32.6;38.0;40.0;33.2;Cadastre;A 1.0;POLYGON Z ((354958.1 6690187.5 38, 354959 6690177.2 38, 354957.2 6690177.3 38, 354957 6690180.6 38, 354957.5 6690180.6 38, 354957.2 6690182.2 38, 354952.2 6690182.1 38, 354952.8 6690177 38, 354950.2 6690176.8 38, 354949.4 6690187 38, 354956.5 6690187.4 38, 354958.1 6690187.5 38))
BATIMENT0000000302934623;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;32.4;35.4;36.5;33.1;Cadastre;;POLYGON Z ((354960.8 6690187.6 35.4, 354961.8 6690182.2 35.4, 354967.1 6690182.4 35.4, 354967.5 6690177.7 35.4, 354959 6690177.2 35.4, 354958.1 6690187.5 35.4, 354960.8 6690187.6 35.4))
BATIMENT0000000302944174;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;8.6;29.3;38.0;41.0;30.1;Cadastre;C 0.9;POLYGON Z ((355037.1 6690188.2 38, 355036.4 6690186.8 38, 355036.8 6690183.3 38, 355036.4 6690183.3 38, 355031.2 6690184.9 38, 355030.4 6690181.5 38, 355024.6 6690183.3 38, 355024.7 6690192.2 38, 355037.1 6690188.2 38))
BATIMENT0000000302944176;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;14;90;8.5;29.7;38.2;41.3;31.0;Cadastre;A 1.0;POLYGON Z ((355024.7 6690192.2 38.2, 355024.6 6690183.3 38.2, 355024.5 6690179.8 38.2, 355007.7 6690182.3 38.2, 355007.9 6690187.5 38.2, 355007.9 6690188.7 38.2, 355008.2 6690197.5 38.2, 355024.7 6690192.2 38.2))
BATIMENT0000000302934592;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;30.7;36.9;39.7;31.6;Cadastre;;POLYGON Z ((354988.3 6690190.7 36.9, 354990 6690195.8 36.9, 354991.8 6690195.2 36.9, 354991.7 6690192.2 36.9, 354991.7 6690189.6 36.9, 354988.3 6690190.7 36.9))
BATIMENT0000000302934587;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;29;8.9;30.3;39.2;40.5;30.9;Cadastre;B 1.0;POLYGON Z ((355008.2 6690197.5 39.2, 355007.9 6690188.7 39.2, 354999.7 6690191 39.2, 354999.7 6690200.2 39.2, 355008.2 6690197.5 39.2))
BATIMENT0000000302934589;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;30;20;6.6;30.5;37.1;39.9;31.2;Cadastre;A 1.0;POLYGON Z ((354991.7 6690202.7 37.1, 354999.7 6690200.2 37.1, 354999.7 6690191 37.1, 354999.8 6690187.7 37.1, 354999.8 6690186.4 37.1, 354996.1 6690186.4 37.1, 354996.1 6690192.1 37.1, 354991.7 6690192.2 37.1, 354991.8 6690195.2 37.1, 354991.7 6690202.7 37.1))
BATIMENT0000000302934591;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;10;4.8;30.8;35.6;37.2;32.0;Cadastre;A 1.0;POLYGON Z ((354983.5 6690198 35.6, 354977.4 6690200.2 35.6, 354979.2 6690206.7 35.6, 354991.7 6690202.7 35.6, 354991.8 6690195.2 35.6, 354990 6690195.8 35.6, 354983.5 6690198 35.6))
BATIMENT0000000302934539;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.9;33.5;39.5;48.2;35.6;Cadastre;A 1.0;POLYGON Z ((354846.9 6690124.4 39.5, 354845.1 6690122.4 39.5, 354839.8 6690115.6 39.5, 354835 6690119.3 39.5, 354842 6690128.4 39.5, 354846.9 6690124.4 39.5))
BATIMENT0000000302934560;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1869-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.0;33.9;43.0;48.0;34.4;Cadastre;A 1.0;POLYGON Z ((354801 6690133.1 43, 354795.6 6690126 43, 354791.5 6690128.9 43, 354791.3 6690130.4 43, 354796.3 6690136.7 43, 354801 6690133.1 43))
BATIMENT0000000302934540;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;35;40;15.1;33.6;48.7;50.7;34.4;Cadastre;C 0.9;POLYGON Z ((354847.3 6690109.9 48.7, 354839.8 6690115.6 48.7, 354845.1 6690122.4 48.7, 354849.6 6690118.8 48.7, 354869.2 6690131.8 48.7, 354858.7 6690155.4 48.7, 354866.4 6690158.8 48.7, 354877.6 6690133.5 48.7, 354878.4 6690131.8 48.7, 354878.7 6690130.3 48.7, 354878.1 6690128 48.7, 354849.9 6690108.9 48.7, 354848.9 6690108.7 48.7, 354847.3 6690109.9 48.7))
BATIMENT0000002011296151;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;50.0;6.0;00;00;20.7;35.0;;;;Imagerie aérienne;A 1.0;POLYGON Z ((354792.8 6690219.8 49.8, 354802.2 6690212.6 50, 354805 6690210.4 50, 354807.5 6690208.4 49.9, 354807 6690207.4 53.4, 354806.3 6690206.4 53.4, 354815.7 6690198.8 53.4, 354817.7 6690197.1 51.1, 354814.7 6690193.6 50.7, 354814.9 6690192.2 47, 354817.1 6690187.9 47.4, 354817.6 6690186.9 50.2, 354822 6690178.3 50.4, 354822.3 6690176.2 47.6, 354820 6690175.2 47.6, 354820.6 6690173.6 47.6, 354814.6 6690171 50.4, 354808.8 6690163.5 50.4, 354811.6 6690161.6 53.7, 354813.5 6690163.7 51.5, 354814.3 6690164.8 50, 354826.8 6690155.3 50, 354827.8 6690156.7 47.4, 354832.5 6690153.2 47.4, 354831.7 6690151.8 49.7, 354834.9 6690149.3 49.7, 354833.3 6690146.8 52.5, 354838.8 6690142.3 52.7, 354833 6690134 52.6, 354831.8 6690132.6 50.8, 354805.5 6690153.2 50.5, 354806.5 6690154.3 52.5, 354809.8 6690158.3 55.7, 354804.9 6690161.4 52.9, 354803.6 6690160.3 51, 354794.5 6690167.1 50.2, 354805.6 6690181.5 50.2, 354814.3 6690185.2 49.9, 354812.3 6690190.1 50.8, 354811 6690188.2 50.8, 354784.5 6690209.1 51.6, 354785.6 6690210 53.2, 354792.1 6690218.6 53.5, 354792.8 6690219.8 49.8))
BATIMENT0000000302934532;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;35;40;14.2;34.2;48.4;50.0;34.7;Cadastre;C 0.7;POLYGON Z ((354841.9 6690193.5 48.4, 354849.7 6690196.9 48.4, 354863.8 6690164.4 48.4, 354856.4 6690160.9 48.4, 354841.9 6690193.5 48.4))
BATIMENT0000002011294704;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:41:05;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.0;35.2;;45.5;36.0;Imagerie aérienne;;POLYGON Z ((354807.1 6690234.1 39.2, 354811.1 6690224.5 39.1, 354802.2 6690212.6 38.7, 354792.8 6690219.8 38.7, 354799.5 6690228.5 38.7, 354792.3 6690233.7 38.7, 354798.3 6690240.8 38.7, 354807.1 6690234.1 39.2))
BATIMENT0000000302934625;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;20.0;5.0;35;40;14.6;35.0;49.6;51.0;35.4;Cadastre;C 0.9;POLYGON Z ((354822.2 6690237.7 49.6, 354820.6 6690237 49.6, 354819.2 6690240.7 49.6, 354820.6 6690241.3 49.6, 354807.9 6690270.3 49.6, 354815.9 6690273.5 49.6, 354847.1 6690202.5 49.6, 354839.5 6690199.1 49.6, 354822.2 6690237.7 49.6))
BATIMENT0000000302934702;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;00;00;17.0;33.9;51.0;53.3;35.4;Cadastre;A 1.0;POLYGON Z ((354872.7 6690221.5 51, 354871.9 6690221.7 51, 354859.6 6690250.3 51, 354860.3 6690250.6 51, 354869.1 6690254 51, 354869.3 6690254.1 51, 354882.9 6690222.5 51, 354874.4 6690221.6 51, 354872.7 6690221.5 51))
BATIMENT0000000302934697;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;34.4;42.0;43.1;35.3;Cadastre;;POLYGON Z ((354847.3 6690247.2 42, 354846.1 6690249.8 42, 354847 6690250.3 42, 354848.1 6690247.3 42, 354847.3 6690247.2 42))
BATIMENT0000000302934701;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.9;34.1;42.0;43.2;35.7;Cadastre;;POLYGON Z ((354840.9 6690261.5 42, 354842 6690262.2 42, 354842.9 6690260 42, 354842 6690259.1 42, 354840.9 6690261.5 42))
BATIMENT0000000302934705;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;00;00;9.3;34.5;43.8;48.0;35.3;Cadastre;C 0.8;POLYGON Z ((354895.9 6690172.5 43.8, 354887.5 6690191.5 43.8, 354887.6 6690191.6 43.8, 354887.6 6690191.8 43.8, 354887.6 6690191.9 43.8, 354887.6 6690192 43.8, 354887.5 6690192.2 43.8, 354887.4 6690192.2 43.8, 354887.3 6690192.3 43.8, 354887.2 6690192.3 43.8, 354887.2 6690192.4 43.8, 354887 6690192.4 43.8, 354886.9 6690192.4 43.8, 354886.8 6690192.3 43.8, 354886.7 6690192.2 43.8, 354880.6 6690189.4 43.8, 354886.2 6690176.8 43.8, 354879.6 6690173.8 43.8, 354875.3 6690183.1 43.8, 354873.8 6690186.5 43.8, 354876 6690187.5 43.8, 354872.8 6690195 43.8, 354870.6 6690193.8 43.8, 354864.9 6690206.7 43.8, 354872.2 6690210 43.8, 354872.3 6690210 43.8, 354872.4 6690210 43.8, 354872.6 6690210 43.8, 354872.7 6690209.9 43.8, 354872.8 6690209.8 43.8, 354872.9 6690209.7 43.8, 354872.9 6690209.5 43.8, 354872.9 6690209.4 43.8, 354872.9 6690209.3 43.8, 354872.9 6690209.2 43.8, 354872.8 6690209.1 43.8, 354872.7 6690209 43.8, 354872.6 6690209 43.8, 354874.7 6690204.1 43.8, 354876.5 6690199.9 43.8, 354877.8 6690197 43.8, 354882 6690198.8 43.8, 354886.9 6690199.9 43.8, 354892.2 6690201.7 43.8, 354899 6690186.4 43.8, 354905 6690173.1 43.8, 354896.9 6690172.5 43.8, 354895.9 6690172.5 43.8))
BATIMENT0000000302934608;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;33.5;42.1;43.5;33.7;Cadastre;;POLYGON Z ((354922.5 6690199.2 42.1, 354925 6690199.6 42.1, 354926.1 6690194.9 42.1, 354926.1 6690194.6 42.1, 354923.8 6690194.1 42.1, 354922.1 6690199 42.1, 354922.5 6690199.2 42.1))
BATIMENT0000000302934605;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;11.8;33.3;45.2;48.5;33.9;Cadastre;C 0.9;POLYGON Z ((354903.7 6690201.4 45.2, 354917.3 6690204.6 45.2, 354919.4 6690202.5 45.2, 354920.4 6690201.6 45.2, 354918.9 6690201.1 45.2, 354919.5 6690199 45.2, 354917.5 6690198.3 45.2, 354918.2 6690196.6 45.2, 354907.7 6690192.2 45.2, 354903.7 6690201.4 45.2))
BATIMENT0000000302934606;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;90;20;6.1;33.6;39.8;42.2;34.1;Cadastre;C 0.5;POLYGON Z ((354922.1 6690202.3 39.8, 354922.1 6690202.6 39.8, 354919.7 6690204.9 39.8, 354919.3 6690205.3 39.8, 354918.7 6690208.2 39.8, 354924.8 6690208.5 39.8, 354925.6 6690208.6 39.8, 354925.6 6690209.8 39.8, 354930.5 6690210.2 39.8, 354931 6690206.3 39.8, 354929 6690206.1 39.8, 354930.3 6690195.3 39.8, 354929.8 6690195.3 39.8, 354926.1 6690194.9 39.8, 354925 6690199.6 39.8, 354922.5 6690199.2 39.8, 354922.3 6690201.4 39.8, 354922.1 6690202.3 39.8))
BATIMENT0000000302934704;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.4;34.4;45.8;48.6;35.3;Cadastre;C 0.8;POLYGON Z ((354886.9 6690199.9 45.8, 354882 6690198.8 45.8, 354884.1 6690199.8 45.8, 354881.5 6690205.6 45.8, 354889.8 6690207.1 45.8, 354892.2 6690201.7 45.8, 354886.9 6690199.9 45.8))
BATIMENT0000000302934601;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;90;13.4;33.4;46.8;50.3;34.1;Cadastre;A 1.0;POLYGON Z ((354900.2 6690209.1 46.8, 354910.6 6690211.5 46.8, 354914.2 6690212.3 46.8, 354925.6 6690212.5 46.8, 354925.6 6690209.8 46.8, 354924.7 6690209.7 46.8, 354919.3 6690209.4 46.8, 354917.6 6690210.2 46.8, 354915 6690209.3 46.8, 354916.2 6690206.5 46.8, 354917.9 6690206.9 46.8, 354918.7 6690205.1 46.8, 354920.2 6690203.6 46.8, 354919.4 6690202.5 46.8, 354917.3 6690204.6 46.8, 354903.7 6690201.4 46.8, 354900.2 6690209.1 46.8))
BATIMENT0000000302934594;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;5.2;32.2;37.5;40.4;34.3;Cadastre;A 1.0;POLYGON Z ((354956.8 6690208.4 37.5, 354956.7 6690205.2 37.5, 354956.7 6690204.1 37.5, 354956.6 6690200.2 37.5, 354948.4 6690203 37.5, 354948.4 6690203.5 37.5, 354948.6 6690203.9 37.5, 354948.5 6690207.3 37.5, 354948.5 6690207.5 37.5, 354948.5 6690213 37.5, 354938.4 6690212.9 37.5, 354935.4 6690214 37.5, 354936.4 6690221 37.5, 354949.5 6690216.8 37.5, 354949.2 6690216.4 37.5, 354950.5 6690216 37.5, 354958.5 6690213.4 37.5, 354956.8 6690208.4 37.5))
BATIMENT0000000302934598;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.2;33.4;45.7;46.7;33.7;Cadastre;;POLYGON Z ((354910.6 6690211.5 45.7, 354909.7 6690214.3 45.7, 354914.1 6690215.2 45.7, 354914.2 6690212.3 45.7, 354910.6 6690211.5 45.7))
BATIMENT0000000302934703;Indifférenciée;Commercial et services;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;;;11.8;34.3;46.1;49.1;35.3;Cadastre;C 0.8;POLYGON Z ((354874.4 6690221.6 46.1, 354882.9 6690222.5 46.1, 354889.8 6690207.1 46.1, 354881.5 6690205.6 46.1, 354874.4 6690221.6 46.1))
BATIMENT0000000302934596;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;10.2;33.2;43.4;46.7;34.1;Cadastre;C 0.4;POLYGON Z ((354921.8 6690218.3 43.4, 354923.9 6690218.2 43.4, 354929.1 6690216.3 43.4, 354935.4 6690214 43.4, 354938.4 6690212.9 43.4, 354925.8 6690212.5 43.4, 354925.6 6690212.5 43.4, 354914.2 6690212.3 43.4, 354914.1 6690215.2 43.4, 354914.2 6690216.8 43.4, 354914.2 6690217.5 43.4, 354914.6 6690217.5 43.4, 354914.6 6690218.1 43.4, 354921.8 6690218.3 43.4))
BATIMENT0000000302934593;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.6;31.3;36.0;39.6;32.6;Cadastre;A 1.0;POLYGON Z ((354977.2 6690197.5 36, 354960.2 6690202.9 36, 354960.5 6690203.9 36, 354956.7 6690205.2 36, 354956.8 6690208.4 36, 354958.5 6690213.4 36, 354979.2 6690206.7 36, 354977.4 6690200.2 36, 354977.2 6690197.5 36))
BATIMENT0000000302944739;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.8;31.0;34.8;;;Cadastre;A 1.0;POLYGON Z ((355022.8 6690203.5 34.8, 355021.8 6690200.7 34.8, 355015.2 6690202.7 34.8, 355016.4 6690216.3 34.8, 355021.3 6690228.9 34.8, 355043.6 6690220.7 34.8, 355038 6690205.6 34.8, 355035.5 6690198.8 34.8, 355022.8 6690203.5 34.8))
BATIMENT0000000302944147;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;12;20;5.0;31.9;36.9;;;Cadastre;A 1.0;POLYGON Z ((355005.3 6690225.5 36.9, 355009.9 6690224.1 36.9, 355013 6690223.3 36.9, 355012.8 6690220.5 36.9, 355011 6690221.1 36.9, 355009.6 6690216.7 36.9, 355012.4 6690215.6 36.9, 355011.2 6690205.1 36.9, 355000.4 6690208.7 36.9, 355001.7 6690213.8 36.9, 355003.2 6690218.6 36.9, 355004.9 6690223.8 36.9, 355005.3 6690225.5 36.9))
BATIMENT0000000302934531;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;5.2;31.9;37.1;;;Cadastre;A 1.0;POLYGON Z ((354992.7 6690211.3 37.1, 354996.3 6690222.9 37.1, 354997.3 6690226.3 37.1, 355004.9 6690223.8 37.1, 355003.2 6690218.6 37.1, 354998.1 6690220.5 37.1, 354996.7 6690215.7 37.1, 355001.7 6690213.8 37.1, 355000.4 6690208.7 37.1, 354992.7 6690211.3 37.1))
BATIMENT0000000302934530;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.8;31.9;40.7;;;Cadastre;A 1.0;POLYGON Z ((354985.3 6690213.7 40.7, 354988.2 6690222.2 40.7, 354988.3 6690222.6 40.7, 354992 6690221.3 40.7, 354992.8 6690224 40.7, 354996.3 6690222.9 40.7, 354992.7 6690211.3 40.7, 354985.3 6690213.7 40.7))
BATIMENT0000000302934529;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;31.9;40.2;44.2;32.0;Cadastre;A 1.0;POLYGON Z ((354970.3 6690218.5 40.2, 354972.4 6690224.8 40.2, 354976.8 6690223.6 40.2, 354976.7 6690222.9 40.2, 354979.3 6690221.9 40.2, 354980.6 6690224.8 40.2, 354988.2 6690222.2 40.2, 354985.3 6690213.7 40.2, 354970.3 6690218.5 40.2))
BATIMENT0000000302944148;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.7;30.6;33.3;34.8;31.2;Cadastre;C 0.3;POLYGON Z ((355006.8 6690229.5 33.3, 355011.1 6690227.7 33.3, 355009.9 6690224.1 33.3, 355005.3 6690225.5 33.3, 355006.8 6690229.5 33.3))
BATIMENT0000000302944149;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;31.9;34.8;;;Cadastre;;POLYGON Z ((355007.9 6690233.2 34.8, 355015.2 6690229.6 34.8, 355014.4 6690227.6 34.8, 355011.5 6690228.7 34.8, 355011.1 6690227.7 34.8, 355006.8 6690229.5 34.8, 355007.9 6690233.2 34.8))
BATIMENT0000000302944150;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;12;6.4;30.4;36.9;38.7;31.7;Cadastre;C 0.3;POLYGON Z ((355007.9 6690233.2 36.9, 355009.5 6690238.8 36.9, 355017.4 6690235 36.9, 355015.2 6690229.6 36.9, 355007.9 6690233.2 36.9))
BATIMENT0000000302934512;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.4;31.9;35.3;44.0;32.7;Cadastre;A 1.0;POLYGON Z ((354962.2 6690221.3 35.3, 354974.2 6690255.9 35.3, 354978.9 6690253.8 35.3, 354967.6 6690219.4 35.3, 354962.2 6690221.3 35.3))
BATIMENT0000000302934597;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;33.2;45.6;45.8;33.6;Cadastre;;POLYGON Z ((354914.2 6690217.5 45.6, 354914.2 6690216.8 45.6, 354913.2 6690216.7 45.6, 354913.3 6690217.5 45.6, 354914.2 6690217.5 45.6))
BATIMENT0000000302934595;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;5.1;32.8;37.9;41.2;33.8;Cadastre;A 1.0;POLYGON Z ((354930.7 6690222.9 37.9, 354936.4 6690221 37.9, 354935.4 6690214 37.9, 354929.1 6690216.3 37.9, 354930.7 6690222.9 37.9))
BATIMENT0000000302934602;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;10;20;14.3;31.5;45.8;50.4;34.2;Cadastre;C 0.8;POLYGON Z ((354894.9 6690221.8 45.8, 354895.3 6690223 45.8, 354913.2 6690228.6 45.8, 354914.6 6690228 45.8, 354914.6 6690218.1 45.8, 354914.6 6690217.5 45.8, 354914.2 6690217.5 45.8, 354913.3 6690217.5 45.8, 354911.8 6690217.5 45.8, 354911 6690218.3 45.8, 354910.7 6690218 45.8, 354909.4 6690218.4 45.8, 354908.5 6690218.4 45.8, 354909.7 6690214.3 45.8, 354910.6 6690211.5 45.8, 354900.2 6690209.1 45.8, 354894.9 6690221.8 45.8))
BATIMENT0000000302934603;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.0;33.0;38.1;42.2;33.8;Cadastre;A 1.0;POLYGON Z ((354923.9 6690218.2 38.1, 354924 6690222.3 38.1, 354924.1 6690225.1 38.1, 354930.7 6690222.9 38.1, 354929.1 6690216.3 38.1, 354923.9 6690218.2 38.1))
BATIMENT0000000302934604;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;33.1;36.5;37.0;33.7;Cadastre;;POLYGON Z ((354924 6690222.3 36.5, 354917.9 6690224.1 36.5, 354918.7 6690226.7 36.5, 354924.1 6690225.1 36.5, 354924 6690222.3 36.5))
BATIMENT0000000302934624;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;10;20;5.2;32.5;37.8;41.5;33.6;Cadastre;A 1.0;POLYGON Z ((354926.2 6690230.4 37.8, 354928.6 6690237.9 37.8, 354930.9 6690239.2 37.8, 354932.5 6690239.8 37.8, 354948.1 6690234.6 37.8, 354945.1 6690224.3 37.8, 354945 6690223.9 37.8, 354925.9 6690230.1 37.8, 354926.2 6690230.4 37.8), (354946.2 6690231.9 37.8, 354946.7 6690233.4 37.8, 354932.4 6690238.4 37.8, 354931.7 6690236.7 37.8, 354946.2 6690231.9 37.8))
BATIMENT0000000302934579;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;33.3;36.7;38.7;33.5;Cadastre;;POLYGON Z ((354923.2 6690238.9 36.7, 354922.1 6690234.2 36.7, 354920.3 6690234.6 36.7, 354921.6 6690239.3 36.7, 354923.2 6690238.9 36.7))
BATIMENT0000000302934576;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;12.5;33.3;45.8;48.9;34.2;Cadastre;A 1.0;POLYGON Z ((354891.2 6690229.8 45.8, 354887.6 6690238.2 45.8, 354898.7 6690245.2 45.8, 354903.9 6690233.7 45.8, 354891.2 6690229.8 45.8))
BATIMENT0000000302934578;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;6.9;33.3;40.2;41.6;34.0;Cadastre;A 1.0;POLYGON Z ((354918.9 6690243.9 40.2, 354921.6 6690239.3 40.2, 354920.3 6690234.6 40.2, 354912.8 6690236.7 40.2, 354912.3 6690236.4 40.2, 354911.1 6690238.9 40.2, 354918.9 6690243.9 40.2))
BATIMENT0000000302934577;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.1;33.3;43.4;45.7;34.0;Cadastre;A 1.0;POLYGON Z ((354904.4 6690248.8 43.4, 354911.1 6690238.9 43.4, 354912.3 6690236.4 43.4, 354903.9 6690233.7 43.4, 354898.7 6690245.2 43.4, 354904.4 6690248.8 43.4))
BATIMENT0000000302934585;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.2;33.2;43.5;46.5;33.9;Cadastre;A 0.9;POLYGON Z ((354916.2 6690246.4 43.5, 354911.4 6690253.9 43.5, 354919.5 6690259 43.5, 354924.3 6690251.6 43.5, 354916.2 6690246.4 43.5))
BATIMENT0000000302934584;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;13;30;15.5;32.5;48.1;49.7;33.6;Cadastre;A 1.0;POLYGON Z ((354940.7 6690272.3 48.1, 354947.9 6690260.5 48.1, 354931.6 6690250 48.1, 354930.2 6690251.8 48.1, 354926 6690249.2 48.1, 354924.3 6690251.6 48.1, 354919.5 6690259 48.1, 354940.7 6690272.3 48.1))
BATIMENT0000000327820026;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:38:05;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;5.0;;;11.8;34.1;;49.6;34.4;Imagerie aérienne;C 0.3;POLYGON Z ((354880 6690281.4 45.9, 354883.2 6690273.9 45.9, 354888.1 6690276.9 45.9, 354892.6 6690268.4 45.9, 354890.8 6690267.3 45.9, 354893.3 6690262.4 45.9, 354884.1 6690257.4 45.9, 354878.6 6690268.7 45.9, 354874.3 6690266.6 45.9, 354870.6 6690275.6 45.9, 354878.9 6690280.6 45.9, 354880 6690281.4 45.9))
BATIMENT0000000302934575;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;10.3;33.0;43.3;46.2;34.4;Cadastre;C 0.6;POLYGON Z ((354905.6 6690274.4 43.3, 354898.3 6690286 43.3, 354908.4 6690292 43.3, 354915.6 6690280.6 43.3, 354909.7 6690276.9 43.3, 354905.6 6690274.4 43.3))
BATIMENT0000000302934481;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;34.0;39.4;43.2;34.4;Cadastre;;POLYGON Z ((354878.7 6690288 39.4, 354878.6 6690288.5 39.4, 354889.8 6690297.5 39.4, 354892.9 6690300.6 39.4, 354894.4 6690299.3 39.4, 354891.4 6690294.8 39.4, 354880.5 6690286.6 39.4, 354883.2 6690283.5 39.4, 354882.1 6690282.7 39.4, 354880 6690281.4 39.4, 354878.9 6690280.6 39.4, 354876 6690286.8 39.4, 354878.7 6690288 39.4))
BATIMENT0000000327820027;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:38:05;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;2.0;;;5.1;34.0;;40.9;34.4;Imagerie aérienne;C 0.3;POLYGON Z ((354882.1 6690282.7 39.1, 354883.2 6690283.5 39.1, 354880.5 6690286.6 39.1, 354891.4 6690294.8 39.1, 354894.4 6690299.3 39.1, 354896.9 6690303.1 39.1, 354902.1 6690296.7 39.1, 354883.9 6690280.5 39, 354882.1 6690282.7 39.1))
BATIMENT0000000302934483;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;34.0;37.0;38.1;34.3;Cadastre;;POLYGON Z ((354878 6690289.7 37, 354874.4 6690294.2 37, 354876.6 6690295.8 37, 354880.4 6690291.4 37, 354878 6690289.7 37))
BATIMENT0000000302934484;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;33.9;37.6;39.9;34.2;Cadastre;;POLYGON Z ((354880.3 6690298.6 37.6, 354883.3 6690300.6 37.6, 354885 6690301.8 37.6, 354887 6690303.6 37.6, 354890.2 6690299.9 37.6, 354880.4 6690291.4 37.6, 354876.6 6690295.8 37.6, 354880.3 6690298.6 37.6))
BATIMENT0000000327820021;Indifférenciée;Commercial et services;;Non;En service;2013-09-26 18:38:05;2019-03-15 08:35:34;2011-01-01;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;4.0;;;9.1;32.7;;45.1;33.7;Imagerie aérienne;C 0.2;POLYGON Z ((354918.2 6690308.4 41.8, 354925.6 6690297.8 41.8, 354935.9 6690285.5 41.8, 354922.2 6690277.2 41.8, 354908.5 6690299.9 41.8, 354902.1 6690311.9 41.8, 354906.5 6690317 41.8, 354908 6690319.2 41.8, 354910.3 6690322.5 41.8, 354918.2 6690308.4 41.8))
BATIMENT0000000302934490;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;6.1;34.0;40.1;41.9;34.2;Cadastre;B 0.3;POLYGON Z ((354883.3 6690300.6 40.1, 354880.3 6690298.6 40.1, 354871.5 6690311.8 40.1, 354875.7 6690315.4 40.1, 354879.2 6690318.1 40.1, 354880.8 6690319.4 40.1, 354882.7 6690316.5 40.1, 354883.2 6690316.8 40.1, 354884.8 6690316.5 40.1, 354886.2 6690314.5 40.1, 354886.1 6690312.5 40.1, 354883.9 6690311 40.1, 354886.2 6690307.3 40.1, 354887.5 6690308.2 40.1, 354889.3 6690305.6 40.1, 354887 6690303.6 40.1, 354885 6690301.8 40.1, 354883.3 6690300.6 40.1))
BATIMENT0000000302934700;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.9;34.5;42.4;43.0;35.6;Cadastre;;POLYGON Z ((354838.7 6690266.5 42.4, 354837.6 6690269 42.4, 354838.6 6690269.6 42.4, 354840 6690267.1 42.4, 354838.7 6690266.5 42.4))
BATIMENT0000000302934698;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;50;20;10.0;34.3;44.3;49.8;35.8;Cadastre;C 0.5;POLYGON Z ((354859.6 6690252.5 44.3, 354858.3 6690252 44.3, 354854.4 6690250.2 44.3, 354848.1 6690247.3 44.3, 354847 6690250.3 44.3, 354846.1 6690249.8 44.3, 354842 6690259.1 44.3, 354842.9 6690260 44.3, 354842 6690262.2 44.3, 354848 6690265.1 44.3, 354851.1 6690257.9 44.3, 354855 6690259.6 44.3, 354855.4 6690259.8 44.3, 354854.4 6690261.6 44.3, 354855.2 6690263.1 44.3, 354856.7 6690263.6 44.3, 354850.5 6690277.7 44.3, 354849.1 6690276.9 44.3, 354847.7 6690277.4 44.3, 354847.2 6690278.8 44.3, 354843.2 6690276.9 44.3, 354846.2 6690269.9 44.3, 354840 6690267.1 44.3, 354838.6 6690269.6 44.3, 354837.6 6690269 44.3, 354833.5 6690278.4 44.3, 354834.8 6690279.1 44.3, 354833.9 6690281.5 44.3, 354836.6 6690282.5 44.3, 354837.6 6690283 44.3, 354839.9 6690284.1 44.3, 354844.3 6690286.1 44.3, 354853.6 6690290.7 44.3, 354857.4 6690282.3 44.3, 354864 6690266 44.3, 354868.2 6690256 44.3, 354869.1 6690254 44.3, 354860.3 6690250.6 44.3, 354859.6 6690252.5 44.3))
BATIMENT0000000302934699;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;34.2;42.4;44.4;35.3;Cadastre;;POLYGON Z ((354832.4 6690281 42.4, 354833.9 6690281.5 42.4, 354834.8 6690279.1 42.4, 354833.5 6690278.4 42.4, 354832.4 6690281 42.4))
BATIMENT0000000302934482;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;20;20;11.2;34.1;45.3;48.7;34.3;Cadastre;C 0.2;POLYGON Z ((354876 6690286.8 45.3, 354878.9 6690280.6 45.3, 354870.6 6690275.6 45.3, 354865.3 6690287.8 45.3, 354873.1 6690293.2 45.3, 354876 6690286.8 45.3))
BATIMENT0000000302934485;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1810-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;14.5;33.9;48.5;51.7;34.2;Cadastre;A 1.0;POLYGON Z ((354873.9 6690293.9 48.5, 354873.1 6690293.2 48.5, 354865.3 6690287.8 48.5, 354858.9 6690301.5 48.5, 354867.4 6690308.3 48.5, 354868.3 6690306.3 48.5, 354873.9 6690293.9 48.5))
BATIMENT0000000302934696;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;34.5;38.3;42.3;35.0;Cadastre;;POLYGON Z ((354823.2 6690300.1 38.3, 354822.2 6690302.4 38.3, 354823 6690302.9 38.3, 354824.2 6690300.6 38.3, 354823.2 6690300.1 38.3))
BATIMENT0000000302934486;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;34.0;41.0;43.5;34.2;Cadastre;;POLYGON Z ((354870.7 6690311.2 41, 354871.8 6690309 41, 354868.3 6690306.3 41, 354867.4 6690308.3 41, 354870.7 6690311.2 41))
BATIMENT0000000302934695;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;34.3;41.0;41.7;34.9;Cadastre;;POLYGON Z ((354816.2 6690314.2 41, 354817.4 6690314.9 41, 354818.5 6690313 41, 354817.3 6690312.4 41, 354816.2 6690314.2 41))
BATIMENT0000000302934487;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.7;34.0;40.7;46.2;34.2;Cadastre;A 1.0;POLYGON Z ((354854.6 6690311.4 40.7, 354862 6690318 40.7, 354864.3 6690320 40.7, 354875.9 6690330.7 40.7, 354881.6 6690323.4 40.7, 354883.4 6690321.6 40.7, 354880.8 6690319.4 40.7, 354879.2 6690318.1 40.7, 354875.7 6690315.4 40.7, 354871.5 6690311.8 40.7, 354870.7 6690311.2 40.7, 354867.4 6690308.3 40.7, 354858.9 6690301.5 40.7, 354854.6 6690311.4 40.7))
BATIMENT0000000302934494;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;12.5;33.7;46.2;48.2;34.1;Cadastre;A 1.0;POLYGON Z ((354849 6690324.3 46.2, 354857.1 6690328 46.2, 354857.8 6690328 46.2, 354862 6690318 46.2, 354854.6 6690311.4 46.2, 354849 6690324.3 46.2))
BATIMENT0000000302944691;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.2;7.4;16.6;16.8;8.2;Cadastre;;POLYGON Z ((355494.6 6690099.6 16.6, 355495.6 6690098.5 16.6, 355494.5 6690097.3 16.6, 355493.4 6690098.4 16.6, 355494.6 6690099.6 16.6))
BATIMENT0000000302944693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;10;20;7.8;6.9;14.7;22.7;8.2;Cadastre;A 1.0;POLYGON Z ((355483.9 6690111.6 14.7, 355490.4 6690111.7 14.7, 355490.6 6690111.7 14.7, 355492.9 6690109.6 14.7, 355496 6690106.9 14.7, 355498.1 6690105.1 14.7, 355499.1 6690104.2 14.7, 355496.4 6690101.4 14.7, 355494.6 6690099.6 14.7, 355493.4 6690098.4 14.7, 355491.6 6690096.6 14.7, 355491.5 6690096.3 14.7, 355484 6690102.3 14.7, 355483.9 6690111.6 14.7), (355489.3 6690102.2 14.7, 355493.5 6690106.5 14.7, 355489.1 6690110.3 14.7, 355489.2 6690107.6 14.7, 355489.9 6690107.7 14.7, 355490 6690106.6 14.7, 355489.2 6690106.5 14.7, 355489.3 6690102.2 14.7))
BATIMENT0000000302944692;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;23;12.1;7.3;19.5;24.8;8.1;Cadastre;A 1.0;POLYGON Z ((355508 6690096.4 19.5, 355507.9 6690096.4 19.5, 355501.1 6690102.4 19.5, 355502.3 6690103.5 19.5, 355502.8 6690103 19.5, 355504 6690104.5 19.5, 355504.1 6690105.5 19.5, 355503 6690106.4 19.5, 355502.9 6690106.1 19.5, 355500.3 6690108.4 19.5, 355499.3 6690107.8 19.5, 355498.1 6690105.1 19.5, 355496 6690106.9 19.5, 355499.3 6690115.9 19.5, 355503.4 6690112.7 19.5, 355507.6 6690109.3 19.5, 355514.5 6690104 19.5, 355508 6690096.4 19.5))
BATIMENT0000000302944258;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.1;8.3;18.5;19.2;8.5;Cadastre;;POLYGON Z ((355551.4 6690115 18.5, 355552.2 6690115.6 18.5, 355555.6 6690110.5 18.5, 355554.6 6690109.8 18.5, 355551.4 6690115 18.5))
BATIMENT0000000302944695;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;10;20;8.3;9.4;17.7;;;Cadastre;A 1.0;POLYGON Z ((355514.5 6690104 17.7, 355507.6 6690109.3 17.7, 355510.5 6690112.7 17.7, 355506.4 6690115.6 17.7, 355506.7 6690117 17.7, 355505.8 6690117.6 17.7, 355503.4 6690112.7 17.7, 355499.3 6690115.9 17.7, 355502.2 6690124 17.7, 355502.5 6690124.5 17.7, 355506.8 6690121.4 17.7, 355509.7 6690119.3 17.7, 355512 6690117.8 17.7, 355520.9 6690111.4 17.7, 355514.5 6690104 17.7))
BATIMENT0000000302944694;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;6.0;6.9;13.0;20.0;7.7;Cadastre;A 1.0;POLYGON Z ((355483.7 6690123.8 13, 355491.9 6690123.9 13, 355494.3 6690123.9 13, 355502.2 6690124 13, 355499.3 6690115.9 13, 355496 6690106.9 13, 355492.9 6690109.6 13, 355497.4 6690122.1 13, 355497.8 6690121.9 13, 355498.2 6690122.8 13, 355496.8 6690122.9 13, 355496.7 6690122.6 13, 355496.3 6690122.5 13, 355496.1 6690121.7 13, 355494.3 6690121.8 13, 355494.2 6690121.3 13, 355491.9 6690121.2 13, 355492 6690114 13, 355490.5 6690114 13, 355490.4 6690111.7 13, 355483.9 6690111.6 13, 355483.7 6690123.8 13))
BATIMENT0000000302944697;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;12;30;10.4;7.8;18.3;20.6;8.2;Cadastre;A 1.0;POLYGON Z ((355520.9 6690111.4 18.3, 355512 6690117.8 18.3, 355521.4 6690128.8 18.3, 355529.7 6690121.6 18.3, 355520.9 6690111.4 18.3))
BATIMENT0000000302944711;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;7.3;13.2;16.6;8.3;Cadastre;;POLYGON Z ((355502.2 6690124 13.2, 355494.3 6690123.9 13.2, 355491.9 6690123.9 13.2, 355483.7 6690123.8 13.2, 355483.5 6690137.5 13.2, 355488.8 6690137.4 13.2, 355491.9 6690133.5 13.2, 355492.2 6690129.6 13.2, 355498.7 6690129.7 13.2, 355506.1 6690142 13.2, 355510.5 6690138.2 13.2, 355512.8 6690136.3 13.2, 355514.8 6690134.5 13.2, 355506.8 6690121.4 13.2, 355502.5 6690124.5 13.2, 355502.2 6690124 13.2))
BATIMENT0000000302944699;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;12;20;8.0;9.4;17.4;;;Cadastre;C 0.8;POLYGON Z ((355528.3 6690138.5 17.4, 355527.5 6690139.2 17.4, 355527.4 6690140.5 17.4, 355530.1 6690143.8 17.4, 355529.1 6690144.7 17.4, 355527.4 6690146.2 17.4, 355528.9 6690148.1 17.4, 355530.7 6690146.5 17.4, 355531.8 6690145.4 17.4, 355533.1 6690144.2 17.4, 355542.3 6690136.2 17.4, 355529.7 6690121.6 17.4, 355521.4 6690128.8 17.4, 355518.1 6690131.6 17.4, 355519.7 6690133.6 17.4, 355522.2 6690131.4 17.4, 355528.3 6690138.5 17.4))
BATIMENT0000000302944726;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;7.3;8.8;10.7;8.2;Cadastre;;POLYGON Z ((355494.3 6690144.3 8.8, 355496.3 6690142.6 8.8, 355494.2 6690140.3 8.8, 355492.3 6690142 8.8, 355494.3 6690144.3 8.8))
BATIMENT0000000302944654;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;13.9;7.7;21.7;24.0;9.3;Cadastre;A 1.0;POLYGON Z ((355471.3 6690144.7 21.7, 355462.2 6690140.1 21.7, 355454.3 6690154.8 21.7, 355455.1 6690155.2 21.7, 355460.4 6690158 21.7, 355462.5 6690159.2 21.7, 355471.2 6690156.1 21.7, 355471.3 6690144.7 21.7))
BATIMENT0000000302944657;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;12.6;17.2;20.0;13.1;Cadastre;;POLYGON Z ((355406.6 6690152.6 17.2, 355408.6 6690153.6 17.2, 355411.5 6690147.9 17.2, 355410.2 6690146.8 17.2, 355409 6690149.2 17.2, 355408.5 6690148.9 17.2, 355406.6 6690152.6 17.2))
BATIMENT0000000302944658;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;4.7;12.5;17.2;18.7;13.1;Cadastre;C 0.3;POLYGON Z ((355415.9 6690150 17.2, 355411.5 6690147.9 17.2, 355408.6 6690153.6 17.2, 355412.9 6690155.8 17.2, 355415.9 6690150 17.2))
BATIMENT0000000302944660;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;1.6;9.4;11.0;16.4;10.6;Cadastre;C 0.3;POLYGON Z ((355442.2 6690148.2 11, 355438.2 6690155.7 11, 355442 6690157.8 11, 355446 6690150.3 11, 355442.2 6690148.2 11))
BATIMENT0000000302944669;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;7.4;10.6;18.0;18.9;12.8;Cadastre;C 0.4;POLYGON Z ((355415.9 6690150 18, 355412.9 6690155.8 18, 355425.6 6690162.2 18, 355428.7 6690156.4 18, 355415.9 6690150 18))
BATIMENT0000000302944655;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;9.8;11.6;21.5;29.4;14.3;Cadastre;C 0.6;POLYGON Z ((355392.9 6690155.1 21.5, 355401.7 6690159.6 21.5, 355410.4 6690164.2 21.5, 355416.7 6690167.5 21.5, 355419.4 6690162.6 21.5, 355406.9 6690155.7 21.5, 355406.3 6690156.6 21.5, 355403.1 6690155.1 21.5, 355403.7 6690153.8 21.5, 355402.3 6690153.2 21.5, 355403.4 6690151.2 21.5, 355396.8 6690147.5 21.5, 355392.9 6690155.1 21.5))
BATIMENT0000000302944662;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.3;8.1;17.5;20.5;9.3;Cadastre;;POLYGON Z ((355460.4 6690158 17.5, 355455.1 6690155.2 17.5, 355454.1 6690157 17.5, 355459.4 6690159.9 17.5, 355460.4 6690158 17.5))
BATIMENT0000000302944661;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.0;7.9;14.0;18.7;9.2;Cadastre;A 1.0;POLYGON Z ((355471.1 6690160.3 14, 355471.2 6690156.1 14, 355462.5 6690159.2 14, 355460.4 6690158 14, 355459.4 6690159.9 14, 355460 6690160.2 14, 355455.2 6690165.4 14, 355455.7 6690165.9 14, 355456.5 6690167.6 14, 355457.4 6690167.4 14, 355461.8 6690170.2 14, 355462 6690170.1 14, 355471.1 6690160.3 14))
BATIMENT0000000302944823;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.7;9.5;12.2;14.5;10.6;Cadastre;;POLYGON Z ((355435.6 6690166.8 12.2, 355440.2 6690169.2 12.2, 355440.7 6690168.3 12.2, 355439.9 6690167.9 12.2, 355440.5 6690166.7 12.2, 355439.8 6690164.9 12.2, 355442.5 6690160.5 12.2, 355439.8 6690158.9 12.2, 355435.6 6690166.8 12.2))
BATIMENT0000000302944677;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1964-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;3.4;10.0;13.5;17.5;10.8;Cadastre;C 0.4;POLYGON Z ((355425.3 6690164.1 13.5, 355429.1 6690165.9 13.5, 355429.9 6690164.4 13.5, 355426.1 6690162.5 13.5, 355425.3 6690164.1 13.5))
BATIMENT0000000302944703;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;12;20;13.6;7.8;21.5;27.5;8.2;Cadastre;A 1.0;POLYGON Z ((355542.3 6690136.2 21.5, 355533.1 6690144.2 21.5, 355535.1 6690146.5 21.5, 355532.5 6690148.8 21.5, 355531.4 6690147.5 21.5, 355532.6 6690146.4 21.5, 355531.8 6690145.4 21.5, 355530.7 6690146.5 21.5, 355528.9 6690148.1 21.5, 355527.3 6690149.6 21.5, 355530.4 6690153.3 21.5, 355545.6 6690140.1 21.5, 355542.3 6690136.2 21.5))
BATIMENT0000000302944723;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;7.7;7.4;15.2;20.0;8.7;Cadastre;A 1.0;POLYGON Z ((355483.4 6690144.4 15.2, 355492.6 6690153.7 15.2, 355494.3 6690152.3 15.2, 355496.1 6690150.7 15.2, 355492.2 6690146.3 15.2, 355487.8 6690141.5 15.2, 355488.5 6690140.8 15.2, 355488.8 6690137.4 15.2, 355483.5 6690137.5 15.2, 355483.4 6690144.4 15.2))
BATIMENT0000000302944712;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;7.4;10.0;14.6;8.7;Cadastre;C 0.5;POLYGON Z ((355496.1 6690150.7 10, 355500.3 6690147.1 10, 355496.3 6690142.6 10, 355494.3 6690144.3 10, 355492.2 6690146.3 10, 355496.1 6690150.7 10))
BATIMENT0000000302944700;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;14.7;7.7;22.5;28.2;8.2;Cadastre;A 1.0;POLYGON Z ((355545.6 6690140.1 22.5, 355530.4 6690153.3 22.5, 355533.4 6690156.7 22.5, 355539.7 6690151.1 22.5, 355544.8 6690157 22.5, 355545.3 6690156.8 22.5, 355545.3 6690156.4 22.5, 355553.6 6690149.3 22.5, 355545.6 6690140.1 22.5))
BATIMENT0000000302944725;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;12.4;7.5;20.0;23.6;8.7;Cadastre;A 1.0;POLYGON Z ((355483.2 6690156 20, 355486.3 6690159.2 20, 355492.6 6690153.7 20, 355483.4 6690144.4 20, 355483.2 6690156 20))
BATIMENT0000000302944701;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.2;7.9;11.1;14.5;8.6;Cadastre;C 0.4;POLYGON Z ((355500.3 6690147.1 11.1, 355513 6690162 11.1, 355518 6690157.8 11.1, 355505.1 6690142.9 11.1, 355500.3 6690147.1 11.1))
BATIMENT0000000302944698;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;36;20;4.2;7.9;12.1;16.5;8.6;Cadastre;C 0.5;POLYGON Z ((355506.1 6690142 12.1, 355505.1 6690142.9 12.1, 355518 6690157.8 12.1, 355523.7 6690164.3 12.1, 355529.2 6690170.6 12.1, 355532.3 6690167.9 12.1, 355538.5 6690162.6 12.1, 355533.4 6690156.7 12.1, 355530.4 6690153.3 12.1, 355527.3 6690149.6 12.1, 355519.6 6690156.2 12.1, 355512.9 6690148.3 12.1, 355518.8 6690143.3 12.1, 355512.8 6690136.3 12.1, 355510.5 6690138.2 12.1, 355506.1 6690142 12.1))
BATIMENT0000000302944724;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;29;13.2;7.7;21.0;23.6;8.8;Cadastre;C 0.8;POLYGON Z ((355499.5 6690173.3 21, 355507.1 6690167.1 21, 355494.3 6690152.3 21, 355492.6 6690153.7 21, 355486.3 6690159.2 21, 355499.5 6690173.3 21))
BATIMENT0000000302944704;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;10;20;12.7;7.7;20.5;26.5;8.5;Cadastre;C 0.6;POLYGON Z ((355553.6 6690149.3 20.5, 355545.3 6690156.4 20.5, 355545.3 6690156.8 20.5, 355548 6690159.9 20.5, 355549.5 6690161.5 20.5, 355548.8 6690161.3 20.5, 355548.3 6690161.9 20.5, 355547.8 6690162.4 20.5, 355547.7 6690163.1 20.5, 355547.8 6690163.6 20.5, 355549.2 6690165.2 20.5, 355550 6690165.4 20.5, 355550.5 6690165.3 20.5, 355551.8 6690164.3 20.5, 355554.1 6690166.8 20.5, 355541 6690178 20.5, 355544.3 6690181.7 20.5, 355544.7 6690181.4 20.5, 355554.7 6690172.8 20.5, 355556.2 6690171.5 20.5, 355565.6 6690163.3 20.5, 355553.6 6690149.3 20.5))
BATIMENT0000000302944714;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.1;7.6;9.7;12.5;8.3;Cadastre;C 0.4;POLYGON Z ((355535.2 6690171.2 9.7, 355541.4 6690165.7 9.7, 355538.6 6690162.5 9.7, 355538.5 6690162.6 9.7, 355532.3 6690167.9 9.7, 355535.2 6690171.2 9.7))
BATIMENT0000000302944544;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;7.9;10.7;16.2;8.8;Cadastre;;POLYGON Z ((355475.7 6690170.5 10.7, 355477.7 6690170.4 10.7, 355479.6 6690167.4 10.7, 355473.8 6690167.5 10.7, 355475.7 6690170.5 10.7))
BATIMENT0000000302944722;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1857-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.2;8.1;18.4;20.9;8.5;Cadastre;A 1.0;POLYGON Z ((355505.4 6690179.5 18.4, 355513 6690173.2 18.4, 355507.1 6690167.1 18.4, 355499.5 6690173.3 18.4, 355505.4 6690179.5 18.4))
BATIMENT0000000302944737;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;7.7;11.7;15.2;8.4;Cadastre;;POLYGON Z ((355536.4 6690174.4 11.7, 355538.2 6690176.6 11.7, 355539.1 6690175.7 11.7, 355537.2 6690173.6 11.7, 355536.4 6690174.4 11.7))
BATIMENT0000000302944705;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1883-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;15.3;7.5;22.9;26.6;8.3;Cadastre;C 0.8;POLYGON Z ((355565.6 6690163.3 22.9, 355556.2 6690171.5 22.9, 355570.9 6690188.6 22.9, 355571.2 6690188.4 22.9, 355572.9 6690186.9 22.9, 355580.4 6690180.5 22.9, 355565.6 6690163.3 22.9))
BATIMENT0000000302944709;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;23;10.0;8.2;18.2;19.7;8.6;Cadastre;A 1.0;POLYGON Z ((355511.4 6690185.9 18.2, 355518.9 6690179.4 18.2, 355513 6690173.2 18.2, 355505.4 6690179.5 18.2, 355511.4 6690185.9 18.2))
BATIMENT0000000302944713;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;00;00;5.1;8.0;13.2;17.7;8.8;Cadastre;C 0.5;POLYGON Z ((355543.4 6690192 13.2, 355559 6690178.5 13.2, 355559 6690177.8 13.2, 355557.7 6690176.3 13.2, 355557.6 6690175.4 13.2, 355556.4 6690174 13.2, 355556.1 6690174.4 13.2, 355554.7 6690172.8 13.2, 355544.7 6690181.4 13.2, 355546.4 6690183.3 13.2, 355545.3 6690184.5 13.2, 355543.5 6690182.4 13.2, 355537.8 6690187.4 13.2, 355543.4 6690192 13.2))
BATIMENT0000000302944707;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1977-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;7.9;9.3;17.2;;;Cadastre;C 0.5;POLYGON Z ((355537.8 6690187.4 17.2, 355543.5 6690182.4 17.2, 355544.3 6690181.7 17.2, 355541 6690178 17.2, 355534.1 6690184.2 17.2, 355537.2 6690187.8 17.2, 355537.8 6690187.4 17.2))
BATIMENT0000000302944545;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;103.0;4.0;00;00;10.2;7.9;18.1;20.4;10.2;Cadastre;A 1.0;POLYGON Z ((355464.7 6690196.1 18.1, 355467.4 6690198.4 18.1, 355469.5 6690196.2 18.1, 355477 6690188.4 18.1, 355487.7 6690198.4 18.1, 355498.6 6690187.2 18.1, 355488.9 6690177 18.1, 355479.6 6690167.4 18.1, 355477.7 6690170.4 18.1, 355475.7 6690170.5 18.1, 355473.8 6690167.5 18.1, 355455.6 6690188.6 18.1, 355464.7 6690196.1 18.1))
BATIMENT0000000302944702;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;5.4;7.8;13.2;19.4;9.1;Cadastre;C 0.7;POLYGON Z ((355524 6690199.2 13.2, 355531.4 6690192.8 13.2, 355529.1 6690190.3 13.2, 355527.9 6690189 13.2, 355524.2 6690185.1 13.2, 355526.1 6690183.4 13.2, 355524 6690181 13.2, 355528.5 6690177 13.2, 355529.6 6690178.1 13.2, 355532.1 6690175.9 13.2, 355531.2 6690174.7 13.2, 355535.2 6690171.2 13.2, 355532.3 6690167.9 13.2, 355529.2 6690170.6 13.2, 355518.9 6690179.4 13.2, 355511.4 6690185.9 13.2, 355524 6690199.2 13.2))
BATIMENT0000000302944706;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;8.1;13.0;13.7;8.8;Cadastre;;POLYGON Z ((355529.1 6690190.3 13, 355530.4 6690189.1 13, 355529.2 6690187.8 13, 355527.9 6690189 13, 355529.1 6690190.3 13))
BATIMENT0000000302944380;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.5;14.3;17.9;24.2;15.5;Cadastre;C 0.3;POLYGON Z ((355357.4 6690144.8 17.9, 355360.4 6690139.8 17.9, 355355.5 6690137.2 17.9, 355346.3 6690132.5 17.9, 355343.4 6690137.6 17.9, 355357.4 6690144.8 17.9))
BATIMENT0000000302944381;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;35;90;15.9;13.8;29.8;31.6;15.2;Cadastre;C 0.8;POLYGON Z ((355350.8 6690171.4 29.8, 355354.6 6690173.6 29.8, 355359.4 6690176 29.8, 355374.2 6690146.9 29.8, 355365.7 6690142.6 29.8, 355350.8 6690171.4 29.8))
BATIMENT0000000302944667;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;50;20;11.7;13.4;25.2;27.9;14.3;Cadastre;C 0.8;POLYGON Z ((355386.7 6690167.3 25.2, 355392.5 6690169.8 25.2, 355393.8 6690167.3 25.2, 355396.8 6690168.9 25.2, 355401.7 6690159.6 25.2, 355392.9 6690155.1 25.2, 355386.7 6690167.3 25.2))
BATIMENT0000000302944666;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;9.4;11.2;20.7;25.1;14.6;Cadastre;A 1.0;POLYGON Z ((355394.7 6690177.5 20.7, 355405.2 6690183.5 20.7, 355404.2 6690185.6 20.7, 355418.1 6690191.7 20.7, 355421.8 6690181.4 20.7, 355418.2 6690179.5 20.7, 355416.2 6690184.7 20.7, 355414.5 6690184 20.7, 355414.2 6690184.7 20.7, 355407.6 6690181.7 20.7, 355406.6 6690181.4 20.7, 355407.1 6690180.4 20.7, 355408.4 6690178.2 20.7, 355392.5 6690169.8 20.7, 355386.7 6690167.3 20.7, 355384.4 6690171.7 20.7, 355394.7 6690177.5 20.7))
BATIMENT0000000302944672;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;9.5;14.1;23.6;25.9;15.0;Cadastre;A 1.0;POLYGON Z ((355389.4 6690188.2 23.6, 355394.7 6690177.5 23.6, 355384.4 6690171.7 23.6, 355378.4 6690183.5 23.6, 355389.4 6690188.2 23.6))
BATIMENT0000000302944671;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.8;13.8;22.7;31.6;15.1;Cadastre;C 0.2;POLYGON Z ((355372.7 6690194.6 22.7, 355378.2 6690197.1 22.7, 355382.1 6690189.4 22.7, 355393.9 6690194.6 22.7, 355390.4 6690202.5 22.7, 355403.1 6690208.1 22.7, 355408.2 6690196.3 22.7, 355401.3 6690193.3 22.7, 355400.6 6690193 22.7, 355389.4 6690188.2 22.7, 355378.4 6690183.5 22.7, 355372.7 6690194.6 22.7))
BATIMENT0000000302944610;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;19;20;11.9;14.7;26.7;29.2;16.2;Cadastre;A 1.0;POLYGON Z ((355379.3 6690209.8 26.7, 355367.8 6690204.6 26.7, 355362.9 6690214.3 26.7, 355374.8 6690219.3 26.7, 355375.7 6690217.8 26.7, 355379.3 6690209.8 26.7))
BATIMENT0000000302944820;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;10.6;14.3;24.9;30.2;16.7;Cadastre;B 0.4;POLYGON Z ((355378.5 6690213.7 24.9, 355385.6 6690217.1 24.9, 355388.3 6690212 24.9, 355381 6690208.8 24.9, 355378.5 6690213.7 24.9))
BATIMENT0000000302944608;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;15.9;19.7;23.5;16.3;Cadastre;;POLYGON Z ((355377.1 6690220.2 19.7, 355377.8 6690218.8 19.7, 355375.7 6690217.8 19.7, 355374.8 6690219.3 19.7, 355377.1 6690220.2 19.7))
BATIMENT0000000302944609;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;7.7;15.4;23.1;26.5;16.6;Cadastre;A 1.0;POLYGON Z ((355356.5 6690227 23.1, 355365.3 6690231.5 23.1, 355366.3 6690229.4 23.1, 355363.8 6690228.1 23.1, 355367.5 6690220.4 23.1, 355368.7 6690220.8 23.1, 355367.5 6690224.6 23.1, 355374.4 6690227.7 23.1, 355376.4 6690222.9 23.1, 355373.7 6690221.4 23.1, 355374.8 6690219.3 23.1, 355362.9 6690214.3 23.1, 355356.5 6690227 23.1))
BATIMENT0000000302944676;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;9.8;13.9;;;Cadastre;;POLYGON Z ((355428.4 6690167.4 13.9, 355432.5 6690169.5 13.9, 355434 6690166.5 13.9, 355429.9 6690164.4 13.9, 355429.1 6690165.9 13.9, 355428.4 6690167.4 13.9))
BATIMENT0000000302944663;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;5.4;10.1;15.5;;;Cadastre;A 1.0;POLYGON Z ((355462.3 6690170.5 15.5, 355462 6690170.1 15.5, 355461.8 6690170.2 15.5, 355457.4 6690167.4 15.5, 355456.5 6690167.6 15.5, 355455.7 6690165.9 15.5, 355455.2 6690165.4 15.5, 355454.2 6690164.6 15.5, 355451.9 6690167 15.5, 355452.2 6690167.3 15.5, 355451.2 6690168.7 15.5, 355450.8 6690168.7 15.5, 355450.7 6690169.3 15.5, 355450.9 6690169.4 15.5, 355451.3 6690169.5 15.5, 355451.6 6690169.2 15.5, 355451.7 6690168.9 15.5, 355458.8 6690174.6 15.5, 355462.3 6690170.5 15.5))
BATIMENT0000000302944668;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;90;6.2;9.8;16.0;18.5;12.2;Cadastre;C 0.3;POLYGON Z ((355421.7 6690163.9 16, 355420 6690167.3 16, 355418.8 6690166.7 16, 355418.1 6690168.2 16, 355425.2 6690171.9 16, 355436.9 6690178 16, 355439.4 6690173.2 16, 355432.5 6690169.5 16, 355428.4 6690167.4 16, 355421.7 6690163.9 16))
BATIMENT0000000302944665;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;6.5;9.8;16.3;18.5;14.3;Cadastre;C 0.3;POLYGON Z ((355410.4 6690164.2 16.3, 355407.7 6690169.4 16.3, 355417.2 6690174.3 16.3, 355415.2 6690178.2 16.3, 355418.2 6690179.5 16.3, 355421.8 6690181.4 16.3, 355425.2 6690171.9 16.3, 355418.1 6690168.2 16.3, 355416.7 6690167.5 16.3, 355410.4 6690164.2 16.3))
BATIMENT0000000302944664;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;6.6;9.1;15.7;17.1;9.9;Cadastre;A 1.0;POLYGON Z ((355458.8 6690174.6 15.7, 355451.7 6690168.9 15.7, 355451.6 6690169.2 15.7, 355451.3 6690169.5 15.7, 355450.9 6690169.4 15.7, 355449.4 6690171.6 15.7, 355449.3 6690171.3 15.7, 355448.8 6690171.1 15.7, 355448.6 6690171.5 15.7, 355447.4 6690173.3 15.7, 355448.7 6690173.9 15.7, 355454.9 6690179.2 15.7, 355458.8 6690174.6 15.7))
BATIMENT0000000302944673;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;10;9.2;9.5;18.7;20.2;10.4;Cadastre;A 1.0;POLYGON Z ((355454.9 6690179.2 18.7, 355448.7 6690173.9 18.7, 355444.5 6690182 18.7, 355450 6690184.9 18.7, 355454.9 6690179.2 18.7))
BATIMENT0000000302944674;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;3.0;50;20;9.5;10.1;19.7;22.5;11.7;Cadastre;A 1.0;POLYGON Z ((355429 6690189.1 19.7, 355429.6 6690189.5 19.7, 355426.7 6690195.5 19.7, 355437 6690200.1 19.7, 355450 6690184.9 19.7, 355444.5 6690182 19.7, 355438.1 6690178.6 19.7, 355432.4 6690185.5 19.7, 355432.1 6690185.2 19.7, 355429 6690189.1 19.7))
BATIMENT0000000302944670;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;10.3;11.2;21.5;25.2;14.7;Cadastre;A 1.0;POLYGON Z ((355418.6 6690192 21.5, 355418.1 6690191.7 21.5, 355404.2 6690185.6 21.5, 355400.6 6690193 21.5, 355401.3 6690193.3 21.5, 355408.2 6690196.3 21.5, 355414.9 6690199.2 21.5, 355418.6 6690192 21.5))
BATIMENT0000000302944675;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;00;00;9.2;11.1;20.4;23.0;12.4;Cadastre;A 1.0;POLYGON Z ((355422 6690193.4 20.4, 355422 6690193.5 20.4, 355418.7 6690200.9 20.4, 355423.6 6690203.1 20.4, 355424 6690203.2 20.4, 355428.4 6690205.1 20.4, 355431.6 6690206.5 20.4, 355437 6690200.1 20.4, 355426.7 6690195.5 20.4, 355422 6690193.4 20.4))
BATIMENT0000000302944679;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.7;9.8;18.5;22.0;12.8;Cadastre;;POLYGON Z ((355428.4 6690205.1 18.5, 355424 6690203.2 18.5, 355423.6 6690203.1 18.5, 355422 6690206.7 18.5, 355426.8 6690208.7 18.5, 355428.4 6690205.1 18.5))
BATIMENT0000000302944546;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.5;7.9;20.4;21.4;8.9;Cadastre;;POLYGON Z ((355489.4 6690200 20.4, 355500.1 6690188.7 20.4, 355498.6 6690187.2 20.4, 355487.7 6690198.4 20.4, 355489.4 6690200 20.4))
BATIMENT0000000302944719;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.3;8.1;9.5;13.2;8.5;Cadastre;;POLYGON Z ((355565.4 6690193.3 9.5, 355569.4 6690197.7 9.5, 355571.5 6690195.8 9.5, 355567.6 6690191.4 9.5, 355565.4 6690193.3 9.5))
BATIMENT0000000302944555;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.9;7.9;20.8;21.4;8.9;Cadastre;;POLYGON Z ((355490 6690200.6 20.8, 355500.7 6690189.4 20.8, 355500.1 6690188.7 20.8, 355489.4 6690200 20.8, 355490 6690200.6 20.8))
BATIMENT0000000302944710;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;00;00;6.6;8.3;15.0;17.4;8.8;Cadastre;C 0.5;POLYGON Z ((355555 6690201.2 15, 355560.3 6690205.5 15, 355563.8 6690201.5 15, 355565.2 6690199.8 15, 355562 6690196.2 15, 355565.4 6690193.3 15, 355567.6 6690191.4 15, 355569.2 6690190 15, 355566.6 6690186.9 15, 355560.5 6690192.1 15, 355561.2 6690192.9 15, 355560.2 6690193.8 15, 355558.3 6690191.6 15, 355557.8 6690191.5 15, 355554.9 6690194.6 15, 355554 6690193.8 15, 355553 6690193.8 15, 355551.1 6690195.8 15, 355551.3 6690196.7 15, 355552.3 6690197.6 15, 355551.6 6690198.5 15, 355555 6690201.2 15))
BATIMENT0000000302944720;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.0;8.0;13.0;14.7;8.6;Cadastre;C 0.4;POLYGON Z ((355572.9 6690201.8 13, 355569.4 6690197.7 13, 355565.4 6690193.3 13, 355562 6690196.2 13, 355565.2 6690199.8 13, 355569.1 6690204.2 13, 355569.6 6690204.7 13, 355572.9 6690201.8 13))
BATIMENT0000000302944708;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;2.0;15;20;4.1;8.6;12.8;18.0;9.4;Cadastre;A 1.0;POLYGON Z ((355531.4 6690192.8 12.8, 355524 6690199.2 12.8, 355540.8 6690217.1 12.8, 355547.5 6690210.8 12.8, 355551.8 6690205.3 12.8, 355555 6690201.2 12.8, 355551.6 6690198.5 12.8, 355543.4 6690192 12.8, 355537.8 6690187.4 12.8, 355537.2 6690187.8 12.8, 355531.4 6690192.8 12.8), (355532.1 6690196.3 12.8, 355534 6690198.5 12.8, 355535.7 6690196.5 12.8, 355541 6690200.8 12.8, 355542 6690199.8 12.8, 355544.9 6690201.8 12.8, 355548.4 6690198.1 12.8, 355551 6690200.3 12.8, 355542.2 6690210.4 12.8, 355530.3 6690197.9 12.8, 355532.1 6690196.3 12.8))
BATIMENT0000000302944721;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;8.2;14.2;15.0;8.6;Cadastre;;POLYGON Z ((355563.8 6690201.5 14.2, 355567.5 6690205.8 14.2, 355569.1 6690204.2 14.2, 355565.2 6690199.8 14.2, 355563.8 6690201.5 14.2))
BATIMENT0000000302944716;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;7.7;8.5;16.2;19.9;9.0;Cadastre;A 1.0;POLYGON Z ((355551.8 6690205.3 16.2, 355554.5 6690207.3 16.2, 355553.5 6690208.7 16.2, 355556 6690210.8 16.2, 355560.3 6690205.5 16.2, 355555 6690201.2 16.2, 355551.8 6690205.3 16.2))
BATIMENT0000000302944547;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:07;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;;;12.9;7.9;20.8;21.9;10.6;Cadastre;A 0.8;POLYGON Z ((355502.5 6690234.1 20.8, 355503.2 6690233.4 20.8, 355512.2 6690224 20.8, 355515.8 6690220.2 20.8, 355516.2 6690219.9 20.8, 355516.7 6690220.2 20.8, 355523.4 6690213.4 20.8, 355506.9 6690195.9 20.8, 355500.7 6690189.4 20.8, 355490 6690200.6 20.8, 355482.9 6690208 20.8, 355468.2 6690223.4 20.8, 355468.8 6690223.9 20.8, 355465.9 6690226.9 20.8, 355469.9 6690230.8 20.8, 355470.6 6690231.4 20.8, 355472.1 6690230 20.8, 355477.5 6690235.3 20.8, 355478.9 6690233.8 20.8, 355484.1 6690239 20.8, 355491.3 6690231.6 20.8, 355493.7 6690233.7 20.8, 355498.7 6690238.2 20.8, 355502.5 6690234.1 20.8))
BATIMENT0000000302944715;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;5.8;8.6;14.5;19.4;9.3;Cadastre;A 1.0;POLYGON Z ((355545.2 6690221.7 14.5, 355551.8 6690215.7 14.5, 355552 6690215.5 14.5, 355556 6690210.8 14.5, 355553.5 6690208.7 14.5, 355549.7 6690213.1 14.5, 355547.5 6690210.8 14.5, 355540.8 6690217.1 14.5, 355545.2 6690221.7 14.5))
BATIMENT0000000302944606;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;16.0;19.7;26.5;17.2;Cadastre;;POLYGON Z ((355377.4 6690220.4 19.7, 355376.6 6690222 19.7, 355386.5 6690226.5 19.7, 355387.3 6690224.8 19.7, 355377.4 6690220.4 19.7))
BATIMENT0000000302944383;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.8;15.3;31.2;35.2;23.1;Cadastre;C 0.3;POLYGON Z ((355314.9 6690263.5 31.2, 355313.1 6690262.5 31.2, 355314.2 6690260.4 31.2, 355316 6690261.3 31.2, 355325.1 6690243.5 31.2, 355323.3 6690242.6 31.2, 355324.1 6690240.9 31.2, 355325.9 6690241.8 31.2, 355329.5 6690234.9 31.2, 355325.1 6690232.6 31.2, 355329.4 6690224.2 31.2, 355325.4 6690219.5 31.2, 355326.6 6690217.1 31.2, 355315.8 6690211.5 31.2, 355322.3 6690199 31.2, 355336.3 6690206.2 31.2, 355336.6 6690206 31.2, 355336.8 6690205.8 31.2, 355337.2 6690205.4 31.2, 355337.4 6690205.3 31.2, 355338 6690204.7 31.2, 355338.2 6690204.5 31.2, 355338.7 6690204 31.2, 355338.9 6690203.9 31.2, 355339 6690203.7 31.2, 355339.1 6690203.7 31.2, 355339.2 6690203.6 31.2, 355339.2 6690203.5 31.2, 355339.4 6690203.3 31.2, 355339.5 6690203.3 31.2, 355339.5 6690203.2 31.2, 355339.7 6690203 31.2, 355340.1 6690202.7 31.2, 355340.1 6690202.6 31.2, 355340.3 6690202.4 31.2, 355340.4 6690202.3 31.2, 355340.7 6690201.9 31.2, 355340.9 6690201.8 31.2, 355341 6690201.7 31.2, 355341.4 6690201.2 31.2, 355341.5 6690201.2 31.2, 355341.9 6690200.7 31.2, 355342 6690200.6 31.2, 355342.3 6690200.2 31.2, 355342.4 6690200.1 31.2, 355342.5 6690199.9 31.2, 355343 6690199.4 31.2, 355342.4 6690198.9 31.2, 355344.4 6690194.9 31.2, 355348.7 6690197.1 31.2, 355359.4 6690176 31.2, 355354.6 6690173.6 31.2, 355350.8 6690171.4 31.2, 355348.8 6690170.4 31.2, 355342.5 6690182.7 31.2, 355338.3 6690180.5 31.2, 355336.1 6690184.9 31.2, 355321.7 6690177.5 31.2, 355316.7 6690175.3 31.2, 355307.9 6690191.6 31.2, 355309.4 6690192.3 31.2, 355302.9 6690204.9 31.2, 355295.7 6690201.6 31.2, 355287.2 6690218.4 31.2, 355293.2 6690221.5 31.2, 355294.4 6690219.1 31.2, 355316.1 6690230.2 31.2, 355313.4 6690235.6 31.2, 355312.5 6690235.2 31.2, 355292.1 6690275 31.2, 355305.5 6690281.9 31.2, 355314.9 6690263.5 31.2))
BATIMENT0000000302944605;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;16.3;24.2;29.0;17.2;Cadastre;;POLYGON Z ((355386.1 6690227.5 24.2, 355387.2 6690228 24.2, 355388.6 6690225.5 24.2, 355387.3 6690224.8 24.2, 355386.5 6690226.5 24.2, 355386.1 6690227.5 24.2))
BATIMENT0000000302944607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;16.1;21.2;21.9;17.4;Cadastre;;POLYGON Z ((355383.7 6690226.4 21.2, 355381.1 6690232.3 21.2, 355383.1 6690233.2 21.2, 355383.8 6690231.9 21.2, 355386.1 6690227.5 21.2, 355383.7 6690226.4 21.2))
BATIMENT0000000302944611;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1826-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;20;20;10.0;15.7;25.7;27.7;16.7;Cadastre;A 1.0;POLYGON Z ((355349.4 6690240.9 25.7, 355358.2 6690245.3 25.7, 355365.3 6690231.5 25.7, 355356.5 6690227 25.7, 355349.4 6690240.9 25.7))
BATIMENT0000000302944802;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;12;5.6;16.9;22.5;25.2;19.0;Cadastre;A 1.0;POLYGON Z ((355398 6690247 22.5, 355405.7 6690251.1 22.5, 355409.3 6690243.3 22.5, 355401.5 6690239.7 22.5, 355398 6690247 22.5))
BATIMENT0000000302944612;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.5;15.9;25.5;27.8;16.8;Cadastre;A 1.0;POLYGON Z ((355343.4 6690252.8 25.5, 355352.1 6690257.4 25.5, 355353.2 6690255.3 25.5, 355358.2 6690245.3 25.5, 355349.4 6690240.9 25.5, 355343.4 6690252.8 25.5))
BATIMENT0000000302944822;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;16.5;19.7;21.7;19.0;Cadastre;;POLYGON Z ((355368.6 6690251.1 19.7, 355369.2 6690252.6 19.7, 355370.8 6690253.1 19.7, 355371.8 6690250.8 19.7, 355370.4 6690250.1 19.7, 355369.4 6690249.6 19.7, 355368.6 6690251.1 19.7))
BATIMENT0000000302944804;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;40;30;7.9;17.9;25.8;26.7;19.5;Cadastre;A 1.0;POLYGON Z ((355398 6690247 25.8, 355395 6690245.4 25.8, 355387.6 6690262.2 25.8, 355398.4 6690267.2 25.8, 355405.7 6690251.1 25.8, 355398 6690247 25.8))
BATIMENT0000000302944613;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;16.5;20.9;22.0;16.9;Cadastre;;POLYGON Z ((355354.3 6690258.7 20.9, 355354.9 6690257.4 20.9, 355354.6 6690256.1 20.9, 355353.2 6690255.3 20.9, 355352.1 6690257.4 20.9, 355354.2 6690258.6 20.9, 355354.3 6690258.7 20.9))
BATIMENT0000000302944728;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;3.6;7.8;11.5;15.7;8.5;Cadastre;C 0.4;POLYGON Z ((355562.4 6690223.4 11.5, 355566.7 6690227.1 11.5, 355566.5 6690227.3 11.5, 355567.1 6690227.8 11.5, 355578.1 6690214.7 11.5, 355577.7 6690214.2 11.5, 355573.9 6690209.8 11.5, 355564.8 6690220.6 11.5, 355562.4 6690223.4 11.5))
BATIMENT0000000302944550;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;20;20;15.9;8.8;24.7;26.9;9.2;Cadastre;B 0.9;POLYGON Z ((355518.4 6690222.7 24.7, 355524.1 6690228.7 24.7, 355525.9 6690230.4 24.7, 355533.1 6690224 24.7, 355523.4 6690213.4 24.7, 355516.7 6690220.2 24.7, 355516.2 6690219.9 24.7, 355515.8 6690220.2 24.7, 355518.4 6690222.7 24.7))
BATIMENT0000000302944729;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;8.1;8.3;16.5;22.9;9.2;Cadastre;A 1.0;POLYGON Z ((355554.7 6690231.8 16.5, 355562.4 6690223.4 16.5, 355564.8 6690220.6 16.5, 355562.5 6690218.4 16.5, 355560.9 6690219.8 16.5, 355557.4 6690216.2 16.5, 355554.8 6690218.5 16.5, 355552 6690215.5 16.5, 355551.8 6690215.7 16.5, 355545.2 6690221.7 16.5, 355554.7 6690231.8 16.5))
BATIMENT0000000302944732;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;2.0;10;20;7.7;7.9;15.7;24.0;8.8;Cadastre;A 1.0;POLYGON Z ((355565 6690242.7 15.7, 355570.6 6690237.7 15.7, 355569.9 6690237 15.7, 355570.1 6690236.8 15.7, 355566 6690232.6 15.7, 355566.9 6690231.3 15.7, 355564.9 6690229.3 15.7, 355566.2 6690227.9 15.7, 355566 6690227.8 15.7, 355566.5 6690227.3 15.7, 355566.7 6690227.1 15.7, 355562.4 6690223.4 15.7, 355554.7 6690231.8 15.7, 355565 6690242.7 15.7))
BATIMENT0000000302944549;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.7;9.1;14.9;16.2;11.7;Cadastre;B 0.5;POLYGON Z ((355509.8 6690242.2 14.9, 355510.1 6690242 14.9, 355520.4 6690232.2 14.9, 355512.2 6690224 14.9, 355503.2 6690233.4 14.9, 355502.5 6690234.1 14.9, 355509.8 6690242.2 14.9))
BATIMENT0000000302944551;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;25;20;6.8;9.0;15.8;26.0;13.1;Cadastre;A 1.0;POLYGON Z ((355524.1 6690228.7 15.8, 355523 6690229.6 15.8, 355520.4 6690232.2 15.8, 355510.1 6690242 15.8, 355509.8 6690242.2 15.8, 355505.3 6690246.6 15.8, 355506.2 6690247.6 15.8, 355506.8 6690248.4 15.8, 355508.4 6690250.6 15.8, 355510.6 6690253.3 15.8, 355513.3 6690256.1 15.8, 355527.8 6690244.3 15.8, 355541.6 6690232.9 15.8, 355533.1 6690224 15.8, 355525.9 6690230.4 15.8, 355524.1 6690228.7 15.8), (355527.2 6690232.1 15.8, 355531 6690236.4 15.8, 355525.4 6690241.7 15.8, 355521.5 6690237.3 15.8, 355527.2 6690232.1 15.8))
BATIMENT0000000302944557;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;10.2;15.6;15.9;12.6;Cadastre;;POLYGON Z ((355501 6690256.5 15.6, 355508.4 6690250.6 15.6, 355506.8 6690248.4 15.6, 355506.2 6690247.6 15.6, 355505.3 6690246.6 15.6, 355500 6690239.9 15.6, 355492.5 6690245.8 15.6, 355494.1 6690247.9 15.6, 355500.2 6690255.5 15.6, 355501 6690256.5 15.6))
BATIMENT0000000302944552;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;3.0;20;20;11.2;8.6;19.8;22.0;10.1;Cadastre;A 1.0;POLYGON Z ((355538 6690244.6 19.8, 355547.7 6690255.4 19.8, 355546.1 6690256.9 19.8, 355544.6 6690255.6 19.8, 355541.1 6690258.7 19.8, 355540.9 6690258.8 19.8, 355546.5 6690265.1 19.8, 355561 6690253.6 19.8, 355541.6 6690232.9 19.8, 355527.8 6690244.3 19.8, 355532.7 6690249.5 19.8, 355538 6690244.6 19.8))
BATIMENT0000000302944558;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.0;9.6;15.6;17.1;12.7;Cadastre;;POLYGON Z ((355500.2 6690255.5 15.6, 355494.1 6690247.9 15.6, 355484.9 6690255.6 15.6, 355490.8 6690262.9 15.6, 355500.2 6690255.5 15.6))
BATIMENT0000000302944554;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;3.0;25;20;8.4;7.9;16.3;20.7;13.1;Cadastre;A 1.0;POLYGON Z ((355543.3 6690267.7 16.3, 355536.5 6690258.5 16.3, 355534.7 6690258.3 16.3, 355526.7 6690264.6 16.3, 355522.1 6690258.8 16.3, 355533 6690250.1 16.3, 355532.7 6690249.5 16.3, 355527.8 6690244.3 16.3, 355513.3 6690256.1 16.3, 355530.4 6690278 16.3, 355543.3 6690267.7 16.3))
BATIMENT0000000302944678;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;12.0;17.5;20.2;12.8;Cadastre;;POLYGON Z ((355428.9 6690209.6 17.5, 355431.6 6690206.5 17.5, 355428.4 6690205.1 17.5, 355426.8 6690208.7 17.5, 355428.9 6690209.6 17.5))
BATIMENT0000000302944680;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;12.4;15.8;17.7;13.6;Cadastre;;POLYGON Z ((355417.6 6690210.2 15.8, 355418.7 6690214.9 15.8, 355425.7 6690213.4 15.8, 355427 6690211.9 15.8, 355424.6 6690209 15.8, 355424.2 6690208.7 15.8, 355417.6 6690210.2 15.8))
BATIMENT0000000302945699;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;2009-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.7;8.9;17.6;22.0;14.9;Cadastre;C 0.3;POLYGON Z ((355428.7 6690232.1 17.6, 355434.9 6690224.8 17.6, 355434.8 6690224.4 17.6, 355438.7 6690220.2 17.6, 355474.5 6690253.6 17.6, 355479.8 6690248.1 17.6, 355469.2 6690238.2 17.6, 355465.6 6690241.8 17.6, 355449.6 6690226.6 17.6, 355453.1 6690222.9 17.6, 355447.1 6690216.8 17.6, 355454.5 6690208.2 17.6, 355456.4 6690209.7 17.6, 355463.7 6690201 17.6, 355462 6690199.5 17.6, 355464.7 6690196.1 17.6, 355455.6 6690188.6 17.6, 355452.4 6690192.3 17.6, 355457.1 6690196.4 17.6, 355452.9 6690201.3 17.6, 355448.1 6690197.1 17.6, 355429.1 6690218.8 17.6, 355428.9 6690218.7 17.6, 355422 6690226.7 17.6, 355428.1 6690231.6 17.6, 355428.7 6690232.1 17.6))
BATIMENT0000000302944805;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;9.0;13.6;22.7;25.4;17.8;Cadastre;B 0.7;POLYGON Z ((355418 6690225.1 22.7, 355405.7 6690219.6 22.7, 355404 6690222.7 22.7, 355402.5 6690222.5 22.7, 355401.2 6690225.6 22.7, 355402.5 6690226.3 22.7, 355400.9 6690229.4 22.7, 355403.6 6690230.6 22.7, 355413.2 6690235 22.7, 355418 6690225.1 22.7))
BATIMENT0000000302944803;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;15.3;22.9;24.8;17.8;Cadastre;A 1.0;POLYGON Z ((355401.5 6690234.5 22.9, 355396.9 6690232.4 22.9, 355395.2 6690236.2 22.9, 355401.5 6690239.7 22.9, 355409.3 6690243.3 22.9, 355413.2 6690235 22.9, 355403.6 6690230.6 22.9, 355401.5 6690234.5 22.9))
BATIMENT0000000302945723;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;1978-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.9;14.4;28.4;39.7;22.4;Cadastre;C 0.3;POLYGON Z ((355375.8 6690333.9 28.4, 355393.3 6690312 28.4, 355396 6690314.1 28.4, 355399.8 6690309.9 28.4, 355410.8 6690318.4 28.4, 355410.9 6690319.8 28.4, 355407.4 6690324.1 28.4, 355417.9 6690332.6 28.4, 355418.9 6690331.8 28.4, 355438.5 6690347.5 28.4, 355440.8 6690345 28.4, 355443.4 6690347.4 28.4, 355505.1 6690298.3 28.4, 355499.7 6690291.9 28.4, 355474.9 6690311.4 28.4, 355466.7 6690317.8 28.4, 355466.7 6690318.2 28.4, 355449.1 6690331.7 28.4, 355428.2 6690314.9 28.4, 355429.7 6690313.2 28.4, 355429.9 6690311.6 28.4, 355428.8 6690309.9 28.4, 355427.4 6690311.4 28.4, 355425.3 6690310 28.4, 355426.6 6690307.6 28.4, 355425.7 6690307.3 28.4, 355425 6690307.3 28.4, 355423.9 6690307.5 28.4, 355421.8 6690309.8 28.4, 355403 6690295 28.4, 355407.9 6690287.6 28.4, 355408.4 6690287.6 28.4, 355414 6690279.1 28.4, 355408.5 6690275.5 28.4, 355409.3 6690273.9 28.4, 355407.9 6690273.3 28.4, 355425.6 6690235.8 28.4, 355426 6690236 28.4, 355428.1 6690231.6 28.4, 355422 6690226.7 28.4, 355394.5 6690285.5 28.4, 355386.1 6690302.8 28.4, 355377.7 6690314.4 28.4, 355367.1 6690305.9 28.4, 355356.8 6690318.7 28.4, 355375.8 6690333.9 28.4))
BATIMENT0000000302944814;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;17.1;22.1;22.7;21.1;Cadastre;;POLYGON Z ((355411.3 6690346.3 22.1, 355427.1 6690358.9 22.1, 355430 6690356.5 22.1, 355413.8 6690343.5 22.1, 355411.3 6690346.3 22.1))
BATIMENT0000000302945715;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;35;29;14.6;13.9;28.5;32.0;17.3;Cadastre;C 0.7;POLYGON Z ((355458.5 6690363.7 28.5, 355459.6 6690365.2 28.5, 355464.5 6690360.9 28.5, 355466.1 6690362.1 28.5, 355474 6690356.5 28.5, 355473.3 6690354.9 28.5, 355478.2 6690350.8 28.5, 355469.9 6690340.6 28.5, 355451.6 6690355.2 28.5, 355456.3 6690361.3 28.5, 355458.5 6690363.7 28.5))
BATIMENT0000000302944307;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;5.0;00;00;9.5;12.0;21.5;34.7;19.0;Cadastre;A 1.0;POLYGON Z ((355431.1 6690389.6 21.5, 355434.5 6690394.5 21.5, 355439.2 6690390.9 21.5, 355441.2 6690389.3 21.5, 355444.5 6690393.4 21.5, 355455.7 6690384.5 21.5, 355448.4 6690375.6 21.5, 355453.2 6690371.7 21.5, 355449.3 6690366.8 21.5, 355456.3 6690361.3 21.5, 355451.6 6690355.2 21.5, 355434.9 6690368.6 21.5, 355435.6 6690369.4 21.5, 355433.2 6690371.2 21.5, 355432.5 6690370.5 21.5, 355429.2 6690373.1 21.5, 355424.7 6690376.7 21.5, 355425.9 6690378.2 21.5, 355424 6690379.7 21.5, 355431.1 6690389.6 21.5))
BATIMENT0000000302944310;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;17.8;28.5;30.5;19.3;Cadastre;;POLYGON Z ((355425.9 6690378.2 28.5, 355424.7 6690376.7 28.5, 355422.9 6690378.2 28.5, 355424 6690379.7 28.5, 355425.9 6690378.2 28.5))
BATIMENT0000000302944741;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;27.7;34.0;36.9;27.9;Cadastre;;POLYGON Z ((355153.7 6690216.3 34, 355156.6 6690216.3 34, 355156.6 6690214.5 34, 355153.8 6690214.1 34, 355153.7 6690216.3 34))
BATIMENT0000000302944748;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;15;20;11.3;25.1;36.5;39.2;27.8;Cadastre;A 1.0;POLYGON Z ((355165.3 6690213.8 36.5, 355165.8 6690221.5 36.5, 355176.4 6690220.7 36.5, 355175.8 6690212.8 36.5, 355165.3 6690213.8 36.5))
BATIMENT0000000302944791;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;6.1;27.8;33.9;37.7;28.4;Cadastre;A 1.0;POLYGON Z ((355117.1 6690217.5 33.9, 355113.2 6690219 33.9, 355112.2 6690216.6 33.9, 355110.2 6690217.2 33.9, 355113.8 6690226.7 33.9, 355120 6690224.6 33.9, 355117.1 6690217.5 33.9))
BATIMENT0000000302944535;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;7.6;28.8;36.4;;;Cadastre;A 1.0;POLYGON Z ((355131.8 6690228.7 36.4, 355135.4 6690227.2 36.4, 355140.7 6690225.2 36.4, 355136.9 6690214.9 36.4, 355133.6 6690216.1 36.4, 355127.9 6690218.3 36.4, 355131.8 6690228.7 36.4))
BATIMENT0000000302944750;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;27.1;32.3;35.6;28.2;Cadastre;;POLYGON Z ((355151.4 6690222.1 32.3, 355152.9 6690227.1 32.3, 355153.4 6690226.9 32.3, 355154.3 6690228.6 32.3, 355156.2 6690227.6 32.3, 355156.4 6690222.3 32.3, 355156.3 6690220.5 32.3, 355151.4 6690222.1 32.3))
BATIMENT0000000302944531;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;13;6.4;28.8;35.2;;;Cadastre;C 0.8;POLYGON Z ((355136.6 6690230.5 35.2, 355137.2 6690230.6 35.2, 355137.5 6690231.7 35.2, 355133.6 6690233.3 35.2, 355136.8 6690241.8 35.2, 355145.5 6690238.5 35.2, 355144.1 6690235.3 35.2, 355145.7 6690234.7 35.2, 355141.9 6690224.7 35.2, 355140.7 6690225.2 35.2, 355135.4 6690227.2 35.2, 355136.6 6690230.5 35.2))
BATIMENT0000000302944792;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;4.3;27.9;32.2;35.9;28.8;Cadastre;A 1.0;POLYGON Z ((355120 6690224.6 32.2, 355113.8 6690226.7 32.2, 355111.1 6690227.8 32.2, 355113.5 6690234 32.2, 355109.4 6690235.5 32.2, 355112.3 6690243.2 32.2, 355117.2 6690241.2 32.2, 355125.1 6690238.2 32.2, 355120 6690224.6 32.2))
BATIMENT0000000302944534;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;28.8;31.9;;;Cadastre;;POLYGON Z ((355160.8 6690240.2 31.9, 355160.1 6690240.3 31.9, 355159 6690234.8 31.9, 355155.9 6690235.2 31.9, 355157.5 6690243.2 31.9, 355161.3 6690242.9 31.9, 355160.8 6690240.2 31.9))
BATIMENT0000000302944529;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;3.6;28.8;32.4;;;Cadastre;C 0.2;POLYGON Z ((355138.9 6690247.4 32.4, 355144 6690245.9 32.4, 355143.9 6690245.1 32.4, 355152.4 6690242.3 32.4, 355150.4 6690236.6 32.4, 355145.5 6690238.5 32.4, 355136.8 6690241.8 32.4, 355138.9 6690247.4 32.4))
BATIMENT0000000302944793;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;10;7.1;28.0;35.1;36.7;28.7;Cadastre;A 1.0;POLYGON Z ((355120.4 6690249.5 35.1, 355128.1 6690246.3 35.1, 355125.1 6690238.2 35.1, 355117.2 6690241.2 35.1, 355120.4 6690249.5 35.1))
BATIMENT0000000302944784;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.2;28.9;37.2;39.3;29.5;Cadastre;B 0.8;POLYGON Z ((355083.9 6690242.8 37.2, 355084.5 6690242.8 37.2, 355085.9 6690246.6 37.2, 355093.5 6690243.7 37.2, 355090.6 6690235.5 37.2, 355082.4 6690238.7 37.2, 355083.9 6690242.8 37.2))
BATIMENT0000000302944816;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;30.1;33.2;34.8;30.4;Cadastre;;POLYGON Z ((355049 6690238.3 33.2, 355051.5 6690245.1 33.2, 355053.8 6690244.2 33.2, 355051.2 6690237.5 33.2, 355049 6690238.3 33.2))
BATIMENT0000000302944768;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.5;29.7;37.2;40.5;30.1;Cadastre;A 1.0;POLYGON Z ((355069.3 6690246.1 37.2, 355066.1 6690247.5 37.2, 355067.2 6690250.5 37.2, 355075.4 6690247.2 37.2, 355072.2 6690238.8 37.2, 355067.2 6690240.8 37.2, 355069.3 6690246.1 37.2))
BATIMENT0000000302944688;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;09;3.9;30.0;33.9;;;Cadastre;B 0.4;POLYGON Z ((355091.9 6690248.6 33.9, 355086.2 6690250.7 33.9, 355087.7 6690254.9 33.9, 355093.6 6690252.7 33.9, 355091.9 6690248.6 33.9))
BATIMENT0000000302944767;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;29.7;37.0;40.3;30.2;Cadastre;A 1.0;POLYGON Z ((355066.7 6690250.7 37, 355068.3 6690254.9 37, 355066 6690255.8 37, 355067 6690258.4 37, 355070 6690257.1 37, 355077.9 6690254 37, 355075.4 6690247.2 37, 355067.2 6690250.5 37, 355066.7 6690250.7 37))
BATIMENT0000000302944687;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.3;30.0;34.3;;;Cadastre;A 1.0;POLYGON Z ((355091.1 6690264.1 34.3, 355099.5 6690260.9 34.3, 355096.1 6690251.6 34.3, 355093.6 6690252.7 34.3, 355087.7 6690254.9 34.3, 355091.1 6690264.1 34.3))
BATIMENT0000000302944777;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.5;30.9;33.4;;;Cadastre;B 0.2;POLYGON Z ((355043.1 6690259.8 33.4, 355044.1 6690262.2 33.4, 355046.6 6690261.4 33.4, 355047.8 6690263.9 33.4, 355056.8 6690259.8 33.4, 355054.8 6690254.9 33.4, 355043.1 6690259.8 33.4))
BATIMENT0000000302944764;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;6.1;29.7;35.8;38.5;30.1;Cadastre;A 0.9;POLYGON Z ((355073.5 6690266.5 35.8, 355081.6 6690263.4 35.8, 355077.9 6690254 35.8, 355070 6690257.1 35.8, 355073.5 6690266.5 35.8))
BATIMENT0000000302944778;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;01;2.2;30.9;33.1;;;Cadastre;A 0.4;POLYGON Z ((355057.5 6690261.4 33.1, 355058.7 6690264.3 33.1, 355060.6 6690263.6 33.1, 355059.4 6690260.6 33.1, 355057.5 6690261.4 33.1))
BATIMENT0000000302944819;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.9;29.0;34.0;36.4;29.5;Cadastre;;POLYGON Z ((355111.4 6690261.9 34, 355108.3 6690262.9 34, 355109.4 6690265.4 34, 355112.3 6690264.4 34, 355111.4 6690261.9 34))
BATIMENT0000000302944530;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.8;28.8;31.6;36.0;29.1;Cadastre;;POLYGON Z ((355153.5 6690244.2 31.6, 355155.2 6690246.8 31.6, 355155.6 6690248.5 31.6, 355156.7 6690252.3 31.6, 355157.1 6690254.9 31.6, 355158.8 6690254.8 31.6, 355157.5 6690243.2 31.6, 355155.9 6690235.2 31.6, 355155.7 6690234.5 31.6, 355150.4 6690236.6 31.6, 355152.4 6690242.3 31.6, 355153.5 6690244.2 31.6))
BATIMENT0000000302944533;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1670-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;10.7;26.0;36.7;38.0;29.1;Cadastre;A 1.0;POLYGON Z ((355178.2 6690242.1 36.7, 355161.3 6690242.9 36.7, 355157.5 6690243.2 36.7, 355158.8 6690254.8 36.7, 355163.4 6690254.5 36.7, 355166.3 6690254.2 36.7, 355166.1 6690252.6 36.7, 355168.5 6690252.4 36.7, 355169.1 6690251.4 36.7, 355170 6690252 36.7, 355171.8 6690252 36.7, 355172 6690253.7 36.7, 355179 6690253 36.7, 355178.6 6690247.9 36.7, 355178.2 6690242.1 36.7))
BATIMENT0000000302944794;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;25;30;8.6;28.1;36.8;38.7;29.1;Cadastre;A 1.0;POLYGON Z ((355119.3 6690249.9 36.8, 355122 6690256.9 36.8, 355130.8 6690253.3 36.8, 355128.1 6690246.3 36.8, 355120.4 6690249.5 36.8, 355119.3 6690249.9 36.8))
BATIMENT0000000302944532;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;28.8;31.5;35.2;29.0;Cadastre;;POLYGON Z ((355141.3 6690253.5 31.5, 355143.6 6690259.7 31.5, 355153.4 6690255.6 31.5, 355155 6690255 31.5, 355157.1 6690254.9 31.5, 355156.7 6690252.3 31.5, 355155.6 6690248.5 31.5, 355141.3 6690253.5 31.5))
BATIMENT0000000302944795;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.2;28.2;35.5;38.5;29.1;Cadastre;A 1.0;POLYGON Z ((355123.6 6690261.7 35.5, 355120.2 6690263.1 35.5, 355121.1 6690265.2 35.5, 355122.1 6690264.9 35.5, 355133.5 6690260.5 35.5, 355130.8 6690253.3 35.5, 355122 6690256.9 35.5, 355123.6 6690261.7 35.5))
BATIMENT0000000302944539;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;4.4;28.7;33.1;;;Cadastre;A 1.0;POLYGON Z ((355147.6 6690270.2 33.1, 355153.7 6690267.9 33.1, 355151.9 6690263 33.1, 355153.8 6690261.9 33.1, 355152.4 6690258.4 33.1, 355154.1 6690257.4 33.1, 355153.4 6690255.6 33.1, 355143.6 6690259.7 33.1, 355147.6 6690270.2 33.1))
BATIMENT0000000302944796;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;10;6.0;29.7;35.7;;;Cadastre;A 1.0;POLYGON Z ((355123.8 6690269.2 35.7, 355124.4 6690268.8 35.7, 355124.3 6690269.6 35.7, 355125.8 6690269.2 35.7, 355127 6690271.9 35.7, 355136.2 6690268.1 35.7, 355133.5 6690260.5 35.7, 355122.1 6690264.9 35.7, 355123.8 6690269.2 35.7))
BATIMENT0000000302944542;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;6.0;10;20;14.8;26.2;41.0;44.7;29.2;Cadastre;A 1.0;POLYGON Z ((355177.5 6690269.7 41, 355180 6690265.5 41, 355179.6 6690260.2 41, 355173.4 6690260.9 41, 355166 6690263.9 41, 355169.6 6690273.1 41, 355177.5 6690269.7 41))
BATIMENT0000000302944541;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.7;28.6;37.3;43.7;29.2;Cadastre;A 1.0;POLYGON Z ((355165.7 6690264.1 37.3, 355165.5 6690263.4 37.3, 355161.7 6690264.9 37.3, 355162.2 6690266.3 37.3, 355160.4 6690267 37.3, 355161.3 6690269.2 37.3, 355163.9 6690275.4 37.3, 355169.6 6690273.1 37.3, 355166 6690263.9 37.3, 355165.7 6690264.1 37.3))
BATIMENT0000000302944540;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;10;6.8;28.6;35.4;37.3;29.0;Cadastre;A 1.0;POLYGON Z ((355147.6 6690270.2 35.4, 355150.1 6690276.8 35.4, 355155.1 6690279.1 35.4, 355156.6 6690278.4 35.4, 355163.9 6690275.4 35.4, 355161.3 6690269.2 35.4, 355155.7 6690271.6 35.4, 355155.3 6690271.7 35.4, 355153.7 6690267.9 35.4, 355147.6 6690270.2 35.4))
BATIMENT0000000302944818;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;2.8;29.1;32.0;33.2;29.6;Cadastre;A 0.3;POLYGON Z ((355107.3 6690266.3 32, 355108.3 6690268.6 32, 355113.2 6690266.7 32, 355112.3 6690264.4 32, 355109.4 6690265.4 32, 355107.3 6690266.3 32))
BATIMENT0000000302944686;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;5.0;30.0;35.0;;;Cadastre;A 1.0;POLYGON Z ((355094.8 6690273.6 35, 355104 6690270 35, 355100.3 6690260.5 35, 355099.5 6690260.9 35, 355091.1 6690264.1 35, 355094.8 6690273.6 35))
BATIMENT0000000302944763;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;5.9;29.7;35.6;37.9;30.3;Cadastre;A 1.0;POLYGON Z ((355077 6690275.6 35.6, 355080.6 6690274.4 35.6, 355084.9 6690272.5 35.6, 355081.6 6690263.4 35.6, 355073.5 6690266.5 35.6, 355077 6690275.6 35.6))
BATIMENT0000000302944752;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;30.5;32.2;32.6;31.0;Cadastre;;POLYGON Z ((355035.5 6690276.2 32.2, 355036.7 6690278.1 32.2, 355039.4 6690276.7 32.2, 355038.2 6690274.8 32.2, 355035.5 6690276.2 32.2))
BATIMENT0000000302944776;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.1;29.5;34.6;37.7;29.9;Cadastre;A 0.6;POLYGON Z ((355109.7 6690279.4 34.6, 355106.3 6690271.2 34.6, 355098 6690274.3 34.6, 355101.3 6690282.3 34.6, 355106.5 6690280.7 34.6, 355109.7 6690279.4 34.6))
BATIMENT0000000302944751;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;30.5;33.4;33.7;31.2;Cadastre;;POLYGON Z ((355038 6690279.2 33.4, 355038.8 6690280.3 33.4, 355040.6 6690279.3 33.4, 355040 6690278.2 33.4, 355038 6690279.2 33.4))
BATIMENT0000000302944761;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;5.9;29.7;35.6;39.0;30.4;Cadastre;A 1.0;POLYGON Z ((355080.6 6690274.4 35.6, 355077 6690275.6 35.6, 355077.5 6690277.1 35.6, 355075.6 6690277.9 35.6, 355079.1 6690287.8 35.6, 355081.8 6690286.8 35.6, 355089.2 6690284 35.6, 355086.9 6690277.8 35.6, 355082.6 6690279.6 35.6, 355082.1 6690278.2 35.6, 355086.4 6690276.5 35.6, 355084.9 6690272.5 35.6, 355080.6 6690274.4 35.6))
BATIMENT0000000302944775;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.4;29.1;34.5;;;Cadastre;;POLYGON Z ((355098.7 6690283.2 34.5, 355099.3 6690284.6 34.5, 355106.9 6690281.7 34.5, 355106.5 6690280.7 34.5, 355101.3 6690282.3 34.5, 355098.7 6690283.2 34.5))
BATIMENT0000000302944774;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;5.7;29.1;34.8;37.6;29.8;Cadastre;A 1.0;POLYGON Z ((355102.5 6690292.6 34.8, 355110.1 6690289.7 34.8, 355106.9 6690281.7 34.8, 355099.3 6690284.6 34.8, 355102.5 6690292.6 34.8))
BATIMENT0000000302944762;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;7.3;29.3;36.7;39.4;30.3;Cadastre;A 1.0;POLYGON Z ((355084.8 6690294.4 36.7, 355092.2 6690291.8 36.7, 355089.2 6690284 36.7, 355081.8 6690286.8 36.7, 355084.8 6690294.4 36.7))
BATIMENT0000000302944797;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;00;00;18.6;28.1;46.7;49.0;28.9;Cadastre;C 0.9;POLYGON Z ((355130 6690279.7 46.7, 355131.7 6690279 46.7, 355139.3 6690275.6 46.7, 355136.2 6690268.1 46.7, 355127 6690271.9 46.7, 355130 6690279.7 46.7))
BATIMENT0000000302944801;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;28.5;31.5;37.2;29.7;Cadastre;C 0.5;POLYGON Z ((355125.1 6690281.5 31.5, 355122.6 6690273.7 31.5, 355117.5 6690275.6 31.5, 355117.9 6690276.5 31.5, 355120.5 6690283.3 31.5, 355123.8 6690282 31.5, 355125.1 6690281.5 31.5))
BATIMENT0000000302944799;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;6.0;20;20;17.2;30.0;47.2;;;Cadastre;A 1.0;POLYGON Z ((355132.3 6690280.4 47.2, 355131.7 6690280.7 47.2, 355130.5 6690280.6 47.2, 355129.1 6690281.2 47.2, 355130.6 6690284.7 47.2, 355132.1 6690284.1 47.2, 355133.7 6690288 47.2, 355139.1 6690285.8 47.2, 355141.4 6690281 47.2, 355139.3 6690275.6 47.2, 355131.7 6690279 47.2, 355132.3 6690280.4 47.2))
BATIMENT0000000302944800;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.4;28.0;47.5;49.4;28.5;Cadastre;;POLYGON Z ((355133.7 6690288 47.5, 355132.1 6690284.1 47.5, 355130.6 6690284.7 47.5, 355132.2 6690288.5 47.5, 355133.7 6690288 47.5))
BATIMENT0000000302944798;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;6.0;20;20;17.4;30.0;47.4;;;Cadastre;A 1.0;POLYGON Z ((355127.3 6690281.8 47.4, 355127 6690282.7 47.4, 355124.5 6690283.6 47.4, 355123.8 6690282 47.4, 355120.5 6690283.3 47.4, 355120.8 6690284.3 47.4, 355123.7 6690292 47.4, 355132.2 6690288.5 47.4, 355130.6 6690284.7 47.4, 355129.1 6690281.2 47.4, 355127.3 6690281.8 47.4))
BATIMENT0000000302944571;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;00;00;13.0;24.4;37.4;41.1;28.9;Cadastre;C 1.0;POLYGON Z ((355181.7 6690286 37.4, 355168.6 6690287.4 37.4, 355170.3 6690308.4 37.4, 355173.8 6690306.3 37.4, 355181 6690302 37.4, 355183.1 6690301.8 37.4, 355181.7 6690286 37.4))
BATIMENT0000000302944596;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;28.3;37.2;41.9;28.9;Cadastre;;POLYGON Z ((355145 6690310 37.2, 355139.3 6690297.4 37.2, 355133.3 6690299.8 37.2, 355138.6 6690312.7 37.2, 355145 6690310 37.2))
BATIMENT0000000302944572;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;90;20;8.9;25.8;34.7;37.5;27.3;Cadastre;C 0.7;POLYGON Z ((355174.9 6690318.6 34.7, 355184.5 6690317.8 34.7, 355183.1 6690301.8 34.7, 355181 6690302 34.7, 355173.8 6690306.3 34.7, 355174.9 6690318.6 34.7))
BATIMENT0000000302944595;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;28.1;31.7;36.0;28.9;Cadastre;;POLYGON Z ((355138.6 6690312.7 31.7, 355133.3 6690299.8 31.7, 355126.7 6690302.5 31.7, 355128.3 6690307.2 31.7, 355129.6 6690308 31.7, 355130.1 6690307.8 31.7, 355137.4 6690324.8 31.7, 355143 6690323.1 31.7, 355138.6 6690312.7 31.7))
BATIMENT0000000302944578;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;2.4;28.2;30.7;31.8;28.9;Cadastre;C 0.1;POLYGON Z ((355140.9 6690314.6 30.7, 355143.8 6690321 30.7, 355162.9 6690311.5 30.7, 355159.7 6690305.3 30.7, 355140.9 6690314.6 30.7))
BATIMENT0000000302944773;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;10;6.5;29.1;35.6;37.0;29.6;Cadastre;A 1.0;POLYGON Z ((355103.9 6690297.1 35.6, 355108.6 6690299.2 35.6, 355113.9 6690297.2 35.6, 355110.5 6690289.4 35.6, 355110.1 6690289.7 35.6, 355102.5 6690292.6 35.6, 355103.9 6690297.1 35.6))
BATIMENT0000000302944765;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;10;4.0;29.7;33.7;37.5;30.0;Cadastre;A 0.6;POLYGON Z ((355088.7 6690304.3 33.7, 355095.6 6690301.6 33.7, 355095.9 6690301.1 33.7, 355092.2 6690291.8 33.7, 355084.8 6690294.4 33.7, 355087.3 6690300.9 33.7, 355088.7 6690304.3 33.7))
BATIMENT0000000302944766;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;29.6;34.5;37.2;30.0;Cadastre;;POLYGON Z ((355082.4 6690295.3 34.5, 355084.8 6690301.8 34.5, 355087.3 6690300.9 34.5, 355084.8 6690294.4 34.5, 355082.4 6690295.3 34.5))
BATIMENT0000000302944616;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.0;30.0;34.0;40.1;30.8;Cadastre;B 0.4;POLYGON Z ((355058.9 6690302.4 34, 355057.2 6690298.7 34, 355055 6690299.3 34, 355052 6690294.5 34, 355050.4 6690295.6 34, 355053.5 6690301.2 34, 355055.1 6690303.9 34, 355058.3 6690309.1 34, 355068.5 6690305.2 34, 355075.1 6690302.6 34, 355073.9 6690299.6 34, 355072.9 6690296.8 34, 355071 6690292.1 34, 355070.7 6690291.5 34, 355067.6 6690292.7 34, 355069 6690296.5 34, 355069.8 6690296.2 34, 355070.4 6690297.8 34, 355058.9 6690302.4 34))
BATIMENT0000000302944618;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;29.8;33.0;34.2;30.1;Cadastre;;POLYGON Z ((355077.3 6690304.4 33, 355076.8 6690303 33, 355077.4 6690302.7 33, 355075.9 6690298.9 33, 355073.9 6690299.6 33, 355075.1 6690302.6 33, 355076.1 6690304.9 33, 355077.3 6690304.4 33))
BATIMENT0000000302944617;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.5;30.4;35.0;38.4;30.9;Cadastre;A 0.1;POLYGON Z ((355051.5 6690302.3 35, 355053.7 6690305.7 35, 355055.1 6690303.9 35, 355053.5 6690301.2 35, 355051.5 6690302.3 35))
BATIMENT0000000302944620;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.6;29.7;37.3;40.7;30.1;Cadastre;A 1.0;POLYGON Z ((355076.1 6690304.9 37.3, 355075.1 6690302.6 37.3, 355068.5 6690305.2 37.3, 355070.4 6690310.5 37.3, 355070.9 6690311.8 37.3, 355073.5 6690310.7 37.3, 355073 6690309.4 37.3, 355077.1 6690307.8 37.3, 355076.1 6690304.9 37.3))
BATIMENT0000000302944826;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.1;29.4;30.6;31.2;29.9;Cadastre;;POLYGON Z ((355076.5 6690308.6 30.6, 355077.4 6690310.5 30.6, 355081 6690308.9 30.6, 355080.3 6690307.4 30.6, 355076.5 6690308.6 30.6))
BATIMENT0000000302944619;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.9;29.7;36.6;39.5;30.8;Cadastre;A 1.0;POLYGON Z ((355062.9 6690316.9 36.6, 355063.9 6690318.9 36.6, 355066.5 6690318 36.6, 355064.1 6690313 36.6, 355070.4 6690310.5 36.6, 355068.5 6690305.2 36.6, 355058.3 6690309.1 36.6, 355062.9 6690316.9 36.6))
BATIMENT0000000302944782;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;7.4;29.7;37.1;;;Cadastre;A 1.0;POLYGON Z ((355091.7 6690316.5 37.1, 355095.4 6690325.4 37.1, 355099.5 6690323.9 37.1, 355099.9 6690324.7 37.1, 355103 6690323.4 37.1, 355098.8 6690313.6 37.1, 355091.7 6690316.5 37.1))
BATIMENT0000000302945711;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.7;22.9;39.6;44.8;27.2;Cadastre;;POLYGON Z ((355190.1 6690240.9 39.6, 355190.6 6690242.9 39.6, 355195.3 6690241.7 39.6, 355201.5 6690265.2 39.6, 355195.5 6690266.4 39.6, 355192.6 6690257.6 39.6, 355191.6 6690256.1 39.6, 355189.3 6690254.8 39.6, 355187.5 6690254.7 39.6, 355189.5 6690281.7 39.6, 355192.3 6690281.2 39.6, 355193 6690279.9 39.6, 355192.5 6690276.9 39.6, 355203.9 6690274.5 39.6, 355206.4 6690273.6 39.6, 355209.8 6690285.8 39.6, 355207.4 6690286.4 39.6, 355193.9 6690289.6 39.6, 355193.5 6690287 39.6, 355192.7 6690286.5 39.6, 355189.9 6690287.4 39.6, 355191.2 6690301.5 39.6, 355209.1 6690296.9 39.6, 355212.7 6690296.1 39.6, 355220.5 6690322.8 39.6, 355216.7 6690323.9 39.6, 355222.8 6690346.1 39.6, 355226.1 6690357.6 39.6, 355227.3 6690357.2 39.6, 355236.9 6690354.4 39.6, 355236.4 6690352 39.6, 355246.3 6690349.1 39.6, 355246.8 6690349.9 39.6, 355251.3 6690348.7 39.6, 355251.1 6690347.5 39.6, 355263.9 6690344 39.6, 355262 6690348 39.6, 355269.9 6690352 39.6, 355273.2 6690345.5 39.6, 355272.4 6690345 39.6, 355279.5 6690330.7 39.6, 355277.3 6690329.9 39.6, 355280.4 6690323.3 39.6, 355274.9 6690320.8 39.6, 355276.6 6690316.8 39.6, 355268.8 6690313.3 39.6, 355266.7 6690317.2 39.6, 355265.1 6690316.3 39.6, 355263.6 6690315.6 39.6, 355258.9 6690325.4 39.6, 355261.1 6690333.1 39.6, 355262.4 6690333.7 39.6, 355261.6 6690335.2 39.6, 355261.3 6690334.9 39.6, 355255.2 6690336.8 39.6, 355233.7 6690342.9 39.6, 355211.3 6690264.9 39.6, 355215.7 6690263.4 39.6, 355207.1 6690232.1 39.6, 355193.8 6690236.3 39.6, 355186.4 6690238.2 39.6, 355186.6 6690241.8 39.6, 355190.1 6690240.9 39.6))
BATIMENT0000000302945710;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:54:10;2018-06-04 12:14:25;;2017-07-01;MSS;MSS:67997;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;23.3;16.3;;;;Imagerie aérienne;;POLYGON Z ((355281.6 6690330.3 30.2, 355285.8 6690322.1 30.2, 355284.4 6690321.4 30.2, 355302.9 6690285.2 30.4, 355301.7 6690284.5 30.4, 355303.5 6690280.9 30.2, 355292.1 6690275 30.2, 355290.1 6690278.6 30.2, 355284 6690276 30.2, 355265.7 6690311.8 30.2, 355267.5 6690312.9 38.9, 355268.8 6690313.3 39.6, 355276.6 6690316.8 39.6, 355275.1 6690320.9 39.6, 355280.4 6690323.3 39.6, 355277.3 6690329.9 39.6, 355279.5 6690330.7 39.5, 355281.6 6690330.3 30.2))
BATIMENT0000000302944393;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;26.5;31.0;41.5;27.0;Cadastre;;POLYGON Z ((355253.8 6690332.6 31, 355236.5 6690337.4 31, 355215.7 6690263.4 31, 355211.3 6690264.9 31, 355233.7 6690342.9 31, 355255.2 6690336.8 31, 355253.8 6690332.6 31))
BATIMENT0000000302944387;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;26.6;33.5;41.2;26.9;Cadastre;;POLYGON Z ((355216.7 6690323.9 33.5, 355220.5 6690322.8 33.5, 355212.7 6690296.1 33.5, 355209.1 6690296.9 33.5, 355216.7 6690323.9 33.5))
BATIMENT0000000302944389;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;11.5;25.0;36.5;37.8;26.4;Cadastre;C 0.4;POLYGON Z ((355199.9 6690314.2 36.5, 355192.4 6690314.9 36.5, 355196.3 6690356.2 36.5, 355200.4 6690355 36.5, 355200.4 6690353 36.5, 355203.6 6690351.9 36.5, 355199.9 6690314.2 36.5))
BATIMENT0000000302944388;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.5;24.5;37.0;40.7;26.6;Cadastre;;POLYGON Z ((355227.3 6690357.2 37, 355226.1 6690357.6 37, 355222.8 6690346.1 37, 355203.6 6690351.9 37, 355200.4 6690353 37, 355200.4 6690355 37, 355196.3 6690356.2 37, 355197.8 6690372.4 37, 355207 6690368.8 37, 355215.5 6690365.3 37, 355228.3 6690360 37, 355227.3 6690357.2 37))
BATIMENT0000000302944386;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;7.0;00;00;17.8;19.1;37.0;38.4;25.5;Cadastre;A 1.0;POLYGON Z ((355245.3 6690373.8 37, 355245.2 6690375.6 37, 355254.7 6690371.7 37, 355258.9 6690373.5 37, 355269.9 6690352 37, 355262 6690348 37, 355260 6690347 37, 355259.2 6690347.3 37, 355255.1 6690355.2 37, 355251.3 6690362.4 37, 355245.3 6690373.8 37))
BATIMENT0000002011294493;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2010-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;54.0;6.0;00;00;21.9;18.4;;;;Imagerie aérienne;A 1.0;POLYGON Z ((355280.2 6690373.7 40.3, 355289.6 6690379.3 40.3, 355294.3 6690372 36.1, 355297.7 6690373.3 33.6, 355303.9 6690361.6 34.3, 355291 6690355.3 34.3, 355280.2 6690373.7 40.3))
BATIMENT0000000302944390;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;6.0;00;00;14.7;23.9;38.7;41.4;25.2;Cadastre;A 1.0;POLYGON Z ((355197.8 6690372.4 38.7, 355199.4 6690389.8 38.7, 355208.3 6690388.6 38.7, 355210.4 6690388.2 38.7, 355210.8 6690388.1 38.7, 355210 6690381.5 38.7, 355212 6690381.5 38.7, 355212.1 6690381.3 38.7, 355212.1 6690380.9 38.7, 355212.2 6690380.5 38.7, 355212.2 6690380.3 38.7, 355212.3 6690379.5 38.7, 355212.5 6690379 38.7, 355212.6 6690378.8 38.7, 355212.7 6690378.4 38.7, 355212.9 6690377.9 38.7, 355213.1 6690377.5 38.7, 355213.1 6690377.3 38.7, 355213.2 6690377.1 38.7, 355213.3 6690376.9 38.7, 355213.5 6690376.6 38.7, 355213.8 6690376.1 38.7, 355214.1 6690375.6 38.7, 355214.5 6690375.1 38.7, 355214.6 6690375 38.7, 355214.7 6690374.8 38.7, 355215 6690374.5 38.7, 355215.1 6690374.4 38.7, 355215.4 6690373.9 38.7, 355215.5 6690373.7 38.7, 355215.6 6690373.6 38.7, 355215.9 6690373.1 38.7, 355216.1 6690372.6 38.7, 355216.2 6690372.3 38.7, 355216.3 6690372 38.7, 355216.4 6690371.6 38.7, 355216.5 6690371.2 38.7, 355216.6 6690370.3 38.7, 355216.6 6690369.9 38.7, 355216.6 6690369.2 38.7, 355216.6 6690368.9 38.7, 355215.7 6690368.9 38.7, 355215.5 6690365.3 38.7, 355207 6690368.8 38.7, 355197.8 6690372.4 38.7))
BATIMENT0000000302944411;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;7.0;00;00;18.8;19.2;38.0;40.0;24.8;Cadastre;C 0.7;POLYGON Z ((355253.3 6690384.7 38, 355250.4 6690376.3 38, 355236.8 6690380.8 38, 355239.5 6690388.6 38, 355237.8 6690389.2 38, 355241 6690398 38, 355248.3 6690394.7 38, 355253.3 6690384.7 38))
BATIMENT0000000302944574;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;90;20;8.1;26.0;34.2;37.7;28.8;Cadastre;C 0.4;POLYGON Z ((355166.2 6690311 34.2, 355150.9 6690320.6 34.2, 355157.1 6690320.3 34.2, 355161 6690319.8 34.2, 355167 6690319.2 34.2, 355166.2 6690311 34.2))
BATIMENT0000000302944589;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.8;27.9;31.7;36.0;29.4;Cadastre;C 0.5;POLYGON Z ((355123.8 6690310.7 31.7, 355124.6 6690310.1 31.7, 355125.2 6690309 31.7, 355123.1 6690304 31.7, 355116.4 6690306.8 31.7, 355124.9 6690327.1 31.7, 355125.5 6690328.4 31.7, 355130.5 6690326.9 31.7, 355123.8 6690310.7 31.7))
BATIMENT0000000302944573;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;12.9;25.4;38.3;40.5;26.4;Cadastre;A 1.0;POLYGON Z ((355167 6690319.2 38.3, 355167.3 6690321.1 38.3, 355168.4 6690321.9 38.3, 355170.7 6690321.8 38.3, 355171.9 6690320.5 38.3, 355172.6 6690320.5 38.3, 355173.5 6690331.3 38.3, 355185.5 6690330.1 38.3, 355184.5 6690317.8 38.3, 355174.9 6690318.6 38.3, 355167 6690319.2 38.3))
BATIMENT0000000302945713;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;4.9;27.9;32.8;36.2;28.8;Cadastre;C 0.2;POLYGON Z ((355151.3 6690327.1 32.8, 355150.9 6690320.6 32.8, 355143 6690323.1 32.8, 355137.4 6690324.8 32.8, 355139.4 6690330.5 32.8, 355151.3 6690327.1 32.8))
BATIMENT0000000302944576;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;11.0;26.0;37.0;40.2;28.8;Cadastre;A 1.0;POLYGON Z ((355151.3 6690327.1 37, 355151.5 6690330.4 37, 355153.9 6690332.1 37, 355153.9 6690332.9 37, 355168.1 6690331.8 37, 355167.8 6690329.2 37, 355167.3 6690321.1 37, 355167 6690319.2 37, 355161 6690319.8 37, 355161.3 6690324.2 37, 355157.2 6690324.3 37, 355157.1 6690320.3 37, 355150.9 6690320.6 37, 355151.3 6690327.1 37))
BATIMENT0000000302944575;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;25.5;29.0;34.5;26.4;Cadastre;;POLYGON Z ((355172.5 6690331.4 29, 355172.3 6690328.8 29, 355171.3 6690327.8 29, 355169.1 6690327.9 29, 355167.8 6690329.2 29, 355168.1 6690331.8 29, 355172.5 6690331.4 29))
BATIMENT0000000302945712;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1700-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;4.9;27.9;32.8;33.4;28.9;Cadastre;C 0.2;POLYGON Z ((355128.8 6690334.4 32.8, 355131 6690337.6 32.8, 355132.4 6690335 32.8, 355134.7 6690333.9 32.8, 355134.1 6690332.1 32.8, 355139.4 6690330.5 32.8, 355137.4 6690324.8 32.8, 355130.5 6690326.9 32.8, 355125.5 6690328.4 32.8, 355124.8 6690328.7 32.8, 355128.8 6690334.4 32.8))
BATIMENT0000000302944588;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;28.1;32.8;35.5;29.2;Cadastre;;POLYGON Z ((355120.2 6690328.8 32.8, 355126.8 6690337.2 32.8, 355128.8 6690334.4 32.8, 355124.8 6690328.7 32.8, 355125.5 6690328.4 32.8, 355124.9 6690327.1 32.8, 355120.2 6690328.8 32.8))
BATIMENT0000000302944584;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;25.9;28.5;34.5;26.5;Cadastre;;POLYGON Z ((355159.7 6690334.4 28.5, 355159.9 6690336.7 28.5, 355161.5 6690336.6 28.5, 355161.8 6690336.4 28.5, 355164 6690336.2 28.5, 355163.8 6690334 28.5, 355159.7 6690334.4 28.5))
BATIMENT0000000302944577;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;7.0;25.3;32.3;41.0;25.8;Cadastre;A 1.0;POLYGON Z ((355179.4 6690332.6 32.3, 355174.9 6690333.1 32.3, 355170.5 6690333.6 32.3, 355171.3 6690345.6 32.3, 355176 6690345.2 32.3, 355180.6 6690344.9 32.3, 355186.8 6690344.3 32.3, 355185.6 6690332.1 32.3, 355179.4 6690332.6 32.3))
BATIMENT0000000302944621;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;29.6;33.2;34.6;30.6;Cadastre;;POLYGON Z ((355059.4 6690321.7 33.2, 355063 6690324 33.2, 355065.1 6690321 33.2, 355063.9 6690318.9 33.2, 355062.9 6690316.9 33.2, 355059.4 6690321.7 33.2))
BATIMENT0000000302944783;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.2;29.7;36.9;;;Cadastre;A 1.0;POLYGON Z ((355111.4 6690308.4 36.9, 355108.2 6690309.7 36.9, 355098.8 6690313.6 36.9, 355103 6690323.4 36.9, 355107 6690333.3 36.9, 355112.1 6690331.4 36.9, 355111.5 6690330.4 36.9, 355112.1 6690330.3 36.9, 355107.3 6690316.1 36.9, 355113.6 6690313 36.9, 355111.4 6690308.4 36.9))
BATIMENT0000000302944781;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;19;7.4;29.7;37.1;;;Cadastre;A 1.0;POLYGON Z ((355085.2 6690319.2 37.1, 355089.1 6690328.3 37.1, 355089.4 6690329.5 37.1, 355093.6 6690327.8 37.1, 355092.9 6690326.7 37.1, 355095.4 6690325.4 37.1, 355091.7 6690316.5 37.1, 355085.2 6690319.2 37.1))
BATIMENT0000000302944780;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;7.4;29.7;37.1;39.3;29.9;Cadastre;A 1.0;POLYGON Z ((355074.9 6690323.4 37.1, 355078.8 6690332.4 37.1, 355089.1 6690328.3 37.1, 355085.2 6690319.2 37.1, 355074.9 6690323.4 37.1))
BATIMENT0000000302944825;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.3;30.1;35.5;39.0;30.6;Cadastre;;POLYGON Z ((355054.6 6690327.3 35.5, 355056.6 6690328.4 35.5, 355058.7 6690325.4 35.5, 355056.9 6690324.5 35.5, 355054.6 6690327.3 35.5))
BATIMENT0000000302944153;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;25;20;6.1;29.2;35.3;40.6;30.9;Cadastre;C 0.7;POLYGON Z ((355050.9 6690340.5 35.3, 355052 6690339 35.3, 355056.3 6690332.7 35.3, 355050.3 6690329 35.3, 355050.8 6690327.9 35.3, 355041.8 6690322.2 35.3, 355041.3 6690322.6 35.3, 355035.7 6690331 35.3, 355050.9 6690340.5 35.3))
BATIMENT0000000302944756;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:07;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;28.4;32.0;32.6;29.2;Cadastre;;POLYGON Z ((355095.1 6690338 32, 355096.7 6690341.5 32, 355097.5 6690340.4 32, 355100.6 6690342.4 32, 355101.9 6690340.4 32, 355100.2 6690336.2 32, 355095.1 6690338 32))
BATIMENT0000000302944152;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.3;28.2;31.6;36.0;30.4;Cadastre;A 0.2;POLYGON Z ((355055.7 6690343.6 31.6, 355056.5 6690341.9 31.6, 355052 6690339 31.6, 355050.9 6690340.5 31.6, 355055.7 6690343.6 31.6))
BATIMENT0000000302944626;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;27.7;35.7;40.7;29.8;Cadastre;A 1.0;POLYGON Z ((355077.3 6690342.9 35.7, 355073 6690335.6 35.7, 355072.7 6690336.2 35.7, 355071.7 6690335.7 35.7, 355071 6690337 35.7, 355071.9 6690337.6 35.7, 355064.7 6690349.5 35.7, 355070.8 6690353.4 35.7, 355074.3 6690347.7 35.7, 355077.3 6690342.9 35.7))
BATIMENT0000000302944829;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.0;28.1;31.2;32.2;28.9;Cadastre;;POLYGON Z ((355087.1 6690350.3 31.2, 355088.7 6690351.4 31.2, 355090.7 6690348.4 31.2, 355089 6690347.2 31.2, 355087.1 6690350.3 31.2))
BATIMENT0000000302944586;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;8.1;25.4;33.5;37.7;26.9;Cadastre;B 0.6;POLYGON Z ((355165.9 6690334 33.5, 355166.4 6690344.3 33.5, 355164.4 6690344.3 33.5, 355164.1 6690338.7 33.5, 355160.1 6690339 33.5, 355160.4 6690346.4 33.5, 355171.3 6690345.6 33.5, 355170.5 6690333.6 33.5, 355165.9 6690334 33.5))
BATIMENT0000000302944585;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;7.9;26.2;34.1;41.5;28.4;Cadastre;B 0.3;POLYGON Z ((355157.9 6690334.5 34.1, 355154 6690334.8 34.1, 355152.1 6690335 34.1, 355152.3 6690335.3 34.1, 355152.4 6690336.9 34.1, 355152.7 6690342 34.1, 355153.2 6690347 34.1, 355158.6 6690346.5 34.1, 355157.9 6690334.5 34.1))
BATIMENT0000000302944828;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;24.1;;;;Cadastre;;POLYGON Z ((355121.1 6690342.5 -1000, 355118.4 6690340.5 -1000, 355115.1 6690345.4 -1000, 355113.6 6690345.2 -1000, 355113.1 6690346.6 -1000, 355116.7 6690348.4 -1000, 355118.6 6690345.9 -1000, 355121.1 6690342.5 -1000))
BATIMENT0000000302944579;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;5.0;00;00;14.8;24.9;39.7;41.8;29.2;Cadastre;A 1.0;POLYGON Z ((355146.9 6690361.1 39.7, 355152.5 6690368.8 39.7, 355159.7 6690367.9 39.7, 355161.2 6690367.8 39.7, 355168.6 6690367.1 39.7, 355171.9 6690366.8 39.7, 355188.6 6690365.1 39.7, 355186.8 6690344.3 39.7, 355180.6 6690344.9 39.7, 355176 6690345.2 39.7, 355171.3 6690345.6 39.7, 355160.4 6690346.4 39.7, 355158.6 6690346.5 39.7, 355153.2 6690347 39.7, 355152.7 6690342 39.7, 355141.6 6690342.8 39.7, 355141.6 6690344 39.7, 355139 6690340.1 39.7, 355134.3 6690342.3 39.7, 355134.7 6690343.1 39.7, 355138.1 6690348.1 39.7, 355146.9 6690361.1 39.7), (355173.3 6690348.1 39.7, 355174.4 6690361.3 39.7, 355161.4 6690362.6 39.7, 355160.7 6690351.4 39.7, 355165.5 6690350.6 39.7, 355165.7 6690351.4 39.7, 355171 6690350.7 39.7, 355171.8 6690349.6 39.7, 355171.9 6690348.3 39.7, 355173.3 6690348.1 39.7))
BATIMENT0000000302944580;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;24.8;28.7;30.2;25.9;Cadastre;;POLYGON Z ((355168.6 6690367.1 28.7, 355169.1 6690372.3 28.7, 355172.3 6690372 28.7, 355171.9 6690366.8 28.7, 355168.6 6690367.1 28.7))
BATIMENT0000000302944583;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;10.3;24.4;34.7;38.2;25.8;Cadastre;C 0.7;POLYGON Z ((355188.6 6690365.1 34.7, 355171.9 6690366.8 34.7, 355172.3 6690372 34.7, 355175.1 6690371.8 34.7, 355174.9 6690368.3 34.7, 355176.4 6690368.2 34.7, 355176.7 6690371.6 34.7, 355175.4 6690371.7 34.7, 355175.6 6690373.5 34.7, 355172.5 6690373.5 34.7, 355172.8 6690377.1 34.7, 355173 6690379.2 34.7, 355173.6 6690379.1 34.7, 355189.7 6690377.6 34.7, 355188.6 6690365.1 34.7))
BATIMENT0000000302944848;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:07;1984-01-01;;;;BDTopo;2.5;BDTopo;1.5;12.0;4.0;50;20;10.2;25.0;;39.0;28.2;Imagerie aérienne;A 1.0;POLYGON Z ((355125.5 6690387.8 35.2, 355132 6690379.2 35.2, 355132.9 6690377.7 35.2, 355115.7 6690366.9 35.2, 355113.7 6690369.8 35.2, 355112.3 6690368.9 35.2, 355107.5 6690376.5 35.2, 355125.5 6690387.8 35.2))
BATIMENT0000000302944581;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;10;20;7.5;25.5;33.0;34.7;27.4;Cadastre;C 0.5;POLYGON Z ((355155.7 6690373.2 33, 355162.8 6690382.3 33, 355167 6690388.3 33, 355171.2 6690385.2 33, 355174 6690384.6 33, 355173.9 6690383.2 33, 355170.7 6690383.7 33, 355159.7 6690367.9 33, 355152.5 6690368.8 33, 355155.7 6690373.2 33))
BATIMENT0000000302944594;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;24.9;30.0;34.2;25.9;Cadastre;;POLYGON Z ((355173.6 6690379.1 30, 355173 6690379.2 30, 355172.8 6690377.1 30, 355170.7 6690377.4 30, 355171.4 6690382.2 30, 355173.8 6690382.1 30, 355173.6 6690379.1 30))
BATIMENT0000000302944592;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;24;13.2;24.2;37.4;42.0;25.8;Cadastre;A 1.0;POLYGON Z ((355189.7 6690377.6 37.4, 355173.6 6690379.1 37.4, 355173.8 6690382.1 37.4, 355175 6690381.9 37.4, 355177.8 6690384.3 37.4, 355174.4 6690384.6 37.4, 355174.7 6690386.7 37.4, 355190.5 6690386.5 37.4, 355189.7 6690377.6 37.4))
BATIMENT0000000302934748;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;34.0;37.3;40.4;34.6;Cadastre;;POLYGON Z ((354703 6690120.9 37.3, 354703.6 6690124.4 37.3, 354709.1 6690123 37.3, 354708.2 6690119.7 37.3, 354703 6690120.9 37.3))
BATIMENT0000000302934636;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;10.0;32.9;43.0;44.6;33.0;Cadastre;A 1.0;POLYGON Z ((354644.3 6690124.4 43, 354642.5 6690118.7 43, 354636.9 6690120.5 43, 354636.3 6690120.6 43, 354636.4 6690121 43, 354638.4 6690126.7 43, 354644.3 6690124.4 43))
BATIMENT0000000302934640;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;2.0;00;00;11.1;32.9;44.0;45.9;33.1;Cadastre;A 0.6;POLYGON Z ((354638.4 6690126.7 44, 354636.4 6690121 44, 354633.3 6690121.9 44, 354629.6 6690123 44, 354632 6690129.1 44, 354638.4 6690126.7 44))
BATIMENT0000000302934767;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;50;40;10.6;34.1;44.7;51.6;34.7;Cadastre;A 1.0;POLYGON Z ((354678.9 6690350.1 44.7, 354689.3 6690363.5 44.7, 354696.3 6690358.2 44.7, 354688.5 6690347.8 44.7, 354686 6690344.5 44.7, 354678.9 6690350.1 44.7))
BATIMENT0000000302934779;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;34.5;38.3;40.7;34.6;Cadastre;;POLYGON Z ((354678.1 6690355.8 38.3, 354674.5 6690350.9 38.3, 354671.2 6690353.5 38.3, 354674.8 6690358.3 38.3, 354678.1 6690355.8 38.3))
BATIMENT0000000302934778;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.9;34.5;38.4;38.9;34.8;Cadastre;A 1.0;POLYGON Z ((354668.2 6690355.9 38.4, 354671.7 6690360.6 38.4, 354674.8 6690358.3 38.4, 354671.2 6690353.5 38.4, 354668.2 6690355.9 38.4))
BATIMENT0000000302934777;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;3.9;34.5;38.4;38.9;34.8;Cadastre;A 1.0;POLYGON Z ((354665.4 6690357.9 38.4, 354668.9 6690362.7 38.4, 354671.7 6690360.6 38.4, 354668.2 6690355.9 38.4, 354665.4 6690357.9 38.4))
BATIMENT0000000302934776;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;4.0;34.5;38.5;38.9;34.8;Cadastre;A 1.0;POLYGON Z ((354662.6 6690360.1 38.5, 354666.2 6690364.9 38.5, 354668.9 6690362.7 38.5, 354665.4 6690357.9 38.5, 354662.6 6690360.1 38.5))
BATIMENT0000000302934775;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.9;34.5;38.4;38.8;34.7;Cadastre;A 1.0;POLYGON Z ((354659.8 6690362.2 38.4, 354663.7 6690366.9 38.4, 354666.2 6690364.9 38.4, 354662.6 6690360.1 38.4, 354659.8 6690362.2 38.4))
BATIMENT0000000302934782;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;15;40;13.4;33.5;46.9;47.7;33.7;Cadastre;A 1.0;POLYGON Z ((354707.2 6690365.3 46.9, 354703.5 6690360.6 46.9, 354695.9 6690366.4 46.9, 354708.7 6690382.9 46.9, 354716.1 6690377.1 46.9, 354707.2 6690365.3 46.9))
BATIMENT0000002011293283;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.3;35.5;;;;Imagerie aérienne;;POLYGON Z ((354757.6 6690219.6 38.8, 354762.4 6690216.3 38.8, 354751.6 6690201.7 38.8, 354746.1 6690206.7 38.8, 354757.6 6690219.6 38.8))
BATIMENT0000000302934760;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;3.9;34.4;38.3;40.9;35.2;Cadastre;C 0.6;POLYGON Z ((354706.6 6690220 38.3, 354711.1 6690225.6 38.3, 354728.7 6690211.9 38.3, 354728.9 6690210 38.3, 354723.8 6690209.3 38.3, 354722.3 6690210.6 38.3, 354721 6690209 38.3, 354706.6 6690220 38.3))
BATIMENT0000002011294582;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:41:05;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.8;35.4;;51.2;35.7;Imagerie aérienne;;POLYGON Z ((354799.5 6690228.5 42.2, 354792.8 6690219.8 42.2, 354792.1 6690218.6 42.2, 354785.6 6690210 42.2, 354784.5 6690209.1 42.2, 354778.1 6690213.8 42.2, 354778.9 6690214.8 42.2, 354781.8 6690212.8 42.2, 354782.6 6690214.3 42.2, 354787.2 6690220.2 42.2, 354788.8 6690222.7 42.2, 354785 6690225.5 42.2, 354792.3 6690233.7 42.2, 354799.5 6690228.5 42.2))
BATIMENT0000002011295286;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;19.4;35.4;;;;Imagerie aérienne;;POLYGON Z ((354778.9 6690214.8 51, 354778.1 6690213.8 51, 354769.1 6690221.2 51.3, 354771.5 6690223.3 53.4, 354783.6 6690236.7 54.4, 354780.7 6690239 51.6, 354789.1 6690248.3 51.5, 354791.9 6690245.9 54.3, 354797.3 6690241.7 54.8, 354798.3 6690240.8 50.8, 354794.1 6690235.7 53, 354792.3 6690233.7 53, 354785 6690225.5 53.2, 354788.8 6690222.7 50.7, 354787.2 6690220.2 54, 354782.6 6690214.3 54.1, 354781.8 6690212.8 51.3, 354778.9 6690214.8 51))
BATIMENT0000000302934785;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;11.6;34.9;46.5;48.0;35.3;Cadastre;A 1.0;POLYGON Z ((354761.1 6690286.6 46.5, 354770.8 6690299.6 46.5, 354777.4 6690294.7 46.5, 354767.5 6690281.6 46.5, 354761.1 6690286.6 46.5))
BATIMENT0000000302934712;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;35;40;6.0;34.1;40.2;48.0;34.7;Cadastre;A 1.0;POLYGON Z ((354777.2 6690306.7 40.2, 354786.9 6690319.8 40.2, 354793.4 6690315 40.2, 354783.7 6690301.9 40.2, 354777.2 6690306.7 40.2))
BATIMENT0000000302934774;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;14.9;34.3;49.2;50.8;35.6;Cadastre;;POLYGON Z ((354741.6 6690301.6 49.2, 354735.1 6690306.6 49.2, 354745.7 6690320.6 49.2, 354752.3 6690315.6 49.2, 354741.6 6690301.6 49.2))
BATIMENT0000000302935361;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;04;09;7.9;34.5;42.5;49.2;34.7;Cadastre;A 1.0;POLYGON Z ((354728.7 6690314.8 42.5, 354725.4 6690310.4 42.5, 354722.5 6690312.6 42.5, 354725.9 6690317.1 42.5, 354728.7 6690314.8 42.5))
BATIMENT0000000302935360;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;3.8;34.5;38.3;40.7;34.7;Cadastre;A 1.0;POLYGON Z ((354720 6690314.5 38.3, 354723.4 6690319 38.3, 354725.9 6690317.1 38.3, 354722.5 6690312.6 38.3, 354720 6690314.5 38.3))
BATIMENT0000000302935359;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;3.7;34.4;38.2;38.3;34.6;Cadastre;A 1.0;POLYGON Z ((354717.7 6690316.3 38.2, 354721 6690321 38.2, 354723.4 6690319 38.2, 354720 6690314.5 38.2, 354717.7 6690316.3 38.2))
BATIMENT0000000302934653;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.9;32.3;39.2;41.1;32.7;Cadastre;C 0.2;POLYGON Z ((354563.2 6690146.5 39.2, 354565.5 6690153.5 39.2, 354571.1 6690151.3 39.2, 354568.6 6690144.8 39.2, 354563.2 6690146.5 39.2))
BATIMENT0000000302934657;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.1;31.8;38.9;42.6;32.5;Cadastre;C 0.7;POLYGON Z ((354553.6 6690157.8 38.9, 354550.6 6690150 38.9, 354550 6690148 38.9, 354550.5 6690147.8 38.9, 354549.6 6690145.4 38.9, 354544.6 6690147.2 38.9, 354544.8 6690147.7 38.9, 354545 6690148.4 38.9, 354545.5 6690149.8 38.9, 354546 6690149.6 38.9, 354549.6 6690159.2 38.9, 354553.6 6690157.8 38.9))
BATIMENT0000000302934655;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.4;32.4;38.8;42.4;32.5;Cadastre;A 1.0;POLYGON Z ((354560.9 6690155.1 38.8, 354558 6690147.3 38.8, 354550.6 6690150 38.8, 354553.6 6690157.8 38.8, 354560.9 6690155.1 38.8))
BATIMENT0000000302934312;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.6;34.8;37.4;;;Cadastre;A 1.0;POLYGON Z ((354617.1 6690395 37.4, 354620.7 6690400 37.4, 354623.6 6690397.8 37.4, 354619.9 6690392.9 37.4, 354617.1 6690395 37.4))
BATIMENT0000000302934313;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.6;34.8;37.4;;;Cadastre;A 1.0;POLYGON Z ((354614.4 6690397.1 37.4, 354618.1 6690402.1 37.4, 354620.7 6690400 37.4, 354617.1 6690395 37.4, 354614.4 6690397.1 37.4))
BATIMENT0000000302934314;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.6;34.8;37.4;;;Cadastre;A 1.0;POLYGON Z ((354611.8 6690399 37.4, 354615.6 6690404 37.4, 354618.1 6690402.1 37.4, 354614.4 6690397.1 37.4, 354611.8 6690399 37.4))
BATIMENT0000000302934315;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.5;34.8;37.3;;;Cadastre;A 1.0;POLYGON Z ((354609.3 6690401 37.3, 354612.9 6690406 37.3, 354615.6 6690404 37.3, 354611.8 6690399 37.3, 354609.3 6690401 37.3))
BATIMENT0000000302934316;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.5;34.8;37.3;;;Cadastre;A 1.0;POLYGON Z ((354606.6 6690402.9 37.3, 354610.2 6690408 37.3, 354612.9 6690406 37.3, 354609.3 6690401 37.3, 354606.6 6690402.9 37.3))
BATIMENT0000000302934317;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;2.4;34.8;37.2;;;Cadastre;A 1.0;POLYGON Z ((354603.9 6690405 37.2, 354607.7 6690409.8 37.2, 354610.2 6690408 37.2, 354606.6 6690402.9 37.2, 354603.9 6690405 37.2))
BATIMENT0000000302934298;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;13;40;12.1;34.9;47.0;;;Cadastre;A 1.0;POLYGON Z ((354594.9 6690414.7 47, 354604.2 6690426.7 47, 354606.8 6690430.1 47, 354613.3 6690425 47, 354601.5 6690409.6 47, 354594.9 6690414.7 47))
BATIMENT0000000302935357;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;09;01;3.7;34.4;38.1;38.3;34.6;Cadastre;A 1.0;POLYGON Z ((354715.3 6690318.2 38.1, 354718.7 6690322.8 38.1, 354721 6690321 38.1, 354717.7 6690316.3 38.1, 354715.3 6690318.2 38.1))
BATIMENT0000000302935358;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;3.6;34.4;38.1;38.2;34.6;Cadastre;A 1.0;POLYGON Z ((354712.9 6690320 38.1, 354716.6 6690324.5 38.1, 354718.7 6690322.8 38.1, 354715.3 6690318.2 38.1, 354712.9 6690320 38.1))
BATIMENT0000000302934773;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;50;40;15.0;34.3;49.3;50.9;34.9;Cadastre;A 0.6;POLYGON Z ((354756 6690334 49.3, 354762.6 6690329 49.3, 354752.3 6690315.6 49.3, 354745.7 6690320.6 49.3, 354756 6690334 49.3))
BATIMENT0000000302934771;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;50;40;15.9;34.2;50.1;51.7;34.7;Cadastre;A 1.0;POLYGON Z ((354705.9 6690329.1 50.1, 354709.3 6690333.7 50.1, 354712 6690337.4 50.1, 354716.2 6690342.9 50.1, 354723.3 6690337.4 50.1, 354713 6690323.8 50.1, 354705.9 6690329.1 50.1))
BATIMENT0000000302934772;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;50;40;15.2;34.4;49.6;50.9;34.7;Cadastre;A 1.0;POLYGON Z ((354766.3 6690347.6 49.6, 354773 6690342.6 49.6, 354762.6 6690329 49.6, 354756 6690334 49.6, 354766.3 6690347.6 49.6))
BATIMENT0000000302934780;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;15;40;14.2;32.4;46.6;47.9;33.7;Cadastre;A 1.0;POLYGON Z ((354724.1 6690344.6 46.6, 354716.8 6690350.3 46.6, 354725.6 6690361.8 46.6, 354729.4 6690366.8 46.6, 354736.7 6690361.2 46.6, 354724.1 6690344.6 46.6))
BATIMENT0000000302934781;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;13;90;14.5;32.2;46.7;47.7;33.4;Cadastre;A 1.0;POLYGON Z ((354733.8 6690372.6 46.7, 354737.9 6690377.9 46.7, 354740.5 6690381.5 46.7, 354742.4 6690383.9 46.7, 354749.7 6690378.2 46.7, 354736.7 6690361.2 46.7, 354729.4 6690366.8 46.7, 354733.8 6690372.6 46.7))
BATIMENT0000000302934692;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;4.0;30;20;9.0;31.6;40.6;45.5;33.7;Cadastre;C 0.7;POLYGON Z ((354773.4 6690400.6 40.6, 354767.9 6690396.4 40.6, 354789.6 6690368 40.6, 354783.4 6690363.3 40.6, 354757.1 6690398.2 40.6, 354758.4 6690399.1 40.6, 354758.6 6690400.4 40.6, 354759.9 6690401.4 40.6, 354761 6690401.1 40.6, 354774.5 6690411.5 40.6, 354776.6 6690411.3 40.6, 354802.4 6690377 40.6, 354799.8 6690375.2 40.6, 354795 6690371.7 40.6, 354773.4 6690400.6 40.6))
BATIMENT0000000302934783;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;13;90;13.4;33.4;46.8;47.5;33.4;Cadastre;A 1.0;POLYGON Z ((354721.8 6690400 46.8, 354729.3 6690394.1 46.8, 354727.6 6690391.9 46.8, 354724.9 6690388.5 46.8, 354720.9 6690383.3 46.8, 354716.1 6690377.1 46.8, 354708.7 6690382.9 46.8, 354721.8 6690400 46.8))
BATIMENT0000000302934256;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;30;20;9.5;31.5;41.0;46.1;32.5;Cadastre;C 0.7;POLYGON Z ((354760.6 6690431.2 41, 354760.5 6690428.3 41, 354744.4 6690412.9 41, 354732.9 6690424.7 41, 354738.4 6690430.1 41, 354741.6 6690426.9 41, 354743.9 6690429 41, 354745.2 6690427.7 41, 354747.2 6690429.6 41, 354750.5 6690432.8 41, 354754.8 6690436.7 41, 354760.6 6690431.2 41))
BATIMENT0000000302935244;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;50;40;16.3;34.7;51.0;52.1;34.9;Cadastre;A 1.0;POLYGON Z ((354651.7 6690370.8 51, 354655.6 6690375.9 51, 354658 6690379.1 51, 354662.3 6690384.6 51, 354669 6690379.2 51, 354658.7 6690365.5 51, 354651.7 6690370.8 51))
BATIMENT0000000302934318;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;40;12.8;35.0;47.8;;;Cadastre;A 1.0;POLYGON Z ((354623.5 6690392.4 47.8, 354635.5 6690407.7 47.8, 354642 6690402.7 47.8, 354634.2 6690392.5 47.8, 354630.3 6690387.3 47.8, 354623.5 6690392.4 47.8))
BATIMENT0000000302934299;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;40;13.1;33.9;47.0;;;Cadastre;A 1.0;POLYGON Z ((354677.4 6690394.6 47, 354673.4 6690397.6 47, 354674.2 6690398.6 47, 354670.8 6690401.4 47, 354673 6690404.4 47, 354679.2 6690412.3 47, 354686.6 6690406.6 47, 354677.4 6690394.6 47))
BATIMENT0000000302934307;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;13;90;14.9;32.0;46.9;47.4;33.9;Cadastre;A 1.0;POLYGON Z ((354640.8 6690409.2 46.9, 354656.2 6690429.1 46.9, 354663.8 6690423.4 46.9, 354654.1 6690411 46.9, 354648.2 6690403.5 46.9, 354640.8 6690409.2 46.9))
BATIMENT0000000302934300;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;34;40;13.0;33.9;46.9;;;Cadastre;A 1.0;POLYGON Z ((354684.9 6690419.6 46.9, 354689 6690424.9 46.9, 354694.3 6690431.8 46.9, 354701.6 6690426.2 46.9, 354686.6 6690406.6 46.9, 354679.2 6690412.3 46.9, 354684.9 6690419.6 46.9))
BATIMENT0000000302934308;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;13;30;14.9;32.0;46.9;47.3;33.6;Cadastre;A 1.0;POLYGON Z ((354656.2 6690429.1 46.9, 354671.6 6690448.6 46.9, 354679 6690442.8 46.9, 354678.4 6690442.1 46.9, 354677 6690440.2 46.9, 354672.1 6690434 46.9, 354668.5 6690429.4 46.9, 354663.8 6690423.4 46.9, 354656.2 6690429.1 46.9))
BATIMENT0000000302934303;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;35;90;11.9;34.2;46.1;;;Cadastre;A 1.0;POLYGON Z ((354618.5 6690452.6 46.1, 354631.4 6690469.1 46.1, 354638.8 6690463.4 46.1, 354625.9 6690446.8 46.1, 354618.5 6690452.6 46.1))
BATIMENT0000000302934302;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;34;40;14.4;31.7;46.2;47.2;32.7;Cadastre;A 1.0;POLYGON Z ((354631.4 6690469.1 46.2, 354632.8809948458 6690471.022695063 46.2, 354644.69851403637 6690471.022695063 46.2, 354638.8 6690463.4 46.2, 354631.4 6690469.1 46.2))
BATIMENT0000000302934262;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;50;20;10.7;31.3;42.0;46.5;32.5;Cadastre;C 0.6;POLYGON Z ((354699.9 6690462.7 42, 354695.9 6690462.3 42, 354686.55425529025 6690471.022695063 42, 354706.4965064569 6690471.022695063 42, 354699.9 6690462.7 42))
BATIMENT0000000302934293;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;34.7;38.0;;;Cadastre;;POLYGON Z ((354556.6 6690440.4 38, 354560.1 6690444.8 38, 354563.3 6690442.5 38, 354559.7 6690438 38, 354556.6 6690440.4 38))
BATIMENT0000000302934304;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;90;11.9;34.2;46.1;;;Cadastre;A 1.0;POLYGON Z ((354606 6690436.3 46.1, 354606.1 6690436.4 46.1, 354615.1 6690448.1 46.1, 354618.5 6690452.6 46.1, 354625.9 6690446.8 46.1, 354613.4 6690430.6 46.1, 354606 6690436.3 46.1))
BATIMENT0000000302934306;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;13;40;12.3;34.3;46.6;;;Cadastre;A 1.0;POLYGON Z ((354564.9 6690437.9 46.6, 354576.7 6690453.2 46.6, 354583.4 6690448 46.6, 354574.6 6690436.5 46.6, 354571.8 6690432.7 46.6, 354564.9 6690437.9 46.6))
BATIMENT0000000302934292;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;3.2;34.7;37.9;;;Cadastre;A 1.0;POLYGON Z ((354554 6690442.4 37.9, 354557.3 6690446.9 37.9, 354560.1 6690444.8 37.9, 354556.6 6690440.4 37.9, 354554 6690442.4 37.9))
BATIMENT0000000302934291;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.2;34.7;37.9;;;Cadastre;A 1.0;POLYGON Z ((354551.4 6690444.3 37.9, 354554.8 6690448.8 37.9, 354557.3 6690446.9 37.9, 354554 6690442.4 37.9, 354551.4 6690444.3 37.9))
BATIMENT0000000302934290;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;3.2;34.7;37.9;;;Cadastre;A 1.0;POLYGON Z ((354548.9 6690446.1 37.9, 354552.3 6690450.6 37.9, 354554.8 6690448.8 37.9, 354551.4 6690444.3 37.9, 354548.9 6690446.1 37.9))
BATIMENT0000000302934289;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;3.2;34.7;37.9;;;Cadastre;A 1.0;POLYGON Z ((354546.6 6690447.9 37.9, 354550 6690452.3 37.9, 354552.3 6690450.6 37.9, 354548.9 6690446.1 37.9, 354546.6 6690447.9 37.9))
BATIMENT0000000302934311;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;40;12.1;33.9;46.0;;;Cadastre;A 1.0;POLYGON Z ((354582.8 6690454.2 46, 354595.4 6690470.6 46, 354602.8 6690464.9 46, 354594 6690453.6 46, 354590.1 6690448.5 46, 354582.8 6690454.2 46))
BATIMENT0000000302934310;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;5.0;10;40;12.2;33.9;46.1;;;Cadastre;A 1.0;POLYGON Z ((354595.4 6690470.6 46.1, 354595.7304706857 6690471.022695063 46.1, 354607.57863091835 6690471.022695063 46.1, 354606.7 6690469.9 46.1, 354602.8 6690464.9 46.1, 354595.4 6690470.6 46.1))
BATIMENT0000000302934257;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;11.2;30.9;42.1;45.8;31.5;Cadastre;A 1.0;POLYGON Z ((354746.1 6690445.3 42.1, 354754.8 6690436.7 42.1, 354750.5 6690432.8 42.1, 354747.2 6690429.6 42.1, 354744.9 6690431.8 42.1, 354743.6 6690433 42.1, 354739.1 6690437.5 42.1, 354746.1 6690445.3 42.1))
BATIMENT0000000302934258;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;10.3;30.1;40.4;44.2;31.7;Cadastre;A 1.0;POLYGON Z ((354738 6690436.3 40.4, 354733.5 6690440 40.4, 354736.7 6690443.8 40.4, 354741.8 6690449.6 40.4, 354746.1 6690445.3 40.4, 354739.1 6690437.5 40.4, 354738 6690436.3 40.4))
BATIMENT0000000302936933;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;30.5;39.5;47.0;31.1;Cadastre;;POLYGON Z ((354771.1 6690452.4 39.5, 354774 6690449.5 39.5, 354768.5 6690443.9 39.5, 354763.4 6690444 39.5, 354771.1 6690452.4 39.5))
BATIMENT0000000302934259;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;30;20;7.1;30.8;38.0;44.5;32.1;Cadastre;C 0.8;POLYGON Z ((354720.5 6690458.9 38, 354719 6690458.8 38, 354718.8 6690457.2 38, 354717.2 6690455.5 38, 354715.6 6690455.5 38, 354715.8 6690453.6 38, 354730.3 6690439.1 38, 354724.3 6690433.6 38, 354717.6 6690440.8 38, 354710.4 6690447.8 38, 354707.2 6690451.2 38, 354706.9 6690455.3 38, 354717.7 6690469 38, 354720.8 6690469.2 38, 354724 6690466.2 38, 354723.9 6690466 38, 354734.2 6690457 38, 354735.1 6690456.2 38, 354741.8 6690449.6 38, 354736.7 6690443.8 38, 354720.5 6690458.9 38))
BATIMENT0000000302936934;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;35;30;15.6;30.6;46.3;47.1;31.2;Cadastre;B 0.3;POLYGON Z ((354763.2 6690462.9 46.3, 354761.7 6690461.3 46.3, 354767.2 6690455.6 46.3, 354767.5 6690456 46.3, 354769.6 6690453.9 46.3, 354771.1 6690452.4 46.3, 354763.4 6690444 46.3, 354748.7 6690458.3 46.3, 354757.9 6690468.1 46.3, 354763.2 6690462.9 46.3))
BATIMENT0000000302934212;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;20;20;7.0;30.7;37.7;46.2;31.1;Cadastre;A 1.0;POLYGON Z ((354743.9 6690462.8 37.7, 354749.9 6690469.1 37.7, 354751.8226950631 6690471.022695063 37.7, 354754.97730493697 6690471.022695063 37.7, 354757.9 6690468.1 37.7, 354748.7 6690458.3 37.7, 354743.9 6690462.8 37.7))
BATIMENT0000000302934214;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.5;29.7;38.2;41.0;30.3;Cadastre;A 1.0;POLYGON Z ((354777.5 6690466.9 38.2, 354781.8323236252 6690471.022695063 38.2, 354785.4511680999 6690471.022695063 38.2, 354790.4 6690466 38.2, 354784.5 6690460 38.2, 354777.5 6690466.9 38.2))
BATIMENT0000000302934213;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;5.4;30.0;35.4;37.8;30.9;Cadastre;A 1.0;POLYGON Z ((354767.5 6690456 35.4, 354767.2 6690455.6 35.4, 354761.7 6690461.3 35.4, 354763.2 6690462.9 35.4, 354757.9 6690468.1 35.4, 354754.97730493697 6690471.022695063 35.4, 354773.3773049373 6690471.022695063 35.4, 354777.5 6690466.9 35.4, 354784.5 6690460 35.4, 354778 6690453.5 35.4, 354773.6 6690457.9 35.4, 354769.6 6690453.9 35.4, 354767.5 6690456 35.4))
BATIMENT0000000302934209;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;5.0;10;20;16.0;30.2;46.2;49.4;31.2;Cadastre;A 1.0;POLYGON Z ((354743.9 6690462.8 46.2, 354739.3 6690467.3 46.2, 354738.85327659245 6690471.022695063 46.2, 354748.0512547475 6690471.022695063 46.2, 354749.9 6690469.1 46.2, 354743.9 6690462.8 46.2))
BATIMENT0000000302944755;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.5;30.6;35.1;36.2;31.3;Cadastre;C 0.2;POLYGON Z ((355028 6690267.3 35.1, 355018.4 6690273.6 35.1, 355020.6 6690276.9 35.1, 355025.6 6690273.7 35.1, 355030.2 6690270.7 35.1, 355028 6690267.3 35.1))
BATIMENT0000000302934582;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;13;20;18.0;31.9;50.0;52.5;33.3;Cadastre;A 1.0;POLYGON Z ((354955.2 6690265.1 50, 354951.1 6690262.4 50, 354947.9 6690260.5 50, 354940.7 6690272.3 50, 354958.9 6690283.9 50, 354959.4 6690284.1 50, 354961.7 6690280.1 50, 354965.3 6690275.2 50, 354967.3 6690272.8 50, 354966.2 6690272 50, 354955.2 6690265.1 50))
BATIMENT0000000302944754;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.9;30.6;35.5;39.2;31.0;Cadastre;B 0.3;POLYGON Z ((355029.9 6690280.6 35.5, 355034.5 6690277.8 35.5, 355030.2 6690270.7 35.5, 355025.6 6690273.7 35.5, 355029.9 6690280.6 35.5))
BATIMENT0000000302944753;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;30.7;32.2;34.4;31.1;Cadastre;;POLYGON Z ((355030.9 6690281.7 32.2, 355032.8 6690284.2 32.2, 355036.5 6690281.4 32.2, 355035.3 6690279 32.2, 355030.9 6690281.7 32.2))
BATIMENT0000000302934581;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;00;00;8.3;31.3;39.7;50.8;33.3;Cadastre;C 0.6;POLYGON Z ((354985.4 6690300.5 39.7, 354987.1 6690297.7 39.7, 354990.1 6690295.6 39.7, 354998.2 6690290.8 39.7, 355004 6690287.1 39.7, 355006.1 6690283.4 39.7, 354975.8 6690264.5 39.7, 354968.8 6690271.3 39.7, 354967.3 6690272.8 39.7, 354965.3 6690275.2 39.7, 354961.7 6690280.1 39.7, 354959.4 6690284.1 39.7, 354985.4 6690300.5 39.7))
BATIMENT0000000302934583;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;30.8;44.4;47.7;32.6;Cadastre;;POLYGON Z ((354988.4 6690302.4 44.4, 354991.8 6690296.8 44.4, 354990.1 6690295.6 44.4, 354987.1 6690297.7 44.4, 354985.4 6690300.5 44.4, 354988.4 6690302.4 44.4))
BATIMENT0000000302934586;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;9.1;29.2;38.3;42.4;32.0;Cadastre;B 0.6;POLYGON Z ((354999.3 6690298.8 38.3, 354998.5 6690300.1 38.3, 354997.2 6690299.3 38.3, 354993.8 6690304.6 38.3, 355008.3 6690313.7 38.3, 355012.5 6690307.3 38.3, 354999.3 6690298.8 38.3))
BATIMENT0000000302934538;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;30;30;19.0;29.9;49.0;52.6;32.7;Cadastre;A 1.0;POLYGON Z ((354940.8 6690305.7 49, 354972.7 6690325.7 49, 354975 6690322.1 49, 354980.2 6690314.2 49, 354968.3 6690306.7 49, 354963.6 6690303.6 49, 354958.8 6690300.6 49, 354948.2 6690293.8 49, 354940.8 6690305.7 49))
BATIMENT0000000302944156;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;20;10.3;29.8;40.1;41.6;31.4;Cadastre;A 1.0;POLYGON Z ((355015.9 6690318.5 40.1, 355021.7 6690309.7 40.1, 355022 6690309.2 40.1, 355018.4 6690307 40.1, 355019.1 6690305.6 40.1, 355015.5 6690303.2 40.1, 355012.5 6690307.3 40.1, 355008.3 6690313.7 40.1, 355015.9 6690318.5 40.1))
BATIMENT0000000302944155;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;32;10;10.0;29.4;39.4;42.1;31.6;Cadastre;A 1.0;POLYGON Z ((355026.2 6690325 39.4, 355031.5 6690316.8 39.4, 355030.2 6690315.8 39.4, 355030.3 6690315.6 39.4, 355021.7 6690309.7 39.4, 355015.9 6690318.5 39.4, 355026.2 6690325 39.4))
BATIMENT0000000302934508;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;33.5;49.1;50.2;33.7;Cadastre;;POLYGON Z ((354897.4 6690317.3 49.1, 354897.2 6690317.6 49.1, 354901.2 6690321.3 49.1, 354902.7 6690319.6 49.1, 354898.7 6690315.9 49.1, 354897.4 6690317.3 49.1))
BATIMENT0000000302934473;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;31.5;35.7;36.7;33.2;Cadastre;;POLYGON Z ((354926.4 6690314 35.7, 354925.9 6690314.4 35.7, 354924.5 6690317 35.7, 354932.8 6690325.4 35.7, 354933.5 6690324.6 35.7, 354935.1 6690322.9 35.7, 354926.4 6690314 35.7))
BATIMENT0000000302934507;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;8.4;33.0;41.5;44.0;33.6;Cadastre;A 1.0;POLYGON Z ((354902 6690322.1 41.5, 354902.9 6690323.2 41.5, 354907.8 6690327.7 41.5, 354910.3 6690322.5 41.5, 354908 6690319.2 41.5, 354906.5 6690317 41.5, 354902 6690322.1 41.5))
BATIMENT0000000302934474;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;31.6;34.5;35.7;33.2;Cadastre;;POLYGON Z ((354935.1 6690326.3 34.5, 354936.8 6690324.6 34.5, 354935.1 6690322.9 34.5, 354933.5 6690324.6 34.5, 354935.1 6690326.3 34.5))
BATIMENT0000000302934496;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;19;90;7.0;33.0;40.0;42.1;33.7;Cadastre;B 0.8;POLYGON Z ((354899.7 6690326.7 40, 354904.1 6690331 40, 354907.5 6690327.9 40, 354907.8 6690327.7 40, 354902.9 6690323.2 40, 354899.7 6690326.7 40))
BATIMENT0000000302934488;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;34.0;37.2;;;Cadastre;;POLYGON Z ((354875.9 6690330.7 37.2, 354880.1 6690334.2 37.2, 354881.8 6690332.1 37.2, 354879.5 6690329.9 37.2, 354883.4 6690325.1 37.2, 354881.6 6690323.4 37.2, 354875.9 6690330.7 37.2))
BATIMENT0000000302934478;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;32.9;34.7;37.0;33.1;Cadastre;;POLYGON Z ((354930.1 6690330.9 34.7, 354931.4 6690332.3 34.7, 354933.6 6690330.1 34.7, 354932.1 6690328.6 34.7, 354930.1 6690330.9 34.7))
BATIMENT0000000302934479;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;12.4;31.2;43.6;46.2;33.4;Cadastre;A 1.0;POLYGON Z ((354916.8 6690329.5 43.6, 354917.2 6690331.1 43.6, 354925.2 6690338.8 43.6, 354929.5 6690334.2 43.6, 354928.9 6690333.6 43.6, 354928.6 6690333.8 43.6, 354923.8 6690329.2 43.6, 354925.8 6690327.2 43.6, 354921.1 6690322.6 43.6, 354916.8 6690329.5 43.6))
BATIMENT0000000302934475;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;31.0;36.1;39.5;33.1;Cadastre;;POLYGON Z ((354946.2 6690334.3 36.1, 354937.8 6690325.7 36.1, 354935.5 6690327.9 36.1, 354944 6690336.5 36.1, 354946.2 6690334.3 36.1))
BATIMENT0000000302934493;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;7.9;33.5;41.5;43.2;33.8;Cadastre;A 1.0;POLYGON Z ((354890.3 6690343.5 41.5, 354896.4 6690337.8 41.5, 354899.5 6690334.8 41.5, 354895.7 6690331.7 41.5, 354886.7 6690340.2 41.5, 354890.3 6690343.5 41.5))
BATIMENT0000000302934537;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;;;10.0;30.5;40.6;44.0;32.0;Cadastre;A 1.0;POLYGON Z ((354975 6690322.1 40.6, 354980.3 6690325.6 40.6, 354985.4 6690317.4 40.6, 354980.2 6690314.2 40.6, 354975 6690322.1 40.6))
BATIMENT0000000302944154;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;23;9.5;29.1;38.7;41.4;31.1;Cadastre;A 0.7;POLYGON Z ((355035.7 6690331 38.7, 355041.3 6690322.6 38.7, 355031.7 6690316.5 38.7, 355031.5 6690316.8 38.7, 355026.2 6690325 38.7, 355035.7 6690331 38.7))
BATIMENT0000000302934534;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;30;90;14.8;30.3;45.2;46.1;33.2;Cadastre;A 1.0;POLYGON Z ((354980.3 6690325.6 45.2, 354976.5 6690331.8 45.2, 354983.6 6690336.8 45.2, 354985.6 6690333.7 45.2, 354987.6 6690330.6 45.2, 354992.9 6690322.1 45.2, 354985.4 6690317.4 45.2, 354980.3 6690325.6 45.2))
BATIMENT0000000302934535;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;20;20;9.8;31.8;41.6;;;Cadastre;A 1.0;POLYGON Z ((354994 6690334.8 41.6, 354993.8 6690335.2 41.6, 354996.9 6690337.2 41.6, 355002.5 6690328.2 41.6, 354992.9 6690322.1 41.6, 354987.6 6690330.6 41.6, 354994 6690334.8 41.6))
BATIMENT0000000302934533;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;30.7;34.0;37.7;33.1;Cadastre;;POLYGON Z ((354983.6 6690336.8 34, 354983.2 6690337.7 34, 354985.4 6690338.8 34, 354987.7 6690335 34, 354985.6 6690333.7 34, 354983.6 6690336.8 34))
BATIMENT0000000302934536;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;9.7;29.7;39.4;42.2;31.2;Cadastre;B 0.9;POLYGON Z ((354996.9 6690337.2 39.4, 354994.8 6690340.6 39.4, 355001.1 6690344.6 39.4, 355003.2 6690341.2 39.4, 355007.4 6690343.9 39.4, 355008.1 6690342.9 39.4, 355013.1 6690334.9 39.4, 355002.5 6690328.2 39.4, 354996.9 6690337.2 39.4))
BATIMENT0000000302944151;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.6;30.4;39.0;41.0;30.6;Cadastre;A 1.0;POLYGON Z ((355008.1 6690342.9 39, 355010.2 6690344.1 39, 355009.9 6690344.7 39, 355018.7 6690350 39, 355016.2 6690354.2 39, 355020.4 6690356.7 39, 355022 6690354.1 39, 355028 6690344.3 39, 355013.1 6690334.9 39, 355008.1 6690342.9 39))
BATIMENT0000000302935362;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.5;32.2;35.7;45.2;33.1;Cadastre;;POLYGON Z ((354958.9 6690347.5 35.7, 354962.4 6690351.2 35.7, 354963.8 6690352.5 35.7, 354965.5 6690350 35.7, 354960.1 6690345.8 35.7, 354958.9 6690347.5 35.7))
BATIMENT0000000302934103;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.7;31.0;40.7;42.7;32.6;Cadastre;A 1.0;POLYGON Z ((354959.9 6690361.4 40.7, 354954.4 6690366.9 40.7, 354960.1 6690372.3 40.7, 354965.6 6690366.5 40.7, 354959.9 6690361.4 40.7))
BATIMENT0000000302934115;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;31.0;35.2;37.0;32.4;Cadastre;;POLYGON Z ((354977.9 6690367.1 35.2, 354978.8 6690368.2 35.2, 354983.4 6690372.5 35.2, 354988 6690368.3 35.2, 354981.1 6690362.3 35.2, 354977.9 6690367.1 35.2))
BATIMENT0000000302934694;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;50;20;11.9;32.7;44.6;48.2;35.1;Cadastre;C 0.7;POLYGON Z ((354817.3 6690312.4 44.6, 354818.5 6690313 44.6, 354817.4 6690314.9 44.6, 354822.8 6690318.2 44.6, 354825.5 6690314 44.6, 354827.2 6690310.4 44.6, 354833.3 6690313.3 44.6, 354827.2 6690325.8 44.6, 354812.8 6690347.9 44.6, 354814.6 6690348.6 44.6, 354820.3 6690351.7 44.6, 354824.4 6690345.3 44.6, 354834.3 6690330.5 44.6, 354841.2 6690316.2 44.6, 354842.4 6690313.6 44.6, 354844 6690309.8 44.6, 354841.7 6690308.7 44.6, 354828.3 6690302.7 44.6, 354824.2 6690300.6 44.6, 354823 6690302.9 44.6, 354822.2 6690302.4 44.6, 354817.3 6690312.4 44.6))
BATIMENT0000000302935048;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;20;7.9;33.6;41.5;45.1;35.0;Cadastre;C 0.6;POLYGON Z ((354806.7 6690328.1 41.5, 354813.2 6690332 41.5, 354817.5 6690325.2 41.5, 354811 6690321.3 41.5, 354806.7 6690328.1 41.5))
BATIMENT0000000302934491;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.1;34.0;40.1;43.2;34.2;Cadastre;;POLYGON Z ((354862.6 6690322.9 40.1, 354866 6690325.8 40.1, 354862.8 6690329.2 40.1, 354872.1 6690337.5 40.1, 354876.5 6690332.7 40.1, 354885.8 6690341.4 40.1, 354886.7 6690340.2 40.1, 354880.1 6690334.2 40.1, 354875.9 6690330.7 40.1, 354864.3 6690320 40.1, 354862.6 6690322.9 40.1))
BATIMENT0000000302934173;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;12.4;33.2;45.7;48.4;34.0;Cadastre;C 0.5;POLYGON Z ((354851.1 6690343.8 45.7, 354850.3 6690342.9 45.7, 354842.2 6690336.5 45.7, 354837.5 6690343.7 45.7, 354846.6 6690349.5 45.7, 354847.1 6690348.8 45.7, 354851.1 6690343.8 45.7))
BATIMENT0000000302934172;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;33.6;40.5;42.2;34.0;Cadastre;;POLYGON Z ((354848.6 6690350.6 40.5, 354849.1 6690350 40.5, 354847.1 6690348.8 40.5, 354846.6 6690349.5 40.5, 354848.6 6690350.6 40.5))
BATIMENT0000000302936948;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;;;9.5;33.2;42.7;47.2;34.0;Cadastre;C 0.8;POLYGON Z ((354850.3 6690342.9 42.7, 354851.1 6690343.8 42.7, 354853.4 6690346.4 42.7, 354858.5 6690352.1 42.7, 354858.8 6690351.7 42.7, 354863.6 6690356.6 42.7, 354883.9 6690377.6 42.7, 354887.4 6690373.7 42.7, 354887.7 6690373.4 42.7, 354886.4 6690372 42.7, 354891.4 6690366.4 42.7, 354876.2 6690352.2 42.7, 354872.2 6690356.5 42.7, 354868.2 6690352.4 42.7, 354857.4 6690341.8 42.7, 354845.5 6690331 42.7, 354842.5 6690336.2 42.7, 354842.2 6690336.5 42.7, 354850.3 6690342.9 42.7))
BATIMENT0000000302934693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;4.0;00;00;11.8;32.0;43.8;48.3;34.8;Cadastre;A 1.0;POLYGON Z ((354800.4 6690351.1 43.8, 354802.8 6690352.6 43.8, 354798.3 6690360 43.8, 354806.4 6690366.1 43.8, 354808.9 6690368 43.8, 354820.3 6690351.7 43.8, 354814.6 6690348.6 43.8, 354812.8 6690347.9 43.8, 354811.3 6690347.3 43.8, 354807.3 6690345.9 43.8, 354806.7 6690345.7 43.8, 354803.6 6690344.6 43.8, 354803 6690346 43.8, 354800.4 6690351.1 43.8), (354808.9 6690352.4 43.8, 354812.4 6690353.9 43.8, 354811.6 6690355.7 43.8, 354808.1 6690354.2 43.8, 354808.9 6690352.4 43.8))
BATIMENT0000000302934163;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;33.5;41.1;;;Cadastre;;POLYGON Z ((354848.4 6690360.9 41.1, 354849.1 6690360.2 41.1, 354848 6690358.9 41.1, 354847.1 6690359.9 41.1, 354848.4 6690360.9 41.1))
BATIMENT0000000302934189;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.2;32.9;37.1;40.2;34.0;Cadastre;C 0.5;POLYGON Z ((354852.4 6690354.4 37.1, 354860 6690362.3 37.1, 354866.7 6690369.5 37.1, 354869.9 6690372.8 37.1, 354871.8 6690371.1 37.1, 354872.5 6690370.5 37.1, 354851.7 6690348.3 37.1, 354849.5 6690351.1 37.1, 354852.4 6690354.4 37.1))
BATIMENT0000000302934162;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;10;20;7.2;33.5;40.7;48.1;34.2;Cadastre;A 1.0;POLYGON Z ((354834.2 6690348.5 40.7, 354828.8 6690356.6 40.7, 354834.7 6690361.2 40.7, 354839 6690365.6 40.7, 354839.3 6690365.9 40.7, 354840.1 6690366.8 40.7, 354842.2 6690369 40.7, 354846.4 6690373.2 40.7, 354845.9 6690373.9 40.7, 354847.7 6690376 40.7, 354856 6690383.2 40.7, 354859 6690385.9 40.7, 354861.8 6690388.2 40.7, 354867.7 6690381.5 40.7, 354865.1 6690379 40.7, 354862.1 6690382.4 40.7, 354859 6690379.6 40.7, 354859.5 6690379.1 40.7, 354851.6 6690372.1 40.7, 354851.3 6690371.8 40.7, 354851.7 6690371.5 40.7, 354850.8 6690370.5 40.7, 354845 6690365 40.7, 354842 6690362 40.7, 354843.2 6690360.6 40.7, 354842.4 6690359.8 40.7, 354840.7 6690358.3 40.7, 354841.5 6690357.1 40.7, 354843.5 6690358.6 40.7, 354846.2 6690360.9 40.7, 354847.1 6690359.9 40.7, 354848 6690358.9 40.7, 354849.1 6690360.2 40.7, 354855.4 6690366.5 40.7, 354857.6 6690364.6 40.7, 354860 6690362.3 40.7, 354852.4 6690354.4 40.7, 354849.5 6690351.1 40.7, 354848.6 6690350.6 40.7, 354846.6 6690349.5 40.7, 354837.5 6690343.7 40.7, 354834.2 6690348.5 40.7))
BATIMENT0000000302934495;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.8;33.3;41.1;44.1;33.7;Cadastre;A 1.0;POLYGON Z ((354899.5 6690334.8 41.1, 354896.4 6690337.8 41.1, 354903.7 6690344.8 41.1, 354904.4 6690344.1 41.1, 354911.2 6690338 41.1, 354904.1 6690331 41.1, 354899.5 6690334.8 41.1))
BATIMENT0000000302934477;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;50;20;8.2;32.7;41.0;43.9;33.2;Cadastre;B 0.9;POLYGON Z ((354931.3 6690332.5 41, 354929.5 6690334.2 41, 354925.2 6690338.8 41, 354934 6690347.2 41, 354939.9 6690340.8 41, 354931.3 6690332.5 41))
BATIMENT0000000302934497;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;8.4;32.6;41.0;43.7;33.7;Cadastre;A 1.0;POLYGON Z ((354904.4 6690344.1 41, 354906.4 6690346 41, 354904 6690348.6 41, 354906.6 6690351.1 41, 354909.1 6690348.5 41, 354915.6 6690342.2 41, 354911.2 6690338 41, 354904.4 6690344.1 41))
BATIMENT0000000302934492;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;33.5;37.1;41.7;33.8;Cadastre;;POLYGON Z ((354895.5 6690351.9 37.1, 354897.4 6690349.9 37.1, 354890.3 6690343.5 37.1, 354886.7 6690340.2 37.1, 354885.8 6690341.4 37.1, 354884.9 6690342.3 37.1, 354895.5 6690351.9 37.1))
BATIMENT0000000302934498;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.1;32.0;41.1;44.1;33.5;Cadastre;A 1.0;POLYGON Z ((354909.1 6690348.5 41.1, 354913.8 6690353 41.1, 354920.1 6690346.5 41.1, 354915.6 6690342.2 41.1, 354909.1 6690348.5 41.1))
BATIMENT0000000302934476;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;00;00;10.1;31.0;41.1;47.5;33.2;Cadastre;A 1.0;POLYGON Z ((354944 6690336.5 41.1, 354939.9 6690340.8 41.1, 354934 6690347.2 41.1, 354950.7 6690363.2 41.1, 354957 6690356.8 41.1, 354952 6690351.9 41.1, 354955.6 6690348 41.1, 354954 6690346.5 41.1, 354956 6690344.5 41.1, 354946.2 6690334.3 41.1, 354944 6690336.5 41.1))
BATIMENT0000000302934499;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.5;31.7;41.2;44.1;33.5;Cadastre;A 1.0;POLYGON Z ((354913.8 6690353 41.2, 354918.3 6690357.3 41.2, 354918.7 6690357.1 41.2, 354924.6 6690350.9 41.2, 354920.1 6690346.5 41.2, 354913.8 6690353 41.2))
BATIMENT0000000302934500;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.8;31.5;41.3;43.7;33.3;Cadastre;A 1.0;POLYGON Z ((354918.7 6690357.1 41.3, 354918.3 6690357.3 41.3, 354923.1 6690361.4 41.3, 354923.5 6690361 41.3, 354929 6690355.1 41.3, 354924.6 6690350.9 41.3, 354918.7 6690357.1 41.3))
BATIMENT0000000327820006;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:38:05;2018-09-18 13:36:50;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.5;32.7;;39.7;33.8;Imagerie aérienne;;POLYGON Z ((354901 6690365.8 36.2, 354906.8 6690359.6 36.2, 354899.6 6690353.1 36.2, 354893.7 6690359.4 36, 354901 6690365.8 36.2))
BATIMENT0000000302934501;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;6.9;32.4;39.4;45.7;33.1;Cadastre;A 1.0;POLYGON Z ((354923.5 6690361 39.4, 354930.4 6690367.6 39.4, 354935.9 6690361.7 39.4, 354929 6690355.1 39.4, 354923.5 6690361 39.4))
BATIMENT0000000302934165;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;33.1;36.7;38.9;34.1;Cadastre;;POLYGON Z ((354864.6 6690371.6 36.7, 354866.7 6690369.5 36.7, 354860 6690362.3 36.7, 354857.6 6690364.6 36.7, 354864.6 6690371.6 36.7))
BATIMENT0000000302934691;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;11.8;32.6;44.4;47.2;33.5;Cadastre;A 1.0;POLYGON Z ((354792.9 6690367 44.4, 354791.3 6690369.2 44.4, 354795 6690371.7 44.4, 354799.8 6690375.2 44.4, 354806.4 6690366.1 44.4, 354798.3 6690360 44.4, 354792.9 6690367 44.4))
BATIMENT0000000302934160;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;12.2;32.7;45.0;47.6;33.4;Cadastre;A 1.0;POLYGON Z ((354830.6 6690376.5 45, 354832.3 6690373.7 45, 354834.9 6690369.8 45, 354839 6690365.6 45, 354834.7 6690361.2 45, 354828.8 6690356.6 45, 354819.8 6690370.3 45, 354828.4 6690378.5 45, 354832 6690381 45, 354833.9 6690378.6 45, 354830.6 6690376.5 45))
BATIMENT0000000302934164;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;33.5;37.4;37.6;34.0;Cadastre;;POLYGON Z ((354853.7 6690369.3 37.4, 354852.9 6690368.6 37.4, 354850.8 6690370.5 37.4, 354851.7 6690371.5 37.4, 354853.7 6690369.3 37.4))
BATIMENT0000000302934203;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;33.0;36.5;39.1;33.6;Cadastre;;POLYGON Z ((354870.5 6690373.5 36.5, 354871.3 6690374.3 36.5, 354873.4 6690376.2 36.5, 354873.8 6690376.8 36.5, 354875.6 6690375.1 36.5, 354871.8 6690371.1 36.5, 354869.9 6690372.8 36.5, 354870.5 6690373.5 36.5))
BATIMENT0000000302934187;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;33.5;37.2;;;Cadastre;;POLYGON Z ((354867.2 6690378.9 37.2, 354868.7 6690380.2 37.2, 354869.4 6690380.8 37.2, 354869.8 6690380.4 37.2, 354873.4 6690376.2 37.2, 354871.3 6690374.3 37.2, 354867.2 6690378.9 37.2))
BATIMENT0000000302934156;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;8.8;32.6;41.5;45.7;33.3;Cadastre;C 0.6;POLYGON Z ((354819.8 6690370.3 41.5, 354817 6690374.4 41.5, 354825.2 6690382.7 41.5, 354824.2 6690384.2 41.5, 354826.1 6690386.5 41.5, 354826.7 6690387.5 41.5, 354829.2 6690384.7 41.5, 354827.6 6690383 41.5, 354826.2 6690381.7 41.5, 354828.4 6690378.5 41.5, 354819.8 6690370.3 41.5))
BATIMENT0000000302934161;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;33.5;36.8;;;Cadastre;;POLYGON Z ((354834.1 6690382.6 36.8, 354836.6 6690379.7 36.8, 354834.5 6690378.2 36.8, 354833.9 6690378.6 36.8, 354832 6690381 36.8, 354834.1 6690382.6 36.8))
BATIMENT0000000302934158;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;32.9;38.7;40.2;33.3;Cadastre;;POLYGON Z ((354829.5 6690380.8 38.7, 354827.6 6690383 38.7, 354829.2 6690384.7 38.7, 354831.2 6690382.2 38.7, 354829.5 6690380.8 38.7))
BATIMENT0000000302934185;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;9.6;32.5;42.2;44.1;33.3;Cadastre;C 0.9;POLYGON Z ((354824.2 6690384.2 42.2, 354825.2 6690382.7 42.2, 354817 6690374.4 42.2, 354812.2 6690381.5 42.2, 354816.9 6690386.1 42.2, 354816.6 6690386.6 42.2, 354820.2 6690390.4 42.2, 354820.9 6690391.1 42.2, 354824.6 6690388 42.2, 354826.1 6690386.5 42.2, 354824.2 6690384.2 42.2))
BATIMENT0000000302934502;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;10.7;31.5;42.2;46.2;33.1;Cadastre;A 1.0;POLYGON Z ((354930.4 6690367.6 42.2, 354929.1 6690368.9 42.2, 354933.9 6690373.5 42.2, 354934.4 6690372.9 42.2, 354941.1 6690379.6 42.2, 354941.7 6690378.9 42.2, 354947.5 6690372.6 42.2, 354940.9 6690366.5 42.2, 354935.9 6690361.7 42.2, 354930.4 6690367.6 42.2))
BATIMENT0000000302934503;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;8.6;32.1;40.7;46.0;32.9;Cadastre;A 1.0;POLYGON Z ((354941.7 6690378.9 40.7, 354945.8 6690383 40.7, 354951.7 6690376.8 40.7, 354947.5 6690372.6 40.7, 354941.7 6690378.9 40.7))
BATIMENT0000000302934206;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;32.8;34.2;36.5;33.6;Cadastre;;POLYGON Z ((354881.2 6690384.6 34.2, 354883 6690382.7 34.2, 354879.2 6690378.9 34.2, 354877.4 6690380.6 34.2, 354881.2 6690384.6 34.2))
BATIMENT0000000302934191;Indifférenciée;Sportif;;Oui;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.4;32.0;37.4;38.8;33.5;Cadastre;C 0.2;POLYGON Z ((354927.9 6690402.9 37.4, 354934.1 6690396.9 37.4, 354941 6690390.4 37.4, 354939.9 6690389.2 37.4, 354935.5 6690385.2 37.4, 354923.8 6690374.3 37.4, 354916.8 6690367.8 37.4, 354912.2 6690363.6 37.4, 354907.7 6690359.4 37.4, 354907.3 6690359 37.4, 354906.8 6690359.6 37.4, 354901 6690365.8 37.4, 354893.2 6690374.3 37.4, 354926.1 6690404.8 37.4, 354927.9 6690402.9 37.4))
BATIMENT0000000302936947;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;32.6;38.1;42.5;33.3;Cadastre;;POLYGON Z ((354912.8 6690407.6 38.1, 354916.6 6690411.5 38.1, 354917.7 6690412.7 38.1, 354921.8 6690409.1 38.1, 354924.1 6690406.8 38.1, 354897.4 6690379.2 38.1, 354895 6690381.4 38.1, 354887.4 6690373.7 38.1, 354883.9 6690377.6 38.1, 354912.8 6690407.6 38.1))
BATIMENT0000000302934175;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;33.2;36.3;36.4;33.7;Cadastre;;POLYGON Z ((354881.7 6690390.9 36.3, 354881.2 6690391.4 36.3, 354882.2 6690392.2 36.3, 354885.9 6690395.4 36.3, 354890.4 6690399.3 36.3, 354895.2 6690403.4 36.3, 354899.5 6690407 36.3, 354901.6 6690408.7 36.3, 354904.7 6690405.7 36.3, 354885.4 6690387.4 36.3, 354884.5 6690388.1 36.3, 354881.7 6690390.9 36.3))
BATIMENT0000000302934190;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;33.5;36.6;37.5;33.6;Cadastre;;POLYGON Z ((354885.9 6690395.4 36.6, 354883.6 6690398.2 36.6, 354879 6690403.5 36.6, 354883.5 6690407.4 36.6, 354883.9 6690406.9 36.6, 354883.9 6690406.6 36.6, 354890.4 6690399.3 36.6, 354885.9 6690395.4 36.6))
BATIMENT0000000302934511;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;31.9;33.6;34.0;32.3;Cadastre;;POLYGON Z ((354938.5 6690400.8 33.6, 354937.7 6690401.5 33.6, 354938.6 6690402.7 33.6, 354939.6 6690401.8 33.6, 354938.5 6690400.8 33.6))
BATIMENT0000000302934506;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;8.5;31.6;40.2;45.9;32.4;Cadastre;A 1.0;POLYGON Z ((354949.3 6690410.2 40.2, 354950.6 6690408.3 40.2, 354950 6690407.8 40.2, 354953.1 6690404.7 40.2, 354954.8 6690402.5 40.2, 354947.2 6690395.6 40.2, 354945.2 6690398.1 40.2, 354945.8 6690398.9 40.2, 354941.7 6690403.6 40.2, 354945 6690406.3 40.2, 354949.3 6690410.2 40.2))
BATIMENT0000000302934193;Indifférenciée;Sportif;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.6;32.0;35.6;35.7;33.1;Cadastre;C 0.3;POLYGON Z ((354926.1 6690404.8 35.6, 354924.1 6690406.8 35.6, 354921.8 6690409.1 35.6, 354926.4 6690413.3 35.6, 354932.2 6690406 35.6, 354927.9 6690402.9 35.6, 354926.1 6690404.8 35.6))
BATIMENT0000000302934102;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.6;31.0;40.6;42.9;32.6;Cadastre;A 1.0;POLYGON Z ((354965.6 6690366.5 40.6, 354960.1 6690372.3 40.6, 354964.4 6690376.4 40.6, 354970.5 6690369.9 40.6, 354966.4 6690365.8 40.6, 354965.6 6690366.5 40.6))
BATIMENT0000000302934116;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;31.1;34.7;36.5;31.7;Cadastre;;POLYGON Z ((354983.4 6690372.5 34.7, 354986 6690375.1 34.7, 354986.8 6690376 34.7, 354987.6 6690374.8 34.7, 354986.8 6690374.2 34.7, 354990 6690369.5 34.7, 354988 6690368.3 34.7, 354983.4 6690372.5 34.7))
BATIMENT0000000302934101;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.4;31.0;40.4;42.6;32.4;Cadastre;A 1.0;POLYGON Z ((354964.4 6690376.4 40.4, 354967.9 6690380 40.4, 354970.3 6690379.7 40.4, 354974.6 6690373.9 40.4, 354970.5 6690369.9 40.4, 354964.4 6690376.4 40.4))
BATIMENT0000000302934117;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;7.9;31.0;38.9;40.8;32.0;Cadastre;A 1.0;POLYGON Z ((354988.6 6690382.9 38.9, 354990.7 6690379.8 38.9, 354986.8 6690376 38.9, 354986 6690375.1 38.9, 354981.4 6690381.6 38.9, 354986.6 6690385.3 38.9, 354988.6 6690382.9 38.9))
BATIMENT0000000302934119;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;31.2;35.7;37.5;31.6;Cadastre;;POLYGON Z ((354989.8 6690383.6 35.7, 354991.7 6690380.9 35.7, 354990.7 6690379.8 35.7, 354988.6 6690382.9 35.7, 354989.8 6690383.6 35.7))
BATIMENT0000000302935363;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;30.0;;;;Cadastre;;POLYGON Z ((354999.9 6690386.6 -1000, 355001.9 6690387.7 -1000, 355003.8 6690384.4 -1000, 355001.9 6690383.3 -1000, 354999.9 6690386.6 -1000))
BATIMENT0000000302934504;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;50;20;10.9;32.9;43.8;47.4;32.9;Cadastre;A 1.0;POLYGON Z ((354945.8 6690383 43.8, 354945.2 6690383.8 43.8, 354950.2 6690388.7 43.8, 354945.1 6690393.8 43.8, 354947.2 6690395.6 43.8, 354958.7 6690383.6 43.8, 354951.7 6690376.8 43.8, 354945.8 6690383 43.8))
BATIMENT0000000302934118;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.0;31.0;39.0;42.2;32.0;Cadastre;A 1.0;POLYGON Z ((354977.1 6690387.4 39, 354984.3 6690392.5 39, 354988.5 6690386.6 39, 354986.6 6690385.3 39, 354981.4 6690381.6 39, 354977.1 6690387.4 39))
BATIMENT0000000302935365;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.6;30.6;35.2;38.2;31.3;Cadastre;;POLYGON Z ((354998.9 6690390 35.2, 355000.2 6690391.1 35.2, 355001 6690390.2 35.2, 355000.6 6690389.8 35.2, 354999.5 6690388.7 35.2, 354998.9 6690390 35.2))
BATIMENT0000002011291489;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.5;27.9;;;;Imagerie aérienne;;POLYGON Z ((355018.9 6690420.8 34.6, 355013.6 6690417.3 34.6, 355014.8 6690415.2 34.6, 355020.5 6690418.5 34.6, 355027.4 6690407.8 34.6, 355023 6690405.1 35.1, 355024.5 6690403.7 37.3, 355028.7 6690405.8 37.3, 355031.9 6690400.6 37.3, 355033.2 6690401.2 37.3, 355036.2 6690396.1 37.3, 355035.4 6690395.4 37.3, 355038 6690391.3 37.3, 355039 6690391.8 37.3, 355048 6690377.1 37.3, 355047.1 6690376.4 40.3, 355049.9 6690372.3 40.3, 355050.5 6690372.8 37.7, 355055.4 6690365.2 37.7, 355056.9 6690362.9 35.2, 355056 6690362.2 37.8, 355046.3 6690356 37.8, 355045.3 6690357.9 40.4, 355043.2 6690356.4 40.4, 355041.9 6690355.7 38.4, 355035.6 6690366.1 38.4, 355036.7 6690366.8 40.3, 355036.6 6690367 40.3, 355038.8 6690368.2 40.3, 355037.7 6690370 40.3, 355036.6 6690369.4 37.5, 355027.4 6690384.2 37.5, 355028.6 6690384.9 37.5, 355025.7 6690389.5 37.5, 355023.7 6690388.3 37.5, 355020.8 6690393.3 37.5, 355021.5 6690393.9 37.5, 355018.2 6690399.4 37.5, 355019.7 6690400.5 37.5, 355018.4 6690402.1 34.9, 355015.9 6690400.5 34.9, 355008.9 6690411.4 34.9, 355011.6 6690413 34.9, 355010.3 6690415.1 34.9, 355007.7 6690413.6 34.9, 355004.1 6690419 34.9, 355015.7 6690426.1 34.9, 355018.9 6690420.8 34.6))
BATIMENT0000000302934167;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;32.8;39.0;43.0;33.4;Cadastre;;POLYGON Z ((354833.2 6690383.8 39, 354831.2 6690382.2 39, 354829.2 6690384.7 39, 354826.7 6690387.5 39, 354827.7 6690389 39, 354828.2 6690389.7 39, 354833.2 6690383.8 39))
BATIMENT0000000302934157;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;32.7;39.7;40.7;33.3;Cadastre;;POLYGON Z ((354826.5 6690390.1 39.7, 354827.7 6690389 39.7, 354826.7 6690387.5 39.7, 354826.1 6690386.5 39.7, 354824.6 6690388 39.7, 354826.5 6690390.1 39.7))
BATIMENT0000000302934166;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.8;33.1;42.0;44.6;33.9;Cadastre;A 1.0;POLYGON Z ((354837.9 6690380.6 42, 354830.3 6690389 42, 354830.1 6690388.7 42, 354828.7 6690390.4 42, 354829.6 6690391.4 42, 354832.8 6690395.9 42, 354833.3 6690396.4 42, 354842.5 6690384.2 42, 354841.5 6690383.2 42, 354840.1 6690382.2 42, 354838.1 6690380.4 42, 354837.9 6690380.6 42))
BATIMENT0000000302934174;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;33.4;41.7;45.3;33.7;Cadastre;;POLYGON Z ((354866.2 6690392.1 41.7, 354870.5 6690396 41.7, 354874.9 6690399.8 41.7, 354879 6690403.5 41.7, 354883.6 6690398.2 41.7, 354885.9 6690395.4 41.7, 354882.2 6690392.2 41.7, 354881.2 6690391.4 41.7, 354881.7 6690390.9 41.7, 354878.2 6690387.8 41.7, 354873.7 6690383.9 41.7, 354869.8 6690380.4 41.7, 354869.4 6690380.8 41.7, 354868.7 6690380.2 41.7, 354867.7 6690381.5 41.7, 354861.8 6690388.2 41.7, 354866.2 6690392.1 41.7))
BATIMENT0000000302934155;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;32.7;34.5;38.0;33.5;Cadastre;;POLYGON Z ((354822.8 6690393.2 34.5, 354825.4 6690396.5 34.5, 354825.6 6690396.6 34.5, 354829.6 6690391.4 34.5, 354828.7 6690390.4 34.5, 354828.2 6690389.7 34.5, 354827.7 6690389 34.5, 354826.5 6690390.1 34.5, 354822.8 6690393.2 34.5))
BATIMENT0000000302934144;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;60;20;5.5;33.5;39.0;44.2;34.0;Cadastre;A 1.0;POLYGON Z ((354833.3 6690396.4 39, 354833.2 6690396.5 39, 354834.8 6690398.5 39, 354837.3 6690401.2 39, 354838.2 6690402.4 39, 354849 6690390.2 39, 354842.5 6690384.2 39, 354833.3 6690396.4 39))
BATIMENT0000000302934198;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;32.6;35.3;38.0;33.0;Cadastre;;POLYGON Z ((354815.9 6690396.8 35.3, 354817.8 6690395.2 35.3, 354818.6 6690396 35.3, 354819.9 6690395 35.3, 354817.9 6690393 35.3, 354817.2 6690392.3 35.3, 354814.7 6690395.8 35.3, 354815.9 6690396.8 35.3))
BATIMENT0000000302934183;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;3.0;20;20;9.9;32.2;42.1;44.2;33.1;Cadastre;A 0.9;POLYGON Z ((354813.7 6690397.1 42.1, 354814.7 6690395.8 42.1, 354817.2 6690392.3 42.1, 354817.9 6690393 42.1, 354820.2 6690390.4 42.1, 354816.6 6690386.6 42.1, 354816.9 6690386.1 42.1, 354812.2 6690381.5 42.1, 354800.6 6690397.4 42.1, 354809.3 6690405.5 42.1, 354811.4 6690407.7 42.1, 354814.6 6690404.5 42.1, 354817.6 6690407.1 42.1, 354820.2 6690403.6 42.1, 354813.7 6690397.1 42.1))
BATIMENT0000000302934159;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;32.6;36.2;40.5;34.0;Cadastre;;POLYGON Z ((354833.2 6690396.5 36.2, 354833.3 6690396.4 36.2, 354832.8 6690395.9 36.2, 354828.8 6690398.9 36.2, 354830.6 6690401.4 36.2, 354834.8 6690398.5 36.2, 354833.2 6690396.5 36.2))
BATIMENT0000000302934181;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;32.8;35.3;35.5;33.2;Cadastre;;POLYGON Z ((354820.9 6690398.2 35.3, 354820.1 6690399.4 35.3, 354821.8 6690401.3 35.3, 354822.7 6690400.2 35.3, 354820.9 6690398.2 35.3))
BATIMENT0000000302934154;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;33.5;36.5;37.5;33.8;Cadastre;;POLYGON Z ((354827.7 6690399.7 36.5, 354828.8 6690398.9 36.5, 354832.8 6690395.9 36.5, 354829.6 6690391.4 36.5, 354825.6 6690396.6 36.5, 354825.4 6690396.5 36.5, 354822.7 6690400.2 36.5, 354821.8 6690401.3 36.5, 354820.2 6690403.6 36.5, 354817.6 6690407.1 36.5, 354818.3 6690408 36.5, 354820.3 6690409.8 36.5, 354827.7 6690399.7 36.5))
BATIMENT0000000302934145;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;00;00;6.4;33.2;39.7;46.5;33.9;Cadastre;A 1.0;POLYGON Z ((354838.2 6690402.4 39.7, 354847.5 6690412.6 39.7, 354851.2 6690408.4 39.7, 354855.1 6690404 39.7, 354859.2 6690399.4 39.7, 354849 6690390.2 39.7, 354838.2 6690402.4 39.7))
BATIMENT0000000302934168;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;33.5;36.4;37.4;33.9;Cadastre;;POLYGON Z ((354855.1 6690404 36.4, 354857.3 6690406.1 36.4, 354861.5 6690401.4 36.4, 354859.2 6690399.4 36.4, 354855.1 6690404 36.4))
BATIMENT0000000302934200;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;8.1;31.8;40.0;43.1;32.5;Cadastre;C 0.8;POLYGON Z ((354800.6 6690397.4 40, 354791.1 6690410.4 40, 354793.5 6690412.2 40, 354794.9 6690413.6 40, 354797.2 6690415.5 40, 354797.7 6690415.7 40, 354798.4 6690414.7 40, 354799.7 6690415.7 40, 354803.5 6690411 40, 354805.1 6690412.3 40, 354808.2 6690408.2 40, 354807.7 6690407.6 40, 354808.4 6690406.7 40, 354809.3 6690405.5 40, 354800.6 6690397.4 40))
BATIMENT0000000302934169;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;33.5;36.5;41.7;33.7;Cadastre;;POLYGON Z ((354865.6 6690405.2 36.5, 354863.4 6690403.2 36.5, 354859.1 6690408 36.5, 354861.5 6690410 36.5, 354865.6 6690405.2 36.5))
BATIMENT0000000302934186;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.5;33.5;41.0;;;Cadastre;;POLYGON Z ((354811.1 6690409.6 41, 354812.2 6690408.5 41, 354811.4 6690407.7 41, 354809.3 6690405.5 41, 354808.4 6690406.7 41, 354811.1 6690409.6 41))
BATIMENT0000000302934147;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;33.4;39.8;42.7;33.9;Cadastre;;POLYGON Z ((354869.2 6690408.3 39.8, 354865.6 6690405.2 39.8, 354861.5 6690410 39.8, 354858.8 6690412.9 39.8, 354862.3 6690416.2 39.8, 354869.2 6690408.3 39.8))
BATIMENT0000000302934182;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;33.5;36.7;;;Cadastre;;POLYGON Z ((354820.3 6690409.8 36.7, 354818.3 6690408 36.7, 354815.4 6690411.9 36.7, 354817.3 6690413.9 36.7, 354820.3 6690409.8 36.7))
BATIMENT0000000302934197;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;33.5;37.7;;;Cadastre;;POLYGON Z ((354809.6 6690411.2 37.7, 354810.2 6690411.8 37.7, 354812.1 6690413.5 37.7, 354814.6 6690411.1 37.7, 354812.2 6690408.5 37.7, 354811.1 6690409.6 37.7, 354809.6 6690411.2 37.7))
BATIMENT0000000302934202;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;31.7;36.0;39.2;32.4;Cadastre;;POLYGON Z ((354791.1 6690410.4 36, 354789.6 6690412.6 36, 354791.7 6690414.3 36, 354793.5 6690412.2 36, 354791.1 6690410.4 36))
BATIMENT0000000302944559;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;10.4;15.6;19.7;14.4;Cadastre;;POLYGON Z ((355485.3 6690267.3 15.6, 355490.8 6690262.9 15.6, 355484.9 6690255.6 15.6, 355479.4 6690260.1 15.6, 355485.3 6690267.3 15.6))
BATIMENT0000000302944553;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;11.0;17.5;19.0;12.9;Cadastre;;POLYGON Z ((355513.3 6690256.1 17.5, 355507.8 6690260.8 17.5, 355519.5 6690275.3 17.5, 355516.4 6690277.9 17.5, 355522.2 6690284.6 17.5, 355530.4 6690278 17.5, 355513.3 6690256.1 17.5))
BATIMENT0000000302944543;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;14.4;19.2;33.5;15.0;Cadastre;;POLYGON Z ((355469.4 6690267 19.2, 355478.6 6690278.8 19.2, 355483.3 6690275.1 19.2, 355473.9 6690263.4 19.2, 355469.4 6690267 19.2))
BATIMENT0000000302944683;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;4.0;10;20;13.0;8.7;21.8;24.9;11.3;Cadastre;C 0.9;POLYGON Z ((355542.1 6690282.9 21.8, 355549.7 6690292.5 21.8, 355550.8 6690291.6 21.8, 355550.3 6690290.7 21.8, 355565.1 6690278.8 21.8, 355565.4 6690278.5 21.8, 355558.6 6690269.8 21.8, 355542.1 6690282.9 21.8))
BATIMENT0000000302944556;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-07-01 11:19:38;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;12.1;17.3;19.2;14.5;Cadastre;;POLYGON Z ((355514 6690291.1 17.3, 355508.2 6690284.3 17.3, 355505.4 6690286.6 17.3, 355493.7 6690272.3 17.3, 355493 6690273 17.3, 355491.8 6690273 17.3, 355488.1 6690276.2 17.3, 355495.9 6690285.9 17.3, 355495.2 6690286.6 17.3, 355499.7 6690291.9 17.3, 355505.1 6690298.3 17.3, 355514 6690291.1 17.3))
BATIMENT0000000302944839;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;9.8;12.5;13.2;11.1;Cadastre;;POLYGON Z ((355550.1 6690294.4 12.5, 355552.6 6690297.6 12.5, 355555 6690295.8 12.5, 355552.5 6690292.5 12.5, 355550.1 6690294.4 12.5))
BATIMENT0000000302944681;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;14.4;8.0;22.5;24.5;11.1;Cadastre;C 0.1;POLYGON Z ((355573.3 6690288.3 22.5, 355572.9 6690288.5 22.5, 355557.7 6690300.3 22.5, 355557 6690299.6 22.5, 355556 6690300.6 22.5, 355563.3 6690309.9 22.5, 355580 6690296.6 22.5, 355577 6690292.7 22.5, 355573.3 6690288.3 22.5))
BATIMENT0000000302944560;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;27.0;4.0;19;20;14.2;9.7;24.0;27.0;13.3;Cadastre;A 1.0;POLYGON Z ((355533.9 6690290.5 24, 355517.2 6690303.9 24, 355523 6690311.8 24, 355530.7 6690321.5 24, 355529.3 6690322.7 24, 355532.3 6690326.4 24, 355533.6 6690325.4 24, 355538.1 6690330.9 24, 355555.1 6690317.4 24, 355533.9 6690290.5 24))
BATIMENT0000000302944327;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.9;10.1;18.0;20.1;14.7;Cadastre;;POLYGON Z ((355562.7 6690321.5 18, 355565.4 6690319.3 18, 355563.1 6690316.4 18, 355556.9 6690321.6 18, 355563.2 6690329.5 18, 355566.8 6690326.7 18, 355562.7 6690321.5 18))
BATIMENT0000000302944335;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;25.0;5.0;00;00;10.4;11.1;21.5;26.8;14.7;Cadastre;A 1.0;POLYGON Z ((355512.8 6690324.6 21.5, 355511 6690325.9 21.5, 355508.2 6690322.5 21.5, 355509.8 6690320.9 21.5, 355517.5 6690314.9 21.5, 355511.8 6690307.2 21.5, 355493.7 6690321.6 21.5, 355499.6 6690329.3 21.5, 355499.7 6690328.9 21.5, 355503.7 6690325.7 21.5, 355519.3 6690344.8 21.5, 355525.3 6690340 21.5, 355512.8 6690324.6 21.5))
BATIMENT0000000302944614;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;35;20;11.5;16.3;27.8;32.3;17.3;Cadastre;B 0.5;POLYGON Z ((355333.1 6690273.4 27.8, 355332.3 6690274.5 27.8, 355335.8 6690282.4 27.8, 355337.9 6690281.3 27.8, 355339.5 6690278.3 27.8, 355343 6690280 27.8, 355354.2 6690258.6 27.8, 355352.1 6690257.4 27.8, 355343.4 6690252.8 27.8, 355333.1 6690273.4 27.8))
BATIMENT0000000302944684;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;16.7;20.0;23.7;22.7;Cadastre;;POLYGON Z ((355366.6 6690264.3 20, 355361.7 6690261.8 20, 355352.8 6690279.3 20, 355353.9 6690281.4 20, 355354.4 6690281.2 20, 355354.9 6690280.4 20, 355359.3 6690278.6 20, 355359.7 6690277.5 20, 355361 6690274.8 20, 355366.6 6690264.3 20))
BATIMENT0000000302944685;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;19.9;23.2;28.0;22.7;Cadastre;;POLYGON Z ((355362.7 6690284.6 23.2, 355367.8 6690282.1 23.2, 355364.7 6690276.6 23.2, 355361 6690274.8 23.2, 355359.7 6690277.5 23.2, 355359.3 6690278.6 23.2, 355362.7 6690284.6 23.2))
BATIMENT0000000302944821;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.2;16.8;23.0;24.5;22.6;Cadastre;;POLYGON Z ((355343.5 6690285 23, 355344.5 6690287.1 23, 355348 6690285.6 23, 355346.8 6690283.2 23, 355343.5 6690285 23))
BATIMENT0000000302944615;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;20;20;9.3;16.7;26.0;28.3;23.5;Cadastre;C 0.7;POLYGON Z ((355324.8 6690289.5 26, 355325.6 6690289.7 26, 355324.8 6690291.6 26, 355327 6690292.7 26, 355326 6690294.9 26, 355328.8 6690296.6 26, 355331.2 6690292.2 26, 355330.9 6690291.8 26, 355332.6 6690289.1 26, 355335.6 6690290.4 26, 355336.7 6690288 26, 355331.5 6690276.3 26, 355324.8 6690289.5 26))
BATIMENT0000000302944638;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;20;20;8.3;17.1;25.4;28.2;22.4;Cadastre;C 0.6;POLYGON Z ((355326.5 6690296.6 25.4, 355322 6690294.2 25.4, 355320.1 6690297.8 25.4, 355324.6 6690300.3 25.4, 355326.5 6690296.6 25.4))
BATIMENT0000002011295432;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2023-01-31 17:49:07;2014-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;28.0;6.0;00;00;18.0;16.3;;37.2;23.1;Imagerie aérienne;A 1.0;POLYGON Z ((355313.6 6690346.5 34.3, 355326.4 6690320.3 32.6, 355323.3 6690315.6 33.7, 355327.8 6690306.5 33.7, 355323.5 6690299.6 33.5, 355319.9 6690298.1 33.5, 355304.6 6690328.5 34.3, 355313.6 6690346.5 34.3))
BATIMENT0000000302945722;Chapelle;Religieux;;Non;En service;2012-06-19 19:54:10;2012-10-24 11:04:04;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;23.7;8.9;32.6;;;Cadastre;;POLYGON Z ((355385 6690346.9 32.6, 355384.5 6690347.6 32.6, 355385.2 6690348.1 32.6, 355385.5 6690347.6 32.6, 355386.6 6690348.4 32.6, 355386.1 6690349.4 32.6, 355385.4 6690349.2 32.6, 355385.5 6690350 32.6, 355385.9 6690350 32.6, 355385.9 6690351.5 32.6, 355385.4 6690351.5 32.6, 355385.7 6690352.2 32.6, 355386.1 6690351.9 32.6, 355387.5 6690353.2 32.6, 355386.6 6690354.9 32.6, 355385.6 6690354.9 32.6, 355385.6 6690355.7 32.6, 355386.3 6690356 32.6, 355386.8 6690357.9 32.6, 355386.2 6690357.9 32.6, 355386.3 6690358.8 32.6, 355387.2 6690358.6 32.6, 355388.1 6690359.4 32.6, 355388.7 6690359.8 32.6, 355388.7 6690360.5 32.6, 355389.4 6690360.8 32.6, 355389.7 6690360.2 32.6, 355390.8 6690360.2 32.6, 355391.6 6690360.1 32.6, 355392.3 6690360.7 32.6, 355392.8 6690360.3 32.6, 355392.6 6690359.8 32.6, 355393.9 6690358.4 32.6, 355395.1 6690359.1 32.6, 355395 6690359.8 32.6, 355395.9 6690359.9 32.6, 355396.2 6690359.2 32.6, 355397 6690359.1 32.6, 355397.3 6690359.8 32.6, 355397.8 6690359.4 32.6, 355397.5 6690358.8 32.6, 355398 6690358.2 32.6, 355399.2 6690358.8 32.6, 355398.9 6690359.1 32.6, 355399.6 6690359.6 32.6, 355400.2 6690359 32.6, 355401.7 6690359.9 32.6, 355402.2 6690359.5 32.6, 355405.9 6690362.5 32.6, 355414.8 6690351.8 32.6, 355411.3 6690348.7 32.6, 355411.5 6690348.3 32.6, 355409.7 6690347 32.6, 355410.1 6690346.5 32.6, 355409 6690345.6 32.6, 355410 6690344.2 32.6, 355410.9 6690344.9 32.6, 355411.5 6690344.1 32.6, 355411 6690343.6 32.6, 355412.3 6690342 32.6, 355412.9 6690342.6 32.6, 355413.6 6690341.6 32.6, 355412.8 6690341 32.6, 355414.3 6690339 32.6, 355415 6690339.6 32.6, 355415.7 6690338.8 32.6, 355415.2 6690338.1 32.6, 355416.8 6690336.3 32.6, 355417.4 6690336.8 32.6, 355417.9 6690336 32.6, 355416.3 6690334.6 32.6, 355417.4 6690333.3 32.6, 355418 6690333.7 32.6, 355418.4 6690333.1 32.6, 355417.9 6690332.6 32.6, 355407.4 6690324.1 32.6, 355406.5 6690323.7 32.6, 355406 6690324.5 32.6, 355406.5 6690325 32.6, 355405.2 6690326.4 32.6, 355403.5 6690325.2 32.6, 355403.1 6690325.7 32.6, 355403.9 6690326.3 32.6, 355402.3 6690328.2 32.6, 355401.5 6690328 32.6, 355400.9 6690328.7 32.6, 355401.7 6690329.3 32.6, 355400.1 6690331.1 32.6, 355399.3 6690330.4 32.6, 355398.8 6690331.2 32.6, 355399.4 6690331.7 32.6, 355398 6690333.6 32.6, 355397.4 6690332.9 32.6, 355396.8 6690333.9 32.6, 355397.4 6690334.3 32.6, 355395.8 6690336.2 32.6, 355395.2 6690335.9 32.6, 355395.6 6690335.2 32.6, 355394.9 6690334.8 32.6, 355394.3 6690335.6 32.6, 355392.5 6690334.2 32.6, 355389.8 6690337.4 32.6, 355390 6690337.8 32.6, 355386.4 6690342.5 32.6, 355386 6690342.1 32.6, 355385.5 6690342.7 32.6, 355386.6 6690343.5 32.6, 355384.7 6690345.8 32.6, 355383.9 6690345.2 32.6, 355383.8 6690345.8 32.6, 355385 6690346.9 32.6))
BATIMENT0000000302944636;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;6.0;12;20;17.1;18.1;35.2;38.7;22.0;Cadastre;C 0.6;POLYGON Z ((355291 6690355.3 35.2, 355303.9 6690361.6 35.2, 355308.3 6690352.6 35.2, 355309 6690352.9 35.2, 355309.5 6690351.4 35.2, 355309.1 6690351.3 35.2, 355310.7 6690348.1 35.2, 355313.6 6690346.5 35.2, 355304.6 6690328.5 35.2, 355291 6690355.3 35.2))
BATIMENT0000000302944634;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.9;18.7;27.6;29.7;23.6;Cadastre;C 0.3;POLYGON Z ((355307 6690363.1 27.6, 355315.9 6690367.5 27.6, 355320.8 6690359.3 27.6, 355320.5 6690358.8 27.6, 355315.4 6690349.8 27.6, 355307 6690363.1 27.6))
BATIMENT0000000302944326;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;14.0;21.2;25.2;14.7;Cadastre;;POLYGON Z ((355563.4 6690330 21.2, 355564.7 6690331.5 21.2, 355565.8 6690332.9 21.2, 355572.1 6690327.9 21.2, 355569.3 6690324.6 21.2, 355566.8 6690326.7 21.2, 355563.2 6690329.5 21.2, 355563.4 6690330 21.2))
BATIMENT0000000302944331;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;14.4;20.7;23.5;14.8;Cadastre;;POLYGON Z ((355563.3 6690332.6 20.7, 355564.4 6690334.1 20.7, 355565.8 6690332.9 20.7, 355564.7 6690331.5 20.7, 355563.3 6690332.6 20.7))
BATIMENT0000000302944328;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.9;9.5;18.4;22.1;14.7;Cadastre;;POLYGON Z ((355552.3 6690338.6 18.4, 355554.3 6690341.5 18.4, 355559.8 6690337.1 18.4, 355557.8 6690334.3 18.4, 355552.3 6690338.6 18.4))
BATIMENT0000000302944323;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;3.0;10;20;8.3;9.5;17.8;21.4;14.7;Cadastre;C 0.3;POLYGON Z ((355540.2 6690348 17.8, 355549.5 6690340.8 17.8, 355551.2 6690339.5 17.8, 355552.3 6690338.6 17.8, 355557.8 6690334.3 17.8, 355563.4 6690330 17.8, 355563.2 6690329.5 17.8, 355556.9 6690321.6 17.8, 355542.8 6690332.9 17.8, 355545.2 6690335.9 17.8, 355526.8 6690350.6 17.8, 355530.4 6690355.3 17.8, 355530.8 6690355.9 17.8, 355540.2 6690348 17.8))
BATIMENT0000000302944334;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;2.0;00;00;8.2;11.6;19.8;20.8;15.5;Cadastre;A 1.0;POLYGON Z ((355482.7 6690330.4 19.8, 355503.9 6690357.1 19.8, 355515.3 6690348 19.8, 355499.7 6690328.9 19.8, 355499.6 6690329.3 19.8, 355493.7 6690321.6 19.8, 355488.4 6690325.8 19.8, 355482.7 6690330.4 19.8), (355498.8 6690338.3 19.8, 355501.4 6690341.3 19.8, 355496.3 6690345.2 19.8, 355494 6690342.3 19.8, 355498.8 6690338.3 19.8))
BATIMENT0000000302944325;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.4;9.5;22.0;23.1;12.7;Cadastre;;POLYGON Z ((355549.5 6690340.8 22, 355550.4 6690341.8 22, 355551.9 6690340.6 22, 355551.2 6690339.5 22, 355549.5 6690340.8 22))
BATIMENT0000000302944316;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;12.2;14.9;27.2;30.5;16.5;Cadastre;A 1.0;POLYGON Z ((355469.9 6690340.6 27.2, 355478.2 6690350.8 27.2, 355485.3 6690344.9 27.2, 355477.1 6690334.8 27.2, 355469.9 6690340.6 27.2))
BATIMENT0000000302944324;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.1;10.6;18.7;20.6;16.3;Cadastre;A 1.0;POLYGON Z ((355477.1 6690334.8 18.7, 355485.3 6690344.9 18.7, 355498.6 6690361.3 18.7, 355500.9 6690359.5 18.7, 355503.9 6690357.1 18.7, 355482.7 6690330.4 18.7, 355477.1 6690334.8 18.7))
BATIMENT0000000302944322;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;10;10.8;8.4;19.3;22.0;12.9;Cadastre;C 0.4;POLYGON Z ((355540.2 6690348 19.3, 355544.7 6690353.6 19.3, 355545.9 6690352.7 19.3, 355550.5 6690349.1 19.3, 355553.9 6690346.4 19.3, 355550.4 6690341.8 19.3, 355549.5 6690340.8 19.3, 355540.2 6690348 19.3))
BATIMENT0000000302944332;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;8.1;13.2;16.7;8.9;Cadastre;;POLYGON Z ((355544.7 6690353.6 13.2, 355547.5 6690357.1 13.2, 355548.8 6690358.7 13.2, 355550 6690357.7 13.2, 355545.9 6690352.7 13.2, 355544.7 6690353.6 13.2))
BATIMENT0000000302944333;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;10;20;8.9;8.1;17.1;20.5;13.7;Cadastre;C 0.4;POLYGON Z ((355550.5 6690349.1 17.1, 355554.5 6690354.1 17.1, 355550 6690357.7 17.1, 355548.8 6690358.7 17.1, 355554.3 6690365.6 17.1, 355555.5 6690364.7 17.1, 355559.5 6690361.5 17.1, 355563.4 6690358.4 17.1, 355561.8 6690356.4 17.1, 355553.9 6690346.4 17.1, 355550.5 6690349.1 17.1))
BATIMENT0000000302944336;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;10.6;17.3;18.5;14.9;Cadastre;;POLYGON Z ((355563.4 6690358.4 17.3, 355564.4 6690359.7 17.3, 355566.9 6690357.8 17.3, 355564.4 6690354.4 17.3, 355561.8 6690356.4 17.3, 355563.4 6690358.4 17.3))
BATIMENT0000000302944321;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.6;8.1;12.7;17.7;10.6;Cadastre;C 0.3;POLYGON Z ((355547.5 6690357.1 12.7, 355544.7 6690353.6 12.7, 355540.2 6690348 12.7, 355530.8 6690355.9 12.7, 355526.8 6690359.3 12.7, 355533.6 6690367.7 12.7, 355534 6690368.1 12.7, 355547.5 6690357.1 12.7))
BATIMENT0000000302944338;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;8.0;15.8;17.7;13.7;Cadastre;;POLYGON Z ((355564.4 6690359.7 15.8, 355563.4 6690358.4 15.8, 355559.5 6690361.5 15.8, 355560.8 6690363.1 15.8, 355564.7 6690360 15.8, 355564.4 6690359.7 15.8))
BATIMENT0000000302944330;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;13.1;8.1;21.2;25.1;11.2;Cadastre;C 0.3;POLYGON Z ((355504.2 6690363.5 21.2, 355502 6690365.5 21.2, 355508.7 6690373.8 21.2, 355526.8 6690359.3 21.2, 355526.3 6690358.6 21.2, 355526.6 6690358.4 21.2, 355522.8 6690353.7 21.2, 355520.4 6690350.5 21.2, 355504.2 6690363.5 21.2))
BATIMENT0000000302945714;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;11.6;15.2;25.5;16.4;Cadastre;;POLYGON Z ((355467.5 6690375.2 15.2, 355477.3 6690366.9 15.2, 355486.9 6690379.3 15.2, 355495.7 6690372.7 15.2, 355478.2 6690350.8 15.2, 355473.3 6690354.9 15.2, 355474 6690356.5 15.2, 355466.1 6690362.1 15.2, 355464.5 6690360.9 15.2, 355459.6 6690365.2 15.2, 355461 6690366.9 15.2, 355467.5 6690375.2 15.2))
BATIMENT0000000302944340;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;7.6;7.7;15.3;17.6;13.8;Cadastre;C 0.3;POLYGON Z ((355560.8 6690363.1 15.3, 355560.7 6690363.3 15.3, 355566.2 6690370.4 15.3, 355566.7 6690370.1 15.3, 355566.5 6690369.8 15.3, 355568.9 6690367.8 15.3, 355570 6690369.1 15.3, 355571.2 6690368.2 15.3, 355570.1 6690366.9 15.3, 355564.7 6690360 15.3, 355560.8 6690363.1 15.3))
BATIMENT0000000302944339;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;7.7;10.2;13.7;8.4;Cadastre;;POLYGON Z ((355555.5 6690364.7 10.2, 355554.3 6690365.6 10.2, 355560.4 6690373.3 10.2, 355561.5 6690372.3 10.2, 355555.5 6690364.7 10.2))
BATIMENT0000000302944342;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;12.5;7.6;20.2;22.0;11.7;Cadastre;C 0.4;POLYGON Z ((355577.4 6690376.1 20.2, 355571.2 6690368.2 20.2, 355570 6690369.1 20.2, 355564 6690374 20.2, 355562.2 6690375.4 20.2, 355568.1 6690382.9 20.2, 355568.4 6690383.2 20.2, 355570.2 6690381.9 20.2, 355577.4 6690376.1 20.2))
BATIMENT0000000302944314;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.2;9.0;14.2;19.2;12.9;Cadastre;A 1.0;POLYGON Z ((355486.9 6690379.3 14.2, 355492.5 6690386.1 14.2, 355500.9 6690379.1 14.2, 355495.7 6690372.7 14.2, 355486.9 6690379.3 14.2))
BATIMENT0000000302945716;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;35;29;14.3;9.4;23.7;27.9;14.2;Cadastre;C 0.5;POLYGON Z ((355472.2 6690382.8 23.7, 355471.1 6690383.6 23.7, 355480.9 6690395.1 23.7, 355492.5 6690386.1 23.7, 355486.9 6690379.3 23.7, 355477.3 6690366.9 23.7, 355467.5 6690375.2 23.7, 355466.4 6690375.9 23.7, 355472.2 6690382.8 23.7))
BATIMENT0000000302944320;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.0;8.1;11.1;12.5;8.7;Cadastre;C 0.2;POLYGON Z ((355544.5 6690381.1 11.1, 355547.4 6690384.7 11.1, 355551.4 6690381.2 11.1, 355550.7 6690380.3 11.1, 355548.6 6690377.7 11.1, 355544.5 6690381.1 11.1))
BATIMENT0000000302944329;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;90;90;15.5;6.9;22.5;25.6;8.4;Cadastre;C 0.6;POLYGON Z ((355570 6690385.3 22.5, 355566.9 6690387.8 22.5, 355564.5 6690385.1 22.5, 355558.5 6690389.9 22.5, 355558.7 6690390.2 22.5, 355562.8 6690395.1 22.5, 355570.9 6690405.1 22.5, 355575.6 6690400.6 22.5, 355579.2 6690396.8 22.5, 355570 6690385.3 22.5))
BATIMENT0000000302944313;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1979-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;5.0;;;3.4;7.3;10.7;22.8;8.8;Cadastre;A 1.0;POLYGON Z ((355508 6690388 10.7, 355516.5 6690398.6 10.7, 355535.5 6690422.2 10.7, 355539.7 6690427.4 10.7, 355547.5 6690421.3 10.7, 355547.2 6690420.7 10.7, 355550.9 6690417.8 10.7, 355552.2 6690419.5 10.7, 355566.8 6690408.8 10.7, 355558.5 6690398.5 10.7, 355552.5 6690391 10.7, 355549.3 6690387.1 10.7, 355547.4 6690384.7 10.7, 355544.5 6690381.1 10.7, 355534 6690368.1 10.7, 355533.6 6690367.7 10.7, 355508 6690388 10.7))
BATIMENT0000000302944312;Indifférenciée;Industriel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.4;9.5;15.9;16.5;10.7;Cadastre;A 1.0;POLYGON Z ((355492.5 6690386.1 15.9, 355480.9 6690395.1 15.9, 355478.7 6690396.8 15.9, 355494.5 6690416.9 15.9, 355516.5 6690398.6 15.9, 355508 6690388 15.9, 355501.4 6690379.7 15.9, 355500.9 6690379.1 15.9, 355492.5 6690386.1 15.9))
BATIMENT0000000302944319;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.9;7.9;16.8;21.0;8.3;Cadastre;C 0.9;POLYGON Z ((355566.8 6690408.8 16.8, 355570.9 6690405.1 16.8, 355562.8 6690395.1 16.8, 355558.5 6690398.5 16.8, 355566.8 6690408.8 16.8))
BATIMENT0000000302944315;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;4.0;90;90;5.8;7.1;13.0;20.7;8.8;Cadastre;A 1.0;POLYGON Z ((355494.5 6690416.9 13, 355516.8 6690445.1 13, 355518.1 6690444 13, 355521.5 6690441 13, 355525 6690438.2 13, 355528.5 6690435.5 13, 355532.2 6690432.8 13, 355535.9 6690430.3 13, 355536.4 6690430 13, 355532.3 6690424.7 13, 355535.5 6690422.2 13, 355516.5 6690398.6 13, 355494.5 6690416.9 13))
BATIMENT0000000302944318;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.3;7.6;17.9;;;Cadastre;A 1.0;POLYGON Z ((355532.3 6690424.7 17.9, 355536.4 6690430 17.9, 355539.8 6690427.6 17.9, 355539.7 6690427.4 17.9, 355535.5 6690422.2 17.9, 355532.3 6690424.7 17.9))
BATIMENT0000000302944311;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;6.0;00;00;15.6;7.0;22.7;26.1;8.6;Cadastre;A 1.0;POLYGON Z ((355485.1 6690453.2 22.7, 355486 6690454.4 22.7, 355482.2 6690457.3 22.7, 355479.8 6690459.4 22.7, 355489.27329255105 6690471.022695063 22.7, 355493.80162701436 6690471.022695063 22.7, 355494.1 6690470.6 22.7, 355502.6 6690460.2 22.7, 355492.5 6690447.3 22.7, 355485.1 6690453.2 22.7))
BATIMENT0000000302945719;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;20.5;14.5;35.1;37.5;19.9;Cadastre;C 0.5;POLYGON Z ((355415.6 6690401.5 35.1, 355431.1 6690389.6 35.1, 355424 6690379.7 35.1, 355422.9 6690378.2 35.1, 355416.8 6690383 35.1, 355408.8 6690389.4 35.1, 355408.1 6690390.8 35.1, 355415.6 6690401.5 35.1))
BATIMENT0000000302944306;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;11.4;16.3;16.5;15.9;Cadastre;;POLYGON Z ((355441.2 6690389.3 16.3, 355439.2 6690390.9 16.3, 355442.4 6690395 16.3, 355444.5 6690393.4 16.3, 355441.2 6690389.3 16.3))
BATIMENT0000000302945720;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;5.0;00;00;15.3;8.8;24.2;27.8;16.1;Cadastre;C 0.6;POLYGON Z ((355446.7 6690399.5 24.2, 355453.7 6690408.1 24.2, 355456.2 6690407.3 24.2, 355463.1 6690415.5 24.2, 355461.7 6690416.8 24.2, 355468.8 6690425.9 24.2, 355470.8 6690424.7 24.2, 355476.7 6690431.9 24.2, 355479 6690430.1 24.2, 355487.5 6690423 24.2, 355456.7 6690383.7 24.2, 355455.7 6690384.5 24.2, 355444.5 6690393.4 24.2, 355448 6690397.7 24.2, 355446.7 6690399.5 24.2))
BATIMENT0000000302945721;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;0.0;00;00;2.6;10.6;13.2;24.7;19.8;Cadastre;C 0.1;POLYGON Z ((355440.2 6690432.1 13.2, 355444.4 6690429.1 13.2, 355427.1 6690407.3 13.2, 355431.8 6690403.7 13.2, 355449.4 6690425.6 13.2, 355451.5 6690424.1 13.2, 355453.9 6690422.5 13.2, 355467.6 6690439.4 13.2, 355476.7 6690431.9 13.2, 355470.8 6690424.7 13.2, 355468.8 6690425.9 13.2, 355461.7 6690416.8 13.2, 355463.1 6690415.5 13.2, 355456.2 6690407.3 13.2, 355453.7 6690408.1 13.2, 355446.7 6690399.5 13.2, 355448 6690397.7 13.2, 355444.5 6690393.4 13.2, 355442.4 6690395 13.2, 355437.5 6690398.9 13.2, 355434.5 6690394.5 13.2, 355431.1 6690389.6 13.2, 355415.6 6690401.5 13.2, 355440.2 6690432.1 13.2))
BATIMENT0000000302944308;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;12.3;21.0;22.5;19.9;Cadastre;;POLYGON Z ((355434.8 6690428.8 21, 355434.5 6690428.5 21, 355433.4 6690429.3 21, 355436.8 6690434.2 21, 355437.6 6690433.5 21, 355437.8 6690433.9 21, 355439 6690433 21, 355435.7 6690428.3 21, 355434.8 6690428.8 21))
BATIMENT0000000302944835;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;10.6;;;;Cadastre;;POLYGON Z ((355422.1 6690460 -1000, 355428.9 6690466.6 -1000, 355431.1 6690464.3 -1000, 355427.2 6690460.3 -1000, 355425.9 6690461.5 -1000, 355423.3 6690459 -1000, 355422.1 6690460 -1000))
BATIMENT0000000302944832;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.9;17.0;24.0;33.0;18.3;Cadastre;;POLYGON Z ((355415.8 6690466.1 24, 355419.9 6690470.4 24, 355421.3 6690467.7 24, 355417.6 6690464.2 24, 355415.8 6690466.1 24))
BATIMENT0000000302944834;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;9.0;;;;Cadastre;;POLYGON Z ((355429.5 6690467.1 -1000, 355432.4 6690469.9 -1000, 355433.9 6690468.3 -1000, 355431 6690465.5 -1000, 355429.5 6690467.1 -1000))
BATIMENT0000000302944317;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;40.0;6.0;05;09;4.9;7.0;12.0;26.6;15.8;Cadastre;A 1.0;POLYGON Z ((355457.3 6690460.1 12, 355464.6 6690470.5 12, 355464.33195124986 6690471.022695063 12, 355489.27329255105 6690471.022695063 12, 355479.8 6690459.4 12, 355467 6690443.5 12, 355457.3 6690460.1 12))
BATIMENT0000000302944420;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;10;40;11.3;20.9;32.2;32.3;23.2;Cadastre;A 1.0;POLYGON Z ((355291.5 6690406.9 32.2, 355305.1 6690413.7 32.2, 355306.8 6690410 32.2, 355303.3 6690408.2 32.2, 355302.7 6690407.6 32.2, 355302.6 6690406.9 32.2, 355307.6 6690396.5 32.2, 355308.4 6690396.2 32.2, 355312.7 6690398.2 32.2, 355314.3 6690395 32.2, 355302.3 6690387.3 32.2, 355301.4 6690386.8 32.2, 355291.5 6690406.9 32.2))
BATIMENT0000000302944494;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:07;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;10;20;14.7;18.4;33.1;38.4;22.8;Cadastre;A 1.0;POLYGON Z ((355391.9 6690425.6 33.1, 355397.5 6690428.6 33.1, 355397 6690429.8 33.1, 355397.5 6690430.6 33.1, 355399 6690431.2 33.1, 355399.6 6690431 33.1, 355400.2 6690429.8 33.1, 355403.9 6690431.8 33.1, 355409.4 6690421 33.1, 355411.5 6690420.3 33.1, 355412.7 6690418 33.1, 355412.6 6690416.1 33.1, 355410.3 6690414.9 33.1, 355410.4 6690414.5 33.1, 355404.2 6690411.3 33.1, 355405.4 6690409 33.1, 355401.5 6690406.8 33.1, 355391.9 6690425.6 33.1))
BATIMENT0000000302944486;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;19;20;11.1;19.5;30.6;32.7;20.3;Cadastre;C 0.6;POLYGON Z ((355377.5 6690451.1 30.6, 355386.3 6690457.8 30.6, 355390.5 6690449.1 30.6, 355391.8 6690449.9 30.6, 355393.3 6690446.7 30.6, 355392.2 6690445.9 30.6, 355394.6 6690441.2 30.6, 355386.5 6690433.4 30.6, 355377.5 6690451.1 30.6))
BATIMENT0000000302945697;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.7;17.4;33.2;40.5;22.3;Cadastre;;POLYGON Z ((355345.9 6690432.5 33.2, 355357 6690438.1 33.2, 355355.5 6690441.1 33.2, 355355.2 6690441.1 33.2, 355354.8 6690441.8 33.2, 355355 6690442 33.2, 355353.1 6690445.9 33.2, 355352.7 6690445.8 33.2, 355352.5 6690446.4 33.2, 355352.6 6690446.6 33.2, 355350.7 6690450.4 33.2, 355350.4 6690450.4 33.2, 355350.1 6690450.9 33.2, 355350.3 6690451.3 33.2, 355348.4 6690455.2 33.2, 355348.1 6690455.1 33.2, 355347.8 6690455.6 33.2, 355348.1 6690455.8 33.2, 355346.4 6690459.5 33.2, 355345.9 6690459.5 33.2, 355345.6 6690460.1 33.2, 355345.9 6690460.3 33.2, 355344 6690464.1 33.2, 355343.6 6690464.1 33.2, 355343.3 6690464.8 33.2, 355343.5 6690464.9 33.2, 355341.5 6690468.8 33.2, 355341.2 6690468.8 33.2, 355341 6690469.1 33.2, 355341.2 6690469.4 33.2, 355341.1 6690469.6 33.2, 355341.36675532424 6690471.022695063 33.2, 355352.85657997214 6690471.022695063 33.2, 355353.4 6690469.8 33.2, 355354.1 6690469.8 33.2, 355354.2 6690469.1 33.2, 355353.9 6690468.6 33.2, 355355.6 6690465.1 33.2, 355356.3 6690465.1 33.2, 355356.7 6690464.4 33.2, 355356.2 6690464 33.2, 355358 6690460.8 33.2, 355358.6 6690460.8 33.2, 355358.8 6690460.4 33.2, 355358.5 6690459.7 33.2, 355360.1 6690456.2 33.2, 355360.7 6690456.2 33.2, 355361.1 6690455.9 33.2, 355360.9 6690455.3 33.2, 355362.7 6690451.7 33.2, 355363.2 6690451.8 33.2, 355363.5 6690451.1 33.2, 355363.2 6690450.5 33.2, 355365 6690447.3 33.2, 355365.4 6690447.2 33.2, 355365.8 6690446.5 33.2, 355365.9 6690445.5 33.2, 355365.5 6690444.8 33.2, 355361.7 6690443 33.2, 355365.6 6690434.8 33.2, 355345.6 6690423.2 33.2, 355340.9 6690432.1 33.2, 355345.2 6690434.1 33.2, 355345.9 6690432.5 33.2))
BATIMENT0000000302945698;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;18.2;25.2;32.0;22.9;Cadastre;;POLYGON Z ((355285.5 6690457.6 25.2, 355290 6690459.9 25.2, 355290.5 6690458.9 25.2, 355314.55888712365 6690471.022695063 25.2, 355318.33865246887 6690471.022695063 25.2, 355319.4 6690468.9 25.2, 355323.64539012505 6690471.022695063 25.2, 355338.8453901261 6690471.022695063 25.2, 355338 6690470.6 25.2, 355345.4 6690456.1 25.2, 355354.3 6690438.7 25.2, 355345.2 6690434.1 25.2, 355340.9 6690432.1 25.2, 355345.6 6690423.2 25.2, 355365.6 6690434.8 25.2, 355366.5 6690433.1 25.2, 355372.7 6690436.1 25.2, 355374.5 6690432.5 25.2, 355356.2 6690421.1 25.2, 355346.3 6690414.9 25.2, 355317.3 6690396.8 25.2, 355307.8 6690415 25.2, 355307.4 6690415.6 25.2, 355302.2 6690425.6 25.2, 355295.4 6690422.1 25.2, 355282.1 6690452.1 25.2, 355280.7 6690455.2 25.2, 355285.5 6690457.6 25.2))
BATIMENT0000000302944484;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;18.4;28.6;30.2;20.1;Cadastre;A 1.0;POLYGON Z ((355372 6690461.9 28.6, 355381.8 6690467.3 28.6, 355385.1 6690469.6 28.6, 355386.5 6690467 28.6, 355382.8 6690464.9 28.6, 355386.3 6690457.8 28.6, 355377.5 6690451.1 28.6, 355372 6690461.9 28.6))
BATIMENT0000000302944833;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.1;19.3;21.5;22.4;20.2;Cadastre;;POLYGON Z ((355388.1 6690459.9 21.5, 355395.6 6690465.4 21.5, 355397.2 6690463.3 21.5, 355389.8 6690457.7 21.5, 355388.1 6690459.9 21.5))
BATIMENT0000000302944419;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.5;18.6;29.1;29.4;21.6;Cadastre;;POLYGON Z ((355312.07427173905 6690471.022695063 29.1, 355314.55888712365 6690471.022695063 29.1, 355290.5 6690458.9 29.1, 355290 6690459.9 29.1, 355312.07427173905 6690471.022695063 29.1))
BATIMENT0000000302944483;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;;;4.6;17.8;22.5;28.1;19.9;Cadastre;A 1.0;POLYGON Z ((355367.35093424685 6690471.022695063 22.5, 355387.1466841257 6690471.022695063 22.5, 355385.1 6690469.6 22.5, 355381.8 6690467.3 22.5, 355372 6690461.9 22.5, 355367.35093424685 6690471.022695063 22.5))
BATIMENT0000000302944587;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;8.1;25.5;33.7;34.6;26.4;Cadastre;A 0.4;POLYGON Z ((355161.6 6690384.2 33.7, 355165.8 6690389.6 33.7, 355167 6690388.3 33.7, 355162.8 6690382.3 33.7, 355161.6 6690384.2 33.7))
BATIMENT0000000302944631;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;11.1;25.3;36.4;38.1;27.7;Cadastre;A 1.0;POLYGON Z ((355136.1 6690394.6 36.4, 355140.6 6690389.2 36.4, 355143 6690386.3 36.4, 355132 6690379.2 36.4, 355125.5 6690387.9 36.4, 355136.1 6690394.6 36.4))
BATIMENT0000000302944590;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.7;24.3;32.0;34.2;25.9;Cadastre;C 0.5;POLYGON Z ((355173.7 6690397.8 32, 355174.6 6690396.6 32, 355176.6 6690396.4 32, 355178 6690396.1 32, 355177.8 6690393.4 32, 355177.2 6690392.9 32, 355177.1 6690388.5 32, 355174.9 6690388.6 32, 355174.7 6690386.7 32, 355174.4 6690384.6 32, 355174 6690384.6 32, 355171.2 6690385.2 32, 355167 6690388.3 32, 355173.7 6690397.8 32))
BATIMENT0000000302944632;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;8.4;25.0;33.4;37.2;26.9;Cadastre;A 1.0;POLYGON Z ((355140.4 6690397.3 33.4, 355147.4 6690388.5 33.4, 355143.5 6690385.7 33.4, 355143 6690386.3 33.4, 355140.6 6690389.2 33.4, 355136.1 6690394.6 33.4, 355140.4 6690397.3 33.4))
BATIMENT0000000302944633;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.2;25.0;33.2;37.1;26.9;Cadastre;A 1.0;POLYGON Z ((355148.4 6690402.3 33.2, 355152.9 6690394.9 33.2, 355154.2 6690393 33.2, 355147.4 6690388.5 33.2, 355140.4 6690397.3 33.2, 355148.4 6690402.3 33.2))
BATIMENT0000000302944593;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;24.3;30.0;31.2;25.3;Cadastre;;POLYGON Z ((355172.7 6690399.7 30, 355174.5 6690399.7 30, 355176.6 6690396.4 30, 355174.6 6690396.6 30, 355173.7 6690397.8 30, 355172.7 6690399.7 30))
BATIMENT0000000302944630;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.1;25.0;33.1;34.7;26.4;Cadastre;A 0.8;POLYGON Z ((355154.5 6690406.2 33.1, 355159 6690399.1 33.1, 355152.9 6690394.9 33.1, 355148.4 6690402.3 33.1, 355154.5 6690406.2 33.1))
BATIMENT0000000302944599;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.6;23.6;38.2;41.2;24.9;Cadastre;;POLYGON Z ((355178.4 6690404.7 38.2, 355177.6 6690406.1 38.2, 355180.4 6690406.8 38.2, 355180.1 6690404.1 38.2, 355178.4 6690404.7 38.2))
BATIMENT0000000302944602;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;24.4;31.2;32.5;25.2;Cadastre;;POLYGON Z ((355167.1 6690405 31.2, 355165.8 6690406.8 31.2, 355167.6 6690407.9 31.2, 355168.6 6690406.3 31.2, 355168.9 6690406 31.2, 355167.1 6690405 31.2))
BATIMENT0000000302944604;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;24.1;27.8;28.6;25.2;Cadastre;;POLYGON Z ((355160.2 6690406.2 27.8, 355158.6 6690409.1 27.8, 355160.4 6690410.2 27.8, 355162.2 6690407.3 27.8, 355160.2 6690406.2 27.8))
BATIMENT0000000302944421;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;6.0;13;40;22.4;17.9;40.3;42.8;19.7;Cadastre;A 1.0;POLYGON Z ((355280.7 6690397.3 40.3, 355281 6690397.5 40.3, 355288.4 6690383 40.3, 355288 6690382.6 40.3, 355289.6 6690379.3 40.3, 355280.2 6690373.7 40.3, 355269.2 6690395.6 40.3, 355279.1 6690400.6 40.3, 355280.7 6690397.3 40.3))
BATIMENT0000000302944591;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;15.6;23.8;39.4;43.2;25.5;Cadastre;A 1.0;POLYGON Z ((355179.3 6690396.1 39.4, 355181.1 6690395.7 39.4, 355191.2 6690394.5 39.4, 355190.5 6690386.5 39.4, 355174.7 6690386.7 39.4, 355174.9 6690388.6 39.4, 355177.1 6690388.5 39.4, 355177.2 6690392.9 39.4, 355177.8 6690393.4 39.4, 355178 6690396.1 39.4, 355179.3 6690396.1 39.4))
BATIMENT0000000302944401;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;8.4;23.5;32.0;35.5;24.4;Cadastre;A 1.0;POLYGON Z ((355200.4 6690400.8 32, 355209.2 6690399.9 32, 355208.3 6690388.6 32, 355199.4 6690389.8 32, 355200.4 6690400.8 32))
BATIMENT0000000302944597;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;10;20;18.4;23.4;41.8;44.7;24.9;Cadastre;A 1.0;POLYGON Z ((355181.8 6690402.2 41.8, 355180.6 6690402.5 41.8, 355180.5 6690401.2 41.8, 355179.9 6690401.2 41.8, 355180.1 6690404.1 41.8, 355180.4 6690406.8 41.8, 355180.5 6690407.5 41.8, 355180.9 6690407.4 41.8, 355182 6690407.2 41.8, 355182.4 6690409.7 41.8, 355183.6 6690409.7 41.8, 355183.8 6690413.1 41.8, 355192.7 6690412.3 41.8, 355191.2 6690394.5 41.8, 355181.1 6690395.7 41.8, 355181.8 6690402.2 41.8))
BATIMENT0000000302944403;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;4.5;22.6;27.1;35.9;24.3;Cadastre;C 0.6;POLYGON Z ((355210.7 6690409.8 27.1, 355214.5 6690408.5 27.1, 355221.6 6690405.9 27.1, 355230 6690402.7 27.1, 355228.2 6690397.4 27.1, 355216.4 6690401.8 27.1, 355217.3 6690404.2 27.1, 355214.8 6690405.1 27.1, 355212.8 6690399.4 27.1, 355209.2 6690399.9 27.1, 355200.4 6690400.8 27.1, 355201.2 6690410.4 27.1, 355210.7 6690409.8 27.1))
BATIMENT0000000302944410;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;34;20;13.8;19.9;33.8;35.2;24.2;Cadastre;A 1.0;POLYGON Z ((355248.3 6690394.7 33.8, 355241 6690398 33.8, 355234.9 6690400.7 33.8, 355233.9 6690401.2 33.8, 355234.5 6690402.1 33.8, 355233.6 6690403.4 33.8, 355232.5 6690402.9 33.8, 355228.8 6690409.2 33.8, 355238.3 6690414.4 33.8, 355248.3 6690394.7 33.8))
BATIMENT0000000302944409;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.6;20.6;24.2;26.5;23.2;Cadastre;A 0.2;POLYGON Z ((355226.9 6690408.3 24.2, 355225.1 6690407.5 24.2, 355223.6 6690409.9 24.2, 355226.6 6690411.5 24.2, 355228 6690408.9 24.2, 355226.9 6690408.3 24.2))
BATIMENT0000000302944418;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.2;19.3;25.6;36.8;21.3;Cadastre;A 1.0;POLYGON Z ((355263.7 6690406.4 25.6, 355276.9 6690412.7 25.6, 355280.4 6690405.8 25.6, 355283 6690407.1 25.6, 355283.3 6690406.6 25.6, 355283.1 6690406.5 25.6, 355283.4 6690405.9 25.6, 355290.5 6690409.5 25.6, 355286.4 6690417.6 25.6, 355290.7 6690419.7 25.6, 355295.4 6690422.1 25.6, 355302.2 6690425.6 25.6, 355307.4 6690415.6 25.6, 355307.8 6690415 25.6, 355305.8 6690414.1 25.6, 355305.1 6690413.7 25.6, 355291.5 6690406.9 25.6, 355291.1 6690406.7 25.6, 355282.2 6690402.2 25.6, 355279.1 6690400.6 25.6, 355269.2 6690395.6 25.6, 355263.7 6690406.4 25.6))
BATIMENT0000000302944417;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;00;00;14.5;17.9;32.4;35.0;21.5;Cadastre;A 1.0;POLYGON Z ((355268.8 6690423.4 32.4, 355271.3 6690418.7 32.4, 355274.1 6690420.1 32.4, 355277.7 6690413.1 32.4, 355276.9 6690412.7 32.4, 355263.7 6690406.4 32.4, 355258 6690417.6 32.4, 355266.7 6690422.3 32.4, 355268.8 6690423.4 32.4))
BATIMENT0000000302944408;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;40;20;7.8;20.2;28.0;33.9;23.0;Cadastre;A 0.7;POLYGON Z ((355226.5 6690413.5 28, 355227.4 6690414 28, 355227.3 6690414.5 28, 355226.8 6690414.6 28, 355226.1 6690415.6 28, 355226.6 6690416 28, 355226 6690416.8 28, 355234.5 6690421.4 28, 355238.3 6690414.4 28, 355228.8 6690409.2 28, 355226.5 6690413.5 28))
BATIMENT0000000302944623;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;27.7;34.2;36.4;28.5;Cadastre;;POLYGON Z ((355083.2 6690352.1 34.2, 355082.6 6690353 34.2, 355086.1 6690355.3 34.2, 355086.8 6690354.3 34.2, 355083.2 6690352.1 34.2))
BATIMENT0000000302944624;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;9.3;27.4;36.7;38.0;28.9;Cadastre;A 1.0;POLYGON Z ((355082.7 6690360.9 36.7, 355086.1 6690355.3 36.7, 355082.6 6690353 36.7, 355074.3 6690347.7 36.7, 355070.8 6690353.4 36.7, 355082.7 6690360.9 36.7))
BATIMENT0000000302944627;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;28.0;30.8;30.9;29.0;Cadastre;;POLYGON Z ((355104.2 6690356.2 30.8, 355104.3 6690355.3 30.8, 355103.1 6690354.3 30.8, 355100.4 6690358 30.8, 355101.9 6690359.2 30.8, 355104.2 6690356.2 30.8))
BATIMENT0000000302944622;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.5;27.2;35.7;38.4;28.8;Cadastre;C 0.7;POLYGON Z ((355087.9 6690364.1 35.7, 355093.9 6690354.4 35.7, 355094.4 6690353.7 35.7, 355091.3 6690351.8 35.7, 355089.4 6690354.8 35.7, 355087.4 6690353.5 35.7, 355086.8 6690354.3 35.7, 355086.1 6690355.3 35.7, 355082.7 6690360.9 35.7, 355087.9 6690364.1 35.7))
BATIMENT0000000302944625;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.5;27.0;35.5;38.0;28.6;Cadastre;A 1.0;POLYGON Z ((355093.9 6690367.9 35.5, 355100.2 6690358.4 35.5, 355093.9 6690354.4 35.5, 355087.9 6690364.1 35.5, 355093.9 6690367.9 35.5))
BATIMENT0000000302944628;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;10.3;25.1;35.4;39.4;28.6;Cadastre;A 1.0;POLYGON Z ((355100 6690371.8 35.4, 355106.3 6690362.2 35.4, 355101.9 6690359.2 35.4, 355100.4 6690358 35.4, 355100.2 6690358.4 35.4, 355093.9 6690367.9 35.4, 355100 6690371.8 35.4))
BATIMENT0000000302944629;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;10.0;25.2;35.2;39.1;28.5;Cadastre;A 1.0;POLYGON Z ((355107.5 6690376.5 35.2, 355112.3 6690368.9 35.2, 355113.6 6690367 35.2, 355106.3 6690362.2 35.2, 355100 6690371.8 35.2, 355107.5 6690376.5 35.2))
BATIMENT0000002011291491;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:49:07;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;12.0;27.0;;39.2;27.4;Imagerie aérienne;;POLYGON Z ((355146.3 6690418.5 35.2, 355066.8 6690368.3 34.8, 355062.3 6690375.2 34.8, 355082.8 6690388.3 34.8, 355078.5 6690395.1 34.6, 355057.9 6690382.4 33.8, 355051.8 6690391.2 35.7, 355067.6 6690401.1 35.7, 355061.7 6690410.2 38.9, 355060.8 6690409.8 39, 355052.2 6690423.2 39, 355058.6 6690427.9 39, 355063.2 6690420.7 39, 355086.8 6690435.9 39, 355097.5 6690442.6 39, 355113.8 6690453 38.3, 355112.7 6690454.9 33.7, 355117.9 6690458 33.7, 355119.2 6690456.7 37.9, 355121.3 6690457.8 37.9, 355125.8 6690450.9 37.9, 355136.3 6690434.6 35.3, 355121.8 6690425.6 35.3, 355127.2 6690416.3 35.3, 355141.7 6690425.3 35.3, 355146.3 6690418.5 35.2))
BATIMENT0000002011291490;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.7;25.3;;;;Imagerie aérienne;;POLYGON Z ((355092 6690462.7 34.2, 355090.4 6690461.8 34.2, 355095.3 6690454 34.2, 355076.7 6690442.5 34.2, 355075.6 6690444.2 34.2, 355062.7 6690435.3 37.6, 355063.5 6690434.4 37.6, 355045 6690423 37.6, 355044.4 6690424.8 40.8, 355040.8 6690422.3 40.8, 355042 6690420.6 37.7, 355036.3 6690417.2 37.7, 355026.7 6690432.2 37.7, 355032.5 6690435.8 37.7, 355033.5 6690434.5 37.7, 355035.5 6690435.4 40.8, 355038.6 6690437.4 40.8, 355036 6690441.3 40.8, 355033.7 6690440 37.5, 355022.4 6690457.7 37.5, 355025.3 6690458.6 41, 355022.8 6690463.5 41, 355019.3 6690461.3 41, 355019.4 6690458.6 37.6, 355012.5 6690454.6 37.6, 355003 6690469.9 37.6, 355004.85847261734 6690471.022695063 37.6, 355080.20124104596 6690471.022695063 34.342331558576035, 355088.4 6690468.5 34.5, 355092 6690462.7 34.2))
BATIMENT0000000302944603;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;5.7;24.0;29.8;34.2;24.9;Cadastre;C 0.5;POLYGON Z ((355163.6 6690405.4 29.8, 355162.2 6690407.3 29.8, 355160.4 6690410.2 29.8, 355164.5 6690412.8 29.8, 355167.6 6690407.9 29.8, 355165.8 6690406.8 29.8, 355163.6 6690405.4 29.8))
BATIMENT0000000302944601;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.5;23.8;32.3;34.5;25.0;Cadastre;A 0.6;POLYGON Z ((355174.9 6690410.2 32.3, 355168.9 6690406 32.3, 355168.6 6690406.3 32.3, 355167.6 6690407.9 32.3, 355164.5 6690412.8 32.3, 355170.8 6690416.8 32.3, 355174.4 6690410.9 32.3, 355174.9 6690410.2 32.3))
BATIMENT0000000302944600;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.0;23.4;31.5;33.6;25.0;Cadastre;A 0.7;POLYGON Z ((355174.4 6690410.9 31.5, 355170.8 6690416.8 31.5, 355175.8 6690420 31.5, 355179.6 6690414 31.5, 355174.4 6690410.9 31.5))
BATIMENT0000000302944502;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.2;24.8;38.0;;;Cadastre;;POLYGON Z ((355155.5 6690424.5 38, 355156 6690423.8 38, 355152.5 6690421.6 38, 355152 6690422.5 38, 355155.5 6690424.5 38))
BATIMENT0000000302944503;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.7;23.7;34.4;36.2;24.1;Cadastre;;POLYGON Z ((355164.1 6690429.9 34.4, 355164.5 6690429.2 34.4, 355161.3 6690427.1 34.4, 355160.9 6690427.8 34.4, 355164.1 6690429.9 34.4))
BATIMENT0000000302944500;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.6;24.8;38.4;;;Cadastre;;POLYGON Z ((355151.6 6690436.5 38.4, 355152.3 6690435.4 38.4, 355145 6690431.2 38.4, 355144.4 6690432.1 38.4, 355151.6 6690436.5 38.4))
BATIMENT0000000302944506;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;23.3;27.5;33.5;24.1;Cadastre;;POLYGON Z ((355167 6690436.7 27.5, 355170.1 6690438.6 27.5, 355172.7 6690434.2 27.5, 355169.5 6690432.2 27.5, 355167 6690436.7 27.5))
BATIMENT0000000302944501;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;16.0;5.0;00;00;10.7;25.3;36.0;;;Cadastre;A 1.0;POLYGON Z ((355151.8 6690453.1 36, 355152.1 6690453 36, 355153 6690452.7 36, 355153.2 6690452.6 36, 355154.1 6690452.2 36, 355154.5 6690452 36, 355155.1 6690451.6 36, 355155.5 6690451.4 36, 355155.7 6690451.3 36, 355156.1 6690451 36, 355156.6 6690450.8 36, 355162.4 6690448.4 36, 355160.5 6690443.6 36, 355159.4 6690440.6 36, 355165.5 6690429.8 36, 355164.5 6690429.2 36, 355164.1 6690429.9 36, 355160.9 6690427.8 36, 355161.3 6690427.1 36, 355158.9 6690425.6 36, 355156 6690423.8 36, 355155.5 6690424.5 36, 355152 6690422.5 36, 355152.5 6690421.6 36, 355151.5 6690421 36, 355145 6690431.2 36, 355152.3 6690435.4 36, 355151.6 6690436.5 36, 355148.4 6690441.4 36, 355146.6 6690444.2 36, 355141 6690446.4 36, 355138.9 6690447.2 36, 355139.7 6690449.1 36, 355140.5 6690451.2 36, 355142.2 6690456.2 36, 355147.6 6690454 36, 355148.3 6690453.9 36, 355149.3 6690453.8 36, 355149.7 6690453.7 36, 355150.4 6690453.5 36, 355150.9 6690453.4 36, 355151.4 6690453.2 36, 355151.8 6690453.1 36))
BATIMENT0000000302944504;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.0;23.1;27.1;33.5;24.1;Cadastre;A 1.0;POLYGON Z ((355167.7 6690442.5 27.1, 355169.1 6690440.3 27.1, 355170.1 6690438.6 27.1, 355167 6690436.7 27.1, 355169.5 6690432.2 27.1, 355165.5 6690429.8 27.1, 355159.4 6690440.6 27.1, 355160.5 6690443.6 27.1, 355162.4 6690448.4 27.1, 355163.6 6690451.4 27.1, 355170.2 6690448.7 27.1, 355169 6690445.9 27.1, 355167.7 6690442.5 27.1))
BATIMENT0000000302944505;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;11.2;22.9;34.2;36.3;23.7;Cadastre;A 1.0;POLYGON Z ((355170.1 6690438.6 34.2, 355169.1 6690440.3 34.2, 355167.7 6690442.5 34.2, 355169 6690445.9 34.2, 355171.6 6690444.6 34.2, 355175.2 6690447 34.2, 355175.7 6690446.7 34.2, 355180.4 6690439.1 34.2, 355172.7 6690434.2 34.2, 355170.1 6690438.6 34.2))
BATIMENT0000000302944404;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;8.0;22.9;31.0;33.2;23.6;Cadastre;A 1.0;POLYGON Z ((355210.8 6690412 31, 355212.6 6690411.8 31, 355212.8 6690412.7 31, 355214.6 6690412.4 31, 355214.5 6690408.5 31, 355210.7 6690409.8 31, 355201.2 6690410.4 31, 355202.8 6690428.2 31, 355211.9 6690427.8 31, 355211.7 6690425.7 31, 355210.8 6690412 31))
BATIMENT0000000302944598;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;19;20;6.2;22.9;29.2;40.1;24.9;Cadastre;A 1.0;POLYGON Z ((355182.1 6690413.1 29.2, 355180 6690413.4 29.2, 355179.6 6690414 29.2, 355175.8 6690420 29.2, 355178 6690421.3 29.2, 355181.8 6690415.5 29.2, 355183.3 6690415.3 29.2, 355183.9 6690425.1 29.2, 355193.9 6690431.4 29.2, 355194.3 6690430.7 29.2, 355192.7 6690412.3 29.2, 355183.8 6690413.1 29.2, 355182.1 6690413.1 29.2))
BATIMENT0000000302944416;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;11.4;20.0;31.5;34.1;22.1;Cadastre;A 1.0;POLYGON Z ((355253.6 6690426.3 31.5, 355261.5 6690430.3 31.5, 355265.4 6690422.4 31.5, 355266.3 6690423 31.5, 355266.7 6690422.3 31.5, 355258 6690417.6 31.5, 355253.6 6690426.3 31.5))
BATIMENT0000000302944406;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;22.9;28.7;30.5;23.1;Cadastre;;POLYGON Z ((355212.2 6690427.8 28.7, 355213.6 6690427.7 28.7, 355213.6 6690425.6 28.7, 355211.7 6690425.7 28.7, 355211.9 6690427.8 28.7, 355212.2 6690427.8 28.7))
BATIMENT0000000302944405;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.3;22.6;30.9;33.2;23.1;Cadastre;A 1.0;POLYGON Z ((355203.6 6690435.7 30.9, 355206.7 6690435.5 30.9, 355206.5 6690434.5 30.9, 355212.4 6690433.9 30.9, 355211.9 6690427.8 30.9, 355202.8 6690428.2 30.9, 355203.6 6690435.7 30.9))
BATIMENT0000000302944415;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;11.1;20.2;31.4;34.2;21.9;Cadastre;A 1.0;POLYGON Z ((355249.1 6690435.2 31.4, 355258.3 6690439.9 31.4, 355262.6 6690431 31.4, 355261.5 6690430.3 31.4, 355253.6 6690426.3 31.4, 355249.1 6690435.2 31.4))
BATIMENT0000000302944414;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;15.5;20.4;36.0;36.8;21.3;Cadastre;C 0.2;POLYGON Z ((355244.1 6690445.1 36, 355256.5 6690451.4 36, 355257 6690450.3 36, 355261.3 6690441.3 36, 355258.3 6690439.9 36, 355249.1 6690435.2 36, 355244.1 6690445.1 36))
BATIMENT0000000302944413;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;20.3;28.0;34.7;20.6;Cadastre;;POLYGON Z ((355258.5 6690452.3 28, 355259 6690451.3 28, 355257 6690450.3 28, 355256.5 6690451.4 28, 355258.5 6690452.3 28))
BATIMENT0000000302944518;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;20.5;22.8;24.0;22.0;Cadastre;;POLYGON Z ((355271.4 6690446.7 22.8, 355268.5 6690452 22.8, 355265.7 6690450.7 22.8, 355263.3 6690454.9 22.8, 355266 6690456.3 22.8, 355271.1 6690458.9 22.8, 355273.9 6690453.5 22.8, 355276.2 6690449.1 22.8, 355271.4 6690446.7 22.8))
BATIMENT0000000302944407;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.5;21.4;32.0;34.8;23.0;Cadastre;A 1.0;POLYGON Z ((355205.94183613674 6690471.022695063 32, 355209.30797100055 6690471.022695063 32, 355217.8 6690454.4 32, 355213.9 6690452.9 32, 355214 6690452.3 32, 355209.9 6690450.2 32, 355209.7 6690450.3 32, 355207.1 6690449.2 32, 355210.1 6690440.2 32, 355209.9 6690437 32, 355209.7 6690435.3 32, 355206.7 6690435.5 32, 355203.6 6690435.7 32, 355205.94183613674 6690471.022695063 32))
BATIMENT0000000302944507;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;24.2;31.5;33.7;25.0;Cadastre;;POLYGON Z ((355146.6 6690444.2 31.5, 355148.4 6690441.4 31.5, 355141.8 6690444 31.5, 355141.6 6690444 31.5, 355141.5 6690444 31.5, 355141.4 6690444.1 31.5, 355141.2 6690444.2 31.5, 355141.1 6690444.3 31.5, 355141 6690444.4 31.5, 355140.9 6690444.5 31.5, 355140.8 6690444.6 31.5, 355140.8 6690444.8 31.5, 355140.7 6690445 31.5, 355140.7 6690445.1 31.5, 355140.6 6690445.3 31.5, 355140.6 6690445.5 31.5, 355140.6 6690445.7 31.5, 355140.7 6690445.9 31.5, 355140.8 6690446 31.5, 355140.9 6690446.2 31.5, 355141 6690446.4 31.5, 355146.6 6690444.2 31.5))
BATIMENT0000000302944508;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;23.7;28.7;35.0;25.2;Cadastre;;POLYGON Z ((355138.1 6690452.1 28.7, 355140.8 6690459.9 28.7, 355143.2 6690459 28.7, 355142.2 6690456.2 28.7, 355140.5 6690451.2 28.7, 355138.1 6690452.1 28.7))
BATIMENT0000000302944450;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;22.9;28.7;30.6;23.2;Cadastre;;POLYGON Z ((355173.9 6690459.6 28.7, 355173.7 6690454.8 28.7, 355170.3 6690456.1 28.7, 355171.7 6690459.9 28.7, 355173.9 6690459.6 28.7))
BATIMENT0000000302944451;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;40;20;6.7;23.0;29.7;37.5;23.7;Cadastre;A 1.0;POLYGON Z ((355150.2 6690463.5 29.7, 355151 6690466 29.7, 355154.4 6690464.5 29.7, 355154.7 6690466.8 29.7, 355161.4 6690470.3 29.7, 355162.3 6690465.4 29.7, 355164.2 6690465.9 29.7, 355167.2 6690466.5 29.7, 355172.9 6690463.9 29.7, 355171.7 6690459.9 29.7, 355170.3 6690456.1 29.7, 355150.2 6690463.5 29.7))
BATIMENT0000000302944469;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;23.4;29.5;31.2;23.8;Cadastre;;POLYGON Z ((355150.9 6690470.3 29.5, 355154.3 6690468.6 29.5, 355151 6690466 29.5, 355150.2 6690463.5 29.5, 355148.6 6690464.1 29.5, 355150.5 6690469.6 29.5, 355150.9 6690470.3 29.5))
BATIMENT0000000302944467;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;23.5;30.7;35.8;23.7;Cadastre;;POLYGON Z ((355161.4 6690470.3 30.7, 355162.845390125 6690471.022695063 30.7, 355163.64116053865 6690471.022695063 30.7, 355164.2 6690465.9 30.7, 355162.3 6690465.4 30.7, 355161.4 6690470.3 30.7))
BATIMENT0000000302944470;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.2;23.5;31.8;33.7;24.1;Cadastre;A 1.0;POLYGON Z ((355140.7 6690467.1 31.8, 355142.13732338184 6690471.022695063 31.8, 355147.8954407412 6690471.022695063 31.8, 355147.8 6690470.8 31.8, 355150.5 6690469.6 31.8, 355148.6 6690464.1 31.8, 355140.7 6690467.1 31.8))
BATIMENT0000000302944433;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;23.8;26.4;27.0;24.2;Cadastre;;POLYGON Z ((355133.6 6690469.8 26.4, 355133.8 6690470.7 26.4, 355133.9173436591 6690471.022695063 26.4, 355138.19912192854 6690471.022695063 26.4, 355137.2 6690468.4 26.4, 355133.6 6690469.8 26.4))
BATIMENT0000000302944432;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;7.4;24.0;31.4;35.0;24.7;Cadastre;A 1.0;POLYGON Z ((355132.9448580844 6690471.022695063 31.4, 355133.9173436591 6690471.022695063 31.4, 355133.8 6690470.7 31.4, 355132.9448580844 6690471.022695063 31.4))
BATIMENT0000000302944412;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;12;20;13.6;19.4;33.0;36.3;20.9;Cadastre;A 1.0;POLYGON Z ((355238.4 6690456.8 33, 355239 6690458.6 33, 355240.3 6690460.3 33, 355249.7 6690464.8 33, 355256.5 6690451.4 33, 355244.1 6690445.1 33, 355238.4 6690456.8 33))
BATIMENT0000000302944517;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;19.9;23.6;27.8;20.8;Cadastre;;POLYGON Z ((355261.6 6690454 23.6, 355260.3 6690456.7 23.6, 355264.7 6690459.1 23.6, 355266 6690456.3 23.6, 355263.3 6690454.9 23.6, 355261.6 6690454 23.6))
BATIMENT0000000302944447;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;3.0;10;20;8.1;22.3;30.4;33.1;23.1;Cadastre;A 1.0;POLYGON Z ((355197.2 6690466.8 30.4, 355196 6690449.3 30.4, 355193.9 6690446.9 30.4, 355190.8 6690448.3 30.4, 355183.5 6690451.2 30.4, 355184 6690458.3 30.4, 355185.3 6690458.2 30.4, 355185.3 6690459.7 30.4, 355181.8 6690460 30.4, 355181.1 6690452.1 30.4, 355181 6690452 30.4, 355173.7 6690454.8 30.4, 355173.9 6690459.6 30.4, 355174.8 6690468.4 30.4, 355183.5 6690467.6 30.4, 355183.5 6690464.8 30.4, 355185.8 6690464.5 30.4, 355186 6690467.4 30.4, 355197.2 6690466.8 30.4))
BATIMENT0000000302944519;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.0;20.5;22.5;23.2;22.0;Cadastre;;POLYGON Z ((355274.6 6690462.8 22.5, 355274.6 6690462.7 22.5, 355278.2 6690455.8 22.5, 355273.9 6690453.5 22.5, 355271.1 6690458.9 22.5, 355270.3 6690460.6 22.5, 355274.6 6690462.8 22.5))
BATIMENT0000000302944806;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;15;20;11.0;19.2;30.2;33.4;20.7;Cadastre;A 1.0;POLYGON Z ((355268.5 6690464.1 30.2, 355259 6690459.1 30.2, 355254.8 6690467.3 30.2, 355261.9475745207 6690471.022695063 30.2, 355265.0484778912 6690471.022695063 30.2, 355267.7 6690465.8 30.2, 355268.5 6690464.1 30.2))
BATIMENT0000000302944808;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;30;30;4.8;20.1;24.9;26.6;21.5;Cadastre;A 1.0;POLYGON Z ((355280.5 6690467 24.9, 355278.8 6690466 24.9, 355279.1 6690465.1 24.9, 355277.6 6690464.3 24.9, 355275.9 6690470.1 24.9, 355276.5 6690470.3 24.9, 355276.1167526182 6690471.022695063 24.9, 355278.3483258966 6690471.022695063 24.9, 355280.5 6690467 24.9))
BATIMENT0000000302944807;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.3;18.8;27.2;29.8;21.5;Cadastre;A 1.0;POLYGON Z ((355276.5 6690470.3 27.2, 355275.9 6690470.1 27.2, 355267.7 6690465.8 27.2, 355265.0484778912 6690471.022695063 27.2, 355276.1167526182 6690471.022695063 27.2, 355276.5 6690470.3 27.2))
BATIMENT0000000302944445;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;7.7;22.0;29.7;34.1;23.2;Cadastre;A 1.0;POLYGON Z ((355183.5 6690467.6 29.7, 355174.8 6690468.4 29.7, 355174.9457052812 6690471.022695063 29.7, 355181.89340425935 6690471.022695063 29.7, 355181.8 6690470.4 29.7, 355186.4 6690470.2 29.7, 355186.45876393304 6690471.022695063 29.7, 355197.48026737146 6690471.022695063 29.7, 355197.2 6690466.8 29.7, 355186 6690467.4 29.7, 355183.5 6690467.6 29.7))
BATIMENT0000000302944440;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;14;23;13.9;19.6;33.5;36.2;21.7;Cadastre;C 1.0;POLYGON Z ((355234.7 6690470.5 33.5, 355234.1 6690470.3 33.5, 355233.5 6690470 33.5, 355232.6 6690469.8 33.5, 355232 6690469.7 33.5, 355231.6 6690469.7 33.5, 355231.3 6690469.8 33.5, 355231 6690469.9 33.5, 355230.7 6690470.1 33.5, 355230.5 6690470.4 33.5, 355230.2 6690470.6 33.5, 355230.0591016458 6690471.022695063 33.5, 355235.71054378786 6690471.022695063 33.5, 355234.7 6690470.5 33.5))
BATIMENT0000000302934141;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;32.6;38.9;42.0;33.9;Cadastre;;POLYGON Z ((354838.2 6690402.4 38.9, 354837.3 6690401.2 38.9, 354831.1 6690407.4 38.9, 354849.1 6690426 38.9, 354854.8 6690420.5 38.9, 354853.4 6690419.1 38.9, 354847.9 6690413 38.9, 354847.5 6690412.6 38.9, 354838.2 6690402.4 38.9))
BATIMENT0000000302934132;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.7;33.3;38.0;;;Cadastre;C 0.3;POLYGON Z ((354851.2 6690408.4 38, 354847.5 6690412.6 38, 354847.9 6690413 38, 354853.4 6690419.1 38, 354854.4 6690418.2 38, 354854.7 6690417.8 38, 354856.3 6690415.8 38, 354857.4 6690414.7 38, 354857.6 6690414.4 38, 354851.2 6690408.4 38))
BATIMENT0000000302934149;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;6.8;33.4;40.2;42.8;33.7;Cadastre;A 0.6;POLYGON Z ((354862.3 6690416.2 40.2, 354865.7 6690419.3 40.2, 354867.4 6690417.3 40.2, 354872.6 6690411.3 40.2, 354869.2 6690408.3 40.2, 354862.3 6690416.2 40.2))
BATIMENT0000000302934184;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;33.5;37.1;;;Cadastre;;POLYGON Z ((354812.1 6690413.5 37.1, 354815.1 6690416.7 37.1, 354817.3 6690413.9 37.1, 354815.4 6690411.9 37.1, 354814.6 6690411.1 37.1, 354812.1 6690413.5 37.1))
BATIMENT0000000302934201;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;31.7;34.4;39.5;32.4;Cadastre;;POLYGON Z ((354790.4 6690415.5 34.4, 354791.7 6690416.8 34.4, 354794.9 6690413.6 34.4, 354793.5 6690412.2 34.4, 354791.7 6690414.3 34.4, 354790.4 6690415.5 34.4))
BATIMENT0000000302934146;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;33.5;38.6;39.2;33.9;Cadastre;;POLYGON Z ((354857.6 6690414.4 38.6, 354857.4 6690414.7 38.6, 354858.2 6690415.5 38.6, 354860.9 6690417.9 38.6, 354862.3 6690416.2 38.6, 354858.8 6690412.9 38.6, 354857.6 6690414.4 38.6))
BATIMENT0000000302934148;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;33.3;36.9;;;Cadastre;;POLYGON Z ((354856.3 6690415.8 36.9, 354857.3 6690416.5 36.9, 354858.2 6690415.5 36.9, 354857.4 6690414.7 36.9, 354856.3 6690415.8 36.9))
BATIMENT0000000302934199;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;6.7;31.9;38.7;40.2;32.7;Cadastre;C 0.5;POLYGON Z ((354805.9 6690416.2 38.7, 354805 6690415.4 38.7, 354802.1 6690418.3 38.7, 354806.3 6690422.4 38.7, 354809.3 6690419.3 38.7, 354811.4 6690421.5 38.7, 354815.1 6690416.7 38.7, 354812.1 6690413.5 38.7, 354810.2 6690411.8 38.7, 354805.9 6690416.2 38.7))
BATIMENT0000000302934150;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.0;33.4;41.5;44.2;33.7;Cadastre;A 1.0;POLYGON Z ((354867.4 6690417.3 41.5, 354865.7 6690419.3 41.5, 354864.8 6690420.4 41.5, 354868 6690423.4 41.5, 354869 6690422.4 41.5, 354870.7 6690420.3 41.5, 354876 6690414.3 41.5, 354872.6 6690411.3 41.5, 354867.4 6690417.3 41.5))
BATIMENT0000000302934152;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;8.1;33.3;41.5;45.6;33.8;Cadastre;A 1.0;POLYGON Z ((354871.1 6690424.3 41.5, 354872.4 6690425.2 41.5, 354873.7 6690423.8 41.5, 354879.3 6690417.2 41.5, 354876 6690414.3 41.5, 354870.7 6690420.3 41.5, 354871.8 6690421.2 41.5, 354872.1 6690421.2 41.5, 354872.5 6690421.6 41.5, 354870.6 6690423.8 41.5, 354871.1 6690424.3 41.5))
BATIMENT0000000302934509;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;10;5.1;31.8;36.9;40.5;32.3;Cadastre;A 1.0;POLYGON Z ((354938.6 6690402.7 36.9, 354936.9 6690404.7 36.9, 354940.4 6690407.8 36.9, 354941.9 6690409.1 36.9, 354940.2 6690411.5 36.9, 354945.4 6690415.4 36.9, 354949.3 6690410.2 36.9, 354945 6690406.3 36.9, 354941.7 6690403.6 36.9, 354940.4 6690402.6 36.9, 354939.6 6690401.8 36.9, 354938.6 6690402.7 36.9))
BATIMENT0000000302934510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;32.0;36.2;37.1;32.3;Cadastre;;POLYGON Z ((354938.4 6690410.3 36.2, 354940.2 6690411.5 36.2, 354941.9 6690409.1 36.2, 354940.4 6690407.8 36.2, 354938.4 6690410.3 36.2))
BATIMENT0000000302934176;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;32.8;35.5;36.5;33.2;Cadastre;;POLYGON Z ((354898.1 6690412.3 35.5, 354901.6 6690408.7 35.5, 354899.5 6690407 35.5, 354896.3 6690410.8 35.5, 354898.1 6690412.3 35.5))
BATIMENT0000000302934180;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;32.5;35.9;38.2;33.0;Cadastre;;POLYGON Z ((354907.4 6690413.6 35.9, 354911.6 6690417.1 35.9, 354912.6 6690416.1 35.9, 354916.6 6690411.5 35.9, 354912.8 6690407.6 35.9, 354907.4 6690413.6 35.9))
BATIMENT0000000302934177;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;4.3;33.5;37.8;;;Cadastre;C 0.6;POLYGON Z ((354892.7 6690415.3 37.8, 354898.1 6690420.1 37.8, 354900.2 6690421.9 37.8, 354904.3 6690425.5 37.8, 354910.2 6690418.9 37.8, 354911.6 6690417.1 37.8, 354907.4 6690413.6 37.8, 354902.7 6690419 37.8, 354895.1 6690412.2 37.8, 354896.3 6690410.8 37.8, 354899.5 6690407 37.8, 354895.2 6690403.4 37.8, 354888.2 6690411.4 37.8, 354888.3 6690411.5 37.8, 354892.7 6690415.3 37.8))
BATIMENT0000000302934178;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;32.5;35.6;38.0;33.0;Cadastre;A 1.0;POLYGON Z ((354918.3 6690413.8 35.6, 354917.5 6690413.1 35.6, 354917.7 6690412.7 35.6, 354916.6 6690411.5 35.6, 354912.6 6690416.1 35.6, 354914.7 6690417.9 35.6, 354918.3 6690413.8 35.6))
BATIMENT0000000302934192;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;32.4;35.0;35.8;33.0;Cadastre;B 1.0;POLYGON Z ((354914.7 6690417.9 35, 354916.8 6690419.7 35, 354920.5 6690415.7 35, 354918.3 6690413.8 35, 354914.7 6690417.9 35))
BATIMENT0000000302934204;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;5.1;31.9;37.0;42.0;32.5;Cadastre;C 0.8;POLYGON Z ((354933.1 6690414.8 37, 354934.7 6690416 37, 354932.6 6690418.5 37, 354939.1 6690424.1 37, 354943.5 6690418.2 37, 354935.4 6690412.1 37, 354933.1 6690414.8 37))
BATIMENT0000000302934194;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;32.4;35.2;36.0;33.2;Cadastre;B 1.0;POLYGON Z ((354916.8 6690419.7 35.2, 354919 6690421.6 35.2, 354922.6 6690417.5 35.2, 354920.5 6690415.7 35.2, 354916.8 6690419.7 35.2))
BATIMENT0000000302934195;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.3;32.9;36.2;36.5;33.2;Cadastre;B 1.0;POLYGON Z ((354919 6690421.6 36.2, 354921.1 6690423.4 36.2, 354924.8 6690419.4 36.2, 354922.6 6690417.5 36.2, 354919 6690421.6 36.2))
BATIMENT0000000302934505;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;12.6;31.5;44.2;46.6;32.4;Cadastre;A 1.0;POLYGON Z ((354947.2 6690395.6 44.2, 354954.8 6690402.5 44.2, 354963.4 6690390.8 44.2, 354962.9 6690387.8 44.2, 354961.4 6690386.2 44.2, 354958.7 6690383.6 44.2, 354947.2 6690395.6 44.2))
BATIMENT0000000302934120;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.4;31.6;39.0;42.0;32.0;Cadastre;A 1.0;POLYGON Z ((354984.3 6690392.5 39, 354977.1 6690387.4 39, 354972.5 6690393.9 39, 354979.6 6690398.8 39, 354981.9 6690395.6 39, 354983.1 6690396.5 39, 354984.2 6690396.3 39, 354986 6690393.8 39, 354984.3 6690392.5 39))
BATIMENT0000000302934121;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;31.6;39.2;42.6;32.0;Cadastre;A 1.0;POLYGON Z ((354968 6690400 39.2, 354975.1 6690405 39.2, 354979.6 6690398.8 39.2, 354972.5 6690393.9 39.2, 354968 6690400 39.2))
BATIMENT0000000302934122;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.1;31.3;39.4;41.5;32.0;Cadastre;A 1.0;POLYGON Z ((354963.1 6690407.1 39.4, 354970.1 6690411.8 39.4, 354975.1 6690405 39.4, 354968 6690400 39.4, 354963.1 6690407.1 39.4))
BATIMENT0000000302934104;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;30.2;34.8;37.0;31.6;Cadastre;;POLYGON Z ((354982.6 6690410.4 34.8, 354985.8 6690413 34.8, 354990.5 6690407 34.8, 354987.2 6690404.4 34.8, 354982.6 6690410.4 34.8))
BATIMENT0000000302934114;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.3;31.6;38.0;41.9;32.1;Cadastre;A 1.0;POLYGON Z ((354953.9 6690421 38, 354952.4 6690422.9 38, 354957.9 6690426.8 38, 354960.1 6690428.6 38, 354961.3 6690429.5 38, 354963 6690427.1 38, 354961 6690425.6 38, 354965.2 6690419.7 38, 354958.3 6690414.8 38, 354953.9 6690421 38))
BATIMENT0000000302934113;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;7.6;30.0;37.6;40.9;32.1;Cadastre;A 1.0;POLYGON Z ((354954.7 6690435.2 37.6, 354956.3 6690436.4 37.6, 354958.6 6690433.2 37.6, 354961.3 6690429.5 37.6, 354960.1 6690428.6 37.6, 354957.9 6690426.8 37.6, 354952.4 6690422.9 37.6, 354947.2 6690429.8 37.6, 354954.7 6690435.2 37.6))
BATIMENT0000000302935364;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.1;30.6;36.7;38.0;31.4;Cadastre;;POLYGON Z ((354959.6 6690444.1 36.7, 354959.9 6690444.3 36.7, 354961 6690445.2 36.7, 354961.1 6690444.8 36.7, 354963.2 6690442.2 36.7, 354961.7 6690441.1 36.7, 354959.6 6690444.1 36.7))
BATIMENT0000002011291487;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:49:07;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.7;28.7;;35.4;29.5;Imagerie aérienne;;POLYGON Z ((355002.3 6690424.9 35.1, 355001.8 6690425.7 35.1, 354999.8 6690424.6 33.2, 354996 6690430.6 33, 354997.8 6690431.8 35, 354998.6 6690432.4 35, 354995.3 6690437.8 35, 354994.5 6690437.4 35, 354992.5 6690436.2 33, 354989.5 6690440.7 32.8, 354991.4 6690442.2 35.2, 354992.2 6690442.7 35.2, 354988.7 6690448.3 35.2, 354987.9 6690447.7 35.2, 354985.8 6690446.5 33.1, 354983 6690450.9 32.9, 354985 6690452.3 35.3, 354985.8 6690452.8 35.3, 354982.4 6690458.1 35.3, 354981.7 6690457.7 35.3, 354979.6 6690456.5 33.2, 354976.7 6690461.1 33.1, 354978.6 6690462.4 35.2, 354979.3 6690462.9 35.2, 354977.5 6690465.7 35.2, 354985 6690470.2 35.2, 354986.3855916846 6690471.022695063 34.29070545697805, 354988.9371033781 6690471.022695063 33.1, 354989.5 6690470.2 33.1, 354986.8 6690468.2 35.4, 354990.3 6690462.3 35.4, 354993.2 6690464.3 32.8, 354995.9 6690459.9 32.8, 354993.1 6690457.8 35.1, 354996.8 6690451.9 35.1, 354999.6 6690454.1 32.8, 355002.2 6690449.8 32.8, 354999.4 6690447.8 35, 355003.3 6690441.7 35, 355005.9 6690443.9 32.6, 355008.7 6690439.6 32.6, 355006 6690437.6 35, 355010.6 6690430.2 35, 355002.3 6690424.9 35.1))
BATIMENT0000000302934131;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;32.7;36.5;;;Cadastre;;POLYGON Z ((354854.7 6690417.8 36.5, 354854.4 6690418.2 36.5, 354853.4 6690419.1 36.5, 354854.8 6690420.5 36.5, 354856.8 6690422.7 36.5, 354857.7 6690421.4 36.5, 354858.1 6690421.1 36.5, 354854.7 6690417.8 36.5))
BATIMENT0000000302934205;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;31.9;37.6;38.7;32.7;Cadastre;;POLYGON Z ((354806.3 6690422.4 37.6, 354808.4 6690424.6 37.6, 354811.4 6690421.5 37.6, 354809.3 6690419.3 37.6, 354806.3 6690422.4 37.6))
BATIMENT0000000302934151;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;33.5;42.2;43.4;33.7;Cadastre;;POLYGON Z ((354869 6690422.4 42.2, 354870.6 6690423.8 42.2, 354872.5 6690421.6 42.2, 354872.1 6690421.2 42.2, 354871.8 6690421.2 42.2, 354870.7 6690420.3 42.2, 354869 6690422.4 42.2))
BATIMENT0000000302934129;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;33.5;36.2;36.3;33.7;Cadastre;;POLYGON Z ((354858.1 6690421.1 36.2, 354857.7 6690421.4 36.2, 354856.8 6690422.7 36.2, 354859.8 6690426.2 36.2, 354861.4 6690424.4 36.2, 354858.1 6690421.1 36.2))
BATIMENT0000000302934170;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;32.9;40.9;41.7;33.8;Cadastre;;POLYGON Z ((354870.3 6690425.2 40.9, 354871.6 6690426.3 40.9, 354872.4 6690425.2 40.9, 354871.1 6690424.3 40.9, 354870.3 6690425.2 40.9))
BATIMENT0000000302934130;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;33.5;36.0;36.8;33.7;Cadastre;;POLYGON Z ((354859.8 6690426.2 36, 354862.7 6690429.4 36, 354864.1 6690428.1 36, 354864.8 6690427.2 36, 354861.4 6690424.4 36, 354859.8 6690426.2 36))
BATIMENT0000000302934133;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;32.6;35.9;38.5;33.7;Cadastre;;POLYGON Z ((354862.7 6690429.4 35.9, 354863.5 6690430.1 35.9, 354865.9 6690432.8 35.9, 354867.4 6690431 35.9, 354864.1 6690428.1 35.9, 354862.7 6690429.4 35.9))
BATIMENT0000000302934270;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;MSS;MSS:69398;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.4;31.3;40.7;43.6;32.8;Cadastre;;POLYGON Z ((354824.4 6690412.4 40.7, 354810.4 6690426.4 40.7, 354832.9 6690449.7 40.7, 354840.5 6690442.1 40.7, 354842.7 6690444.2 40.7, 354848.2 6690438.7 40.7, 354846.1 6690436.5 40.7, 354846.8 6690435.8 40.7, 354824.4 6690412.4 40.7))
BATIMENT0000000302934134;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;31.5;35.7;37.7;33.6;Cadastre;;POLYGON Z ((354866.8 6690434 35.7, 354871.8 6690439.5 35.7, 354872.9 6690438.4 35.7, 354873.2 6690438.1 35.7, 354868.3 6690432.6 35.7, 354866.8 6690434 35.7))
BATIMENT0000000302936950;Indifférenciée;Sportif;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.9;31.0;39.9;42.1;32.7;Cadastre;;POLYGON Z ((354814.4 6690441.9 39.9, 354817.9 6690445.5 39.9, 354823 6690440.6 39.9, 354810.8 6690428.1 39.9, 354805.9 6690432.9 39.9, 354810.4 6690437.4 39.9, 354814.4 6690441.9 39.9))
BATIMENT0000000302934171;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;33.1;40.7;42.4;33.8;Cadastre;A 1.0;POLYGON Z ((354873.7 6690423.8 40.7, 354880.4 6690429.8 40.7, 354881 6690429.2 40.7, 354886.2 6690423.2 40.7, 354879.3 6690417.2 40.7, 354873.7 6690423.8 40.7))
BATIMENT0000000302934196;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.5;31.9;42.5;44.7;33.1;Cadastre;A 1.0;POLYGON Z ((354930.6 6690421.2 42.5, 354928.4 6690419.7 42.5, 354927.1 6690421.3 42.5, 354929.7 6690423.5 42.5, 354935.9 6690428.7 42.5, 354939.1 6690424.1 42.5, 354932.6 6690418.5 42.5, 354930.6 6690421.2 42.5))
BATIMENT0000000302934153;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.9;33.0;40.0;42.8;33.7;Cadastre;A 1.0;POLYGON Z ((354881 6690429.2 40, 354885.4 6690433.1 40, 354890.6 6690427.1 40, 354886.2 6690423.2 40, 354881 6690429.2 40))
BATIMENT0000000302934179;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;4.0;34;40;11.6;32.1;43.7;45.0;33.1;Cadastre;A 1.0;POLYGON Z ((354904.3 6690425.5 43.7, 354923.1 6690442.2 43.7, 354926.1 6690441.8 43.7, 354935.9 6690428.7 43.7, 354929.7 6690423.5 43.7, 354924.3 6690431.5 43.7, 354910.2 6690418.9 43.7, 354904.3 6690425.5 43.7))
BATIMENT0000000302934139;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.4;32.8;41.2;44.6;33.4;Cadastre;A 1.0;POLYGON Z ((354889.9 6690437.7 41.2, 354895.6 6690431.5 41.2, 354890.6 6690427.1 41.2, 354885.4 6690433.1 41.2, 354885 6690433.5 41.2, 354889.4 6690437.2 41.2, 354889.9 6690437.7 41.2))
BATIMENT0000000302934112;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;10;6.0;30.8;36.8;40.2;32.1;Cadastre;A 1.0;POLYGON Z ((354941 6690438.2 36.8, 354948.6 6690443.6 36.8, 354954.7 6690435.2 36.8, 354947.2 6690429.8 36.8, 354941 6690438.2 36.8))
BATIMENT0000000302934140;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.4;32.2;39.7;41.5;32.7;Cadastre;A 1.0;POLYGON Z ((354897.6 6690445.8 39.7, 354901.4 6690449 39.7, 354901.7 6690448.7 39.7, 354907.6 6690442 39.7, 354901.4 6690436.4 39.7, 354895.1 6690443.6 39.7, 354897.6 6690445.8 39.7))
BATIMENT0000000302934138;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.3;32.4;36.7;41.5;33.4;Cadastre;A 1.0;POLYGON Z ((354889.9 6690437.7 36.7, 354889.4 6690437.2 36.7, 354881.6 6690445.9 36.7, 354879.7 6690448.2 36.7, 354884.9 6690453.9 36.7, 354885.3 6690454.4 36.7, 354886.5 6690453.2 36.7, 354892.2 6690446.6 36.7, 354895.1 6690443.6 36.7, 354901.4 6690436.4 36.7, 354895.6 6690431.5 36.7, 354889.9 6690437.7 36.7))
BATIMENT0000000302934110;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1979-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;6.2;30.5;36.7;40.8;32.2;Cadastre;A 1.0;POLYGON Z ((354948.6 6690443.6 36.7, 354941 6690438.2 36.7, 354938.6 6690441.4 36.7, 354942.1 6690444 36.7, 354940.6 6690446.1 36.7, 354943.4 6690447.8 36.7, 354944.8 6690448.7 36.7, 354948.6 6690443.6 36.7))
BATIMENT0000000302934137;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;32.1;34.5;35.9;33.4;Cadastre;;POLYGON Z ((354877.5 6690442.1 34.5, 354877.1 6690442.4 34.5, 354875.9 6690443.9 34.5, 354879.7 6690448.2 34.5, 354881.6 6690445.9 34.5, 354877.5 6690442.1 34.5))
BATIMENT0000000302934136;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;30.6;35.8;35.9;33.5;Cadastre;;POLYGON Z ((354871.8 6690439.5 35.8, 354872.9 6690440.8 35.8, 354874.8 6690442.9 35.8, 354875.9 6690443.9 35.8, 354877.1 6690442.4 35.8, 354872.9 6690438.4 35.8, 354871.8 6690439.5 35.8))
BATIMENT0000000302936949;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;30.9;36.2;38.7;31.7;Cadastre;;POLYGON Z ((354811 6690445.6 36.2, 354814.4 6690441.9 36.2, 354810.4 6690437.4 36.2, 354806.6 6690441.2 36.2, 354811 6690445.6 36.2))
BATIMENT0000000302934271;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.1;29.6;36.7;41.4;32.2;Cadastre;A 1.0;POLYGON Z ((354777 6690434.3 36.7, 354789.6 6690447 36.7, 354797.4 6690439.1 36.7, 354800.3 6690441.9 36.7, 354792.4 6690449.8 36.7, 354794.8 6690452.4 36.7, 354794.5 6690452.7 36.7, 354796.8 6690454.9 36.7, 354799.6 6690452.3 36.7, 354808.3 6690461.1 36.7, 354805.6 6690463.7 36.7, 354807.7 6690465.9 36.7, 354808 6690465.6 36.7, 354810.7 6690468.3 36.7, 354822.1 6690457 36.7, 354811 6690445.6 36.7, 354806.6 6690441.2 36.7, 354804 6690438.7 36.7, 354803.3 6690439.3 36.7, 354800.6 6690436.4 36.7, 354801.1 6690435.7 36.7, 354788.3 6690422.8 36.7, 354777 6690434.3 36.7))
BATIMENT0000000302934126;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.3;29.3;38.6;38.7;30.5;Cadastre;;POLYGON Z ((354838.8 6690461.9 38.6, 354844.5 6690456.3 38.6, 354840.8 6690452.8 38.6, 354835.2 6690458.3 38.6, 354838.8 6690461.9 38.6))
BATIMENT0000000302934125;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.3;28.9;38.2;39.2;31.4;Cadastre;;POLYGON Z ((354836.9 6690449.1 38.2, 354832.4 6690453.5 38.2, 354815 6690470.6 38.2, 354815.43353339797 6690471.022695063 38.2, 354822.4773049375 6690471.022695063 38.2, 354825.6 6690467.9 38.2, 354826.3 6690467.2 38.2, 354835.2 6690458.3 38.2, 354840.8 6690452.8 38.2, 354836.9 6690449.1 38.2))
BATIMENT0000000302935235;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;30.3;35.2;37.3;32.6;Cadastre;;POLYGON Z ((354879.3 6690470.1 35.2, 354851.1 6690442.6 35.2, 354844.9 6690448.7 35.2, 354867.78885037237 6690471.022695063 35.2, 354890.4777413808 6690471.022695063 35.2, 354895.6 6690465.8 35.2, 354891.2 6690460.9 35.2, 354889.7 6690459.3 35.2, 354879.3 6690470.1 35.2))
BATIMENT0000000302934124;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;29.1;33.3;38.6;30.5;Cadastre;;POLYGON Z ((354844.5 6690456.3 33.3, 354838.8 6690461.9 33.3, 354835.2 6690458.3 33.3, 354826.3 6690467.2 33.3, 354825.6 6690467.9 33.3, 354828.6382978991 6690471.022695063 33.3, 354831.8773049377 6690471.022695063 33.3, 354845.5 6690457.4 33.3, 354844.5 6690456.3 33.3))
BATIMENT0000000302934123;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.7;28.5;38.2;39.4;30.1;Cadastre;;POLYGON Z ((354825.6 6690467.9 38.2, 354822.4773049375 6690471.022695063 38.2, 354828.6382978991 6690471.022695063 38.2, 354825.6 6690467.9 38.2))
BATIMENT0000000302934215;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;24;7.2;29.5;36.7;42.0;29.9;Cadastre;A 1.0;POLYGON Z ((354785.4511680999 6690471.022695063 36.7, 354795.4226950626 6690471.022695063 36.7, 354790.4 6690466 36.7, 354785.4511680999 6690471.022695063 36.7))
BATIMENT0000000302934142;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;30;20;7.9;32.2;40.1;42.7;32.7;Cadastre;A 1.0;POLYGON Z ((354907.6 6690442 40.1, 354901.7 6690448.7 40.1, 354901.4 6690449 40.1, 354900.7 6690449.9 40.1, 354903.1 6690452.1 40.1, 354903.3 6690451.7 40.1, 354907.6 6690455.8 40.1, 354908.4 6690454.9 40.1, 354914.4 6690448.1 40.1, 354907.6 6690442 40.1))
BATIMENT0000000302934135;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-07-01 11:18:26;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;30.3;35.4;36.9;33.3;Cadastre;;POLYGON Z ((354872.9 6690440.8 35.4, 354868.7 6690444.7 35.4, 354870.5 6690446.8 35.4, 354870.1 6690447.1 35.4, 354875.2 6690452.9 35.4, 354873.4 6690454.4 35.4, 354874.6 6690455.5 35.4, 354871.4 6690458.1 35.4, 354875.8 6690462.6 35.4, 354880.1 6690458.5 35.4, 354884.9 6690453.9 35.4, 354879.7 6690448.2 35.4, 354875.9 6690443.9 35.4, 354874.8 6690442.9 35.4, 354872.9 6690440.8 35.4))
BATIMENT0000000302934109;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.2;30.6;36.8;39.8;32.4;Cadastre;A 1.0;POLYGON Z ((354944.8 6690448.7 36.8, 354943.4 6690447.8 36.8, 354940.6 6690446.1 36.8, 354939.2 6690448.1 36.8, 354937.4 6690448.7 36.8, 354934.8 6690446.6 36.8, 354932.1 6690450.3 36.8, 354939.6 6690455.6 36.8, 354941.8 6690457.3 36.8, 354941.9 6690457.4 36.8, 354945.1 6690459.7 36.8, 354946.8 6690457.2 36.8, 354943.4 6690454.7 36.8, 354942.8 6690455.5 36.8, 354940.9 6690454 36.8, 354944.8 6690448.7 36.8))
BATIMENT0000000302934143;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;32.0;38.4;40.3;32.7;Cadastre;;POLYGON Z ((354908.4 6690454.9 38.4, 354907.6 6690455.8 38.4, 354906.7 6690456.9 38.4, 354906.5 6690457.2 38.4, 354911.4 6690461.7 38.4, 354911.7 6690461.3 38.4, 354917.4 6690453.6 38.4, 354917.5 6690450.8 38.4, 354914.4 6690448.1 38.4, 354908.4 6690454.9 38.4))
BATIMENT0000000302934107;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1917-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;5.9;30.7;36.6;39.5;32.4;Cadastre;A 1.0;POLYGON Z ((354929.1 6690454.3 36.6, 354935.9 6690459.2 36.6, 354939.2 6690461.5 36.6, 354941.8 6690457.3 36.6, 354939.6 6690455.6 36.6, 354932.1 6690450.3 36.6, 354929.1 6690454.3 36.6))
BATIMENT0000000302934106;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;20;6.3;30.1;36.4;39.6;32.3;Cadastre;A 1.0;POLYGON Z ((354929.1 6690454.3 36.4, 354926.2 6690458.5 36.4, 354936.1 6690465.9 36.4, 354937.8 6690466.8 36.4, 354939.3 6690464.4 36.4, 354937.9 6690463.1 36.4, 354934.4 6690460.9 36.4, 354935.9 6690459.2 36.4, 354929.1 6690454.3 36.4))
BATIMENT0000000302934105;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;31.2;34.2;36.0;31.9;Cadastre;;POLYGON Z ((354939.2 6690461.5 34.2, 354935.9 6690459.2 34.2, 354934.4 6690460.9 34.2, 354937.9 6690463.1 34.2, 354939.2 6690461.5 34.2))
BATIMENT0000000302934108;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;15;20;7.5;31.6;39.2;41.6;32.4;Cadastre;A 1.0;POLYGON Z ((354920.5 6690466.4 39.2, 354926.9151686586 6690471.022695063 39.2, 354928.40524820914 6690471.022695063 39.2, 354929.2 6690469.8 39.2, 354930.8981875875 6690471.022695063 39.2, 354932.1456388988 6690471.022695063 39.2, 354936.1 6690465.9 39.2, 354926.2 6690458.5 39.2, 354920.5 6690466.4 39.2))
BATIMENT0000000302934111;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.6;31.3;38.9;41.6;32.4;Cadastre;A 1.0;POLYGON Z ((354918.045390126 6690471.022695063 38.9, 354926.9151686586 6690471.022695063 38.9, 354920.5 6690466.4 38.9, 354917.2 6690470.6 38.9, 354918.045390126 6690471.022695063 38.9))
BATIMENT0000000302928914;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;10.5;27.7;38.2;42.7;29.9;Cadastre;C 0.9;POLYGON Z ((354282.9 6689921.4 38.2, 354281.2 6689925 38.2, 354285.8 6689940.5 38.2, 354291.3 6689939 38.2, 354289.5 6689931.9 38.2, 354292 6689931.1 38.2, 354291 6689927.1 38.2, 354296.5 6689924.2 38.2, 354293 6689916.7 38.2, 354282.9 6689921.4 38.2))
BATIMENT0000000302928364;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.2;29.6;37.8;42.2;30.4;Cadastre;A 1.0;POLYGON Z ((354334 6689940.6 37.8, 354342.8 6689942.5 37.8, 354344.7 6689931 37.8, 354335.1 6689931.7 37.8, 354334 6689940.6 37.8))
BATIMENT0000000302929156;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;3.8;29.1;33.0;35.5;29.4;Cadastre;C 0.3;POLYGON Z ((354299.5 6689937.4 33, 354300.8 6689943.5 33, 354304.7 6689942.3 33, 354303 6689936.3 33, 354299.5 6689937.4 33))
BATIMENT0000000302929154;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;15;09;4.3;29.1;33.5;34.1;30.4;Cadastre;C 0.3;POLYGON Z ((354314.6 6689941.9 33.5, 354314.8 6689944.9 33.5, 354315 6689947.3 33.5, 354319.2 6689947.3 33.5, 354318.8 6689941.4 33.5, 354314.6 6689941.9 33.5))
BATIMENT0000000302928363;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;10.3;29.4;39.7;42.9;30.4;Cadastre;C 1.0;POLYGON Z ((354331.1 6689940.1 39.7, 354330.2 6689947.2 39.7, 354330.7 6689947.3 39.7, 354331.7 6689947.4 39.7, 354332.8 6689947.5 39.7, 354341.8 6689949.1 39.7, 354342.8 6689942.5 39.7, 354334 6689940.6 39.7, 354331.1 6689940.1 39.7))
BATIMENT0000000302928412;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.7;27.4;33.2;36.4;28.8;Cadastre;A 1.0;POLYGON Z ((354271.7 6689948.3 33.2, 354277.3 6689946.8 33.2, 354276.3 6689943.6 33.2, 354270.8 6689945.2 33.2, 354271.7 6689948.3 33.2))
BATIMENT0000000302929157;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.7;29.2;32.9;33.7;30.1;Cadastre;;POLYGON Z ((354312.6 6689945.1 32.9, 354312.6 6689947.4 32.9, 354313.8 6689947.4 32.9, 354315 6689947.3 32.9, 354314.8 6689944.9 32.9, 354312.6 6689945.1 32.9))
BATIMENT0000000302929153;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1901-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;15;09;3.6;29.1;32.8;33.1;30.1;Cadastre;C 0.3;POLYGON Z ((354312.6 6689947.4 32.8, 354306.1 6689947.6 32.8, 354307.6 6689952.7 32.8, 354313.6 6689953 32.8, 354313.8 6689947.4 32.8, 354312.6 6689947.4 32.8))
BATIMENT0000000302928362;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;29.9;35.2;39.2;30.4;Cadastre;;POLYGON Z ((354330.6 6689948.4 35.2, 354328.6 6689948.2 35.2, 354327.6 6689953.6 35.2, 354328.5 6689953.7 35.2, 354331.6 6689954.1 35.2, 354332.6 6689948.7 35.2, 354331.6 6689948.5 35.2, 354331.7 6689947.4 35.2, 354330.7 6689947.3 35.2, 354330.6 6689948.4 35.2))
BATIMENT0000000302928361;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1901-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;11.0;29.4;40.5;42.9;30.4;Cadastre;C 0.8;POLYGON Z ((354341.8 6689949.1 40.5, 354332.8 6689947.5 40.5, 354331.7 6689947.4 40.5, 354331.6 6689948.5 40.5, 354332.6 6689948.7 40.5, 354331.6 6689954.1 40.5, 354340.8 6689956 40.5, 354341.8 6689949.1 40.5))
BATIMENT0000000302928825;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.9;25.2;35.2;38.5;26.6;Cadastre;B 0.8;POLYGON Z ((354199.5 6689937.5 35.2, 354199.9 6689938.1 35.2, 354204.7 6689948 35.2, 354225.1 6689938.4 35.2, 354220.9 6689929.8 35.2, 354219.9 6689927.8 35.2, 354199.5 6689937.5 35.2))
BATIMENT0000000302929043;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;8.5;26.3;34.8;37.0;28.0;Cadastre;A 1.0;POLYGON Z ((354246.5 6689938.1 34.8, 354249.4 6689948.7 34.8, 354249.8 6689950.4 34.8, 354251 6689955.2 34.8, 354258.9 6689953.2 34.8, 354258.4 6689951.7 34.8, 354257.5 6689948.6 34.8, 354256.9 6689946.3 34.8, 354257.3 6689946.3 34.8, 354253.9 6689934.5 34.8, 354246.5 6689938 34.8, 354246.5 6689938.1 34.8))
BATIMENT0000000302928826;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;9.9;25.2;35.2;38.1;26.4;Cadastre;A 1.0;POLYGON Z ((354195.9 6689939.9 35.2, 354195.5 6689939 35.2, 354189.3 6689941.8 35.2, 354190.1 6689943.9 35.2, 354186.8 6689945.5 35.2, 354191.2 6689954.5 35.2, 354204.7 6689948 35.2, 354199.9 6689938.1 35.2, 354195.9 6689939.9 35.2))
BATIMENT0000000302928953;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;5.8;26.1;32.0;36.6;27.2;Cadastre;A 1.0;POLYGON Z ((354223.9 6689959.6 32, 354231.5 6689958.1 32, 354228.8 6689948.5 32, 354221.6 6689951.9 32, 354223.9 6689959.6 32))
BATIMENT0000000302928951;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.1;26.7;34.8;37.0;27.2;Cadastre;A 1.0;POLYGON Z ((354216.6 6689954.3 34.8, 354218.3 6689962.1 34.8, 354224.1 6689960.7 34.8, 354224 6689960.2 34.8, 354223.9 6689959.6 34.8, 354221.6 6689951.9 34.8, 354216.6 6689954.3 34.8))
BATIMENT0000000302928950;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.9;26.7;35.6;38.0;26.9;Cadastre;A 1.0;POLYGON Z ((354210.1 6689957.5 35.6, 354212.2 6689967.3 35.6, 354219.1 6689965.8 35.6, 354218.3 6689962.1 35.6, 354216.6 6689954.3 35.6, 354210.1 6689957.5 35.6))
BATIMENT0000000302929049;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;9.6;27.0;36.6;38.0;27.1;Cadastre;A 1.0;POLYGON Z ((354251 6689964.8 36.6, 354248.8 6689955.8 36.6, 354240 6689958 36.6, 354242.2 6689966.9 36.6, 354249.9 6689965.1 36.6, 354251 6689964.8 36.6))
BATIMENT0000000302928442;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;23;7.9;27.2;35.1;37.0;27.2;Cadastre;A 1.0;POLYGON Z ((354232.1 6689962.5 35.1, 354224.1 6689964.6 35.1, 354225.4 6689970.1 35.1, 354233.6 6689968.3 35.1, 354232.1 6689962.5 35.1))
BATIMENT0000000302928952;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;20;8.9;26.7;35.6;38.0;26.9;Cadastre;C 0.8;POLYGON Z ((354193.2 6689965.6 35.6, 354197.8 6689975.5 35.6, 354209 6689970.2 35.6, 354208.8 6689969.6 35.6, 354212.4 6689968.1 35.6, 354212.2 6689967.3 35.6, 354210.1 6689957.5 35.6, 354193.2 6689965.6 35.6))
BATIMENT0000000302928441;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.5;27.1;34.6;37.4;27.3;Cadastre;A 1.0;POLYGON Z ((354223.7 6689970.5 34.6, 354225.2 6689976 34.6, 354227.3 6689975.4 34.6, 354234.9 6689973.4 34.6, 354233.6 6689968.3 34.6, 354225.4 6689970.1 34.6, 354223.7 6689970.5 34.6))
BATIMENT0000000302928413;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;15;20;10.6;27.6;38.2;40.5;28.8;Cadastre;A 1.0;POLYGON Z ((354266.9 6689949.7 38.2, 354268.2 6689953.8 38.2, 354269.8 6689953.4 38.2, 354270.9 6689957.1 38.2, 354279.5 6689955 38.2, 354277.3 6689946.8 38.2, 354271.7 6689948.3 38.2, 354266.9 6689949.7 38.2))
BATIMENT0000000302928358;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;10;7.7;28.0;35.7;40.3;29.5;Cadastre;A 1.0;POLYGON Z ((354288.6 6689950 35.7, 354291.9 6689962.1 35.7, 354302.4 6689959.3 35.7, 354298.9 6689947.3 35.7, 354288.6 6689950 35.7))
BATIMENT0000000302928360;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;23;23;10.0;29.6;39.6;43.5;30.1;Cadastre;A 1.0;POLYGON Z ((354330.8 6689960.6 39.6, 354339.9 6689962.2 39.6, 354340.8 6689956 39.6, 354331.6 6689954.1 39.6, 354330.8 6689960.6 39.6))
BATIMENT0000000302928414;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.1;28.2;37.3;42.5;28.6;Cadastre;A 1.0;POLYGON Z ((354269.2 6689957.5 37.3, 354270.6 6689962.1 37.3, 354271 6689962 37.3, 354271.7 6689964.6 37.3, 354271.3 6689964.9 37.3, 354271.4 6689965.5 37.3, 354270.8 6689965.8 37.3, 354271.6 6689968.4 37.3, 354272.3 6689968.3 37.3, 354274.1 6689974.5 37.3, 354284.4 6689971.8 37.3, 354279.5 6689955 37.3, 354270.9 6689957.1 37.3, 354269.2 6689957.5 37.3))
BATIMENT0000000302928357;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1974-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;30;49;3.2;29.0;32.2;45.3;30.4;Cadastre;A 1.0;POLYGON Z ((354325 6689959.6 32.2, 354321.9 6689980.3 32.2, 354316.5 6689978.8 32.2, 354314.7 6689979.2 32.2, 354309.5 6689959.5 32.2, 354310.8 6689959.1 32.2, 354310.7 6689957.4 32.2, 354309.9 6689957.3 32.2, 354303.1 6689959.1 32.2, 354309.8 6689983.3 32.2, 354310.5 6689983.2 32.2, 354317.1 6689981.4 32.2, 354317.3 6689982.1 32.2, 354325.4 6689980.7 32.2, 354332.1 6689979.4 32.2, 354337.1 6689980 32.2, 354339.9 6689962.2 32.2, 354330.8 6689960.6 32.2, 354325 6689959.6 32.2))
BATIMENT0000000302928415;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;24;20;11.3;28.3;39.6;43.0;28.9;Cadastre;A 1.0;POLYGON Z ((354276 6689981.9 39.6, 354279.2 6689981 39.6, 354286.5 6689979.1 39.6, 354284.4 6689971.8 39.6, 354274.1 6689974.5 39.6, 354276 6689981.9 39.6))
BATIMENT0000000302928359;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;28.3;35.0;36.7;29.9;Cadastre;;POLYGON Z ((354311.9 6689987.6 35, 354314.1 6689987.2 35, 354315 6689989.7 35, 354319.1 6689988.6 35, 354317.3 6689982.1 35, 354317.1 6689981.4 35, 354310.5 6689983.2 35, 354311.9 6689987.6 35))
BATIMENT0000000302928356;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;35;20;10.7;29.7;40.5;43.2;30.2;Cadastre;A 1.0;POLYGON Z ((354327.3 6689992.2 40.5, 354327.7 6689992.1 40.5, 354335.3 6689991.6 40.5, 354337.1 6689980 40.5, 354332.1 6689979.4 40.5, 354325.4 6689980.7 40.5, 354327.3 6689992.2 40.5))
BATIMENT0000000302928416;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.1;28.6;34.7;38.5;29.5;Cadastre;A 1.0;POLYGON Z ((354280.1 6689984.3 34.7, 354277.4 6689985.1 34.7, 354281.4 6689999.9 34.7, 354291.8 6689997.2 34.7, 354286.5 6689979.1 34.7, 354279.2 6689981 34.7, 354280.1 6689984.3 34.7))
BATIMENT0000000302928355;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1826-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.8;29.7;37.5;39.4;30.2;Cadastre;A 1.0;POLYGON Z ((354326.6 6690000.9 37.5, 354329.1 6690000.7 37.5, 354333.7 6690001.6 37.5, 354335.3 6689991.6 37.5, 354327.7 6689992.1 37.5, 354327.3 6689992.2 37.5, 354326 6689992.2 37.5, 354326.3 6689995.4 37.5, 354325.1 6689995.8 37.5, 354326.6 6690000.9 37.5))
BATIMENT0000000302928830;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;10.2;25.3;35.6;36.8;26.5;Cadastre;A 1.0;POLYGON Z ((354150.8 6689960.8 35.6, 354155.7 6689971.3 35.6, 354168.9 6689965.1 35.6, 354169.7 6689964.7 35.6, 354165.2 6689954.9 35.6, 354164.9 6689954.3 35.6, 354150.8 6689960.8 35.6))
BATIMENT0000000302928831;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.4;25.7;32.1;36.0;26.5;Cadastre;A 1.0;POLYGON Z ((354144.2 6689964 32.1, 354149.2 6689974.5 32.1, 354155.7 6689971.3 32.1, 354150.8 6689960.8 32.1, 354144.2 6689964 32.1))
BATIMENT0000000302929009;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.2;25.2;35.5;39.5;26.2;Cadastre;B 0.8;POLYGON Z ((354131.3 6689971.8 35.5, 354130.1 6689971.5 35.5, 354129.6 6689971.5 35.5, 354129.3 6689971.4 35.5, 354128.9 6689971.4 35.5, 354128.7 6689971.5 35.5, 354128.5 6689971.5 35.5, 354128.1 6689971.7 35.5, 354128 6689971.8 35.5, 354127.6 6689972 35.5, 354127.4 6689972.2 35.5, 354127.3 6689972.4 35.5, 354127.2 6689972.6 35.5, 354127.1 6689972.8 35.5, 354126.8 6689973.9 35.5, 354124.8 6689975 35.5, 354129.3 6689983.8 35.5, 354129.9 6689983.5 35.5, 354140 6689978.8 35.5, 354135.7 6689969.8 35.5, 354131.3 6689971.8 35.5))
BATIMENT0000000302928908;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;12;7.6;26.2;33.8;38.1;26.8;Cadastre;A 1.0;POLYGON Z ((354176 6689989.6 33.8, 354175.7 6689971.5 33.8, 354170.4 6689974.1 33.8, 354172.8 6689979.6 33.8, 354173.5 6689979.4 33.8, 354173.5 6689980.5 33.8, 354173.8 6689989.6 33.8, 354176 6689989.6 33.8))
BATIMENT0000000302927332;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;02;3.7;25.7;29.5;32.3;26.2;Cadastre;B 0.4;POLYGON Z ((354122.6 6689981 29.5, 354119 6689982.5 29.5, 354121.5 6689987.8 29.5, 354121.8 6689988.4 29.5, 354125.3 6689986.3 29.5, 354122.6 6689981 29.5))
BATIMENT0000000302928907;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;26.0;34.3;38.1;26.9;Cadastre;C 0.7;POLYGON Z ((354162.6 6689980.6 34.3, 354162.7 6689989.7 34.3, 354173.8 6689989.6 34.3, 354173.5 6689980.5 34.3, 354162.6 6689980.6 34.3))
BATIMENT0000000302927331;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2023-01-31 17:40:55;1927-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.9;25.4;35.4;37.6;26.2;Cadastre;A 1.0;POLYGON Z ((354108.6 6689982 35.4, 354114 6689993.5 35.4, 354121.8 6689988.4 35.4, 354121.5 6689987.8 35.4, 354119 6689982.5 35.4, 354116.8 6689978 35.4, 354108.6 6689982 35.4))
BATIMENT0000000302927330;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;24;5.4;25.2;30.6;35.3;25.9;Cadastre;A 1.0;POLYGON Z ((354106.5 6689983 30.6, 354105.9 6689982.1 30.6, 354101.6 6689984.2 30.6, 354102.7 6689986.5 30.6, 354100.1 6689987.9 30.6, 354101.6 6689990.9 30.6, 354105.6 6689998.8 30.6, 354114 6689993.5 30.6, 354108.6 6689982 30.6, 354106.5 6689983 30.6))
BATIMENT0000000302929006;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.4;26.1;29.5;32.2;27.1;Cadastre;C 0.5;POLYGON Z ((354178.1 6690002.8 29.5, 354178 6689998.3 29.5, 354164.7 6689998.5 29.5, 354164.8 6690002.9 29.5, 354171.2 6690003 29.5, 354178.1 6690002.8 29.5))
BATIMENT0000000302929084;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;69.0;4.0;00;00;12.5;24.9;37.4;41.8;26.9;Cadastre;C 0.2;POLYGON Z ((354133.4 6690013.7 37.4, 354133 6690012.8 37.4, 354143.8 6690005.8 37.4, 354144.4 6690006.6 37.4, 354149.9 6690003.3 37.4, 354149.4 6690002.5 37.4, 354157.9 6689997.3 37.4, 354157.7 6689988 37.4, 354155.2 6689988.1 37.4, 354152.7 6689983 37.4, 354151.5 6689983.5 37.4, 354151.6 6689983.6 37.4, 354153.1 6689986.1 37.4, 354148.2 6689989.3 37.4, 354146.4 6689986.1 37.4, 354140.9 6689988.8 37.4, 354137.6 6689990.3 37.4, 354134.1 6689992.2 37.4, 354135.6 6689994.6 37.4, 354130.3 6689998.1 37.4, 354128.7 6689995.5 37.4, 354123.2 6689998.9 37.4, 354123.3 6689998.9 37.4, 354124.9 6690001.4 37.4, 354114.6 6690007.9 37.4, 354113 6690005.3 37.4, 354107.5 6690008.8 37.4, 354111.3 6690014.9 37.4, 354116.4 6690023.3 37.4, 354127.3 6690016.4 37.4, 354127.8 6690017.2 37.4, 354133.4 6690013.7 37.4))
BATIMENT0000000302929048;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;26.9;34.5;38.1;28.2;Cadastre;A 1.0;POLYGON Z ((354245.5 6689980 34.5, 354253.1 6689978.2 34.5, 354265.2 6689975.5 34.5, 354264.5 6689973.3 34.5, 354259.4 6689974.5 34.5, 354258.8 6689973.2 34.5, 354252.4 6689974.6 34.5, 354249.9 6689965.1 34.5, 354242.2 6689966.9 34.5, 354245.5 6689980 34.5))
BATIMENT0000000302929039;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;6.5;24.9;31.4;33.5;26.7;Cadastre;C 0.5;POLYGON Z ((354183 6689968.5 31.4, 354188.1 6689980.4 31.4, 354188.6 6689980.3 31.4, 354189 6689982.8 31.4, 354192.9 6689982.2 31.4, 354192.4 6689978.5 31.4, 354187.5 6689966.3 31.4, 354183 6689968.5 31.4))
BATIMENT0000000302928440;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;6.2;27.2;33.4;38.1;27.3;Cadastre;A 1.0;POLYGON Z ((354227.3 6689975.4 33.4, 354225.2 6689976 33.4, 354222.1 6689976.8 33.4, 354221.8 6689976.8 33.4, 354222.7 6689980.2 33.4, 354227.8 6689978.9 33.4, 354230.6 6689989.9 33.4, 354238.7 6689988 33.4, 354237.9 6689985.2 33.4, 354234.9 6689973.4 33.4, 354227.3 6689975.4 33.4))
BATIMENT0000000302929047;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1874-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;7.0;27.2;34.2;38.5;27.8;Cadastre;A 1.0;POLYGON Z ((354250.5 6689999.8 34.2, 354256.4 6689998.1 34.2, 354255.6 6689993.9 34.2, 354262.3 6689992.3 34.2, 354260.8 6689986 34.2, 354259.2 6689984.9 34.2, 354255.2 6689985.9 34.2, 354254.3 6689982.8 34.2, 354252.7 6689983.1 34.2, 354252.3 6689982.2 34.2, 354253.2 6689982.1 34.2, 354253.8 6689981 34.2, 354253.1 6689978.2 34.2, 354245.5 6689980 34.2, 354250.5 6689999.8 34.2))
BATIMENT0000000302928867;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;5.2;27.2;32.4;33.7;27.8;Cadastre;C 0.3;POLYGON Z ((354218.5 6689996.5 32.4, 354219 6689999.5 32.4, 354219.6 6690002.3 32.4, 354224.1 6690001.4 32.4, 354222.5 6689993.1 32.4, 354218 6689994.1 32.4, 354218.5 6689996.5 32.4))
BATIMENT0000000302928866;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;27.2;32.4;34.6;27.7;Cadastre;;POLYGON Z ((354215 6689997.5 32.4, 354215.9 6690000.6 32.4, 354219 6689999.5 32.4, 354218.5 6689996.5 32.4, 354215 6689997.5 32.4))
BATIMENT0000000302928832;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;23;7.3;28.0;35.3;38.5;28.0;Cadastre;C 0.8;POLYGON Z ((354239.2 6689991.4 35.3, 354233.8 6689992.7 35.3, 354233.9 6689993.7 35.3, 354228.8 6689995.2 35.3, 354227.5 6689997.5 35.3, 354228.4 6690001.3 35.3, 354230.2 6690002.9 35.3, 354228.2 6690003.4 35.3, 354228.8 6690006.6 35.3, 354234.4 6690005.4 35.3, 354242.4 6690003.4 35.3, 354239.2 6689991.4 35.3))
BATIMENT0000000302928946;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.6;26.7;29.3;31.0;27.0;Cadastre;C 0.2;POLYGON Z ((354204.7 6689997.1 29.3, 354199.7 6689994.5 29.3, 354200.3 6690004.4 29.3, 354206.4 6690002.5 29.3, 354205.4 6689999.3 29.3, 354204.7 6689997.1 29.3))
BATIMENT0000000302928947;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;26.6;30.2;31.5;27.2;Cadastre;;POLYGON Z ((354211.9 6690000.6 30.2, 354211 6689997.8 30.2, 354205.4 6689999.3 30.2, 354206.4 6690002.5 30.2, 354211.9 6690000.6 30.2))
BATIMENT0000000302929046;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;16;12;8.9;27.0;35.9;39.6;28.3;Cadastre;A 1.0;POLYGON Z ((354254.3 6690014.6 35.9, 354262.3 6690012.5 35.9, 354259.4 6690002.1 35.9, 354261.6 6690001.7 35.9, 354260.4 6689997 35.9, 354256.4 6689998.1 35.9, 354250.5 6689999.8 35.9, 354254.3 6690014.6 35.9))
BATIMENT0000000302934096;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.8;26.1;28.9;30.7;26.9;Cadastre;B 0.3;POLYGON Z ((354164.8 6690006.2 28.9, 354171.2 6690006.2 28.9, 354171.2 6690003 28.9, 354164.8 6690002.9 28.9, 354164.8 6690006.2 28.9))
BATIMENT0000000302934094;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;27.0;30.5;32.7;27.6;Cadastre;;POLYGON Z ((354179.7 6690017.4 30.5, 354179.6 6690008.2 30.5, 354178.1 6690008.3 30.5, 354178.1 6690010.7 30.5, 354178.1 6690015.9 30.5, 354178.1 6690016.2 30.5, 354178.1 6690017.5 30.5, 354179.7 6690017.4 30.5))
BATIMENT0000000302934092;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;12;4.9;26.4;31.3;33.4;27.6;Cadastre;B 0.7;POLYGON Z ((354171.1 6690018.7 31.3, 354174.3 6690018.6 31.3, 354175.2 6690018.6 31.3, 354178.1 6690018.6 31.3, 354178.1 6690017.5 31.3, 354178.1 6690016.2 31.3, 354178.1 6690015.9 31.3, 354175.2 6690015.9 31.3, 354175.2 6690010.6 31.3, 354164.8 6690010.6 31.3, 354164.9 6690018.9 31.3, 354171.1 6690018.7 31.3))
BATIMENT0000000302934099;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;33.0;5.0;90;90;13.3;24.9;38.2;42.4;26.5;Cadastre;C 0.1;POLYGON Z ((354100.7 6690033.6 38.2, 354100.9 6690033.7 38.2, 354101.4 6690033.8 38.2, 354101.6 6690033.9 38.2, 354102.1 6690034 38.2, 354102.2 6690034 38.2, 354102.6 6690034 38.2, 354102.9 6690034 38.2, 354103.2 6690034 38.2, 354103.5 6690033.9 38.2, 354104 6690033.9 38.2, 354104.3 6690033.8 38.2, 354104.5 6690033.7 38.2, 354104.7 6690033.6 38.2, 354105.2 6690033.5 38.2, 354106.7 6690035.9 38.2, 354112.3 6690032.2 38.2, 354110.9 6690029.9 38.2, 354111 6690029.8 38.2, 354111 6690029.7 38.2, 354111.3 6690029.5 38.2, 354111.3 6690029.4 38.2, 354111.5 6690029.2 38.2, 354111.7 6690028.9 38.2, 354111.8 6690028.7 38.2, 354111.9 6690028.5 38.2, 354112.1 6690028.3 38.2, 354112.2 6690028 38.2, 354112.4 6690027.5 38.2, 354112.6 6690027.1 38.2, 354112.6 6690026.9 38.2, 354112.7 6690026.6 38.2, 354112.7 6690026.5 38.2, 354112.7 6690026.4 38.2, 354112.7 6690026.2 38.2, 354112.8 6690026 38.2, 354112.8 6690025.7 38.2, 354116.4 6690023.3 38.2, 354111.3 6690014.9 38.2, 354107.5 6690008.8 38.2, 354106.4 6690009.5 38.2, 354108 6690012.1 38.2, 354105.7 6690013.7 38.2, 354104.9 6690013.3 38.2, 354104.3 6690013 38.2, 354104 6690012.9 38.2, 354103.9 6690012.9 38.2, 354103.5 6690012.8 38.2, 354103.4 6690012.7 38.2, 354103.3 6690012.7 38.2, 354102.6 6690012.6 38.2, 354102.5 6690012.6 38.2, 354102.1 6690012.5 38.2, 354102.2 6690013.5 38.2, 354102 6690013.5 38.2, 354101.3 6690013.6 38.2, 354101.4 6690014.4 38.2, 354095.6 6690017.9 38.2, 354095.2 6690017.3 38.2, 354094.8 6690017.7 38.2, 354094.6 6690018.1 38.2, 354094.3 6690018.5 38.2, 354094.1 6690018.9 38.2, 354093.9 6690019.3 38.2, 354093.7 6690019.8 38.2, 354093.5 6690020.2 38.2, 354093.4 6690020.7 38.2, 354093.2 6690021.2 38.2, 354093.1 6690021.6 38.2, 354093 6690022.1 38.2, 354093 6690022.6 38.2, 354092.9 6690023.5 38.2, 354092.9 6690024 38.2, 354093 6690024.5 38.2, 354093 6690025 38.2, 354093.1 6690025.4 38.2, 354093.1 6690025.7 38.2, 354094 6690025.6 38.2, 354097.3 6690031.4 38.2, 354096.9 6690031.7 38.2, 354097.7 6690032.3 38.2, 354100.2 6690033.4 38.2, 354100.7 6690033.6 38.2))
BATIMENT0000000302934095;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;13;3.8;26.8;30.6;34.8;28.0;Cadastre;A 1.0;POLYGON Z ((354171.1 6690018.7 30.6, 354164.9 6690018.9 30.6, 354164.9 6690022.7 30.6, 354169.1 6690022.6 30.6, 354168.7 6690027.2 30.6, 354164.9 6690027.3 30.6, 354164.9 6690031 30.6, 354171.1 6690030.8 30.6, 354178.3 6690030.8 30.6, 354178.1 6690018.6 30.6, 354175.2 6690018.6 30.6, 354174.3 6690018.6 30.6, 354171.1 6690018.7 30.6))
BATIMENT0000000302935321;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.9;26.3;30.2;34.7;27.1;Cadastre;;POLYGON Z ((354135.5 6690025.9 30.2, 354136.6 6690033.6 30.2, 354139.4 6690033.6 30.2, 354138.3 6690024.8 30.2, 354135.5 6690025.9 30.2))
BATIMENT0000000302934941;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.0;26.5;36.5;39.2;27.6;Cadastre;A 1.0;POLYGON Z ((354159.1 6690024.6 36.5, 354148.9 6690024.6 36.5, 354149.1 6690033.8 36.5, 354159.2 6690034.1 36.5, 354159.1 6690024.6 36.5))
BATIMENT0000000302934940;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;26.8;36.7;39.2;27.7;Cadastre;A 1.0;POLYGON Z ((354149 6690042.6 36.7, 354149.6 6690042.5 36.7, 354159.4 6690042.6 36.7, 354159.2 6690034.1 36.7, 354149.1 6690033.8 36.7, 354149 6690042.6 36.7))
BATIMENT0000000302934938;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.9;26.5;35.4;38.5;26.8;Cadastre;A 1.0;POLYGON Z ((354118.1 6690036.3 35.4, 354112.5 6690043.6 35.4, 354119.7 6690049.6 35.4, 354125.5 6690042.6 35.4, 354118.1 6690036.3 35.4))
BATIMENT0000000302934939;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;60;20;8.6;26.9;35.5;39.0;27.7;Cadastre;A 1.0;POLYGON Z ((354149.2 6690047.3 35.5, 354149.9 6690047.4 35.5, 354159.5 6690047.3 35.5, 354159.4 6690042.6 35.5, 354149.6 6690042.5 35.5, 354149.2 6690047.3 35.5))
BATIMENT0000000302934079;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.2;28.9;37.1;38.0;29.3;Cadastre;;POLYGON Z ((354281.4 6690005.7 37.1, 354281.6 6690006.4 37.1, 354281.6 6690006.8 37.1, 354283.3 6690006.3 37.1, 354283.2 6690005.7 37.1, 354283 6690005.2 37.1, 354281.4 6690005.7 37.1))
BATIMENT0000000302928417;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;45;20;6.7;29.0;35.7;41.3;29.5;Cadastre;B 0.9;POLYGON Z ((354283 6690005.2 35.7, 354283.2 6690005.7 35.7, 354283.3 6690006.3 35.7, 354283.5 6690006.8 35.7, 354287.7 6690005.6 35.7, 354291.2 6690018.2 35.7, 354297.2 6690016.7 35.7, 354291.8 6689997.2 35.7, 354281.4 6689999.9 35.7, 354283 6690005.2 35.7))
BATIMENT0000000302934074;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.4;29.6;38.0;39.9;30.3;Cadastre;A 1.0;POLYGON Z ((354326.6 6690000.9 38, 354324.9 6690001 38, 354325.3 6690005.2 38, 354326.8 6690005.6 38, 354325.6 6690011.6 38, 354326.6 6690015.4 38, 354331.7 6690016.2 38, 354333.7 6690001.6 38, 354329.1 6690000.7 38, 354326.6 6690000.9 38))
BATIMENT0000000302934076;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;30;40;3.9;29.6;33.5;36.5;30.2;Cadastre;C 0.5;POLYGON Z ((354325.6 6690011.6 33.5, 354323.7 6690005.6 33.5, 354321.8 6690006.4 33.5, 354321.4 6690006.5 33.5, 354320.7 6690006.6 33.5, 354320.5 6690006.6 33.5, 354319.8 6690006.8 33.5, 354319.6 6690006.9 33.5, 354319.4 6690006.9 33.5, 354319.2 6690007 33.5, 354319 6690007 33.5, 354318.8 6690007 33.5, 354318.2 6690006.9 33.5, 354317.5 6690006.9 33.5, 354317.1 6690006.9 33.5, 354316.7 6690006.9 33.5, 354316.5 6690006.9 33.5, 354316.3 6690006.8 33.5, 354316.3 6690006.3 33.5, 354314.8 6690006.5 33.5, 354314.6 6690006.5 33.5, 354314.1 6690006.5 33.5, 354313.9 6690006.5 33.5, 354313.5 6690006.4 33.5, 354313.3 6690006.4 33.5, 354313.1 6690006.4 33.5, 354312.3 6690006.3 33.5, 354311.7 6690006.2 33.5, 354311.1 6690006 33.5, 354310 6690005.6 33.5, 354309.4 6690005.4 33.5, 354309.1 6690005.2 33.5, 354308.9 6690005.1 33.5, 354308.3 6690004.8 33.5, 354308.1 6690004.7 33.5, 354307.8 6690004.5 33.5, 354307.5 6690004.2 33.5, 354304.9 6690007 33.5, 354307.7 6690016.9 33.5, 354313.3 6690015.3 33.5, 354316.8 6690014.2 33.5, 354326.6 6690015.4 33.5, 354325.6 6690011.6 33.5))
BATIMENT0000000302934080;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1908-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;23;5.9;28.7;34.6;37.3;29.9;Cadastre;B 0.7;POLYGON Z ((354281.4 6690005.7 34.6, 354280.8 6690003.9 34.6, 354274.7 6690005.6 34.6, 354275.7 6690009.4 34.6, 354279.1 6690021.5 34.6, 354285.4 6690019.8 34.6, 354281.6 6690006.8 34.6, 354281.6 6690006.4 34.6, 354281.4 6690005.7 34.6))
BATIMENT0000000302934075;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;15;20;11.5;29.7;41.2;43.9;30.3;Cadastre;A 1.0;POLYGON Z ((354322.9 6690027 41.2, 354329.9 6690028 41.2, 354331.7 6690016.2 41.2, 354326.6 6690015.4 41.2, 354316.8 6690014.2 41.2, 354313.3 6690015.3 41.2, 354317.2 6690028.4 41.2, 354322.9 6690027 41.2))
BATIMENT0000000302934077;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.6;30.0;34.6;38.0;30.0;Cadastre;A 1.0;POLYGON Z ((354311.4 6690029.7 34.6, 354317.2 6690028.4 34.6, 354313.3 6690015.3 34.6, 354307.7 6690016.9 34.6, 354311.4 6690029.7 34.6))
BATIMENT0000000302934078;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;11.9;29.9;41.8;45.7;30.7;Cadastre;A 1.0;POLYGON Z ((354322.5 6690030.3 41.8, 354321.2 6690030.1 41.8, 354314 6690032.2 41.8, 354315.6 6690038.9 41.8, 354314.1 6690039.2 41.8, 354315.4 6690044.5 41.8, 354319 6690045.1 41.8, 354328.4 6690036.1 41.8, 354329.9 6690028 41.8, 354322.9 6690027 41.8, 354322.5 6690030.3 41.8))
BATIMENT0000000302935237;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;19;20;12.4;29.8;42.2;48.0;30.4;Cadastre;A 1.0;POLYGON Z ((354288.9 6690055.6 42.2, 354293.1 6690054.6 42.2, 354293.4 6690054.9 42.2, 354305.8 6690051.2 42.2, 354302.1 6690038.3 42.2, 354289 6690042 42.2, 354289.5 6690043.5 42.2, 354289.4 6690043.8 42.2, 354288.9 6690044.2 42.2, 354288.7 6690044.5 42.2, 354288.5 6690044.7 42.2, 354288.5 6690045 42.2, 354288.4 6690045.2 42.2, 354288.5 6690045.5 42.2, 354288.6 6690045.7 42.2, 354288.7 6690045.9 42.2, 354288.8 6690046.1 42.2, 354289 6690046.2 42.2, 354289.1 6690046.3 42.2, 354286.5 6690047.2 42.2, 354288.9 6690055.6 42.2))
BATIMENT0000000302935236;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;40;8.7;28.8;37.5;41.0;30.0;Cadastre;A 1.0;POLYGON Z ((354269.4 6690048.9 37.5, 354269.7 6690049.5 37.5, 354264.2 6690049.9 37.5, 354266.5 6690059.1 37.5, 354289.1 6690056.8 37.5, 354288.9 6690055.6 37.5, 354286.5 6690047.2 37.5, 354269.4 6690048.9 37.5))
BATIMENT0000000302934093;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;6.0;26.8;32.8;38.2;27.4;Cadastre;C 0.2;POLYGON Z ((354197.1 6690016.8 32.8, 354196.2 6690002.3 32.8, 354179.6 6690003 32.8, 354179.6 6690008.2 32.8, 354179.7 6690017.4 32.8, 354197.1 6690016.8 32.8))
BATIMENT0000000302934091;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.7;27.8;36.5;39.4;28.3;Cadastre;A 1.0;POLYGON Z ((354235.6 6690009.4 36.5, 354235 6690009.6 36.5, 354237.9 6690020.8 36.5, 354238.4 6690020.9 36.5, 354239.3 6690024.8 36.5, 354247.3 6690022.8 36.5, 354242.4 6690003.4 36.5, 354234.4 6690005.4 36.5, 354235.6 6690009.4 36.5))
BATIMENT0000000302934097;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1876-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;5.1;27.8;33.0;39.7;28.5;Cadastre;A 1.0;POLYGON Z ((354257.4 6690027.2 33, 354265.4 6690025 33, 354263.2 6690016 33, 354271.5 6690013.9 33, 354270.4 6690010.5 33, 354262.3 6690012.5 33, 354254.3 6690014.6 33, 354257.4 6690027.2 33))
BATIMENT0000000302934089;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.6;27.8;36.4;39.2;28.5;Cadastre;A 1.0;POLYGON Z ((354241.1 6690031.4 36.4, 354238.3 6690032.1 36.4, 354239.8 6690037.8 36.4, 354245.9 6690036.4 36.4, 354246.7 6690039.5 36.4, 354240.5 6690041.1 36.4, 354241.4 6690044.8 36.4, 354242.8 6690044.5 36.4, 354252.3 6690042.1 36.4, 354247.3 6690022.8 36.4, 354239.3 6690024.8 36.4, 354241.1 6690031.4 36.4))
BATIMENT0000000302934088;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;17.7;28.3;46.0;48.6;29.2;Cadastre;A 1.0;POLYGON Z ((354240.5 6690048.5 46, 354241.7 6690061.4 46, 354253.8 6690060.3 46, 354256.1 6690057.2 46, 354252.3 6690042.1 46, 354242.8 6690044.5 46, 354243.8 6690047.9 46, 354240.5 6690048.5 46))
BATIMENT0000000302934090;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;11.3;28.0;39.3;46.2;28.7;Cadastre;C 0.6;POLYGON Z ((354240.1 6690045.2 39.3, 354235.5 6690046.2 39.3, 354236.1 6690048.6 39.3, 354234.4 6690048.8 39.3, 354235.8 6690062 39.3, 354241.7 6690061.4 39.3, 354240.5 6690048.5 39.3, 354240.1 6690045.2 39.3))
BATIMENT0000000302935190;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;9.6;28.0;37.6;40.8;28.5;Cadastre;A 1.0;POLYGON Z ((354225.5 6690062.9 37.6, 354224.9 6690056.5 37.6, 354224.5 6690052.7 37.6, 354213.5 6690053.7 37.6, 354214.1 6690063.9 37.6, 354225.5 6690062.9 37.6))
BATIMENT0000000302935189;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.5;28.0;37.5;40.8;28.4;Cadastre;A 1.0;POLYGON Z ((354213.4 6690052.5 37.5, 354203.2 6690053.3 37.5, 354203.9 6690064.9 37.5, 354214.1 6690063.9 37.5, 354213.5 6690053.7 37.5, 354213.4 6690052.5 37.5))
BATIMENT0000000302935191;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;10.5;28.1;38.6;40.0;28.5;Cadastre;C 0.4;POLYGON Z ((354228.8 6690062.6 38.6, 354228.2 6690056.2 38.6, 354224.9 6690056.5 38.6, 354225.5 6690062.9 38.6, 354228.8 6690062.6 38.6))
BATIMENT0000000302934942;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;03;7.8;28.4;36.2;42.4;29.0;Cadastre;C 0.4;POLYGON Z ((354241.9 6690080.2 36.2, 354241.9 6690078.9 36.2, 354242.4 6690078.8 36.2, 354242 6690073.3 36.2, 354237.9 6690073.6 36.2, 354238.4 6690080.4 36.2, 354241.9 6690080.2 36.2))
BATIMENT0000000302934937;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;8.7;26.7;35.4;39.0;26.9;Cadastre;A 1.0;POLYGON Z ((354130.4 6690058.3 35.4, 354135.7 6690051.9 35.4, 354133.4 6690049.7 35.4, 354135 6690047.8 35.4, 354131.9 6690045.2 35.4, 354131.4 6690045.6 35.4, 354126.3 6690041.4 35.4, 354125.5 6690042.6 35.4, 354119.7 6690049.6 35.4, 354130.4 6690058.3 35.4))
BATIMENT0000000302934935;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;26.7;29.0;30.2;27.0;Cadastre;;POLYGON Z ((354143.3 6690053.7 29, 354142.2 6690055 29, 354141.2 6690056.2 29, 354143.8 6690058.5 29, 354143.3 6690053.7 29))
BATIMENT0000000302934933;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.7;26.7;35.4;38.1;27.0;Cadastre;A 1.0;POLYGON Z ((354136 6690062.7 35.4, 354141.2 6690056.2 35.4, 354142.2 6690055 35.4, 354136.9 6690050.5 35.4, 354135.7 6690051.9 35.4, 354130.4 6690058.3 35.4, 354136 6690062.7 35.4))
BATIMENT0000000302934936;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;5.2;26.7;32.0;41.7;27.5;Cadastre;A 1.0;POLYGON Z ((354159.5 6690069.1 32, 354159.3 6690058.3 32, 354154.4 6690058.8 32, 354153.7 6690050.7 32, 354159.5 6690050.3 32, 354159.5 6690047.3 32, 354149.9 6690047.4 32, 354150.3 6690050.9 32, 354150.9 6690059.1 32, 354151 6690059.8 32, 354152 6690069.9 32, 354159.5 6690069.1 32))
BATIMENT0000000302935276;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;23;6.9;26.8;33.7;35.0;27.8;Cadastre;C 0.7;POLYGON Z ((354186.2 6690066.5 33.7, 354185.9 6690059.4 33.7, 354187.7 6690059.3 33.7, 354187.2 6690049.9 33.7, 354177.5 6690050.1 33.7, 354177.5 6690060.3 33.7, 354177.7 6690067.4 33.7, 354186.2 6690066.5 33.7))
BATIMENT0000000302935275;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;6.3;26.8;33.1;39.1;27.7;Cadastre;C 0.4;POLYGON Z ((354177.5 6690060.3 33.1, 354177.5 6690050.1 33.1, 354167.6 6690050.4 33.1, 354168.3 6690059.8 33.1, 354167.2 6690059.9 33.1, 354167.3 6690063.1 33.1, 354164.2 6690063.3 33.1, 354164.1 6690068.6 33.1, 354177.7 6690067.4 33.1, 354177.5 6690060.3 33.1))
BATIMENT0000000302934932;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.7;26.7;35.4;36.5;27.0;Cadastre;A 1.0;POLYGON Z ((354144.7 6690070 35.4, 354144.1 6690060.3 35.4, 354143.8 6690058.5 35.4, 354141.2 6690056.2 35.4, 354136 6690062.7 35.4, 354144.7 6690070 35.4))
BATIMENT0000000302934934;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;9.2;26.6;35.8;40.2;27.0;Cadastre;A 1.0;POLYGON Z ((354145.3 6690070.7 35.8, 354152 6690069.9 35.8, 354151 6690059.8 35.8, 354144.1 6690060.3 35.8, 354144.7 6690070 35.8, 354145.3 6690070.7 35.8))
BATIMENT0000000302935222;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.2;26.7;34.9;39.0;27.4;Cadastre;A 1.0;POLYGON Z ((354166.4 6690081.4 34.9, 354167.3 6690090 34.9, 354172 6690089.5 34.9, 354172.2 6690090.4 34.9, 354175.9 6690089.9 34.9, 354175 6690080.5 34.9, 354166.4 6690081.4 34.9))
BATIMENT0000000302935221;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1909-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.8;26.1;36.9;39.8;27.4;Cadastre;C 0.9;POLYGON Z ((354176.2 6690092.3 36.9, 354188 6690090.9 36.9, 354186.8 6690081.5 36.9, 354180.2 6690082.3 36.9, 354179.8 6690080.2 36.9, 354175 6690080.5 36.9, 354175.9 6690089.9 36.9, 354176.2 6690092.3 36.9))
BATIMENT0000000302935218;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;29.6;36.7;41.7;30.5;Cadastre;;POLYGON Z ((354291.6 6690077.2 36.7, 354295.1 6690076.9 36.7, 354294.3 6690067.9 36.7, 354290.8 6690068.2 36.7, 354291.4 6690074.9 36.7, 354291.6 6690077.2 36.7))
BATIMENT0000000302935217;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.5;29.4;39.0;42.0;30.0;Cadastre;A 1.0;POLYGON Z ((354277.6 6690069.6 39, 354279.2 6690077.8 39, 354280 6690077.7 39, 354280.6 6690076 39, 354291.4 6690074.9 39, 354290.8 6690068.2 39, 354277.6 6690069.6 39))
BATIMENT0000000302934996;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.9;30.0;38.9;41.1;30.6;Cadastre;A 1.0;POLYGON Z ((354310.2 6690066.7 38.9, 354301.8 6690067.6 38.9, 354302.8 6690075.3 38.9, 354300.9 6690077.3 38.9, 354303.6 6690080 38.9, 354307.1 6690076.7 38.9, 354313.6 6690070.3 38.9, 354310.2 6690066.7 38.9))
BATIMENT0000000302935215;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.9;29.4;38.3;39.4;29.7;Cadastre;;POLYGON Z ((354274.7 6690069.9 38.3, 354276.5 6690079 38.3, 354279.2 6690078.2 38.3, 354279.2 6690077.8 38.3, 354277.6 6690069.6 38.3, 354274.7 6690069.9 38.3))
BATIMENT0000000302935216;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;24;8.9;29.1;38.0;40.2;29.7;Cadastre;A 1.0;POLYGON Z ((354266.8 6690071.9 38, 354269.2 6690080.8 38, 354276.5 6690079 38, 354274.7 6690069.9 38, 354266.8 6690071.9 38))
BATIMENT0000000302934995;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.5;30.0;38.5;42.0;30.6;Cadastre;A 1.0;POLYGON Z ((354312.4 6690082.1 38.5, 354311.6 6690087.1 38.5, 354320.9 6690088.8 38.5, 354322.3 6690079.1 38.5, 354313.6 6690070.3 38.5, 354307.1 6690076.7 38.5, 354312.4 6690082.1 38.5))
BATIMENT0000000302934997;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.4;29.6;38.0;40.7;30.5;Cadastre;A 1.0;POLYGON Z ((354310.4 6690086.8 38, 354308.7 6690097.3 38, 354319.3 6690098.9 38, 354320.9 6690088.8 38, 354311.6 6690087.1 38, 354310.4 6690086.8 38))
BATIMENT0000000302934981;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.8;29.4;37.2;40.0;29.9;Cadastre;A 1.0;POLYGON Z ((354285 6690099.1 37.2, 354282.7 6690089.2 37.2, 354274.9 6690091.2 37.2, 354277.2 6690100.9 37.2, 354284.3 6690099.3 37.2, 354285 6690099.1 37.2))
BATIMENT0000000302935038;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;50;20;15.1;30.1;45.2;46.4;31.4;Cadastre;A 0.3;POLYGON Z ((354330.1 6690101.8 45.2, 354341.6 6690103.6 45.2, 354342.4 6690099.4 45.2, 354343.5 6690099.6 45.2, 354343.9 6690096.5 45.2, 354342.2 6690095.9 45.2, 354342.5 6690093.2 45.2, 354331.5 6690091.5 45.2, 354330.1 6690101.8 45.2))
BATIMENT0000000302934980;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;29.5;37.5;40.0;29.9;Cadastre;A 1.0;POLYGON Z ((354278.5 6690105.6 37.5, 354285.2 6690104.1 37.5, 354284.3 6690099.3 37.5, 354277.2 6690100.9 37.5, 354278.5 6690105.6 37.5))
BATIMENT0000000302928158;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;32.0;36.7;38.1;32.4;Cadastre;;POLYGON Z ((354487.7 6689990.5 36.7, 354486.9 6689993.6 36.7, 354493.7 6689994.1 36.7, 354497.8 6689993.3 36.7, 354497.3 6689990.1 36.7, 354492.4 6689991.2 36.7, 354492.2 6689989.7 36.7, 354487.7 6689990.5 36.7))
BATIMENT0000000302928164;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:37;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.0;32.0;40.0;42.0;33.0;Cadastre;;POLYGON Z ((354518.1 6689996.9 40, 354518.3 6689994.9 40, 354517 6689994.4 40, 354517 6689994 40, 354515.7 6689993.9 40, 354515.5 6689996.6 40, 354518.1 6689996.9 40))
BATIMENT0000000302928162;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;23;8.3;32.0;40.3;43.2;33.1;Cadastre;A 1.0;POLYGON Z ((354527.9 6689993 40.3, 354518.7 6689991.4 40.3, 354517.3 6689992.2 40.3, 354517 6689994 40.3, 354517 6689994.4 40.3, 354518.3 6689994.9 40.3, 354518.1 6689996.9 40.3, 354517.5 6690002.2 40.3, 354526.9 6690001.5 40.3, 354527.9 6689993 40.3))
BATIMENT0000000302928157;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;50;20;6.4;32.0;38.4;40.2;32.5;Cadastre;A 1.0;POLYGON Z ((354484.7 6690002.3 38.4, 354493.6 6690004.5 38.4, 354494.5 6690000.3 38.4, 354492.5 6689999.4 38.4, 354493.7 6689994.1 38.4, 354486.9 6689993.6 38.4, 354484.7 6690002.3 38.4))
BATIMENT0000000302928139;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;40;20;9.6;32.0;41.7;44.5;32.7;Cadastre;A 1.0;POLYGON Z ((354532.9 6690002.9 41.7, 354543 6690004.1 41.7, 354543.2 6690000.7 41.7, 354546.2 6690001 41.7, 354546.8 6689997.3 41.7, 354545.3 6689997.2 41.7, 354533.6 6689996.7 41.7, 354532.9 6690002.9 41.7))
BATIMENT0000000302934062;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1897-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.5;32.0;40.5;44.0;33.2;Cadastre;A 1.0;POLYGON Z ((354515.3 6690002.6 40.5, 354515.3 6690006.5 40.5, 354514.6 6690006.6 40.5, 354514.7 6690011.2 40.5, 354515.4 6690011.1 40.5, 354525.6 6690012.1 40.5, 354526.9 6690001.5 40.5, 354517.5 6690002.2 40.5, 354515.3 6690002.6 40.5))
BATIMENT0000000302934059;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.5;32.0;39.5;42.2;32.6;Cadastre;A 1.0;POLYGON Z ((354482.7 6690009.9 39.5, 354491.6 6690012.1 39.5, 354493.6 6690004.5 39.5, 354484.7 6690002.3 39.5, 354482.7 6690009.9 39.5))
BATIMENT0000000302934058;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;15;20;11.3;31.9;43.2;46.2;32.6;Cadastre;A 1.0;POLYGON Z ((354531.6 6690014 43.2, 354539.9 6690015.1 43.2, 354542.6 6690015.5 43.2, 354544.1 6690004.3 43.2, 354543 6690004.1 43.2, 354532.9 6690002.9 43.2, 354531.6 6690014 43.2))
BATIMENT0000000302934063;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;32.0;40.3;43.7;33.2;Cadastre;A 1.0;POLYGON Z ((354515.4 6690011.1 40.3, 354514.7 6690011.2 40.3, 354511.7 6690011.4 40.3, 354511.9 6690014.1 40.3, 354515.7 6690014.2 40.3, 354515.4 6690017.2 40.3, 354524.9 6690018.2 40.3, 354525.6 6690012.1 40.3, 354515.4 6690011.1 40.3))
BATIMENT0000000302934060;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.7;31.9;36.6;41.9;32.6;Cadastre;A 1.0;POLYGON Z ((354480.5 6690019.2 36.6, 354489.1 6690021.3 36.6, 354490.5 6690015.8 36.6, 354497.2 6690015.7 36.6, 354497 6690014.6 36.6, 354498.3 6690014.7 36.6, 354498.2 6690012.3 36.6, 354491.6 6690012.1 36.6, 354482.7 6690009.9 36.6, 354480.5 6690019.2 36.6))
BATIMENT0000000302927831;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.9;30.7;34.6;37.2;31.4;Cadastre;A 1.0;POLYGON Z ((354393 6689996.9 34.6, 354398.7 6689996.7 34.6, 354398.3 6689990.5 34.6, 354392.7 6689990.5 34.6, 354392.4 6689990.7 34.6, 354392.6 6689992.4 34.6, 354393 6689996.9 34.6))
BATIMENT0000000302929004;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;8.0;30.1;38.1;40.5;30.7;Cadastre;C 0.8;POLYGON Z ((354344.9 6690001.7 38.1, 354354.2 6690003.1 38.1, 354355.5 6690003.3 38.1, 354357.2 6689993.1 38.1, 354346.4 6689991.6 38.1, 354344.9 6690001.7 38.1))
BATIMENT0000000302928456;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.0;30.9;34.9;39.2;31.5;Cadastre;C 0.4;POLYGON Z ((354368.7 6689993.8 34.9, 354366.8 6690004.1 34.9, 354370.9 6690004.8 34.9, 354372.5 6689994.4 34.9, 354368.7 6689993.8 34.9))
BATIMENT0000000302927833;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.6;30.7;34.3;34.7;31.4;Cadastre;A 1.0;POLYGON Z ((354393.1 6689998.3 34.3, 354393.6 6690003 34.3, 354399.6 6690002.5 34.3, 354399.2 6689996.6 34.3, 354398.7 6689996.7 34.3, 354393 6689996.9 34.3, 354393.1 6689998.3 34.3))
BATIMENT0000000302928455;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.3;30.8;40.2;43.9;31.6;Cadastre;A 1.0;POLYGON Z ((354377 6690007 40.2, 354381.4 6690007.8 40.2, 354383.1 6689995.9 40.2, 354372.5 6689994.4 40.2, 354370.9 6690004.8 40.2, 354370.7 6690006.2 40.2, 354377 6690007 40.2))
BATIMENT0000000302928434;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;30.9;37.2;39.1;31.5;Cadastre;;POLYGON Z ((354403.7 6690003.6 37.2, 354406.1 6690003.4 37.2, 354405.7 6689999.9 37.2, 354403 6690000.1 37.2, 354403.7 6690003.6 37.2))
BATIMENT0000000302927832;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1897-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;4.0;30.7;34.7;35.7;31.4;Cadastre;C 0.4;POLYGON Z ((354388.7 6689997.8 34.7, 354389.2 6690005.8 34.7, 354388.5 6690005.8 34.7, 354388.7 6690009.1 34.7, 354394 6690008.8 34.7, 354393.6 6690003 34.7, 354393.1 6689998.3 34.7, 354388.7 6689997.8 34.7))
BATIMENT0000000302934087;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;51;02;3.4;30.9;34.3;39.3;31.6;Cadastre;C 0.4;POLYGON Z ((354365.6 6690003.9 34.3, 354364.9 6690008 34.3, 354370.4 6690008.8 34.3, 354370.7 6690006.2 34.3, 354370.9 6690004.8 34.3, 354366.8 6690004.1 34.3, 354365.6 6690003.9 34.3))
BATIMENT0000000302934086;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;31.2;37.5;39.8;31.5;Cadastre;;POLYGON Z ((354376.7 6690008.8 37.5, 354381.1 6690009.5 37.5, 354381.4 6690007.8 37.5, 354377 6690007 37.5, 354376.7 6690008.8 37.5))
BATIMENT0000000302935028;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.6;30.2;36.8;40.5;31.3;Cadastre;C 0.9;POLYGON Z ((354359.4 6690007 36.8, 354345.4 6690004.7 36.8, 354343.3 6690018.2 36.8, 354354.6 6690023.2 36.8, 354361.3 6690026 36.8, 354367.8 6690027 36.8, 354368 6690025.5 36.8, 354370 6690012.9 36.8, 354370 6690012.8 36.8, 354365.6 6690012.3 36.8, 354364.8 6690018 36.8, 354363.9 6690017.9 36.8, 354362.9 6690024.8 36.8, 354357.2 6690022.4 36.8, 354359.4 6690007 36.8))
BATIMENT0000000302928429;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:00:51;2018-09-18 13:36:35;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;31.8;36.0;39.5;32.4;Cadastre;;POLYGON Z ((354432.8 6689997.8 36, 354433.2 6690000.3 36, 354435.4 6690001.7 36, 354437.4 6690001.3 36, 354437.8 6689997.5 36, 354437.8 6689997.1 36, 354432.8 6689997.8 36))
BATIMENT0000000302928421;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:00:51;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.6;32.0;38.6;43.2;32.8;Cadastre;A 1.0;POLYGON Z ((354465.7 6690003.8 38.6, 354461.7 6690002.8 38.6, 354460.6 6690006.7 38.6, 354472 6690009.3 38.6, 354474.1 6690000.3 38.6, 354466.9 6689998.7 38.6, 354465.7 6690003.8 38.6))
BATIMENT0000000302934085;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;5.2;31.1;36.3;37.2;32.7;Cadastre;B 0.5;POLYGON Z ((354436.1 6690014.7 36.3, 354436 6690016.4 36.3, 354440 6690016.3 36.3, 354440.1 6690014.1 36.3, 354440.8 6690014.2 36.3, 354441.2 6690010.2 36.3, 354440.5 6690010.1 36.3, 354440.9 6690007.2 36.3, 354442.1 6690007.5 36.3, 354442.2 6690008.2 36.3, 354446.3 6690008.9 36.3, 354447.3 6690004 36.3, 354444.6 6690003.6 36.3, 354437.3 6690002.5 36.3, 354436.1 6690014.7 36.3))
BATIMENT0000000302934081;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;59;20;6.7;32.0;38.7;43.6;33.4;Cadastre;B 0.8;POLYGON Z ((354454.8 6690005.6 38.7, 354453.1 6690013.3 38.7, 354457 6690014.5 38.7, 354457.3 6690014.6 38.7, 354463.8 6690016.3 38.7, 354469.7 6690017.9 38.7, 354472 6690009.3 38.7, 354460.6 6690006.7 38.7, 354454.8 6690005.6 38.7))
BATIMENT0000000302935323;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.2;31.0;34.2;35.4;31.6;Cadastre;;POLYGON Z ((354410 6690016.6 34.2, 354410.2 6690020 34.2, 354415.7 6690019.8 34.2, 354415.4 6690016.1 34.2, 354410 6690016.6 34.2))
BATIMENT0000000302934082;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;23;20;6.5;32.0;38.5;42.3;33.4;Cadastre;A 1.0;POLYGON Z ((354463.8 6690016.3 38.5, 354457.3 6690014.6 38.5, 354457 6690014.5 38.5, 354455.4 6690020.3 38.5, 354456.9 6690020.6 38.5, 354456.2 6690023.3 38.5, 354459.4 6690024.1 38.5, 354461.7 6690024.7 38.5, 354467.7 6690026.3 38.5, 354469.7 6690017.9 38.5, 354463.8 6690016.3 38.5))
BATIMENT0000000302934083;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.8;31.7;38.5;40.9;31.9;Cadastre;A 1.0;POLYGON Z ((354461.7 6690024.7 38.5, 354459.4 6690024.1 38.5, 354457.9 6690029.8 38.5, 354466.4 6690031.8 38.5, 354467.7 6690026.3 38.5, 354461.7 6690024.7 38.5))
BATIMENT0000000302935015;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;31.3;34.9;36.2;32.2;Cadastre;;POLYGON Z ((354442.3 6690032.7 34.9, 354446.7 6690032.6 34.9, 354447.6 6690027.3 34.9, 354443 6690026.2 34.9, 354442.3 6690032.7 34.9))
BATIMENT0000000302934084;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.5;32.0;38.5;41.8;32.1;Cadastre;A 1.0;POLYGON Z ((354455.6 6690029.3 38.5, 354455 6690032.1 38.5, 354456.2 6690032.4 38.5, 354454.5 6690038.8 38.5, 354448.4 6690038.9 38.5, 354448.5 6690040.2 38.5, 354447.6 6690040.2 38.5, 354446.8 6690040.8 38.5, 354446.9 6690043.6 38.5, 354448.4 6690043.7 38.5, 354448.3 6690045.2 38.5, 354460 6690044.8 38.5, 354463.7 6690041.6 38.5, 354466.4 6690031.8 38.5, 354457.9 6690029.8 38.5, 354455.6 6690029.3 38.5))
BATIMENT0000000302935017;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;23;6.9;31.3;38.2;43.6;32.2;Cadastre;A 1.0;POLYGON Z ((354433.9 6690036.3 38.2, 354434.3 6690033.5 38.2, 354434.3 6690032.9 38.2, 354434.7 6690029.6 38.2, 354430.3 6690029.7 38.2, 354430.3 6690030.5 38.2, 354423.6 6690030.7 38.2, 354423.9 6690033.3 38.2, 354424.1 6690037.8 38.2, 354424.4 6690046.1 38.2, 354432.8 6690045.7 38.2, 354433.9 6690036.3 38.2))
BATIMENT0000000302934055;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;3.8;32.0;35.8;42.6;32.5;Cadastre;A 1.0;POLYGON Z ((354545.2 6690022.9 35.8, 354545.6 6690019.3 35.8, 354539.5 6690018.6 35.8, 354539.9 6690015.1 35.8, 354531.6 6690014 35.8, 354530.8 6690020.9 35.8, 354530.6 6690021.9 35.8, 354530.5 6690022.7 35.8, 354539.6 6690023.9 35.8, 354539.7 6690023.1 35.8, 354539.9 6690022.1 35.8, 354545.2 6690022.9 35.8))
BATIMENT0000000302934064;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1917-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.3;32.0;40.3;43.5;33.0;Cadastre;A 1.0;POLYGON Z ((354515 6690020.1 40.3, 354511.8 6690019.9 40.3, 354511.5 6690022.5 40.3, 354512.5 6690022.7 40.3, 354524.3 6690023.3 40.3, 354524.9 6690018.2 40.3, 354515.4 6690017.2 40.3, 354515 6690020.1 40.3))
BATIMENT0000000302934061;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;19;29;4.2;31.7;35.9;43.1;32.6;Cadastre;A 1.0;POLYGON Z ((354478.8 6690025.9 35.9, 354489.5 6690028.6 35.9, 354491.3 6690028.8 35.9, 354492.7 6690022.4 35.9, 354489.1 6690021.3 35.9, 354480.5 6690019.2 35.9, 354478.8 6690025.9 35.9))
BATIMENT0000000302934065;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;7.0;32.0;39.0;42.4;33.1;Cadastre;A 1.0;POLYGON Z ((354512 6690028.7 39, 354517 6690029.3 39, 354523.6 6690029.4 39, 354524.3 6690023.3 39, 354512.5 6690022.7 39, 354512 6690028.7 39))
BATIMENT0000000302934067;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;5.4;31.6;37.0;41.1;32.6;Cadastre;C 0.1;POLYGON Z ((354477.9 6690029.7 37, 354488.5 6690032.5 37, 354489.5 6690028.6 37, 354478.8 6690025.9 37, 354477.9 6690029.7 37))
BATIMENT0000000302935327;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;32.0;34.6;35.1;32.7;Cadastre;;POLYGON Z ((354492 6690031.6 34.6, 354502.1 6690031.9 34.6, 354502.2 6690028.9 34.6, 354491.9 6690028.8 34.6, 354492 6690031.6 34.6))
BATIMENT0000000302934066;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;32.5;35.8;38.7;33.1;Cadastre;;POLYGON Z ((354511.1 6690028.8 35.8, 354511.2 6690031.8 35.8, 354516.8 6690032.2 35.8, 354517 6690029.3 35.8, 354512 6690028.7 35.8, 354511.1 6690028.8 35.8))
BATIMENT0000000302935240;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;30;20;6.9;32.3;39.2;41.4;32.6;Cadastre;A 1.0;POLYGON Z ((354530.7 6690029.6 39.2, 354529.1 6690042.9 39.2, 354539.2 6690042.5 39.2, 354539.1 6690034.8 39.2, 354539.7 6690030.7 39.2, 354530.7 6690029.6 39.2))
BATIMENT0000000302935241;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1893-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;7.7;32.2;39.9;45.5;32.6;Cadastre;A 1.0;POLYGON Z ((354551.2 6690042.3 39.9, 354552 6690035.9 39.9, 354543 6690036.5 39.9, 354542.8 6690034.9 39.9, 354539.1 6690034.8 39.9, 354539.2 6690042.5 39.9, 354551.2 6690042.3 39.9))
BATIMENT0000000302935202;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;00;00;15.2;31.6;46.8;49.3;32.2;Cadastre;C 0.9;POLYGON Z ((354479.3 6690035.6 46.8, 354479.1 6690034.5 46.8, 354475.9 6690033.6 46.8, 354474 6690040.6 46.8, 354477.7 6690044.6 46.8, 354493.2 6690043.9 46.8, 354493 6690035 46.8, 354479.3 6690035.6 46.8))
BATIMENT0000000302935137;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.2;31.0;34.2;34.6;31.5;Cadastre;A 1.0;POLYGON Z ((354403.2 6690020.6 34.2, 354405.1 6690020.5 34.2, 354404.5 6690014.6 34.2, 354401.2 6690014.7 34.2, 354401.6 6690020.6 34.2, 354403.2 6690020.6 34.2))
BATIMENT0000000302935135;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.9;31.0;34.9;;;Cadastre;A 1.0;POLYGON Z ((354397.7 6690015 34.9, 354398.2 6690020.8 34.9, 354401.6 6690020.6 34.9, 354401.2 6690014.7 34.9, 354397.7 6690015 34.9))
BATIMENT0000000302935134;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;3.0;30.9;34.0;34.7;31.3;Cadastre;A 1.0;POLYGON Z ((354394.6 6690015.1 34, 354394.6 6690016 34, 354395.2 6690021 34, 354398.2 6690020.8 34, 354397.7 6690015 34, 354394.6 6690015.1 34))
BATIMENT0000000302935136;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1897-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.4;31.0;36.4;40.1;31.5;Cadastre;C 0.3;POLYGON Z ((354390 6690016.2 36.4, 354389.8 6690015.9 36.4, 354380.3 6690016.3 36.4, 354378.8 6690024.6 36.4, 354379.3 6690024.7 36.4, 354387.1 6690024.2 36.4, 354395.3 6690023.8 36.4, 354395.2 6690021 36.4, 354394.6 6690016 36.4, 354390 6690016.2 36.4))
BATIMENT0000000302935027;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.7;30.1;39.8;46.5;31.1;Cadastre;A 1.0;POLYGON Z ((354342 6690027.7 39.8, 354351.9 6690029.4 39.8, 354353.5 6690029.6 39.8, 354354.6 6690023.2 39.8, 354343.3 6690018.2 39.8, 354342 6690027.7 39.8))
BATIMENT0000000302935026;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;12;20;14.7;30.1;44.8;49.4;31.2;Cadastre;A 1.0;POLYGON Z ((354340.4 6690037.9 44.8, 354351.2 6690050.6 44.8, 354358 6690050 44.8, 354357.9 6690039.6 44.8, 354355.3 6690039.8 44.8, 354350.9 6690034.6 44.8, 354351.9 6690029.4 44.8, 354342 6690027.7 44.8, 354340.4 6690037.9 44.8))
BATIMENT0000000302935020;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;10.4;31.3;41.7;42.7;31.6;Cadastre;A 1.0;POLYGON Z ((354403.7 6690046.7 41.7, 354403.6 6690037.9 41.7, 354403.6 6690037.3 41.7, 354395.8 6690037.5 41.7, 354395.9 6690047 41.7, 354403.7 6690046.7 41.7))
BATIMENT0000000302935021;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;10.2;31.3;41.5;42.7;31.6;Cadastre;A 1.0;POLYGON Z ((354395.9 6690047 41.5, 354395.8 6690037.5 41.5, 354388.1 6690037.8 41.5, 354388.6 6690047.1 41.5, 354395.9 6690047 41.5))
BATIMENT0000000302935022;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;10.1;31.3;41.4;42.9;31.5;Cadastre;A 1.0;POLYGON Z ((354388.6 6690047.1 41.4, 354388.1 6690037.8 41.4, 354380.5 6690038.4 41.4, 354381.1 6690047.8 41.4, 354388.6 6690047.1 41.4))
BATIMENT0000000302935025;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;11.2;30.1;41.3;42.2;31.2;Cadastre;A 1.0;POLYGON Z ((354369.1 6690049 41.3, 354368.4 6690037.9 41.3, 354368.4 6690036.8 41.3, 354365.2 6690037.1 41.3, 354365.4 6690040.1 41.3, 354363.7 6690040.3 41.3, 354361.7 6690040.4 41.3, 354361.3 6690036.5 41.3, 354357.9 6690036.8 41.3, 354357.9 6690039.6 41.3, 354358 6690050 41.3, 354363.6 6690049.5 41.3, 354369.1 6690049 41.3))
BATIMENT0000000302935016;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1919-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;8.7;31.3;40.0;41.6;32.2;Cadastre;A 1.0;POLYGON Z ((354441.8 6690036.8 40, 354442.1 6690034.1 40, 354442.2 6690033.3 40, 354439.2 6690033.1 40, 354438.9 6690032.5 40, 354437.3 6690032.4 40, 354436.6 6690033 40, 354434.3 6690032.9 40, 354434.3 6690033.5 40, 354433.9 6690036.3 40, 354432.8 6690045.7 40, 354440.7 6690045.5 40, 354441.8 6690036.8 40))
BATIMENT0000000302935018;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1884-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;12;20;12.1;31.3;43.4;46.8;32.1;Cadastre;A 1.0;POLYGON Z ((354424.4 6690046.1 43.4, 354424.1 6690037.8 43.4, 354423.9 6690033.3 43.4, 354420.3 6690033.4 43.4, 354420.2 6690032.5 43.4, 354415.1 6690032.6 43.4, 354415.1 6690035 43.4, 354412.3 6690035.1 43.4, 354412.5 6690037.4 43.4, 354412.9 6690046.4 43.4, 354424.4 6690046.1 43.4))
BATIMENT0000000302935019;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.3;31.1;40.5;44.0;31.6;Cadastre;A 1.0;POLYGON Z ((354412.9 6690046.4 40.5, 354412.5 6690037.4 40.5, 354403.6 6690037.9 40.5, 354403.7 6690046.7 40.5, 354412.9 6690046.4 40.5))
BATIMENT0000000302934810;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;10.8;31.1;42.0;46.3;31.7;Cadastre;C 1.0;POLYGON Z ((354415.2 6690059.3 42, 354415.3 6690064.3 42, 354417.5 6690064.1 42, 354417.5 6690059.2 42, 354415.2 6690059.3 42))
BATIMENT0000000302934976;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;12;4.6;31.7;36.3;39.2;32.0;Cadastre;A 1.0;POLYGON Z ((354409.3 6690058.4 36.3, 354404.7 6690058.5 36.3, 354404.6 6690068.4 36.3, 354409.5 6690068.3 36.3, 354409.3 6690058.4 36.3))
BATIMENT0000000302934809;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1894-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;23;8.5;32.0;40.5;43.7;32.8;Cadastre;A 1.0;POLYGON Z ((354431.6 6690058.8 40.5, 354432.2 6690067.6 40.5, 354438.6 6690067.4 40.5, 354438.7 6690068.8 40.5, 354443 6690068.8 40.5, 354442.8 6690058.3 40.5, 354431.6 6690058.8 40.5))
BATIMENT0000000302934815;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;;;8.1;32.7;40.8;;;Cadastre;A 0.6;POLYGON Z ((354480.8 6690059 40.8, 354478.7 6690057.2 40.8, 354462.3 6690057.8 40.8, 354463.2 6690072.4 40.8, 354469.1 6690072 40.8, 354469 6690070 40.8, 354464.9 6690070 40.8, 354464.8 6690067.9 40.8, 354471.3 6690067.7 40.8, 354471.4 6690068.1 40.8, 354474.7 6690068 40.8, 354474.8 6690067.6 40.8, 354475.7 6690067.6 40.8, 354481.2 6690067.4 40.8, 354480.8 6690059 40.8))
BATIMENT0000000302934807;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;20;20;11.9;31.2;43.2;46.4;32.3;Cadastre;A 1.0;POLYGON Z ((354428.4 6690072.2 43.2, 354432.4 6690072.1 43.2, 354432.3 6690069.3 43.2, 354432.2 6690067.6 43.2, 354431.6 6690058.8 43.2, 354421.3 6690059.1 43.2, 354417.5 6690059.2 43.2, 354417.5 6690064.1 43.2, 354417.6 6690072.9 43.2, 354422 6690072.8 43.2, 354422 6690069.7 43.2, 354422.9 6690069.6 43.2, 354426.7 6690069.5 43.2, 354428.3 6690069.4 43.2, 354428.4 6690072.2 43.2))
BATIMENT0000000302934813;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;24;8.7;32.9;41.6;46.2;33.1;Cadastre;A 1.0;POLYGON Z ((354442.8 6690058.3 41.6, 354443 6690068.8 41.6, 354448.6 6690068.6 41.6, 354448.9 6690071.4 41.6, 354448.1 6690071.4 41.6, 354448.2 6690072.6 41.6, 354448.8 6690072.6 41.6, 354449.2 6690077.9 41.6, 354453.2 6690077.8 41.6, 354452.9 6690074.1 41.6, 354452.8 6690070.3 41.6, 354452.1 6690058.1 41.6, 354442.8 6690058.3 41.6))
BATIMENT0000000302934975;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;31.8;36.8;;;Cadastre;;POLYGON Z ((354409.5 6690070.6 36.8, 354409.5 6690068.3 36.8, 354404.6 6690068.4 36.8, 354404.3 6690068.4 36.8, 354404.3 6690070.7 36.8, 354409.5 6690070.6 36.8))
BATIMENT0000000302935201;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;9.9;32.1;42.0;44.3;32.8;Cadastre;A 1.0;POLYGON Z ((354503.4 6690043.7 42, 354503.5 6690036.4 42, 354503.4 6690034.8 42, 354493 6690035 42, 354493.2 6690043.9 42, 354503.4 6690043.7 42))
BATIMENT0000000302935200;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;8.7;32.1;40.8;43.6;32.9;Cadastre;A 1.0;POLYGON Z ((354510.5 6690043.4 40.8, 354510.5 6690038.2 40.8, 354510.3 6690036.4 40.8, 354503.5 6690036.4 40.8, 354503.4 6690043.7 40.8, 354510.5 6690043.4 40.8))
BATIMENT0000000302935199;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.8;32.1;39.9;41.7;32.8;Cadastre;A 1.0;POLYGON Z ((354521 6690043 39.9, 354521.5 6690037.7 39.9, 354510.5 6690038.2 39.9, 354510.5 6690043.4 39.9, 354521 6690043 39.9))
BATIMENT0000000302934962;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.1;32.0;41.1;44.2;32.3;Cadastre;C 0.8;POLYGON Z ((354493.5 6690056.7 41.1, 354491.4 6690058.7 41.1, 354491.8 6690065.9 41.1, 354502.4 6690065.8 41.1, 354502.1 6690056.4 41.1, 354493.5 6690056.7 41.1))
BATIMENT0000000302934963;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.4;31.6;43.0;46.2;32.0;Cadastre;A 1.0;POLYGON Z ((354502.1 6690056.4 43, 354502.4 6690065.8 43, 354502.3 6690067.6 43, 354513.1 6690067.6 43, 354512.5 6690056.1 43, 354502.1 6690056.4 43))
BATIMENT0000000302934964;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;20;20;12.8;32.1;44.9;49.7;33.0;Cadastre;A 1.0;POLYGON Z ((354528 6690055.8 44.9, 354512.5 6690056.1 44.9, 354513.1 6690067.6 44.9, 354520.1 6690067.6 44.9, 354520.4 6690070.5 44.9, 354526.3 6690070.5 44.9, 354526.3 6690071.4 44.9, 354526 6690071.5 44.9, 354525.9 6690077 44.9, 354528.1 6690076.9 44.9, 354528.1 6690075.3 44.9, 354528.1 6690061.7 44.9, 354528 6690055.8 44.9))
BATIMENT0000000302935374;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1970-01-01;;;;BDTopo;2.5;BDTopo;1.5;18.0;7.0;13;20;18.4;32.0;;53.8;33.1;Imagerie aérienne;A 1.0;POLYGON Z ((354528.1 6690075.3 50.4, 354550 6690074.9 50.4, 354550 6690066.3 50.4, 354551.8 6690066.2 50.4, 354551.7 6690061.1 50.4, 354528.1 6690061.7 50.4, 354528.1 6690075.3 50.4))
BATIMENT0000000302934821;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;32.8;38.6;;;Cadastre;;POLYGON Z ((354475.7 6690069.3 38.6, 354473 6690069.4 38.6, 354473 6690071.2 38.6, 354475.8 6690070.7 38.6, 354475.7 6690069.3 38.6))
BATIMENT0000000302934820;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;15;20;6.7;32.8;39.5;;;Cadastre;A 1.0;POLYGON Z ((354481.2 6690067.4 39.5, 354475.7 6690067.6 39.5, 354475.7 6690069.3 39.5, 354475.8 6690070.7 39.5, 354473 6690071.2 39.5, 354472.9 6690071.3 39.5, 354473.1 6690077 39.5, 354481.7 6690077.1 39.5, 354481.2 6690067.4 39.5))
BATIMENT0000000302935220;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;03;2.7;32.4;35.1;;;Cadastre;C 0.3;POLYGON Z ((354501.6 6690071.5 35.1, 354495.6 6690071.8 35.1, 354495.8 6690075.9 35.1, 354496.4 6690075.9 35.1, 354501.9 6690075.7 35.1, 354501.6 6690071.5 35.1))
BATIMENT0000000302935023;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;23;6.6;31.3;37.9;40.4;31.4;Cadastre;A 1.0;POLYGON Z ((354381.1 6690047.8 37.9, 354380.5 6690038.4 37.9, 354371.4 6690039 37.9, 354371.1 6690037.7 37.9, 354368.4 6690037.9 37.9, 354369.1 6690049 37.9, 354381.1 6690047.8 37.9))
BATIMENT0000000302934966;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.3;31.7;39.0;43.5;32.0;Cadastre;A 0.7;POLYGON Z ((354396 6690058.8 39, 354396.7 6690068.6 39, 354401 6690068.5 39, 354404.3 6690068.4 39, 354404.6 6690068.4 39, 354404.7 6690058.5 39, 354396 6690058.8 39))
BATIMENT0000000302934969;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.4;30.2;38.6;43.1;31.8;Cadastre;A 1.0;POLYGON Z ((354369.3 6690060.8 38.6, 354369.7 6690070 38.6, 354369.8 6690070.4 38.6, 354374 6690070.2 38.6, 354374 6690070.7 38.6, 354377.6 6690070.5 38.6, 354377.6 6690069.8 38.6, 354384.8 6690069.2 38.6, 354384.9 6690059.3 38.6, 354369.3 6690060.8 38.6))
BATIMENT0000000302934973;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;7.6;31.7;39.3;43.1;32.0;Cadastre;A 1.0;POLYGON Z ((354390.4 6690058.9 39.3, 354390.8 6690068.8 39.3, 354391 6690073.5 39.3, 354393.2 6690073.5 39.3, 354393.3 6690068.6 39.3, 354396.7 6690068.6 39.3, 354396 6690058.8 39.3, 354390.4 6690058.9 39.3))
BATIMENT0000000302934972;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.5;30.9;40.5;43.1;32.1;Cadastre;A 1.0;POLYGON Z ((354384.9 6690059.3 40.5, 354384.8 6690069.2 40.5, 354384.9 6690073.6 40.5, 354387.1 6690073.7 40.5, 354387.1 6690068.9 40.5, 354390.8 6690068.8 40.5, 354390.4 6690058.9 40.5, 354384.9 6690059.3 40.5))
BATIMENT0000000302934968;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.4;30.2;39.6;42.9;31.6;Cadastre;A 1.0;POLYGON Z ((354353.8 6690062.3 39.6, 354350.2 6690065.8 39.6, 354356.7 6690072.3 39.6, 354359.8 6690069.5 39.6, 354362.2 6690071.7 39.6, 354362.4 6690075 39.6, 354364 6690074.8 39.6, 354363 6690061.3 39.6, 354353.8 6690062.3 39.6))
BATIMENT0000000302934974;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;31.7;34.8;35.3;32.0;Cadastre;;POLYGON Z ((354400.9 6690070.7 34.8, 354404.3 6690070.7 34.8, 354404.3 6690068.4 34.8, 354401 6690068.5 34.8, 354400.9 6690070.7 34.8))
BATIMENT0000000302934967;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;4.2;30.8;35.0;38.7;31.7;Cadastre;A 1.0;POLYGON Z ((354367.8 6690070.1 35, 354369.7 6690070 35, 354369.3 6690060.8 35, 354363 6690061.3 35, 354364 6690074.8 35, 354364.4 6690080.1 35, 354364.4 6690081.1 35, 354368.4 6690080.9 35, 354368.4 6690079.9 35, 354367.8 6690070.1 35))
BATIMENT0000000302934971;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.9;30.2;40.1;42.2;31.3;Cadastre;A 1.0;POLYGON Z ((354342.6 6690072.9 40.1, 354348.9 6690079.8 40.1, 354356.7 6690072.3 40.1, 354350.2 6690065.8 40.1, 354342.6 6690072.9 40.1))
BATIMENT0000000302934982;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;10;6.8;31.8;38.6;41.5;32.3;Cadastre;A 1.0;POLYGON Z ((354409.7 6690080.6 38.6, 354409.6 6690072.8 38.6, 354401.6 6690073.1 38.6, 354401.8 6690076.6 38.6, 354397.3 6690076.8 38.6, 354397.6 6690080.8 38.6, 354403.5 6690080.8 38.6, 354409.7 6690080.6 38.6))
BATIMENT0000000302934812;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;31.8;35.5;39.5;32.8;Cadastre;;POLYGON Z ((354438.9 6690071.7 35.5, 354443.2 6690071.6 35.5, 354443 6690068.8 35.5, 354438.7 6690068.8 35.5, 354438.9 6690071.7 35.5))
BATIMENT0000000302934808;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.5;31.5;35.0;36.2;32.5;Cadastre;A 1.0;POLYGON Z ((354417.7 6690075.9 35, 354424.7 6690075.7 35, 354424.5 6690072.7 35, 354422 6690072.8 35, 354417.6 6690072.9 35, 354417.7 6690075.9 35))
BATIMENT0000000302934814;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;6.8;31.5;38.4;50.5;33.3;Cadastre;A 1.0;POLYGON Z ((354452.1 6690058.1 38.4, 354452.8 6690070.3 38.4, 354455.7 6690070.3 38.4, 354455.9 6690073.8 38.4, 354452.9 6690074.1 38.4, 354453.2 6690077.8 38.4, 354453.9 6690093.1 38.4, 354459.3 6690092.8 38.4, 354464.3 6690092.4 38.4, 354464.1 6690087 38.4, 354463.2 6690072.4 38.4, 354462.3 6690057.8 38.4, 354452.1 6690058.1 38.4))
BATIMENT0000000302934811;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.8;31.7;37.5;41.5;32.6;Cadastre;A 1.0;POLYGON Z ((354417.7 6690079.1 37.5, 354426.4 6690078.9 37.5, 354426.4 6690075.7 37.5, 354424.7 6690075.7 37.5, 354417.7 6690075.9 37.5, 354417.7 6690079.1 37.5))
BATIMENT0000000302934827;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.1;32.9;36.0;36.5;33.1;Cadastre;A 1.0;POLYGON Z ((354464.1 6690087 36, 354468.2 6690086.9 36, 354467.8 6690077.6 36, 354469.3 6690077.3 36, 354469.1 6690072 36, 354463.2 6690072.4 36, 354464.1 6690087 36))
BATIMENT0000000302934828;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.5;32.0;39.5;41.7;32.7;Cadastre;A 1.0;POLYGON Z ((354417.9 6690089.4 39.5, 354425.5 6690089 39.5, 354425.4 6690080.3 39.5, 354426.4 6690080.4 39.5, 354426.4 6690078.9 39.5, 354417.7 6690079.1 39.5, 354417.9 6690089.4 39.5))
BATIMENT0000000302935193;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;32.1;35.3;36.5;33.2;Cadastre;;POLYGON Z ((354449.5 6690092.4 35.3, 354450 6690092.4 35.3, 354449.7 6690087.7 35.3, 354445.1 6690087.9 35.3, 354445.1 6690089.3 35.3, 354445.3 6690092.8 35.3, 354449.5 6690092.4 35.3))
BATIMENT0000000302935192;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;32.0;35.3;36.4;32.9;Cadastre;;POLYGON Z ((354439.5 6690089.8 35.3, 354439.7 6690094 35.3, 354445.4 6690093.2 35.3, 354445.3 6690092.8 35.3, 354445.1 6690089.3 35.3, 354439.5 6690089.8 35.3))
BATIMENT0000000302934829;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;32.2;36.2;38.7;32.7;Cadastre;;POLYGON Z ((354425.5 6690089 36.2, 354425.9 6690096.2 36.2, 354426.5 6690096.1 36.2, 354427.5 6690096 36.2, 354427.2 6690088.9 36.2, 354427.1 6690088.8 36.2, 354425.5 6690089 36.2))
BATIMENT0000000302934985;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.8;31.9;38.7;40.2;32.4;Cadastre;A 1.0;POLYGON Z ((354401.7 6690097.4 38.7, 354406.2 6690097.3 38.7, 354410.1 6690097 38.7, 354409.9 6690088.1 38.7, 354401.8 6690088.3 38.7, 354401.7 6690097.4 38.7))
BATIMENT0000000302935219;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;32.6;35.1;;;Cadastre;;POLYGON Z ((354496.5 6690079.3 35.1, 354501.8 6690079.3 35.1, 354501.9 6690075.7 35.1, 354496.4 6690075.9 35.1, 354496.5 6690079.3 35.1))
BATIMENT0000000302934822;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;20;8.3;32.9;41.2;;;Cadastre;A 1.0;POLYGON Z ((354481.7 6690077.1 41.2, 354473.1 6690077 41.2, 354473.2 6690078.1 41.2, 354474.8 6690078.1 41.2, 354474.8 6690086.6 41.2, 354482 6690086.3 41.2, 354481.7 6690077.1 41.2))
BATIMENT0000000302934955;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.2;31.7;38.0;40.6;32.9;Cadastre;A 1.0;POLYGON Z ((354502 6690083.8 38, 354491.6 6690084.1 38, 354491.9 6690089.4 38, 354493.4 6690092.9 38, 354502.7 6690095.1 38, 354502 6690083.8 38))
BATIMENT0000000302934818;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;10;20;12.5;31.7;44.2;46.8;33.3;Cadastre;A 1.0;POLYGON Z ((354470.2 6690091.9 44.2, 354468.6 6690092 44.2, 354469 6690098.3 44.2, 354475.3 6690098 44.2, 354475.5 6690100.6 44.2, 354485.3 6690099.9 44.2, 354482.5 6690092.8 44.2, 354482 6690086.3 44.2, 354474.8 6690086.6 44.2, 354473.6 6690086.7 44.2, 354473.2 6690086.7 44.2, 354473.6 6690091.7 44.2, 354472.8 6690091.1 44.2, 354470.5 6690091.4 44.2, 354470.2 6690091.9 44.2))
BATIMENT0000000302934956;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;20;6.0;33.0;39.0;;;Cadastre;A 1.0;POLYGON Z ((354500.3 6690109.7 39, 354508.6 6690106.4 39, 354509.1 6690106.2 39, 354504.9 6690095.7 39, 354502.7 6690095.1 39, 354493.4 6690092.9 39, 354500.3 6690109.7 39))
BATIMENT0000000302935343;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.0;32.0;36.0;41.7;32.9;Cadastre;;POLYGON Z ((354537.3 6690105.9 36, 354537.7 6690104.5 36, 354529.8 6690102.5 36, 354526.3 6690104 36, 354528.7 6690109.3 36, 354530.5 6690108.6 36, 354532.8 6690107.7 36, 354537.3 6690105.9 36))
BATIMENT0000000302934819;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.3;32.9;39.2;41.9;33.3;Cadastre;A 0.9;POLYGON Z ((354475.2 6690100.6 39.2, 354476.8 6690103.9 39.2, 354478.8 6690103.2 39.2, 354481.3 6690109.3 39.2, 354478.9 6690110.4 39.2, 354479.8 6690112.5 39.2, 354478.8 6690112.9 39.2, 354479.4 6690114.8 39.2, 354481.1 6690114.1 39.2, 354489.6 6690110.5 39.2, 354485.3 6690099.9 39.2, 354475.5 6690100.6 39.2, 354475.2 6690100.6 39.2))
BATIMENT0000000302934957;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;3.5;31.8;35.4;41.2;32.4;Cadastre;A 1.0;POLYGON Z ((354510.4 6690110.9 35.4, 354513.3 6690109.7 35.4, 354516.7 6690108.3 35.4, 354514.8 6690103.7 35.4, 354509.1 6690106.2 35.4, 354508.6 6690106.4 35.4, 354500.3 6690109.7 35.4, 354502.2 6690114.1 35.4, 354510.4 6690110.9 35.4))
BATIMENT0000000302935342;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;3.2;32.1;35.4;35.8;32.8;Cadastre;C 0.3;POLYGON Z ((354533.6 6690115.9 35.4, 354535.7 6690115 35.4, 354532.8 6690107.7 35.4, 354530.5 6690108.6 35.4, 354533.6 6690115.9 35.4))
BATIMENT0000000302934958;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;6.3;31.8;38.2;41.9;32.3;Cadastre;C 0.5;POLYGON Z ((354504.6 6690119.9 38.2, 354512.9 6690116.4 38.2, 354514 6690115.8 38.2, 354515.6 6690115.2 38.2, 354515.2 6690114.3 38.2, 354515.6 6690113.3 38.2, 354514.8 6690111.4 38.2, 354513.8 6690110.9 38.2, 354513.3 6690109.7 38.2, 354510.4 6690110.9 38.2, 354502.2 6690114.1 38.2, 354504.6 6690119.9 38.2))
BATIMENT0000000302934710;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;32.0;41.5;45.1;33.0;Cadastre;C 0.9;POLYGON Z ((354576.9 6690053.3 41.5, 354577.4 6690065.8 41.5, 354578.8 6690065.8 41.5, 354586.8 6690065.5 41.5, 354586.7 6690062.9 41.5, 354586.5 6690052.9 41.5, 354576.9 6690053.3 41.5))
BATIMENT0000000302934965;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.6;31.8;39.5;46.1;33.2;Cadastre;C 0.7;POLYGON Z ((354551.8 6690066.2 39.5, 354566.3 6690065.8 39.5, 354566.1 6690054.5 39.5, 354551.4 6690054.9 39.5, 354551.7 6690061.1 39.5, 354551.8 6690066.2 39.5))
BATIMENT0000000302934709;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;33.0;36.2;40.2;33.0;Cadastre;;POLYGON Z ((354579 6690069.3 36.2, 354586.9 6690069.1 36.2, 354586.8 6690065.5 36.2, 354578.8 6690065.8 36.2, 354579 6690069.3 36.2))
BATIMENT0000000302935288;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.1;32.5;35.6;41.7;33.0;Cadastre;C 0.4;POLYGON Z ((354615.3 6690072.8 35.6, 354622.1 6690072.6 35.6, 354628 6690072.3 35.6, 354627.8 6690067.4 35.6, 354612.7 6690067.9 35.6, 354611.5 6690067.1 35.6, 354606.9 6690067.4 35.6, 354607 6690073.1 35.6, 354615.3 6690072.8 35.6))
BATIMENT0000000302935286;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;5.5;32.5;38.0;41.5;33.2;Cadastre;A 1.0;POLYGON Z ((354607.2 6690082.6 38, 354615.6 6690082.4 38, 354615.3 6690072.8 38, 354607 6690073.1 38, 354607.2 6690082.6 38))
BATIMENT0000000302934683;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;02;4.1;33.0;37.1;39.0;33.4;Cadastre;C 0.4;POLYGON Z ((354591.7 6690078.7 37.1, 354591.6 6690082.6 37.1, 354598.4 6690082.6 37.1, 354598.3 6690078.6 37.1, 354591.7 6690078.7 37.1))
BATIMENT0000000029197613;Indifférenciée;Résidentiel;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;2005-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;1.0;60;10;2.1;33.0;;47.9;33.1;Imagerie aérienne;C 0.4;POLYGON Z ((354557.5 6690086.8 34.9, 354558.9 6690075.1 35.1, 354553.5 6690074.9 35.1, 354552.2 6690086.7 34.9, 354557.5 6690086.8 34.9))
BATIMENT0000000302934764;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.2;32.7;38.0;43.0;33.4;Cadastre;C 0.2;POLYGON Z ((354576.6 6690077.7 38, 354572.8 6690077.8 38, 354573 6690084.3 38, 354576.9 6690084.1 38, 354576.6 6690077.7 38))
BATIMENT0000000302935287;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;10;5.6;32.5;38.1;40.9;33.2;Cadastre;A 1.0;POLYGON Z ((354607.6 6690090.5 38.1, 354615.8 6690088.2 38.1, 354615.6 6690082.4 38.1, 354607.2 6690082.6 38.1, 354607.6 6690090.5 38.1))
BATIMENT0000000302934681;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;7.5;32.8;40.4;42.7;33.5;Cadastre;A 1.0;POLYGON Z ((354598.4 6690084 40.4, 354590.5 6690083.8 40.4, 354590.3 6690085.5 40.4, 354588 6690085.7 40.4, 354588.1 6690088.2 40.4, 354586.2 6690088.3 40.4, 354585.1 6690089.1 40.4, 354585 6690091.4 40.4, 354585.3 6690091.4 40.4, 354598.6 6690091 40.4, 354598.4 6690084 40.4))
BATIMENT0000000302934627;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.9;32.1;42.0;45.1;33.0;Cadastre;A 1.0;POLYGON Z ((354638.4 6690051.3 42, 354638.8 6690062.1 42, 354643.7 6690061.9 42, 354643.9 6690061.2 42, 354648.4 6690061.1 42, 354648.3 6690051 42, 354638.4 6690051.3 42))
BATIMENT0000000302934629;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;9.5;32.1;41.6;43.5;33.0;Cadastre;A 1.0;POLYGON Z ((354628.1 6690051.7 41.6, 354628.7 6690061.8 41.6, 354628.7 6690063 41.6, 354638.8 6690062.9 41.6, 354638.8 6690062.1 41.6, 354638.4 6690051.3 41.6, 354628.1 6690051.7 41.6))
BATIMENT0000000302934626;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;6.0;32.6;38.7;45.2;33.4;Cadastre;A 1.0;POLYGON Z ((354648.3 6690051 38.7, 354648.4 6690061.1 38.7, 354648.9 6690067.1 38.7, 354658.4 6690066.8 38.7, 354657.6 6690060.8 38.7, 354656.4 6690050.8 38.7, 354648.3 6690051 38.7))
BATIMENT0000000302934630;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;6.0;16;10;16.2;32.2;48.4;51.7;33.7;Cadastre;A 1.0;POLYGON Z ((354665.1 6690050.5 48.4, 354666.7 6690061 48.4, 354667.7 6690070.5 48.4, 354672.8 6690069.8 48.4, 354671.8 6690059.3 48.4, 354688.1 6690058.8 48.4, 354687.1 6690049.9 48.4, 354665.1 6690050.5 48.4))
BATIMENT0000000302934628;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;19;20;4.3;32.7;37.1;47.6;33.6;Cadastre;A 1.0;POLYGON Z ((354656.4 6690050.8 37.1, 354657.6 6690060.8 37.1, 354658.4 6690066.8 37.1, 354658.9 6690071.2 37.1, 354665.5 6690070.7 37.1, 354664.5 6690061.2 37.1, 354666.7 6690061 37.1, 354665.1 6690050.5 37.1, 354656.4 6690050.8 37.1))
BATIMENT0000000302935289;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.1;32.5;35.6;36.7;33.1;Cadastre;B 0.4;POLYGON Z ((354622.3 6690078.7 35.6, 354638.4 6690078 35.6, 354638.1 6690072.1 35.6, 354628 6690072.3 35.6, 354622.1 6690072.6 35.6, 354622.3 6690078.7 35.6))
BATIMENT0000000302934632;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;65.0;6.0;00;00;15.4;32.1;47.5;50.6;33.8;Cadastre;A 1.0;POLYGON Z ((354695.2 6690058.7 47.5, 354695.2 6690061.1 47.5, 354696.8 6690061 47.5, 354697 6690066.8 47.5, 354693.3 6690071.3 47.5, 354684 6690082.8 47.5, 354680.7 6690086.8 47.5, 354682.4 6690088.3 47.5, 354680.1 6690091.2 47.5, 354681.8 6690092.6 47.5, 354678.9 6690096.2 47.5, 354674.9 6690098.4 47.5, 354673.7 6690096.3 47.5, 354666.3 6690100.5 47.5, 354661 6690102.4 47.5, 354661.8 6690104.5 47.5, 354655.7 6690106.8 47.5, 354659.8 6690118.8 47.5, 354672 6690114.2 47.5, 354688.1 6690105.3 47.5, 354688.3 6690105.1 47.5, 354692.7 6690099.7 47.5, 354690.5 6690097.8 47.5, 354692.3 6690095.6 47.5, 354693.6 6690096.6 47.5, 354697.3 6690092 47.5, 354698.3 6690092.8 47.5, 354708.8 6690079.9 47.5, 354718.4 6690068.2 47.5, 354714 6690064.7 47.5, 354711.2 6690052.7 47.5, 354711.1 6690049.2 47.5, 354690.7 6690049.7 47.5, 354691.9 6690058.7 47.5, 354695.2 6690058.7 47.5))
BATIMENT0000000302935326;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;32.9;35.8;36.1;33.1;Cadastre;;POLYGON Z ((354639.4 6690084.4 35.8, 354638.6 6690084.5 35.8, 354638.5 6690082.7 35.8, 354628.7 6690085.4 35.8, 354629 6690086.5 35.8, 354627.9 6690086.8 35.8, 354628.2 6690087.7 35.8, 354628.4 6690088.3 35.8, 354629.3 6690088.1 35.8, 354630 6690090.3 35.8, 354640 6690087.4 35.8, 354639.4 6690084.4 35.8))
BATIMENT0000000302934684;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;0.0;00;00;3.7;31.8;35.5;39.9;33.4;Cadastre;C 0.2;POLYGON Z ((354650.2 6690081.7 35.5, 354645 6690083.1 35.5, 354646.7 6690087.5 35.5, 354646.1 6690087.7 35.5, 354646.9 6690090.8 35.5, 354646.3 6690090.9 35.5, 354647 6690093.8 35.5, 354651.1 6690092.8 35.5, 354650.2 6690081.7 35.5))
BATIMENT0000000302934633;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.7;32.1;45.8;48.7;33.7;Cadastre;;POLYGON Z ((354674.9 6690098.4 45.8, 354678.9 6690096.2 45.8, 354681.8 6690092.6 45.8, 354680.1 6690091.2 45.8, 354677.8 6690094.1 45.8, 354673.7 6690096.3 45.8, 354674.9 6690098.4 45.8))
BATIMENT0000000302934573;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;50;90;15.7;33.4;49.1;51.7;33.7;Cadastre;C 0.5;POLYGON Z ((354780.9 6690085.1 49.1, 354789 6690084.9 49.1, 354792.4 6690085 49.1, 354792.5 6690073.3 49.1, 354781.3 6690072.9 49.1, 354780.9 6690085.1 49.1))
BATIMENT0000000302934721;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;10;20;7.1;34.7;41.8;;;Cadastre;A 1.0;POLYGON Z ((354725.4 6690079.2 41.8, 354729.6 6690082.5 41.8, 354731.3 6690083.9 41.8, 354734.5 6690086.6 41.8, 354732.3 6690089.2 41.8, 354729.2 6690092.4 41.8, 354733.4 6690092.5 41.8, 354754.2 6690092.9 41.8, 354771 6690093.3 41.8, 354771.4 6690081.2 41.8, 354761 6690080.9 41.8, 354761 6690083.1 41.8, 354752.7 6690082.9 41.8, 354752.9 6690080.5 41.8, 354740.7 6690080.2 41.8, 354744.5 6690076 41.8, 354743.4 6690074.9 41.8, 354740.1 6690072.3 41.8, 354738.8 6690071.2 41.8, 354738.2 6690070.8 41.8, 354734.4 6690067.6 41.8, 354734 6690068 41.8, 354725.4 6690079.2 41.8))
BATIMENT0000000302934722;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;33.7;38.2;39.0;34.0;Cadastre;;POLYGON Z ((354731.3 6690083.9 38.2, 354729.1 6690086.4 38.2, 354732.3 6690089.2 38.2, 354734.5 6690086.6 38.2, 354731.3 6690083.9 38.2))
BATIMENT0000000302934740;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;20;20;4.5;33.6;38.2;41.4;33.9;Cadastre;A 1.0;POLYGON Z ((354725 6690078.7 38.2, 354724.9 6690078.6 38.2, 354725 6690078.9 38.2, 354716.5 6690090 38.2, 354717.1 6690094.8 38.2, 354717.9 6690100.9 38.2, 354718.1 6690102.1 38.2, 354724.8 6690097.1 38.2, 354727 6690094.7 38.2, 354724.7 6690092.6 38.2, 354722 6690095.3 38.2, 354721.2 6690094.4 38.2, 354729.6 6690082.5 38.2, 354725.4 6690079.2 38.2, 354725 6690078.7 38.2))
BATIMENT0000000302934572;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;3.0;00;00;7.1;34.9;42.0;;;Cadastre;A 0.6;POLYGON Z ((354780.6 6690096.1 42, 354788.8 6690096.1 42, 354789 6690084.9 42, 354780.9 6690085.1 42, 354780.6 6690096.1 42))
BATIMENT0000000302934727;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;33.7;36.6;37.9;34.0;Cadastre;C 0.2;POLYGON Z ((354731.3 6690098.8 36.6, 354730.6 6690098.7 36.6, 354730.7 6690095.7 36.6, 354733.3 6690095.6 36.6, 354733.4 6690092.5 36.6, 354729.2 6690092.4 36.6, 354727 6690094.7 36.6, 354724.8 6690097.1 36.6, 354718.1 6690102.1 36.6, 354721.7 6690102.2 36.6, 354731.2 6690102.4 36.6, 354731.3 6690098.8 36.6))
BATIMENT0000000302934726;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;30;20;17.0;33.7;50.7;53.8;34.4;Cadastre;C 0.7;POLYGON Z ((354753.8 6690102.9 50.7, 354759.1 6690103 50.7, 354770.7 6690103.5 50.7, 354771 6690093.3 50.7, 354754.2 6690092.9 50.7, 354753.8 6690102.9 50.7))
BATIMENT0000000302934569;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;20;20;7.0;34.9;41.9;;;Cadastre;A 1.0;POLYGON Z ((354780.4 6690103.1 41.9, 354788.5 6690103.2 41.9, 354788.8 6690096.1 41.9, 354780.6 6690096.1 41.9, 354780.4 6690103.1 41.9))
BATIMENT0000000302934730;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;50;20;4.5;33.9;38.4;42.0;34.8;Cadastre;C 0.6;POLYGON Z ((354700.7 6690110.3 38.4, 354702.2 6690117 38.4, 354704 6690116.2 38.4, 354707.9 6690110.9 38.4, 354707.1 6690110.3 38.4, 354712.6 6690103.7 38.4, 354713.7 6690114.3 38.4, 354707.9 6690116.1 38.4, 354707.5 6690117.2 38.4, 354708.2 6690119.7 38.4, 354720 6690116.6 38.4, 354718.1 6690102.1 38.4, 354717.9 6690100.9 38.4, 354715.8 6690101.3 38.4, 354715.6 6690101.6 38.4, 354713.8 6690101.9 38.4, 354715.5 6690098.8 38.4, 354714.6 6690097.8 38.4, 354717.1 6690094.8 38.4, 354716.5 6690090 38.4, 354700.7 6690110.3 38.4))
BATIMENT0000000302934568;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;6.5;35.0;41.5;;;Cadastre;B 0.9;POLYGON Z ((354780.2 6690111.7 41.5, 354790.1 6690111.5 41.5, 354790.1 6690109.4 41.5, 354792.3 6690109.4 41.5, 354792.2 6690107 41.5, 354790.2 6690106.9 41.5, 354790.3 6690103.3 41.5, 354788.5 6690103.2 41.5, 354780.4 6690103.1 41.5, 354780.2 6690111.7 41.5))
BATIMENT0000000302934674;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;33.1;38.5;46.7;33.4;Cadastre;;POLYGON Z ((354569.2 6690086.1 38.5, 354571.1 6690091.9 38.5, 354574.3 6690091.7 38.5, 354574.1 6690085.3 38.5, 354569.2 6690086.1 38.5))
BATIMENT0000000302934678;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;10;7.8;32.9;40.7;42.9;33.4;Cadastre;A 0.6;POLYGON Z ((354598.6 6690096.4 40.7, 354598.6 6690091 40.7, 354585.3 6690091.4 40.7, 354585 6690091.4 40.7, 354584 6690091.4 40.7, 354584.1 6690097 40.7, 354585.8 6690096.9 40.7, 354586.6 6690096.9 40.7, 354590 6690096.9 40.7, 354598.6 6690096.4 40.7))
BATIMENT0000000302934672;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.8;33.0;35.9;36.7;33.4;Cadastre;A 0.4;POLYGON Z ((354574.3 6690091.7 35.9, 354571.1 6690091.9 35.9, 354572.9 6690097.4 35.9, 354573 6690097.4 35.9, 354574.4 6690097.4 35.9, 354574.3 6690091.7 35.9))
BATIMENT0000000302934660;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;12;5.2;31.8;37.0;42.5;33.3;Cadastre;C 0.7;POLYGON Z ((354619.9 6690101 37, 354619.8 6690090.7 37, 354613.3 6690092.5 37, 354613.4 6690093.2 37, 354608.7 6690094.4 37, 354609.1 6690104.2 37, 354614.2 6690102.6 37, 354619.9 6690101 37))
BATIMENT0000000302934668;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;33.0;35.4;36.2;33.3;Cadastre;;POLYGON Z ((354584.1 6690097 35.4, 354583.4 6690097.1 35.4, 354583.5 6690098.6 35.4, 354586.6 6690098.5 35.4, 354586.6 6690096.9 35.4, 354585.8 6690096.9 35.4, 354584.1 6690097 35.4))
BATIMENT0000000302934667;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;33.2;35.1;35.4;33.3;Cadastre;;POLYGON Z ((354578.3 6690097.3 35.1, 354578.8 6690098.7 35.1, 354583.5 6690098.6 35.1, 354583.4 6690097.1 35.1, 354578.3 6690097.3 35.1))
BATIMENT0000000302934677;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;9.2;32.9;42.2;43.0;33.3;Cadastre;A 0.9;POLYGON Z ((354590.2 6690102.2 42.2, 354591.8 6690102 42.2, 354592.9 6690102 42.2, 354598.9 6690101.8 42.2, 354598.6 6690096.4 42.2, 354590 6690096.9 42.2, 354590.2 6690102.2 42.2))
BATIMENT0000000302935284;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;32.8;41.2;47.2;33.1;Cadastre;;POLYGON Z ((354567.8 6690104.8 41.2, 354567.2 6690098.8 41.2, 354556.8 6690099.8 41.2, 354557.3 6690105.8 41.2, 354567.8 6690104.8 41.2))
BATIMENT0000000302934673;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;32.9;39.2;42.9;33.2;Cadastre;;POLYGON Z ((354593 6690103.7 39.2, 354593.4 6690103.7 39.2, 354593.4 6690104.3 39.2, 354594.1 6690104.3 39.2, 354599 6690104.1 39.2, 354598.9 6690101.8 39.2, 354592.9 6690102 39.2, 354592.9 6690103 39.2, 354593 6690103.7 39.2))
BATIMENT0000000302935283;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;32.8;37.4;44.5;33.1;Cadastre;;POLYGON Z ((354548.6 6690106.1 37.4, 354552.3 6690107.2 37.4, 354554.8 6690107.9 37.4, 354556.1 6690103.1 37.4, 354549.2 6690101.3 37.4, 354548.6 6690106.1 37.4))
BATIMENT0000000302934686;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;31.8;35.7;38.9;33.2;Cadastre;;POLYGON Z ((354635.8 6690096.8 35.7, 354634.9 6690093.6 35.7, 354630 6690095 35.7, 354630.9 6690098.1 35.7, 354635.8 6690096.8 35.7))
BATIMENT0000000302934688;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;90;03;3.7;31.8;35.5;38.9;33.3;Cadastre;C 0.4;POLYGON Z ((354624.9 6690094.6 35.5, 354626.3 6690099.3 35.5, 354629.9 6690098.4 35.5, 354630.9 6690098.1 35.5, 354630 6690095 35.5, 354629.5 6690093.4 35.5, 354624.9 6690094.6 35.5))
BATIMENT0000000302934685;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;31.8;36.0;42.0;33.4;Cadastre;;POLYGON Z ((354638.2 6690102 36, 354653.7 6690097.9 36, 354652.1 6690092.5 36, 354651.1 6690092.8 36, 354647 6690093.8 36, 354644.5 6690094.5 36, 354643 6690094.9 36, 354636.6 6690096.6 36, 354638.2 6690102 36))
BATIMENT0000000302934634;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.9;32.0;43.9;47.4;33.5;Cadastre;;POLYGON Z ((354655.2 6690105.3 43.9, 354655.7 6690106.8 43.9, 354661.8 6690104.5 43.9, 354661 6690102.4 43.9, 354655 6690104.7 43.9, 354655.2 6690105.3 43.9))
BATIMENT0000000302934689;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;33.0;38.1;38.5;33.3;Cadastre;;POLYGON Z ((354622.1 6690100.3 38.1, 354623.5 6690104.1 38.1, 354627.3 6690102.9 38.1, 354631.1 6690113.9 38.1, 354634.5 6690112.9 38.1, 354631.7 6690103.6 38.1, 354629.9 6690098.4 38.1, 354626.3 6690099.3 38.1, 354622.1 6690100.3 38.1))
BATIMENT0000000302934687;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.1;31.8;35.9;39.5;33.2;Cadastre;;POLYGON Z ((354634.6 6690113.3 35.9, 354637.2 6690112.5 35.9, 354636.8 6690111.3 35.9, 354639.3 6690110.6 35.9, 354636.8 6690102.2 35.9, 354631.7 6690103.6 35.9, 354634.5 6690112.9 35.9, 354634.6 6690113.3 35.9))
BATIMENT0000000302934635;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;8.7;31.8;40.5;43.2;33.5;Cadastre;A 0.6;POLYGON Z ((354659.8 6690118.8 40.5, 354655.7 6690106.8 40.5, 354655.2 6690105.3 40.5, 354655 6690104.7 40.5, 354654 6690101.8 40.5, 354648.4 6690104 40.5, 354650.1 6690109.4 40.5, 354640.5 6690112.5 40.5, 354641.7 6690116.3 40.5, 354642.5 6690118.7 40.5, 354644.3 6690124.4 40.5, 354659.8 6690118.8 40.5))
BATIMENT0000000302934690;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;33.0;35.0;36.2;33.2;Cadastre;;POLYGON Z ((354635.1 6690114.8 35, 354637.7 6690114.2 35, 354637.2 6690112.5 35, 354634.6 6690113.3 35, 354635.1 6690114.8 35))
BATIMENT0000000302934639;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;6.2;31.8;38.0;43.7;33.1;Cadastre;B 1.0;POLYGON Z ((354636.4 6690121 38, 354636.3 6690120.6 38, 354636.9 6690120.5 38, 354635.9 6690117.2 38, 354632.1 6690118.5 38, 354633.3 6690121.9 38, 354636.4 6690121 38))
BATIMENT0000000302934641;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;8.6;31.8;40.4;44.6;33.1;Cadastre;A 1.0;POLYGON Z ((354632 6690129.1 40.4, 354629.6 6690123 40.4, 354626 6690111.9 40.4, 354623.5 6690112.8 40.4, 354624.9 6690116.2 40.4, 354624.3 6690116.3 40.4, 354625.2 6690120 40.4, 354620.8 6690121.5 40.4, 354624.4 6690131.8 40.4, 354632 6690129.1 40.4))
BATIMENT0000000302934665;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;10;4.3;32.9;37.2;38.8;33.5;Cadastre;A 1.0;POLYGON Z ((354590.2 6690102.2 37.2, 354587.6 6690102.7 37.2, 354589.2 6690107.6 37.2, 354582.6 6690110 37.2, 354578.8 6690098.7 37.2, 354578.3 6690097.3 37.2, 354574.4 6690097.4 37.2, 354573 6690097.4 37.2, 354572.9 6690097.4 37.2, 354577.7 6690111.9 37.2, 354578.7 6690114.6 37.2, 354579.3 6690116.3 37.2, 354585.1 6690114 37.2, 354591.6 6690111.5 37.2, 354593.1 6690111 37.2, 354593.2 6690106.8 37.2, 354594.1 6690105.8 37.2, 354594.1 6690104.3 37.2, 354593.4 6690104.3 37.2, 354593.4 6690103.7 37.2, 354593 6690103.7 37.2, 354592.9 6690103 37.2, 354592.9 6690102 37.2, 354591.8 6690102 37.2, 354590.2 6690102.2 37.2))
BATIMENT0000000302934676;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;05;01;3.4;32.7;36.1;36.9;33.2;Cadastre;A 1.0;POLYGON Z ((354594.1 6690105.8 36.1, 354593.2 6690106.8 36.1, 354593.1 6690111 36.1, 354599.2 6690108.4 36.1, 354599.2 6690105.5 36.1, 354594.1 6690105.8 36.1))
BATIMENT0000000302934650;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;3.4;33.0;36.4;40.0;33.3;Cadastre;A 1.0;POLYGON Z ((354609.1 6690104.2 36.4, 354608.1 6690104.5 36.4, 354606.7 6690107.5 36.4, 354607.1 6690108 36.4, 354608.8 6690112.7 36.4, 354610 6690116.2 36.4, 354617.9 6690113.4 36.4, 354614.2 6690102.6 36.4, 354609.1 6690104.2 36.4))
BATIMENT0000000302934663;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;04;09;3.6;32.0;35.6;43.5;33.0;Cadastre;C 0.3;POLYGON Z ((354574.1 6690118.1 35.6, 354574.4 6690117.4 35.6, 354580.2 6690118.9 35.6, 354579.8 6690117.6 35.6, 354579.3 6690116.3 35.6, 354578.7 6690114.6 35.6, 354567.3 6690111.9 35.6, 354564.7 6690111.2 35.6, 354566.4 6690116.2 35.6, 354574.1 6690118.1 35.6))
BATIMENT0000000302934649;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;3.8;32.9;36.7;42.1;33.3;Cadastre;A 1.0;POLYGON Z ((354608.8 6690112.7 36.7, 354607.1 6690108 36.7, 354604.4 6690109 36.7, 354606.8 6690116.5 36.7, 354606.1 6690116.8 36.7, 354606.5 6690117.8 36.7, 354604.2 6690118.7 36.7, 354603.7 6690117.1 36.7, 354600.9 6690118.1 36.7, 354598.8 6690112.2 36.7, 354596 6690113.3 36.7, 354596.4 6690115.2 36.7, 354598.8 6690122 36.7, 354599.8 6690124.6 36.7, 354600.4 6690126.4 36.7, 354609.9 6690123 36.7, 354611.2 6690122.5 36.7, 354610.2 6690119.1 36.7, 354609.8 6690117.9 36.7, 354610.5 6690117.7 36.7, 354610 6690116.2 36.7, 354608.8 6690112.7 36.7))
BATIMENT0000000302934664;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;09;3.8;33.0;36.8;38.9;33.2;Cadastre;C 0.1;POLYGON Z ((354580.2 6690118.9 36.8, 354580.9 6690120.9 36.8, 354585.5 6690119.3 36.8, 354586.8 6690118.8 36.8, 354585.1 6690114 36.8, 354579.3 6690116.3 36.8, 354579.8 6690117.6 36.8, 354580.2 6690118.9 36.8))
BATIMENT0000000302934646;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;90;7.7;31.8;39.5;40.9;33.1;Cadastre;C 0.4;POLYGON Z ((354590.6 6690117.4 39.5, 354593.9 6690126.8 39.5, 354594.5 6690126.7 39.5, 354599.8 6690124.6 39.5, 354598.8 6690122 39.5, 354596.4 6690115.2 39.5, 354590.6 6690117.4 39.5))
BATIMENT0000000302934659;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1886-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.4;32.9;39.3;;;Cadastre;A 1.0;POLYGON Z ((354561.7 6690124.4 39.3, 354568.3 6690122 39.3, 354566.7 6690117.3 39.3, 354556.1 6690121.3 39.3, 354557.2 6690126.1 39.3, 354561.7 6690124.4 39.3))
BATIMENT0000000302934669;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;33.2;36.3;;;Cadastre;;POLYGON Z ((354583.7 6690129.7 36.3, 354588.5 6690128 36.3, 354585.5 6690119.3 36.3, 354580.9 6690120.9 36.3, 354583.7 6690129.7 36.3))
BATIMENT0000000302934662;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;6.2;33.2;39.4;;;Cadastre;A 1.0;POLYGON Z ((354556.1 6690120.9 39.4, 354544.4 6690125.3 39.4, 354543.1 6690122.7 39.4, 354540.7 6690123.4 39.4, 354543.3 6690129.6 39.4, 354544 6690131.2 39.4, 354550.9 6690128.5 39.4, 354556.8 6690126.3 39.4, 354557.2 6690126.1 39.4, 354556.1 6690121.3 39.4, 354556.1 6690120.9 39.4))
BATIMENT0000002011294814;Indifférenciée;Résidentiel;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:41:05;2017-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;24.0;5.0;56;30;11.7;34.0;;48.2;34.5;Imagerie aérienne;C 0.7;POLYGON Z ((354769.5 6690103.5 45.7, 354759.1 6690103 45.7, 354753.8 6690102.9 45.7, 354752.7 6690102.9 45.7, 354752.5 6690126.7 45.7, 354768.8 6690127.2 45.7, 354769.5 6690103.5 45.7))
BATIMENT0000002011293843;Indifférenciée;Annexe;;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;2016-01-01;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;0.0;00;00;6.6;34.1;;;;Imagerie aérienne;C 0.2;POLYGON Z ((354727.8 6690110.5 40.1, 354727.8 6690116.2 40.7, 354727.3 6690120.9 37.7, 354745.9 6690121.5 37.4, 354746.4 6690116.7 40.3, 354746.1 6690111.3 40, 354727.8 6690110.5 40.1))
BATIMENT0000000302934562;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;10;20;9.3;33.9;43.2;45.0;34.4;Cadastre;A 1.0;POLYGON Z ((354779.9 6690121.2 43.2, 354793.1 6690121.6 43.2, 354794.6 6690119.5 43.2, 354790 6690119.6 43.2, 354790.1 6690112.8 43.2, 354790.1 6690111.5 43.2, 354780.2 6690111.7 43.2, 354779.9 6690121.2 43.2))
BATIMENT0000002011291755;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:41:05;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;1.3;34.2;;42.0;34.8;Imagerie aérienne;;POLYGON Z ((354745.8 6690126.5 35.5, 354752.5 6690126.7 35.5, 354752.6 6690121.1 35.5, 354747.4 6690121.1 35.5, 354747.3 6690123 35.5, 354745.9 6690123.1 35.5, 354745.8 6690126.5 35.5))
BATIMENT0000000302934563;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;16;20;8.9;35.0;43.9;;;Cadastre;A 1.0;POLYGON Z ((354779.7 6690130.5 43.9, 354785.7 6690130.5 43.9, 354789.5 6690130.4 43.9, 354791.3 6690130.4 43.9, 354791.5 6690128.9 43.9, 354791.7 6690126.5 43.9, 354787.7 6690126.4 43.9, 354788 6690122.9 43.9, 354791.1 6690122.9 43.9, 354790.2 6690125.2 43.9, 354791.8 6690125.4 43.9, 354792.5 6690122.2 43.9, 354793.1 6690121.6 43.9, 354779.9 6690121.2 43.9, 354779.7 6690130.5 43.9))
BATIMENT0000000302934732;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;5.1;34.0;39.1;43.2;34.8;Cadastre;A 1.0;POLYGON Z ((354704.4 6690128.1 39.1, 354702.6 6690134.4 39.1, 354705 6690135.2 39.1, 354721.4 6690130.6 39.1, 354721.9 6690131.1 39.1, 354721.5 6690125.9 39.1, 354721.2 6690124.6 39.1, 354707.7 6690128.4 39.1, 354706.9 6690125.7 39.1, 354709.6 6690124.9 39.1, 354709.1 6690123 39.1, 354703.6 6690124.4 39.1, 354704.4 6690128.1 39.1))
BATIMENT0000000302934750;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;6.7;34.4;41.1;46.4;35.0;Cadastre;A 1.0;POLYGON Z ((354749.5 6690136.3 41.1, 354755.8 6690136.4 41.1, 354758.4 6690136.4 41.1, 354769.7 6690136.5 41.1, 354770 6690127.2 41.1, 354744.8 6690126.5 41.1, 354744.5 6690136.1 41.1, 354749.5 6690136.3 41.1), (354750.8 6690128.8 41.1, 354760.6 6690129.1 41.1, 354760.4 6690133.9 41.1, 354757.4 6690133.8 41.1, 354757.5 6690131.6 41.1, 354750.7 6690131.4 41.1, 354750.8 6690128.8 41.1))
BATIMENT0000000302934731;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.0;34.5;38.5;39.8;35.1;Cadastre;B 0.5;POLYGON Z ((354730.1 6690131.8 38.5, 354730.3 6690137.9 38.5, 354736.1 6690134.9 38.5, 354733.5 6690126.2 38.5, 354721.5 6690125.9 38.5, 354721.9 6690131.1 38.5, 354730.1 6690131.8 38.5))
BATIMENT0000000302934734;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.7;34.0;39.7;41.8;35.0;Cadastre;;POLYGON Z ((354744.5 6690136.1 39.7, 354744.3 6690141.9 39.7, 354749.4 6690142.1 39.7, 354749.5 6690136.3 39.7, 354744.5 6690136.1 39.7))
BATIMENT0000000302934565;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;13.0;4.0;00;00;10.6;35.0;45.6;;;Cadastre;A 1.0;POLYGON Z ((354779.2 6690146.7 45.6, 354782.2 6690147.8 45.6, 354796.3 6690136.7 45.6, 354791.3 6690130.4 45.6, 354789.5 6690130.4 45.6, 354785.7 6690133.6 45.6, 354785.7 6690130.5 45.6, 354779.7 6690130.5 45.6, 354779.2 6690146.7 45.6))
BATIMENT0000000302934642;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;10;9.7;32.8;42.5;44.7;33.1;Cadastre;A 1.0;POLYGON Z ((354624.4 6690131.8 42.5, 354620.8 6690121.5 42.5, 354610.6 6690125 42.5, 354610.2 6690125.3 42.5, 354611.6 6690129.5 42.5, 354613.9 6690135.7 42.5, 354624.4 6690131.8 42.5))
BATIMENT0000000302934645;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;32.7;35.7;39.0;33.1;Cadastre;;POLYGON Z ((354591.9 6690127.4 35.7, 354593.8 6690132.6 35.7, 354596.2 6690131.8 35.7, 354594.5 6690126.7 35.7, 354593.9 6690126.8 35.7, 354591.9 6690127.4 35.7))
BATIMENT0000000302934651;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;32.3;36.5;39.9;32.7;Cadastre;;POLYGON Z ((354571.5 6690131.7 36.5, 354568.9 6690123.7 36.5, 354563 6690126 36.5, 354565.5 6690133.3 36.5, 354568.6 6690132.3 36.5, 354571.1 6690139 36.5, 354573.5 6690138 36.5, 354573.2 6690136.8 36.5, 354571.5 6690131.7 36.5))
BATIMENT0000000302934643;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1947-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;2.0;16;12;7.2;32.2;39.4;42.1;33.1;Cadastre;A 1.0;POLYGON Z ((354613.9 6690135.7 39.4, 354611.6 6690129.5 39.4, 354597.3 6690134.6 39.4, 354599.3 6690141 39.4, 354613.9 6690135.7 39.4))
BATIMENT0000000302934644;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;7.1;32.5;39.6;42.2;33.0;Cadastre;A 1.0;POLYGON Z ((354591.9 6690133.4 39.6, 354592.8 6690136.2 39.6, 354586.6 6690138.2 39.6, 354588.7 6690144.8 39.6, 354599.3 6690141 39.6, 354597.3 6690134.6 39.6, 354596.2 6690131.8 39.6, 354593.8 6690132.6 39.6, 354591.9 6690133.4 39.6))
BATIMENT0000000302934647;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;7.3;31.8;39.1;42.2;32.9;Cadastre;C 0.8;POLYGON Z ((354584.7 6690132.6 39.1, 354579.5 6690134.5 39.1, 354584.1 6690146.6 39.1, 354588.7 6690144.8 39.1, 354586.6 6690138.2 39.1, 354584.7 6690132.6 39.1))
BATIMENT0000000302934648;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;3.8;32.4;36.2;42.2;32.7;Cadastre;A 1.0;POLYGON Z ((354573.2 6690136.8 36.2, 354573.5 6690138 36.2, 354577.3 6690149 36.2, 354584.1 6690146.6 36.2, 354579.5 6690134.5 36.2, 354573.2 6690136.8 36.2))
BATIMENT0000000302934652;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.0;31.8;38.8;41.4;32.8;Cadastre;;POLYGON Z ((354572.3 6690143.3 38.8, 354568.6 6690144.8 38.8, 354571.1 6690151.3 38.8, 354577.3 6690149 38.8, 354573.5 6690138 38.8, 354571.1 6690139 38.8, 354572.3 6690143.3 38.8))
BATIMENT0000000302934656;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;32.2;36.2;38.7;32.5;Cadastre;;POLYGON Z ((354550.5 6690147.8 36.2, 354550 6690148 36.2, 354550.6 6690150 36.2, 354558 6690147.3 36.2, 354557.2 6690145.3 36.2, 354550.5 6690147.8 36.2))
BATIMENT0000000302934654;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;25;29;7.1;32.0;39.1;42.3;32.5;Cadastre;A 1.0;POLYGON Z ((354561.6 6690141.9 39.1, 354556.6 6690143.7 39.1, 354557.2 6690145.3 39.1, 354558 6690147.3 39.1, 354560.9 6690155.1 39.1, 354565.5 6690153.5 39.1, 354563.2 6690146.5 39.1, 354561.6 6690141.9 39.1))
BATIMENT0000000302934751;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;34.3;41.2;44.0;34.8;Cadastre;;POLYGON Z ((354758.4 6690136.4 41.2, 354755.8 6690136.4 41.2, 354755.4 6690142.2 41.2, 354758.3 6690142.3 41.2, 354758.4 6690136.4 41.2))
BATIMENT0000000302934752;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;39;90;10.3;34.8;45.1;;;Cadastre;C 1.0;POLYGON Z ((354769.7 6690136.5 45.1, 354758.4 6690136.4 45.1, 354758.3 6690142.3 45.1, 354769.5 6690142.5 45.1, 354769.7 6690136.5 45.1))
BATIMENT0000000302934759;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.2;34.5;37.7;;;Cadastre;A 1.0;POLYGON Z ((354710.8 6690138.9 37.7, 354708.9 6690137.9 37.7, 354705.2 6690139.7 37.7, 354706.8 6690142.6 37.7, 354711.7 6690140.4 37.7, 354710.8 6690138.9 37.7))
BATIMENT0000000302934757;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;34.0;38.0;44.7;34.7;Cadastre;;POLYGON Z ((354721.3 6690136.6 38, 354712.6 6690141.8 38, 354713.2 6690143.1 38, 354714.5 6690145.8 38, 354718.2 6690143.9 38, 354719.6 6690143.2 38, 354724.4 6690140.8 38, 354721.3 6690136.6 38))
BATIMENT0000000302934758;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.8;34.2;38.0;43.0;34.6;Cadastre;A 1.0;POLYGON Z ((354706.8 6690142.6 38, 354708.3 6690145.6 38, 354713.2 6690143.1 38, 354712.6 6690141.8 38, 354711.7 6690140.4 38, 354706.8 6690142.6 38))
BATIMENT0000000302936951;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.5;34.4;39.0;42.1;35.0;Cadastre;C 0.3;POLYGON Z ((354729.1 6690141.4 39, 354732.5 6690148.5 39, 354734.6 6690153.3 39, 354738 6690151.6 39, 354738.1 6690142.2 39, 354736.1 6690134.9 39, 354730.3 6690137.9 39, 354724.4 6690140.8 39, 354719.6 6690143.2 39, 354721 6690145.4 39, 354729.1 6690141.4 39))
BATIMENT0000000302934735;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.9;34.0;39.9;41.9;35.0;Cadastre;;POLYGON Z ((354744.1 6690147.9 39.9, 354749.4 6690148 39.9, 354749.4 6690142.1 39.9, 354744.3 6690141.9 39.9, 354744.1 6690147.9 39.9))
BATIMENT0000000302934754;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;34.4;42.2;46.7;34.8;Cadastre;;POLYGON Z ((354758.3 6690142.3 42.2, 354755.4 6690142.2 42.2, 354755.3 6690148.1 42.2, 354758.1 6690148.2 42.2, 354758.3 6690142.3 42.2))
BATIMENT0000000302934755;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1985-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;39;90;9.7;34.3;44.0;50.0;34.8;Cadastre;C 1.0;POLYGON Z ((354769.5 6690142.5 44, 354758.3 6690142.3 44, 354758.1 6690148.2 44, 354760.3 6690148.1 44, 354769.3 6690148.5 44, 354769.5 6690142.5 44))
BATIMENT0000000302934753;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;11.2;34.2;45.5;50.5;34.7;Cadastre;A 1.0;POLYGON Z ((354708.3 6690145.6 45.5, 354709.7 6690148.2 45.5, 354714.5 6690145.8 45.5, 354713.2 6690143.1 45.5, 354708.3 6690145.6 45.5))
BATIMENT0000000302934733;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;13;39;6.6;34.0;40.6;47.6;35.1;Cadastre;A 1.0;POLYGON Z ((354744.3 6690165.6 40.6, 354745.9 6690167.3 40.6, 354750.6 6690173.2 40.6, 354758.9 6690166.9 40.6, 354753.8 6690160.9 40.6, 354749 6690164.8 40.6, 354746.4 6690161.6 40.6, 354751 6690157.8 40.6, 354749.6 6690156.2 40.6, 354749.3 6690155.8 40.6, 354748.6 6690155.1 40.6, 354744.1 6690149.5 40.6, 354744.1 6690147.9 40.6, 354744.3 6690141.9 40.6, 354744.5 6690136.1 40.6, 354744.8 6690126.5 40.6, 354733.5 6690126.2 40.6, 354736.1 6690134.9 40.6, 354738.1 6690142.2 40.6, 354738 6690151.6 40.6, 354734.6 6690153.3 40.6, 354727.9 6690156.8 40.6, 354730.3 6690161.5 40.6, 354738.1 6690157.5 40.6, 354744.3 6690165.6 40.6))
BATIMENT0000000302934736;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;34.8;38.7;41.1;35.0;Cadastre;;POLYGON Z ((354744.1 6690149.5 38.7, 354748.6 6690155.1 38.7, 354752.1 6690152 38.7, 354749.4 6690148.5 38.7, 354749.4 6690148 38.7, 354744.1 6690147.9 38.7, 354744.1 6690149.5 38.7))
BATIMENT0000000302936952;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;13;10;14.2;34.5;48.7;51.4;35.0;Cadastre;C 0.6;POLYGON Z ((354717.2 6690162.4 48.7, 354727.9 6690156.8 48.7, 354734.6 6690153.3 48.7, 354732.5 6690148.5 48.7, 354725.3 6690152.1 48.7, 354726.2 6690154 48.7, 354724.2 6690155.1 48.7, 354718.2 6690143.9 48.7, 354714.5 6690145.8 48.7, 354709.7 6690148.2 48.7, 354717.2 6690162.4 48.7))
BATIMENT0000000302934738;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;34.8;43.0;48.7;35.0;Cadastre;;POLYGON Z ((354751.9 6690153.9 43, 354749.3 6690155.8 43, 354749.6 6690156.2 43, 354751 6690157.8 43, 354751.9 6690158.7 43, 354754.4 6690156.8 43, 354751.9 6690153.9 43))
BATIMENT0000000302934739;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;4.0;10;20;13.3;34.5;47.8;52.0;35.0;Cadastre;A 1.0;POLYGON Z ((354769 6690159.1 47.8, 354769 6690159 47.8, 354769.3 6690148.5 47.8, 354760.3 6690148.1 47.8, 354759.9 6690148.6 47.8, 354757.9 6690148.6 47.8, 354757.9 6690150.4 47.8, 354758.5 6690150.4 47.8, 354758.5 6690153.7 47.8, 354754.4 6690156.8 47.8, 354751.9 6690158.7 47.8, 354753.8 6690160.9 47.8, 354758.9 6690166.9 47.8, 354769 6690159.1 47.8))
BATIMENT0000000302934756;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;20;20;6.8;34.6;41.5;47.5;35.2;Cadastre;B 0.6;POLYGON Z ((354720.5 6690168.7 41.5, 354731.2 6690163.4 41.5, 354730.3 6690161.5 41.5, 354727.9 6690156.8 41.5, 354717.2 6690162.4 41.5, 354720.5 6690168.7 41.5))
BATIMENT0000000302934765;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;2.8;35.0;37.8;38.5;35.1;Cadastre;A 1.0;POLYGON Z ((354777.9 6690164.8 37.8, 354780.3 6690167.9 37.8, 354785.6 6690163.6 37.8, 354783.3 6690160.3 37.8, 354777.9 6690164.8 37.8))
BATIMENT0000000302934737;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;00;00;7.5;34.8;42.3;46.5;35.3;Cadastre;A 1.0;POLYGON Z ((354735.8 6690171.8 42.3, 354740.8 6690180.9 42.3, 354750.6 6690173.2 42.3, 354745.9 6690167.3 42.3, 354744.3 6690165.6 42.3, 354735.8 6690171.8 42.3))
BATIMENT0000000302934749;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;20;20;7.4;34.7;42.1;45.0;35.2;Cadastre;B 1.0;POLYGON Z ((354727.2 6690175.9 42.1, 354724.9 6690177.1 42.1, 354727.1 6690181.5 42.1, 354737.5 6690183.7 42.1, 354740.8 6690180.9 42.1, 354735.8 6690171.8 42.1, 354727.2 6690175.9 42.1))
BATIMENT0000000302934766;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;;;9.1;35.3;44.4;50.3;35.8;Cadastre;A 1.0;POLYGON Z ((354765.1 6690192.5 44.4, 354765.3 6690192.8 44.4, 354756.8 6690199.5 44.4, 354758.5 6690201.5 44.4, 354757.9 6690202.1 44.4, 354758.8 6690203.6 44.4, 354759.7 6690202.9 44.4, 354764 6690208.1 44.4, 354772.6 6690201.5 44.4, 354772.9 6690201.7 44.4, 354778.8 6690197.1 44.4, 354780.8 6690195.6 44.4, 354780.6 6690195.4 44.4, 354789.2 6690188.7 44.4, 354782 6690179.5 44.4, 354773.3 6690186.4 44.4, 354773 6690186.1 44.4, 354765.1 6690192.5 44.4))
BATIMENT0000000302934830;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;30;10.2;32.0;42.2;42.9;32.6;Cadastre;A 1.0;POLYGON Z ((354418 6690097.1 42.2, 354425.9 6690096.2 42.2, 354425.5 6690089 42.2, 354417.9 6690089.4 42.2, 354418 6690097.1 42.2))
BATIMENT0000000302934817;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;32.7;41.0;42.9;33.3;Cadastre;;POLYGON Z ((354468.6 6690092 41, 354464.3 6690092.4 41, 354464.6 6690098.6 41, 354469 6690098.3 41, 354468.6 6690092 41))
BATIMENT0000000302934816;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;40;10;5.8;32.0;37.8;41.8;33.5;Cadastre;A 1.0;POLYGON Z ((354459.5 6690098 37.8, 354448.7 6690098.7 37.8, 354449 6690102.9 37.8, 354458.3 6690102.5 37.8, 354458.6 6690104.3 37.8, 354460.1 6690104.3 37.8, 354464.8 6690104.1 37.8, 354464.8 6690101 37.8, 354464.6 6690098.6 37.8, 354464.3 6690092.4 37.8, 354459.3 6690092.8 37.8, 354459.5 6690098 37.8))
BATIMENT0000000302934824;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.2;32.9;36.1;38.5;33.2;Cadastre;;POLYGON Z ((354464.9 6690104.9 36.1, 354467.9 6690104.9 36.1, 354467.6 6690101 36.1, 354464.8 6690101 36.1, 354464.8 6690104.1 36.1, 354464.9 6690104.9 36.1))
BATIMENT0000000302934986;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;7.4;32.0;39.4;41.5;32.4;Cadastre;A 1.0;POLYGON Z ((354399.7 6690097.4 39.4, 354404.8 6690111.2 39.4, 354410.5 6690109.1 39.4, 354406.2 6690097.3 39.4, 354401.7 6690097.4 39.4, 354399.7 6690097.4 39.4))
BATIMENT0000000302934823;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.9;32.9;34.8;36.0;33.1;Cadastre;;POLYGON Z ((354465.1 6690109 34.8, 354468 6690108.8 34.8, 354467.9 6690104.9 34.8, 354464.9 6690104.9 34.8, 354465.1 6690109 34.8))
BATIMENT0000000302935068;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;7.3;32.0;39.3;43.2;32.8;Cadastre;A 1.0;POLYGON Z ((354432.7 6690109.9 39.3, 354428.9 6690100.5 39.3, 354425.8 6690100.8 39.3, 354418.6 6690103.3 39.3, 354423.4 6690115.9 39.3, 354427.5 6690114.3 39.3, 354426.5 6690111.2 39.3, 354428.9 6690110.5 39.3, 354431.9 6690110.1 39.3, 354432.7 6690109.9 39.3))
BATIMENT0000000302934825;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;02;02;3.5;32.4;36.0;38.0;33.2;Cadastre;A 0.2;POLYGON Z ((354465.3 6690112.2 36, 354468 6690112 36, 354468 6690108.8 36, 354465.1 6690109 36, 354465.3 6690112.2 36))
BATIMENT0000000302935234;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.4;32.0;38.4;41.5;33.2;Cadastre;A 1.0;POLYGON Z ((354463.2 6690115 38.4, 354462.8 6690110.4 38.4, 354446.3 6690111.2 38.4, 354446.5 6690116 38.4, 354451.2 6690115.7 38.4, 354463.2 6690115 38.4))
BATIMENT0000000302934987;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1868-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.3;32.0;39.3;42.4;32.4;Cadastre;A 1.0;POLYGON Z ((354408.8 6690121 39.3, 354416.2 6690118.1 39.3, 354412.6 6690108.3 39.3, 354410.5 6690109.1 39.3, 354404.8 6690111.2 39.3, 354408.8 6690121 39.3))
BATIMENT0000000302935037;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;12;20;13.5;30.2;43.7;49.1;31.6;Cadastre;A 1.0;POLYGON Z ((354343.6 6690087.4 43.7, 354348 6690088 43.7, 354353.6 6690092.4 43.7, 354355 6690091 43.7, 354340 6690074.5 43.7, 354333.1 6690080.9 43.7, 354331.5 6690091.5 43.7, 354342.5 6690093.2 43.7, 354343.6 6690087.4 43.7))
BATIMENT0000000302934983;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.9;31.8;38.7;40.1;32.4;Cadastre;A 1.0;POLYGON Z ((354397.6 6690088.3 38.7, 354401.8 6690088.3 38.7, 354409.9 6690088.1 38.7, 354409.8 6690083.7 38.7, 354403.6 6690083.9 38.7, 354403.5 6690080.8 38.7, 354397.6 6690080.8 38.7, 354397.6 6690088.3 38.7))
BATIMENT0000000302934984;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;32.1;37.0;39.5;32.4;Cadastre;;POLYGON Z ((354397.6 6690080.8 37, 354394.5 6690080.8 37, 354394.7 6690088.4 37, 354397.6 6690088.3 37, 354397.6 6690080.8 37))
BATIMENT0000000302935322;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.3;31.5;35.9;37.0;32.4;Cadastre;;POLYGON Z ((354383.9 6690088.4 35.9, 354386.6 6690088.5 35.9, 354386.5 6690081 35.9, 354383.9 6690081 35.9, 354383.9 6690088.4 35.9))
BATIMENT0000000302935340;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.6;30.9;34.5;34.8;31.5;Cadastre;;POLYGON Z ((354352.6 6690116.8 34.5, 354354.8 6690117 34.5, 354359.1 6690115.8 34.5, 354359.9 6690109.4 34.5, 354353.4 6690108.3 34.5, 354352.6 6690116.8 34.5))
BATIMENT0000000302935182;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.6;31.2;32.8;34.5;31.5;Cadastre;;POLYGON Z ((354379.2 6690130.3 32.8, 354377.6 6690124.4 32.8, 354375.2 6690125.2 32.8, 354376.9 6690131.1 32.8, 354378 6690130.9 32.8, 354379.2 6690130.3 32.8))
BATIMENT0000000302935337;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.5;30.7;35.2;36.5;31.2;Cadastre;;POLYGON Z ((354358.9 6690128.8 35.2, 354362.9 6690133 35.2, 354364.6 6690127.1 35.2, 354358.9 6690128.8 35.2))
BATIMENT0000000302935181;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.5;30.7;39.2;41.4;31.6;Cadastre;A 1.0;POLYGON Z ((354377.3 6690133.2 39.2, 354380.8 6690141.1 39.2, 354386 6690138.8 39.2, 354382.7 6690131.1 39.2, 354378.7 6690132.8 39.2, 354378 6690130.9 39.2, 354376.9 6690131.1 39.2, 354377.3 6690133.2 39.2))
BATIMENT0000000302935043;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;32;32;5.4;30.9;36.3;;;Cadastre;B 0.7;POLYGON Z ((354345.1 6690132.9 36.3, 354344 6690138.7 36.3, 354339.7 6690138.3 36.3, 354339.3 6690142.7 36.3, 354346.8 6690143.7 36.3, 354348.6 6690131.9 36.3, 354345.1 6690132.9 36.3))
BATIMENT0000000302935180;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;30.7;38.9;41.6;31.3;Cadastre;A 1.0;POLYGON Z ((354371.9 6690135.8 38.9, 354375.1 6690143.7 38.9, 354380.8 6690141.1 38.9, 354377.3 6690133.2 38.9, 354371.9 6690135.8 38.9))
BATIMENT0000000302934826;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.6;32.9;38.5;;;Cadastre;A 1.0;POLYGON Z ((354489.6 6690110.5 38.5, 354481.1 6690114.1 38.5, 354483.7 6690120.4 38.5, 354479.2 6690122.2 38.5, 354481.1 6690126.5 38.5, 354484.9 6690125.1 38.5, 354487.7 6690123.9 38.5, 354494.4 6690121.3 38.5, 354489.6 6690110.5 38.5))
BATIMENT0000000302935345;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.3;32.0;35.4;36.0;32.8;Cadastre;;POLYGON Z ((354537.3 6690118.2 35.4, 354535.7 6690115 35.4, 354533.6 6690115.9 35.4, 354524.3 6690119.9 35.4, 354525.6 6690123.1 35.4, 354537.3 6690118.2 35.4))
BATIMENT0000000302934959;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.7;31.9;38.7;41.6;32.3;Cadastre;C 0.8;POLYGON Z ((354507.7 6690127.2 38.7, 354515.9 6690123.8 38.7, 354519.2 6690122.5 38.7, 354518.6 6690121 38.7, 354515.2 6690122.3 38.7, 354513.2 6690117.7 38.7, 354514.4 6690117.2 38.7, 354514 6690115.8 38.7, 354512.9 6690116.4 38.7, 354504.6 6690119.9 38.7, 354507.7 6690127.2 38.7))
BATIMENT0000000302935344;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.5;32.0;33.5;36.3;32.3;Cadastre;;POLYGON Z ((354524.3 6690119.9 33.5, 354521.5 6690121 33.5, 354521.5 6690121.1 33.5, 354522.9 6690124.3 33.5, 354525.6 6690123.1 33.5, 354524.3 6690119.9 33.5))
BATIMENT0000000302934675;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;10;20;6.2;33.2;39.4;;;Cadastre;A 1.0;POLYGON Z ((354540.7 6690123.4 39.4, 354539.4 6690120.6 39.4, 354534.7 6690122.6 39.4, 354538.4 6690131.6 39.4, 354543.3 6690129.6 39.4, 354540.7 6690123.4 39.4))
BATIMENT0000000302934960;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.6;32.0;39.6;42.1;32.3;Cadastre;A 1.0;POLYGON Z ((354510.7 6690134.5 39.6, 354518.8 6690131.1 39.6, 354518 6690129 39.6, 354515.5 6690130.1 39.6, 354514.7 6690128.2 39.6, 354517.1 6690127.2 39.6, 354515.9 6690123.8 39.6, 354507.7 6690127.2 39.6, 354510.7 6690134.5 39.6))
BATIMENT0000000302934831;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.2;31.7;39.0;42.4;32.2;Cadastre;A 1.0;POLYGON Z ((354487.7 6690123.9 39, 354484.9 6690125.1 39, 354486.5 6690129.3 39, 354486 6690129.6 39, 354490.2 6690140.2 39, 354491.6 6690139.7 39, 354500.3 6690135.9 39, 354494.4 6690121.3 39, 354487.7 6690123.9 39))
BATIMENT0000000302934961;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;10;3.9;33.0;36.9;;;Cadastre;A 1.0;POLYGON Z ((354510.7 6690134.5 36.9, 354513.9 6690141.8 36.9, 354528.7 6690135.7 36.9, 354526.6 6690130.6 36.9, 354524.4 6690131.5 36.9, 354524.9 6690135.1 36.9, 354523.9 6690135.6 36.9, 354523.3 6690134.5 36.9, 354521.7 6690135 36.9, 354519.9 6690130.7 36.9, 354518.8 6690131.1 36.9, 354510.7 6690134.5 36.9))
BATIMENT0000000302934682;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.3;33.0;35.3;;;Cadastre;;POLYGON Z ((354539.9 6690135 35.3, 354541.9 6690139.6 35.3, 354546.7 6690137.7 35.3, 354545 6690133 35.3, 354539.9 6690135 35.3))
BATIMENT0000000302934680;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;33.0;36.0;;;Cadastre;;POLYGON Z ((354533.7 6690137.3 36, 354534.5 6690138.7 36, 354535.7 6690142 36, 354541.9 6690139.6 36, 354539.9 6690135 36, 354533.7 6690137.3 36))
BATIMENT0000000302935338;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.7;32.4;37.2;41.0;33.2;Cadastre;;POLYGON Z ((354464.4 6690114.5 37.2, 354464.5 6690114.9 37.2, 354464.7 6690119.5 37.2, 354467.5 6690118.5 37.2, 354467.2 6690114.4 37.2, 354464.4 6690114.5 37.2))
BATIMENT0000000302935067;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;45;20;6.5;32.0;38.5;41.9;32.6;Cadastre;A 1.0;POLYGON Z ((354426.8 6690124.7 38.5, 354432.7 6690122.3 38.5, 354434.6 6690121.6 38.5, 354431.3 6690112.8 38.5, 354432.8 6690112.2 38.5, 354431.9 6690110.1 38.5, 354428.9 6690110.5 38.5, 354426.5 6690111.2 38.5, 354427.5 6690114.3 38.5, 354423.4 6690115.9 38.5, 354426.8 6690124.7 38.5))
BATIMENT0000000302935233;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;32.3;36.3;38.5;32.9;Cadastre;;POLYGON Z ((354446.5 6690116.6 36.3, 354446.7 6690120.2 36.3, 354451.4 6690120.2 36.3, 354451.2 6690115.7 36.3, 354446.5 6690116 36.3, 354446.5 6690116.6 36.3))
BATIMENT0000000302935066;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;6.8;32.0;38.8;41.2;32.6;Cadastre;A 1.0;POLYGON Z ((354430.3 6690133.7 38.8, 354431.2 6690133.4 38.8, 354441.9 6690129.4 38.8, 354446.1 6690128 38.8, 354445.8 6690123.6 38.8, 354440 6690124.1 38.8, 354434.2 6690126.3 38.8, 354432.7 6690122.3 38.8, 354426.8 6690124.7 38.8, 354430.3 6690133.7 38.8))
BATIMENT0000000302934989;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.9;32.0;41.0;42.4;32.4;Cadastre;A 1.0;POLYGON Z ((354414.1 6690134 41, 354421.3 6690131 41, 354417.9 6690122.4 41, 354410.8 6690125.1 41, 354414.1 6690134 41))
BATIMENT0000000302935065;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;59;23;6.9;32.0;38.9;40.9;32.6;Cadastre;A 1.0;POLYGON Z ((354433 6690138 38.9, 354434.9 6690137.4 38.9, 354440.7 6690135 38.9, 354440.2 6690134 38.9, 354439.9 6690133.2 38.9, 354442.8 6690132.2 38.9, 354441.9 6690129.4 38.9, 354431.2 6690133.4 38.9, 354433 6690138 38.9))
BATIMENT0000000302934990;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;26;29;7.3;31.4;38.7;40.7;32.3;Cadastre;A 0.8;POLYGON Z ((354412.3 6690134.8 38.7, 354415.3 6690141.7 38.7, 354416.3 6690141.3 38.7, 354418.1 6690145.4 38.7, 354418.4 6690145.3 38.7, 354419.9 6690144.7 38.7, 354421.9 6690143.9 38.7, 354425.7 6690142.4 38.7, 354421.3 6690131 38.7, 354414.1 6690134 38.7, 354412.3 6690134.8 38.7))
BATIMENT0000000302935064;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;20;7.4;32.0;39.4;42.5;32.6;Cadastre;A 1.0;POLYGON Z ((354438.6 6690147.4 39.4, 354443.7 6690145.6 39.4, 354445.5 6690144.9 39.4, 354441.7 6690134.9 39.4, 354440.7 6690135 39.4, 354434.9 6690137.4 39.4, 354438.6 6690147.4 39.4))
BATIMENT0000000302934991;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;32.0;38.5;38.7;32.3;Cadastre;;POLYGON Z ((354417.1 6690145.8 38.5, 354417.3 6690145.7 38.5, 354418.1 6690145.4 38.5, 354416.3 6690141.3 38.5, 354415.3 6690141.7 38.5, 354417.1 6690145.8 38.5))
BATIMENT0000000302935170;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;04;02;2.8;32.5;35.3;38.5;32.9;Cadastre;A 0.4;POLYGON Z ((354463.1 6690160.6 35.3, 354465.5 6690159.2 35.3, 354466 6690149.7 35.3, 354465.6 6690137.1 35.3, 354458.8 6690139.5 35.3, 354460.7 6690151.8 35.3, 354463.6 6690150.5 35.3, 354463.1 6690160.6 35.3))
BATIMENT0000000302935044;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.8;30.9;36.7;;;Cadastre;A 1.0;POLYGON Z ((354353.1 6690149 36.7, 354356.3 6690145.8 36.7, 354351 6690140.6 36.7, 354351.8 6690132.5 36.7, 354352.7 6690132.5 36.7, 354353.1 6690130.5 36.7, 354348.6 6690131.9 36.7, 354346.8 6690143.7 36.7, 354353.1 6690149 36.7))
BATIMENT0000000302935139;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.1;31.7;34.9;37.2;32.2;Cadastre;A 0.4;POLYGON Z ((354399.6 6690140.3 34.9, 354400.2 6690141 34.9, 354401.6 6690143.1 34.9, 354403.5 6690142.4 34.9, 354402.9 6690140.8 34.9, 354406.4 6690139.5 34.9, 354405.8 6690137.9 34.9, 354399.6 6690140.3 34.9))
BATIMENT0000000302935140;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;8.5;31.1;39.6;41.7;32.2;Cadastre;A 1.0;POLYGON Z ((354399.2 6690146.5 39.6, 354402.7 6690144.5 39.6, 354401.6 6690143.1 39.6, 354400.2 6690141 39.6, 354398 6690141.9 39.6, 354397.4 6690140.8 39.6, 354389.4 6690144.4 39.6, 354389.5 6690144.8 39.6, 354391.6 6690150.1 39.6, 354399.2 6690146.5 39.6))
BATIMENT0000000302935045;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.4;30.9;37.3;;;Cadastre;A 1.0;POLYGON Z ((354357.6 6690152.9 37.3, 354362.9 6690147.6 37.3, 354364.3 6690145.9 37.3, 354361.2 6690143.2 37.3, 354361.8 6690141.7 37.3, 354360.7 6690140.6 37.3, 354360.3 6690141.6 37.3, 354356.3 6690145.8 37.3, 354353.1 6690149 37.3, 354357.6 6690152.9 37.3))
BATIMENT0000000302935141;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;31.5;35.1;38.7;32.1;Cadastre;;POLYGON Z ((354401.8 6690150.6 35.1, 354405.5 6690148.9 35.1, 354402.7 6690144.5 35.1, 354399.2 6690146.5 35.1, 354401.8 6690150.6 35.1))
BATIMENT0000000302935142;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.7;31.0;39.7;42.4;31.6;Cadastre;A 1.0;POLYGON Z ((354387.1 6690145.9 39.7, 354389.7 6690151.2 39.7, 354387.4 6690152.2 39.7, 354385.1 6690146.8 39.7, 354377.2 6690150.2 39.7, 354380.4 6690157.7 39.7, 354380.7 6690158.1 39.7, 354388.6 6690154.8 39.7, 354390 6690155.8 39.7, 354391.3 6690155.5 39.7, 354391.5 6690154 39.7, 354390.1 6690151 39.7, 354391.6 6690150.1 39.7, 354389.5 6690144.8 39.7, 354387.1 6690145.9 39.7))
BATIMENT0000000302935143;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;20;20;11.3;30.0;41.3;44.6;31.2;Cadastre;A 1.0;POLYGON Z ((354374.1 6690151.4 41.3, 354369.5 6690152.9 41.3, 354368.2 6690154.5 41.3, 354368.4 6690155.2 41.3, 354358.8 6690157.9 41.3, 354360.6 6690164 41.3, 354368.7 6690161.8 41.3, 354368.4 6690160.6 41.3, 354370 6690160.1 41.3, 354370.3 6690161.3 41.3, 354375.7 6690159.9 41.3, 354376.5 6690159.6 41.3, 354380.4 6690157.7 41.3, 354377.2 6690150.2 41.3, 354374.1 6690151.4 41.3))
BATIMENT0000000302935118;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;10.5;30.1;40.6;41.9;30.4;Cadastre;A 1.0;POLYGON Z ((354344.9 6690163.8 40.6, 354345.4 6690165 40.6, 354351 6690163.8 40.6, 354349.6 6690158.9 40.6, 354343.6 6690153.3 40.6, 354342.9 6690157.9 40.6, 354342.1 6690163.4 40.6, 354344.9 6690163.8 40.6))
BATIMENT0000000302935119;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;30.0;34.0;39.7;30.4;Cadastre;;POLYGON Z ((354339.2 6690157.6 34, 354338.3 6690162.9 34, 354342.1 6690163.4 34, 354342.9 6690157.9 34, 354339.2 6690157.6 34))
BATIMENT0000000302935144;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.1;29.9;39.0;41.7;30.9;Cadastre;A 1.0;POLYGON Z ((354362.4 6690170.3 39, 354370.9 6690168 39, 354369.1 6690161.7 39, 354368.7 6690161.8 39, 354360.6 6690164 39, 354362.4 6690170.3 39))
BATIMENT0000000302934832;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;7.5;31.9;39.5;41.7;32.2;Cadastre;C 0.7;POLYGON Z ((354494.9 6690147.8 39.5, 354503.8 6690144.2 39.5, 354500.3 6690135.9 39.5, 354491.6 6690139.7 39.5, 354494.9 6690147.8 39.5))
BATIMENT0000000302934670;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;12;3.6;33.0;36.6;;;Cadastre;A 1.0;POLYGON Z ((354525.2 6690142.2 36.6, 354529.3 6690152.3 36.6, 354530.4 6690155.2 36.6, 354531.9 6690154.8 36.6, 354532.6 6690154.6 36.6, 354531.3 6690150.4 36.6, 354530.4 6690150.7 36.6, 354530.1 6690149.6 36.6, 354537.6 6690146.6 36.6, 354536.5 6690143.9 36.6, 354535.7 6690142 36.6, 354534.5 6690138.7 36.6, 354525.2 6690142.2 36.6))
BATIMENT0000000302934679;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.1;31.8;38.9;42.1;32.3;Cadastre;A 1.0;POLYGON Z ((354515 6690144.9 38.9, 354519.7 6690156.2 38.9, 354529.3 6690152.3 38.9, 354525.2 6690142.2 38.9, 354524.6 6690140.9 38.9, 354515 6690144.9 38.9))
BATIMENT0000000302934833;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.8;31.9;38.7;41.6;32.3;Cadastre;A 1.0;POLYGON Z ((354497.5 6690153.6 38.7, 354506.3 6690150.2 38.7, 354503.8 6690144.2 38.7, 354494.9 6690147.8 38.7, 354497.5 6690153.6 38.7))
BATIMENT0000000302934658;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.9;31.9;38.8;42.6;32.4;Cadastre;A 1.0;POLYGON Z ((354549.6 6690159.2 38.8, 354546 6690149.6 38.8, 354545.5 6690149.8 38.8, 354545 6690148.4 38.8, 354544.8 6690147.7 38.8, 354544.6 6690147.2 38.8, 354544.5 6690146.9 38.8, 354538.5 6690149.1 38.8, 354539.2 6690150.9 38.8, 354539.6 6690151.9 38.8, 354541.6 6690151.2 38.8, 354545.1 6690160.8 38.8, 354549.6 6690159.2 38.8))
BATIMENT0000000302934834;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1945-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;4.6;32.9;37.5;;;Cadastre;A 1.0;POLYGON Z ((354496.5 6690161.6 37.5, 354499 6690160.6 37.5, 354501.1 6690159.8 37.5, 354509 6690156.6 37.5, 354506.3 6690150.2 37.5, 354497.5 6690153.6 37.5, 354493.9 6690155 37.5, 354496.5 6690161.6 37.5))
BATIMENT0000000302934661;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;20;6.3;32.3;38.6;41.1;32.4;Cadastre;A 1.0;POLYGON Z ((354539.6 6690151.9 38.6, 354537.8 6690152.7 38.6, 354538.7 6690155.8 38.6, 354533 6690158 38.6, 354532.6 6690156.9 38.6, 354531.9 6690154.8 38.6, 354530.4 6690155.2 38.6, 354534.1 6690165.1 38.6, 354545.1 6690160.8 38.6, 354541.6 6690151.2 38.6, 354539.6 6690151.9 38.6))
BATIMENT0000000302934836;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1891-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;31.8;41.2;43.3;32.2;Cadastre;A 1.0;POLYGON Z ((354502.9 6690164.2 41.2, 354506.4 6690162.9 41.2, 354506.3 6690162.2 41.2, 354510.6 6690160.6 41.2, 354509 6690156.6 41.2, 354501.1 6690159.8 41.2, 354502.9 6690164.2 41.2))
BATIMENT0000000302934666;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;12;20;6.8;31.8;38.6;42.4;32.4;Cadastre;A 1.0;POLYGON Z ((354525.1 6690168.8 38.6, 354529.5 6690166.7 38.6, 354534.1 6690165.1 38.6, 354530.4 6690155.2 38.6, 354529.3 6690152.3 38.6, 354519.7 6690156.2 38.6, 354525.1 6690168.8 38.6))
BATIMENT0000000302934835;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;31.9;35.1;35.7;32.3;Cadastre;;POLYGON Z ((354496.5 6690161.6 35.1, 354497.7 6690164.6 35.1, 354500.2 6690163.6 35.1, 354499 6690160.6 35.1, 354496.5 6690161.6 35.1))
BATIMENT0000000302934992;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.7;31.8;39.6;42.1;32.3;Cadastre;A 1.0;POLYGON Z ((354418 6690156.1 39.6, 354420.8 6690155.1 39.6, 354425.1 6690153 39.6, 354429.2 6690151.5 39.6, 354425.7 6690142.4 39.6, 354421.9 6690143.9 39.6, 354419.9 6690144.7 39.6, 354418.4 6690145.3 39.6, 354418.1 6690145.4 39.6, 354417.3 6690145.7 39.6, 354417.1 6690145.8 39.6, 354416.9 6690145.9 39.6, 354418.2 6690149.1 39.6, 354415.7 6690150.1 39.6, 354418 6690156.1 39.6))
BATIMENT0000000302935168;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;3.2;32.5;35.7;38.4;32.9;Cadastre;C 0.3;POLYGON Z ((354470.8 6690156 35.7, 354471.3 6690157.3 35.7, 354474.3 6690156 35.7, 354476.5 6690155 35.7, 354473.1 6690146.8 35.7, 354466 6690149.7 35.7, 354465.5 6690159.2 35.7, 354470.8 6690156 35.7))
BATIMENT0000000302935063;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.2;32.0;38.2;41.4;32.4;Cadastre;A 0.9;POLYGON Z ((354435.8 6690148.5 38.2, 354440.8 6690161.5 38.2, 354447.8 6690158.3 38.2, 354449 6690157.8 38.2, 354446.1 6690150.8 38.2, 354445.5 6690151 38.2, 354443.7 6690145.6 38.2, 354438.6 6690147.4 38.2, 354435.8 6690148.5 38.2))
BATIMENT0000000302935171;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;32.4;35.9;37.1;32.9;Cadastre;;POLYGON Z ((354473.6 6690163.1 35.9, 354476.1 6690162 35.9, 354476.6 6690161.7 35.9, 354474.3 6690156 35.9, 354471.3 6690157.3 35.9, 354473.6 6690163.1 35.9))
BATIMENT0000000302934993;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;5.9;31.6;37.5;41.9;32.3;Cadastre;A 1.0;POLYGON Z ((354425.1 6690153 37.5, 354420.8 6690155.1 37.5, 354423.9 6690162.9 37.5, 354425.9 6690162.2 37.5, 354428.9 6690170.3 37.5, 354435.4 6690167.8 37.5, 354429.2 6690151.5 37.5, 354425.1 6690153 37.5))
BATIMENT0000000302935062;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.9;31.8;38.7;42.1;32.8;Cadastre;A 1.0;POLYGON Z ((354444.9 6690171.7 38.7, 354451.6 6690167.8 38.7, 354447.8 6690158.3 38.7, 354440.8 6690161.5 38.7, 354444.9 6690171.7 38.7))
BATIMENT0000000302935339;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.9;31.6;35.5;36.7;32.4;Cadastre;;POLYGON Z ((354416.9 6690168.2 35.5, 354422.6 6690176.7 35.5, 354424.3 6690175.4 35.5, 354422.2 6690172.4 35.5, 354418.5 6690166.9 35.5, 354416.9 6690168.2 35.5))
BATIMENT0000000302935059;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;31.8;41.2;43.2;33.1;Cadastre;A 1.0;POLYGON Z ((354447.5 6690178.6 41.2, 354455.4 6690175.3 41.2, 354452.4 6690167.3 41.2, 354451.6 6690167.8 41.2, 354444.9 6690171.7 41.2, 354447.5 6690178.6 41.2))
BATIMENT0000000302934994;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.0;31.4;37.4;39.4;32.4;Cadastre;A 1.0;POLYGON Z ((354428 6690170.6 37.4, 354430.2 6690175.9 37.4, 354429.2 6690176.2 37.4, 354430.6 6690180.4 37.4, 354439 6690177.3 37.4, 354435.4 6690167.8 37.4, 354428.9 6690170.3 37.4, 354428 6690170.6 37.4))
BATIMENT0000000302935060;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.5;31.7;42.2;44.4;33.1;Cadastre;;POLYGON Z ((354447.5 6690178.6 42.2, 354448.1 6690180.2 42.2, 354456.1 6690177.1 42.2, 354455.6 6690175.9 42.2, 354455.4 6690175.3 42.2, 354447.5 6690178.6 42.2))
BATIMENT0000000302935117;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;30.1;34.7;38.7;30.4;Cadastre;;POLYGON Z ((354346.4 6690168.6 34.7, 354348.2 6690170.1 34.7, 354348.4 6690171.2 34.7, 354352.9 6690170 34.7, 354351 6690163.8 34.7, 354345.4 6690165 34.7, 354346.4 6690168.6 34.7))
BATIMENT0000000302935145;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;9.0;30.0;39.0;41.2;30.9;Cadastre;A 1.0;POLYGON Z ((354363.9 6690175.5 39, 354375.6 6690172.1 39, 354374.9 6690170.2 39, 354371.8 6690171.2 39, 354370.9 6690168 39, 354362.4 6690170.3 39, 354363.9 6690175.5 39))
BATIMENT0000000302935107;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;04;4.7;29.9;34.6;38.0;30.3;Cadastre;C 0.3;POLYGON Z ((354344.1 6690175.8 34.6, 354345.4 6690175.4 34.6, 354353.7 6690173.1 34.6, 354352.9 6690170 34.6, 354348.4 6690171.2 34.6, 354346.8 6690171.6 34.6, 354343.2 6690172.6 34.6, 354344.1 6690175.8 34.6))
BATIMENT0000000302935146;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;30.0;38.2;40.9;30.9;Cadastre;A 1.0;POLYGON Z ((354366.5 6690184.5 38.2, 354378.5 6690181.1 38.2, 354379 6690180.9 38.2, 354376.7 6690171.8 38.2, 354375.6 6690172.1 38.2, 354363.9 6690175.5 38.2, 354366.5 6690184.5 38.2))
BATIMENT0000000302935105;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;30;20;7.8;30.1;38.0;40.6;30.3;Cadastre;A 1.0;POLYGON Z ((354351 6690187.2 38, 354357.2 6690185.3 38, 354353.7 6690173.1 38, 354345.4 6690175.4 38, 354347.4 6690182.6 38, 354344.2 6690183.6 38, 354345.8 6690188.8 38, 354351 6690187.2 38))
BATIMENT0000000302935049;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;31.0;34.4;37.2;31.8;Cadastre;;POLYGON Z ((354399.2 6690182.1 34.4, 354400.4 6690185 34.4, 354405.8 6690183.4 34.4, 354404.5 6690180.4 34.4, 354399.2 6690182.1 34.4))
BATIMENT0000000302935147;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;6.0;30.0;36.0;40.8;30.8;Cadastre;A 1.0;POLYGON Z ((354369.3 6690194.2 36, 354379 6690191.2 36, 354377.8 6690186.2 36, 354379.6 6690185.7 36, 354378.5 6690181.1 36, 354366.5 6690184.5 36, 354369.3 6690194.2 36))
BATIMENT0000000302935341;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;01;02;4.3;29.8;34.1;34.5;30.1;Cadastre;C 0.3;POLYGON Z ((354339.5 6690189 34.1, 354339.4 6690189 34.1, 354339.2 6690189.1 34.1, 354338.8 6690189.2 34.1, 354338.7 6690189.3 34.1, 354338.4 6690189.5 34.1, 354338.2 6690189.7 34.1, 354338.1 6690189.9 34.1, 354338 6690190 34.1, 354337.9 6690190.2 34.1, 354337.9 6690190.3 34.1, 354337.8 6690190.7 34.1, 354337.8 6690190.8 34.1, 354337.8 6690191 34.1, 354337.8 6690191.2 34.1, 354337.8 6690191.3 34.1, 354337.9 6690191.5 34.1, 354337.9 6690191.6 34.1, 354338 6690191.8 34.1, 354341.1 6690192.2 34.1, 354341.4 6690189.8 34.1, 354341.3 6690189.7 34.1, 354341.1 6690189.6 34.1, 354341 6690189.4 34.1, 354340.7 6690189.2 34.1, 354340.3 6690189.1 34.1, 354339.9 6690189 34.1, 354339.7 6690189 34.1, 354339.5 6690189 34.1))
BATIMENT0000000302935148;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;30.0;35.8;37.0;30.9;Cadastre;;POLYGON Z ((354385.2 6690195.5 35.8, 354383.3 6690190 35.8, 354379.7 6690191.1 35.8, 354381.5 6690196.6 35.8, 354385.2 6690195.5 35.8))
BATIMENT0000000302935149;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;30.1;40.2;42.7;30.7;Cadastre;A 1.0;POLYGON Z ((354370.9 6690199.7 40.2, 354381.5 6690196.6 40.2, 354379.7 6690191.1 40.2, 354379 6690191.2 40.2, 354369.3 6690194.2 40.2, 354370.9 6690199.7 40.2))
BATIMENT0000000302935058;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.4;31.7;36.2;44.3;33.1;Cadastre;A 1.0;POLYGON Z ((354460.1 6690173.6 36.2, 354455.6 6690175.9 36.2, 354456.1 6690177.1 36.2, 354448.1 6690180.2 36.2, 354450.7 6690186.8 36.2, 354458.7 6690183.6 36.2, 354459.9 6690183.1 36.2, 354463.3 6690181.7 36.2, 354460.1 6690173.6 36.2))
BATIMENT0000000302934988;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;04;01;3.8;31.7;35.5;37.2;32.5;Cadastre;C 0.5;POLYGON Z ((354430.6 6690180.4 35.5, 354428.9 6690181 35.5, 354431.3 6690184.4 35.5, 354440.4 6690180.9 35.5, 354439 6690177.3 35.5, 354430.6 6690180.4 35.5))
BATIMENT0000000302935050;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;10;4.9;31.0;35.9;38.3;32.0;Cadastre;C 0.3;POLYGON Z ((354424.3 6690185.6 35.9, 354419.9 6690178.8 35.9, 354415.6 6690176.8 35.9, 354411.3 6690178.5 35.9, 354409.9 6690182.9 35.9, 354406.2 6690184.2 35.9, 354408.4 6690188.7 35.9, 354410.8 6690194 35.9, 354411.2 6690195.2 35.9, 354412.7 6690194.7 35.9, 354412 6690192.8 35.9, 354418.6 6690190.3 35.9, 354417.9 6690188.3 35.9, 354417.3 6690187.1 35.9, 354420.3 6690185.9 35.9, 354421.5 6690186.8 35.9, 354424.3 6690185.6 35.9))
BATIMENT0000000302935051;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;31.0;35.9;37.5;31.7;Cadastre;;POLYGON Z ((354421.5 6690186.8 35.9, 354420.3 6690185.9 35.9, 354417.3 6690187.1 35.9, 354417.9 6690188.3 35.9, 354421.5 6690186.8 35.9))
BATIMENT0000000302935061;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.2;31.9;39.1;41.9;32.4;Cadastre;C 0.9;POLYGON Z ((354456.6 6690202.6 39.1, 354464.5 6690198.8 39.1, 354460.2 6690187.8 39.1, 354461.4 6690187.4 39.1, 354459.9 6690183.1 39.1, 354458.7 6690183.6 39.1, 354450.7 6690186.8 39.1, 354456.6 6690202.6 39.1))
BATIMENT0000000302934858;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;5.6;31.4;37.0;41.4;32.0;Cadastre;C 0.7;POLYGON Z ((354445.6 6690194.3 37, 354444.4 6690191.1 37, 354436.2 6690194.2 37, 354437.3 6690197.2 37, 354440 6690204.3 37, 354448.1 6690200.7 37, 354445.6 6690194.3 37))
BATIMENT0000000302934859;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;10;4.1;31.3;35.4;39.4;31.5;Cadastre;A 1.0;POLYGON Z ((354449.8 6690205 35.4, 354448.1 6690200.7 35.4, 354440 6690204.3 35.4, 354441.8 6690208.9 35.4, 354449.8 6690205 35.4))
BATIMENT0000000302934855;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.9;30.8;38.7;42.1;31.8;Cadastre;A 1.0;POLYGON Z ((354434.7 6690212.2 38.7, 354441.8 6690208.9 38.7, 354440 6690204.3 38.7, 354437.3 6690197.2 38.7, 354430.4 6690199.9 38.7, 354431.6 6690203.4 38.7, 354428.6 6690204.6 38.7, 354429.5 6690207 38.7, 354431.9 6690213.6 38.7, 354434.7 6690212.2 38.7))
BATIMENT0000000302934853;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;30.6;34.9;36.5;31.7;Cadastre;;POLYGON Z ((354429.5 6690207 34.9, 354425 6690209 34.9, 354428.3 6690216.9 34.9, 354431.9 6690213.6 34.9, 354429.5 6690207 34.9))
BATIMENT0000000302934850;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;30.6;37.9;41.5;31.8;Cadastre;A 1.0;POLYGON Z ((354428.3 6690216.9 37.9, 354425 6690209 37.9, 354419.1 6690211.5 37.9, 354419.4 6690212 37.9, 354423.6 6690221.2 37.9, 354428.3 6690216.9 37.9))
BATIMENT0000000302935106;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;7.9;30.0;37.9;40.9;30.3;Cadastre;A 1.0;POLYGON Z ((354357.2 6690185.3 37.9, 354351 6690187.2 37.9, 354354.7 6690198.9 37.9, 354356 6690198.6 37.9, 354356.6 6690200.9 37.9, 354339.7 6690205.7 37.9, 354339.1 6690210 37.9, 354338.9 6690211.1 37.9, 354353.8 6690207.1 37.9, 354362.8 6690204.5 37.9, 354357.2 6690185.3 37.9))
BATIMENT0000000302935150;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.3;30.0;39.4;42.5;30.5;Cadastre;A 1.0;POLYGON Z ((354372.4 6690205.2 39.4, 354382.4 6690202.2 39.4, 354383.1 6690202 39.4, 354381.5 6690196.6 39.4, 354370.9 6690199.7 39.4, 354372.4 6690205.2 39.4))
BATIMENT0000000302935151;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.4;29.9;38.4;41.1;30.4;Cadastre;A 1.0;POLYGON Z ((354374.7 6690213.5 38.4, 354383.5 6690210.8 38.4, 354381.3 6690204.1 38.4, 354382.7 6690203.8 38.4, 354382.4 6690202.2 38.4, 354372.4 6690205.2 38.4, 354374.7 6690213.5 38.4))
BATIMENT0000000302935108;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1875-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.7;30.0;38.7;41.1;30.1;Cadastre;A 1.0;POLYGON Z ((354355.1 6690212.2 38.7, 354364.3 6690209.6 38.7, 354362.8 6690204.5 38.7, 354353.8 6690207.1 38.7, 354355.1 6690212.2 38.7))
BATIMENT0000000302935155;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.1;30.4;33.5;34.6;31.1;Cadastre;;POLYGON Z ((354400.1 6690209.4 33.5, 354398.6 6690205.7 33.5, 354391.8 6690207.9 33.5, 354387.2 6690209.4 33.5, 354386.5 6690211 33.5, 354387.6 6690214 33.5, 354394.9 6690211.3 33.5, 354400.1 6690209.4 33.5))
BATIMENT0000000302935110;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1897-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;90;8.6;29.9;38.5;41.0;30.2;Cadastre;A 1.0;POLYGON Z ((354352.4 6690213 38.5, 354353.9 6690218.5 38.5, 354354.9 6690218.2 38.5, 354356.7 6690217.7 38.5, 354358.6 6690217.1 38.5, 354365.9 6690215 38.5, 354364.3 6690209.6 38.5, 354355.1 6690212.2 38.5, 354352.4 6690213 38.5))
BATIMENT0000000302935152;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;29.8;38.0;41.2;30.6;Cadastre;;POLYGON Z ((354376 6690217.5 38, 354384.7 6690215 38, 354383.5 6690210.8 38, 354374.7 6690213.5 38, 354376 6690217.5 38))
BATIMENT0000000302935154;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;30.3;33.9;35.0;31.0;Cadastre;;POLYGON Z ((354395.9 6690215.2 33.9, 354394.9 6690211.3 33.9, 354387.6 6690214 33.9, 354385.7 6690214.7 33.9, 354386.6 6690218.2 33.9, 354395.9 6690215.2 33.9))
BATIMENT0000000302935111;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;02;6.7;30.0;36.7;41.0;30.0;Cadastre;A 1.0;POLYGON Z ((354359.4 6690219.7 36.7, 354366.5 6690217.6 36.7, 354365.9 6690215 36.7, 354358.6 6690217.1 36.7, 354359.4 6690219.7 36.7))
BATIMENT0000000302935112;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;30.0;34.3;38.2;30.1;Cadastre;;POLYGON Z ((354355.6 6690220.8 34.3, 354359.4 6690219.7 34.3, 354358.6 6690217.1 34.3, 354356.7 6690217.7 34.3, 354354.9 6690218.2 34.3, 354355.6 6690220.8 34.3))
BATIMENT0000000302934944;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.5;27.3;37.8;40.1;28.6;Cadastre;A 1.0;POLYGON Z ((354218.2 6690075.5 37.8, 354219.1 6690085.1 37.8, 354226.4 6690084.4 37.8, 354226.5 6690083.6 37.8, 354225.4 6690074.9 37.8, 354218.2 6690075.5 37.8))
BATIMENT0000000302934943;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;6.8;28.1;35.0;38.6;29.0;Cadastre;A 1.0;POLYGON Z ((354225.4 6690074.9 35, 354226.5 6690083.6 35, 354227.5 6690083.5 35, 354227.6 6690086.5 35, 354238.6 6690085.5 35, 354238.6 6690082.5 35, 354238.4 6690080.4 35, 354237.9 6690073.6 35, 354225.4 6690074.9 35))
BATIMENT0000000302934945;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.5;27.2;37.7;39.9;28.4;Cadastre;A 1.0;POLYGON Z ((354211.9 6690076.1 37.7, 354212 6690077.8 37.7, 354213 6690089.7 37.7, 354213.3 6690092.8 37.7, 354215 6690092.7 37.7, 354215 6690090.8 37.7, 354216.5 6690090.8 37.7, 354216.2 6690086.4 37.7, 354219.2 6690086 37.7, 354219.1 6690085.1 37.7, 354218.2 6690075.5 37.7, 354211.9 6690076.1 37.7))
BATIMENT0000000302935034;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.6;29.2;38.8;41.4;29.6;Cadastre;C 0.7;POLYGON Z ((354260.1 6690074.7 38.8, 354251.4 6690076.8 38.8, 354253.3 6690084.3 38.8, 354250.5 6690085.1 38.8, 354252.9 6690094.5 38.8, 354255.6 6690094 38.8, 354264.7 6690091.8 38.8, 354260.1 6690074.7 38.8))
BATIMENT0000000302934946;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;28.5;33.2;35.9;29.0;Cadastre;;POLYGON Z ((354238.6 6690087.3 33.2, 354239.6 6690096.7 33.2, 354243.7 6690095.8 33.2, 354241.5 6690086.7 33.2, 354238.6 6690087.3 33.2))
BATIMENT0000000302934947;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.6;27.6;34.2;41.0;28.4;Cadastre;A 1.0;POLYGON Z ((354207.1 6690106.6 34.2, 354214.7 6690106 34.2, 354214.3 6690102 34.2, 354213.3 6690092.8 34.2, 354213 6690089.7 34.2, 354212 6690077.8 34.2, 354200 6690078.9 34.2, 354198.3 6690081.4 34.2, 354200.8 6690090.6 34.2, 354209.6 6690090 34.2, 354209.3 6690099.5 34.2, 354203.3 6690099.8 34.2, 354205.2 6690106.6 34.2, 354207.1 6690106.6 34.2))
BATIMENT0000000302935035;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.9;28.8;36.7;40.4;29.6;Cadastre;A 1.0;POLYGON Z ((354257.9 6690103.1 36.7, 354259.6 6690102.7 36.7, 354267 6690100.8 36.7, 354264.7 6690091.8 36.7, 354255.6 6690094 36.7, 354257.9 6690103.1 36.7))
BATIMENT0000000302935036;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.9;28.7;37.6;41.0;29.7;Cadastre;C 1.0;POLYGON Z ((354260.4 6690105.9 37.6, 354259.8 6690106.2 37.6, 354262 6690115 37.6, 354270 6690113 37.6, 354267 6690100.8 37.6, 354259.6 6690102.7 37.6, 354260.4 6690105.9 37.6))
BATIMENT0000000302935184;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.2;27.2;37.5;41.2;27.7;Cadastre;A 1.0;POLYGON Z ((354193 6690102.2 37.5, 354187.6 6690103.6 37.5, 354187.7 6690104.3 37.5, 354185.4 6690105 37.5, 354184.1 6690100.9 37.5, 354179 6690102.3 37.5, 354181.8 6690112.1 37.5, 354182.9 6690111.6 37.5, 354184.3 6690116.6 37.5, 354186.5 6690116.1 37.5, 354195.9 6690113.4 37.5, 354193 6690102.2 37.5))
BATIMENT0000000302934948;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.8;27.6;33.4;36.6;28.0;Cadastre;A 1.0;POLYGON Z ((354207.8 6690116.3 33.4, 354214.5 6690116.1 33.4, 354215.5 6690116.1 33.4, 354214.7 6690106 33.4, 354207.1 6690106.6 33.4, 354207.8 6690116.3 33.4))
BATIMENT0000000302935223;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.0;26.1;36.1;38.7;27.3;Cadastre;A 1.0;POLYGON Z ((354156.4 6690082.4 36.1, 354157.3 6690091.3 36.1, 354157.4 6690093.1 36.1, 354162.5 6690092.5 36.1, 354162.4 6690092.1 36.1, 354167.5 6690091.4 36.1, 354167.3 6690090 36.1, 354166.4 6690081.4 36.1, 354156.4 6690082.4 36.1))
BATIMENT0000000302935224;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;14.2;26.2;40.5;43.4;27.3;Cadastre;A 1.0;POLYGON Z ((354146.7 6690083.2 40.5, 354138 6690093.7 40.5, 354141 6690100.8 40.5, 354149 6690097.1 40.5, 354149.7 6690096.7 40.5, 354148.8 6690094 40.5, 354150.3 6690092.2 40.5, 354157.3 6690091.3 40.5, 354156.4 6690082.4 40.5, 354146.7 6690083.2 40.5))
BATIMENT0000000302935033;Eglise;Religieux;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.1;25.6;34.7;;;Cadastre;;POLYGON Z ((354093.9 6690066.3 34.7, 354094.5 6690079.2 34.7, 354092.5 6690079.5 34.7, 354093.1 6690085.7 34.7, 354096.9 6690085.4 34.7, 354097.2 6690087.5 34.7, 354101.3 6690087.1 34.7, 354105 6690125.5 34.7, 354100.7 6690126.2 34.7, 354100.5 6690126 34.7, 354100 6690125.8 34.7, 354099.8 6690125.7 34.7, 354099.5 6690125.7 34.7, 354099.3 6690125.7 34.7, 354099 6690125.7 34.7, 354098.7 6690125.7 34.7, 354098.5 6690125.8 34.7, 354098.3 6690125.9 34.7, 354098 6690126 34.7, 354097.8 6690126.1 34.7, 354097.6 6690126.3 34.7, 354097.4 6690126.5 34.7, 354097.2 6690126.8 34.7, 354097 6690127 34.7, 354096.9 6690127.2 34.7, 354096.8 6690127.4 34.7, 354096.7 6690127.8 34.7, 354096.6 6690128.2 34.7, 354096.6 6690128.4 34.7, 354096.7 6690128.9 34.7, 354096.7 6690129.1 34.7, 354096.8 6690129.4 34.7, 354096.9 6690129.6 34.7, 354097 6690129.8 34.7, 354097.1 6690130 34.7, 354097.3 6690130.1 34.7, 354097.4 6690130.3 34.7, 354097.6 6690130.4 34.7, 354097.8 6690130.5 34.7, 354098 6690130.6 34.7, 354098.2 6690130.6 34.7, 354098.6 6690130.7 34.7, 354098.8 6690130.8 34.7, 354099 6690130.8 34.7, 354099.5 6690130.8 34.7, 354099.9 6690130.7 34.7, 354100.1 6690130.7 34.7, 354100.3 6690130.7 34.7, 354100.5 6690130.6 34.7, 354100.8 6690130.4 34.7, 354101.1 6690130.1 34.7, 354101.3 6690129.8 34.7, 354105.4 6690129.4 34.7, 354105.7 6690131.8 34.7, 354125.2 6690129.8 34.7, 354125.1 6690127.8 34.7, 354128.1 6690127.4 34.7, 354128.6 6690128 34.7, 354128.8 6690128.3 34.7, 354129.1 6690128.5 34.7, 354129.4 6690128.6 34.7, 354129.6 6690128.8 34.7, 354129.9 6690128.9 34.7, 354130.3 6690129 34.7, 354130.6 6690129.1 34.7, 354130.9 6690129.1 34.7, 354131.2 6690129.1 34.7, 354131.5 6690129.1 34.7, 354131.8 6690129.1 34.7, 354132.5 6690128.9 34.7, 354133 6690128.7 34.7, 354133.3 6690128.5 34.7, 354133.6 6690128.3 34.7, 354133.8 6690128.1 34.7, 354134.1 6690127.9 34.7, 354134.2 6690127.6 34.7, 354134.4 6690127.4 34.7, 354134.6 6690127.1 34.7, 354134.7 6690126.8 34.7, 354134.8 6690126.5 34.7, 354134.9 6690126.2 34.7, 354135 6690125.9 34.7, 354135 6690125.5 34.7, 354135 6690125.2 34.7, 354135 6690124.9 34.7, 354134.9 6690124.6 34.7, 354134.9 6690124.3 34.7, 354134.6 6690123.7 34.7, 354134.5 6690123.4 34.7, 354134.3 6690123.1 34.7, 354134.1 6690122.9 34.7, 354133.9 6690122.6 34.7, 354133.7 6690122.4 34.7, 354133.5 6690122.2 34.7, 354133.2 6690122.1 34.7, 354132.9 6690121.9 34.7, 354132.6 6690121.8 34.7, 354132.3 6690121.7 34.7, 354132 6690121.6 34.7, 354131.7 6690121.5 34.7, 354131.4 6690121.5 34.7, 354131.1 6690121.5 34.7, 354130.8 6690121.5 34.7, 354130.4 6690121.6 34.7, 354130.1 6690121.7 34.7, 354129.8 6690121.8 34.7, 354129.5 6690121.9 34.7, 354129.3 6690122 34.7, 354128.8 6690122.4 34.7, 354128.5 6690122.6 34.7, 354128.3 6690122.9 34.7, 354128.2 6690123.1 34.7, 354127.8 6690123.5 34.7, 354127.5 6690123.7 34.7, 354124.8 6690124 34.7, 354121.8 6690087.8 34.7, 354122.2 6690087.9 34.7, 354121 6690072.9 34.7, 354117.3 6690073.4 34.7, 354116.8 6690070.7 34.7, 354113.5 6690070.8 34.7, 354113.5 6690069.7 34.7, 354113.5 6690069.4 34.7, 354113.4 6690069.2 34.7, 354113.2 6690068.6 34.7, 354113 6690068.4 34.7, 354112.8 6690068.2 34.7, 354112.7 6690068 34.7, 354112.5 6690067.8 34.7, 354112.2 6690067.6 34.7, 354112 6690067.5 34.7, 354111.7 6690067.3 34.7, 354111.5 6690067.2 34.7, 354111 6690067.1 34.7, 354110.7 6690067.1 34.7, 354110.4 6690067 34.7, 354110.1 6690066.9 34.7, 354109.8 6690066.9 34.7, 354109.5 6690066.9 34.7, 354109.2 6690066.9 34.7, 354108.9 6690067 34.7, 354108.6 6690067.1 34.7, 354108.4 6690067.2 34.7, 354108.1 6690067.3 34.7, 354107.8 6690067.4 34.7, 354107.6 6690067.6 34.7, 354107.3 6690067.8 34.7, 354107.1 6690068 34.7, 354106.9 6690068.2 34.7, 354106.8 6690068.4 34.7, 354106.6 6690068.7 34.7, 354106.5 6690069 34.7, 354106.4 6690069.3 34.7, 354106.3 6690069.6 34.7, 354106.2 6690069.9 34.7, 354106.2 6690070.2 34.7, 354106.2 6690070.6 34.7, 354106.2 6690070.9 34.7, 354106.2 6690071.3 34.7, 354100.7 6690071.9 34.7, 354100.1 6690065.9 34.7, 354093.9 6690066.3 34.7))
BATIMENT0000000302935183;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1909-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;01;7.1;26.0;33.1;34.6;27.4;Cadastre;C 0.4;POLYGON Z ((354167.4 6690100.4 33.1, 354168.9 6690104.8 33.1, 354177.2 6690102.7 33.1, 354175.9 6690098.2 33.1, 354167.4 6690100.4 33.1))
BATIMENT0000000302935225;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;10.5;26.0;36.5;38.5;26.7;Cadastre;A 1.0;POLYGON Z ((354145.2 6690110.6 36.5, 354150 6690108.4 36.5, 354153.3 6690107 36.5, 354149 6690097.1 36.5, 354141 6690100.8 36.5, 354145.2 6690110.6 36.5))
BATIMENT0000000302935226;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;10.4;26.1;36.5;38.2;27.2;Cadastre;A 1.0;POLYGON Z ((354150.7 6690123.3 36.5, 354159.2 6690119.8 36.5, 354155.3 6690111.2 36.5, 354152 6690112.7 36.5, 354150 6690108.4 36.5, 354145.2 6690110.6 36.5, 354150.7 6690123.3 36.5))
BATIMENT0000000302935227;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;10.4;26.3;36.7;38.2;27.3;Cadastre;A 1.0;POLYGON Z ((354154.2 6690131.1 36.7, 354162.6 6690128 36.7, 354159.2 6690119.8 36.7, 354150.7 6690123.3 36.7, 354154.2 6690131.1 36.7))
BATIMENT0000000302935228;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;20;5.3;26.4;31.7;40.2;27.7;Cadastre;A 1.0;POLYGON Z ((354157.2 6690138.2 31.7, 354165.5 6690134.8 31.7, 354170.6 6690132.7 31.7, 354167.8 6690125.9 31.7, 354162.6 6690128 31.7, 354154.2 6690131.1 31.7, 354157.2 6690138.2 31.7))
BATIMENT0000000302935014;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.5;25.0;33.5;37.8;26.5;Cadastre;C 0.7;POLYGON Z ((354131.6 6690155.2 33.5, 354141.6 6690154.3 33.5, 354141.7 6690153.9 33.5, 354147.1 6690153.3 33.5, 354142.6 6690142.8 33.5, 354140.2 6690143.1 33.5, 354140.2 6690142.6 33.5, 354130.3 6690143.4 33.5, 354130.2 6690144.9 33.5, 354131.3 6690153.4 33.5, 354131.6 6690155.2 33.5))
BATIMENT0000000302935229;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1971-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;13;20;3.8;26.5;30.3;41.6;28.3;Cadastre;A 1.0;POLYGON Z ((354173.8 6690177.9 30.3, 354182.2 6690174.3 30.3, 354178.6 6690165.6 30.3, 354187.7 6690161.6 30.3, 354184.3 6690153.2 30.3, 354180.8 6690139.2 30.3, 354178.2 6690129.7 30.3, 354170.6 6690132.7 30.3, 354165.5 6690134.8 30.3, 354157.2 6690138.2 30.3, 354173.8 6690177.9 30.3))
BATIMENT0000000302934998;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.4;29.7;38.1;41.7;30.3;Cadastre;A 1.0;POLYGON Z ((354308.2 6690101.4 38.1, 354310.1 6690101.8 38.1, 354309.1 6690107.2 38.1, 354317.7 6690108.6 38.1, 354319.3 6690098.9 38.1, 354308.7 6690097.3 38.1, 354308.2 6690101.4 38.1))
BATIMENT0000000302935039;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.2;30.2;38.4;44.7;30.9;Cadastre;A 1.0;POLYGON Z ((354328.3 6690114.1 38.4, 354334.7 6690115 38.4, 354335.3 6690111.8 38.4, 354339.6 6690112.4 38.4, 354339.9 6690111.2 38.4, 354340.7 6690111.4 38.4, 354341.3 6690108.8 38.4, 354340.3 6690108.4 38.4, 354340.9 6690105 38.4, 354341.4 6690105.2 38.4, 354341.6 6690103.6 38.4, 354330.1 6690101.8 38.4, 354328.3 6690114.1 38.4))
BATIMENT0000000302934979;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;00;00;6.4;29.5;36.0;39.9;30.1;Cadastre;A 1.0;POLYGON Z ((354280.8 6690114.9 36, 354288.8 6690113 36, 354287.7 6690108.7 36, 354290.1 6690108.2 36, 354289.2 6690105 36, 354291.6 6690104.5 36, 354290.9 6690102.5 36, 354285.2 6690104.1 36, 354278.5 6690105.6 36, 354280.8 6690114.9 36))
BATIMENT0000000302934999;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.6;29.6;38.2;40.5;30.3;Cadastre;A 1.0;POLYGON Z ((354307.5 6690107 38.2, 354307.2 6690109.1 38.2, 354308.2 6690109.1 38.2, 354307.1 6690116.6 38.2, 354316.4 6690118 38.2, 354317.7 6690108.6 38.2, 354309.1 6690107.2 38.2, 354307.5 6690107 38.2))
BATIMENT0000000302934978;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1889-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;8.7;29.5;38.2;40.5;30.1;Cadastre;A 1.0;POLYGON Z ((354283.4 6690124.7 38.2, 354288.8 6690123.4 38.2, 354290.4 6690122.9 38.2, 354291.2 6690122.7 38.2, 354288.8 6690113 38.2, 354280.8 6690114.9 38.2, 354283.4 6690124.7 38.2))
BATIMENT0000000302935000;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.8;29.6;38.4;42.4;30.3;Cadastre;A 1.0;POLYGON Z ((354306.3 6690116.5 38.4, 354304.8 6690126.4 38.4, 354308.3 6690126.9 38.4, 354314.9 6690127.9 38.4, 354316.4 6690118 38.4, 354307.1 6690116.6 38.4, 354306.3 6690116.5 38.4))
BATIMENT0000000302934977;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;03;3.7;29.0;32.7;38.0;30.2;Cadastre;C 0.3;POLYGON Z ((354288.8 6690123.4 32.7, 354283.4 6690124.7 32.7, 354284.3 6690127.9 32.7, 354284.9 6690130.4 32.7, 354295.8 6690127.5 32.7, 354295.1 6690124.1 32.7, 354294.8 6690121.8 32.7, 354291.2 6690122.7 32.7, 354290.4 6690122.9 32.7, 354288.8 6690123.4 32.7))
BATIMENT0000000302935040;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1871-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.2;29.7;36.9;40.6;31.0;Cadastre;A 1.0;POLYGON Z ((354335.6 6690135.8 36.9, 354343.6 6690133.4 36.9, 354345.8 6690116.1 36.9, 354335.8 6690115 36.9, 354333.4 6690132.2 36.9, 354325.5 6690131.3 36.9, 354324.4 6690139.4 36.9, 354326.7 6690138.6 36.9, 354335.6 6690135.8 36.9))
BATIMENT0000000302935001;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;29.7;35.7;40.3;30.4;Cadastre;;POLYGON Z ((354307.7 6690131.6 35.7, 354314.2 6690132.7 35.7, 354314.9 6690127.9 35.7, 354308.3 6690126.9 35.7, 354307.7 6690131.6 35.7))
BATIMENT0000000302935085;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.1;28.8;35.9;40.0;29.6;Cadastre;B 1.0;POLYGON Z ((354265.4 6690142.1 35.9, 354266.3 6690141.9 35.9, 354267.7 6690147.7 35.9, 354278.3 6690145.2 35.9, 354274.1 6690128.1 35.9, 354262.4 6690130.9 35.9, 354265.4 6690142.1 35.9))
BATIMENT0000000302935185;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;56;19;7.1;27.8;34.9;;;Cadastre;A 1.0;POLYGON Z ((354195.9 6690113.4 34.9, 354186.5 6690116.1 34.9, 354184.3 6690116.6 34.9, 354183.8 6690116.8 34.9, 354184.3 6690119.1 34.9, 354184.6 6690119 34.9, 354185.7 6690123 34.9, 354191.3 6690121.5 34.9, 354197.7 6690120.1 34.9, 354195.9 6690113.4 34.9))
BATIMENT0000000302935198;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;01;4.8;27.6;32.4;33.7;28.9;Cadastre;C 0.3;POLYGON Z ((354230.2 6690117.7 32.4, 354230.5 6690121.6 32.4, 354236.4 6690120.3 32.4, 354235.4 6690116.4 32.4, 354230.2 6690117.7 32.4))
BATIMENT0000000302935084;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.0;28.8;35.8;40.0;29.7;Cadastre;C 0.8;POLYGON Z ((354271 6690116.2 35.8, 354259.2 6690119.2 35.8, 354262.4 6690130.9 35.8, 354274.1 6690128.1 35.8, 354271 6690116.2 35.8))
BATIMENT0000000302934949;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;8.1;27.6;35.7;41.0;28.6;Cadastre;A 1.0;POLYGON Z ((354212.3 6690132.4 35.7, 354220.8 6690130 35.7, 354221.9 6690129.7 35.7, 354218.8 6690119.3 35.7, 354215.7 6690120 35.7, 354214.5 6690116.1 35.7, 354207.8 6690116.3 35.7, 354212.3 6690132.4 35.7))
BATIMENT0000000029199018;Indifférenciée;Annexe;;Non;En service;2006-10-04 09:41:10;2019-03-15 08:35:34;1890-01-01;;;;BDTopo;2.5;BDTopo;1.5;0.0;1.0;05;01;4.9;27.4;;40.4;29.1;Imagerie aérienne;C 0.2;POLYGON Z ((354239.8 6690129.3 31.8, 354240.2 6690122.7 32.3, 354230.2 6690123 31.7, 354230 6690125.1 31.7, 354228.8 6690125 31.7, 354229 6690129.7 31.7, 354239.8 6690129.3 31.8))
BATIMENT0000000302935186;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.0;27.8;36.8;40.5;27.8;Cadastre;A 1.0;POLYGON Z ((354198.5 6690123.1 36.8, 354187.5 6690125.8 36.8, 354188.5 6690130.5 36.8, 354187.7 6690130.7 36.8, 354189 6690135.9 36.8, 354190.8 6690135.5 36.8, 354201 6690133.1 36.8, 354198.5 6690123.1 36.8))
BATIMENT0000000302934950;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.0;27.8;37.9;40.0;28.3;Cadastre;A 1.0;POLYGON Z ((354214.5 6690140.8 37.9, 354223 6690138.5 37.9, 354220.8 6690130 37.9, 354212.3 6690132.4 37.9, 354214.5 6690140.8 37.9))
BATIMENT0000000302935232;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;9.3;28.4;37.7;42.2;28.9;Cadastre;B 0.3;POLYGON Z ((354233.9 6690135.7 37.7, 354234.5 6690144.9 37.7, 354239.7 6690144.7 37.7, 354238.8 6690135.2 37.7, 354233.9 6690135.7 37.7))
BATIMENT0000000302935187;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.6;27.8;37.4;41.2;28.1;Cadastre;A 1.0;POLYGON Z ((354192 6690139.7 37.4, 354192.9 6690139.5 37.4, 354195.4 6690149.3 37.4, 354204.9 6690146.8 37.4, 354201 6690133.1 37.4, 354190.8 6690135.5 37.4, 354192 6690139.7 37.4))
BATIMENT0000000302934951;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.3;27.8;38.2;40.3;28.3;Cadastre;A 1.0;POLYGON Z ((354216.4 6690147.7 38.2, 354225.4 6690147.2 38.2, 354224.3 6690143.3 38.2, 354225 6690141.6 38.2, 354224.2 6690138.2 38.2, 354223 6690138.5 38.2, 354214.5 6690140.8 38.2, 354216.4 6690147.7 38.2))
BATIMENT0000000302935042;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;29.7;33.3;35.0;30.6;Cadastre;;POLYGON Z ((354330.9 6690141.6 33.3, 354331.1 6690139 33.3, 354332.7 6690139.3 33.3, 354335.6 6690137.4 33.3, 354335.6 6690135.8 33.3, 354326.7 6690138.6 33.3, 354326.3 6690141 33.3, 354330.9 6690141.6 33.3))
BATIMENT0000000302935002;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;24;7.2;29.2;36.4;41.0;30.4;Cadastre;C 1.0;POLYGON Z ((354306.5 6690131.3 36.4, 354305.7 6690134.9 36.4, 354302.7 6690134.5 36.4, 354301.6 6690140.7 36.4, 354293 6690139.3 36.4, 354292.3 6690143.8 36.4, 354300.1 6690145 36.4, 354310.4 6690146.5 36.4, 354311.7 6690135.9 36.4, 354313.6 6690136.2 36.4, 354314.2 6690132.7 36.4, 354307.7 6690131.6 36.4, 354306.5 6690131.3 36.4))
BATIMENT0000000302935041;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;29.7;33.2;33.9;30.1;Cadastre;;POLYGON Z ((354324.2 6690140.9 33.2, 354326.3 6690141 33.2, 354326.7 6690138.6 33.2, 354324.4 6690139.4 33.2, 354324.2 6690140.9 33.2))
BATIMENT0000000302935003;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;8.4;29.2;37.6;40.4;30.1;Cadastre;A 1.0;POLYGON Z ((354299.2 6690151.2 37.6, 354301.3 6690151.7 37.6, 354300.6 6690156.4 37.6, 354310.4 6690157.9 37.6, 354312.1 6690146.8 37.6, 354310.4 6690146.5 37.6, 354300.1 6690145 37.6, 354299.2 6690151.2 37.6))
BATIMENT0000000302935231;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;29.2;31.2;32.5;29.7;Cadastre;;POLYGON Z ((354296.2 6690151.2 31.2, 354295.3 6690150.1 31.2, 354290.1 6690149.3 31.2, 354291.1 6690153 31.2, 354295.8 6690153.7 31.2, 354296.2 6690151.2 31.2))
BATIMENT0000000302935086;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;11.2;29.2;40.4;42.6;29.7;Cadastre;A 1.0;POLYGON Z ((354266.7 6690147.9 40.4, 354269.8 6690159.3 40.4, 354281.4 6690156.4 40.4, 354278.3 6690145.2 40.4, 354267.7 6690147.7 40.4, 354266.7 6690147.9 40.4))
BATIMENT0000000302935230;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;29.2;32.5;33.8;29.8;Cadastre;;POLYGON Z ((354292 6690156.5 32.5, 354297.3 6690157.3 32.5, 354297.7 6690153.9 32.5, 354295.8 6690153.7 32.5, 354291.1 6690153 32.5, 354292 6690156.5 32.5))
BATIMENT0000000302935258;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.4;28.7;36.1;38.9;30.1;Cadastre;A 1.0;POLYGON Z ((354330.1 6690161.9 36.1, 354331.1 6690156.1 36.1, 354333.2 6690156.4 36.1, 354333.9 6690152.1 36.1, 354322.9 6690150.5 36.1, 354321.2 6690160.6 36.1, 354330.1 6690161.9 36.1))
BATIMENT0000000302935004;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.7;29.1;37.8;41.1;29.8;Cadastre;A 1.0;POLYGON Z ((354300.3 6690159.7 37.8, 354299.8 6690159.5 37.8, 354299.3 6690162.5 37.8, 354299.8 6690162.6 37.8, 354299.3 6690166 37.8, 354299.8 6690166 37.8, 354308.9 6690167.4 37.8, 354310.4 6690157.9 37.8, 354300.6 6690156.4 37.8, 354300.3 6690159.7 37.8))
BATIMENT0000000302935087;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;30;10;9.5;28.6;38.1;41.5;29.7;Cadastre;A 1.0;POLYGON Z ((354268.8 6690159.6 38.1, 354270.8 6690166.3 38.1, 354271.7 6690166.6 38.1, 354272.7 6690166.4 38.1, 354272.8 6690167.1 38.1, 354271.8 6690167.2 38.1, 354272.2 6690168.7 38.1, 354273.1 6690168.5 38.1, 354283.8 6690165.7 38.1, 354281.4 6690156.4 38.1, 354269.8 6690159.3 38.1, 354268.8 6690159.6 38.1))
BATIMENT0000000302934952;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;40;8.1;27.6;35.7;38.0;28.7;Cadastre;A 1.0;POLYGON Z ((354220.2 6690162.3 35.7, 354230.6 6690159.3 35.7, 354228.5 6690151.5 35.7, 354229.2 6690150.2 35.7, 354228.7 6690147.2 35.7, 354225.4 6690147.2 35.7, 354216.4 6690147.7 35.7, 354220.2 6690162.3 35.7))
BATIMENT0000000302935188;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2010-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;90;5.4;27.6;33.0;36.2;28.1;Cadastre;A 1.0;POLYGON Z ((354194.8 6690149.5 33, 354195.9 6690153.5 33, 354194.6 6690153.9 33, 354195.8 6690158.2 33, 354197.2 6690157.8 33, 354198.2 6690161.6 33, 354192.8 6690163 33, 354193.7 6690166.3 33, 354209 6690162.4 33, 354204.9 6690146.8 33, 354195.4 6690149.3 33, 354194.8 6690149.5 33))
BATIMENT0000000302934953;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;8.5;27.6;36.1;42.7;28.2;Cadastre;A 1.0;POLYGON Z ((354223.3 6690174.5 36.1, 354232.7 6690172 36.1, 354236.6 6690170.9 36.1, 354235.4 6690166.6 36.1, 354236.8 6690166.2 36.1, 354235.5 6690161.1 36.1, 354234.1 6690161.3 36.1, 354233.3 6690158.6 36.1, 354230.6 6690159.3 36.1, 354220.2 6690162.3 36.1, 354223.3 6690174.5 36.1))
BATIMENT0000000302934954;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;10.5;27.8;38.4;42.0;28.1;Cadastre;C 0.5;POLYGON Z ((354224.3 6690177.6 38.4, 354233.3 6690175.2 38.4, 354232.7 6690172 38.4, 354223.3 6690174.5 38.4, 354224.3 6690177.6 38.4))
BATIMENT0000000302935097;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.4;27.0;38.5;40.9;28.1;Cadastre;A 1.0;POLYGON Z ((354211.7 6690169 38.5, 354201.4 6690171.5 38.5, 354203.2 6690177.4 38.5, 354202.8 6690177.6 38.5, 354202.6 6690177.7 38.5, 354202.4 6690177.9 38.5, 354202.3 6690178.1 38.5, 354202 6690178.4 38.5, 354201.8 6690178.8 38.5, 354201.7 6690179.3 38.5, 354201.6 6690179.5 38.5, 354201.6 6690179.7 38.5, 354201.6 6690179.9 38.5, 354201.6 6690180.1 38.5, 354201.6 6690180.4 38.5, 354201.6 6690180.6 38.5, 354201.7 6690180.8 38.5, 354201.7 6690181 38.5, 354201.8 6690181.2 38.5, 354201.9 6690181.4 38.5, 354202 6690181.6 38.5, 354202.3 6690181.9 38.5, 354202.5 6690182.1 38.5, 354202.6 6690182.2 38.5, 354203 6690182.5 38.5, 354203.2 6690182.5 38.5, 354203.4 6690182.6 38.5, 354203.6 6690182.7 38.5, 354204.3 6690182.6 38.5, 354204.6 6690182.6 38.5, 354214.5 6690179.9 38.5, 354211.7 6690169 38.5))
BATIMENT0000000302935158;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.3;28.0;36.3;40.9;28.9;Cadastre;C 0.5;POLYGON Z ((354251 6690170.5 36.3, 354246.5 6690171.6 36.3, 354246.1 6690169.4 36.3, 354243 6690170.2 36.3, 354243.3 6690172.5 36.3, 354240.7 6690173.2 36.3, 354243.9 6690185.6 36.3, 354244.5 6690185.4 36.3, 354254.6 6690182.8 36.3, 354251 6690170.5 36.3))
BATIMENT0000000302935282;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2008-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;43;6.2;26.0;32.2;38.2;27.4;Cadastre;A 1.0;POLYGON Z ((354186.4 6690189.9 32.2, 354195.3 6690184.8 32.2, 354193.2 6690178.7 32.2, 354190.1 6690180.2 32.2, 354188.3 6690176.1 32.2, 354191.9 6690174.9 32.2, 354190.1 6690169.7 32.2, 354183.5 6690172.3 32.2, 354183.5 6690172.4 32.2, 354186.1 6690177.8 32.2, 354184.3 6690183.5 32.2, 354177.2 6690186.7 32.2, 354179.4 6690191.7 32.2, 354186.4 6690189.9 32.2))
BATIMENT0000000302935095;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.5;27.0;38.5;41.4;27.9;Cadastre;C 0.8;POLYGON Z ((354206.1 6690188.8 38.5, 354208.1 6690188.4 38.5, 354216.3 6690186.2 38.5, 354214.5 6690179.9 38.5, 354204.6 6690182.6 38.5, 354204.3 6690182.6 38.5, 354206.1 6690188.8 38.5))
BATIMENT0000000302935157;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;28.0;36.2;40.3;28.9;Cadastre;A 1.0;POLYGON Z ((354246.5 6690193.8 36.2, 354244.8 6690194.3 36.2, 354246 6690198.3 36.2, 354256.8 6690195.4 36.2, 354254.9 6690187.3 36.2, 354255.5 6690187.2 36.2, 354254.6 6690182.8 36.2, 354244.5 6690185.4 36.2, 354246.5 6690193.8 36.2))
BATIMENT0000000302935096;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;8.2;27.3;35.5;38.6;28.0;Cadastre;A 1.0;POLYGON Z ((354211.1 6690199.9 35.5, 354219.6 6690197.9 35.5, 354216.3 6690186.2 35.5, 354208.1 6690188.4 35.5, 354211.1 6690199.9 35.5))
BATIMENT0000000302935255;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.7;28.7;39.4;43.2;30.2;Cadastre;A 1.0;POLYGON Z ((354330.2 6690172 39.4, 354331.7 6690162.1 39.4, 354330.1 6690161.9 39.4, 354321.2 6690160.6 39.4, 354319.7 6690170.5 39.4, 354329.4 6690172 39.4, 354330.2 6690172 39.4))
BATIMENT0000000302935005;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.8;29.1;38.9;42.4;29.7;Cadastre;A 1.0;POLYGON Z ((354298.9 6690173 38.9, 354307.9 6690174.3 38.9, 354308.9 6690167.4 38.9, 354299.8 6690166 38.9, 354298.9 6690173 38.9))
BATIMENT0000000302935088;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.8;28.7;38.5;41.7;29.8;Cadastre;A 1.0;POLYGON Z ((354273.1 6690168.5 38.5, 354273.4 6690170.1 38.5, 354274.2 6690170.9 38.5, 354272.7 6690171.4 38.5, 354274.8 6690179.6 38.5, 354273.5 6690179.9 38.5, 354273.4 6690179.4 38.5, 354271 6690180 38.5, 354271.8 6690182.8 38.5, 354276.2 6690181.6 38.5, 354276.7 6690181.4 38.5, 354287.1 6690178.8 38.5, 354283.8 6690165.7 38.5, 354273.1 6690168.5 38.5))
BATIMENT0000000302935006;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;13.2;29.1;42.4;43.0;29.4;Cadastre;A 1.0;POLYGON Z ((354295.7 6690172.6 42.4, 354297.9 6690181.1 42.4, 354302.3 6690181.4 42.4, 354302.7 6690180.5 42.4, 354306.8 6690180.7 42.4, 354307.9 6690174.3 42.4, 354298.9 6690173 42.4, 354295.7 6690172.6 42.4))
BATIMENT0000000302935253;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.3;28.7;34.0;37.2;30.1;Cadastre;;POLYGON Z ((354326.2 6690176.2 34, 354325.3 6690182.3 34, 354328 6690182.8 34, 354328.8 6690176.6 34, 354326.2 6690176.2 34))
BATIMENT0000000302935254;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.2;29.2;38.5;43.2;30.1;Cadastre;C 0.7;POLYGON Z ((354317.3 6690185.6 38.5, 354324 6690186.8 38.5, 354323.6 6690189.5 38.5, 354328.8 6690190.3 38.5, 354328.9 6690189.8 38.5, 354329.1 6690189.5 38.5, 354329.2 6690189.4 38.5, 354329.3 6690189.2 38.5, 354329.4 6690188.9 38.5, 354329.4 6690188.7 38.5, 354329.4 6690188.4 38.5, 354329.4 6690188.2 38.5, 354329.4 6690188 38.5, 354329.3 6690187.9 38.5, 354329.3 6690187.7 38.5, 354329.2 6690187.6 38.5, 354329.1 6690187.4 38.5, 354329 6690187.3 38.5, 354328.9 6690187.2 38.5, 354328.6 6690186.9 38.5, 354328.5 6690186.8 38.5, 354328.4 6690186.7 38.5, 354328.1 6690186.6 38.5, 354327.7 6690186.5 38.5, 354327.4 6690186.5 38.5, 354328 6690182.8 38.5, 354325.3 6690182.3 38.5, 354326.2 6690176.2 38.5, 354328.8 6690176.6 38.5, 354329.4 6690172 38.5, 354319.7 6690170.5 38.5, 354317.3 6690185.6 38.5))
BATIMENT0000000302935089;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;29;20;9.1;28.6;37.7;40.8;29.6;Cadastre;A 1.0;POLYGON Z ((354277 6690182.9 37.7, 354276.3 6690183.2 37.7, 354276.5 6690184.2 37.7, 354274.8 6690184.8 37.7, 354276.2 6690189 37.7, 354279 6690188.2 37.7, 354288.8 6690185.4 37.7, 354287.1 6690178.8 37.7, 354276.7 6690181.4 37.7, 354277 6690182.9 37.7))
BATIMENT0000000302935007;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;12.2;29.0;41.2;42.7;29.3;Cadastre;A 1.0;POLYGON Z ((354300.4 6690191.3 41.2, 354305.4 6690191 41.2, 354306.8 6690180.7 41.2, 354302.7 6690180.5 41.2, 354302.3 6690181.4 41.2, 354297.9 6690181.1 41.2, 354300.4 6690191.3 41.2))
BATIMENT0000000302935090;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;9.1;28.7;37.8;41.6;29.4;Cadastre;A 1.0;POLYGON Z ((354280.7 6690194.9 37.8, 354290.6 6690192.2 37.8, 354288.8 6690185.4 37.8, 354279 6690188.2 37.8, 354280.7 6690194.9 37.8))
BATIMENT0000000302935256;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.0;29.1;36.2;41.2;29.9;Cadastre;A 1.0;POLYGON Z ((354322.5 6690203.1 36.2, 354326.6 6690203.8 36.2, 354326.7 6690203.8 36.2, 354329.8 6690204.3 36.2, 354330.5 6690199.9 36.2, 354329.4 6690199.8 36.2, 354330.2 6690194.8 36.2, 354331.3 6690195 36.2, 354331.9 6690190.8 36.2, 354328.8 6690190.3 36.2, 354323.6 6690189.5 36.2, 354320.8 6690189.2 36.2, 354319.2 6690199.5 36.2, 354315.4 6690198.9 36.2, 354315 6690201.8 36.2, 354322.5 6690203.1 36.2))
BATIMENT0000000302935013;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;8.1;22.7;30.8;34.8;25.6;Cadastre;A 1.0;POLYGON Z ((354100.5 6690147.9 30.8, 354109.2 6690185.2 30.8, 354117.7 6690184.9 30.8, 354111 6690155.5 30.8, 354131.3 6690153.4 30.8, 354130.2 6690144.9 30.8, 354100.5 6690147.9 30.8))
BATIMENT0000000302935207;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;25.3;27.9;28.9;26.6;Cadastre;;POLYGON Z ((354144.4 6690158 27.9, 354152.2 6690176.3 27.9, 354155.9 6690174.9 27.9, 354148 6690156.6 27.9, 354144.4 6690158 27.9))
BATIMENT0000000302935335;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;4.2;25.7;30.0;30.1;26.6;Cadastre;A 1.0;POLYGON Z ((354152.2 6690178.7 30, 354153.3 6690181.7 30, 354158.5 6690181.4 30, 354156.8 6690177 30, 354152.2 6690178.7 30))
BATIMENT0000000302935012;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;20;90;8.5;22.0;30.6;34.5;24.5;Cadastre;A 1.0;POLYGON Z ((354110 6690195.2 30.6, 354117.7 6690194.9 30.6, 354117.7 6690184.9 30.6, 354109.2 6690185.2 30.6, 354109 6690195.2 30.6, 354110 6690195.2 30.6))
BATIMENT0000000302935281;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;02;03;3.6;26.3;30.0;33.8;26.7;Cadastre;C 0.3;POLYGON Z ((354186.4 6690189.9 30, 354179.4 6690191.7 30, 354181.9 6690197.7 30, 354185.1 6690196.9 30, 354188.2 6690196.1 30, 354186.4 6690189.9 30))
BATIMENT0000000302935031;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;25.4;41.5;43.2;26.5;Cadastre;;POLYGON Z ((354156.4 6690198.7 41.5, 354157.9 6690198 41.5, 354156 6690193.4 41.5, 354154.5 6690194.1 41.5, 354156.4 6690198.7 41.5))
BATIMENT0000000302935011;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.3;21.7;34.0;36.2;22.2;Cadastre;;POLYGON Z ((354110 6690195.2 34, 354109 6690195.2 34, 354108.9 6690201.2 34, 354110 6690201.3 34, 354110 6690195.2 34))
BATIMENT0000000302935030;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;38.0;6.0;00;00;17.5;22.9;40.4;44.7;26.5;Cadastre;C 0.3;POLYGON Z ((354135.3 6690190.4 40.4, 354134.5 6690192.4 40.4, 354140.4 6690206.2 40.4, 354141.9 6690205.6 40.4, 354143.2 6690208.3 40.4, 354145.9 6690212.5 40.4, 354147.6 6690211.8 40.4, 354149.1 6690215.4 40.4, 354152.3 6690214 40.4, 354154.6 6690219.4 40.4, 354165.7 6690214.6 40.4, 354160.3 6690202.4 40.4, 354159.1 6690200.9 40.4, 354157.9 6690198 40.4, 354156.4 6690198.7 40.4, 354154.5 6690194.1 40.4, 354154.2 6690193.3 40.4, 354150.7 6690194.8 40.4, 354146.1 6690183.8 40.4, 354133.1 6690184.6 40.4, 354135.3 6690190.4 40.4))
BATIMENT0000000302935010;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;13.7;21.5;35.2;39.8;23.1;Cadastre;C 0.5;POLYGON Z ((354108.5 6690219.8 35.2, 354109.8 6690219.8 35.2, 354109.8 6690225 35.2, 354108.4 6690225.7 35.2, 354108.3 6690225.7 35.2, 354108.3 6690226.6 35.2, 354114.3 6690226.5 35.2, 354119.1 6690226.5 35.2, 354120.1 6690226.4 35.2, 354120 6690220.4 35.2, 354123.6 6690220.5 35.2, 354123.6 6690214.2 35.2, 354125.9 6690214.3 35.2, 354126.2 6690211.7 35.2, 354126.3 6690207.7 35.2, 354123.8 6690207.7 35.2, 354123.9 6690201.5 35.2, 354120.5 6690201.4 35.2, 354120.7 6690194.8 35.2, 354120.3 6690194.8 35.2, 354119.9 6690194.8 35.2, 354119.4 6690194.8 35.2, 354117.7 6690194.9 35.2, 354110 6690195.2 35.2, 354110 6690201.3 35.2, 354108.9 6690201.2 35.2, 354108.5 6690219.8 35.2))
BATIMENT0000000302935334;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;21.6;24.2;26.7;23.7;Cadastre;;POLYGON Z ((354137.6 6690216 24.2, 354141 6690214.6 24.2, 354139.4 6690210.9 24.2, 354136 6690212.3 24.2, 354137.6 6690216 24.2))
BATIMENT0000000302935138;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;01;3.3;28.0;31.3;34.0;28.9;Cadastre;B 0.3;POLYGON Z ((354254.8 6690197.3 31.3, 354256 6690201.3 31.3, 354262.3 6690199.8 31.3, 354261.3 6690195.9 31.3, 354254.8 6690197.3 31.3))
BATIMENT0000000302935280;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;6.6;26.0;32.6;38.7;27.0;Cadastre;A 1.0;POLYGON Z ((354185.9 6690199.8 32.6, 354183.2 6690200.6 32.6, 354185.9 6690206.9 32.6, 354187.7 6690206.5 32.6, 354197 6690204 32.6, 354198.3 6690203.7 32.6, 354197.7 6690201.4 32.6, 354196.4 6690201.7 32.6, 354194.5 6690194.4 32.6, 354188.2 6690196.1 32.6, 354185.1 6690196.9 32.6, 354185.9 6690199.8 32.6))
BATIMENT0000000302935098;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;13;40;6.7;27.1;33.9;35.4;27.9;Cadastre;A 1.0;POLYGON Z ((354212.2 6690204.3 33.9, 354213.7 6690204 33.9, 354220.7 6690202.2 33.9, 354219.6 6690197.9 33.9, 354211.1 6690199.9 33.9, 354211.9 6690202.6 33.9, 354212.2 6690204.3 33.9))
BATIMENT0000000302935099;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;26.7;34.4;37.9;27.8;Cadastre;;POLYGON Z ((354202.8 6690202.2 34.4, 354203 6690202.8 34.4, 354203.6 6690204.7 34.4, 354211.9 6690202.6 34.4, 354211.1 6690199.9 34.4, 354202.8 6690202.2 34.4))
BATIMENT0000000302935100;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.0;27.2;30.2;33.5;27.9;Cadastre;A 1.0;POLYGON Z ((354214.6 6690207.2 30.2, 354221.7 6690205.6 30.2, 354220.7 6690202.2 30.2, 354213.7 6690204 30.2, 354214.6 6690207.2 30.2))
BATIMENT0000000302935101;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;03;09;2.9;27.2;30.1;31.1;27.8;Cadastre;A 1.0;POLYGON Z ((354215.6 6690210.8 30.1, 354222.7 6690209.1 30.1, 354221.7 6690205.6 30.1, 354214.6 6690207.2 30.1, 354215.6 6690210.8 30.1))
BATIMENT0000000302935279;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;14;20;16.1;26.3;42.4;44.1;26.8;Cadastre;A 1.0;POLYGON Z ((354189.5 6690213.1 42.4, 354198.8 6690210.8 42.4, 354197 6690204 42.4, 354187.7 6690206.5 42.4, 354189.5 6690213.1 42.4))
BATIMENT0000000302935032;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;20;5.2;27.7;32.9;40.2;28.7;Cadastre;B 0.6;POLYGON Z ((354231.9 6690206.2 32.9, 354234 6690214 32.9, 354250 6690210 32.9, 354249.1 6690206.8 32.9, 354249 6690206.5 32.9, 354248.7 6690205.9 32.9, 354248.5 6690205.6 32.9, 354248.3 6690205.4 32.9, 354248 6690205.1 32.9, 354248 6690205 32.9, 354247.9 6690204.9 32.9, 354247.8 6690204.8 32.9, 354247.6 6690204.7 32.9, 354247.5 6690204.7 32.9, 354247.4 6690204.6 32.9, 354247.2 6690204.6 32.9, 354247.1 6690204.6 32.9, 354245.2 6690205.1 32.9, 354242.4 6690205.7 32.9, 354241.7 6690203.8 32.9, 354231.9 6690206.2 32.9))
BATIMENT0000000302935052;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;03;3.0;28.5;31.5;34.4;28.7;Cadastre;C 0.4;POLYGON Z ((354263 6690206.7 31.5, 354259.9 6690207.5 31.5, 354260.8 6690211 31.5, 354261.9 6690211.9 31.5, 354263.3 6690216.6 31.5, 354266.9 6690215.4 31.5, 354263.9 6690206.5 31.5, 354263 6690206.7 31.5))
BATIMENT0000000302935102;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;03;2.8;27.2;30.0;34.7;27.8;Cadastre;A 1.0;POLYGON Z ((354216.6 6690214.5 30, 354216.9 6690214.4 30, 354223.6 6690212.7 30, 354222.7 6690209.1 30, 354215.6 6690210.8 30, 354216.6 6690214.5 30))
BATIMENT0000000302935091;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;20;9.3;28.5;37.8;42.6;29.2;Cadastre;A 1.0;POLYGON Z ((354282.6 6690201.7 37.8, 354292.4 6690199.1 37.8, 354290.6 6690192.2 37.8, 354280.7 6690194.9 37.8, 354282.6 6690201.7 37.8))
BATIMENT0000000302935093;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;28.6;33.0;39.2;29.3;Cadastre;;POLYGON Z ((354277 6690203.2 33, 354277.3 6690203.7 33, 354276.5 6690204.3 33, 354276.3 6690204.6 33, 354276.3 6690204.7 33, 354276.2 6690204.8 33, 354276.2 6690205.1 33, 354276.2 6690205.3 33, 354276.2 6690205.4 33, 354276.2 6690205.7 33, 354276.3 6690205.8 33, 354276.4 6690206.1 33, 354276.5 6690206.2 33, 354276.5 6690206.3 33, 354276.6 6690206.4 33, 354276.9 6690206.6 33, 354277.1 6690206.8 33, 354277.3 6690206.8 33, 354277.5 6690206.9 33, 354277.8 6690206.9 33, 354278.1 6690206.9 33, 354278.4 6690207.7 33, 354282.1 6690206.8 33, 354281 6690202.1 33, 354277 6690203.2 33))
BATIMENT0000000302935092;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;10.9;28.8;39.7;42.2;29.3;Cadastre;C 0.9;POLYGON Z ((354282.6 6690201.7 39.7, 354281 6690202.1 39.7, 354282.1 6690206.8 39.7, 354282.6 6690208.5 39.7, 354281.3 6690208.7 39.7, 354282.5 6690213.7 39.7, 354286.7 6690212.6 39.7, 354295.1 6690210.3 39.7, 354292.4 6690199.1 39.7, 354282.6 6690201.7 39.7))
BATIMENT0000000302935257;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;9.7;27.8;37.5;39.7;29.7;Cadastre;C 0.9;POLYGON Z ((354312.9 6690215.3 37.5, 354319.4 6690216.5 37.5, 354322.8 6690217 37.5, 354323.4 6690213.9 37.5, 354321.1 6690213.6 37.5, 354322 6690206.5 37.5, 354325.1 6690206.9 37.5, 354326 6690207.1 37.5, 354326.7 6690203.8 37.5, 354326.6 6690203.8 37.5, 354322.5 6690203.1 37.5, 354315 6690201.8 37.5, 354312.9 6690215.3 37.5))
BATIMENT0000000302935109;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;30.0;32.7;34.0;30.0;Cadastre;;POLYGON Z ((354337.6 6690209.9 32.7, 354337.4 6690211.3 32.7, 354338.8 6690211.6 32.7, 354338.9 6690211.1 32.7, 354339.1 6690210 32.7, 354337.6 6690209.9 32.7))
BATIMENT0000000302935104;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.4;30.0;32.4;32.9;30.2;Cadastre;;POLYGON Z ((354335.1 6690218.7 32.4, 354337.6 6690219.1 32.4, 354337.9 6690217.1 32.4, 354338.2 6690215.4 32.4, 354336.3 6690215.2 32.4, 354336.1 6690216.2 32.4, 354335.4 6690216.1 32.4, 354335.1 6690218.7 32.4))
BATIMENT0000000302935094;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;9.1;28.5;37.6;41.6;29.3;Cadastre;C 0.8;POLYGON Z ((354287.1 6690213.4 37.6, 354285.5 6690216.3 37.6, 354282.3 6690217.2 37.6, 354285.1 6690226.2 37.6, 354292.7 6690223.9 37.6, 354296.7 6690216.7 37.6, 354295.1 6690210.3 37.6, 354286.7 6690212.6 37.6, 354287.1 6690213.4 37.6))
BATIMENT0000000302935056;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;3.0;28.5;31.5;33.7;28.8;Cadastre;C 0.3;POLYGON Z ((354275.3 6690229.4 31.5, 354272.9 6690222.7 31.5, 354271 6690216.7 31.5, 354267.7 6690217.6 31.5, 354270.1 6690224.7 31.5, 354272.1 6690230.5 31.5, 354275.3 6690229.4 31.5))
BATIMENT0000000302935259;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.6;27.8;37.4;40.5;29.2;Cadastre;A 1.0;POLYGON Z ((354310.5 6690231.2 37.4, 354320.2 6690232.6 37.4, 354320.8 6690229.1 37.4, 354317.7 6690228.5 37.4, 354319.4 6690216.5 37.4, 354312.9 6690215.3 37.4, 354310.5 6690231.2 37.4))
BATIMENT0000000302935057;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.9;28.5;31.4;33.7;28.9;Cadastre;C 0.4;POLYGON Z ((354281.4 6690227.5 31.4, 354279.1 6690220.9 31.4, 354272.9 6690222.7 31.4, 354275.3 6690229.4 31.4, 354281.4 6690227.5 31.4))
BATIMENT0000000302934033;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;23.5;29.5;32.7;23.6;Cadastre;;POLYGON Z ((354017.5 6690089.7 29.5, 354019 6690089.4 29.5, 354019.4 6690089.3 29.5, 354017.7 6690081 29.5, 354015.7 6690081.5 29.5, 354017.5 6690089.7 29.5))
BATIMENT0000000302918733;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;24.2;28.5;31.5;24.7;Cadastre;;POLYGON Z ((353957.2 6690089.9 28.5, 353958.1 6690093.6 28.5, 353964.9 6690092.3 28.5, 353964.1 6690088.9 28.5, 353957.2 6690089.9 28.5))
BATIMENT0000000302934030;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;23.5;28.7;32.2;24.0;Cadastre;;POLYGON Z ((354019.9 6690101.6 28.7, 354021.9 6690101.1 28.7, 354020.5 6690094.8 28.7, 354020.2 6690094.8 28.7, 354018.5 6690095.1 28.7, 354019.9 6690101.6 28.7))
BATIMENT0000000302918793;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;23;6.0;23.2;29.2;33.3;24.7;Cadastre;A 1.0;POLYGON Z ((353998.8 6690115.4 29.2, 353993.5 6690090 29.2, 353987.2 6690091 29.2, 353988.9 6690098.6 29.2, 353990.3 6690098.4 29.2, 353993.1 6690111.5 29.2, 353986.6 6690113 29.2, 353987.6 6690117.7 29.2, 353998.8 6690115.4 29.2))
BATIMENT0000000302934031;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;6.4;24.4;30.8;;;Cadastre;A 1.0;POLYGON Z ((354017 6690105.9 30.8, 354017.2 6690106.7 30.8, 354008.6 6690108.5 30.8, 354011.6 6690122.5 30.8, 354017.3 6690121.3 30.8, 354019.7 6690120.7 30.8, 354020.1 6690120.6 30.8, 354018.2 6690110.8 30.8, 354018.7 6690110.8 30.8, 354018.9 6690110.7 30.8, 354019.1 6690110.7 30.8, 354019.6 6690110.5 30.8, 354019.8 6690110.4 30.8, 354020 6690110.3 30.8, 354020.6 6690109.9 30.8, 354020.8 6690109.8 30.8, 354021.1 6690109.5 30.8, 354021.3 6690109.3 30.8, 354021.4 6690109.1 30.8, 354021.5 6690108.9 30.8, 354021.7 6690108.7 30.8, 354021.9 6690108.3 30.8, 354022 6690108.1 30.8, 354022.2 6690107.7 30.8, 354022.3 6690107.2 30.8, 354022.4 6690107 30.8, 354022.4 6690106.8 30.8, 354022.4 6690106.5 30.8, 354022.4 6690106.3 30.8, 354022.4 6690105.8 30.8, 354022.3 6690105.4 30.8, 354022.3 6690105.1 30.8, 354022.2 6690104.9 30.8, 354022.1 6690104.7 30.8, 354022.1 6690104.5 30.8, 354020.7 6690104.9 30.8, 354017.4 6690105.8 30.8, 354017 6690105.9 30.8))
BATIMENT0000000302918791;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;29;8.3;23.0;31.3;32.1;24.8;Cadastre;A 1.0;POLYGON Z ((353987.6 6690117.7 31.3, 353986.6 6690113 31.3, 353986.2 6690111 31.3, 353985.9 6690109.4 31.3, 353968 6690113.3 31.3, 353967.2 6690109.7 31.3, 353965.7 6690110 31.3, 353964.9 6690106.4 31.3, 353961.6 6690107.1 31.3, 353963.4 6690115.5 31.3, 353964.9 6690122.6 31.3, 353987.6 6690117.7 31.3))
BATIMENT0000000302918792;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;24.0;27.7;32.1;24.4;Cadastre;;POLYGON Z ((353963.4 6690115.5 27.7, 353960 6690116.3 27.7, 353960.1 6690117 27.7, 353959 6690116.7 27.7, 353958.3 6690119.7 27.7, 353959.4 6690121.5 27.7, 353964.9 6690122.6 27.7, 353963.4 6690115.5 27.7))
BATIMENT0000000302918788;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;12;5.9;23.7;29.7;35.7;24.2;Cadastre;A 1.0;POLYGON Z ((353999.4 6690117.9 29.7, 353989.9 6690120.1 29.7, 353992.6 6690134.2 29.7, 353998.5 6690133 29.7, 354002.3 6690132.3 29.7, 353999.4 6690117.9 29.7))
BATIMENT0000000302918789;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1975-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;90;90;18.3;23.3;41.7;45.1;24.2;Cadastre;A 1.0;POLYGON Z ((353987.8 6690135.2 41.7, 353991.3 6690151.9 41.7, 354000 6690150.1 41.7, 354002.2 6690149.6 41.7, 353998.5 6690133 41.7, 353992.6 6690134.2 41.7, 353987.8 6690135.2 41.7))
BATIMENT0000000302919081;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;16;19;7.1;22.7;29.8;35.2;24.6;Cadastre;A 1.0;POLYGON Z ((353963.8 6690153.6 29.8, 353963.7 6690153.1 29.8, 353969.5 6690151.8 29.8, 353968.4 6690147.1 29.8, 353967.2 6690141.5 29.8, 353961.9 6690142.7 29.8, 353962.5 6690145.6 29.8, 353962.1 6690145.7 29.8, 353962.1 6690145.4 29.8, 353957.6 6690146.4 29.8, 353958.2 6690149.1 29.8, 353953.7 6690150.1 29.8, 353953.8 6690150.4 29.8, 353949.2 6690151.3 29.8, 353950.5 6690157.6 29.8, 353958.2 6690156 29.8, 353957.9 6690154.8 29.8, 353963.8 6690153.6 29.8))
BATIMENT0000000302935210;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;24.7;36.5;37.3;25.7;Cadastre;;POLYGON Z ((354071.4 6690094.9 36.5, 354080.9 6690095.3 36.5, 354081.1 6690091.3 36.5, 354077.8 6690091.1 36.5, 354076 6690092.1 36.5, 354071.5 6690091.8 36.5, 354071.4 6690094.9 36.5))
BATIMENT0000000302935212;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;34;20;11.0;24.6;35.6;37.6;25.8;Cadastre;A 1.0;POLYGON Z ((354070.9 6690099.7 35.6, 354080.7 6690097.6 35.6, 354080.9 6690095.3 35.6, 354071.4 6690094.9 35.6, 354070.9 6690099.7 35.6))
BATIMENT0000000302935213;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;40;20;8.8;24.8;33.6;36.5;25.8;Cadastre;A 1.0;POLYGON Z ((354069.2 6690100.2 33.6, 354071.6 6690112.1 33.6, 354074.8 6690111.3 33.6, 354081.4 6690109.7 33.6, 354080.3 6690104.9 33.6, 354080.7 6690097.6 33.6, 354070.9 6690099.7 33.6, 354069.2 6690100.2 33.6))
BATIMENT0000000302935214;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;3.3;24.1;27.5;33.2;25.2;Cadastre;C 0.5;POLYGON Z ((354075.8 6690115.8 27.5, 354082.4 6690114.1 27.5, 354081.4 6690109.7 27.5, 354074.8 6690111.3 27.5, 354075.8 6690115.8 27.5))
BATIMENT0000000302934032;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;35;20;5.5;23.4;29.0;43.7;25.0;Cadastre;A 1.0;POLYGON Z ((354013.9 6690133.2 29, 354018 6690132.4 29, 354026.9 6690130.5 29, 354030.7 6690129.7 29, 354049.5 6690125.7 29, 354049 6690123.4 29, 354047.4 6690117 29, 354047 6690115 29, 354041.6 6690116.2 29, 354043 6690122.2 29, 354041.5 6690122.2 29, 354039.5 6690123 29, 354038.6 6690122.7 29, 354036.6 6690123.7 29, 354035.5 6690123.5 29, 354032.9 6690124.7 29, 354032 6690124.1 29, 354030 6690125.3 29, 354029 6690124.8 29, 354027 6690125.9 29, 354026.1 6690125.6 29, 354023.8 6690126.7 29, 354023 6690126.1 29, 354021.1 6690127.3 29, 354019.7 6690120.7 29, 354017.3 6690121.3 29, 354011.6 6690122.5 29, 354013.9 6690133.2 29))
BATIMENT0000000302934037;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;03;04;4.7;24.4;29.1;35.0;25.3;Cadastre;C 0.3;POLYGON Z ((354051.3 6690132.4 29.1, 354054.8 6690131.4 29.1, 354053.9 6690128.5 29.1, 354054.3 6690128.2 29.1, 354052.8 6690122.4 29.1, 354049 6690123.4 29.1, 354049.5 6690125.7 29.1, 354051.3 6690132.4 29.1))
BATIMENT0000000302935332;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;6.8;23.1;30.0;31.2;24.0;Cadastre;;POLYGON Z ((354039.5 6690135 30, 354043.4 6690134.2 30, 354043 6690132.3 30, 354039.1 6690133.1 30, 354039.5 6690135 30))
BATIMENT0000000302935317;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;26;23;9.0;23.7;32.7;35.5;25.2;Cadastre;C 0.7;POLYGON Z ((354084.8 6690126.7 32.7, 354078.7 6690128.3 32.7, 354079.9 6690133.7 32.7, 354077.8 6690136.5 32.7, 354072.8 6690137.8 32.7, 354074.1 6690142 32.7, 354074.9 6690144.5 32.7, 354088 6690140.1 32.7, 354084.8 6690126.7 32.7))
BATIMENT0000000302935316;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.9;22.7;28.6;31.0;25.2;Cadastre;;POLYGON Z ((354073.1 6690142.3 28.6, 354072.9 6690142 28.6, 354066.7 6690144.1 28.6, 354067.6 6690146.9 28.6, 354072.6 6690145.4 28.6, 354074.9 6690144.5 28.6, 354074.1 6690142 28.6, 354073.1 6690142.3 28.6))
BATIMENT0000000302935315;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;4.0;;;16.2;21.0;37.2;41.1;25.2;Cadastre;A 1.0;POLYGON Z ((354073.6 6690150.4 37.2, 354066.1 6690152.3 37.2, 354065.8 6690150.7 37.2, 354056.7 6690157 37.2, 354061.1 6690173.2 37.2, 354065 6690172.3 37.2, 354064.9 6690171.9 37.2, 354077.8 6690169.1 37.2, 354081 6690181.8 37.2, 354083 6690181.1 37.2, 354091.3 6690178.3 37.2, 354096.4 6690177.4 37.2, 354096.5 6690176.5 37.2, 354088 6690140.1 37.2, 354074.9 6690144.5 37.2, 354072.6 6690145.4 37.2, 354073.6 6690150.4 37.2))
BATIMENT0000000302918651;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;8.4;21.8;30.2;33.9;23.0;Cadastre;A 1.0;POLYGON Z ((353895.9 6690125 30.2, 353897.7 6690124.4 30.2, 353893.7 6690112.9 30.2, 353892.0022898072 6690113.6818402205 30.2, 353892.0022898072 6690126.299236731 30.2, 353895.9 6690125 30.2))
BATIMENT0000000302918650;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;45;10;8.7;21.2;30.0;33.5;23.6;Cadastre;A 1.0;POLYGON Z ((353894.4 6690136.2 30, 353899.1 6690134.6 30, 353895.9 6690125 30, 353892.0022898072 6690126.299236731 30, 353892.0022898072 6690137.059556484 30, 353894.4 6690136.2 30))
BATIMENT0000000302918861;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;23.7;26.9;28.0;24.4;Cadastre;;POLYGON Z ((353926.9 6690132.6 26.9, 353923.7 6690133.3 26.9, 353925.2 6690137.4 26.9, 353928.1 6690136.3 26.9, 353926.9 6690132.6 26.9))
BATIMENT0000000302918860;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;23.8;30.5;32.0;24.2;Cadastre;;POLYGON Z ((353949.1 6690137.6 30.5, 353948.2 6690133.4 30.5, 353944.1 6690134.2 30.5, 353945.1 6690138.6 30.5, 353949.1 6690137.6 30.5))
BATIMENT0000000302918858;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.3;23.0;31.3;33.6;24.2;Cadastre;C 0.4;POLYGON Z ((353945.1 6690138.6 31.3, 353944.1 6690134.2 31.3, 353948.2 6690133.4 31.3, 353947.1 6690128.2 31.3, 353930.8 6690131.3 31.3, 353932.4 6690137.3 31.3, 353936.3 6690136.5 31.3, 353937 6690139.1 31.3, 353937.6 6690139.4 31.3, 353941.1 6690138.5 31.3, 353941.9 6690141.9 31.3, 353939.6 6690142.5 31.3, 353940.6 6690145.3 31.3, 353946.2 6690143.3 31.3, 353945.1 6690138.6 31.3))
BATIMENT0000000302918859;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.4;23.7;27.1;28.5;24.5;Cadastre;C 0.2;POLYGON Z ((353925.2 6690137.4 27.1, 353923.7 6690133.3 27.1, 353921.5 6690126.8 27.1, 353917.6 6690128.1 27.1, 353915.9 6690128.7 27.1, 353923.8 6690151.1 27.1, 353929.6 6690149.1 27.1, 353925.2 6690137.4 27.1))
BATIMENT0000000302918857;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;3.6;23.6;27.2;28.3;24.1;Cadastre;C 0.2;POLYGON Z ((353933.1 6690145.3 27.2, 353932.2 6690145.6 27.2, 353930 6690139.5 27.2, 353929.6 6690139.7 27.2, 353928.1 6690136.3 27.2, 353925.2 6690137.4 27.2, 353929.6 6690149.1 27.2, 353933.9 6690147.6 27.2, 353933.1 6690145.3 27.2))
BATIMENT0000000302918648;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;35;40;14.4;23.0;37.5;40.2;24.1;Cadastre;C 0.6;POLYGON Z ((353902.1 6690158.6 37.5, 353911.2 6690155.5 37.5, 353908.3 6690147.4 37.5, 353915.4 6690144.7 37.5, 353913.3 6690138.8 37.5, 353907.4 6690140.8 37.5, 353907.1 6690140.1 37.5, 353905.6 6690139.8 37.5, 353903.3 6690133.2 37.5, 353899.1 6690134.6 37.5, 353894.4 6690136.2 37.5, 353902.1 6690158.6 37.5))
BATIMENT0000000302918856;Industriel, agricole ou commercial;Industriel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.2;23.5;26.7;28.0;24.1;Cadastre;C 0.3;POLYGON Z ((353922.9 6690151.4 26.7, 353924.7 6690157.4 26.7, 353947.5 6690149.4 26.7, 353946.2 6690143.3 26.7, 353940.6 6690145.3 26.7, 353933.9 6690147.6 26.7, 353929.6 6690149.1 26.7, 353923.8 6690151.1 26.7, 353922.9 6690151.4 26.7))
BATIMENT0000000302919080;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:58;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;22.7;26.2;32.0;23.7;Cadastre;;POLYGON Z ((353944.9 6690156.6 26.2, 353945.1 6690157.9 26.2, 353940 6690158.8 26.2, 353940.9 6690161.6 26.2, 353948.9 6690159.8 26.2, 353948 6690156 26.2, 353944.9 6690156.6 26.2))
BATIMENT0000000302935314;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.4;22.0;28.5;33.7;23.0;Cadastre;;POLYGON Z ((354061.3 6690174 28.5, 354054.5 6690175.6 28.5, 354055.8 6690181.4 28.5, 354062.6 6690179.9 28.5, 354061.3 6690174 28.5))
BATIMENT0000000302934038;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;30.0;6.0;00;00;16.4;21.3;37.7;40.6;23.5;Cadastre;C 0.3;POLYGON Z ((354018 6690132.4 37.7, 354019.2 6690138.2 37.7, 354018.2 6690138.5 37.7, 354019.4 6690143.8 37.7, 354019.8 6690143.7 37.7, 354020.6 6690147.2 37.7, 354020.1 6690147.3 37.7, 354022.6 6690159 37.7, 354023.6 6690158.8 37.7, 354024.9 6690165.2 37.7, 354023.9 6690165.4 37.7, 354026.1 6690175.4 37.7, 354027.2 6690175.2 37.7, 354029.8 6690187 37.7, 354028.6 6690187.3 37.7, 354030.8 6690197.7 37.7, 354031.6 6690197.5 37.7, 354032.9 6690203.7 37.7, 354032.1 6690203.9 37.7, 354034.6 6690215.8 37.7, 354035.2 6690215.7 37.7, 354036 6690219.5 37.7, 354035.6 6690219.6 37.7, 354036.7 6690224.5 37.7, 354037.4 6690224.3 37.7, 354038.8 6690230.7 37.7, 354039.3 6690230.6 37.7, 354044.6 6690229.4 37.7, 354050.1 6690228.2 37.7, 354051.5 6690227.9 37.7, 354050.1 6690221.5 37.7, 354051.6 6690221.2 37.7, 354048.1 6690204.6 37.7, 354046.6 6690204.9 37.7, 354045.8 6690201.3 37.7, 354047.3 6690201 37.7, 354046.8 6690198.6 37.7, 354045.3 6690198.9 37.7, 354043.5 6690190.4 37.7, 354045 6690190.1 37.7, 354043.4 6690182.7 37.7, 354042 6690183 37.7, 354040.1 6690174.3 37.7, 354041.6 6690174 37.7, 354040 6690166.5 37.7, 354038.5 6690166.8 37.7, 354036.7 6690158.4 37.7, 354038.2 6690158.1 37.7, 354037.7 6690155.5 37.7, 354036.2 6690155.8 37.7, 354035.4 6690152.2 37.7, 354036.9 6690151.9 37.7, 354032.9 6690133 37.7, 354031.4 6690133.3 37.7, 354030.7 6690129.7 37.7, 354026.9 6690130.5 37.7, 354018 6690132.4 37.7))
BATIMENT0000000302935318;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;10.2;22.2;32.5;37.5;23.6;Cadastre;A 1.0;POLYGON Z ((354083.3 6690184.8 32.5, 354078.1 6690186.8 32.5, 354078.7 6690197 32.5, 354097.7 6690197.6 32.5, 354096.4 6690177.4 32.5, 354091.3 6690178.3 32.5, 354083 6690181.1 32.5, 354083.3 6690184.8 32.5))
BATIMENT0000000302935331;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.0;21.9;27.0;27.8;22.7;Cadastre;;POLYGON Z ((354060 6690186.6 27, 354060.8 6690190.2 27, 354062.8 6690189.7 27, 354062 6690186.1 27, 354060 6690186.6 27))
BATIMENT0000000302935179;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;5.0;23.1;28.1;32.3;23.2;Cadastre;A 1.0;POLYGON Z ((354090 6690202.2 28.1, 354089.8 6690212.4 28.1, 354088.2 6690212.6 28.1, 354086.7 6690214.5 28.1, 354086.8 6690217.7 28.1, 354088.2 6690219.4 28.1, 354090 6690219.4 28.1, 354090 6690220.5 28.1, 354092.9 6690219.8 28.1, 354098.7 6690217.6 28.1, 354098.9 6690202.2 28.1, 354090 6690202.2 28.1))
BATIMENT0000000302934793;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.3;22.7;29.0;;;Cadastre;A 1.0;POLYGON Z ((354098.5 6690228.5 29, 354097.3 6690228.6 29, 354097.2 6690222.7 29, 354089.1 6690222.4 29, 354088.6 6690242.4 29, 354092.2 6690241.4 29, 354098.4 6690239.9 29, 354098.5 6690228.5 29))
BATIMENT0000000302934039;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1968-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;50;40;5.7;20.7;26.5;39.6;22.1;Cadastre;A 1.0;POLYGON Z ((354045.8 6690262.7 26.5, 354049.8 6690261.4 26.5, 354061.7 6690257.3 26.5, 354069.9 6690254.4 26.5, 354063.4 6690225.3 26.5, 354051.5 6690227.9 26.5, 354050.1 6690228.2 26.5, 354044.6 6690229.4 26.5, 354039.3 6690230.6 26.5, 354045.8 6690262.7 26.5))
BATIMENT0000000302934794;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;3.5;21.6;25.1;27.3;21.9;Cadastre;A 1.0;POLYGON Z ((354091.9 6690246.3 25.1, 354093.4 6690246.4 25.1, 354093.2 6690251.7 25.1, 354087 6690251.6 25.1, 354086.9 6690249.4 25.1, 354081 6690249.5 25.1, 354081.7 6690252.5 25.1, 354082.4 6690255.2 25.1, 354098.1 6690254.8 25.1, 354098.4 6690239.9 25.1, 354092.2 6690241.4 25.1, 354091.9 6690246.3 25.1))
BATIMENT0000000302934796;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;21.0;25.2;25.7;21.6;Cadastre;;POLYGON Z ((354076.5 6690251 25.2, 354077.4 6690253.9 25.2, 354081.7 6690252.5 25.2, 354081 6690249.5 25.2, 354076.5 6690251 25.2))
BATIMENT0000000302934795;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.4;21.6;26.0;28.2;21.6;Cadastre;;POLYGON Z ((354083.1 6690258.5 26, 354087 6690258.6 26, 354087 6690259.8 26, 354090.5 6690259.8 26, 354090.5 6690261.9 26, 354091.9 6690261.9 26, 354091.7 6690265.7 26, 354098 6690265.2 26, 354098.1 6690260.1 26, 354098.1 6690254.8 26, 354082.4 6690255.2 26, 354083.1 6690258.5 26))
BATIMENT0000000302918647;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;6.0;35;90;16.5;22.3;38.8;39.6;23.8;Cadastre;C 0.5;POLYGON Z ((353910.1 6690181 38.8, 353920.4 6690177.3 38.8, 353921.3 6690177.1 38.8, 353913.3 6690154.8 38.8, 353911.2 6690155.5 38.8, 353902.1 6690158.6 38.8, 353910.1 6690181 38.8))
BATIMENT0000000302918786;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.1;22.5;24.6;30.2;23.5;Cadastre;C 0.3;POLYGON Z ((353926.7 6690168.6 24.6, 353928.7 6690173.9 24.6, 353942.4 6690169 24.6, 353940.7 6690163.6 24.6, 353926.7 6690168.6 24.6))
BATIMENT0000000302918649;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;00;00;16.9;22.2;39.1;40.3;23.1;Cadastre;C 0.6;POLYGON Z ((353917.8 6690203.2 39.1, 353928.2 6690199.5 39.1, 353920.4 6690177.3 39.1, 353910.1 6690181 39.1, 353917.8 6690203.2 39.1))
BATIMENT0000000302918795;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.1;23.0;25.1;35.7;23.4;Cadastre;C 0.3;POLYGON Z ((353931.8 6690192.4 25.1, 353933.5 6690197.7 25.1, 353952.2 6690191.4 25.1, 353950.1 6690186 25.1, 353931.8 6690192.4 25.1))
BATIMENT0000000302919094;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;6.0;00;00;5.7;22.9;28.7;41.8;25.9;Cadastre;A 1.0;POLYGON Z ((353897.6 6690212.8 28.7, 353897.5 6690212.3 28.7, 353896.8 6690212.5 28.7, 353895.6 6690208.8 28.7, 353896.3 6690208.5 28.7, 353892.0022898072 6690196.6180953495 28.7, 353892.0022898072 6690214.766763041 28.7, 353897.6 6690212.8 28.7))
BATIMENT0000000302918652;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;17.1;22.1;39.2;40.0;23.1;Cadastre;C 0.4;POLYGON Z ((353922.2 6690215.6 39.2, 353923 6690215.3 39.2, 353933.4 6690211.8 39.2, 353933.8 6690211.6 39.2, 353929.5 6690199 39.2, 353928.2 6690199.5 39.2, 353917.8 6690203.2 39.2, 353922.2 6690215.6 39.2))
BATIMENT0000000302918659;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.3;21.9;25.2;32.2;22.7;Cadastre;C 0.3;POLYGON Z ((353958 6690207.9 25.2, 353940 6690214 25.2, 353941.8 6690219.3 25.2, 353954.1 6690215.1 25.2, 353959.9 6690213.2 25.2, 353958 6690207.9 25.2))
BATIMENT0000000302918654;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.8;21.3;28.1;34.5;22.5;Cadastre;A 1.0;POLYGON Z ((353915.3 6690217.9 28.1, 353918.5 6690227.5 28.1, 353925.4 6690225.2 28.1, 353926.2 6690224.9 28.1, 353923 6690215.3 28.1, 353922.2 6690215.6 28.1, 353915.3 6690217.9 28.1))
BATIMENT0000000302918655;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;6.0;00;00;17.0;21.3;38.3;39.5;22.3;Cadastre;C 0.6;POLYGON Z ((353928.8 6690235 38.3, 353940.6 6690230.8 38.3, 353937 6690221 38.3, 353936.8 6690221.1 38.3, 353926.2 6690224.9 38.3, 353925.4 6690225.2 38.3, 353928.8 6690235 38.3))
BATIMENT0000000302919095;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;7.0;00;00;9.8;21.7;31.5;40.7;25.8;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6690214.766763041 31.5, 353892.0022898072 6690238.229321439 31.5, 353905 6690233.6 31.5, 353905.3 6690233.5 31.5, 353897.6 6690212.8 31.5, 353892.0022898072 6690214.766763041 31.5))
BATIMENT0000000302918790;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1972-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;31.0;6.0;50;40;18.2;23.1;41.3;41.9;24.1;Cadastre;A 1.0;POLYGON Z ((353988.5 6690152.7 41.3, 353990.6 6690162.4 41.3, 353988.9 6690162.7 41.3, 353993.3 6690184.2 41.3, 354002.2 6690182.3 41.3, 354006.5 6690181.4 41.3, 354004.9 6690173.4 41.3, 354007 6690172.8 41.3, 354003.9 6690158.1 41.3, 354001.8 6690158.4 41.3, 354000 6690150.1 41.3, 353991.3 6690151.9 41.3, 353988.5 6690152.7 41.3))
BATIMENT0000000302934018;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;14;4.9;22.7;27.6;35.0;23.7;Cadastre;B 0.4;POLYGON Z ((354003.2 6690186.5 27.6, 354013.5 6690184.5 27.6, 354012.7 6690180.3 27.6, 354006.5 6690181.4 27.6, 354002.2 6690182.3 27.6, 354003.2 6690186.5 27.6))
BATIMENT0000000302918884;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;01;5.8;22.8;28.7;32.3;23.7;Cadastre;B 0.3;POLYGON Z ((353963.6 6690190 28.7, 353964.6 6690194 28.7, 353965.5 6690193.9 28.7, 353965.8 6690194.8 28.7, 353972.5 6690193.4 28.7, 353972.3 6690192.5 28.7, 353973.4 6690192.3 28.7, 353972.7 6690188.2 28.7, 353963.6 6690190 28.7))
BATIMENT0000000302934019;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;9.7;22.5;32.2;36.5;23.7;Cadastre;B 1.0;POLYGON Z ((354003.5 6690187.8 32.2, 354004.3 6690192.1 32.2, 354002.3 6690192.5 32.2, 354001.1 6690194.1 32.2, 354001.7 6690197.1 32.2, 354001.9 6690198.4 32.2, 354005.4 6690197.7 32.2, 354016 6690195.4 32.2, 354013.8 6690185.8 32.2, 354003.5 6690187.8 32.2))
BATIMENT0000000302934020;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;9.3;22.1;31.5;37.2;23.2;Cadastre;A 1.0;POLYGON Z ((354007.6 6690208.1 31.5, 354015.1 6690206.6 31.5, 354015.2 6690207 31.5, 354018.3 6690206.6 31.5, 354016 6690195.4 31.5, 354005.4 6690197.7 31.5, 354007.6 6690208.1 31.5))
BATIMENT0000000302918658;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:58;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;21.9;25.2;31.0;22.5;Cadastre;;POLYGON Z ((353957.4 6690224.9 25.2, 353963.1 6690223 25.2, 353962.7 6690221.8 25.2, 353959.9 6690213.2 25.2, 353954.1 6690215.1 25.2, 353957.4 6690224.9 25.2))
BATIMENT0000000302934896;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;34;20;5.0;22.0;27.0;29.6;22.4;Cadastre;A 1.0;POLYGON Z ((354007.7 6690215.5 27, 354010.4 6690229.7 27, 354021.8 6690227.4 27, 354018.8 6690213.2 27, 354007.7 6690215.5 27))
BATIMENT0000000302934897;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;3.0;21.2;24.3;24.8;22.0;Cadastre;C 0.5;POLYGON Z ((354009.5 6690231.8 24.3, 354010.2 6690234.8 24.3, 354015.3 6690233.4 24.3, 354015.4 6690233.7 24.3, 354022.8 6690232.3 24.3, 354022.1 6690229.1 24.3, 354009.5 6690231.8 24.3))
BATIMENT0000000302934898;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;4.7;20.8;25.5;29.2;21.7;Cadastre;C 0.5;POLYGON Z ((354023.9 6690237 25.5, 354018.4 6690238.2 25.5, 354017.7 6690235.7 25.5, 354014.7 6690236.3 25.5, 354014.6 6690235.7 25.5, 354010.6 6690236.6 25.5, 354012.1 6690244.3 25.5, 354016.3 6690243.5 25.5, 354024.9 6690241.8 25.5, 354023.9 6690237 25.5))
BATIMENT0000000302918636;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;10;6.7;20.8;27.5;31.3;22.2;Cadastre;A 1.0;POLYGON Z ((353986.8 6690249 27.5, 353985.6 6690242.5 27.5, 353988.8 6690241.7 27.5, 353987.4 6690235.4 27.5, 353974.8 6690238.1 27.5, 353977.3 6690250.8 27.5, 353979.5 6690250.4 27.5, 353986.8 6690249 27.5))
BATIMENT0000000302918656;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;35;20;2.6;21.1;23.7;39.6;22.1;Cadastre;A 1.0;POLYGON Z ((353933 6690247.2 23.7, 353956.2 6690239 23.7, 353960.1 6690237.6 23.7, 353955.8 6690225.5 23.7, 353940.6 6690230.8 23.7, 353928.8 6690235 23.7, 353933 6690247.2 23.7))
BATIMENT0000000302919096;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;7.0;00;00;15.0;20.3;35.4;41.4;23.7;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6690238.229321439 35.4, 353892.0022898072 6690262.62052057 35.4, 353912.7 6690255 35.4, 353905 6690233.6 35.4, 353892.0022898072 6690238.229321439 35.4))
BATIMENT0000000302918657;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;7.0;50;20;13.4;19.3;32.7;40.4;22.2;Cadastre;A 1.0;POLYGON Z ((353939.1 6690264.3 32.7, 353957.2 6690258 32.7, 353959.2 6690263.2 32.7, 353960 6690262.9 32.7, 353964.4 6690261.4 32.7, 353956.2 6690239 32.7, 353933 6690247.2 32.7, 353939.1 6690264.3 32.7))
BATIMENT0000000302919097;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;6.0;50;40;10.2;19.7;29.9;41.0;20.9;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6690262.62052057 29.9, 353892.0022898072 6690266.801244715 29.9, 353894.5 6690273.9 29.9, 353908.5 6690268.5 29.9, 353916.1 6690265.6 29.9, 353916.4 6690265.5 29.9, 353912.7 6690255 29.9, 353892.0022898072 6690262.62052057 29.9))
BATIMENT0000000302918660;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;00;00;5.3;17.8;23.1;26.4;22.0;Cadastre;A 1.0;POLYGON Z ((353934.2 6690271.7 23.1, 353935.4 6690274.8 23.1, 353935.1 6690275 23.1, 353937.2 6690281.3 23.1, 353939 6690280.7 23.1, 353942.6 6690279.3 23.1, 353941.3 6690275.2 23.1, 353961.7 6690268.2 23.1, 353960 6690262.9 23.1, 353959.2 6690263.2 23.1, 353934.2 6690271.7 23.1))
BATIMENT0000000302919098;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;10.7;18.5;29.2;35.5;20.1;Cadastre;A 1.0;POLYGON Z ((353908.5 6690268.5 29.2, 353912.5 6690280 29.2, 353923.4 6690276.2 29.2, 353919.6 6690265.7 29.2, 353916.5 6690266.8 29.2, 353916.1 6690265.6 29.2, 353908.5 6690268.5 29.2))
BATIMENT0000000302918887;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;17.5;21.2;24.1;18.2;Cadastre;;POLYGON Z ((353953.2 6690289.5 21.2, 353950.5 6690282.2 21.2, 353948 6690283.2 21.2, 353950.6 6690290.5 21.2, 353953.2 6690289.5 21.2))
BATIMENT0000000302918886;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;40;6.2;17.6;23.8;25.1;18.3;Cadastre;A 1.0;POLYGON Z ((353948 6690283.2 23.8, 353940.5 6690285.7 23.8, 353943.1 6690293.2 23.8, 353950.6 6690290.5 23.8, 353948 6690283.2 23.8))
BATIMENT0000000302918817;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;5.9;17.5;23.4;25.9;18.4;Cadastre;A 1.0;POLYGON Z ((353915.6 6690291.6 23.4, 353919.7 6690302.9 23.4, 353921.5 6690302.2 23.4, 353931.6 6690298.6 23.4, 353927.4 6690287.5 23.4, 353915.6 6690291.6 23.4))
BATIMENT0000000302918885;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;40;5.9;17.6;23.5;25.2;18.0;Cadastre;A 1.0;POLYGON Z ((353945.8 6690300.9 23.5, 353952.7 6690298.3 23.5, 353951.6 6690295.8 23.5, 353952.5 6690295.3 23.5, 353950.6 6690290.5 23.5, 353943.1 6690293.2 23.5, 353945.8 6690300.9 23.5))
BATIMENT0000000302934899;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;7.5;20.4;28.0;30.4;21.4;Cadastre;A 1.0;POLYGON Z ((354018.8 6690255.3 28, 354027.4 6690253.5 28, 354024.9 6690241.8 28, 354016.3 6690243.5 28, 354018.8 6690255.3 28))
BATIMENT0000000302934900;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.7;18.1;26.8;30.5;20.8;Cadastre;A 1.0;POLYGON Z ((354027.7 6690255.2 26.8, 354017.5 6690257.3 26.8, 354018.1 6690259.7 26.8, 354014.3 6690260.9 26.8, 354015.1 6690265.5 26.8, 354016.4 6690265.1 26.8, 354019.7 6690264 26.8, 354019.5 6690262.9 26.8, 354028.9 6690261.1 26.8, 354027.7 6690255.2 26.8))
BATIMENT0000000302934901;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;24;7.3;19.2;26.5;30.0;20.3;Cadastre;A 1.0;POLYGON Z ((354018.5 6690272.7 26.5, 354030.6 6690268.6 26.5, 354028.9 6690261.1 26.5, 354019.5 6690262.9 26.5, 354019.7 6690264 26.5, 354016.4 6690265.1 26.5, 354018.5 6690272.7 26.5))
BATIMENT0000000302934902;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;12.5;19.2;31.7;35.9;20.0;Cadastre;A 1.0;POLYGON Z ((354011.9 6690275.2 31.7, 354016 6690285.9 31.7, 354023.8 6690283.4 31.7, 354033 6690280.1 31.7, 354030.6 6690268.6 31.7, 354018.5 6690272.7 31.7, 354011.9 6690275.2 31.7))
BATIMENT0000000302935197;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;18.5;22.2;23.4;18.7;Cadastre;;POLYGON Z ((354021.2 6690298.8 22.2, 354022.1 6690302.3 22.2, 354025.1 6690301.5 22.2, 354024.2 6690297.7 22.2, 354021.2 6690298.8 22.2))
BATIMENT0000000302918888;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;40;20;8.2;16.3;24.5;26.4;17.9;Cadastre;A 1.0;POLYGON Z ((353949.1 6690310.2 24.5, 353959.4 6690306.5 24.5, 353960.7 6690306 24.5, 353959.9 6690303.7 24.5, 353959.8 6690303.5 24.5, 353959.6 6690303.3 24.5, 353959.4 6690303.1 24.5, 353959.2 6690303 24.5, 353959 6690302.8 24.5, 353958.7 6690302.7 24.5, 353958.5 6690302.6 24.5, 353958.2 6690302.5 24.5, 353957.7 6690302.4 24.5, 353957.2 6690302.4 24.5, 353956.9 6690302.4 24.5, 353956.6 6690302.4 24.5, 353954.8 6690302.9 24.5, 353953.1 6690298.3 24.5, 353952.7 6690298.3 24.5, 353945.8 6690300.9 24.5, 353949.1 6690310.2 24.5))
BATIMENT0000000302918839;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;17.5;21.0;23.5;18.4;Cadastre;;POLYGON Z ((353992.2 6690305.9 21, 353993.6 6690309.9 21, 353997.3 6690308.6 21, 353995.9 6690304.6 21, 353992.2 6690305.9 21))
BATIMENT0000000302935351;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;18.0;20.6;21.4;18.6;Cadastre;;POLYGON Z ((354014.8 6690306.5 20.6, 354016.7 6690312.2 20.6, 354019.8 6690311.2 20.6, 354017.7 6690305.5 20.6, 354014.8 6690306.5 20.6))
BATIMENT0000000302918838;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;4.1;17.6;21.7;25.7;18.5;Cadastre;C 0.3;POLYGON Z ((353998.9 6690313.3 21.7, 353995.4 6690314.5 21.7, 353995.5 6690315.1 21.7, 353996.8 6690318.7 21.7, 354007.7 6690315.2 21.7, 354010.2 6690314.4 21.7, 354009.4 6690311.9 21.7, 354007.4 6690310.5 21.7, 354006.5 6690310.8 21.7, 354003.3 6690302 21.7, 353995.9 6690304.6 21.7, 353997.3 6690308.6 21.7, 353998.9 6690313.3 21.7))
BATIMENT0000000302918889;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;9.2;15.9;25.1;27.0;16.5;Cadastre;A 1.0;POLYGON Z ((353952.6 6690319.8 25.1, 353960.5 6690316.9 25.1, 353963 6690316.1 25.1, 353959.4 6690306.5 25.1, 353949.1 6690310.2 25.1, 353952.6 6690319.8 25.1))
BATIMENT0000000302934040;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;13;8.6;19.6;28.2;34.2;21.0;Cadastre;A 1.0;POLYGON Z ((354041.5 6690264.3 28.2, 354043.9 6690275 28.2, 354050.9 6690273.2 28.2, 354050 6690268.9 28.2, 354051.4 6690268.6 28.2, 354049.8 6690261.4 28.2, 354045.8 6690262.7 28.2, 354041.5 6690264.3 28.2))
BATIMENT0000000302934044;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;35;30;5.4;22.0;27.4;;;Cadastre;A 1.0;POLYGON Z ((354097.6 6690281.9 27.4, 354097.8 6690270.2 27.4, 354092.8 6690270.2 27.4, 354092.9 6690275.1 27.4, 354087.3 6690276.3 27.4, 354088.3 6690279.8 27.4, 354091.7 6690285.4 27.4, 354097.6 6690281.9 27.4))
BATIMENT0000000302934043;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;4.3;22.0;26.3;;;Cadastre;A 1.0;POLYGON Z ((354085.8 6690269.7 26.3, 354083.5 6690270.3 26.3, 354084.9 6690275.5 26.3, 354079.5 6690277.2 26.3, 354081.9 6690284.6 26.3, 354084.6 6690282.7 26.3, 354088.7 6690289.6 26.3, 354093.3 6690288 26.3, 354091.7 6690285.4 26.3, 354088.3 6690279.8 26.3, 354087.3 6690276.3 26.3, 354085.8 6690269.7 26.3))
BATIMENT0000000302934042;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;10;10.7;19.5;30.2;32.5;20.4;Cadastre;A 1.0;POLYGON Z ((354073.7 6690290.9 30.2, 354080.4 6690285.8 30.2, 354077.2 6690277 30.2, 354069.7 6690279.8 30.2, 354071.2 6690284.2 30.2, 354072.3 6690287.3 30.2, 354073.7 6690290.9 30.2))
BATIMENT0000000302934041;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;3.0;00;00;11.2;19.2;30.4;33.4;20.3;Cadastre;A 1.0;POLYGON Z ((354057.7 6690288.3 30.4, 354054.4 6690274.2 30.4, 354044.1 6690276.3 30.4, 354047 6690290.8 30.4, 354048.9 6690290.3 30.4, 354049.1 6690291.8 30.4, 354050.1 6690291.5 30.4, 354051.1 6690292.3 30.4, 354049.1 6690295.5 30.4, 354053.3 6690298.1 30.4, 354055.2 6690295.1 30.4, 354057.5 6690296.4 30.4, 354058.2 6690296 30.4, 354059.1 6690298.5 30.4, 354060 6690298.8 30.4, 354074.2 6690294.2 30.4, 354072.3 6690287.3 30.4, 354071.2 6690284.2 30.4, 354057.7 6690288.3 30.4))
BATIMENT0000000302934903;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1824-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;16;23;7.4;18.2;25.6;30.5;19.7;Cadastre;A 1.0;POLYGON Z ((354025.3 6690289.2 25.6, 354024.7 6690289.4 25.6, 354025.7 6690294.1 25.6, 354035.4 6690290.9 25.6, 354033 6690280.1 25.6, 354023.8 6690283.4 25.6, 354025.3 6690289.2 25.6))
BATIMENT0000000302935196;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;18.7;26.2;29.1;19.2;Cadastre;A 1.0;POLYGON Z ((354025.4 6690302.6 26.2, 354029.3 6690301.4 26.2, 354031.3 6690309.1 26.2, 354039.1 6690307.6 26.2, 354036 6690293.5 26.2, 354024.2 6690297.7 26.2, 354025.1 6690301.5 26.2, 354025.4 6690302.6 26.2))
BATIMENT0000000302935125;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;20;20;19.0;19.0;38.0;40.2;21.3;Cadastre;A 1.0;POLYGON Z ((354088.6 6690309.9 38, 354089.5 6690310.4 38, 354089.5 6690314.1 38, 354097.2 6690314.2 38, 354097.3 6690306.2 38, 354090.7 6690301.5 38, 354084.2 6690303.6 38, 354085.1 6690306.6 38, 354085.6 6690308.6 38, 354085.7 6690310.7 38, 354088.6 6690309.9 38))
BATIMENT0000000302935124;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;6.7;19.7;26.5;35.7;21.0;Cadastre;A 1.0;POLYGON Z ((354072.6 6690307.2 26.5, 354074.3 6690312.8 26.5, 354074.6 6690313.7 26.5, 354078.4 6690313.8 26.5, 354077.5 6690310.6 26.5, 354082.9 6690309.2 26.5, 354083.2 6690313.9 26.5, 354086 6690314.1 26.5, 354085.7 6690310.7 26.5, 354085.6 6690308.6 26.5, 354085.1 6690306.6 26.5, 354084.2 6690303.6 26.5, 354072.6 6690307.2 26.5))
BATIMENT0000000302935123;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;4.0;19.4;23.5;28.5;20.4;Cadastre;A 1.0;POLYGON Z ((354068.1 6690310.3 23.5, 354072.4 6690314.5 23.5, 354074.3 6690312.8 23.5, 354072.6 6690307.2 23.5, 354068.1 6690310.3 23.5))
BATIMENT0000000302935195;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;23;7.7;18.8;26.5;30.2;20.3;Cadastre;A 1.0;POLYGON Z ((354028.7 6690309.6 26.5, 354027.8 6690309.8 26.5, 354028.4 6690313.8 26.5, 354028.1 6690313.8 26.5, 354029.2 6690318.9 26.5, 354030.4 6690318.6 26.5, 354031.4 6690318.5 26.5, 354040.7 6690316.3 26.5, 354039.1 6690307.6 26.5, 354031.3 6690309.1 26.5, 354028.7 6690309.6 26.5))
BATIMENT0000000302935126;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;7.0;10;20;17.8;20.3;38.2;42.5;21.8;Cadastre;A 1.0;POLYGON Z ((354087.1 6690314.1 38.2, 354086.8 6690325.9 38.2, 354096.9 6690326.2 38.2, 354097.2 6690314.2 38.2, 354089.5 6690314.1 38.2, 354087.1 6690314.1 38.2))
BATIMENT0000000302935122;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;35;20;14.4;19.2;33.7;35.8;20.6;Cadastre;A 1.0;POLYGON Z ((354066.9 6690311.2 33.7, 354056.2 6690323 33.7, 354054.2 6690326.4 33.7, 354059.9 6690330.1 33.7, 354060.7 6690328.9 33.7, 354062 6690329.1 33.7, 354063.8 6690326.9 33.7, 354064.4 6690327.5 33.7, 354066.9 6690324.5 33.7, 354066.4 6690324.2 33.7, 354068.9 6690321.5 33.7, 354069.5 6690322 33.7, 354072.1 6690319.1 33.7, 354071.6 6690318.5 33.7, 354073.4 6690316.5 33.7, 354073.3 6690315.1 33.7, 354072.4 6690314.5 33.7, 354068.1 6690310.3 33.7, 354066.9 6690311.2 33.7))
BATIMENT0000000302935194;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;9.3;18.6;27.9;30.8;20.3;Cadastre;A 1.0;POLYGON Z ((354032.2 6690326 27.9, 354030.7 6690332.5 27.9, 354035.4 6690335.1 27.9, 354042.4 6690323.3 27.9, 354040.7 6690316.3 27.9, 354031.4 6690318.5 27.9, 354032.2 6690326 27.9))
BATIMENT0000000302935120;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;13;10.4;19.0;29.4;31.1;20.8;Cadastre;A 1.0;POLYGON Z ((354050.9 6690332.2 29.4, 354055.2 6690335 29.4, 354058.5 6690336.8 29.4, 354061.8 6690331.3 29.4, 354059.9 6690330.1 29.4, 354054.2 6690326.4 29.4, 354050.9 6690332.2 29.4))
BATIMENT0000000302935121;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;04;9.4;18.8;28.2;31.0;20.8;Cadastre;C 0.4;POLYGON Z ((354048.9 6690335.6 28.2, 354053.1 6690338.2 28.2, 354055.2 6690335 28.2, 354050.9 6690332.2 28.2, 354048.9 6690335.6 28.2))
BATIMENT0000000302935127;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;50;40;7.0;21.0;28.1;37.0;21.8;Cadastre;A 1.0;POLYGON Z ((354086.4 6690337.7 28.1, 354082.2 6690338.7 28.1, 354083.7 6690345.9 28.1, 354091.9 6690343.7 28.1, 354096.7 6690337.5 28.1, 354096.9 6690326.2 28.1, 354086.8 6690325.9 28.1, 354086.4 6690337.7 28.1))
BATIMENT0000000302935128;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;8.1;19.8;27.9;31.1;21.5;Cadastre;A 1.0;POLYGON Z ((354081.9 6690337.6 27.9, 354074.2 6690339.5 27.9, 354074.7 6690341 27.9, 354076.4 6690347.6 27.9, 354083.7 6690345.9 27.9, 354082.2 6690338.7 27.9, 354081.9 6690337.6 27.9))
BATIMENT0000000302935129;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1923-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;8.3;19.2;27.5;30.2;21.1;Cadastre;A 1.0;POLYGON Z ((354072 6690341.6 27.5, 354071.6 6690340.2 27.5, 354067.3 6690341.2 27.5, 354069.1 6690349.4 27.5, 354076.4 6690347.6 27.5, 354074.7 6690341 27.5, 354072 6690341.6 27.5))
BATIMENT0000000302935130;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;12;8.3;19.2;27.5;30.2;21.1;Cadastre;A 1.0;POLYGON Z ((354067.2 6690340.6 27.5, 354061 6690342.2 27.5, 354062.9 6690351 27.5, 354069.1 6690349.4 27.5, 354067.3 6690341.2 27.5, 354067.2 6690340.6 27.5))
BATIMENT0000000302935278;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;29;9.8;26.0;35.8;41.7;27.2;Cadastre;A 1.0;POLYGON Z ((354188.7 6690213.3 35.8, 354191.9 6690220.7 35.8, 354197.6 6690219.1 35.8, 354204.8 6690217.3 35.8, 354204 6690214.2 35.8, 354201.3 6690214.9 35.8, 354200 6690210.5 35.8, 354198.8 6690210.8 35.8, 354189.5 6690213.1 35.8, 354188.7 6690213.3 35.8))
BATIMENT0000000302935103;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;03;9.7;27.5;37.2;40.4;27.9;Cadastre;B 0.4;POLYGON Z ((354218.2 6690219 37.2, 354224.8 6690217.3 37.2, 354223.6 6690212.7 37.2, 354216.9 6690214.4 37.2, 354218.2 6690219 37.2))
BATIMENT0000000302935277;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;7.3;26.4;33.7;36.3;27.3;Cadastre;B 0.4;POLYGON Z ((354193.3 6690224.1 33.7, 354198.7 6690222.4 33.7, 354197.6 6690219.1 33.7, 354191.9 6690220.7 33.7, 354193.3 6690224.1 33.7))
BATIMENT0000000302935054;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1903-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;9.2;28.0;37.2;40.1;29.0;Cadastre;C 0.9;POLYGON Z ((354265.8 6690220.6 37.2, 354262.1 6690221.7 37.2, 354261.4 6690222.5 37.2, 354256.5 6690223.9 37.2, 354260.3 6690234.4 37.2, 354269.5 6690231.4 37.2, 354267.6 6690225.5 37.2, 354265.8 6690220.6 37.2))
BATIMENT0000000302935053;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;13;20;14.6;27.6;42.2;47.7;29.0;Cadastre;A 1.0;POLYGON Z ((354255.4 6690220.6 42.2, 354237.4 6690226.3 42.2, 354240 6690236.6 42.2, 354245.1 6690239.4 42.2, 354260.3 6690234.4 42.2, 354256.5 6690223.9 42.2, 354255.4 6690220.6 42.2))
BATIMENT0000000302934792;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.2;27.4;34.6;37.2;28.1;Cadastre;B 0.9;POLYGON Z ((354213 6690235.7 34.6, 354209.1 6690237.3 34.6, 354207.6 6690233.5 34.6, 354205.3 6690234.5 34.6, 354203.6 6690230.6 34.6, 354197.6 6690233 34.6, 354201.8 6690242.8 34.6, 354211.7 6690238.9 34.6, 354213.8 6690237.9 34.6, 354213.7 6690237.6 34.6, 354213 6690235.7 34.6))
BATIMENT0000000302934790;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.9;27.4;36.3;39.7;28.4;Cadastre;B 0.7;POLYGON Z ((354228.4 6690245.7 36.3, 354231 6690241.3 36.3, 354229.1 6690234.2 36.3, 354224.3 6690235.7 36.3, 354223.8 6690234.3 36.3, 354213.7 6690237.6 36.3, 354213.8 6690237.9 36.3, 354214.8 6690240.8 36.3, 354217.6 6690249.2 36.3, 354228.4 6690245.7 36.3))
BATIMENT0000000302934791;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;20;7.6;27.4;35.0;38.3;28.0;Cadastre;A 1.0;POLYGON Z ((354203.5 6690246.7 35, 354212.2 6690251.1 35, 354217.6 6690249.2 35, 354214.8 6690240.8 35, 354212.6 6690241.7 35, 354211.7 6690238.9 35, 354201.8 6690242.8 35, 354203.5 6690246.7 35))
BATIMENT0000000302935077;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.9;27.7;36.7;39.1;28.3;Cadastre;A 1.0;POLYGON Z ((354247 6690251 36.7, 354250.3 6690261.3 36.7, 354271.9 6690254.1 36.7, 354271.3 6690252.6 36.7, 354268.2 6690244.3 36.7, 354247 6690251 36.7))
BATIMENT0000000302935076;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.3;26.7;36.0;40.6;28.8;Cadastre;A 1.0;POLYGON Z ((354229.8 6690256.7 36, 354233 6690266.4 36, 354243.2 6690263.1 36, 354243.9 6690265.2 36, 354250.8 6690263 36, 354250.3 6690261.3 36, 354247 6690251 36, 354229.8 6690256.7 36))
BATIMENT0000000302935029;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.0;23.4;37.5;41.5;23.7;Cadastre;;POLYGON Z ((354147.2 6690216.3 37.5, 354149.1 6690215.4 37.5, 354147.6 6690211.8 37.5, 354145.9 6690212.5 37.5, 354145.6 6690212.7 37.5, 354147.2 6690216.3 37.5))
BATIMENT0000000302935009;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;21.4;29.7;33.0;21.7;Cadastre;;POLYGON Z ((354109.8 6690219.8 29.7, 354108.5 6690219.8 29.7, 354108.3 6690225.7 29.7, 354108.4 6690225.7 29.7, 354109.8 6690225 29.7, 354109.8 6690219.8 29.7))
BATIMENT0000000302935320;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;4.7;25.1;29.8;32.5;26.7;Cadastre;C 0.4;POLYGON Z ((354172.1 6690228.9 29.8, 354173.9 6690233.3 29.8, 354179.9 6690230.7 29.8, 354178 6690226.3 29.8, 354172.1 6690228.9 29.8))
BATIMENT0000000302935008;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;8.3;22.6;30.9;35.7;22.6;Cadastre;A 1.0;POLYGON Z ((354129.7 6690246.1 30.9, 354129.3 6690233.6 30.9, 354120.8 6690233.7 30.9, 354114.3 6690233.8 30.9, 354114.3 6690226.5 30.9, 354108.3 6690226.6 30.9, 354108.2 6690245.7 30.9, 354129.7 6690246.1 30.9))
BATIMENT0000000302934904;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;10.8;25.6;36.5;40.6;26.8;Cadastre;C 0.9;POLYGON Z ((354184.7 6690259.7 36.5, 354188.9 6690250.7 36.5, 354184.2 6690240.1 36.5, 354179.2 6690242.4 36.5, 354180.6 6690245.8 36.5, 354175.2 6690248.3 36.5, 354177.4 6690255 36.5, 354179.1 6690261.4 36.5, 354184.7 6690259.7 36.5))
BATIMENT0000000302935336;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;22.2;;;;Cadastre;;POLYGON Z ((354119.3 6690262.8 -1000, 354124.6 6690263.1 -1000, 354124.9 6690250.7 -1000, 354119.5 6690248.9 -1000, 354119.3 6690262.8 -1000))
BATIMENT0000000302934905;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.4;25.1;33.5;37.5;25.9;Cadastre;A 1.0;POLYGON Z ((354173.8 6690256 33.5, 354173 6690254 33.5, 354169 6690255.2 33.5, 354171.6 6690263.8 33.5, 354179.1 6690261.4 33.5, 354177.4 6690255 33.5, 354173.8 6690256 33.5))
BATIMENT0000000302934906;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;8.9;24.7;33.6;36.2;25.5;Cadastre;A 1.0;POLYGON Z ((354160.3 6690257.7 33.6, 354163.1 6690266.5 33.6, 354171.6 6690263.8 33.6, 354169 6690255.2 33.6, 354160.3 6690257.7 33.6))
BATIMENT0000000302934907;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.5;22.0;32.5;35.7;25.0;Cadastre;A 1.0;POLYGON Z ((354159.7 6690256 32.5, 354154.9 6690257.4 32.5, 354155.1 6690259.4 32.5, 354152.4 6690260.2 32.5, 354152.7 6690261.1 32.5, 354155.1 6690269.1 32.5, 354163.1 6690266.5 32.5, 354160.3 6690257.7 32.5, 354159.7 6690256 32.5))
BATIMENT0000000302934908;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;23;10.3;22.1;32.4;36.2;24.7;Cadastre;A 1.0;POLYGON Z ((354145.8 6690263.2 32.4, 354148.1 6690271.2 32.4, 354155.1 6690269.1 32.4, 354152.7 6690261.1 32.4, 354145.8 6690263.2 32.4))
BATIMENT0000000302935055;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.7;28.3;32.0;35.0;28.6;Cadastre;;POLYGON Z ((354267.6 6690225.5 32, 354269.5 6690231.4 32, 354272.1 6690230.5 32, 354270.1 6690224.7 32, 354267.6 6690225.5 32))
BATIMENT0000000302935260;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.1;27.9;38.0;42.2;29.3;Cadastre;A 1.0;POLYGON Z ((354320.2 6690232.6 38, 354310.5 6690231.2 38, 354309.6 6690237.2 38, 354316.5 6690238.4 38, 354323.4 6690239.4 38, 354324.3 6690233.4 38, 354320.2 6690232.6 38))
BATIMENT0000000302934921;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.2;27.1;37.3;40.0;28.8;Cadastre;A 1.0;POLYGON Z ((354298.1 6690239.4 37.3, 354294.1 6690235.8 37.3, 354286.5 6690238.2 37.3, 354288.1 6690243.8 37.3, 354287.2 6690247.8 37.3, 354287.7 6690247.9 37.3, 354287.4 6690250.1 37.3, 354296.1 6690251.8 37.3, 354298.1 6690239.4 37.3))
BATIMENT0000000302935261;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;9.8;27.8;37.6;42.5;28.9;Cadastre;C 0.8;POLYGON Z ((354316.5 6690238.4 37.6, 354309.6 6690237.2 37.6, 354307.3 6690250.3 37.6, 354308.3 6690250.5 37.6, 354310.6 6690250.8 37.6, 354316.4 6690251.6 37.6, 354317 6690248.1 37.6, 354315.1 6690247.8 37.6, 354316.5 6690238.4 37.6))
BATIMENT0000000302935079;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;28.0;31.9;36.2;28.6;Cadastre;;POLYGON Z ((354279.9 6690253.9 31.9, 354281.9 6690250.7 31.9, 354282.7 6690249.4 31.9, 354280.3 6690248.7 31.9, 354280 6690247.8 31.9, 354281.9 6690247.1 31.9, 354279.6 6690240.4 31.9, 354275.4 6690241.8 31.9, 354278.4 6690250.4 31.9, 354279.9 6690253.9 31.9))
BATIMENT0000000302935078;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.7;28.0;36.7;39.6;28.5;Cadastre;A 1.0;POLYGON Z ((354268.2 6690244.3 36.7, 354271.3 6690252.6 36.7, 354278.4 6690250.4 36.7, 354275.4 6690241.8 36.7, 354268.2 6690244.3 36.7))
BATIMENT0000000302934920;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;40;10;9.1;27.8;36.9;39.6;28.6;Cadastre;A 1.0;POLYGON Z ((354287 6690250.1 36.9, 354286.5 6690253.4 36.9, 354286 6690253.3 36.9, 354285.5 6690256.5 36.9, 354295.1 6690258.4 36.9, 354296.1 6690251.8 36.9, 354287.4 6690250.1 36.9, 354287 6690250.1 36.9))
BATIMENT0000000302935262;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;27.7;34.8;37.5;28.6;Cadastre;;POLYGON Z ((354307 6690258.5 34.8, 354308.3 6690250.5 34.8, 354307.3 6690250.3 34.8, 354306 6690258.4 34.8, 354307 6690258.5 34.8))
BATIMENT0000000302935268;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.3;28.1;33.5;35.5;28.7;Cadastre;;POLYGON Z ((354318.7 6690254.8 33.5, 354316.9 6690256 33.5, 354316.4 6690259.5 33.5, 354317.7 6690261.2 33.5, 354318.7 6690254.8 33.5))
BATIMENT0000000302935269;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;28.7;32.3;33.7;29.1;Cadastre;;POLYGON Z ((354332.6 6690259 32.3, 354333.2 6690261 32.3, 354336.1 6690260.2 32.3, 354335.6 6690258.3 32.3, 354332.6 6690259 32.3))
BATIMENT0000000302934919;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;9.1;27.6;36.7;39.5;28.6;Cadastre;A 1.0;POLYGON Z ((354285.5 6690263.3 36.7, 354294.1 6690264.5 36.7, 354295.1 6690258.4 36.7, 354285.5 6690256.5 36.7, 354282.3 6690255.9 36.7, 354281.6 6690259.3 36.7, 354282.3 6690259.4 36.7, 354281.9 6690262.6 36.7, 354285 6690263.2 36.7, 354285.5 6690263.3 36.7))
BATIMENT0000000302935263;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;7.3;27.8;35.1;38.7;28.9;Cadastre;A 1.0;POLYGON Z ((354310.9 6690264.2 35.1, 354315.5 6690264.9 35.1, 354318.8 6690265.4 35.1, 354317.8 6690271.5 35.1, 354331.7 6690267.9 35.1, 354330.5 6690263 35.1, 354326 6690264.2 35.1, 354322.1 6690264 35.1, 354322.3 6690262.9 35.1, 354321 6690261.7 35.1, 354317.7 6690261.2 35.1, 354316.4 6690259.5 35.1, 354316.9 6690256 35.1, 354318.7 6690254.8 35.1, 354319.1 6690252.1 35.1, 354319.1 6690252 35.1, 354318.4 6690251.9 35.1, 354316.4 6690251.6 35.1, 354310.6 6690250.8 35.1, 354308.3 6690250.5 35.1, 354307 6690258.5 35.1, 354306 6690258.4 35.1, 354305.2 6690263.3 35.1, 354310.9 6690264.2 35.1))
BATIMENT0000000302935265;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.5;27.8;33.3;;;Cadastre;;POLYGON Z ((354326 6690264.2 33.3, 354330.5 6690263 33.3, 354330.3 6690262.1 33.3, 354330.2 6690261.6 33.3, 354322.1 6690264 33.3, 354326 6690264.2 33.3))
BATIMENT0000000302935264;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;05;04;3.9;28.5;32.4;34.8;29.0;Cadastre;C 0.4;POLYGON Z ((354329.7 6690259.7 32.4, 354330.2 6690261.6 32.4, 354330.3 6690262.1 32.4, 354330.5 6690263 32.4, 354331.7 6690267.9 32.4, 354334.5 6690267.1 32.4, 354333.3 6690261.9 32.4, 354333.2 6690261 32.4, 354332.6 6690259 32.4, 354329.7 6690259.7 32.4))
BATIMENT0000000302935266;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;7.1;28.9;36.0;37.0;29.5;Cadastre;A 1.0;POLYGON Z ((354333.3 6690261.9 36, 354334.5 6690267.1 36, 354342.8 6690265 36, 354341.7 6690260 36, 354333.3 6690261.9 36))
BATIMENT0000000302934917;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.3;27.4;36.7;39.9;28.3;Cadastre;A 1.0;POLYGON Z ((354284.5 6690270 36.7, 354285.8 6690270.2 36.7, 354292.8 6690271.1 36.7, 354294.1 6690264.5 36.7, 354285.5 6690263.3 36.7, 354284.5 6690270 36.7))
BATIMENT0000000302935267;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;15;20;9.8;27.9;37.7;40.4;28.5;Cadastre;A 1.0;POLYGON Z ((354315.5 6690264.9 37.7, 354310.9 6690264.2 37.7, 354305.2 6690263.3 37.7, 354303.7 6690272.2 37.7, 354306.3 6690274.5 37.7, 354314.5 6690272.4 37.7, 354315.5 6690264.9 37.7))
BATIMENT0000000302934914;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;9.9;27.0;36.9;39.4;28.3;Cadastre;A 1.0;POLYGON Z ((354285.4 6690272.8 36.9, 354282.2 6690274.5 36.9, 354284.9 6690279.3 36.9, 354292.3 6690275.4 36.9, 354292.8 6690271.1 36.9, 354285.8 6690270.2 36.9, 354285.4 6690272.8 36.9))
BATIMENT0000000302934912;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;13.3;27.6;41.0;44.1;28.1;Cadastre;A 1.0;POLYGON Z ((354279.3 6690269.3 41, 354278.8 6690268.4 41, 354275.5 6690270 41, 354274.6 6690268.7 41, 354271.8 6690270.3 41, 354271.3 6690271 41, 354268.7 6690272.5 41, 354269.1 6690273.5 41, 354260 6690278.1 41, 354257.7 6690279.3 41, 354258.8 6690281.5 41, 354263.5 6690290.7 41, 354284.9 6690279.3 41, 354282.2 6690274.5 41, 354279.3 6690269.3 41))
BATIMENT0000000302934874;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.4;28.2;38.7;42.2;28.8;Cadastre;A 1.0;POLYGON Z ((354324.2 6690278.4 38.7, 354327.3 6690289.2 38.7, 354335.8 6690287 38.7, 354333.5 6690282.2 38.7, 354330.8 6690276.7 38.7, 354324.2 6690278.4 38.7))
BATIMENT0000000302934909;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1954-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;35;90;17.3;22.3;39.7;40.4;24.0;Cadastre;B 0.6;POLYGON Z ((354144.8 6690259.7 39.7, 354120.9 6690267.8 39.7, 354121.3 6690269.1 39.7, 354124.4 6690278.9 39.7, 354148.1 6690271.2 39.7, 354145.8 6690263.2 39.7, 354144.8 6690259.7 39.7))
BATIMENT0000000302934910;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.2;21.4;32.7;40.0;22.7;Cadastre;A 1.0;POLYGON Z ((354110.9 6690272.6 32.7, 354112.4 6690276.9 32.7, 354114.2 6690276.4 32.7, 354115.8 6690281.7 32.7, 354124.4 6690278.9 32.7, 354121.3 6690269.1 32.7, 354110.9 6690272.6 32.7))
BATIMENT0000000302935176;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.8;23.8;32.6;36.9;25.7;Cadastre;A 1.0;POLYGON Z ((354178.1 6690284.3 32.6, 354177.7 6690282.5 32.6, 354181 6690281.4 32.6, 354178.2 6690273.1 32.6, 354165.7 6690276.9 32.6, 354168.8 6690287.2 32.6, 354178.1 6690284.3 32.6))
BATIMENT0000000302935174;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.9;24.2;35.1;36.9;25.1;Cadastre;A 1.0;POLYGON Z ((354157 6690279.7 35.1, 354160.2 6690289.8 35.1, 354168.8 6690287.2 35.1, 354165.7 6690276.9 35.1, 354157 6690279.7 35.1))
BATIMENT0000000302935173;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.6;23.6;34.2;36.5;24.9;Cadastre;A 1.0;POLYGON Z ((354148.7 6690282.4 34.2, 354151.4 6690291.7 34.2, 354151.9 6690293.1 34.2, 354160.5 6690290.6 34.2, 354160.2 6690289.8 34.2, 354157 6690279.7 34.2, 354148.7 6690282.4 34.2))
BATIMENT0000000302935175;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;40;20;7.2;23.8;31.0;34.2;24.4;Cadastre;A 1.0;POLYGON Z ((354143.8 6690283.9 31, 354144 6690284.4 31, 354139.1 6690286 31, 354141.9 6690294.5 31, 354151.4 6690291.7 31, 354148.7 6690282.4 31, 354143.8 6690283.9 31))
BATIMENT0000000302935080;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1921-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.9;21.9;28.9;29.7;23.2;Cadastre;A 1.0;POLYGON Z ((354121.1 6690301.7 28.9, 354126.3 6690300.1 28.9, 354131.3 6690298.7 28.9, 354130.6 6690296 28.9, 354128.6 6690290.1 28.9, 354118.6 6690293.3 28.9, 354121.1 6690301.7 28.9))
BATIMENT0000000302935081;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.2;23.3;25.5;28.0;23.7;Cadastre;A 1.0;POLYGON Z ((354131.3 6690298.7 25.5, 354132 6690301.2 25.5, 354134.3 6690309.7 25.5, 354134.9 6690311.8 25.5, 354140 6690310.4 25.5, 354135.6 6690294.6 25.5, 354137.5 6690294 25.5, 354135.7 6690287.9 25.5, 354128.6 6690290.1 25.5, 354130.6 6690296 25.5, 354131.3 6690298.7 25.5))
BATIMENT0000000302935354;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.1;24.8;29.0;32.0;25.6;Cadastre;;POLYGON Z ((354163.4 6690300.7 29, 354164.1 6690303 29, 354164.3 6690303.8 29, 354171.1 6690301.6 29, 354173.1 6690301 29, 354172.2 6690297.9 29, 354163.4 6690300.7 29))
BATIMENT0000000302935083;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;22.5;25.8;26.8;23.2;Cadastre;;POLYGON Z ((354128.5 6690303.5 25.8, 354131 6690302.6 25.8, 354132 6690301.2 25.8, 354131.3 6690298.7 25.8, 354126.3 6690300.1 25.8, 354127.1 6690302.8 25.8, 354128.5 6690303.5 25.8))
BATIMENT0000000302935075;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.2;26.8;36.0;40.9;28.7;Cadastre;A 1.0;POLYGON Z ((354217.9 6690260.4 36, 354213.3 6690269.4 36, 354215.5 6690273.7 36, 354233.5 6690267.8 36, 354233 6690266.4 36, 354229.8 6690256.7 36, 354217.9 6690260.4 36))
BATIMENT0000000302934911;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;12.4;27.0;39.4;40.5;28.1;Cadastre;;POLYGON Z ((354263.6 6690275.1 39.4, 354262.1 6690274.7 39.4, 354259.1 6690276.3 39.4, 354260 6690278.1 39.4, 354269.1 6690273.5 39.4, 354268.7 6690272.5 39.4, 354263.6 6690275.1 39.4))
BATIMENT0000000302935178;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;11.4;25.6;37.0;40.0;27.4;Cadastre;A 1.0;POLYGON Z ((354198.3 6690274.7 37, 354194.8 6690276.1 37, 354188.7 6690273.5 37, 354187.4 6690270 37, 354182.2 6690271.7 37, 354185 6690280 37, 354186.8 6690279.5 37, 354191.3 6690281.8 37, 354191.6 6690283 37, 354200.4 6690279.6 37, 354198.3 6690274.7 37))
BATIMENT0000000302934918;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;26.9;31.2;37.2;27.6;Cadastre;;POLYGON Z ((354220.9 6690281.1 31.2, 354218.8 6690281.8 31.2, 354221.7 6690288.6 31.2, 354223.7 6690287.6 31.2, 354220.9 6690281.1 31.2))
BATIMENT0000000302935333;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.1;27.0;30.1;34.0;27.8;Cadastre;;POLYGON Z ((354234.2 6690282.8 30.1, 354237.1 6690288.5 30.1, 354239.9 6690287.2 30.1, 354238.5 6690284.5 30.1, 354236.9 6690281.7 30.1, 354234.2 6690282.8 30.1))
BATIMENT0000000302935177;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.2;26.3;35.6;37.7;27.1;Cadastre;A 1.0;POLYGON Z ((354194.4 6690289.3 35.6, 354198.4 6690287.8 35.6, 354199.7 6690290.8 35.6, 354204.4 6690288.7 35.6, 354200.4 6690279.6 35.6, 354191.6 6690283 35.6, 354194.4 6690289.3 35.6))
BATIMENT0000000302934913;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;00;00;10.9;27.3;38.2;40.9;27.8;Cadastre;A 1.0;POLYGON Z ((354242.4 6690290.1 38.2, 354242.6 6690290.3 38.2, 354243.6 6690292.4 38.2, 354247.2 6690299.3 38.2, 354263.5 6690290.7 38.2, 354258.8 6690281.5 38.2, 354242.4 6690290.1 38.2))
BATIMENT0000000302934916;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;9.2;27.0;36.2;42.7;27.7;Cadastre;A 1.0;POLYGON Z ((354230 6690287.5 36.2, 354229 6690287.9 36.2, 354228.1 6690285.7 36.2, 354223.7 6690287.6 36.2, 354221.7 6690288.6 36.2, 354225.8 6690297.7 36.2, 354233.2 6690294.4 36.2, 354230 6690287.5 36.2))
BATIMENT0000000302934915;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1951-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;10;15.2;27.2;42.5;43.9;27.5;Cadastre;A 1.0;POLYGON Z ((354237.1 6690295.9 42.5, 354236.6 6690297.2 42.5, 354235.6 6690297.7 42.5, 354234.4 6690297 42.5, 354233.2 6690294.4 42.5, 354225.8 6690297.7 42.5, 354228.7 6690305.1 42.5, 354233.5 6690306.8 42.5, 354247.2 6690299.3 42.5, 354243.6 6690292.4 42.5, 354237.1 6690295.9 42.5))
BATIMENT0000000302935307;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;25;20;13.1;27.3;40.5;44.5;28.0;Cadastre;A 1.0;POLYGON Z ((354257.5 6690307.3 40.5, 354261.7 6690315.3 40.5, 354269.5 6690311.2 40.5, 354265.5 6690303 40.5, 354257.5 6690307.3 40.5))
BATIMENT0000000302934881;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;00;00;9.1;28.0;37.1;38.5;28.5;Cadastre;A 1.0;POLYGON Z ((354303 6690283.9 37.1, 354302.2 6690288.9 37.1, 354308.5 6690289.5 37.1, 354308.8 6690289.5 37.1, 354308.2 6690286.9 37.1, 354311.3 6690286.2 37.1, 354310.4 6690282 37.1, 354303 6690283.9 37.1))
BATIMENT0000000302934880;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;28.1;37.9;41.0;28.8;Cadastre;A 1.0;POLYGON Z ((354310.4 6690282 37.9, 354311.3 6690286.2 37.9, 354311.9 6690288.8 37.9, 354312.5 6690291.2 37.9, 354319.4 6690289.6 37.9, 354316.9 6690280.3 37.9, 354310.4 6690282 37.9))
BATIMENT0000000302934879;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;23;10.5;28.2;38.7;42.2;29.3;Cadastre;A 1.0;POLYGON Z ((354316.9 6690280.3 38.7, 354319.4 6690289.6 38.7, 354319.6 6690290.5 38.7, 354320.4 6690292.1 38.7, 354321.2 6690293.6 38.7, 354323.6 6690293 38.7, 354323 6690290.4 38.7, 354327.3 6690289.2 38.7, 354324.2 6690278.4 38.7, 354316.9 6690280.3 38.7))
BATIMENT0000000302934892;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;8.7;28.1;36.8;39.7;29.0;Cadastre;A 1.0;POLYGON Z ((354301.6 6690293 36.8, 354310.7 6690293.7 36.8, 354313.1 6690293.9 36.8, 354312.5 6690291.2 36.8, 354311.9 6690288.8 36.8, 354308.8 6690289.5 36.8, 354308.5 6690289.5 36.8, 354302.2 6690288.9 36.8, 354301.6 6690293 36.8))
BATIMENT0000000302934890;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.9;28.2;39.2;41.7;29.0;Cadastre;A 1.0;POLYGON Z ((354300.4 6690301 39.2, 354309.5 6690302.4 39.2, 354310.7 6690293.7 39.2, 354301.6 6690293 39.2, 354300.4 6690301 39.2))
BATIMENT0000000302934891;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;28.5;31.6;33.0;29.0;Cadastre;;POLYGON Z ((354309.2 6690306.8 31.6, 354311.3 6690307.1 31.6, 354311.9 6690307.2 31.6, 354312.1 6690305 31.6, 354313.4 6690304.2 31.6, 354312.3 6690302.8 31.6, 354309.8 6690302.4 31.6, 354309.2 6690306.8 31.6))
BATIMENT0000000302935311;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;5.0;10;20;14.3;27.5;41.9;44.7;28.7;Cadastre;A 1.0;POLYGON Z ((354269.5 6690311.2 41.9, 354269.8 6690312 41.9, 354269.9 6690312.2 41.9, 354276.9 6690308.8 41.9, 354275.4 6690319 41.9, 354285.4 6690320.5 41.9, 354289.2 6690295.2 41.9, 354289.1 6690294.4 41.9, 354286 6690292 41.9, 354265.5 6690303 41.9, 354269.5 6690311.2 41.9), (354277.7 6690303.1 41.9, 354277.2 6690306.8 41.9, 354275.3 6690306.9 41.9, 354274.5 6690304.6 41.9, 354277.7 6690303.1 41.9))
BATIMENT0000000302934889;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.2;28.4;35.6;39.2;29.5;Cadastre;C 0.7;POLYGON Z ((354298.6 6690312.4 35.6, 354306.7 6690313.6 35.6, 354310.2 6690314.2 35.6, 354311.3 6690307.1 35.6, 354309.2 6690306.8 35.6, 354309.8 6690302.4 35.6, 354309.5 6690302.4 35.6, 354300.4 6690301 35.6, 354298.6 6690312.4 35.6))
BATIMENT0000000302934895;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;04;2.8;29.9;32.7;35.7;30.1;Cadastre;C 0.4;POLYGON Z ((354326.4 6690305.1 32.7, 354321.8 6690304.3 32.7, 354325.2 6690312.4 32.7, 354328.3 6690311.1 32.7, 354328.9 6690310.9 32.7, 354326.4 6690305.1 32.7))
BATIMENT0000000302934894;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.2;29.9;33.1;34.2;30.2;Cadastre;C 0.4;POLYGON Z ((354333.9 6690322.4 33.1, 354338.8 6690320.2 33.1, 354333.1 6690309.1 33.1, 354328.9 6690310.9 33.1, 354328.3 6690311.1 33.1, 354333.9 6690322.4 33.1))
BATIMENT0000000302935082;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;6.1;21.3;27.5;32.5;23.0;Cadastre;A 1.0;POLYGON Z ((354111.9 6690295.4 27.5, 354107.4 6690302.1 27.5, 354114.9 6690307.5 27.5, 354117.5 6690303.9 27.5, 354119.4 6690309.9 27.5, 354123 6690308.7 27.5, 354121.1 6690301.7 27.5, 354118.6 6690293.3 27.5, 354111.9 6690295.4 27.5))
BATIMENT0000000302935352;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;23.3;26.2;29.2;24.2;Cadastre;;POLYGON Z ((354142.6 6690308.5 26.2, 354144.1 6690314.5 26.2, 354147.6 6690313.5 26.2, 354146.1 6690307.6 26.2, 354142.6 6690308.5 26.2))
BATIMENT0000000302935353;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;01;3.9;21.3;25.3;26.0;23.0;Cadastre;C 0.4;POLYGON Z ((354106.2 6690312.9 25.3, 354106.1 6690316.9 25.3, 354116.9 6690313.6 25.3, 354115.9 6690309.7 25.3, 354106.2 6690312.9 25.3))
BATIMENT0000000302934801;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;25.1;35.3;37.2;26.0;Cadastre;A 1.0;POLYGON Z ((354175.7 6690312.7 35.3, 354177.9 6690322.2 35.3, 354184.8 6690320.5 35.3, 354182.5 6690311.2 35.3, 354175.7 6690312.7 35.3))
BATIMENT0000000302934799;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.9;24.8;34.8;36.9;26.0;Cadastre;A 1.0;POLYGON Z ((354173 6690313.3 34.8, 354172.4 6690310.2 34.8, 354168.1 6690311.3 34.8, 354168.7 6690313.6 34.8, 354170.9 6690324.1 34.8, 354177.9 6690322.2 34.8, 354175.7 6690312.7 34.8, 354173 6690313.3 34.8))
BATIMENT0000000302934797;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.0;24.2;32.2;36.2;24.5;Cadastre;;POLYGON Z ((354155.5 6690320.4 32.2, 354159.6 6690319.4 32.2, 354159.2 6690317.8 32.2, 354155.1 6690318.7 32.2, 354155.5 6690320.4 32.2))
BATIMENT0000000302934798;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.2;24.0;34.2;37.0;25.5;Cadastre;A 1.0;POLYGON Z ((354170.9 6690324.1 34.2, 354168.7 6690313.6 34.2, 354158.9 6690316.2 34.2, 354159.2 6690317.8 34.2, 354159.6 6690319.4 34.2, 354155.5 6690320.4 34.2, 354155.1 6690318.7 34.2, 354155.1 6690318.4 34.2, 354150.8 6690319.4 34.2, 354151.4 6690322.1 34.2, 354152.7 6690328.6 34.2, 354170.9 6690324.1 34.2))
BATIMENT0000000302934800;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;8.1;23.0;31.1;36.4;24.2;Cadastre;A 1.0;POLYGON Z ((354148.4 6690322.9 31.1, 354147.5 6690320 31.1, 354138.7 6690322.2 31.1, 354140.7 6690331.5 31.1, 354152.7 6690328.6 31.1, 354151.4 6690322.1 31.1, 354148.4 6690322.9 31.1))
BATIMENT0000000302934802;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.6;23.4;31.0;35.2;24.4;Cadastre;A 1.0;POLYGON Z ((354129.5 6690324.6 31, 354131.7 6690333.7 31, 354140.7 6690331.5 31, 354138.7 6690322.2 31, 354129.5 6690324.6 31))
BATIMENT0000000302934803;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;10.3;22.8;33.1;35.0;24.4;Cadastre;A 1.0;POLYGON Z ((354129.1 6690323.5 33.1, 354122 6690325.3 33.1, 354124.2 6690335.7 33.1, 354131.7 6690333.7 33.1, 354129.5 6690324.6 33.1, 354129.1 6690323.5 33.1))
BATIMENT0000000302934806;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.3;25.9;34.2;38.1;26.5;Cadastre;A 1.0;POLYGON Z ((354203.2 6690315.8 34.2, 354202.2 6690309.8 34.2, 354201.2 6690309.1 34.2, 354200.4 6690304.4 34.2, 354197.6 6690303.8 34.2, 354192.1 6690305.4 34.2, 354192.8 6690308.2 34.2, 354189.4 6690309.2 34.2, 354191.6 6690318.7 34.2, 354203.2 6690315.8 34.2))
BATIMENT0000000302935306;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;7.9;27.1;35.0;37.5;27.6;Cadastre;A 1.0;POLYGON Z ((354257 6690315.1 35, 354258.5 6690314.2 35, 354256.2 6690308.1 35, 354250.1 6690311.4 35, 354254.5 6690319.5 35, 354257.7 6690317.8 35, 354257 6690315.1 35))
BATIMENT0000000302934804;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;90;20;9.6;25.5;35.2;38.0;26.3;Cadastre;A 1.0;POLYGON Z ((354185.6 6690310 35.2, 354185.3 6690308.6 35.2, 354182 6690309.4 35.2, 354182.5 6690311.2 35.2, 354184.8 6690320.5 35.2, 354191.6 6690318.7 35.2, 354189.4 6690309.2 35.2, 354185.6 6690310 35.2))
BATIMENT0000000302935301;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.6;28.4;37.0;;;Cadastre;A 1.0;POLYGON Z ((354245.7 6690313.7 37, 354249.9 6690321.8 37, 354252.6 6690320.5 37, 354254.5 6690319.5 37, 354250.1 6690311.4 37, 354245.7 6690313.7 37))
BATIMENT0000000302935312;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;27.7;30.6;37.5;28.6;Cadastre;;POLYGON Z ((354267.7 6690315.3 30.6, 354268.6 6690317.3 30.6, 354269.8 6690317.2 30.6, 354270 6690317.7 30.6, 354264.3 6690320.7 30.6, 354263.8 6690322.1 30.6, 354264.5 6690323.6 30.6, 354273.1 6690318.7 30.6, 354270.7 6690313.8 30.6, 354267.7 6690315.3 30.6))
BATIMENT0000000302935302;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1887-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;4.9;29.0;33.9;;;Cadastre;A 1.0;POLYGON Z ((354262.4 6690324.8 33.9, 354259.2 6690318.4 33.9, 354259.9 6690318.1 33.9, 354259.5 6690316.9 33.9, 354257.7 6690317.8 33.9, 354254.5 6690319.5 33.9, 354258.6 6690327 33.9, 354262.4 6690324.8 33.9))
BATIMENT0000000302935303;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;27.3;30.7;34.0;28.2;Cadastre;;POLYGON Z ((354255.3 6690325.6 30.7, 354252.4 6690327.1 30.7, 354253.7 6690329.7 30.7, 354258.6 6690327 30.7, 354254.5 6690319.5 30.7, 354252.6 6690320.5 30.7, 354255.3 6690325.6 30.7))
BATIMENT0000000302935299;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.2;27.0;40.3;42.4;28.1;Cadastre;A 1.0;POLYGON Z ((354250.1 6690331.7 40.3, 354251.4 6690331 40.3, 354248.7 6690324.8 40.3, 354246.1 6690326 40.3, 354245 6690325.6 40.3, 354244.4 6690324.6 40.3, 354249.9 6690321.8 40.3, 354245.7 6690313.7 40.3, 354235.9 6690318.7 40.3, 354235 6690321.6 40.3, 354236.5 6690323.9 40.3, 354239.3 6690327.2 40.3, 354238.2 6690327.6 40.3, 354241.9 6690336.2 40.3, 354250.1 6690331.7 40.3))
BATIMENT0000000302935046;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.8;27.6;35.4;39.6;28.9;Cadastre;A 1.0;POLYGON Z ((354207 6690329.1 35.4, 354211.6 6690339.9 35.4, 354215.7 6690338.1 35.4, 354215.3 6690337.3 35.4, 354219.2 6690335.7 35.4, 354220.4 6690338.2 35.4, 354225.6 6690336 35.4, 354222.1 6690327.9 35.4, 354221.3 6690328.2 35.4, 354221.3 6690328 35.4, 354221 6690327.5 35.4, 354220.9 6690327.3 35.4, 354220.7 6690327.1 35.4, 354220.6 6690327 35.4, 354220.5 6690326.8 35.4, 354220.2 6690326.5 35.4, 354220.1 6690326.4 35.4, 354219.7 6690326.2 35.4, 354219.2 6690325.9 35.4, 354218.8 6690325.8 35.4, 354218.6 6690325.7 35.4, 354218.2 6690325.6 35.4, 354217.7 6690325.6 35.4, 354217.5 6690325.6 35.4, 354217.1 6690325.6 35.4, 354216.9 6690325.7 35.4, 354216.5 6690325.8 35.4, 354216.3 6690325.9 35.4, 354215.9 6690326.1 35.4, 354215.4 6690325.5 35.4, 354207 6690329.1 35.4))
BATIMENT0000000302935300;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;30;40;8.6;29.0;37.6;;;Cadastre;A 1.0;POLYGON Z ((354245.5 6690345 37.6, 354254.2 6690341.2 37.6, 354250.1 6690331.7 37.6, 354241.9 6690336.2 37.6, 354245.5 6690345 37.6))
BATIMENT0000000302935356;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;2.7;29.0;31.7;33.1;30.1;Cadastre;C 0.3;POLYGON Z ((354318.7 6690314.8 31.7, 354322.1 6690321.9 31.7, 354325.1 6690320.6 31.7, 354321.8 6690313.4 31.7, 354318.7 6690314.8 31.7))
BATIMENT0000000302934888;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.3;28.6;36.0;40.5;29.6;Cadastre;C 0.7;POLYGON Z ((354297.2 6690321.4 36, 354308.9 6690323.1 36, 354309.3 6690320.4 36, 354306.2 6690316.6 36, 354306.7 6690313.6 36, 354298.6 6690312.4 36, 354297.2 6690321.4 36))
BATIMENT0000000302934887;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.6;28.8;36.5;39.7;29.7;Cadastre;A 1.0;POLYGON Z ((354295.9 6690330.3 36.5, 354306.1 6690331.9 36.5, 354308.7 6690332.4 36.5, 354309.4 6690329 36.5, 354307.9 6690328.7 36.5, 354308.9 6690323.1 36.5, 354297.2 6690321.4 36.5, 354295.9 6690330.3 36.5))
BATIMENT0000000302934882;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;50;30;9.5;29.9;39.4;41.4;30.5;Cadastre;C 1.0;POLYGON Z ((354345.1 6690332.2 39.4, 354340.2 6690322.9 39.4, 354329.6 6690327.7 39.4, 354330.4 6690329.4 39.4, 354334.1 6690336.9 39.4, 354345.1 6690332.2 39.4))
BATIMENT0000000302935313;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;50;10;14.5;28.5;43.1;45.6;29.3;Cadastre;A 1.0;POLYGON Z ((354275.2 6690320.5 43.1, 354274.6 6690320.4 43.1, 354271.9 6690339.5 43.1, 354272.4 6690339.5 43.1, 354272.3 6690341.3 43.1, 354273.6 6690341.5 43.1, 354282.1 6690342.7 43.1, 354285.4 6690320.5 43.1, 354275.4 6690319 43.1, 354275.2 6690320.5 43.1))
BATIMENT0000000302934893;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;29.6;36.6;38.9;30.0;Cadastre;;POLYGON Z ((354320.2 6690333.7 36.6, 354319 6690331 36.6, 354316.1 6690332 36.6, 354317.3 6690334.9 36.6, 354320.2 6690333.7 36.6))
BATIMENT0000000302934883;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;8.1;30.0;38.1;41.0;30.4;Cadastre;A 1.0;POLYGON Z ((354334.1 6690336.9 38.1, 354330.4 6690329.4 38.1, 354322.7 6690332.6 38.1, 354321.5 6690330.2 38.1, 354319 6690331 38.1, 354320.2 6690333.7 38.1, 354323.6 6690341.4 38.1, 354334.1 6690336.9 38.1))
BATIMENT0000000302934886;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1907-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;12;20;11.1;29.1;40.2;42.7;29.8;Cadastre;A 1.0;POLYGON Z ((354294.4 6690340 40.2, 354302.8 6690341.4 40.2, 354303.9 6690340.9 40.2, 354304.7 6690335.2 40.2, 354308.3 6690335.7 40.2, 354308.7 6690332.4 40.2, 354306.1 6690331.9 40.2, 354295.9 6690330.3 40.2, 354294.4 6690340 40.2))
BATIMENT0000000302934884;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1905-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;10;20;8.9;29.9;38.8;42.2;30.1;Cadastre;A 1.0;POLYGON Z ((354323.6 6690341.4 38.8, 354320.2 6690333.7 38.8, 354317.3 6690334.9 38.8, 354313 6690336.7 38.8, 354311.7 6690335.2 38.8, 354309.5 6690338.5 38.8, 354312.9 6690346 38.8, 354323.6 6690341.4 38.8))
BATIMENT0000000302934885;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1770-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.1;29.3;36.5;41.4;30.0;Cadastre;A 1.0;POLYGON Z ((354292.8 6690351.1 36.5, 354296.2 6690353.3 36.5, 354298.7 6690352.1 36.5, 354299.8 6690344.3 36.5, 354303.3 6690344.4 36.5, 354303.4 6690343.9 36.5, 354305.8 6690344 36.5, 354307.9 6690343.1 36.5, 354309.8 6690347.4 36.5, 354312.9 6690346 36.5, 354309.5 6690338.5 36.5, 354303.9 6690340.9 36.5, 354302.8 6690341.4 36.5, 354294.4 6690340 36.5, 354292.8 6690351.1 36.5))
BATIMENT0000000302935153;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1883-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;19;6.3;29.8;36.2;38.7;30.6;Cadastre;A 1.0;POLYGON Z ((354379.1 6690228.4 36.2, 354383.8 6690227.2 36.2, 354382.9 6690223.7 36.2, 354381.9 6690220.5 36.2, 354383.5 6690220 36.2, 354386.7 6690219 36.2, 354386.6 6690218.2 36.2, 354385.7 6690214.7 36.2, 354384.7 6690215 36.2, 354376 6690217.5 36.2, 354379.1 6690228.4 36.2))
BATIMENT0000000302935156;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;30.0;33.9;35.5;30.4;Cadastre;;POLYGON Z ((354384.6 6690223.3 33.9, 354383.5 6690220 33.9, 354381.9 6690220.5 33.9, 354382.9 6690223.7 33.9, 354384.6 6690223.3 33.9))
BATIMENT0000000302935113;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;8.7;29.7;38.5;41.4;30.1;Cadastre;A 1.0;POLYGON Z ((354360.1 6690222.7 38.5, 354357 6690223.6 38.5, 354357.2 6690224.6 38.5, 354355.7 6690224.9 38.5, 354357 6690229 38.5, 354358.4 6690228.6 38.5, 354358.8 6690230.2 38.5, 354361.1 6690229.6 38.5, 354369.3 6690227.2 38.5, 354366.5 6690217.6 38.5, 354359.4 6690219.7 38.5, 354360.1 6690222.7 38.5))
BATIMENT0000000302935115;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.4;29.8;40.2;41.5;30.2;Cadastre;A 1.0;POLYGON Z ((354369.3 6690227.2 40.2, 354361.1 6690229.6 40.2, 354362.6 6690235.2 40.2, 354370.9 6690232.9 40.2, 354369.3 6690227.2 40.2))
BATIMENT0000000302934854;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1911-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;24;4.5;30.0;34.5;41.0;30.7;Cadastre;A 1.0;POLYGON Z ((354381.6 6690232.8 34.5, 354382.8 6690237 34.5, 354388.8 6690235.1 34.5, 354391.9 6690234.1 34.5, 354393.2 6690233.6 34.5, 354401.9 6690230.8 34.5, 354400.7 6690227 34.5, 354381.6 6690232.8 34.5))
BATIMENT0000000302935114;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;29.9;36.2;39.7;30.2;Cadastre;;POLYGON Z ((354358.2 6690230.3 36.2, 354359.7 6690235.9 36.2, 354361.4 6690235.6 36.2, 354362.6 6690235.2 36.2, 354361.1 6690229.6 36.2, 354358.8 6690230.2 36.2, 354358.2 6690230.3 36.2))
BATIMENT0000000302934857;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;30.3;34.1;37.0;30.7;Cadastre;;POLYGON Z ((354390 6690239.1 34.1, 354393 6690238 34.1, 354393 6690237.5 34.1, 354391.9 6690234.1 34.1, 354388.8 6690235.1 34.1, 354390 6690239.1 34.1))
BATIMENT0000000302935116;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;7.5;29.7;37.3;41.0;30.2;Cadastre;A 1.0;POLYGON Z ((354362.4 6690239 37.3, 354357.8 6690240.2 37.3, 354358.6 6690243.1 37.3, 354372.9 6690239.5 37.3, 354370.9 6690232.9 37.3, 354362.6 6690235.2 37.3, 354361.4 6690235.6 37.3, 354362.4 6690239 37.3))
BATIMENT0000000302934852;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;4.8;30.0;34.8;37.6;30.7;Cadastre;A 1.0;POLYGON Z ((354404.1 6690238.8 34.8, 354402.7 6690234.3 34.8, 354393 6690237.5 34.8, 354393 6690238 34.8, 354395.8 6690246.3 34.8, 354404.1 6690238.8 34.8))
BATIMENT0000000302934856;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.3;30.6;35.9;38.4;30.7;Cadastre;A 1.0;POLYGON Z ((354391.4 6690243.5 35.9, 354385.9 6690248.6 35.9, 354386.5 6690250.1 35.9, 354390.2 6690251.4 35.9, 354395.8 6690246.3 35.9, 354393 6690238 35.9, 354390 6690239.1 35.9, 354391.4 6690243.5 35.9))
BATIMENT0000000302935273;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;20;20;14.0;28.9;42.9;45.0;30.2;Cadastre;A 1.0;POLYGON Z ((354362.1 6690253.7 42.9, 354363.6 6690259.6 42.9, 354374.1 6690257.1 42.9, 354375.9 6690253.2 42.9, 354374.2 6690247.4 42.9, 354361.3 6690250.6 42.9, 354362.1 6690253.7 42.9))
BATIMENT0000000302935271;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;12;20;9.0;28.9;37.9;40.1;29.8;Cadastre;A 1.0;POLYGON Z ((354346.7 6690254.5 37.9, 354348.8 6690263.5 37.9, 354355 6690261.9 37.9, 354353.6 6690256 37.9, 354352.7 6690252.4 37.9, 354350.7 6690251.6 37.9, 354347.5 6690252.5 37.9, 354346.5 6690253.7 37.9, 354346.7 6690254.5 37.9))
BATIMENT0000000302935272;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1896-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.3;29.1;37.5;42.2;30.0;Cadastre;A 1.0;POLYGON Z ((354353.6 6690256 37.5, 354355 6690261.9 37.5, 354363.6 6690259.6 37.5, 354362.1 6690253.7 37.5, 354353.6 6690256 37.5))
BATIMENT0000000302935270;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1898-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.8;28.9;37.7;39.9;29.7;Cadastre;A 1.0;POLYGON Z ((354341.7 6690260 37.7, 354342.8 6690265 37.7, 354348.8 6690263.5 37.7, 354346.7 6690254.5 37.7, 354340.7 6690256.2 37.7, 354341.4 6690259 37.7, 354341.7 6690260 37.7))
BATIMENT0000000302934844;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;4.0;30.2;34.2;40.7;31.0;Cadastre;A 1.0;POLYGON Z ((354396 6690266.2 34.2, 354398.6 6690265.3 34.2, 354399.6 6690267.1 34.2, 354404 6690265.3 34.2, 354402.2 6690261.7 34.2, 354397.2 6690255.9 34.2, 354391.7 6690261 34.2, 354389.6 6690261.7 34.2, 354392.8 6690272.3 34.2, 354397.3 6690270.9 34.2, 354396 6690266.2 34.2))
BATIMENT0000000302934861;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;29.6;32.5;36.0;30.0;Cadastre;;POLYGON Z ((354379.1 6690273.3 32.5, 354378.6 6690270.6 32.5, 354376.6 6690271.2 32.5, 354377.2 6690273.9 32.5, 354379.1 6690273.3 32.5))
BATIMENT0000000302934864;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;8.9;29.0;38.0;42.6;30.2;Cadastre;A 1.0;POLYGON Z ((354359.6 6690269.4 38, 354361.2 6690275.1 38, 354364.5 6690274.2 38, 354365.2 6690276.3 38, 354370.7 6690274.7 38, 354372.8 6690281.4 38, 354375.3 6690280.5 38, 354371.4 6690266.3 38, 354359.6 6690269.4 38))
BATIMENT0000000302934867;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;10;8.9;28.8;37.7;40.7;29.9;Cadastre;A 1.0;POLYGON Z ((354347 6690272.6 37.7, 354348.5 6690278.2 37.7, 354358.1 6690275.9 37.7, 354358.6 6690277.5 37.7, 354360.2 6690283 37.7, 354363.2 6690282.1 37.7, 354361.2 6690275.1 37.7, 354359.6 6690269.4 37.7, 354347 6690272.6 37.7))
BATIMENT0000000302934860;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;3.6;30.0;33.6;38.6;30.5;Cadastre;A 1.0;POLYGON Z ((354385.1 6690282.3 33.6, 354380 6690283.8 33.6, 354377.2 6690273.9 33.6, 354376.6 6690271.2 33.6, 354378.6 6690270.6 33.6, 354379.1 6690273.3 33.6, 354382.2 6690272.4 33.6, 354379.8 6690264 33.6, 354371.4 6690266.3 33.6, 354375.3 6690280.5 33.6, 354377.6 6690288.8 33.6, 354377.9 6690288.7 33.6, 354386.3 6690286.3 33.6, 354385.1 6690282.3 33.6))
BATIMENT0000000302934842;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;14;20;4.3;30.2;34.5;38.1;31.3;Cadastre;A 1.0;POLYGON Z ((354396.9 6690287.2 34.5, 354404.6 6690285 34.5, 354403.2 6690281.2 34.5, 354402.6 6690281.4 34.5, 354400.2 6690272.9 34.5, 354405.1 6690271.5 34.5, 354408.2 6690276.4 34.5, 354409.7 6690275.8 34.5, 354405.8 6690268.5 34.5, 354397.3 6690270.9 34.5, 354392.8 6690272.3 34.5, 354396.9 6690287.2 34.5))
BATIMENT0000000302934851;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;30.8;36.2;38.2;31.3;Cadastre;;POLYGON Z ((354415.5 6690217.6 36.2, 354416.8 6690220.1 36.2, 354419.5 6690218.6 36.2, 354418.6 6690216.5 36.2, 354415.5 6690217.6 36.2))
BATIMENT0000000302934847;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;30.5;37.7;40.9;31.8;Cadastre;;POLYGON Z ((354413.2 6690217.6 37.7, 354407.9 6690221.2 37.7, 354409.8 6690225.4 37.7, 354411.3 6690228.2 37.7, 354412.7 6690230.9 37.7, 354417.5 6690226.8 37.7, 354423.6 6690221.2 37.7, 354419.4 6690212 37.7, 354417.3 6690213.2 37.7, 354418.6 6690216.5 37.7, 354419.5 6690218.6 37.7, 354416.8 6690220.1 37.7, 354415.5 6690217.6 37.7, 354413.6 6690218.4 37.7, 354413.2 6690217.6 37.7))
BATIMENT0000000302934849;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;6.8;30.1;37.0;39.7;30.9;Cadastre;A 1.0;POLYGON Z ((354399.9 6690224.4 37, 354400.7 6690227 37, 354401.9 6690230.8 37, 354402 6690231.8 37, 354402.7 6690234.3 37, 354404.1 6690238.8 37, 354408.3 6690234.9 37, 354405.9 6690229.3 37, 354409 6690227.9 37, 354409.2 6690228.1 37, 354409.4 6690228.2 37, 354409.5 6690228.2 37, 354409.8 6690228.3 37, 354409.9 6690228.3 37, 354410.2 6690228.4 37, 354410.6 6690228.4 37, 354410.8 6690228.4 37, 354411 6690228.3 37, 354411.3 6690228.2 37, 354409.8 6690225.4 37, 354407.9 6690221.2 37, 354399.9 6690224.4 37))
BATIMENT0000000302934845;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;30.4;33.4;33.7;31.3;Cadastre;;POLYGON Z ((354409 6690277.4 33.4, 354410.2 6690277 33.4, 354409.7 6690275.8 33.4, 354408.2 6690276.4 33.4, 354409 6690277.4 33.4))
BATIMENT0000000302934843;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1884-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;13;5.2;30.2;35.4;37.7;31.5;Cadastre;A 1.0;POLYGON Z ((354407.5 6690284.2 35.4, 354413.3 6690282.6 35.4, 354410.9 6690278.2 35.4, 354408.3 6690279 35.4, 354408.6 6690279.7 35.4, 354403.2 6690281.2 35.4, 354404.6 6690285 35.4, 354407.5 6690284.2 35.4))
BATIMENT0000000302934840;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;6.5;30.2;36.7;39.8;30.9;Cadastre;A 1.0;POLYGON Z ((354398.8 6690293.6 36.7, 354406.5 6690291.3 36.7, 354407.7 6690295 36.7, 354412.4 6690293.6 36.7, 354411.7 6690291.3 36.7, 354409.6 6690291.8 36.7, 354407.5 6690284.2 36.7, 354404.6 6690285 36.7, 354396.9 6690287.2 36.7, 354398.8 6690293.6 36.7))
BATIMENT0000000302934839;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;10;30;3.3;30.6;33.9;38.5;31.9;Cadastre;A 1.0;POLYGON Z ((354403.7 6690310.4 33.9, 354412.5 6690307.9 33.9, 354424.7 6690304.2 33.9, 354417 6690289.8 33.9, 354413.1 6690291.1 33.9, 354413.7 6690293.2 33.9, 354412.4 6690293.6 33.9, 354407.7 6690295 33.9, 354406.5 6690291.3 33.9, 354398.8 6690293.6 33.9, 354403.7 6690310.4 33.9))
BATIMENT0000000302934841;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1902-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;30;9.5;30.8;40.4;41.1;31.1;Cadastre;A 1.0;POLYGON Z ((354405.2 6690315.4 40.4, 354413.8 6690312.7 40.4, 354412.5 6690307.9 40.4, 354403.7 6690310.4 40.4, 354405.2 6690315.4 40.4))
BATIMENT0000000302934846;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.0;31.5;36.5;42.0;32.5;Cadastre;A 1.0;POLYGON Z ((354411 6690335.9 36.5, 354436 6690325.4 36.5, 354427.1 6690308.7 36.5, 354413.8 6690312.7 36.5, 354405.2 6690315.4 36.5, 354411 6690335.9 36.5))
BATIMENT0000000302934875;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;29.0;34.0;37.7;29.6;Cadastre;;POLYGON Z ((354358.1 6690275.9 34, 354348.5 6690278.2 34, 354349.2 6690280.1 34, 354358.6 6690277.5 34, 354358.1 6690275.9 34))
BATIMENT0000000302934868;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;24;5.5;30.0;35.5;;;Cadastre;A 1.0;POLYGON Z ((354330.8 6690276.7 35.5, 354333.5 6690282.2 35.5, 354337.7 6690281 35.5, 354339.1 6690285.1 35.5, 354350 6690282.2 35.5, 354349.2 6690280.1 35.5, 354348.5 6690278.2 35.5, 354347 6690272.6 35.5, 354330.8 6690276.7 35.5))
BATIMENT0000000302934862;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;6.6;30.2;36.8;40.0;30.7;Cadastre;C 0.7;POLYGON Z ((354386.3 6690286.3 36.8, 354377.9 6690288.7 36.8, 354379.1 6690293.1 36.8, 354387.6 6690290.6 36.8, 354386.3 6690286.3 36.8))
BATIMENT0000000302934863;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;30.2;33.8;36.7;30.7;Cadastre;;POLYGON Z ((354377.9 6690288.7 33.8, 354377.6 6690288.8 33.8, 354375.5 6690289.4 33.8, 354376.7 6690293.8 33.8, 354379.1 6690293.1 33.8, 354377.9 6690288.7 33.8))
BATIMENT0000000302934788;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;02;2.5;30.0;32.5;34.0;30.6;Cadastre;C 0.4;POLYGON Z ((354369.7 6690291 32.5, 354365.9 6690292.1 32.5, 354367.2 6690296.4 32.5, 354371 6690295.3 32.5, 354369.7 6690291 32.5))
BATIMENT0000000302934865;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1885-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.6;30.3;39.0;40.6;30.7;Cadastre;A 1.0;POLYGON Z ((354387.6 6690290.6 39, 354379.1 6690293.1 39, 354380.6 6690298.2 39, 354389.1 6690296 39, 354387.6 6690290.6 39))
BATIMENT0000000302934789;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;30.0;32.5;33.4;30.7;Cadastre;;POLYGON Z ((354367.7 6690297.9 32.5, 354368.1 6690298.9 32.5, 354373.7 6690297 32.5, 354372.8 6690294.8 32.5, 354371 6690295.3 32.5, 354367.2 6690296.4 32.5, 354367.7 6690297.9 32.5))
BATIMENT0000000302934866;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.6;30.5;38.1;40.0;30.7;Cadastre;A 1.0;POLYGON Z ((354389.1 6690296 38.1, 354380.6 6690298.2 38.1, 354381.9 6690303.1 38.1, 354382.4 6690303 38.1, 354385.5 6690302.1 38.1, 354390.6 6690300.8 38.1, 354389.1 6690296 38.1))
BATIMENT0000000302934869;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;30.0;35.6;38.2;30.7;Cadastre;;POLYGON Z ((354385.5 6690302.1 35.6, 354382.4 6690303 35.6, 354383.4 6690305.7 35.6, 354386.3 6690304.9 35.6, 354385.5 6690302.1 35.6))
BATIMENT0000000302934870;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;5.9;30.0;35.9;38.9;30.8;Cadastre;A 1.0;POLYGON Z ((354390.6 6690300.8 35.9, 354385.5 6690302.1 35.9, 354386.3 6690304.9 35.9, 354387.1 6690307.4 35.9, 354392.2 6690305.9 35.9, 354390.6 6690300.8 35.9))
BATIMENT0000000302934837;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.1;31.7;39.8;42.6;32.1;Cadastre;A 1.0;POLYGON Z ((354500.8 6690165 39.8, 354501.5 6690166.9 39.8, 354502 6690167.6 39.8, 354502.2 6690167.9 39.8, 354502.4 6690168 39.8, 354502.6 6690168.4 39.8, 354502.7 6690168.5 39.8, 354502.9 6690168.6 39.8, 354504.1 6690168.9 39.8, 354512.4 6690165.3 39.8, 354510.6 6690160.6 39.8, 354506.3 6690162.2 39.8, 354506.4 6690162.9 39.8, 354502.9 6690164.2 39.8, 354500.8 6690165 39.8))
BATIMENT0000000302935172;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;32.4;36.4;36.9;32.8;Cadastre;;POLYGON Z ((354474.6 6690165.7 36.4, 354475.9 6690169 36.4, 354476.1 6690169.7 36.4, 354478.8 6690168.4 36.4, 354476.1 6690162 36.4, 354473.6 6690163.1 36.4, 354474.6 6690165.7 36.4))
BATIMENT0000000302935203;Indifférenciée;Annexe;;Oui;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;00;00;3.1;33.0;36.1;;;Cadastre;B 1.0;POLYGON Z ((354485.2 6690165.8 36.1, 354487.9 6690172.8 36.1, 354494.1 6690170.2 36.1, 354491.4 6690163.2 36.1, 354485.2 6690165.8 36.1))
BATIMENT0000000302934838;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;14;20;7.3;31.6;39.0;41.4;32.1;Cadastre;A 1.0;POLYGON Z ((354507.6 6690178 39, 354516.1 6690174.1 39, 354512.4 6690165.3 39, 354504.1 6690168.9 39, 354507.6 6690178 39))
BATIMENT0000000302935204;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;10;20;9.7;31.5;41.2;42.8;32.2;Cadastre;A 1.0;POLYGON Z ((354503 6690179.8 41.2, 354498.7 6690171 41.2, 354488.8 6690175.1 41.2, 354489.5 6690176.8 41.2, 354492.7 6690184.8 41.2, 354503 6690179.8 41.2))
BATIMENT0000000302935205;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1899-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;11.0;31.4;42.5;44.9;32.7;Cadastre;A 1.0;POLYGON Z ((354480.4 6690181 42.5, 354481.4 6690183.5 42.5, 354483.6 6690189.1 42.5, 354492.7 6690184.8 42.5, 354489.5 6690176.8 42.5, 354480.4 6690181 42.5))
BATIMENT0000000302935206;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;03;9.1;31.3;40.4;42.2;32.6;Cadastre;C 0.3;POLYGON Z ((354478.3 6690184.9 40.4, 354480.5 6690190.6 40.4, 354483.6 6690189.1 40.4, 354481.4 6690183.5 40.4, 354478.3 6690184.9 40.4))
BATIMENT0000000302934288;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;09;01;3.1;34.7;37.8;;;Cadastre;C 1.0;POLYGON Z ((354544.3 6690449.8 37.8, 354544.5 6690450 37.8, 354547.8 6690454 37.8, 354550 6690452.3 37.8, 354546.6 6690447.9 37.8, 354544.3 6690449.8 37.8))
BATIMENT0000000302934301;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;90;13.0;34.6;47.6;;;Cadastre;A 1.0;POLYGON Z ((354536.3 6690460.2 47.6, 354544.48523156025 6690471.022695063 47.6, 354553.8589503193 6690471.022695063 47.6, 354554.4 6690470.6 47.6, 354542.7 6690455.1 47.6, 354536.3 6690460.2 47.6))
BATIMENT0000000302935355;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;03;1.9;29.5;31.5;32.1;29.8;Cadastre;C 0.3;POLYGON Z ((354348.5 6690305.5 31.5, 354344.4 6690307.3 31.5, 354346.1 6690310.7 31.5, 354350 6690308.9 31.5, 354348.5 6690305.5 31.5))
BATIMENT0000000302934871;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.9;30.0;36.9;38.7;30.9;Cadastre;A 1.0;POLYGON Z ((354392.2 6690312.1 36.9, 354393.3 6690309.6 36.9, 354392.2 6690305.9 36.9, 354387.1 6690307.4 36.9, 354384.5 6690308.1 36.9, 354385 6690309.8 36.9, 354385.5 6690311.7 36.9, 354388.2 6690311.1 36.9, 354388.8 6690313.7 36.9, 354392.2 6690312.1 36.9))
BATIMENT0000000302934872;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.5;29.9;36.4;39.1;30.8;Cadastre;A 1.0;POLYGON Z ((354384.7 6690315.3 36.4, 354384 6690312.8 36.4, 354383.4 6690310.3 36.4, 354385 6690309.8 36.4, 354384.5 6690308.1 36.4, 354379.2 6690309.6 36.4, 354381.2 6690316.8 36.4, 354384.7 6690315.3 36.4))
BATIMENT0000000302934873;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;8.4;30.5;39.0;40.1;30.9;Cadastre;A 0.7;POLYGON Z ((354381.2 6690316.8 39, 354379.2 6690309.6 39, 354378.8 6690308.2 39, 354373.3 6690310.4 39, 354376.5 6690318.7 39, 354381.2 6690316.8 39))
BATIMENT0000000302934876;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;2.0;10;29;5.2;29.9;35.1;39.2;31.1;Cadastre;A 1.0;POLYGON Z ((354376.5 6690318.7 35.1, 354373.3 6690310.4 35.1, 354373.2 6690310.3 35.1, 354370.9 6690311.1 35.1, 354369.9 6690310.6 35.1, 354369.2 6690309.2 35.1, 354365.1 6690310.9 35.1, 354366.3 6690313.8 35.1, 354362.2 6690315.7 35.1, 354362.3 6690316 35.1, 354365.6 6690323.4 35.1, 354376.5 6690318.7 35.1))
BATIMENT0000000302934877;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;23;7.1;30.0;37.1;39.6;31.0;Cadastre;C 1.0;POLYGON Z ((354362.3 6690316 37.1, 354362.2 6690315.7 37.1, 354361.3 6690313.5 37.1, 354354.2 6690316.7 37.1, 354353.7 6690315.4 37.1, 354350.1 6690317 37.1, 354350.7 6690318.2 37.1, 354351.7 6690320.5 37.1, 354355.3 6690327.9 37.1, 354365.6 6690323.4 37.1, 354362.3 6690316 37.1))
BATIMENT0000000302934878;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.0;30.1;39.2;41.3;30.5;Cadastre;A 1.0;POLYGON Z ((354355.3 6690327.9 39.2, 354351.7 6690320.5 39.2, 354350.7 6690318.2 39.2, 354340.2 6690322.9 39.2, 354345.1 6690332.2 39.2, 354355.3 6690327.9 39.2))
BATIMENT0000000302934931;Industriel, agricole ou commercial;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1990-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;;;7.1;30.5;37.6;40.0;32.0;Cadastre;A 1.0;POLYGON Z ((354385.9 6690340.2 37.6, 354388.2 6690345.5 37.6, 354401.9 6690339.9 37.6, 354398.2 6690327.7 37.6, 354395.8 6690319.5 37.6, 354379.8 6690326.3 37.6, 354383.5 6690334.6 37.6, 354385.9 6690340.2 37.6))
BATIMENT0000000302935376;Industriel, agricole ou commercial;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1996-01-01;;;;BDTopo;2.5;BDTopo;1.5;20.0;3.0;00;00;4.0;31.7;;;;Imagerie aérienne;C 0.5;POLYGON Z ((354370.6 6690341.3 35.7, 354363 6690344.3 35.7, 354365.2 6690349.4 35.7, 354385.9 6690340.2 35.7, 354383.5 6690334.6 35.7, 354379.8 6690326.3 35.7, 354366.3 6690331.9 35.7, 354370.6 6690341.3 35.7))
BATIMENT0000000302935375;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2017-12-13 14:38:36;;;;;BDTopo;2.5;BDTopo;1.5;;;;;4.6;30.9;;;;Imagerie aérienne;;POLYGON Z ((354363 6690344.3 35.5, 354370.6 6690341.3 35.5, 354366.3 6690331.9 35.5, 354358.9 6690335.3 35.5, 354363 6690344.3 35.5))
BATIMENT0000000302934929;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;30.2;40.0;43.0;30.4;Cadastre;A 1.0;POLYGON Z ((354355 6690336.9 40, 354358.2 6690343.9 40, 354359 6690345.5 40, 354359.2 6690346 40, 354363 6690344.3 40, 354358.9 6690335.3 40, 354355 6690336.9 40))
BATIMENT0000000302934928;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.0;30.1;39.2;41.2;30.7;Cadastre;A 1.0;POLYGON Z ((354348.1 6690339.6 39.2, 354350 6690344.5 39.2, 354351.8 6690348.6 39.2, 354359 6690345.5 39.2, 354358.2 6690343.9 39.2, 354355 6690336.9 39.2, 354348.1 6690339.6 39.2))
BATIMENT0000000302934927;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.2;30.0;40.2;42.7;30.7;Cadastre;A 1.0;POLYGON Z ((354338.2 6690343.9 40.2, 354341.9 6690352.7 40.2, 354351.8 6690348.6 40.2, 354350 6690344.5 40.2, 354348.1 6690339.6 40.2, 354338.2 6690343.9 40.2))
BATIMENT0000000302934381;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;33.7;36.6;;;Cadastre;;POLYGON Z ((354378 6690463.2 36.6, 354384.4 6690457.9 36.6, 354374.4 6690447.5 36.6, 354368.4 6690452.9 36.6, 354371 6690455.6 36.6, 354370.8 6690455.9 36.6, 354378 6690463.2 36.6))
BATIMENT0000000302934382;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.7;33.6;36.3;;;Cadastre;;POLYGON Z ((354364.9 6690456.3 36.3, 354367.4 6690458.9 36.3, 354370.8 6690455.9 36.3, 354371 6690455.6 36.3, 354368.4 6690452.9 36.3, 354364.9 6690456.3 36.3))
BATIMENT0000000302934383;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;33.7;36.2;;;Cadastre;;POLYGON Z ((354357.3 6690463.4 36.2, 354360.5 6690466.7 36.2, 354368 6690459.7 36.2, 354367.4 6690458.9 36.2, 354364.9 6690456.3 36.2, 354357.3 6690463.4 36.2))
BATIMENT0000000302934463;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.0;33.9;35.9;;;Cadastre;;POLYGON Z ((354368.4 6690469.1 35.9, 354366.1 6690466.8 35.9, 354363.3 6690469.6 35.9, 354363.4 6690469.7 35.9, 354364.66257255955 6690471.022695063 35.9, 354366.40863725665 6690471.022695063 35.9, 354368.4 6690469.1 35.9))
BATIMENT0000000302934423;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;11.3;32.9;44.2;46.7;33.6;Cadastre;A 1.0;POLYGON Z ((354343.6 6690469.7 44.2, 354342.22831623134 6690471.022695063 44.2, 354344.8658049523 6690471.022695063 44.2, 354343.6 6690469.7 44.2))
BATIMENT0000002275364507;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:13:00;2023-01-31 17:41:05;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;11.6;32.6;;48.5;34.4;Imagerie aérienne;;POLYGON Z ((354385.7 6690470.3 41.6, 354384.7364065829 6690471.022695063 41.5793515696326, 354386.2325121515 6690471.022695063 41.75214632899428, 354385.7 6690470.3 41.6))
BATIMENT0000000302934805;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;29;8.5;23.0;31.5;35.2;23.5;Cadastre;C 0.7;POLYGON Z ((354112 6690327.9 31.5, 354114.3 6690338.1 31.5, 354124.2 6690335.7 31.5, 354122 6690325.3 31.5, 354112 6690327.9 31.5))
BATIMENT0000000302935071;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;23;10.1;24.8;34.9;37.2;27.2;Cadastre;A 1.0;POLYGON Z ((354169.5 6690336.4 34.9, 354171.8 6690345.6 34.9, 354178.5 6690343.8 34.9, 354176.4 6690334.7 34.9, 354169.5 6690336.4 34.9))
BATIMENT0000000302935070;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;10;8.8;25.1;34.0;38.2;27.8;Cadastre;A 1.0;POLYGON Z ((354178.5 6690343.8 34, 354179 6690345.5 34, 354179.8 6690348.3 34, 354183 6690347.5 34, 354183.4 6690349.3 34, 354188.3 6690348.1 34, 354187.2 6690343.6 34, 354184.4 6690332.7 34, 354176.4 6690334.7 34, 354178.5 6690343.8 34))
BATIMENT0000000302935072;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;24.2;32.2;36.7;27.1;Cadastre;A 1.0;POLYGON Z ((354154.9 6690340.2 32.2, 354156.4 6690346.4 32.2, 354160 6690345.2 32.2, 354160.9 6690348.6 32.2, 354171.9 6690345.9 32.2, 354171.8 6690345.6 32.2, 354169.5 6690336.4 32.2, 354154.9 6690340.2 32.2))
BATIMENT0000000302935073;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.8;23.7;32.5;34.2;26.7;Cadastre;A 1.0;POLYGON Z ((354148.7 6690351.9 32.5, 354149.1 6690353.1 32.5, 354153.8 6690352 32.5, 354157.6 6690351 32.5, 354156.4 6690346.4 32.5, 354152.7 6690347.4 32.5, 354151.2 6690341.1 32.5, 354142.3 6690343.3 32.5, 354144.7 6690352.8 32.5, 354148.7 6690351.9 32.5))
BATIMENT0000000302935069;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;26.9;30.7;30.9;27.7;Cadastre;;POLYGON Z ((354183.4 6690349.3 30.7, 354183 6690347.5 30.7, 354179.8 6690348.3 30.7, 354180 6690349.1 30.7, 354180.2 6690350.1 30.7, 354183.4 6690349.3 30.7))
BATIMENT0000000302935074;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;20;8.4;23.3;31.7;33.6;25.9;Cadastre;A 1.0;POLYGON Z ((354132.9 6690345.7 31.7, 354135.3 6690355.9 31.7, 354140 6690354.6 31.7, 354140.5 6690355.8 31.7, 354145.1 6690354.6 31.7, 354144.7 6690352.8 31.7, 354142.3 6690343.3 31.7, 354132.9 6690345.7 31.7))
BATIMENT0000000302935159;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;23.8;31.1;33.1;24.5;Cadastre;A 1.0;POLYGON Z ((354116.4 6690357.8 31.1, 354122.5 6690356 31.1, 354120.6 6690348.8 31.1, 354114.4 6690350.5 31.1, 354116.2 6690357.5 31.1, 354116.4 6690357.8 31.1))
BATIMENT0000000302935160;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;9.6;21.9;31.5;33.1;24.3;Cadastre;C 0.7;POLYGON Z ((354105 6690352.8 31.5, 354106.8 6690360.2 31.5, 354107.1 6690361.3 31.5, 354112.2 6690359.8 31.5, 354112 6690358.7 31.5, 354116.2 6690357.5 31.5, 354114.4 6690350.5 31.5, 354105 6690352.8 31.5))
BATIMENT0000000302934366;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;7.7;23.7;31.5;36.4;24.6;Cadastre;C 0.4;POLYGON Z ((354125.2 6690363.9 31.5, 354121.8 6690364.9 31.5, 354118.9 6690377.5 31.5, 354122.1 6690378.4 31.5, 354124 6690369.6 31.5, 354125.2 6690363.9 31.5))
BATIMENT0000000302935304;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;30;40;8.0;29.0;37.0;;;Cadastre;A 1.0;POLYGON Z ((354249.1 6690353.4 37, 354255.2 6690350.8 37, 354253.4 6690346.3 37, 354256 6690345.1 37, 354254.2 6690341.2 37, 354245.5 6690345 37, 354249.1 6690353.4 37))
BATIMENT0000000302934358;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;28.3;37.7;41.1;28.9;Cadastre;A 1.0;POLYGON Z ((354229.2 6690352 37.7, 354227.4 6690352.7 37.7, 354223 6690343 37.7, 354212 6690347.7 37.7, 354214.9 6690354.2 37.7, 354217 6690353.3 37.7, 354220.1 6690360.9 37.7, 354221.7 6690360.2 37.7, 354231.4 6690356.2 37.7, 354229.2 6690352 37.7))
BATIMENT0000000302934354;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;28.3;38.2;41.4;29.6;Cadastre;A 1.0;POLYGON Z ((354225.8 6690369.5 38.2, 354228.7 6690368.3 38.2, 354237.4 6690364.6 38.2, 354233.4 6690355.4 38.2, 354231.4 6690356.2 38.2, 354221.7 6690360.2 38.2, 354225.8 6690369.5 38.2))
BATIMENT0000000302935305;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;5.0;00;00;12.4;29.0;41.4;43.8;30.2;Cadastre;A 1.0;POLYGON Z ((354258.7 6690375.7 41.4, 354264.1 6690378.2 41.4, 354277.6 6690374.1 41.4, 354278.1 6690370.5 41.4, 354274.3 6690371.6 41.4, 354272.5 6690369.3 41.4, 354270.5 6690370.8 41.4, 354265.9 6690364.9 41.4, 354265.9 6690364.7 41.4, 354265.9 6690364.6 41.4, 354265.9 6690364.3 41.4, 354265.9 6690364.1 41.4, 354265.8 6690363.9 41.4, 354265.7 6690363.7 41.4, 354266.9 6690362.1 41.4, 354257.2 6690349.8 41.4, 354255.2 6690350.8 41.4, 354249.1 6690353.4 41.4, 354258.7 6690375.7 41.4))
BATIMENT0000000302934352;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;10;7.5;30.2;37.7;;;Cadastre;A 1.0;POLYGON Z ((354233.7 6690380.2 37.7, 354242.3 6690376.4 37.7, 354237.4 6690364.6 37.7, 354228.7 6690368.3 37.7, 354233.7 6690380.2 37.7))
BATIMENT0000000302934351;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.3;29.3;39.7;43.5;30.7;Cadastre;A 1.0;POLYGON Z ((354228.7 6690382.2 39.7, 354229.8 6690385 39.7, 354233.1 6690383.8 39.7, 354234.2 6690386.6 39.7, 354233.4 6690386.9 39.7, 354235.3 6690391.2 39.7, 354238.8 6690389.7 39.7, 354246.7 6690386.5 39.7, 354242.3 6690376.4 39.7, 354233.7 6690380.2 39.7, 354228.7 6690382.2 39.7))
BATIMENT0000000302934367;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.1;27.5;36.7;38.9;29.4;Cadastre;A 1.0;POLYGON Z ((354192 6690398.3 36.7, 354195.9 6690384.5 36.7, 354195.9 6690384.3 36.7, 354191.2 6690383.2 36.7, 354190.3 6690386.2 36.7, 354187.3 6690385.3 36.7, 354184.2 6690396.1 36.7, 354192 6690398.3 36.7))
BATIMENT0000000302934368;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.2;28.1;36.4;39.0;29.8;Cadastre;A 1.0;POLYGON Z ((354202.2 6690401.2 36.4, 354205.8 6690388.2 36.4, 354204.9 6690388 36.4, 354205.7 6690385.3 36.4, 354202.2 6690384.4 36.4, 354201.9 6690385.9 36.4, 354195.9 6690384.5 36.4, 354192 6690398.3 36.4, 354202.2 6690401.2 36.4))
BATIMENT0000000302934353;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;9.7;29.5;39.2;42.2;30.7;Cadastre;A 1.0;POLYGON Z ((354240.2 6690392.7 39.2, 354238.9 6690393.5 39.2, 354239.3 6690395.6 39.2, 354238.1 6690397 39.2, 354237.7 6690397.9 39.2, 354238.7 6690398.7 39.2, 354246.1 6690406.1 39.2, 354250.4 6690402.1 39.2, 354251.2 6690400.8 39.2, 354251.7 6690397.9 39.2, 354246.7 6690386.5 39.2, 354238.8 6690389.7 39.2, 354240.2 6690392.7 39.2))
BATIMENT0000000302934357;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.0;29.2;38.2;40.9;30.5;Cadastre;A 1.0;POLYGON Z ((354223.2 6690396.2 38.2, 354213.7 6690393.6 38.2, 354212.5 6690397.5 38.2, 354208.9 6690396.6 38.2, 354207.1 6690402.5 38.2, 354220.2 6690406.4 38.2, 354223 6690397 38.2, 354223.2 6690396.2 38.2))
BATIMENT0000000302935310;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;10.4;29.1;39.5;43.2;29.7;Cadastre;A 1.0;POLYGON Z ((354272.3 6690350.1 39.5, 354272.2 6690350.4 39.5, 354280.7 6690351.8 39.5, 354282.1 6690342.7 39.5, 354273.6 6690341.5 39.5, 354272.3 6690350.1 39.5))
BATIMENT0000000302934925;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.3;30.9;37.2;;;Cadastre;A 1.0;POLYGON Z ((354328 6690348.3 37.2, 354329.9 6690353.1 37.2, 354334.4 6690351.1 37.2, 354335.6 6690353.9 37.2, 354339 6690352.4 37.2, 354339.6 6690353.8 37.2, 354341.9 6690352.7 37.2, 354338.2 6690343.9 37.2, 354328 6690348.3 37.2))
BATIMENT0000000302934926;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;29.8;33.5;36.7;30.1;Cadastre;;POLYGON Z ((354334.4 6690351.1 33.5, 354329.9 6690353.1 33.5, 354330 6690353.4 33.5, 354331 6690355.9 33.5, 354335.6 6690353.9 33.5, 354334.4 6690351.1 33.5))
BATIMENT0000000302934924;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;8.5;29.7;38.2;39.4;30.2;Cadastre;A 1.0;POLYGON Z ((354317.7 6690352.9 38.2, 354321.2 6690361.1 38.2, 354322.4 6690360.5 38.2, 354321.1 6690357.2 38.2, 354330 6690353.4 38.2, 354329.9 6690353.1 38.2, 354328 6690348.3 38.2, 354317.7 6690352.9 38.2))
BATIMENT0000000302935309;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;10.4;29.1;39.5;41.9;30.0;Cadastre;A 1.0;POLYGON Z ((354271.1 6690358.7 39.5, 354279.5 6690360.3 39.5, 354280.7 6690351.8 39.5, 354272.2 6690350.4 39.5, 354271.1 6690358.7 39.5))
BATIMENT0000000302935308;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;10;20;10.4;29.0;39.4;42.2;30.2;Cadastre;A 1.0;POLYGON Z ((354278.1 6690370.5 39.4, 354279.5 6690360.3 39.4, 354271.1 6690358.7 39.4, 354266.9 6690362.1 39.4, 354272.5 6690369.3 39.4, 354274.3 6690371.6 39.4, 354278.1 6690370.5 39.4))
BATIMENT0000002244337957;Indifférenciée;Indifférencié;;Non;En service;2021-06-09 10:35:56;2023-01-31 17:41:03;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;13.5;29.7;43.2;44.9;30.9;Cadastre;;POLYGON Z ((354316 6690376.5 43.2, 354313.2 6690370.1 43.2, 354312.8 6690370.3 43.2, 354311.2 6690366.4 43.2, 354320.7 6690362.3 43.2, 354316.7 6690352.8 43.2, 354298.6 6690360.5 43.2, 354296.8 6690365.5 43.2, 354298.7 6690368.9 43.2, 354300.4 6690368.2 43.2, 354301.2 6690370.3 43.2, 354299.7 6690370.8 43.2, 354302.4 6690375.7 43.2, 354303.1 6690375.3 43.2, 354304.9 6690380.2 43.2, 354316 6690376.5 43.2))
BATIMENT0000000302934922;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;30.4;32.9;33.5;30.9;Cadastre;;POLYGON Z ((354307.3 6690382.6 32.9, 354309.2 6690381.7 32.9, 354308 6690379.5 32.9, 354305.9 6690380.2 32.9, 354307.3 6690382.6 32.9))
BATIMENT0000000029076401;Indifférenciée;Indifférencié;;Non;En service;2006-10-04 09:41:10;2018-09-18 13:36:50;;;;;BDTopo;2.5;BDTopo;1.5;;;;;1.4;31.8;;33.6;32.0;Imagerie aérienne;;POLYGON Z ((354344.2 6690410.1 33.2, 354332.3 6690393.4 33.2, 354322.6 6690400.9 33.2, 354333.6 6690417.4 32.6, 354344.2 6690410.1 33.2))
BATIMENT0000000302934442;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;50;10;16.8;30.4;47.2;49.5;31.3;Cadastre;A 1.0;POLYGON Z ((354297.6 6690392.7 47.2, 354289.6 6690397.2 47.2, 354300.6 6690417.3 47.2, 354300 6690417.7 47.2, 354300.7 6690418.4 47.2, 354309.2 6690413.6 47.2, 354297.6 6690392.7 47.2))
BATIMENT0000000302934365;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.5;24.1;32.6;36.0;24.8;Cadastre;A 1.0;POLYGON Z ((354129 6690380.4 32.6, 354131 6690372.5 32.6, 354131.3 6690371.7 32.6, 354124 6690369.6 32.6, 354122.1 6690378.4 32.6, 354129 6690380.4 32.6))
BATIMENT0000000302934364;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;8.4;24.4;32.8;35.6;25.3;Cadastre;A 1.0;POLYGON Z ((354136.3 6690382.5 32.8, 354138.7 6690374.6 32.8, 354131 6690372.5 32.8, 354129 6690380.4 32.8, 354136.3 6690382.5 32.8))
BATIMENT0000000302934363;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.9;25.0;32.9;35.7;26.0;Cadastre;A 1.0;POLYGON Z ((354146.6 6690385.5 32.9, 354149 6690376.4 32.9, 354149.3 6690375.1 32.9, 354139.2 6690372.4 32.9, 354138.7 6690374.6 32.9, 354136.3 6690382.5 32.9, 354146.6 6690385.5 32.9))
BATIMENT0000000302934359;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;23;10.0;24.3;34.3;37.1;27.9;Cadastre;A 1.0;POLYGON Z ((354165.6 6690381.1 34.3, 354166.9 6690376.5 34.3, 354167.2 6690375.4 34.3, 354157.2 6690372.9 34.3, 354156 6690377.1 34.3, 354155.7 6690378.1 34.3, 354153.2 6690387.5 34.3, 354163.2 6690390.1 34.3, 354165.6 6690381.1 34.3))
BATIMENT0000000302934361;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.7;25.2;36.0;37.6;27.8;Cadastre;A 1.0;POLYGON Z ((354153.2 6690387.5 36, 354155.7 6690378.1 36, 354149 6690376.4 36, 354146.6 6690385.5 36, 354153.2 6690387.5 36))
BATIMENT0000000302934360;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;40;10.6;26.3;37.0;37.5;27.8;Cadastre;A 1.0;POLYGON Z ((354168.1 6690391.5 37, 354169.5 6690386.7 37, 354172.3 6690387.5 37, 354174.8 6690378.8 37, 354166.9 6690376.5 37, 354165.6 6690381.1 37, 354163.2 6690390.1 37, 354168.1 6690391.5 37))
BATIMENT0000000302934362;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;10;7.4;26.9;34.4;37.4;28.1;Cadastre;A 1.0;POLYGON Z ((354171 6690392.3 34.4, 354184.2 6690396.1 34.4, 354187.3 6690385.3 34.4, 354187.9 6690383.4 34.4, 354180.1 6690381.2 34.4, 354180.7 6690379.1 34.4, 354175.3 6690377.7 34.4, 354174.8 6690378.8 34.4, 354172.3 6690387.5 34.4, 354171 6690392.3 34.4))
BATIMENT0000000302934412;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.3;26.5;35.8;38.2;29.1;Cadastre;A 1.0;POLYGON Z ((354154.4 6690410.3 35.8, 354151.7 6690420.9 35.8, 354163.4 6690424.2 35.8, 354163.7 6690423.5 35.8, 354166.6 6690413.8 35.8, 354154.4 6690410.3 35.8))
BATIMENT0000000302934411;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;13;20;9.4;27.5;37.0;39.4;29.0;Cadastre;A 1.0;POLYGON Z ((354173.3 6690428.1 37, 354175.1 6690424.5 37, 354173 6690423.5 37, 354174.2 6690420.8 37, 354174.6 6690421 37, 354175.6 6690418.3 37, 354174.9 6690416.1 37, 354174.7 6690416 37, 354166.6 6690413.8 37, 354163.7 6690423.5 37, 354166.3 6690424.8 37, 354173.3 6690428.1 37))
BATIMENT0000000302934413;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;37.0;5.0;00;00;9.7;24.9;34.6;40.1;29.1;Cadastre;A 1.0;POLYGON Z ((354094.5 6690444.5 34.6, 354105.9 6690450.1 34.6, 354116.3 6690428.4 34.6, 354120.8 6690430.5 34.6, 354121.8 6690428.4 34.6, 354123.6 6690429.3 34.6, 354130.5 6690416 34.6, 354135.7 6690417.3 34.6, 354135.2 6690419.2 34.6, 354143.7 6690421.4 34.6, 354144.1 6690419.5 34.6, 354151.5 6690421.4 34.6, 354151.7 6690420.9 34.6, 354154.4 6690410.3 34.6, 354139.8 6690406.2 34.6, 354116.3 6690399.4 34.6, 354115 6690404.2 34.6, 354116.9 6690404.8 34.6, 354115.8 6690409.6 34.6, 354111.3 6690419.1 34.6, 354109 6690418.1 34.6, 354106.3 6690423.7 34.6, 354102.4 6690421.8 34.6, 354102.3 6690421.8 34.6, 354096.1 6690435.1 34.6, 354091.9 6690443.5 34.6, 354094.5 6690444.5 34.6))
BATIMENT0000000302934356;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.5;29.7;38.2;41.4;30.7;Cadastre;A 1.0;POLYGON Z ((354227.8 6690396.5 38.2, 354227.4 6690397.9 38.2, 354223 6690397 38.2, 354220.2 6690406.4 38.2, 354230.4 6690409.2 38.2, 354233.6 6690398.3 38.2, 354227.8 6690396.5 38.2))
BATIMENT0000000302934355;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;6.0;30.1;36.1;36.5;30.7;Cadastre;A 1.0;POLYGON Z ((354237.3 6690397.4 36.1, 354233.6 6690398.3 36.1, 354230.4 6690409.2 36.1, 354240.2 6690412.1 36.1, 354244.5 6690407.8 36.1, 354239.2 6690402.4 36.1, 354237.7 6690401.8 36.1, 354238.7 6690398.7 36.1, 354237.7 6690397.9 36.1, 354237.3 6690397.4 36.1))
BATIMENT0000000302935296;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;4.0;10;20;13.9;28.9;42.8;46.6;30.6;Cadastre;A 1.0;POLYGON Z ((354194.6 6690421.2 42.8, 354192.6 6690421.8 42.8, 354188.6 6690430.3 42.8, 354196.6 6690434.2 42.8, 354197.7 6690431.5 42.8, 354202.2 6690432.7 42.8, 354204.8 6690424 42.8, 354194.6 6690421.2 42.8))
BATIMENT0000000302935293;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;13;10;7.8;28.9;36.7;42.0;30.9;Cadastre;A 1.0;POLYGON Z ((354184.3 6690439.1 36.7, 354192.2 6690443.1 36.7, 354194.5 6690438.3 36.7, 354195.7 6690438.7 36.7, 354196 6690437.9 36.7, 354200.1 6690439.8 36.7, 354201.1 6690436.3 36.7, 354196.6 6690434.2 36.7, 354188.6 6690430.3 36.7, 354184.3 6690439.1 36.7))
BATIMENT0000000302935295;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;30.9;35.0;44.2;31.4;Cadastre;;POLYGON Z ((354230.5 6690440.8 35, 354226.5 6690442.2 35, 354227.6 6690445.6 35, 354238.4 6690441.6 35, 354237.2 6690438.4 35, 354230.5 6690440.8 35))
BATIMENT0000000302935294;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:05;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;14.9;28.9;43.8;43.9;31.3;Cadastre;A 1.0;POLYGON Z ((354192.2 6690443.1 43.8, 354184.3 6690439.1 43.8, 354179.4 6690449.5 43.8, 354179.5 6690449.5 43.8, 354181.6 6690450.5 43.8, 354185.3 6690452.3 43.8, 354187.4 6690453.3 43.8, 354193.8 6690456.4 43.8, 354197.8 6690448.3 43.8, 354198.8 6690446.2 43.8, 354198.4 6690446 43.8, 354192.2 6690443.1 43.8))
BATIMENT0000000302935290;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;30.8;34.6;42.0;31.4;Cadastre;;POLYGON Z ((354201.8 6690452.3 34.6, 354202.2 6690452.5 34.6, 354204.6 6690453.5 34.6, 354216.8 6690449.3 34.6, 354216 6690447.3 34.6, 354201.8 6690452.3 34.6))
BATIMENT0000000302935291;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.0;28.9;41.9;45.3;32.4;Cadastre;A 1.0;POLYGON Z ((354223.4 6690467 41.9, 354224.7 6690466.7 41.9, 354225.5 6690468.5 41.9, 354224.9 6690469.9 41.9, 354223.8 6690469.5 41.9, 354223.1 6690470 41.9, 354222.61873173516 6690471.022695063 41.9, 354236.8988153571 6690471.022695063 41.9, 354237.7 6690469.2 41.9, 354234.1 6690467.7 41.9, 354232.2 6690462.5 41.9, 354234 6690461.8 41.9, 354232.4 6690457.7 41.9, 354233.1 6690457.3 41.9, 354228.6 6690446.1 41.9, 354227.9 6690446.4 41.9, 354227.6 6690445.6 41.9, 354226.5 6690442.2 41.9, 354230.5 6690440.8 41.9, 354228.7 6690435.9 41.9, 354208.1 6690429.6 41.9, 354208.6 6690428 41.9, 354205.9 6690427.2 41.9, 354206.7 6690424.6 41.9, 354204.8 6690424 41.9, 354202.2 6690432.7 41.9, 354201.1 6690436.3 41.9, 354200.1 6690439.8 41.9, 354199.5 6690441.9 41.9, 354211.8 6690445.5 41.9, 354215.8 6690446.7 41.9, 354216 6690447.3 41.9, 354216.8 6690449.3 41.9, 354217.2 6690450.3 41.9, 354217.5 6690451.2 41.9, 354218.1 6690451 41.9, 354219.1 6690454 41.9, 354217.9 6690454.3 41.9, 354219.3 6690458.7 41.9, 354218.3 6690458.9 41.9, 354218.6 6690459.6 41.9, 354215.7 6690465.6 41.9, 354215.2 6690466.7 41.9, 354213.3 6690470.5 41.9, 354213.0560756374 6690471.022695063 41.9, 354216.23483935324 6690471.022695063 41.9, 354221 6690460.8 41.9, 354223.4 6690467 41.9))
BATIMENT0000000302935292;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.3;30.3;36.6;42.9;32.2;Cadastre;A 1.0;POLYGON Z ((354183.5 6690456.4 36.6, 354190.3 6690459.6 36.6, 354188.6 6690463.4 36.6, 354189.9 6690464 36.6, 354189.5 6690464.9 36.6, 354192.4 6690466.4 36.6, 354193.3 6690466.8 36.6, 354191.5 6690470.3 36.6, 354191.24189462047 6690471.022695063 36.6, 354213.0560756374 6690471.022695063 36.6, 354213.3 6690470.5 36.6, 354215.2 6690466.7 36.6, 354215.7 6690465.6 36.6, 354218.6 6690459.6 36.6, 354218.3 6690458.9 36.6, 354219.3 6690458.7 36.6, 354217.9 6690454.3 36.6, 354219.1 6690454 36.6, 354218.1 6690451 36.6, 354217.5 6690451.2 36.6, 354217.2 6690450.3 36.6, 354211.6 6690452 36.6, 354210.4 6690456.1 36.6, 354204.6 6690453.5 36.6, 354202.2 6690452.5 36.6, 354201.8 6690452.3 36.6, 354197.3 6690450.3 36.6, 354195.3 6690457.1 36.6, 354193.8 6690456.4 36.6, 354187.4 6690453.3 36.6, 354185.3 6690452.3 36.6, 354181.6 6690450.5 36.6, 354180 6690453.9 36.6, 354179.2 6690453.5 36.6, 354178.9 6690454.3 36.6, 354183.5 6690456.4 36.6))
BATIMENT0000000302934441;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;9.0;31.0;40.0;45.7;32.2;Cadastre;A 1.0;POLYGON Z ((354299.9 6690419 40, 354303.8 6690426.3 40, 354313.3 6690421 40, 354309.2 6690413.6 40, 354300.7 6690418.4 40, 354299.9 6690419 40))
BATIMENT0000000302934440;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;10;8.7;31.4;40.2;44.1;32.8;Cadastre;A 1.0;POLYGON Z ((354305.2 6690428.9 40.2, 354304.3 6690429.5 40.2, 354308 6690436.2 40.2, 354309.2 6690435.6 40.2, 354310.8 6690438.4 40.2, 354320.4 6690433.4 40.2, 354313.3 6690421 40.2, 354303.8 6690426.3 40.2, 354305.2 6690428.9 40.2))
BATIMENT0000000302934439;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;12;20;7.1;31.9;39.0;41.6;32.8;Cadastre;A 1.0;POLYGON Z ((354314.9 6690445.9 39, 354324.4 6690440.9 39, 354320.4 6690433.4 39, 354310.8 6690438.4 39, 354314.9 6690445.9 39))
BATIMENT0000000302934432;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;01;02;6.3;32.1;38.4;41.6;33.0;Cadastre;A 1.0;POLYGON Z ((354324.4 6690440.9 38.4, 354314.9 6690445.9 38.4, 354311.7 6690447.5 38.4, 354311.7 6690447.6 38.4, 354314.4 6690452.7 38.4, 354317.6 6690451 38.4, 354318.9 6690453.6 38.4, 354328.4 6690448.3 38.4, 354324.4 6690440.9 38.4))
BATIMENT0000000302934424;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;30;5.5;32.2;37.7;42.5;33.0;Cadastre;A 1.0;POLYGON Z ((354316.8 6690454.8 37.7, 354319.4 6690460.1 37.7, 354321.4 6690459 37.7, 354331.3 6690453.4 37.7, 354328.4 6690448.3 37.7, 354318.9 6690453.6 37.7, 354316.8 6690454.8 37.7))
BATIMENT0000000302934425;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;25.0;5.0;00;00;4.5;32.2;36.7;48.1;33.2;Cadastre;A 1.0;POLYGON Z ((354315.2 6690462.6 36.7, 354312.7 6690457 36.7, 354309.3 6690448.8 36.7, 354305.9 6690441 36.7, 354303.6 6690435.9 36.7, 354286.3 6690440.5 36.7, 354289.6 6690450.7 36.7, 354289.2 6690450.9 36.7, 354290.8 6690455.4 36.7, 354291.2 6690455.4 36.7, 354296.19926241995 6690471.022695063 36.7, 354318.7362460187 6690471.022695063 36.7, 354315.2 6690462.6 36.7))
BATIMENT0000000302934421;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1978-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;8.4;32.2;40.7;44.2;33.1;Cadastre;A 1.0;POLYGON Z ((354326.9 6690469.7 40.7, 354330.1 6690466.6 40.7, 354335.8 6690461.2 40.7, 354331.3 6690453.4 40.7, 354321.4 6690459 40.7, 354326.9 6690469.7 40.7))
BATIMENT0000000302934420;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.1;32.5;41.6;44.2;33.5;Cadastre;A 1.0;POLYGON Z ((354334.2105048233 6690471.022695063 41.6, 354342.22831623134 6690471.022695063 41.6, 354343.6 6690469.7 41.6, 354335.8 6690461.2 41.6, 354330.1 6690466.6 41.6, 354334.2105048233 6690471.022695063 41.6))
BATIMENT0000000302934422;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;32.7;40.2;42.6;33.7;Cadastre;A 1.0;POLYGON Z ((354330.1 6690466.6 40.2, 354326.9 6690469.7 40.2, 354325.5332151021 6690471.022695063 40.2, 354334.2105048233 6690471.022695063 40.2, 354330.1 6690466.6 40.2))
BATIMENT0000000302934414;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;24.8;28.2;31.5;25.7;Cadastre;;POLYGON Z ((354122.6 6690431.3 28.2, 354123.6 6690429.3 28.2, 354121.8 6690428.4 28.2, 354120.8 6690430.5 28.2, 354122.6 6690431.3 28.2))
BATIMENT0000000302934410;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1927-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;14;20;6.8;28.6;35.4;36.5;29.2;Cadastre;A 1.0;POLYGON Z ((354162 6690434 35.4, 354160.4 6690433.8 35.4, 354159.4 6690437.1 35.4, 354161.9 6690438.2 35.4, 354167.2 6690440.8 35.4, 354173.3 6690428.1 35.4, 354166.3 6690424.8 35.4, 354162 6690434 35.4))
BATIMENT0000000302934408;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;30.2;36.5;;;Cadastre;;POLYGON Z ((354161.9 6690438.2 36.5, 354159.4 6690437.1 36.5, 354157.6 6690442.6 36.5, 354157.4 6690443.5 36.5, 354158.9 6690444.3 36.5, 354161.9 6690438.2 36.5))
BATIMENT0000000302934409;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;30;20;6.0;29.8;35.8;;;Cadastre;A 1.0;POLYGON Z ((354158.9 6690444.3 35.8, 354164.3 6690446.9 35.8, 354167.2 6690440.8 35.8, 354161.9 6690438.2 35.8, 354158.9 6690444.3 35.8))
BATIMENT0000000302934407;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;12;20;10.7;29.0;39.7;42.6;29.5;Cadastre;A 1.0;POLYGON Z ((354157.4 6690443.5 39.7, 354157.6 6690442.6 39.7, 354156 6690442.2 39.7, 354152.2 6690450.3 39.7, 354149.3 6690449 39.7, 354148.5 6690450.2 39.7, 354150.7 6690451.3 39.7, 354159.9 6690455.8 39.7, 354164.3 6690446.9 39.7, 354158.9 6690444.3 39.7, 354157.4 6690443.5 39.7))
BATIMENT0000000302934406;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;00;00;14.8;29.2;44.0;47.4;30.3;Cadastre;A 1.0;POLYGON Z ((354149.9 6690453.2 44, 354147.5 6690452.1 44, 354145 6690457.2 44, 354147.3 6690458.2 44, 354146.4 6690460.4 44, 354155.6 6690464.7 44, 354159.9 6690455.8 44, 354150.7 6690451.3 44, 354149.9 6690453.2 44))
BATIMENT0000000302935298;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;13.4;28.9;42.3;43.8;32.2;Cadastre;A 1.0;POLYGON Z ((354170.8 6690467.5 42.3, 354178.20161771565 6690471.022695063 42.3, 354191.24189462047 6690471.022695063 42.3, 354191.5 6690470.3 42.3, 354193.3 6690466.8 42.3, 354192.4 6690466.4 42.3, 354189.5 6690464.9 42.3, 354188.6 6690466.8 42.3, 354187.4 6690466.2 42.3, 354188.3 6690464.3 42.3, 354188.3 6690464.2 42.3, 354188.6 6690463.4 42.3, 354190.3 6690459.6 42.3, 354183.5 6690456.4 42.3, 354178.9 6690454.3 42.3, 354177.4 6690453.6 42.3, 354170.8 6690467.5 42.3))
BATIMENT0000000302934405;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;10.3;29.7;40.0;43.0;30.3;Cadastre;A 1.0;POLYGON Z ((354143.1 6690467.4 40, 354150.67472604034 6690471.022695063 40, 354152.66128257645 6690471.022695063 40, 354155.6 6690464.7 40, 354146.4 6690460.4 40, 354143.1 6690467.4 40))
BATIMENT0000000302934404;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1942-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;7.0;29.9;36.9;40.6;30.2;Cadastre;A 1.0;POLYGON Z ((354142.2 6690466.9 36.9, 354140.1149588189 6690471.022695063 36.9, 354150.67472604034 6690471.022695063 36.9, 354143.1 6690467.4 36.9, 354142.2 6690466.9 36.9))
BATIMENT0000000302918892;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;15.7;19.5;23.7;16.1;Cadastre;;POLYGON Z ((353966.7 6690325.1 19.5, 353965.4 6690321 19.5, 353963.9 6690321.4 19.5, 353962.9 6690318.9 19.5, 353961.4 6690319.4 19.5, 353963.7 6690326.2 19.5, 353965.6 6690325.5 19.5, 353966.7 6690325.1 19.5))
BATIMENT0000000302918890;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;35;90;9.9;15.6;25.6;26.6;16.3;Cadastre;A 1.0;POLYGON Z ((353955.7 6690329 25.6, 353963.7 6690326.2 25.6, 353961.4 6690319.4 25.6, 353960.5 6690316.9 25.6, 353952.6 6690319.8 25.6, 353955.7 6690329 25.6))
BATIMENT0000000302918891;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2023-01-31 17:32:48;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;13;8.1;15.5;23.6;25.6;15.9;Cadastre;A 1.0;POLYGON Z ((353959.3 6690338.6 23.6, 353968 6690335.5 23.6, 353969 6690335.2 23.6, 353965.6 6690325.5 23.6, 353963.7 6690326.2 23.6, 353955.7 6690329 23.6, 353959.3 6690338.6 23.6))
BATIMENT0000000302934023;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;14;3.8;17.5;21.3;26.4;18.9;Cadastre;B 0.4;POLYGON Z ((354028.3 6690342.4 21.3, 354028.3 6690341.9 21.3, 354031.4 6690340.8 21.3, 354026.8 6690328.2 21.3, 354023.6 6690329.5 21.3, 354023.7 6690329.8 21.3, 354021.8 6690330.5 21.3, 354021.6 6690330.1 21.3, 354021.1 6690330.4 21.3, 354022.7 6690334.6 21.3, 354016.4 6690336.8 21.3, 354019.7 6690345.5 21.3, 354028.3 6690342.4 21.3))
BATIMENT0000000302918893;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;30;30;4.3;15.4;19.8;25.3;15.9;Cadastre;A 1.0;POLYGON Z ((353971.4 6690345 19.8, 353971.8 6690344.8 19.8, 353978 6690342.6 19.8, 353974.6 6690333.2 19.8, 353969 6690335.2 19.8, 353968 6690335.5 19.8, 353959.3 6690338.6 19.8, 353962.8 6690348 19.8, 353971.4 6690345 19.8))
BATIMENT0000000302918899;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.0;16.9;18.9;21.7;17.6;Cadastre;C 0.3;POLYGON Z ((354002.2 6690333.9 18.9, 353997.2 6690337 18.9, 354003.4 6690353.5 18.9, 354008.4 6690350.7 18.9, 354006.7 6690346.3 18.9, 354002.2 6690333.9 18.9))
BATIMENT0000000302934021;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;30;6.3;17.6;23.9;25.0;18.4;Cadastre;A 1.0;POLYGON Z ((354019.7 6690345.5 23.9, 354016.4 6690336.8 23.9, 354015.4 6690334.1 23.9, 354012.4 6690335.3 23.9, 354011.3 6690336 23.9, 354011.1 6690336.5 23.9, 354011 6690337 23.9, 354010.9 6690337.6 23.9, 354010.9 6690338.2 23.9, 354010.9 6690338.7 23.9, 354012.6 6690344 23.9, 354006.7 6690346.3 23.9, 354008.4 6690350.7 23.9, 354011.7 6690359.5 23.9, 354023.2 6690355.3 23.9, 354020.3 6690347.4 23.9, 354019.7 6690345.5 23.9))
BATIMENT0000000302934022;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.5;17.6;21.1;22.2;18.4;Cadastre;B 0.5;POLYGON Z ((354023.4 6690355.6 21.1, 354026.7 6690349.9 21.1, 354024.8 6690345.6 21.1, 354020.3 6690347.4 21.1, 354023.2 6690355.3 21.1, 354023.4 6690355.6 21.1))
BATIMENT0000000302918894;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;35;90;7.6;15.3;23.0;23.7;16.1;Cadastre;A 1.0;POLYGON Z ((353966 6690357.3 23, 353974.9 6690354.1 23, 353971.8 6690344.8 23, 353971.4 6690345 23, 353962.8 6690348 23, 353966 6690357.3 23))
BATIMENT0000000302918854;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.7;15.0;18.7;22.7;17.0;Cadastre;C 0.5;POLYGON Z ((353981.2 6690344.5 18.7, 353982.6 6690349 18.7, 353985.9 6690358.4 18.7, 353987.1 6690361.4 18.7, 353991.9 6690358.2 18.7, 353985.9 6690341.4 18.7, 353981.2 6690344.5 18.7))
BATIMENT0000000302918818;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;30;6.0;17.5;23.5;25.2;17.7;Cadastre;A 1.0;POLYGON Z ((353921.5 6690302.2 23.5, 353925 6690312.2 23.5, 353937.8 6690307.7 23.5, 353936 6690302.8 23.5, 353933.5 6690303.7 23.5, 353931.6 6690298.6 23.5, 353921.5 6690302.2 23.5))
BATIMENT0000000302918819;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;8.4;16.0;24.5;27.1;16.8;Cadastre;A 1.0;POLYGON Z ((353925 6690312.2 24.5, 353928.4 6690321.8 24.5, 353931.2 6690320.9 24.5, 353941.3 6690317.4 24.5, 353937.8 6690307.7 24.5, 353925 6690312.2 24.5))
BATIMENT0000000302918820;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;10;8.6;15.5;24.2;26.1;16.2;Cadastre;A 1.0;POLYGON Z ((353931.2 6690320.9 24.2, 353934.5 6690330.2 24.2, 353944.6 6690326.7 24.2, 353941.3 6690317.4 24.2, 353931.2 6690320.9 24.2))
BATIMENT0000000302918821;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;35;30;8.4;15.0;23.5;26.4;15.8;Cadastre;A 1.0;POLYGON Z ((353934.5 6690330.2 23.5, 353934 6690330.4 23.5, 353937.4 6690339.7 23.5, 353941.5 6690338.3 23.5, 353948 6690336.1 23.5, 353944.6 6690326.7 23.5, 353934.5 6690330.2 23.5))
BATIMENT0000000302918822;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;10;6.2;15.0;21.2;23.0;15.7;Cadastre;A 1.0;POLYGON Z ((353944.8 6690347.8 21.2, 353951.4 6690345.6 21.2, 353948 6690336.1 21.2, 353941.5 6690338.3 21.2, 353944.8 6690347.8 21.2))
BATIMENT0000000302918779;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;0.8;16.0;16.8;;;Cadastre;C 0.2;POLYGON Z ((353920.5 6690335.3 16.8, 353932.8 6690369.8 16.8, 353937.3 6690368.2 16.8, 353935.1 6690362.1 16.8, 353931.7 6690352.7 16.8, 353928.2 6690343.2 16.8, 353924.8 6690333.9 16.8, 353920.5 6690335.3 16.8))
BATIMENT0000000302918823;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;5.8;14.8;20.7;22.7;15.6;Cadastre;A 1.0;POLYGON Z ((353954.7 6690354.8 20.7, 353951.4 6690345.6 20.7, 353944.8 6690347.8 20.7, 353946.7 6690353.2 20.7, 353943.9 6690354.4 20.7, 353945.3 6690358.1 20.7, 353954.7 6690354.8 20.7))
BATIMENT0000002011292761;Indifférenciée;Commercial et services;;Non;En service;2018-06-04 12:14:25;2019-07-01 11:16:29;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;5.2;14.8;;;;Imagerie aérienne;;POLYGON Z ((353911.5 6690358.9 20, 353908.3 6690349.5 20, 353898.2 6690352.7 20, 353901 6690362.3 20, 353911.5 6690358.9 20))
BATIMENT0000000302918824;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;34;30;6.9;15.0;22.0;23.3;15.8;Cadastre;A 1.0;POLYGON Z ((353945.3 6690358.1 22, 353940.6 6690359.8 22, 353944.1 6690369.3 22, 353950.6 6690366.9 22, 353958.1 6690364.2 22, 353954.7 6690354.8 22, 353945.3 6690358.1 22))
BATIMENT0000002011295128;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.4;15.1;;;;Imagerie aérienne;;POLYGON Z ((353917.2 6690369.7 19.5, 353921.5 6690382.6 19.5, 353925 6690380.5 18.2, 353912.1 6690342.2 18.5, 353906.9 6690344.1 18.5, 353908.3 6690349.5 18, 353911.5 6690358.9 18, 353915.4 6690370.6 19.5, 353917.2 6690369.7 19.5))
BATIMENT0000000302935131;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.3;19.2;27.5;30.1;21.0;Cadastre;C 0.8;POLYGON Z ((354054.4 6690343.8 27.5, 354056.4 6690352.7 27.5, 354062.9 6690351 27.5, 354061 6690342.2 27.5, 354054.4 6690343.8 27.5))
BATIMENT0000000302935133;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;10.5;18.7;29.2;31.4;20.6;Cadastre;A 1.0;POLYGON Z ((354047.7 6690345.1 29.2, 354047.4 6690343.7 29.2, 354046.6 6690343.8 29.2, 354046.2 6690341.8 29.2, 354045.3 6690341.5 29.2, 354042.5 6690346.4 29.2, 354043.4 6690352.2 29.2, 354046 6690355.2 29.2, 354050.2 6690354.1 29.2, 354048.1 6690345.2 29.2, 354047.7 6690345.1 29.2))
BATIMENT0000000302935132;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.4;19.5;29.9;31.1;20.6;Cadastre;A 1.0;POLYGON Z ((354048.8 6690345 29.9, 354048.1 6690345.2 29.9, 354050.2 6690354.1 29.9, 354056.4 6690352.7 29.9, 354054.4 6690343.8 29.9, 354048.8 6690345 29.9))
BATIMENT0000000302935161;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;10;11.0;21.6;32.6;33.9;24.0;Cadastre;A 1.0;POLYGON Z ((354097.2 6690354.8 32.6, 354099.1 6690362.3 32.6, 354106.8 6690360.2 32.6, 354105 6690352.8 32.6, 354097.2 6690354.8 32.6))
BATIMENT0000000302935162;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;34;20;10.4;21.2;31.7;33.5;23.7;Cadastre;A 1.0;POLYGON Z ((354090.8 6690356.5 31.7, 354092.6 6690364 31.7, 354099.1 6690362.5 31.7, 354099.1 6690362.3 31.7, 354097.2 6690354.8 31.7, 354090.8 6690356.5 31.7))
BATIMENT0000000302935164;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.2;20.7;26.0;29.2;21.4;Cadastre;B 1.0;POLYGON Z ((354081.7 6690360.3 26, 354082 6690362.6 26, 354085.1 6690362 26, 354084.2 6690358.2 26, 354080.6 6690359 26, 354080.9 6690360.5 26, 354081.7 6690360.3 26))
BATIMENT0000000302935167;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.0;20.6;25.6;26.0;21.4;Cadastre;A 1.0;POLYGON Z ((354076.4 6690360.1 25.6, 354076.5 6690364.9 25.6, 354079.3 6690365.5 25.6, 354079.5 6690359.2 25.6, 354076.4 6690360.1 25.6))
BATIMENT0000000302935166;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;4.6;20.7;25.3;26.7;21.5;Cadastre;A 1.0;POLYGON Z ((354079.5 6690359.2 25.3, 354079.3 6690365.5 25.3, 354082.6 6690366.5 25.3, 354082 6690362.6 25.3, 354081.7 6690360.3 25.3, 354080.9 6690360.5 25.3, 354080.6 6690359 25.3, 354079.5 6690359.2 25.3))
BATIMENT0000000302935163;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;10.2;20.9;31.1;33.3;23.1;Cadastre;A 1.0;POLYGON Z ((354094.1 6690369.8 31.1, 354092.6 6690364 31.1, 354090.8 6690356.5 31.1, 354084.2 6690358.2 31.1, 354085.1 6690362 31.1, 354086.2 6690365.9 31.1, 354086.6 6690367.8 31.1, 354094.1 6690369.8 31.1))
BATIMENT0000000302935165;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.2;20.9;27.2;31.5;21.9;Cadastre;A 1.0;POLYGON Z ((354086.6 6690367.8 27.2, 354086.2 6690365.9 27.2, 354085.1 6690362 27.2, 354082 6690362.6 27.2, 354082.6 6690366.5 27.2, 354086.6 6690367.8 27.2))
BATIMENT0000000302934386;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;9.7;20.0;29.7;32.8;21.4;Cadastre;A 1.0;POLYGON Z ((354050 6690390.9 29.7, 354050.5 6690388.7 29.7, 354054.9 6690389.9 29.7, 354057 6690381.5 29.7, 354050.5 6690379.6 29.7, 354047.5 6690390.3 29.7, 354050 6690390.9 29.7))
BATIMENT0000000302934385;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;9.2;20.0;29.2;31.9;21.4;Cadastre;A 1.0;POLYGON Z ((354045.9 6690378.3 29.2, 354043.1 6690389 29.2, 354042.3 6690391.8 29.2, 354046.7 6690393.2 29.2, 354047.5 6690390.3 29.2, 354050.5 6690379.6 29.2, 354045.9 6690378.3 29.2))
BATIMENT0000000302934387;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;9.5;20.0;29.5;30.5;22.0;Cadastre;A 1.0;POLYGON Z ((354054.5 6690391.1 29.5, 354062.2 6690393.3 29.5, 354062.5 6690392.5 29.5, 354064.8 6690383.9 29.5, 354057 6690381.5 29.5, 354054.9 6690389.9 29.5, 354054.5 6690391.1 29.5))
BATIMENT0000000302934388;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;9.5;20.0;29.5;32.1;23.1;Cadastre;A 1.0;POLYGON Z ((354071.1 6690394.9 29.5, 354073.6 6690386.3 29.5, 354064.8 6690383.9 29.5, 354062.5 6690392.5 29.5, 354071.1 6690394.9 29.5))
BATIMENT0000000302934384;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;20.8;29.8;34.7;21.3;Cadastre;;POLYGON Z ((354043.1 6690389 29.8, 354039.7 6690387.9 29.8, 354040.9 6690391.4 29.8, 354042.3 6690391.8 29.8, 354043.1 6690389 29.8))
BATIMENT0000000302934389;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1941-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;10;9.3;20.0;29.3;31.9;23.6;Cadastre;A 1.0;POLYGON Z ((354070.9 6690395.8 29.3, 354081.4 6690398.8 29.3, 354084 6690389.3 29.3, 354073.6 6690386.3 29.3, 354071.1 6690394.9 29.3, 354070.9 6690395.8 29.3))
BATIMENT0000000302934390;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;8.1;22.3;30.4;35.7;23.9;Cadastre;A 0.8;POLYGON Z ((354088.2 6690400.7 30.4, 354090.8 6690391.1 30.4, 354084 6690389.3 30.4, 354081.4 6690398.8 30.4, 354088.2 6690400.7 30.4))
BATIMENT0000000302934371;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.5;24.4;30.0;33.5;25.3;Cadastre;A 0.2;POLYGON Z ((354080.1 6690420.1 30, 354078.4 6690423.6 30, 354080.1 6690424.5 30, 354081.3 6690420.7 30, 354080.1 6690420.1 30))
BATIMENT0000000302934372;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;4.7;24.6;29.3;32.9;25.5;Cadastre;A 1.0;POLYGON Z ((354086.3 6690423.1 29.3, 354081.3 6690420.7 29.3, 354080.1 6690424.5 29.3, 354084.6 6690426.6 29.3, 354086.3 6690423.1 29.3))
BATIMENT0000000302934369;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;12;12;9.2;24.3;33.5;36.4;25.9;Cadastre;A 1.0;POLYGON Z ((354074.4 6690421.7 33.5, 354071.5 6690428.1 33.5, 354073.3 6690428.9 33.5, 354081.5 6690432.9 33.5, 354084.6 6690426.6 33.5, 354080.1 6690424.5 33.5, 354078.4 6690423.6 33.5, 354074.4 6690421.7 33.5))
BATIMENT0000000302918895;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;13;20;5.4;17.2;22.6;;;Cadastre;A 1.0;POLYGON Z ((353969.3 6690366.7 22.6, 353977.5 6690363.8 22.6, 353978.4 6690363.5 22.6, 353974.9 6690354.1 22.6, 353966 6690357.3 22.6, 353969.3 6690366.7 22.6))
BATIMENT0000000302918896;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;7.7;15.5;23.2;25.5;16.7;Cadastre;A 1.0;POLYGON Z ((353972.8 6690376.1 23.2, 353980.9 6690373.3 23.2, 353977.5 6690363.8 23.2, 353969.3 6690366.7 23.2, 353972.8 6690376.1 23.2))
BATIMENT0000000302918825;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;90;6.8;15.3;22.2;23.0;15.8;Cadastre;A 1.0;POLYGON Z ((353953.9 6690376 22.2, 353961.4 6690373.3 22.2, 353958.1 6690364.2 22.2, 353950.6 6690366.9 22.2, 353953.9 6690376 22.2))
BATIMENT0000000302918898;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;8.0;35;20;23.6;17.0;40.7;43.3;17.7;Cadastre;C 0.5;POLYGON Z ((354015.4 6690369 40.7, 354012.4 6690361.5 40.7, 354010 6690358.7 40.7, 353990.5 6690370.8 40.7, 353992.6 6690377 40.7, 353994.5 6690382.3 40.7, 354015.4 6690369 40.7))
BATIMENT0000000302918826;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;34;23;6.5;17.5;24.0;;;Cadastre;A 1.0;POLYGON Z ((353953.9 6690376 24, 353953.4 6690376.2 24, 353957.1 6690386 24, 353965 6690383.3 24, 353961.4 6690373.3 24, 353953.9 6690376 24))
BATIMENT0000000302918897;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;00;00;10.0;16.0;26.1;30.7;17.2;Cadastre;A 1.0;POLYGON Z ((353977.4 6690389.3 26.1, 353981.5 6690390.4 26.1, 353994.5 6690382.3 26.1, 353992.6 6690377 26.1, 353985.8 6690379.4 26.1, 353983.4 6690372.4 26.1, 353980.9 6690373.3 26.1, 353972.8 6690376.1 26.1, 353977.4 6690389.3 26.1))
BATIMENT0000000302918557;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;40;9.8;15.4;25.2;26.4;16.6;Cadastre;A 1.0;POLYGON Z ((353958.7 6690389.7 25.2, 353959.5 6690393.6 25.2, 353950.8 6690399 25.2, 353950.9 6690399.3 25.2, 353953.9 6690407.3 25.2, 353966.7 6690399.5 25.2, 353968.8 6690393.9 25.2, 353966.3 6690386.9 25.2, 353958.7 6690389.7 25.2))
BATIMENT0000000302918552;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:56;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.8;17.8;29.7;33.9;22.7;Cadastre;;POLYGON Z ((353966.6 6690460.6 29.7, 353963.5 6690461.5 29.7, 353967.97278101434 6690471.022695063 29.7, 353969.7217734005 6690471.022695063 29.7, 353966.6 6690460.6 29.7))
BATIMENT0000000302920101;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;18.3;22.1;40.5;46.5;28.4;Cadastre;;POLYGON Z ((354045.7 6690470.5 40.5, 354041.9 6690458.2 40.5, 354035.9 6690460.2 40.5, 354034.3 6690454.6 40.5, 354031.9 6690455.2 40.5, 354028.4 6690443.8 40.5, 354007.4 6690450.4 40.5, 354009.2 6690455.8 40.5, 354012 6690455 40.5, 354013.9 6690461 40.5, 354006.2 6690463.4 40.5, 354007.8 6690468.7 40.5, 354001.5 6690470.6 40.5, 353985 6690471 40.5, 353985.00092256354 6690471.022695063 40.5, 354045.8599034238 6690471.022695063 40.5, 354045.7 6690470.5 40.5))
BATIMENT0000000302918514;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2018-09-18 13:31:58;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;13.1;17.7;19.4;14.9;Cadastre;;POLYGON Z ((353907.5 6690374.4 17.7, 353904.5 6690368.4 17.7, 353898.4 6690371.5 17.7, 353901.3 6690377.5 17.7, 353907.5 6690374.4 17.7))
BATIMENT0000000302918518;Industriel, agricole ou commercial;Indifférencié;;Oui;En service;2012-06-19 18:28:24;2023-01-31 17:32:49;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.4;14.0;17.4;18.8;15.4;Cadastre;;POLYGON Z ((353941.2 6690370.7 17.4, 353938.8 6690372.2 17.4, 353926.6 6690379.5 17.4, 353921.5 6690382.6 17.4, 353922.3 6690385.1 17.4, 353938.7 6690375 17.4, 353941.2 6690381.4 17.4, 353944.6 6690379.8 17.4, 353942 6690373 17.4, 353941.2 6690370.7 17.4))
BATIMENT0000000302920115;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-19 18:28:24;2018-09-18 13:31:58;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;13.9;19.5;22.7;15.1;Cadastre;;POLYGON Z ((353901.7 6690399.7 19.5, 353911 6690395.3 19.5, 353917.7 6690392 19.5, 353918.9 6690395.3 19.5, 353920.5 6690399.5 19.5, 353926.8 6690396.9 19.5, 353922.3 6690385.1 19.5, 353921.5 6690382.6 19.5, 353917.2 6690369.7 19.5, 353907.5 6690374.4 19.5, 353901.3 6690377.5 19.5, 353893 6690381.6 19.5, 353901.7 6690399.7 19.5))
BATIMENT0000000302918517;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:28:24;2019-07-01 11:16:29;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;14.6;18.1;18.9;15.1;Cadastre;;POLYGON Z ((353911 6690395.3 18.1, 353912.6 6690398.3 18.1, 353918.9 6690395.3 18.1, 353917.7 6690392 18.1, 353911 6690395.3 18.1))
BATIMENT0000000302918556;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;10.5;14.9;25.5;27.8;16.4;Cadastre;C 1.0;POLYGON Z ((353934.6 6690409.4 25.5, 353932.5 6690404.9 25.5, 353933 6690404.7 25.5, 353932.2 6690403 25.5, 353928.6 6690404.6 25.5, 353934.1 6690419.3 25.5, 353953.9 6690407.3 25.5, 353950.9 6690399.3 25.5, 353934.6 6690409.4 25.5))
BATIMENT0000000302920116;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 18:28:24;2019-07-01 11:16:29;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.6;13.9;19.5;24.5;15.8;Cadastre;C 0.1;POLYGON Z ((353904.2 6690410.8 19.5, 353905.2 6690413.1 19.5, 353907.6 6690411.9 19.5, 353913.3 6690409.1 19.5, 353917.1 6690407.5 19.5, 353912.6 6690398.3 19.5, 353911 6690395.3 19.5, 353901.7 6690399.7 19.5, 353902.7 6690401.7 19.5, 353892.0022898072 6690407.048855097 19.5, 353892.0022898072 6690416.751894733 19.5, 353904.2 6690410.8 19.5))
BATIMENT0000000302918516;Indifférenciée;Commercial et services;;Oui;En service;2012-06-19 18:28:24;2019-07-01 11:16:29;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;15.3;16.7;18.7;15.9;Cadastre;;POLYGON Z ((353908.1 6690418.4 16.7, 353914.8 6690430.7 16.7, 353917.3 6690429.4 16.7, 353907.6 6690411.9 16.7, 353905.2 6690413.1 16.7, 353908.1 6690418.4 16.7))
BATIMENT0000000302918515;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;6.0;00;00;8.3;15.2;23.5;35.6;16.4;Cadastre;A 1.0;POLYGON Z ((353892.0022898072 6690419.5398465395 23.5, 353892.0022898072 6690438.620748422 23.5, 353905.1 6690432.1 23.5, 353900.3 6690422.4 23.5, 353908.1 6690418.4 23.5, 353905.2 6690413.1 23.5, 353892.0022898072 6690419.5398465395 23.5))
BATIMENT0000000302918551;Indifférenciée;Annexe;;Non;En service;2012-06-19 18:28:24;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.6;18.8;23.5;27.8;23.6;Cadastre;C 0.2;POLYGON Z ((353932.0082803639 6690471.022695063 23.5, 353967.97278101434 6690471.022695063 23.5, 353963.5 6690461.5 23.5, 353932.0082803639 6690471.022695063 23.5))
BATIMENT0000000302934370;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.5;24.7;33.2;35.7;25.9;Cadastre;A 1.0;POLYGON Z ((354070.8 6690434.4 33.2, 354079 6690438.3 33.2, 354081.5 6690432.9 33.2, 354073.3 6690428.9 33.2, 354070.8 6690434.4 33.2))
BATIMENT0000000302934373;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.4;25.0;33.5;38.2;26.1;Cadastre;A 1.0;POLYGON Z ((354068.4 6690433.4 33.5, 354065.5 6690439.3 33.5, 354068.3 6690440.8 33.5, 354076.2 6690444.4 33.5, 354079 6690438.3 33.5, 354070.8 6690434.4 33.5, 354068.4 6690433.4 33.5))
BATIMENT0000000302934374;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;12;5.9;26.2;32.1;35.7;26.8;Cadastre;A 1.0;POLYGON Z ((354064.4 6690449.4 32.1, 354072 6690452.8 32.1, 354076.2 6690444.4 32.1, 354068.3 6690440.8 32.1, 354064.4 6690449.4 32.1))
BATIMENT0000000302934415;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;35;23;7.6;26.2;33.8;35.6;28.7;Cadastre;A 1.0;POLYGON Z ((354104.6 6690459.3 33.8, 354108.4 6690451.3 33.8, 354105.9 6690450.1 33.8, 354094.5 6690444.5 33.8, 354090.4 6690452.8 33.8, 354100.2 6690457.3 33.8, 354104.6 6690459.3 33.8))
BATIMENT0000000302934375;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.9;26.0;34.0;35.7;26.8;Cadastre;A 1.0;POLYGON Z ((354062.5 6690453.6 34, 354063.9 6690454.3 34, 354063.4 6690455.4 34, 354069.3 6690458.3 34, 354072 6690452.8 34, 354064.4 6690449.4 34, 354062.5 6690453.6 34))
BATIMENT0000000302934416;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.6;26.6;35.2;37.9;29.2;Cadastre;A 1.0;POLYGON Z ((354086.2 6690461.9 35.2, 354095.2 6690466.2 35.2, 354097.6 6690461.1 35.2, 354098.2 6690461.4 35.2, 354100.2 6690457.3 35.2, 354090.4 6690452.8 35.2, 354086.2 6690461.9 35.2))
BATIMENT0000000302934417;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2023-01-31 17:41:03;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;8.9;27.2;36.1;38.2;29.0;Cadastre;A 1.0;POLYGON Z ((354082.7 6690469.3 36.1, 354086.35547488905 6690471.022695063 36.1, 354092.54462830327 6690471.022695063 36.1, 354092.7 6690470.7 36.1, 354093.7 6690470.9 36.1, 354095.7 6690466.5 36.1, 354095.2 6690466.2 36.1, 354086.2 6690461.9 36.1, 354082.7 6690469.3 36.1))
BATIMENT0000000302934418;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:24:58;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;5.5;28.9;34.4;36.6;28.9;Cadastre;A 1.0;POLYGON Z ((354081.9226863741 6690471.022695063 34.4, 354086.35547488905 6690471.022695063 34.4, 354082.7 6690469.3 34.4, 354081.9226863741 6690471.022695063 34.4))
BATIMENT0000000302936931;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:24:58;2018-09-18 13:36:47;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.1;25.0;33.1;38.4;27.8;Cadastre;;POLYGON Z ((354045.8599034238 6690471.022695063 33.1, 354047.5141089576 6690471.022695063 33.1, 354047.2 6690470.1 33.1, 354045.7 6690470.5 33.1, 354045.8599034238 6690471.022695063 33.1))
BATIMENT0000000303961788;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;13.2;21.0;34.2;38.5;21.6;Cadastre;C 1.0;POLYGON Z ((355931.6 6689958.9 34.2, 355935.6 6689954.9 34.2, 355941.8 6689948.9 34.2, 355940.8 6689947.8 34.2, 355943 6689945.5 34.2, 355944.2 6689946.7 34.2, 355954 6689937.7 34.2, 355949.4 6689932.3 34.2, 355928.1 6689950.6 34.2, 355928.3 6689951 34.2, 355930.5 6689953.4 34.2, 355928 6689956.1 34.2, 355931.6 6689958.9 34.2))
BATIMENT0000000303961789;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;11.2;21.5;32.7;36.2;21.8;Cadastre;A 1.0;POLYGON Z ((355944.2 6689946.7 32.7, 355945.5 6689948.2 32.7, 355947.2 6689950 32.7, 355945.6 6689952.7 32.7, 355947 6689953.9 32.7, 355958.5 6689943.2 32.7, 355954 6689937.7 32.7, 355944.2 6689946.7 32.7))
BATIMENT0000000303961838;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;14.7;21.0;35.7;37.5;21.7;Cadastre;A 1.0;POLYGON Z ((355980.5 6689942.3 35.7, 355977.9 6689940.4 35.7, 355977.5 6689940.8 35.7, 355973.5 6689945.7 35.7, 355978.6 6689952 35.7, 355985.2 6689944.3 35.7, 355980.5 6689942.3 35.7))
BATIMENT0000000303961787;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.5;21.3;22.9;23.1;21.6;Cadastre;;POLYGON Z ((355919.9 6689947.3 22.9, 355922.5 6689950.1 22.9, 355924.5 6689948.2 22.9, 355921.8 6689945.6 22.9, 355919.9 6689947.3 22.9))
BATIMENT0000000303961807;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2023-01-31 17:48:58;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;12.6;21.1;33.7;36.2;21.9;Cadastre;A 1.0;POLYGON Z ((355944.2 6689946.7 33.7, 355941.8 6689948.9 33.7, 355935.6 6689954.9 33.7, 355937.5 6689956.9 33.7, 355940.5 6689959.4 33.7, 355947 6689953.9 33.7, 355945.6 6689952.7 33.7, 355943.3 6689950.3 33.7, 355945.5 6689948.2 33.7, 355944.2 6689946.7 33.7))
BATIMENT0000000303961791;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;20;20;13.2;21.4;34.7;37.5;22.0;Cadastre;C 1.0;POLYGON Z ((355961.3 6689946.5 34.7, 355958.5 6689943.2 34.7, 355947 6689953.9 34.7, 355940.5 6689959.4 34.7, 355943.9 6689963.2 34.7, 355949.1 6689957.8 34.7, 355947.9 6689956.7 34.7, 355952 6689952.7 34.7, 355953.2 6689953.8 34.7, 355961.3 6689946.5 34.7))
BATIMENT0000000303961775;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;21.5;26.2;;;Cadastre;;POLYGON Z ((355922.1 6689957.6 26.2, 355924.5 6689959.8 26.2, 355928 6689956.1 26.2, 355930.5 6689953.4 26.2, 355928.3 6689951 26.2, 355922.1 6689957.6 26.2))
BATIMENT0000000303961792;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;20;20;15.1;20.7;35.9;39.1;22.0;Cadastre;C 1.0;POLYGON Z ((355953.2 6689953.8 35.9, 355949.1 6689957.8 35.9, 355943.9 6689963.2 35.9, 355946.4 6689965.8 35.9, 355947.8 6689967.3 35.9, 355952.6 6689962.8 35.9, 355951.1 6689961.2 35.9, 355955.9 6689956.3 35.9, 355957.5 6689957.8 35.9, 355964.6 6689950.7 35.9, 355961.3 6689946.5 35.9, 355953.2 6689953.8 35.9))
BATIMENT0000000303961806;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.1;20.8;30.0;35.2;21.6;Cadastre;;POLYGON Z ((355931.6 6689958.9 30, 355932.9 6689960.1 30, 355935.5 6689957.5 30, 355936.3 6689958.1 30, 355937.5 6689956.9 30, 355935.6 6689954.9 30, 355931.6 6689958.9 30))
BATIMENT0000000303961794;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;13.0;20.7;33.8;39.0;21.5;Cadastre;A 1.0;POLYGON Z ((355954.8 6689968.4 33.8, 355968.6 6689955.3 33.8, 355964.6 6689950.7 33.8, 355957.5 6689957.8 33.8, 355958.4 6689958.9 33.8, 355952 6689965.4 33.8, 355954.8 6689968.4 33.8))
BATIMENT0000000303961781;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;20.4;24.6;26.0;21.3;Cadastre;;POLYGON Z ((355903.4 6689942.1 24.6, 355901.4 6689943.6 24.6, 355902.5 6689945.1 24.6, 355904.6 6689943.3 24.6, 355903.4 6689942.1 24.6))
BATIMENT0000000303961785;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;19.5;23.5;25.2;21.2;Cadastre;;POLYGON Z ((355900.4 6689942.7 23.5, 355897.6 6689944.9 23.5, 355899.7 6689947.4 23.5, 355902.5 6689945.1 23.5, 355901.4 6689943.6 23.5, 355900.4 6689942.7 23.5))
BATIMENT0000000303961772;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.7;18.2;25.0;28.2;21.2;Cadastre;C 0.3;POLYGON Z ((355896.2 6689943.2 25, 355894.9 6689941.7 25, 355891.2 6689944.7 25, 355895.3 6689949.9 25, 355896 6689950.6 25, 355899.7 6689947.4 25, 355897.6 6689944.9 25, 355896.2 6689943.2 25))
BATIMENT0000000303961765;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;19.1;26.0;31.0;21.4;Cadastre;;POLYGON Z ((355907.3 6689941.1 26, 355904.6 6689943.3 26, 355902.5 6689945.1 26, 355899.7 6689947.4 26, 355896 6689950.6 26, 355899.8 6689955.3 26, 355905.4 6689950.8 26, 355908.1 6689948.6 26, 355913.7 6689943.8 26, 355911.9 6689941.9 26, 355909.7 6689939.1 26, 355907.3 6689941.1 26))
BATIMENT0000000303961764;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;19.1;25.7;30.5;20.2;Cadastre;;POLYGON Z ((355900.9 6689957 25.7, 355899.8 6689955.3 25.7, 355894.5 6689960.3 25.7, 355895.2 6689961 25.7, 355897.9 6689958.4 25.7, 355898.3 6689958.8 25.7, 355900.9 6689957 25.7))
BATIMENT0000000303961761;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;19.5;27.2;32.0;21.6;Cadastre;;POLYGON Z ((355906 6689962.8 27.2, 355909.6 6689959.6 27.2, 355906.7 6689956.4 27.2, 355908.8 6689954.7 27.2, 355905.4 6689950.8 27.2, 355899.8 6689955.3 27.2, 355900.9 6689957 27.2, 355902.4 6689958.7 27.2, 355896 6689965.1 27.2, 355900.7 6689969.5 27.2, 355907.2 6689963.9 27.2, 355906 6689962.8 27.2))
BATIMENT0000000303961758;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;15.0;5.0;00;00;19.0;16.7;35.7;39.5;18.5;Cadastre;C 0.4;POLYGON Z ((355851 6689970.7 35.7, 355852.9 6689969.1 35.7, 355866 6689981.5 35.7, 355864.8 6689979.6 35.7, 355875.3 6689957.9 35.7, 355857.5 6689940 35.7, 355845.2 6689965.2 35.7, 355851 6689970.7 35.7), (355857.6 6689961.6 35.7, 355862.8 6689964.1 35.7, 355860.6 6689968.4 35.7, 355855.2 6689965.9 35.7, 355857.6 6689961.6 35.7))
BATIMENT0000000303961762;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;18.7;23.2;26.7;20.2;Cadastre;;POLYGON Z ((355893.8 6689962.7 23.2, 355889.4 6689966.7 23.2, 355891.9 6689969.3 23.2, 355896 6689965.1 23.2, 355893.8 6689962.7 23.2))
BATIMENT0000000303961760;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;18.8;23.0;28.9;20.6;Cadastre;;POLYGON Z ((355889.2 6689972.4 23, 355885.6 6689976 23, 355890.4 6689981 23, 355892.8 6689983.5 23, 355904.1 6689972.8 23, 355900.7 6689969.5 23, 355896 6689965.1 23, 355891.9 6689969.3 23, 355889.2 6689972.4 23))
BATIMENT0000000303961757;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;9.0;17.8;26.8;29.1;19.2;Cadastre;C 0.3;POLYGON Z ((355873 6689988.4 26.8, 355881.5 6689979.9 26.8, 355885.6 6689976 26.8, 355889.2 6689972.4 26.8, 355886.4 6689969.6 26.8, 355881.6 6689964.5 26.8, 355872.2 6689983.5 26.8, 355869.5 6689983.4 26.8, 355866 6689981.5 26.8, 355873 6689988.4 26.8))
BATIMENT0000000303962376;Indifférenciée;Industriel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.3;20.2;24.6;29.0;21.0;Cadastre;A 0.4;POLYGON Z ((356030.5 6689948.7 24.6, 356027 6689951.7 24.6, 356015.2 6689962.3 24.6, 356017.5 6689964.6 24.6, 356018.8 6689965.1 24.6, 356023.3 6689960.8 24.6, 356025.1 6689962.7 24.6, 356029.4 6689967.5 24.6, 356021.7 6689974.7 24.6, 356026.1 6689979.2 24.6, 356035.2 6689970.9 24.6, 356050.2 6689956.9 24.6, 356039.3 6689946.8 24.6, 356038.9 6689946.4 24.6, 356036.1 6689943.8 24.6, 356030.5 6689948.7 24.6))
BATIMENT0000000303961834;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;10.4;21.1;31.5;35.2;21.3;Cadastre;A 1.0;POLYGON Z ((356005.2 6689958.4 31.5, 356000.2 6689953.8 31.5, 355989.6 6689965.4 31.5, 355989.2 6689965.8 31.5, 355993.2 6689970.3 31.5, 356004.8 6689959 31.5, 356005.2 6689958.4 31.5))
BATIMENT0000000303962394;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;20.4;24.7;26.7;21.2;Cadastre;;POLYGON Z ((356011.8 6689963.4 24.7, 356010.8 6689964.3 24.7, 356011.7 6689965.4 24.7, 356012.9 6689964.4 24.7, 356011.8 6689963.4 24.7))
BATIMENT0000000303962395;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;20.4;25.7;28.2;21.1;Cadastre;;POLYGON Z ((356013.8 6689965.4 25.7, 356012.9 6689964.4 25.7, 356011.7 6689965.4 25.7, 356011.3 6689965.8 25.7, 356012.6 6689966.7 25.7, 356013.8 6689965.4 25.7))
BATIMENT0000000303962381;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;2016-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;00;00;9.9;21.0;30.9;33.4;21.2;Cadastre;C 0.6;POLYGON Z ((356056.8 6689961.4 30.9, 356053.9 6689958 30.9, 356050.2 6689956.9 30.9, 356035.2 6689970.9 30.9, 356041.4 6689976.1 30.9, 356056.8 6689961.4 30.9))
BATIMENT0000000303961831;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2023-01-31 17:56:48;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.0;20.7;33.8;34.5;21.3;Cadastre;A 1.0;POLYGON Z ((356005.3 6689963.7 33.8, 356007.2 6689961.1 33.8, 356004.8 6689959 33.8, 355993.2 6689970.3 33.8, 355999.1 6689977.1 33.8, 356009.5 6689967.4 33.8, 356005.3 6689963.7 33.8))
BATIMENT0000000303962392;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:05:20;2018-09-18 13:52:25;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;20.5;23.7;31.2;20.8;Cadastre;;POLYGON Z ((356017.7 6689970.8 23.7, 356021.7 6689974.7 23.7, 356029.4 6689967.5 23.7, 356025.1 6689962.7 23.7, 356017.7 6689970.8 23.7))
BATIMENT0000000303961830;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;10;20;10.5;21.1;31.6;34.1;21.1;Cadastre;A 1.0;POLYGON Z ((356012.6 6689966.7 31.6, 356011.3 6689965.8 31.6, 356009.5 6689967.4 31.6, 355999.1 6689977.1 31.6, 355998.6 6689977.6 31.6, 356003.9 6689983.7 31.6, 356012.7 6689976.2 31.6, 356011.7 6689975.2 31.6, 356011.1 6689975.6 31.6, 356008.9 6689973 31.6, 356011.4 6689971.2 31.6, 356013.6 6689973.5 31.6, 356014 6689973.9 31.6, 356016.4 6689970.7 31.6, 356012.6 6689966.7 31.6))
BATIMENT0000000303962393;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;10.4;21.1;31.5;36.2;21.1;Cadastre;A 1.0;POLYGON Z ((356016.9 6689970.1 31.5, 356016.4 6689970.7 31.5, 356014 6689973.9 31.5, 356013.6 6689973.5 31.5, 356011.7 6689975.2 31.5, 356012.7 6689976.2 31.5, 356003.9 6689983.7 31.5, 356007 6689987.4 31.5, 356007.6 6689987 31.5, 356021.7 6689974.7 31.5, 356017.7 6689970.8 31.5, 356016.9 6689970.1 31.5))
BATIMENT0000000303962380;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;15.5;20.7;36.3;37.7;21.1;Cadastre;A 1.0;POLYGON Z ((356012.2 6689992.5 36.3, 356019.6 6689985.5 36.3, 356017.1 6689983.2 36.3, 356019.8 6689980.2 36.3, 356022.6 6689982.7 36.3, 356026.1 6689979.2 36.3, 356021.7 6689974.7 36.3, 356007.6 6689987 36.3, 356012.2 6689992.5 36.3))
BATIMENT0000000303961795;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;14.1;20.8;35.0;38.5;21.6;Cadastre;A 1.0;POLYGON Z ((355954.8 6689968.4 35, 355956.3 6689970.2 35, 355962.7 6689964.3 35, 355963.3 6689965 35, 355961.3 6689966.8 35, 355963.5 6689969.4 35, 355962.2 6689971 35, 355962.9 6689971.8 35, 355962 6689972.8 35, 355962.8 6689973.6 35, 355963.6 6689972.9 35, 355974.9 6689963.1 35, 355968.6 6689955.3 35, 355954.8 6689968.4 35))
BATIMENT0000000303961763;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;9.5;20.2;29.7;34.9;21.6;Cadastre;C 0.3;POLYGON Z ((355912.2 6689962.6 29.7, 355912.7 6689963.1 29.7, 355910.9 6689965.2 29.7, 355909.7 6689964 29.7, 355908.8 6689964.7 29.7, 355907.6 6689963.5 29.7, 355907.2 6689963.9 29.7, 355900.7 6689969.5 29.7, 355904.1 6689972.8 29.7, 355905.9 6689974.5 29.7, 355911.9 6689968.2 29.7, 355917.3 6689962.7 29.7, 355914.4 6689960.3 29.7, 355912.2 6689962.6 29.7))
BATIMENT0000000303961867;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.3;21.1;25.5;27.7;21.9;Cadastre;;POLYGON Z ((355926.5 6689972.5 25.5, 355927.4 6689973.4 25.5, 355928.6 6689972.3 25.5, 355929.1 6689972.6 25.5, 355938.5 6689963.3 25.5, 355937.2 6689961.7 25.5, 355926.5 6689972.5 25.5))
BATIMENT0000000303961803;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;20.3;23.9;28.0;22.0;Cadastre;;POLYGON Z ((355935.8 6689971.7 23.9, 355938.9 6689974.5 23.9, 355941.3 6689970.3 23.9, 355942.3 6689971 23.9, 355945.5 6689966.7 23.9, 355942.8 6689964.4 23.9, 355935.8 6689971.7 23.9))
BATIMENT0000000303961809;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;14.2;20.7;35.0;39.0;21.6;Cadastre;C 0.7;POLYGON Z ((355964.9 6689974.2 35, 355964.4 6689975 35, 355966.3 6689976.9 35, 355968.8 6689974.7 35, 355977.5 6689966.2 35, 355974.9 6689963.1 35, 355963.6 6689972.9 35, 355964.9 6689974.2 35))
BATIMENT0000000303961811;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;10;20;11.9;20.5;32.5;35.5;21.3;Cadastre;A 1.0;POLYGON Z ((355981.7 6689971.2 32.5, 355977.5 6689966.2 32.5, 355968.8 6689974.7 32.5, 355973.4 6689979.2 32.5, 355981.7 6689971.2 32.5))
BATIMENT0000000303961773;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;19;90;5.5;21.5;27.0;;;Cadastre;C 0.3;POLYGON Z ((355905.9 6689974.5 27, 355910.4 6689978.8 27, 355911.1 6689979.5 27, 355919.5 6689971.2 27, 355917.4 6689969.2 27, 355915.1 6689971.2 27, 355911.9 6689968.2 27, 355905.9 6689974.5 27))
BATIMENT0000000303961793;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;9.3;20.4;29.7;31.6;21.3;Cadastre;C 0.6;POLYGON Z ((355948.1 6689969.2 29.7, 355947.2 6689968.4 29.7, 355940.4 6689975.9 29.7, 355952.3 6689985.1 29.7, 355955.9 6689980.8 29.7, 355958.2 6689978.1 29.7, 355950.7 6689972.2 29.7, 355954.8 6689968.4 29.7, 355952 6689965.4 29.7, 355948.1 6689969.2 29.7))
BATIMENT0000000303961782;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.7;20.2;28.0;29.7;21.3;Cadastre;A 0.4;POLYGON Z ((355911.1 6689979.5 28, 355916.2 6689984.5 28, 355924.5 6689975.9 28, 355919.5 6689971.2 28, 355911.1 6689979.5 28))
BATIMENT0000000303961813;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;20.4;29.4;31.5;21.1;Cadastre;;POLYGON Z ((355971.1 6689981.4 29.4, 355973.9 6689983.9 29.4, 355974.6 6689983.3 29.4, 355975.8 6689982.1 29.4, 355973.4 6689979.2 29.4, 355971.1 6689981.4 29.4))
BATIMENT0000000303961783;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;9.7;20.0;29.7;30.8;21.5;Cadastre;C 0.4;POLYGON Z ((355924.5 6689975.9 29.7, 355916.2 6689984.5 29.7, 355919.6 6689987.8 29.7, 355920.4 6689988.1 29.7, 355928.4 6689979.6 29.7, 355924.5 6689975.9 29.7))
BATIMENT0000000303961812;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;11.0;20.4;31.5;33.5;20.8;Cadastre;A 1.0;POLYGON Z ((355960 6689983.8 31.5, 355964.3 6689988.1 31.5, 355971.1 6689981.4 31.5, 355966.3 6689976.9 31.5, 355960 6689983.8 31.5))
BATIMENT0000000303961808;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;20.7;27.0;29.7;21.3;Cadastre;;POLYGON Z ((355952.3 6689985.1 27, 355954.7 6689986.5 27, 355958.2 6689982.5 27, 355955.9 6689980.8 27, 355952.3 6689985.1 27))
BATIMENT0000000303961814;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;11.1;20.5;31.7;35.2;21.3;Cadastre;C 0.8;POLYGON Z ((355964.3 6689988.1 31.7, 355967.1 6689991.2 31.7, 355964.4 6689994.1 31.7, 355966.9 6689996.3 31.7, 355967.3 6689996.4 31.7, 355976.5 6689986.8 31.7, 355976.4 6689986.6 31.7, 355978.2 6689984.7 31.7, 355979.2 6689983.7 31.7, 355979.5 6689984.1 31.7, 355986.6 6689977.2 31.7, 355981.7 6689971.2 31.7, 355973.4 6689979.2 31.7, 355975.8 6689982.1 31.7, 355976.7 6689983 31.7, 355975.4 6689984.2 31.7, 355974.6 6689983.3 31.7, 355973.9 6689983.9 31.7, 355971.1 6689981.4 31.7, 355964.3 6689988.1 31.7))
BATIMENT0000000303961815;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.0;20.6;27.6;29.7;20.8;Cadastre;;POLYGON Z ((355961.8 6689990.6 27.6, 355963 6689989.3 27.6, 355960.7 6689987.5 27.6, 355959.6 6689988.9 27.6, 355961.8 6689990.6 27.6))
BATIMENT0000000303961779;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;20;90;4.0;19.1;23.1;26.1;21.5;Cadastre;A 1.0;POLYGON Z ((355928.4 6689979.6 23.1, 355920.4 6689988.1 23.1, 355919.6 6689987.8 23.1, 355914.3 6689993.6 23.1, 355906 6690002.7 23.1, 355910.5 6690006.6 23.1, 355938.9 6689974.5 23.1, 355935.8 6689971.7 23.1, 355928.4 6689979.6 23.1))
BATIMENT0000000303961816;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;12.8;20.9;33.7;38.5;21.5;Cadastre;C 0.7;POLYGON Z ((355967.3 6689996.4 33.7, 355969.2 6689998.3 33.7, 355968 6689999.5 33.7, 355966.1 6689998.7 33.7, 355963.5 6690001.8 33.7, 355965.6 6690004.2 33.7, 355970.3 6689999.5 33.7, 355976.1 6689993.9 33.7, 355979 6689991 33.7, 355989.4 6689980.8 33.7, 355986.6 6689977.2 33.7, 355979.5 6689984.1 33.7, 355979.2 6689983.7 33.7, 355978.2 6689984.7 33.7, 355980 6689986.4 33.7, 355978 6689988.4 33.7, 355976.5 6689986.8 33.7, 355967.3 6689996.4 33.7))
BATIMENT0000000303961818;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;12;20;14.2;20.9;35.1;40.8;21.3;Cadastre;C 0.7;POLYGON Z ((355970.3 6689999.5 35.1, 355971.3 6690000.6 35.1, 355969.1 6690002.8 35.1, 355970.4 6690004 35.1, 355971.6 6690003.9 35.1, 355973.2 6690002.3 35.1, 355975 6690004.1 35.1, 355993.5 6689985.8 35.1, 355989.4 6689980.8 35.1, 355979 6689991 35.1, 355981.4 6689993.3 35.1, 355978.6 6689996.3 35.1, 355976.1 6689993.9 35.1, 355970.3 6689999.5 35.1))
BATIMENT0000000303961784;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;19.9;22.2;22.2;21.0;Cadastre;;POLYGON Z ((355925.3 6689993.1 22.2, 355926.8 6689994.8 22.2, 355928.2 6689993.4 22.2, 355926.5 6689991.5 22.2, 355925.3 6689993.1 22.2))
BATIMENT0000000303961817;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;20.5;25.0;26.6;21.1;Cadastre;;POLYGON Z ((355955.9 6689996.9 25, 355955.7 6689996.6 25, 355961.8 6689990.6 25, 355959.6 6689988.9 25, 355958.2 6689987.8 25, 355950.3 6689996 25, 355953.9 6689999.1 25, 355955.9 6689996.9 25))
BATIMENT0000000303961796;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;18.8;22.7;28.7;20.7;Cadastre;;POLYGON Z ((355892.8 6689983.5 22.7, 355891.1 6689985.3 22.7, 355893.2 6689987.4 22.7, 355900.2 6689993.9 22.7, 355904.4 6689989.6 22.7, 355905.4 6689990.8 22.7, 355908.3 6689987.7 22.7, 355909.9 6689989.4 22.7, 355914.3 6689993.6 22.7, 355919.6 6689987.8 22.7, 355916.2 6689984.5 22.7, 355911.1 6689979.5 22.7, 355910.4 6689978.8 22.7, 355905.9 6689974.5 22.7, 355904.1 6689972.8 22.7, 355892.8 6689983.5 22.7))
BATIMENT0000000303961759;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;9.6;18.2;27.8;30.2;19.1;Cadastre;A 1.0;POLYGON Z ((355881.5 6689979.9 27.8, 355873 6689988.4 27.8, 355882 6689997.1 27.8, 355882.3 6689997.4 27.8, 355885.1 6689994 27.8, 355885.4 6689992.7 27.8, 355884.5 6689991.8 27.8, 355881.6 6689994.7 27.8, 355879.1 6689992.4 27.8, 355890.4 6689981 27.8, 355885.6 6689976 27.8, 355881.5 6689979.9 27.8))
BATIMENT0000000303961754;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;10;20;8.3;16.6;25.0;32.4;18.7;Cadastre;A 1.0;POLYGON Z ((355853.9 6690008.1 25, 355851.6 6690010.8 25, 355856.7 6690015.3 25, 355858.6 6690013.1 25, 355859.8 6690013.3 25, 355861.7 6690011.5 25, 355860.3 6690010.3 25, 355866.8 6690004.1 25, 355868.2 6690002.8 25, 355869 6690001.6 25, 355868.7 6690000.1 25, 355872.4 6689996.6 25, 355874.1 6689997.9 25, 355871.5 6690001.5 25, 355870.4 6690001.1 25, 355869.3 6690002.1 25, 355870.3 6690003 25, 355869.7 6690003.4 25, 355871.6 6690005.2 25, 355874.7 6690005 25, 355882.3 6689997.4 25, 355882 6689997.1 25, 355873 6689988.4 25, 355866 6689981.5 25, 355852.9 6689969.1 25, 355851 6689970.7 25, 355845.2 6689965.2 25, 355842.3 6689971 25, 355866.6 6689987.7 25, 355854.2 6690000.1 25, 355838 6689985.2 25, 355840.8 6689978.7 25, 355839.2 6689977.9 25, 355833.2 6689990 25, 355853.9 6690008.1 25))
BATIMENT0000000303961778;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;20;20;5.6;18.6;24.2;26.7;19.8;Cadastre;A 1.0;POLYGON Z ((355896.6 6690003.4 24.2, 355901.1 6690007.8 24.2, 355906 6690002.7 24.2, 355914.3 6689993.6 24.2, 355909.9 6689989.4 24.2, 355896.6 6690003.4 24.2))
BATIMENT0000000303961756;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;5.5;18.4;24.0;26.9;18.9;Cadastre;A 1.0;POLYGON Z ((355884.4 6689999.5 24, 355897.1 6690011.9 24, 355898.6 6690010.5 24, 355901.1 6690007.8 24, 355896.6 6690003.4 24, 355896.3 6690003.2 24, 355888.3 6689995.9 24, 355884.4 6689999.5 24))
BATIMENT0000000304020507;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;18.4;23.0;24.7;18.7;Cadastre;;POLYGON Z ((355867.9 6690005.2 23, 355869.3 6690003.9 23, 355868.2 6690002.8 23, 355866.8 6690004.1 23, 355867.9 6690005.2 23))
BATIMENT0000000304020505;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;18.2;21.4;27.0;18.7;Cadastre;;POLYGON Z ((355869.7 6690003.4 21.4, 355869.3 6690003.9 21.4, 355867.9 6690005.2 21.4, 355867.5 6690005.7 21.4, 355869.2 6690007.4 21.4, 355871.6 6690005.2 21.4, 355869.7 6690003.4 21.4))
BATIMENT0000000304020521;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.7;18.8;25.5;29.0;19.7;Cadastre;A 1.0;POLYGON Z ((355901.1 6690007.8 25.5, 355898.6 6690010.5 25.5, 355900 6690012 25.5, 355902.2 6690009.7 25.5, 355905 6690012.4 25.5, 355910.5 6690006.6 25.5, 355906 6690002.7 25.5, 355901.1 6690007.8 25.5))
BATIMENT0000000303961755;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;20;20;8.1;18.2;26.4;32.7;18.9;Cadastre;A 1.0;POLYGON Z ((355877.6 6690026.5 26.4, 355878.2 6690027.1 26.4, 355881 6690029.5 26.4, 355883.4 6690026.8 26.4, 355890.7 6690018.9 26.4, 355891.8 6690017.7 26.4, 355897.1 6690011.9 26.4, 355884.4 6689999.5 26.4, 355880.9 6690003.3 26.4, 355890.4 6690012 26.4, 355883.7 6690018.9 26.4, 355884.7 6690019.8 26.4, 355884.1 6690020.5 26.4, 355885.3 6690021.6 26.4, 355884.5 6690022.2 26.4, 355874.4 6690013 26.4, 355874.2 6690012.7 26.4, 355874.4 6690012.3 26.4, 355869.2 6690007.4 26.4, 355867.5 6690005.7 26.4, 355862.6 6690010.5 26.4, 355878.9 6690024.8 26.4, 355877.7 6690026.4 26.4, 355877.6 6690026.5 26.4))
BATIMENT0000000303961753;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;10;20;17.1;15.4;32.5;36.2;18.4;Cadastre;A 1.0;POLYGON Z ((355849.4 6690013.3 32.5, 355830.2 6689996.9 32.5, 355816.5 6690024.6 32.5, 355832.3 6690036.4 32.5, 355835.6 6690031.8 32.5, 355829.7 6690028.8 32.5, 355837.6 6690012.1 32.5, 355842.3 6690016.1 32.5, 355841.8 6690016.7 32.5, 355835.6 6690029.4 32.5, 355836.8 6690030.1 32.5, 355846.9 6690017 32.5, 355847.3 6690016.6 32.5, 355849.5 6690013.4 32.5, 355849.4 6690013.3 32.5))
BATIMENT0000000303962378;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;4.0;10;20;11.5;21.0;32.5;37.0;21.2;Cadastre;A 1.0;POLYGON Z ((356035.2 6689970.9 32.5, 356026.1 6689979.2 32.5, 356022.6 6689982.7 32.5, 356019.6 6689985.5 32.5, 356012.2 6689992.5 32.5, 356021 6690003.1 32.5, 356031.9 6689993.6 32.5, 356039.5 6689987.5 32.5, 356043.9 6689983.8 32.5, 356047.3 6689981.1 32.5, 356041.4 6689976.1 32.5, 356035.2 6689970.9 32.5), (356042 6689978.6 32.5, 356043.2 6689979.7 32.5, 356040.7 6689982.3 32.5, 356037.6 6689984.2 32.5, 356037.2 6689983.7 32.5, 356027.5 6689994.3 32.5, 356025.6 6689992.4 32.5, 356026 6689990.9 32.5, 356024.6 6689989.5 32.5, 356023.2 6689989.7 32.5, 356022.7 6689990.2 32.5, 356021.7 6689988.9 32.5, 356024 6689986.1 32.5, 356027.8 6689986.3 32.5, 356035.7 6689978.7 32.5, 356038 6689979 32.5, 356039.5 6689980.7 32.5, 356042 6689978.6 32.5))
BATIMENT0000000303961822;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;14;20;13.4;20.7;34.2;37.5;21.0;Cadastre;A 1.0;POLYGON Z ((355983.6 6690003 34.2, 355989.4 6690008.7 34.2, 355992.2 6690005.9 34.2, 355995.2 6690002.7 34.2, 355994.3 6690001.7 34.2, 356001.4 6689995.6 34.2, 355997.5 6689990.7 34.2, 355983.6 6690003 34.2))
BATIMENT0000000303962382;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:05:20;2019-03-15 08:35:34;1873-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;10;20;17.4;20.5;37.9;40.2;21.1;Cadastre;A 1.0;POLYGON Z ((356034.1 6690019.1 37.9, 356045.5 6690010 37.9, 356045.6 6690009.8 37.9, 356037.5 6690000.3 37.9, 356031.9 6689993.6 37.9, 356021 6690003.1 37.9, 356034.1 6690019.1 37.9))
BATIMENT0000000303961824;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;12;20;15.8;20.6;36.4;39.7;21.1;Cadastre;A 1.0;POLYGON Z ((355995.6 6690009.4 36.4, 355994.4 6690010.2 36.4, 355992.9 6690008.8 36.4, 355992.3 6690008.7 36.4, 355982.1 6690018.5 36.4, 355985.8 6690022.4 36.4, 355996.7 6690010.8 36.4, 355996.2 6690009.9 36.4, 356006.7 6690001.9 36.4, 356001.4 6689995.6 36.4, 355994.3 6690001.7 36.4, 355995.2 6690002.7 36.4, 355992.2 6690005.9 36.4, 355995.6 6690009.4 36.4))
BATIMENT0000000303967633;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;20.8;28.7;30.2;21.1;Cadastre;;POLYGON Z ((356050.4 6690015.4 28.7, 356050.9 6690014.3 28.7, 356048.9 6690011.9 28.7, 356048.1 6690013.1 28.7, 356050.4 6690015.4 28.7))
BATIMENT0000000303967590;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;10.2;19.8;30.1;34.5;20.8;Cadastre;A 1.0;POLYGON Z ((356000.3 6690013.1 30.1, 356000.8 6690013.6 30.1, 356002.8 6690015.7 30.1, 355999.7 6690018.2 30.1, 355998.9 6690017.3 30.1, 355999.1 6690016.8 30.1, 355998.5 6690016.2 30.1, 355997.4 6690017.2 30.1, 355997.7 6690017.6 30.1, 355990 6690025.8 30.1, 355991 6690027.1 30.1, 355994 6690029.8 30.1, 356013.5 6690009.7 30.1, 356009.9 6690005.7 30.1, 356000.3 6690013.1 30.1))
BATIMENT0000000303967631;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;10;20;12.5;20.8;33.3;37.2;21.0;Cadastre;C 0.9;POLYGON Z ((356033.5 6690019.5 33.3, 356039.4 6690026.7 33.3, 356040.1 6690026.2 33.3, 356052.3 6690017.5 33.3, 356051.5 6690016.5 33.3, 356050.4 6690015.4 33.3, 356048.1 6690013.1 33.3, 356047.4 6690012.1 33.3, 356045.5 6690010 33.3, 356034.1 6690019.1 33.3, 356033.5 6690019.5 33.3))
BATIMENT0000000303967632;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1775-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;;;6.5;20.5;27.1;33.0;21.1;Cadastre;A 1.0;POLYGON Z ((356043.7 6690030.6 27.1, 356052.2 6690024 27.1, 356055.2 6690021.7 27.1, 356060 6690017.5 27.1, 356058.4 6690015.5 27.1, 356057.3 6690013.8 27.1, 356052.3 6690017.5 27.1, 356040.1 6690026.2 27.1, 356043.7 6690030.6 27.1))
BATIMENT0000000303967588;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;5.0;00;00;11.3;18.8;30.2;38.7;21.1;Cadastre;A 1.0;POLYGON Z ((355997.7 6690017.6 30.2, 355997.4 6690017.2 30.2, 355995.4 6690015 30.2, 355998.7 6690011.6 30.2, 356000.3 6690013.1 30.2, 356009.9 6690005.7 30.2, 356006.7 6690001.9 30.2, 355996.2 6690009.9 30.2, 355996.7 6690010.8 30.2, 355985.8 6690022.4 30.2, 355984.8 6690023.4 30.2, 355983.8 6690024.4 30.2, 355969.6 6690039.5 30.2, 355973.4 6690043.1 30.2, 355978.5 6690037.8 30.2, 355976.6 6690036.1 30.2, 355985.3 6690026.4 30.2, 355985 6690024.8 30.2, 355985.7 6690024 30.2, 355987.5 6690023.8 30.2, 355990 6690025.8 30.2, 355997.7 6690017.6 30.2))
BATIMENT0000000303967589;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;;;7.1;20.5;27.6;30.6;20.7;Cadastre;A 1.0;POLYGON Z ((355998.1 6690033.9 27.6, 356003.6 6690027.5 27.6, 356004.4 6690026.4 27.6, 356002.8 6690025 27.6, 356004.8 6690023 27.6, 356010.1 6690026.8 27.6, 356016.7 6690017 27.6, 356016.7 6690013.5 27.6, 356013.5 6690009.7 27.6, 355994 6690029.8 27.6, 355992.6 6690031.2 27.6, 355991.8 6690032.1 27.6, 355996.1 6690036.2 27.6, 355998.1 6690033.9 27.6))
BATIMENT0000000303961819;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1866-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.3;20.4;22.7;22.8;20.9;Cadastre;A 0.4;POLYGON Z ((355948.3 6689998.2 22.7, 355950.4 6689999.9 22.7, 355950.2 6690000.3 22.7, 355951.6 6690001.6 22.7, 355953.9 6689999.1 22.7, 355950.3 6689996 22.7, 355948.3 6689998.2 22.7))
BATIMENT0000000303961823;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:04:17;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;4.8;20.1;24.9;28.0;21.0;Cadastre;C 0.4;POLYGON Z ((355938.1 6689996.4 24.9, 355934.5 6690000.2 24.9, 355937 6690002.1 24.9, 355939.4 6689999.5 24.9, 355939.6 6689999.7 24.9, 355940.6 6689998.6 24.9, 355938.1 6689996.4 24.9))
BATIMENT0000000303961820;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;20.0;27.2;30.2;21.2;Cadastre;;POLYGON Z ((355940.6 6689998.6 27.2, 355939.6 6689999.7 27.2, 355939.4 6689999.5 27.2, 355937 6690002.1 27.2, 355939.9 6690005.1 27.2, 355947.5 6689997.1 27.2, 355944.5 6689994.4 27.2, 355940.6 6689998.6 27.2))
BATIMENT0000000304020544;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1866-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;7.2;19.7;27.0;30.6;20.9;Cadastre;A 0.2;POLYGON Z ((355946.1 6690000.8 27, 355940.9 6690006.1 27, 355944.3 6690009.7 27, 355947.3 6690006.5 27, 355949.6 6690003.8 27, 355946.1 6690000.8 27))
BATIMENT0000000304020539;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;3.9;21.1;25.0;26.6;21.5;Cadastre;C 0.3;POLYGON Z ((355963.7 6690006.1 25, 355960.5 6690003 25, 355956.9 6690006.6 25, 355956.2 6690007.3 25, 355958.2 6690009.2 25, 355959.6 6690010.6 25, 355963.7 6690006.1 25))
BATIMENT0000000304020543;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;11.1;17.5;28.6;31.6;21.3;Cadastre;C 0.4;POLYGON Z ((355949.6 6690003.8 28.6, 355947.3 6690006.5 28.6, 355949.5 6690008.4 28.6, 355946.2 6690011.8 28.6, 355947.9 6690013.6 28.6, 355949.1 6690014.6 28.6, 355953.1 6690010.4 28.6, 355956.2 6690007.3 28.6, 355956.9 6690006.6 28.6, 355951.6 6690001.6 28.6, 355949.6 6690003.8 28.6))
BATIMENT0000000303961821;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:04:17;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;19.6;25.2;35.6;21.8;Cadastre;;POLYGON Z ((355963.9 6690015 25.2, 355960.4 6690018.5 25.2, 355956.1 6690022.7 25.2, 355964.5 6690033.4 25.2, 355969.9 6690028 25.2, 355978.5 6690019.5 25.2, 355979.7 6690018.3 25.2, 355989.4 6690008.7 25.2, 355983.6 6690003 25.2, 355997.5 6689990.7 25.2, 355993.5 6689985.8 25.2, 355975 6690004.1 25.2, 355979.7 6690009 25.2, 355974.8 6690013.7 25.2, 355970.1 6690008.9 25.2, 355963.9 6690015 25.2))
BATIMENT0000000304020536;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;46;90;3.2;21.0;24.3;26.2;21.6;Cadastre;C 0.3;POLYGON Z ((355970.1 6690008.9 24.3, 355970.6 6690008.4 24.3, 355967.6 6690005.4 24.3, 355966.4 6690005.5 24.3, 355960.4 6690011.5 24.3, 355963.9 6690015 24.3, 355970.1 6690008.9 24.3))
BATIMENT0000000304020538;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;20.3;24.1;24.7;21.3;Cadastre;;POLYGON Z ((355959.6 6690010.6 24.1, 355958.2 6690009.2 24.1, 355955.3 6690012.2 24.1, 355956.6 6690013.6 24.1, 355959.6 6690010.6 24.1))
BATIMENT0000000304020542;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;10.3;17.5;27.8;30.0;21.2;Cadastre;C 0.3;POLYGON Z ((355949.1 6690014.6 27.8, 355952.2 6690018.2 27.8, 355956 6690014.2 27.8, 355956.6 6690013.6 27.8, 355955.3 6690012.2 27.8, 355953.1 6690010.4 27.8, 355949.1 6690014.6 27.8))
BATIMENT0000000304020966;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;19.7;;;;Cadastre;;POLYGON Z ((355914.9 6690015.1 -1000, 355916.9 6690016.8 -1000, 355918.6 6690015.1 -1000, 355916.5 6690013.2 -1000, 355914.9 6690015.1 -1000))
BATIMENT0000000304020540;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;10.6;18.7;29.4;30.8;21.1;Cadastre;A 1.0;POLYGON Z ((355956 6690014.2 29.4, 355952.2 6690018.2 29.4, 355956.1 6690022.7 29.4, 355960.4 6690018.5 29.4, 355956 6690014.2 29.4))
BATIMENT0000000304020549;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.7;17.5;26.2;27.4;20.1;Cadastre;A 0.7;POLYGON Z ((355930.5 6690023.5 26.2, 355930.6 6690023.9 26.2, 355928.1 6690026.2 26.2, 355931.1 6690030.3 26.2, 355935 6690026.5 26.2, 355937.2 6690024.3 26.2, 355945.2 6690016.4 26.2, 355947.9 6690013.6 26.2, 355946.2 6690011.8 26.2, 355944.6 6690010.2 26.2, 355930.5 6690023.5 26.2))
BATIMENT0000000304020550;Indifférenciée;Annexe;;Oui;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;06;02;9.4;17.5;26.9;30.5;19.4;Cadastre;B 1.0;POLYGON Z ((355945.2 6690016.4 26.9, 355937.2 6690024.3 26.9, 355941.2 6690027.8 26.9, 355942.9 6690026.3 26.9, 355949.1 6690021 26.9, 355945.2 6690016.4 26.9))
BATIMENT0000000304020545;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1865-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;13.6;18.3;32.0;33.7;21.8;Cadastre;A 1.0;POLYGON Z ((355969.9 6690028 32, 355973 6690031.1 32, 355971 6690031.1 32, 355966.5 6690035.9 32, 355969.6 6690039.5 32, 355983.8 6690024.4 32, 355978.5 6690019.5 32, 355969.9 6690028 32))
BATIMENT0000000304020553;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.6;18.3;26.0;29.7;19.3;Cadastre;;POLYGON Z ((355935 6690026.5 26, 355944.9 6690035.1 26, 355946.9 6690033 26, 355941.2 6690027.8 26, 355937.2 6690024.3 26, 355935 6690026.5 26))
BATIMENT0000000304020526;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;25;29;3.8;17.5;21.3;26.7;20.4;Cadastre;A 1.0;POLYGON Z ((355923.2 6690025.2 21.3, 355923 6690025.1 21.3, 355916.5 6690032.5 21.3, 355911.8 6690037.9 21.3, 355914.4 6690040.2 21.3, 355919.2 6690035 21.3, 355920.4 6690033.5 21.3, 355924.4 6690037.6 21.3, 355927.6 6690033.5 21.3, 355927.8 6690033.7 21.3, 355931.1 6690030.3 21.3, 355928.1 6690026.2 21.3, 355925.4 6690022.7 21.3, 355923.2 6690025.2 21.3))
BATIMENT0000000304020551;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;4.0;10;20;11.1;17.5;28.6;33.6;19.0;Cadastre;A 1.0;POLYGON Z ((355944.9 6690035.1 28.6, 355938 6690042.8 28.6, 355941.2 6690045.4 28.6, 355944.2 6690042 28.6, 355945.2 6690042.7 28.6, 355947.7 6690040.1 28.6, 355946.8 6690039 28.6, 355949.8 6690035.7 28.6, 355949.1 6690035.1 28.6, 355951 6690033.9 28.6, 355953.5 6690036.6 28.6, 355952.5 6690037.7 28.6, 355952.2 6690037.5 28.6, 355951.9 6690038 28.6, 355952.1 6690038.3 28.6, 355949.7 6690041.5 28.6, 355949.8 6690041.8 28.6, 355944.2 6690047.8 28.6, 355948.1 6690050.9 28.6, 355952.5 6690046.1 28.6, 355952.3 6690045.7 28.6, 355956.5 6690041.3 28.6, 355961.1 6690037.2 28.6, 355961.9 6690036.4 28.6, 355949.1 6690021 28.6, 355942.9 6690026.3 28.6, 355947.9 6690031.9 28.6, 355946.9 6690033 28.6, 355944.9 6690035.1 28.6))
BATIMENT0000000304020548;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1999-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;6.2;17.4;23.7;28.7;20.2;Cadastre;A 0.2;POLYGON Z ((355973.4 6690043.1 23.7, 355977.7 6690047.1 23.7, 355986.7 6690037.1 23.7, 355982.7 6690033.4 23.7, 355978.5 6690037.8 23.7, 355973.4 6690043.1 23.7))
BATIMENT0000000291510933;Indifférenciée;Indifférencié;;Non;En service;2011-11-16 12:28:21;2018-09-18 13:45:57;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.0;17.6;;25.9;18.1;Imagerie aérienne;;POLYGON Z ((355934.8 6690043.9 20.6, 355919.8 6690059.7 20.6, 355925.3 6690063.7 20.6, 355939.2 6690047.3 20.5, 355934.8 6690043.9 20.6))
BATIMENT0000000304020504;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;20;20;9.6;17.1;26.7;29.6;18.4;Cadastre;C 0.6;POLYGON Z ((355847.3 6690016.6 26.7, 355852.1 6690020.8 26.7, 355852.5 6690020.5 26.7, 355856.7 6690023.6 26.7, 355857 6690023.4 26.7, 355858.3 6690021.8 26.7, 355854.4 6690018.1 26.7, 355856.7 6690015.3 26.7, 355851.6 6690010.8 26.7, 355849.5 6690013.4 26.7, 355847.3 6690016.6 26.7))
BATIMENT0000000304020506;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;10;5.3;17.5;22.8;33.7;18.8;Cadastre;A 1.0;POLYGON Z ((355854.4 6690018.1 22.8, 355858.3 6690021.8 22.8, 355868.4 6690029.9 22.8, 355874.2 6690023.6 22.8, 355868.7 6690018.6 22.8, 355865.8 6690021.9 22.8, 355859 6690016 22.8, 355856.7 6690015.3 22.8, 355854.4 6690018.1 22.8))
BATIMENT0000000304020517;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.1;18.3;28.5;30.5;18.9;Cadastre;A 1.0;POLYGON Z ((355868.4 6690029.9 28.5, 355872.5 6690033.5 28.5, 355878.2 6690027.1 28.5, 355877.6 6690026.5 28.5, 355877.7 6690026.4 28.5, 355874.2 6690023.6 28.5, 355868.4 6690029.9 28.5))
BATIMENT0000000304020500;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1780-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;20;20;11.6;16.6;28.2;31.6;18.7;Cadastre;C 0.6;POLYGON Z ((355836.8 6690030.1 28.2, 355835.6 6690031.8 28.2, 355832.3 6690036.4 28.2, 355833.8 6690037.6 28.2, 355837 6690033.3 28.2, 355837.1 6690033 28.2, 355840.2 6690028.9 28.2, 355842.1 6690030.2 28.2, 355839.2 6690034.1 28.2, 355838.8 6690034 28.2, 355835.4 6690038.7 28.2, 355838.1 6690040.8 28.2, 355841.6 6690043.5 28.2, 355854.7 6690026.6 28.2, 355846.2 6690020.2 28.2, 355847.9 6690017.8 28.2, 355846.9 6690017 28.2, 355836.8 6690030.1 28.2))
BATIMENT0000000304020499;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;5.4;15.0;20.5;29.0;18.7;Cadastre;A 1.0;POLYGON Z ((355810.6 6690036.7 20.5, 355818.7 6690042.7 20.5, 355818.1 6690043.7 20.5, 355829.4 6690052.1 20.5, 355838.1 6690040.8 20.5, 355835.4 6690038.7 20.5, 355833.8 6690037.6 20.5, 355832.3 6690036.4 20.5, 355816.5 6690024.6 20.5, 355810.6 6690036.7 20.5))
BATIMENT0000000304020522;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.7;17.9;24.7;27.0;18.7;Cadastre;;POLYGON Z ((355890.1 6690043.8 24.7, 355888.1 6690046.2 24.7, 355889.5 6690047.3 24.7, 355891.5 6690044.9 24.7, 355890.1 6690043.8 24.7))
BATIMENT0000000304020518;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1770-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;9.3;15.7;25.0;28.2;18.7;Cadastre;A 1.0;POLYGON Z ((355884.9 6690056.9 25, 355886.7 6690054.9 25, 355890.7 6690058.4 25, 355888.9 6690060.7 25, 355890.6 6690062.2 25, 355892.1 6690060.3 25, 355897.9 6690053.7 25, 355899.9 6690051.5 25, 355902 6690048.7 25, 355894.5 6690041.9 25, 355891.5 6690044.9 25, 355889.5 6690047.3 25, 355885.8 6690051.7 25, 355883.1 6690055.3 25, 355884.9 6690056.9 25))
BATIMENT0000000304020496;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;5.3;14.7;20.0;30.0;18.7;Cadastre;A 1.0;POLYGON Z ((355829.4 6690052.1 20, 355824.1 6690058.8 20, 355831.7 6690065.6 20, 355840.7 6690054.3 20, 355846.2 6690047.1 20, 355841.6 6690043.5 20, 355838.1 6690040.8 20, 355829.4 6690052.1 20))
BATIMENT0000000304020511;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;15.8;21.3;24.5;18.1;Cadastre;;POLYGON Z ((355881.2 6690052.9 21.3, 355879.8 6690051.8 21.3, 355869.9 6690063.8 21.3, 355874.2 6690066.3 21.3, 355883.1 6690055.3 21.3, 355885.8 6690051.7 21.3, 355883.7 6690050.1 21.3, 355881.2 6690052.9 21.3))
BATIMENT0000000304020523;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;10;5.5;16.1;21.7;23.7;17.9;Cadastre;A 0.3;POLYGON Z ((355892.1 6690060.3 21.7, 355898.1 6690064.8 21.7, 355900.3 6690066.4 21.7, 355902.3 6690064.1 21.7, 355904.1 6690062 21.7, 355902.1 6690060.7 21.7, 355904.1 6690058.2 21.7, 355897.9 6690053.7 21.7, 355892.1 6690060.3 21.7))
BATIMENT0000000302930524;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;30;40;17.1;11.4;28.5;30.6;11.8;Cadastre;C 0.6;POLYGON Z ((355632.4 6689892.3 28.5, 355637.4 6689894.3 28.5, 355645.7 6689880.5 28.5, 355633.9 6689861.5 28.5, 355633.3 6689861.8 28.5, 355622.9 6689844.6 28.5, 355623.1 6689844.1 28.5, 355619 6689837.5 28.5, 355607.1 6689844.2 28.5, 355600.5 6689852.9 28.5, 355603.9 6689857.9 28.5, 355608.5 6689865.5 28.5, 355613.2 6689862.8 28.5, 355606.1 6689850.9 28.5, 355608.5 6689849.3 28.5, 355606.9 6689846.5 28.5, 355609.4 6689845 28.5, 355610 6689845.9 28.5, 355610.1 6689846 28.5, 355610.4 6689846.1 28.5, 355610.7 6689846.3 28.5, 355611 6689846.4 28.5, 355611.4 6689846.4 28.5, 355611.7 6689846.3 28.5, 355611.9 6689846.3 28.5, 355612 6689846.2 28.5, 355612.2 6689846.2 28.5, 355612.3 6689846.1 28.5, 355612.6 6689845.9 28.5, 355624.5 6689865.4 28.5, 355623.9 6689865.9 28.5, 355624.4 6689866.9 28.5, 355623.9 6689868.1 28.5, 355623.9 6689868.3 28.5, 355623.9 6689868.5 28.5, 355623.9 6689868.7 28.5, 355623.9 6689868.8 28.5, 355624 6689869 28.5, 355624.1 6689869.2 28.5, 355624.2 6689869.5 28.5, 355624.4 6689869.6 28.5, 355624.5 6689869.8 28.5, 355624.6 6689869.9 28.5, 355624.8 6689870 28.5, 355624.9 6689870.1 28.5, 355625.1 6689870.2 28.5, 355625.4 6689870.3 28.5, 355625.8 6689870.4 28.5, 355626 6689870.4 28.5, 355626.3 6689870.4 28.5, 355626.7 6689870.3 28.5, 355626.8 6689870.2 28.5, 355627 6689870.1 28.5, 355627.2 6689870.1 28.5, 355627.3 6689869.9 28.5, 355629.7 6689873.9 28.5, 355630.4 6689873.5 28.5, 355634.1 6689879.9 28.5, 355633.7 6689880.5 28.5, 355632.3 6689880.2 28.5, 355632.1 6689880.2 28.5, 355631.7 6689880.4 28.5, 355631.5 6689880.5 28.5, 355631.3 6689880.7 28.5, 355631.2 6689880.8 28.5, 355630.9 6689881.1 28.5, 355630.6 6689881.5 28.5, 355630.5 6689881.7 28.5, 355630.5 6689881.9 28.5, 355630.4 6689882.3 28.5, 355630.3 6689882.5 28.5, 355630.3 6689882.7 28.5, 355630.3 6689882.9 28.5, 355630.4 6689883.4 28.5, 355630.5 6689883.6 28.5, 355630.6 6689883.8 28.5, 355630.7 6689884 28.5, 355630.8 6689884.2 28.5, 355631.1 6689884.5 28.5, 355631.2 6689884.6 28.5, 355629.9 6689887.2 28.5, 355633.7 6689889.9 28.5, 355632.7 6689891.8 28.5, 355632.4 6689892.3 28.5))
BATIMENT0000000302930522;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;10.9;16.1;18.1;11.5;Cadastre;;POLYGON Z ((355612.4 6689872.5 16.1, 355616.1 6689870.5 16.1, 355617.1 6689869.7 16.1, 355613.2 6689862.8 16.1, 355608.5 6689865.5 16.1, 355612.4 6689872.5 16.1))
BATIMENT0000000302930515;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.9;8.3;16.2;20.2;11.9;Cadastre;;POLYGON Z ((355600.5 6689852.9 16.2, 355591.1 6689872.1 16.2, 355596.5 6689874.4 16.2, 355595.4 6689876.6 16.2, 355603.4 6689880.1 16.2, 355610 6689883.1 16.2, 355614.4 6689885.3 16.2, 355616.4 6689886.3 16.2, 355620.3 6689879.6 16.2, 355613.1 6689875.1 16.2, 355611.7 6689873.2 16.2, 355611.1 6689873.3 16.2, 355609.8 6689876.4 16.2, 355602.8 6689873.5 16.2, 355595.1 6689870.1 16.2, 355603.9 6689857.9 16.2, 355600.5 6689852.9 16.2))
BATIMENT0000000302930518;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.6;8.3;21.0;21.7;9.9;Cadastre;;POLYGON Z ((355586.7 6689870.1 21, 355583.7 6689867.5 21, 355583 6689868.2 21, 355584.6 6689871.2 21, 355588.1 6689873.1 21, 355589.3 6689872.8 21, 355590 6689871.6 21, 355586.7 6689870.1 21))
BATIMENT0000000302930516;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;6.0;12;20;19.3;8.4;27.7;30.9;10.5;Cadastre;C 0.8;POLYGON Z ((355563.4 6689873.4 27.7, 355563.2 6689873.7 27.7, 355563 6689874.1 27.7, 355562.9 6689874.4 27.7, 355562.8 6689874.8 27.7, 355562.7 6689875.2 27.7, 355562.7 6689875.6 27.7, 355562.7 6689875.9 27.7, 355562.7 6689876.3 27.7, 355562.8 6689876.7 27.7, 355562.9 6689877.1 27.7, 355563 6689877.4 27.7, 355563.2 6689877.8 27.7, 355563.4 6689878.1 27.7, 355563.6 6689878.4 27.7, 355563.8 6689878.7 27.7, 355564.1 6689879 27.7, 355564.4 6689879.2 27.7, 355564.7 6689879.4 27.7, 355565 6689879.6 27.7, 355565.4 6689879.8 27.7, 355571.7 6689882.7 27.7, 355588.8 6689890.5 27.7, 355595.4 6689876.6 27.7, 355596.5 6689874.4 27.7, 355591.1 6689872.1 27.7, 355588 6689877.7 27.7, 355578.3 6689872.7 27.7, 355582.8 6689866.6 27.7, 355583.2 6689865.9 27.7, 355573.8 6689858.9 27.7, 355563.6 6689873.1 27.7, 355563.4 6689873.4 27.7))
BATIMENT0000000302930520;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;04;7.3;10.4;17.7;18.3;11.9;Cadastre;C 0.1;POLYGON Z ((355611.7 6689873.2 17.7, 355613.1 6689875.1 17.7, 355620.3 6689879.6 17.7, 355621 6689878.3 17.7, 355616.1 6689870.5 17.7, 355612.4 6689872.5 17.7, 355611.7 6689873.2 17.7))
BATIMENT0000000302930521;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;2.0;01;01;14.0;9.9;24.0;30.0;11.4;Cadastre;C 0.1;POLYGON Z ((355616.4 6689886.3 24, 355618.3 6689887.5 24, 355623.1 6689890 24, 355623.7 6689889 24, 355628.1 6689890.5 24, 355629.9 6689887.2 24, 355627.8 6689885.7 24, 355628.3 6689884.8 24, 355620.3 6689879.6 24, 355616.4 6689886.3 24))
BATIMENT0000000302930514;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;17.6;7.8;25.5;27.9;9.7;Cadastre;A 1.0;POLYGON Z ((355595.4 6689876.6 25.5, 355588.8 6689890.5 25.5, 355607.5 6689899.3 25.5, 355610.7 6689892.8 25.5, 355611.6 6689890.9 25.5, 355614.4 6689885.3 25.5, 355610 6689883.1 25.5, 355608.2 6689886.4 25.5, 355602.1 6689883.1 25.5, 355603.4 6689880.1 25.5, 355595.4 6689876.6 25.5))
BATIMENT0000000302930517;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;10;20;17.7;10.1;27.8;30.6;11.4;Cadastre;A 1.0;POLYGON Z ((355607.5 6689899.3 27.8, 355628.6 6689909 27.8, 355637.4 6689894.3 27.8, 355632.4 6689892.3 27.8, 355632.7 6689891.8 27.8, 355628.1 6689890.5 27.8, 355623.7 6689889 27.8, 355623.1 6689890 27.8, 355624.4 6689893.9 27.8, 355623 6689896.8 27.8, 355619.8 6689898 27.8, 355614.7 6689895.8 27.8, 355618.3 6689887.5 27.8, 355616.4 6689886.3 27.8, 355614.4 6689885.3 27.8, 355611.6 6689890.9 27.8, 355613.5 6689892 27.8, 355612.6 6689893.9 27.8, 355610.7 6689892.8 27.8, 355607.5 6689899.3 27.8))
BATIMENT0000000302930353;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.2;8.3;23.5;27.4;10.9;Cadastre;;POLYGON Z ((355611.7 6689936.7 23.5, 355623.5 6689916.9 23.5, 355612.1 6689911.7 23.5, 355607.8 6689918.9 23.5, 355565.2 6689894.1 23.5, 355566.3 6689892.2 23.5, 355555.3 6689885.7 23.5, 355543.4 6689906 23.5, 355553.4 6689912.4 23.5, 355554 6689912.8 23.5, 355558.8 6689904.8 23.5, 355599.4 6689928.6 23.5, 355601.8 6689929.8 23.5, 355601.3 6689930.5 23.5, 355598.6 6689935.2 23.5, 355608.9 6689941 23.5, 355611.7 6689936.7 23.5))
BATIMENT0000000302930485;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;2.0;10;20;6.6;15.1;21.8;28.7;17.6;Cadastre;B 0.4;POLYGON Z ((355730.4 6689922.8 21.8, 355732.4 6689923.7 21.8, 355738.4 6689926.7 21.8, 355748.2 6689906.5 21.8, 355731.6 6689898.4 21.8, 355728.2 6689896.9 21.8, 355728.3 6689902 21.8, 355738.1 6689906.7 21.8, 355731.4 6689921 21.8, 355730.4 6689922.8 21.8))
BATIMENT0000000302930489;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.4;13.7;18.1;21.2;16.2;Cadastre;;POLYGON Z ((355728.6 6689919.5 18.1, 355730.3 6689920.4 18.1, 355730.8 6689917.7 18.1, 355728.4 6689916.6 18.1, 355728.6 6689919.5 18.1))
BATIMENT0000000302930488;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;10;20;14.5;11.1;25.7;30.2;16.6;Cadastre;A 1.0;POLYGON Z ((355728.4 6689916.6 25.7, 355728.4 6689911.1 25.7, 355728.3 6689907.3 25.7, 355728.2 6689902.4 25.7, 355717.6 6689903.1 25.7, 355714.9 6689903.3 25.7, 355711.3 6689909.5 25.7, 355723 6689909.8 25.7, 355723.1 6689917.1 25.7, 355707.1 6689916.3 25.7, 355699.7 6689928.5 25.7, 355716.6 6689938.2 25.7, 355718.5 6689935.1 25.7, 355718.7 6689934.6 25.7, 355712 6689929.9 25.7, 355712 6689929.7 25.7, 355715.7 6689929.9 25.7, 355716.1 6689929.7 25.7, 355716.5 6689929.5 25.7, 355716.9 6689929.4 25.7, 355717.2 6689929.1 25.7, 355717.6 6689928.9 25.7, 355717.9 6689928.6 25.7, 355718.2 6689928.2 25.7, 355718.5 6689927.9 25.7, 355718.7 6689927.5 25.7, 355718.9 6689927.2 25.7, 355719.1 6689926.8 25.7, 355719.2 6689926.4 25.7, 355719.4 6689925.5 25.7, 355726.6 6689925.8 25.7, 355728.5 6689925.8 25.7, 355728.6 6689919.5 25.7, 355728.4 6689916.6 25.7))
BATIMENT0000000302930487;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;13.5;18.5;20.0;16.1;Cadastre;;POLYGON Z ((355732.4 6689923.7 18.5, 355730.4 6689922.8 18.5, 355731.4 6689921 18.5, 355730.3 6689920.4 18.5, 355728.6 6689919.5 18.5, 355728.5 6689925.8 18.5, 355731 6689925.9 18.5, 355732.4 6689923.7 18.5))
BATIMENT0000000302930490;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;12.5;17.2;21.2;16.2;Cadastre;;POLYGON Z ((355730.8 6689947.7 17.2, 355732.8 6689944.2 17.2, 355742.2 6689928.6 17.2, 355738.4 6689926.7 17.2, 355732.4 6689923.7 17.2, 355731 6689925.9 17.2, 355723.9 6689938.3 17.2, 355721.7 6689942.3 17.2, 355730.8 6689947.7 17.2))
BATIMENT0000000302930500;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;16.0;10.9;27.0;31.0;12.2;Cadastre;A 1.0;POLYGON Z ((355716.6 6689938.2 27, 355699.7 6689928.5 27, 355689 6689946.2 27, 355705.4 6689956.2 27, 355712.3 6689945.3 27, 355704.5 6689940.9 27, 355706.9 6689936.3 27, 355714.9 6689940.9 27, 355716.6 6689938.2 27))
BATIMENT0000000302930493;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.4;11.6;28.0;32.1;13.5;Cadastre;;POLYGON Z ((355718.5 6689935.1 28, 355716.6 6689938.2 28, 355714.9 6689940.9 28, 355712.3 6689945.3 28, 355705.4 6689956.2 28, 355724.6 6689967.8 28, 355731.6 6689956.5 28, 355727.1 6689953.8 28, 355727.3 6689953.4 28, 355718.4 6689948 28, 355721.7 6689942.3 28, 355723.9 6689938.3 28, 355718.5 6689935.1 28))
BATIMENT0000000302931813;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.8;10.6;14.5;17.5;10.9;Cadastre;;POLYGON Z ((355677.7 6689955 14.5, 355679.9 6689951.4 14.5, 355674.9 6689948.4 14.5, 355672.8 6689952.1 14.5, 355677.7 6689955 14.5))
BATIMENT0000000302930501;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;17.0;13.2;30.3;30.5;14.2;Cadastre;;POLYGON Z ((355740.1 6689954.8 30.3, 355740.9 6689953.5 30.3, 355740.6 6689952.5 30.3, 355736.4 6689950 30.3, 355735.2 6689951.7 30.3, 355740.1 6689954.8 30.3))
BATIMENT0000000302930492;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;18.4;13.0;31.5;34.9;14.6;Cadastre;A 1.0;POLYGON Z ((355741.4 6689954.7 31.5, 355738.3 6689960.3 31.5, 355731.6 6689956.5 31.5, 355724.6 6689967.8 31.5, 355736.6 6689975.1 31.5, 355742.6 6689965.9 31.5, 355743.3 6689964.6 31.5, 355742.1 6689964.1 31.5, 355746 6689956 31.5, 355745.4 6689955.8 31.5, 355747.5 6689951.4 31.5, 355739.8 6689947.7 31.5, 355732.8 6689944.2 31.5, 355730.8 6689947.7 31.5, 355730.1 6689948.7 31.5, 355735.2 6689951.7 31.5, 355736.4 6689950 31.5, 355740.6 6689952.5 31.5, 355740.9 6689953.5 31.5, 355741.4 6689954.7 31.5))
BATIMENT0000000302931857;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;20;7.3;18.0;25.3;26.9;19.1;Cadastre;C 0.3;POLYGON Z ((355774.5 6689864.3 25.3, 355777.4 6689858.6 25.3, 355768.6 6689854.2 25.3, 355765.7 6689860.1 25.3, 355774.5 6689864.3 25.3))
BATIMENT0000000302931858;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;5.0;00;00;18.1;18.0;36.1;41.0;19.2;Cadastre;C 0.8;POLYGON Z ((355761 6689880.8 36.1, 355793.9 6689896.7 36.1, 355799.6 6689885.1 36.1, 355800 6689885.2 36.1, 355804.7 6689875.1 36.1, 355804.4 6689875 36.1, 355805.7 6689872.4 36.1, 355795.6 6689867.5 36.1, 355784.8 6689862.3 36.1, 355777.4 6689858.6 36.1, 355774.5 6689864.3 36.1, 355787.7 6689870.7 36.1, 355781.2 6689884.1 36.1, 355759.2 6689873.5 36.1, 355756.6 6689878.7 36.1, 355761 6689880.8 36.1))
BATIMENT0000000302930482;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;;;11.9;16.3;28.2;34.0;19.1;Cadastre;A 1.0;POLYGON Z ((355748.2 6689906.5 28.2, 355751.2 6689908.1 28.2, 355754.3 6689901.6 28.2, 355751.8 6689900.5 28.2, 355752.2 6689899.9 28.2, 355750.1 6689898.7 28.2, 355756.3 6689886.4 28.2, 355757.9 6689887.1 28.2, 355761 6689880.8 28.2, 355756.6 6689878.7 28.2, 355737.6 6689869.4 28.2, 355727.4 6689864.7 28.2, 355727.5 6689866.9 28.2, 355727.6 6689868.6 28.2, 355751.9 6689880.1 28.2, 355750.8 6689882.8 28.2, 355750.4 6689882.8 28.2, 355747.9 6689888.1 28.2, 355747.5 6689888 28.2, 355746.1 6689891.2 28.2, 355746.4 6689891.4 28.2, 355743.8 6689896.7 28.2, 355744 6689897 28.2, 355743.8 6689897.7 28.2, 355742.6 6689897.1 28.2, 355742.1 6689898.2 28.2, 355737.4 6689896 28.2, 355737.1 6689896.7 28.2, 355733.2 6689894.7 28.2, 355731.6 6689898.4 28.2, 355748.2 6689906.5 28.2))
BATIMENT0000000302930483;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;17.0;6.0;00;00;19.1;16.7;35.9;40.7;18.3;Cadastre;A 1.0;POLYGON Z ((355757.9 6689887.1 35.9, 355773 6689894.3 35.9, 355775.2 6689893.6 35.9, 355778.2 6689895.3 35.9, 355770.5 6689910.9 35.9, 355768 6689909.4 35.9, 355766.6 6689907.4 35.9, 355754.3 6689901.6 35.9, 355751.2 6689908.1 35.9, 355762.7 6689913.7 35.9, 355772.6 6689918.6 35.9, 355781.3 6689922.9 35.9, 355783.1 6689919.4 35.9, 355783.6 6689919.4 35.9, 355788.8 6689908.9 35.9, 355788.3 6689908.6 35.9, 355793.9 6689896.7 35.9, 355761 6689880.8 35.9, 355757.9 6689887.1 35.9))
BATIMENT0000000302930484;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;5.0;10;20;19.9;16.0;35.9;39.2;17.0;Cadastre;B 0.8;POLYGON Z ((355753.4 6689934.2 35.9, 355756.2 6689935.5 35.9, 355764 6689939.4 35.9, 355771.6 6689943.1 35.9, 355781.3 6689922.9 35.9, 355772.6 6689918.6 35.9, 355762.7 6689913.7 35.9, 355752.8 6689933.7 35.9, 355753.4 6689934.2 35.9))
BATIMENT0000000302930491;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;5.0;00;00;16.6;14.1;30.7;40.4;16.3;Cadastre;A 1.0;POLYGON Z ((355747.5 6689951.4 30.7, 355747.8 6689951.2 30.7, 355752.9 6689953.5 30.7, 355764 6689958.7 30.7, 355766.5 6689953.4 30.7, 355767.2 6689953.6 30.7, 355772.2 6689943.5 30.7, 355771.6 6689943.1 30.7, 355764 6689939.4 30.7, 355756.2 6689935.5 30.7, 355753.4 6689934.2 30.7, 355752.8 6689933.7 30.7, 355742.2 6689928.6 30.7, 355732.8 6689944.2 30.7, 355739.8 6689947.7 30.7, 355747.5 6689951.4 30.7))
BATIMENT0000000302930502;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;00;00;21.6;13.7;35.4;40.0;15.7;Cadastre;A 1.0;POLYGON Z ((355736.6 6689975.1 35.4, 355751 6689983.9 35.4, 355752.3 6689983.9 35.4, 355757.5 6689973.5 35.4, 355757.2 6689973.3 35.4, 355764 6689958.7 35.4, 355752.9 6689953.5 35.4, 355747.8 6689951.2 35.4, 355747.5 6689951.4 35.4, 355745.4 6689955.8 35.4, 355746 6689956 35.4, 355752.1 6689959 35.4, 355747.3 6689968.2 35.4, 355742.6 6689965.9 35.4, 355736.6 6689975.1 35.4))
BATIMENT0000000304020501;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.3;14.5;24.8;26.9;17.7;Cadastre;;POLYGON Z ((355810.1 6690037.8 24.8, 355818.1 6690043.7 24.8, 355818.7 6690042.7 24.8, 355810.6 6690036.7 24.8, 355810.1 6690037.8 24.8))
BATIMENT0000000304020498;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;00;00;10.5;14.2;24.7;27.7;18.4;Cadastre;A 1.0;POLYGON Z ((355807.6 6690042.9 24.7, 355807.7 6690044.1 24.7, 355818 6690051.3 24.7, 355817.6 6690053.2 24.7, 355824.1 6690058.8 24.7, 355829.4 6690052.1 24.7, 355818.1 6690043.7 24.7, 355810.1 6690037.8 24.7, 355807.6 6690042.9 24.7))
BATIMENT0000000304020983;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:07;2010-01-01;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;0.0;1.0;;;15.6;7.1;;28.9;14.6;Imagerie aérienne;A 1.0;POLYGON Z ((355762.4 6690133 22.7, 355766.5 6690134.7 22.7, 355765.5 6690137 22.7, 355772.7 6690140 22.7, 355776.6 6690141.9 22.7, 355776 6690142.9 22.7, 355776.7 6690143.2 22.7, 355778.7 6690144.1 22.7, 355779.1 6690143.4 22.7, 355778.2 6690142.9 22.7, 355781.2 6690137.3 22.7, 355779.4 6690136.3 22.7, 355784.5 6690125.5 22.7, 355794.3 6690132.6 22.7, 355802.3 6690138.8 22.7, 355802.6 6690138.4 22.7, 355803.8 6690136.7 22.7, 355805.7 6690130.9 22.7, 355817.9 6690111.7 22.7, 355809.5 6690104.2 22.7, 355819.4 6690081.6 22.7, 355820.6 6690082 22.7, 355820.6 6690081.4 22.7, 355820.1 6690081.2 22.7, 355823.4 6690074.5 22.7, 355824.4 6690072.4 22.7, 355824.6 6690071.4 22.7, 355798.8 6690059.6 22.7, 355795.8 6690068.3 22.7, 355793.4 6690068 22.7, 355787.2 6690093.2 22.7, 355788.6 6690094 22.7, 355779.7 6690105.6 22.7, 355784.8 6690108.7 22.7, 355783.6 6690110.5 22.7, 355775.4 6690107.1 22.7, 355767.5 6690121.9 22.7, 355765.2 6690120.8 22.7, 355760 6690131 22.7, 355762.8 6690131.9 22.7, 355762.4 6690133 22.7))
BATIMENT0000000302931814;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.0;9.3;14.3;14.7;10.9;Cadastre;;POLYGON Z ((355624.6 6689923.7 14.3, 355629.4 6689926.5 14.3, 355631.9 6689922.5 14.3, 355627 6689919.6 14.3, 355624.6 6689923.7 14.3))
BATIMENT0000000302930351;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;7.3;11.0;11.4;8.7;Cadastre;;POLYGON Z ((355593.8 6689943.6 11, 355590.8 6689948.4 11, 355600.8 6689954.2 11, 355603.9 6689949.5 11, 355593.8 6689943.6 11))
BATIMENT0000000302930352;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:09:03;2019-07-01 11:20:18;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.4;8.9;25.3;28.5;11.1;Cadastre;;POLYGON Z ((355608.9 6689941 25.3, 355603.9 6689949.5 25.3, 355600.8 6689954.2 25.3, 355625.7 6689969.3 25.3, 355624.8 6689971 25.3, 355637.2 6689978.5 25.3, 355638.2 6689977.1 25.3, 355658.5 6689989.2 25.3, 355669.3 6689970.8 25.3, 355648.9 6689958.7 25.3, 355649.9 6689957.4 25.3, 355637.4 6689949.9 25.3, 355636.6 6689951.4 25.3, 355611.7 6689936.7 25.3, 355608.9 6689941 25.3))
BATIMENT0000000302944255;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;5.0;;;17.1;5.6;22.7;26.5;7.6;Cadastre;A 1.0;POLYGON Z ((355564 6690070.5 22.7, 355568.4 6690075.6 22.7, 355575.2 6690083.5 22.7, 355582.6 6690071.2 22.7, 355579.7 6690067.6 22.7, 355576.7 6690064 22.7, 355573.6 6690060.5 22.7, 355570.5 6690057.1 22.7, 355567.2 6690053.8 22.7, 355559.8 6690065.7 22.7, 355564 6690070.5 22.7))
BATIMENT0000000302944257;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;29;9.4;5.6;15.0;19.3;8.6;Cadastre;A 1.0;POLYGON Z ((355593.2 6690106.6 15, 355594.1 6690105.2 15, 355595.3 6690105.1 15, 355596 6690105 15, 355598.1 6690104.1 15, 355600.6 6690101.6 15, 355601.9 6690101.2 15, 355600.9 6690099.3 15, 355599.9 6690097.4 15, 355598.9 6690095.4 15, 355597.9 6690093.6 15, 355596.8 6690091.7 15, 355589.9 6690103.5 15, 355588.1 6690106.7 15, 355591.9 6690109.1 15, 355593.2 6690106.6 15))
BATIMENT0000000302944260;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.3;6.9;13.2;16.5;7.9;Cadastre;C 0.1;POLYGON Z ((355594.5 6690107.7 13.2, 355598.1 6690104.1 13.2, 355596 6690105 13.2, 355595.3 6690105.1 13.2, 355594.1 6690105.2 13.2, 355593.2 6690106.6 13.2, 355594.5 6690107.7 13.2))
BATIMENT0000000302944256;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;33.0;4.0;35;20;13.0;5.6;18.6;25.9;8.6;Cadastre;C 0.5;POLYGON Z ((355575.2 6690083.5 18.6, 355578.8 6690088.5 18.6, 355578.6 6690089.8 18.6, 355575.7 6690091.7 18.6, 355574.5 6690093.9 18.6, 355570.4 6690091.5 18.6, 355569.6 6690091 18.6, 355567.1 6690089.6 18.6, 355564.2 6690094.1 18.6, 355563.4 6690093.7 18.6, 355562.8 6690094.6 18.6, 355563.6 6690095.2 18.6, 355561.2 6690099 18.6, 355560.6 6690098.7 18.6, 355559.8 6690099.8 18.6, 355560.6 6690100.3 18.6, 355558.2 6690104.1 18.6, 355557.3 6690103.6 18.6, 355556.5 6690104.9 18.6, 355557.4 6690105.4 18.6, 355554.6 6690109.8 18.6, 355555.6 6690110.5 18.6, 355552.2 6690115.6 18.6, 355551.4 6690115 18.6, 355545.5 6690124.3 18.6, 355548.5 6690127.8 18.6, 355555.9 6690136.4 18.6, 355559.9 6690141.1 18.6, 355568.3 6690127.5 18.6, 355563.2 6690124.5 18.6, 355563.8 6690123.5 18.6, 355579.9 6690097.2 18.6, 355589.3 6690102.7 18.6, 355589.9 6690103.5 18.6, 355596.8 6690091.7 18.6, 355594.1 6690087.5 18.6, 355591.3 6690083.3 18.6, 355588.5 6690079.2 18.6, 355585.6 6690075.2 18.6, 355582.6 6690071.2 18.6, 355575.2 6690083.5 18.6))
BATIMENT0000000302944261;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;4.6;7.0;11.6;14.1;8.6;Cadastre;C 0.6;POLYGON Z ((355587.6 6690131.9 11.6, 355592.1 6690125.9 11.6, 355592.3 6690126 11.6, 355605.4 6690108.6 11.6, 355604.6 6690106.7 11.6, 355604.1 6690105.7 11.6, 355603.7 6690104.8 11.6, 355603.2 6690103.9 11.6, 355598.2 6690110.6 11.6, 355597.7 6690110.2 11.6, 355588.4 6690123 11.6, 355587.8 6690122.6 11.6, 355588.2 6690121.9 11.6, 355585.7 6690120 11.6, 355591.9 6690109.1 11.6, 355588.1 6690106.7 11.6, 355577.8 6690124.4 11.6, 355587.6 6690131.9 11.6))
BATIMENT0000000302944263;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.8;7.0;12.8;18.0;7.9;Cadastre;A 1.0;POLYGON Z ((355600.5 6690124.2 12.8, 355602.9 6690125.9 12.8, 355606.7 6690120.6 12.8, 355609.1 6690117.3 12.8, 355608.4 6690115.5 12.8, 355607.7 6690113.8 12.8, 355606.9 6690112 12.8, 355606.2 6690110.3 12.8, 355605.4 6690108.6 12.8, 355592.3 6690126 12.8, 355592.1 6690125.9 12.8, 355587.6 6690131.9 12.8, 355588.2 6690132.2 12.8, 355590.6 6690133.8 12.8, 355595.2 6690136.9 12.8, 355595.3 6690136.7 12.8, 355598.7 6690131.8 12.8, 355596.3 6690130.2 12.8, 355600.5 6690124.2 12.8))
BATIMENT0000000302944262;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;7.6;10.3;14.4;7.9;Cadastre;C 0.1;POLYGON Z ((355586.8 6690139.2 10.3, 355590.6 6690133.8 10.3, 355588.2 6690132.2 10.3, 355584.4 6690137.6 10.3, 355586.8 6690139.2 10.3))
BATIMENT0000000302931166;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:09:03;2023-01-31 17:48:58;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;2.0;00;00;14.3;10.6;24.9;27.2;11.8;Cadastre;C 0.3;POLYGON Z ((355688.6 6689974.7 24.9, 355693.5 6689967.7 24.9, 355697.8 6689961.4 24.9, 355685.2 6689954.1 24.9, 355672.8 6689974.8 24.9, 355682.7 6689980.3 24.9, 355684.1 6689981 24.9, 355684.9 6689979.7 24.9, 355686.3 6689977.5 24.9, 355688.6 6689974.7 24.9))
BATIMENT0000000302931868;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;17.7;10.3;28.0;33.1;12.9;Cadastre;;POLYGON Z ((355706.8 6689985.2 28, 355714.7 6689971.8 28, 355697.8 6689961.4 28, 355693.5 6689967.7 28, 355688.6 6689974.7 28, 355706.8 6689985.2 28))
BATIMENT0000000302931866;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:40;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.5;10.3;16.8;27.5;11.7;Cadastre;;POLYGON Z ((355704.7 6689992 16.8, 355704.4 6689989.3 16.8, 355706.8 6689985.2 16.8, 355688.6 6689974.7 16.8, 355686.3 6689977.5 16.8, 355684.9 6689979.7 16.8, 355704.7 6689992 16.8))
BATIMENT0000000302931164;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;11.0;19.9;33.1;13.7;Cadastre;;POLYGON Z ((355705.4 6690017.5 19.9, 355706.1 6690017.9 19.9, 355716 6690001.9 19.9, 355719.7 6690003.8 19.9, 355732.2 6689982.3 19.9, 355714.7 6689971.8 19.9, 355706.8 6689985.2 19.9, 355704.4 6689989.3 19.9, 355704.7 6689992 19.9, 355706.6 6689993.2 19.9, 355709.9 6689995.1 19.9, 355707.2 6689999.7 19.9, 355708.1 6690000.2 19.9, 355709.7 6690005.2 19.9, 355709 6690007.3 19.9, 355711 6690008.5 19.9, 355709.4 6690011.2 19.9, 355705.4 6690017.5 19.9))
BATIMENT0000000302931165;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:09:03;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.9;12.3;29.2;33.1;14.4;Cadastre;A 1.0;POLYGON Z ((355719.7 6690003.8 29.2, 355738.4 6690015 29.2, 355748.8 6689993.2 29.2, 355748.5 6689992.2 29.2, 355732.2 6689982.3 29.2, 355719.7 6690003.8 29.2))
BATIMENT0000000302931163;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:09:03;2018-09-18 13:45:36;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;10.7;14.5;19.9;11.6;Cadastre;;POLYGON Z ((355699.2 6690005.4 14.5, 355707.7 6690010.7 14.5, 355708.1 6690010.4 14.5, 355709.4 6690011.2 14.5, 355711 6690008.5 14.5, 355709 6690007.3 14.5, 355709.7 6690005.2 14.5, 355708.1 6690000.2 14.5, 355707.2 6689999.7 14.5, 355709.9 6689995.1 14.5, 355706.6 6689993.2 14.5, 355699.2 6690005.4 14.5))
BATIMENT0000000302944277;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;19.5;11.3;30.8;33.8;13.7;Cadastre;;POLYGON Z ((355716 6690001.9 30.8, 355706.1 6690017.9 30.8, 355728.1 6690031.3 30.8, 355730.8 6690030.7 30.8, 355738.4 6690015 30.8, 355719.7 6690003.8 30.8, 355716 6690001.9 30.8))
BATIMENT0000000304020859;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.1;6.1;15.2;22.7;7.9;Cadastre;A 1.0;POLYGON Z ((355691.4 6690157.2 15.2, 355695.2 6690159.3 15.2, 355698.9 6690151.4 15.2, 355695.4 6690149.8 15.2, 355691.4 6690157.2 15.2))
BATIMENT0000000304020880;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.7;6.5;8.2;9.4;7.0;Cadastre;;POLYGON Z ((355725.2 6690238.5 8.2, 355729.1 6690241.8 8.2, 355730.6 6690239.3 8.2, 355726 6690235.3 8.2, 355724.5 6690238.3 8.2, 355725.2 6690238.5 8.2))
BATIMENT0000000304020879;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;5.0;24;20;19.9;5.4;25.3;28.4;7.3;Cadastre;A 1.0;POLYGON Z ((355719.7 6690229.9 25.3, 355714.4 6690230.3 25.3, 355707.3 6690245.3 25.3, 355716.5 6690249.7 25.3, 355722.5 6690237.5 25.3, 355724.5 6690238.3 25.3, 355726 6690235.3 25.3, 355719.7 6690229.9 25.3))
BATIMENT0000000302944259;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;23.0;4.0;00;00;7.2;7.4;14.6;21.3;8.6;Cadastre;A 1.0;POLYGON Z ((355568.3 6690127.5 14.6, 355559.9 6690141.1 14.6, 355572 6690155.1 14.6, 355577.5 6690147.4 14.6, 355582.5 6690140.4 14.6, 355584.4 6690137.6 14.6, 355588.2 6690132.2 14.6, 355587.6 6690131.9 14.6, 355577.8 6690124.4 14.6, 355572.6 6690120.6 14.6, 355569.2 6690126.1 14.6, 355568.3 6690127.5 14.6), (355570.7 6690127.8 14.6, 355580.5 6690135.2 14.6, 355579.1 6690137.2 14.6, 355578.2 6690136.6 14.6, 355571.4 6690146.2 14.6, 355567 6690141.1 14.6, 355571.6 6690134.3 14.6, 355569.9 6690130 14.6, 355570.7 6690127.8 14.6))
BATIMENT0000000302944268;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;15.4;7.0;22.5;27.6;7.9;Cadastre;C 0.2;POLYGON Z ((355604.3 6690160.5 22.5, 355611.3 6690150.9 22.5, 355616.7 6690143.6 22.5, 355613.7 6690131.8 22.5, 355612.9 6690128.9 22.5, 355612.2 6690126.5 22.5, 355611.5 6690124.2 22.5, 355610.7 6690121.9 22.5, 355609.9 6690119.6 22.5, 355609.1 6690117.3 22.5, 355606.7 6690120.6 22.5, 355602.9 6690125.9 22.5, 355598.7 6690131.8 22.5, 355595.3 6690136.7 22.5, 355595.2 6690136.9 22.5, 355594.8 6690137.3 22.5, 355599.6 6690140.8 22.5, 355599.8 6690140.5 22.5, 355600.7 6690140.7 22.5, 355601.5 6690143.6 22.5, 355604.3 6690160.5 22.5))
BATIMENT0000000302944270;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;7.0;22.7;24.2;7.6;Cadastre;;POLYGON Z ((355601.5 6690143.6 22.7, 355600.7 6690140.7 22.7, 355599.8 6690140.5 22.7, 355599.6 6690140.8 22.7, 355598.9 6690141.7 22.7, 355601.5 6690143.6 22.7))
BATIMENT0000000302944264;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;20;10;9.9;5.7;15.6;18.4;7.9;Cadastre;C 0.6;POLYGON Z ((355572 6690155.1 15.6, 355577.3 6690161.3 15.6, 355584.1 6690152.1 15.6, 355584.2 6690152 15.6, 355580.2 6690149.2 15.6, 355577.5 6690147.4 15.6, 355572 6690155.1 15.6))
BATIMENT0000000302944265;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.8;7.1;14.0;17.7;7.9;Cadastre;A 1.0;POLYGON Z ((355582 6690166.8 14, 355588.6 6690157.8 14, 355590.2 6690155.7 14, 355584.5 6690151.6 14, 355584.2 6690152 14, 355584.1 6690152.1 14, 355577.3 6690161.3 14, 355582 6690166.8 14))
BATIMENT0000000302944275;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;6.0;00;00;15.2;7.0;22.3;27.5;7.4;Cadastre;C 0.5;POLYGON Z ((355620.5 6690172.2 22.3, 355620.3 6690169.4 22.3, 355620 6690166.7 22.3, 355619.7 6690163.9 22.3, 355619.2 6690161.2 22.3, 355619.5 6690161.2 22.3, 355619 6690157.6 22.3, 355618.5 6690154.1 22.3, 355617.9 6690150.6 22.3, 355617.3 6690147.1 22.3, 355616.7 6690143.6 22.3, 355611.3 6690150.9 22.3, 355604.3 6690160.5 22.3, 355606.2 6690160.1 22.3, 355606.6 6690162.5 22.3, 355607.8 6690163.3 22.3, 355608.3 6690163.3 22.3, 355609.4 6690174.5 22.3, 355620.7 6690174.9 22.3, 355620.5 6690172.2 22.3))
BATIMENT0000000302944266;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:07;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;00;00;12.9;5.6;18.5;21.5;7.7;Cadastre;C 0.8;POLYGON Z ((355597.4 6690169.9 18.5, 355599.4 6690167.2 18.5, 355592.5 6690162.2 18.5, 355588.6 6690157.8 18.5, 355582 6690166.8 18.5, 355583 6690167.9 18.5, 355583.4 6690167.6 18.5, 355585.1 6690169.5 18.5, 355584.7 6690169.9 18.5, 355586.3 6690171.7 18.5, 355586.6 6690171.4 18.5, 355589.5 6690173.5 18.5, 355589.1 6690174.4 18.5, 355589.9 6690175.3 18.5, 355590.3 6690175.8 18.5, 355590 6690176.1 18.5, 355591.6 6690177.9 18.5, 355594.4 6690174.1 18.5, 355597.4 6690169.9 18.5))
BATIMENT0000000302944274;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.9;7.0;19.0;24.2;7.4;Cadastre;;POLYGON Z ((355609.4 6690174.5 19, 355605.8 6690173.7 19, 355604.8 6690175.2 19, 355607.5 6690177.1 19, 355609.4 6690174.5 19))
BATIMENT0000000302944267;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;4.0;00;00;12.1;5.6;17.7;20.0;7.6;Cadastre;C 0.8;POLYGON Z ((355600.3 6690186.8 17.7, 355607.5 6690177.1 17.7, 355604.8 6690175.2 17.7, 355597.4 6690169.9 17.7, 355594.4 6690174.1 17.7, 355591.6 6690177.9 17.7, 355599.8 6690187.4 17.7, 355600.3 6690186.8 17.7))
BATIMENT0000000302944272;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.2;7.3;18.5;20.2;7.7;Cadastre;;POLYGON Z ((355620.9 6690177.6 18.5, 355620.1 6690177.6 18.5, 355620.2 6690180.5 18.5, 355621.1 6690180.5 18.5, 355620.9 6690177.6 18.5))
BATIMENT0000000304020831;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;4.9;7.1;12.0;13.6;8.2;Cadastre;C 0.2;POLYGON Z ((355811.5 6690142.8 12, 355817 6690147.2 12, 355821.6 6690140.7 12, 355815.8 6690136.7 12, 355811.5 6690142.8 12))
BATIMENT0000000304020832;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;10;20;16.0;6.9;22.9;26.4;9.9;Cadastre;A 0.9;POLYGON Z ((355776 6690142.9 22.9, 355772.5 6690141.1 22.9, 355770.7 6690140.3 22.9, 355769.7 6690142.4 22.9, 355766.6 6690140.9 22.9, 355767.4 6690138.9 22.9, 355761.4 6690135.6 22.9, 355760.5 6690135.6 22.9, 355753 6690148.5 22.9, 355755.1 6690149.6 22.9, 355767 6690156.4 22.9, 355768.8 6690157.4 22.9, 355771.3 6690152.9 22.9, 355772.5 6690153.7 22.9, 355775.3 6690148.5 22.9, 355774 6690147.9 22.9, 355776.7 6690143.2 22.9, 355776 6690142.9 22.9))
BATIMENT0000000304020833;Indifférenciée;Annexe;;Oui;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.1;6.7;12.8;16.9;9.9;Cadastre;A 0.4;POLYGON Z ((355777.3 6690162.3 12.8, 355778.8 6690160.5 12.8, 355789 6690149.1 12.8, 355785.1 6690146.9 12.8, 355778.7 6690144.1 12.8, 355776.7 6690143.2 12.8, 355774 6690147.9 12.8, 355775.3 6690148.5 12.8, 355772.5 6690153.7 12.8, 355771.3 6690152.9 12.8, 355768.8 6690157.4 12.8, 355777.3 6690162.3 12.8))
BATIMENT0000000304020829;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.3;7.1;13.4;14.6;11.0;Cadastre;;POLYGON Z ((355818.2 6690151.2 13.4, 355816 6690148.7 13.4, 355817 6690147.2 13.4, 355811.5 6690142.8 13.4, 355809.8 6690141.4 13.4, 355804 6690136.9 13.4, 355803.8 6690136.7 13.4, 355802.6 6690138.4 13.4, 355802.3 6690138.8 13.4, 355784.8 6690164.1 13.4, 355796.3 6690171.4 13.4, 355802.1 6690175.1 13.4, 355812.6 6690159.7 13.4, 355816.6 6690153.6 13.4, 355818.2 6690151.2 13.4))
BATIMENT0000000304020827;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;7.9;10.3;14.3;11.0;Cadastre;;POLYGON Z ((355797.8 6690181.3 10.3, 355797.7 6690181.8 10.3, 355811.9 6690188.7 10.3, 355817.5 6690178.3 10.3, 355826 6690162.4 10.3, 355826.2 6690161.7 10.3, 355826.2 6690161.4 10.3, 355826.2 6690161.2 10.3, 355826.3 6690161.1 10.3, 355826.5 6690160.2 10.3, 355826.5 6690160.1 10.3, 355826.6 6690159.5 10.3, 355826.6 6690159.4 10.3, 355826.7 6690159.1 10.3, 355826.7 6690158.8 10.3, 355826.8 6690158.7 10.3, 355816.6 6690153.6 10.3, 355812.6 6690159.7 10.3, 355802.1 6690175.1 10.3, 355796.3 6690171.4 10.3, 355794.5 6690175.3 10.3, 355792.8 6690178.9 10.3, 355797.8 6690181.3 10.3))
BATIMENT0000000304020830;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.3;7.1;18.5;26.6;10.5;Cadastre;;POLYGON Z ((355749.3 6690174.9 18.5, 355748.8 6690176 18.5, 355775.7 6690189.8 18.5, 355776.4 6690188.5 18.5, 355749.3 6690174.9 18.5))
BATIMENT0000000304020828;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;189.0;8.0;00;00;12.9;7.3;20.2;29.5;11.2;Cadastre;A 1.0;POLYGON Z ((355826.1 6690219.4 20.2, 355829.1 6690213.7 20.2, 355831.3 6690214.7 20.2, 355833.7 6690215.8 20.2, 355834.4 6690214.6 20.2, 355843.5 6690196.5 20.2, 355842.2 6690195.9 20.2, 355841.3 6690195.4 20.2, 355843.3 6690190.9 20.2, 355824.8 6690181.9 20.2, 355817.5 6690178.3 20.2, 355811.9 6690188.7 20.2, 355797.7 6690181.8 20.2, 355797.8 6690181.3 20.2, 355792.8 6690178.9 20.2, 355784.7 6690175.1 20.2, 355768.7 6690166.5 20.2, 355770 6690164 20.2, 355765.1 6690161.7 20.2, 355764.7 6690161.5 20.2, 355765.4 6690159.9 20.2, 355767 6690156.4 20.2, 355755.1 6690149.6 20.2, 355753.3 6690153.2 20.2, 355752.2 6690155.5 20.2, 355746.6 6690167.4 20.2, 355745 6690170.9 20.2, 355744.3 6690172.2 20.2, 355749.3 6690174.9 20.2, 355776.4 6690188.5 20.2, 355775.7 6690189.8 20.2, 355773.6 6690193.9 20.2, 355826.1 6690219.4 20.2))
BATIMENT0000000304020869;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;15.0;6.9;22.0;28.0;10.5;Cadastre;C 0.1;POLYGON Z ((355731 6690195.2 22, 355725.9 6690205.7 22, 355723.5 6690210.2 22, 355724.5 6690214 22, 355725.6 6690214.5 22, 355725.1 6690215.5 22, 355750.2 6690237.1 22, 355762.4 6690212.2 22, 355760 6690211 22, 355760.7 6690209.6 22, 355731 6690195.2 22))
BATIMENT0000000304020870;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;102.0;7.0;00;00;13.9;8.0;22.0;29.6;11.1;Cadastre;A 1.0;POLYGON Z ((355750.2 6690237.1 22, 355768.3 6690252.7 22, 355777 6690260.2 22, 355788.4 6690237 22, 355806.4 6690245.8 22, 355814.1 6690252.3 22, 355816.9 6690246.3 22, 355822 6690235.6 22, 355764.5 6690207.8 22, 355762.4 6690212.2 22, 355750.2 6690237.1 22))
BATIMENT0000000304020893;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;9.8;17.0;20.7;10.8;Cadastre;;POLYGON Z ((355815.6 6690277.7 17, 355819.2 6690273.5 17, 355818.7 6690273.3 17, 355817.8 6690272.4 17, 355817.8 6690272.5 17, 355815.5 6690275.1 17, 355811.7 6690271.9 17, 355810.3 6690273.2 17, 355815.6 6690277.7 17))
BATIMENT0000000302944718;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;12.5;9.4;21.9;;;Cadastre;C 0.9;POLYGON Z ((355580.4 6690180.5 21.9, 355572.9 6690186.9 21.9, 355574.4 6690188.7 21.9, 355573.3 6690189.6 21.9, 355574.8 6690191.3 21.9, 355575.8 6690190.3 21.9, 355577 6690191.6 21.9, 355575.3 6690193 21.9, 355577.6 6690195.6 21.9, 355578.7 6690194.7 21.9, 355579.6 6690195.9 21.9, 355580.3 6690195.3 21.9, 355587.6 6690188.9 21.9, 355580.4 6690180.5 21.9))
BATIMENT0000000302944271;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;15.2;5.7;20.9;22.9;7.6;Cadastre;;POLYGON Z ((355602.4 6690190.4 20.9, 355602.9 6690189.9 20.9, 355600.3 6690186.8 20.9, 355599.8 6690187.4 20.9, 355602.4 6690190.4 20.9))
BATIMENT0000000302944269;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;20.0;6.0;00;00;14.9;7.2;22.1;26.7;7.7;Cadastre;C 0.4;POLYGON Z ((355607.4 6690196.2 22.1, 355608 6690195.7 22.1, 355610.3 6690198.4 22.1, 355610.1 6690198.6 22.1, 355610.1 6690198.8 22.1, 355610.2 6690199.5 22.1, 355613 6690202.7 22.1, 355614.1 6690201.8 22.1, 355614.9 6690202.9 22.1, 355618.2 6690203.1 22.1, 355619.1 6690203 22.1, 355619.6 6690202.9 22.1, 355620.1 6690202.6 22.1, 355620.5 6690202.1 22.1, 355620.7 6690201.5 22.1, 355620.8 6690197.4 22.1, 355620 6690196.6 22.1, 355620.9 6690196 22.1, 355620.9 6690194.1 22.1, 355620.8 6690193.9 22.1, 355620.6 6690193.4 22.1, 355620.2 6690193.3 22.1, 355620.2 6690191.3 22.1, 355621 6690191.3 22.1, 355621.1 6690189.2 22.1, 355621.2 6690187 22.1, 355621.2 6690184.9 22.1, 355621.1 6690182.7 22.1, 355621.1 6690180.5 22.1, 355620.2 6690180.5 22.1, 355620.1 6690177.6 22.1, 355620.9 6690177.6 22.1, 355620.7 6690174.9 22.1, 355609.4 6690174.5 22.1, 355607.5 6690177.1 22.1, 355600.3 6690186.8 22.1, 355602.9 6690189.9 22.1, 355602.4 6690190.4 22.1, 355607.4 6690196.2 22.1))
BATIMENT0000000302944717;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;8.0;16.2;17.5;8.3;Cadastre;;POLYGON Z ((355570.9 6690188.6 16.2, 355569.9 6690189.4 16.2, 355570.6 6690190.1 16.2, 355571.7 6690189 16.2, 355571.2 6690188.4 16.2, 355570.9 6690188.6 16.2))
BATIMENT0000000302944727;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;7.0;7.3;14.3;25.1;8.6;Cadastre;A 1.0;POLYGON Z ((355579.6 6690195.9 14.3, 355572.9 6690201.8 14.3, 355569.6 6690204.7 14.3, 355573.9 6690209.8 14.3, 355577.7 6690214.2 14.3, 355584 6690208.4 14.3, 355595.6 6690198.2 14.3, 355587.6 6690188.9 14.3, 355580.3 6690195.3 14.3, 355579.6 6690195.9 14.3), (355582.2 6690198.1 14.3, 355584.1 6690200.4 14.3, 355582.6 6690201.6 14.3, 355585.5 6690204.7 14.3, 355580.7 6690208.9 14.3, 355575.3 6690203 14.3, 355577.5 6690201.3 14.3, 355577.8 6690201.7 14.3, 355582.2 6690198.1 14.3))
BATIMENT0000000302944734;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;7.2;13.9;16.0;7.8;Cadastre;A 1.0;POLYGON Z ((355595.6 6690198.2 13.9, 355584 6690208.4 13.9, 355587 6690211.8 13.9, 355591.5 6690216.8 13.9, 355602.7 6690206.4 13.9, 355595.6 6690198.2 13.9))
BATIMENT0000000302944735;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1996-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;7.3;7.2;14.6;19.1;7.9;Cadastre;B 0.1;POLYGON Z ((355602.7 6690206.4 14.6, 355591.5 6690216.8 14.6, 355592.3 6690217.8 14.6, 355603.5 6690207.3 14.6, 355602.7 6690206.4 14.6))
BATIMENT0000000302944730;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;7.1;7.3;14.5;15.7;8.3;Cadastre;A 1.0;POLYGON Z ((355590 6690220 14.5, 355582.8 6690211.6 14.5, 355583.8 6690210.5 14.5, 355585.8 6690212.8 14.5, 355587 6690211.8 14.5, 355584 6690208.4 14.5, 355577.7 6690214.2 14.5, 355578.1 6690214.7 14.5, 355585.8 6690223.7 14.5, 355590 6690220 14.5))
BATIMENT0000000302944733;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;30;40;7.0;7.2;14.2;21.0;8.1;Cadastre;B 0.7;POLYGON Z ((355590 6690220 14.2, 355585.8 6690223.7 14.2, 355587.1 6690225.2 14.2, 355594 6690233.6 14.2, 355601.8 6690227.4 14.2, 355602.5 6690226.7 14.2, 355602.9 6690226.1 14.2, 355603 6690225 14.2, 355604.2 6690208.2 14.2, 355603.5 6690207.3 14.2, 355592.3 6690217.8 14.2, 355590 6690220 14.2), (355598.4 6690219.9 14.2, 355598.3 6690222.8 14.2, 355596.1 6690224.6 14.2, 355594.4 6690223.2 14.2, 355598.4 6690219.9 14.2))
BATIMENT0000000302944563;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;11.1;8.3;19.4;;;Cadastre;C 0.7;POLYGON Z ((355618.7 6690229.1 19.4, 355611 6690228.4 19.4, 355600.8 6690236.5 19.4, 355605.8 6690243.1 19.4, 355608.3 6690241.3 19.4, 355608.1 6690237.2 19.4, 355609.6 6690237.2 19.4, 355609.6 6690240.5 19.4, 355617.7 6690240.8 19.4, 355618.7 6690229.1 19.4))
BATIMENT0000000302944736;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;16.0;7.9;23.9;25.0;8.2;Cadastre;;POLYGON Z ((355570.6 6690237.7 23.9, 355570.8 6690237.9 23.9, 355573.1 6690236.2 23.9, 355572.1 6690235.1 23.9, 355570.1 6690236.8 23.9, 355569.9 6690237 23.9, 355570.6 6690237.7 23.9))
BATIMENT0000000302944731;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;10;20;14.1;7.6;21.7;25.7;8.7;Cadastre;C 0.6;POLYGON Z ((355572.4 6690250.6 21.7, 355594 6690233.6 21.7, 355587.1 6690225.2 21.7, 355573.1 6690236.2 21.7, 355570.8 6690237.9 21.7, 355570.6 6690237.7 21.7, 355565 6690242.7 21.7, 355572.4 6690250.6 21.7))
BATIMENT0000000302944561;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.6;7.3;20.0;20.4;7.5;Cadastre;;POLYGON Z ((355609.6 6690240.5 20, 355609.6 6690237.2 20, 355608.1 6690237.2 20, 355608.3 6690241.3 20, 355609.2 6690240.5 20, 355609.6 6690240.5 20))
BATIMENT0000000302944562;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;11.3;7.1;18.5;21.2;7.9;Cadastre;C 0.7;POLYGON Z ((355617.7 6690240.8 18.5, 355609.6 6690240.5 18.5, 355609.2 6690240.5 18.5, 355608.3 6690241.3 18.5, 355605.8 6690243.1 18.5, 355607.7 6690245.6 18.5, 355608.2 6690245.2 18.5, 355609 6690244.5 18.5, 355610.3 6690245.3 18.5, 355610 6690247.2 18.5, 355609.8 6690248.4 18.5, 355610.1 6690249 18.5, 355610.6 6690249.1 18.5, 355617 6690249.5 18.5, 355617.7 6690240.8 18.5))
BATIMENT0000000302944564;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.7;7.2;21.0;22.7;7.8;Cadastre;;POLYGON Z ((355602.8 6690255.3 21, 355604.7 6690253.8 21, 355610.6 6690249.1 21, 355610.1 6690249 21, 355609.8 6690248.4 21, 355610 6690247.2 21, 355608.2 6690245.2 21, 355607.7 6690245.6 21, 355605.8 6690243.1 21, 355600.8 6690236.5 21, 355593.2 6690242.5 21, 355602.8 6690255.3 21))
BATIMENT0000000302944566;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2001-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;00;00;13.1;7.4;20.5;22.8;8.3;Cadastre;C 0.5;POLYGON Z ((355577.4 6690255 20.5, 355588.5 6690266.7 20.5, 355600 6690257.6 20.5, 355602.8 6690255.3 20.5, 355593.2 6690242.5 20.5, 355577.4 6690255 20.5))
BATIMENT0000000302944567;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;7.1;19.2;21.6;7.4;Cadastre;;POLYGON Z ((355605.8 6690256.5 19.2, 355606.5 6690256.6 19.2, 355606.7 6690254.9 19.2, 355605.7 6690254.9 19.2, 355604.7 6690253.8 19.2, 355604.1 6690262.3 19.2, 355605.5 6690261.4 19.2, 355605.8 6690256.5 19.2))
BATIMENT0000000302944565;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;13.2;7.0;20.2;21.9;7.5;Cadastre;A 1.0;POLYGON Z ((355606.3 6690264.6 20.2, 355606.5 6690265 20.2, 355607 6690265.5 20.2, 355606.9 6690267.7 20.2, 355615.4 6690268.1 20.2, 355616 6690261.4 20.2, 355615.4 6690260.2 20.2, 355615.6 6690257 20.2, 355616.4 6690255.7 20.2, 355617 6690249.5 20.2, 355610.6 6690249.1 20.2, 355604.7 6690253.8 20.2, 355605.7 6690254.9 20.2, 355606.7 6690254.9 20.2, 355606.5 6690256.6 20.2, 355605.8 6690256.5 20.2, 355605.5 6690261.4 20.2, 355604.1 6690262.3 20.2, 355606.3 6690264.6 20.2))
BATIMENT0000000302944570;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.0;7.2;18.2;20.4;7.5;Cadastre;;POLYGON Z ((355603.9 6690262 18.2, 355603.8 6690261.8 18.2, 355603 6690262.5 18.2, 355603.9 6690263.4 18.2, 355603.6 6690263.8 18.2, 355605.3 6690266 18.2, 355606.5 6690265 18.2, 355606.3 6690264.6 18.2, 355604.1 6690262.3 18.2, 355603.9 6690262 18.2))
BATIMENT0000000302944569;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;12;20;12.2;7.3;19.5;22.3;7.8;Cadastre;A 1.0;POLYGON Z ((355596.3 6690275 19.5, 355604.5 6690267.6 19.5, 355605 6690267.1 19.5, 355604.6 6690266.8 19.5, 355600.5 6690262.6 19.5, 355602.9 6690260.7 19.5, 355600 6690257.6 19.5, 355588.5 6690266.7 19.5, 355596.3 6690275 19.5))
BATIMENT0000000304020637;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;8.6;6.6;15.2;17.7;7.1;Cadastre;C 0.4;POLYGON Z ((355702 6690259.7 15.2, 355699.5 6690265 15.2, 355708.2 6690269.5 15.2, 355711 6690264 15.2, 355711.7 6690262.5 15.2, 355716.2 6690253.3 15.2, 355707.1 6690249 15.2, 355702 6690259.7 15.2))
BATIMENT0000000304020634;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;00;00;13.8;5.0;18.8;23.2;7.2;Cadastre;C 0.6;POLYGON Z ((355695 6690274.5 18.8, 355693.7 6690290.5 18.8, 355710.5 6690293.9 18.8, 355711.3 6690279.9 18.8, 355712 6690278.7 18.8, 355710.9 6690278.1 18.8, 355713.7 6690272.2 18.8, 355708.2 6690269.5 18.8, 355699.5 6690265 18.8, 355695 6690274.5 18.8))
BATIMENT0000000304020632;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.4;6.6;10.1;11.9;7.3;Cadastre;;POLYGON Z ((355727.2 6690279.1 10.1, 355721.9 6690276.4 10.1, 355717.2 6690292.3 10.1, 355717.1 6690292.7 10.1, 355722.5 6690294.2 10.1, 355723.7 6690290.3 10.1, 355727.2 6690279.1 10.1))
BATIMENT0000000304020633;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.9;6.8;9.8;12.2;7.3;Cadastre;;POLYGON Z ((355714.4 6690294.4 9.8, 355716.5 6690295 9.8, 355717.1 6690292.7 9.8, 355717.2 6690292.3 9.8, 355711.8 6690290.4 9.8, 355711.4 6690294 9.8, 355711.5 6690294.1 9.8, 355714.4 6690294.4 9.8))
BATIMENT0000000304020635;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;5.0;00;00;13.6;5.6;19.2;23.1;7.5;Cadastre;C 0.7;POLYGON Z ((355693.7 6690290.5 19.2, 355693.4 6690294.6 19.2, 355692.6 6690303.5 19.2, 355702.6 6690305.4 19.2, 355707.6 6690306.3 19.2, 355709.6 6690306.7 19.2, 355710.5 6690293.9 19.2, 355693.7 6690290.5 19.2))
BATIMENT0000000304020641;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;6.6;13.7;16.6;7.0;Cadastre;;POLYGON Z ((355729.1 6690310.3 13.7, 355729.2 6690309.8 13.7, 355735.5 6690311.4 13.7, 355735.5 6690311.5 13.7, 355738.3 6690312.1 13.7, 355738.7 6690310.3 13.7, 355740.7 6690310.7 13.7, 355741.2 6690308.5 13.7, 355741.3 6690307.8 13.7, 355742.2 6690303.5 13.7, 355738.2 6690302.3 13.7, 355737.5 6690304.5 13.7, 355721.8 6690300.4 13.7, 355719.5 6690308.5 13.7, 355720.2 6690308.7 13.7, 355722 6690309 13.7, 355723 6690309.2 13.7, 355729.1 6690310.3 13.7))
BATIMENT0000000304020636;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;24.0;5.0;39;90;9.9;6.8;16.7;22.7;7.5;Cadastre;C 0.6;POLYGON Z ((355702.6 6690305.4 16.7, 355692.6 6690303.5 16.7, 355692.5 6690305.4 16.7, 355690.8 6690325.7 16.7, 355719.1 6690327.8 16.7, 355725.5 6690328.3 16.7, 355726.7 6690328.4 16.7, 355727.8 6690314.2 16.7, 355721.6 6690313.7 16.7, 355722 6690309 16.7, 355720.2 6690308.7 16.7, 355719.5 6690308.5 16.7, 355709.6 6690306.7 16.7, 355707.6 6690306.3 16.7, 355702.6 6690305.4 16.7))
BATIMENT0000000304020638;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;;;11.0;6.3;17.4;19.4;7.3;Cadastre;C 0.6;POLYGON Z ((355689.9 6690336.4 17.4, 355696.8 6690336.8 17.4, 355697.2 6690333.7 17.4, 355718.3 6690335 17.4, 355719.1 6690327.8 17.4, 355690.8 6690325.7 17.4, 355689.9 6690336.4 17.4))
BATIMENT0000000304020639;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;3.9;6.0;9.9;11.1;7.1;Cadastre;C 0.3;POLYGON Z ((355724.9 6690335.1 9.9, 355734.6 6690335.9 9.9, 355738.4 6690336.2 9.9, 355741.8 6690336.5 9.9, 355742.5 6690329.6 9.9, 355726.7 6690328.4 9.9, 355725.5 6690328.3 9.9, 355724.9 6690335.1 9.9))
BATIMENT0000000304020640;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;6.0;9.8;12.0;7.1;Cadastre;;POLYGON Z ((355733.2 6690350.9 9.8, 355736.5 6690351.2 9.8, 355737.1 6690344.4 9.8, 355737.6 6690344.5 9.8, 355738.4 6690336.2 9.8, 355734.6 6690335.9 9.8, 355733.2 6690350.9 9.8))
BATIMENT0000000303967636;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.4;21.0;31.4;33.7;21.2;Cadastre;;POLYGON Z ((356057.3 6690013.8 31.4, 356058.4 6690015.5 31.4, 356059.9 6690014.1 31.4, 356061 6690014.5 31.4, 356062.6 6690012.8 31.4, 356061.4 6690010.4 31.4, 356057.3 6690013.8 31.4))
BATIMENT0000000303967635;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;10;20;12.2;21.0;33.2;35.9;21.4;Cadastre;A 1.0;POLYGON Z ((356075 6690015.2 33.2, 356066.5 6690005.2 33.2, 356061.4 6690010.4 33.2, 356062.6 6690012.8 33.2, 356061 6690014.5 33.2, 356059.9 6690014.1 33.2, 356058.4 6690015.5 33.2, 356060 6690017.5 33.2, 356064.8 6690023.6 33.2, 356075 6690015.2 33.2))
BATIMENT0000000303963153;Eglise;Religieux;;Non;En service;2012-06-26 20:05:20;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.4;22.0;26.4;;;Cadastre;;POLYGON Z ((356078 6690034.7 26.4, 356081.1 6690038.9 26.4, 356098.6 6690024.5 26.4, 356095.6 6690020.7 26.4, 356094.8 6690015.5 26.4, 356099.3 6690012 26.4, 356103.7 6690013.2 26.4, 356107.2 6690017.3 26.4, 356112.5 6690013.1 26.4, 356118.3 6690012.3 26.4, 356121.2 6690016.7 26.4, 356119.7 6690021.4 26.4, 356114.3 6690025.7 26.4, 356117.1 6690029 26.4, 356118.3 6690035.4 26.4, 356118.7 6690035.5 26.4, 356118.8 6690034.8 26.4, 356118.5 6690034.6 26.4, 356118.9 6690034.1 26.4, 356119.2 6690034.4 26.4, 356119.5 6690034.1 26.4, 356119.8 6690034.5 26.4, 356120.8 6690033.7 26.4, 356120.4 6690033.3 26.4, 356120.8 6690033 26.4, 356120.4 6690032.5 26.4, 356124.7 6690029.1 26.4, 356125.1 6690029.4 26.4, 356125.5 6690029.1 26.4, 356125.8 6690029.5 26.4, 356126.5 6690028.9 26.4, 356127.2 6690029.7 26.4, 356138.8 6690020.4 26.4, 356134.2 6690014.8 26.4, 356134.4 6690014.6 26.4, 356133.8 6690013.9 26.4, 356133.6 6690014.1 26.4, 356131.4 6690011.4 26.4, 356131.8 6690010.7 26.4, 356130.9 6690010.7 26.4, 356131.2 6690010 26.4, 356130.3 6690010 26.4, 356128.2 6690007.4 26.4, 356128.4 6690006.8 26.4, 356127.7 6690006.8 26.4, 356127.9 6690006.1 26.4, 356127.3 6690006.3 26.4, 356122.7 6690000.6 26.4, 356123 6690000.4 26.4, 356122.4 6689999.7 26.4, 356122.1 6689999.9 26.4, 356118 6689994.8 26.4, 356117.5 6689995.2 26.4, 356117.3 6689994.9 26.4, 356116.6 6689995.4 26.4, 356116.9 6689995.7 26.4, 356112.3 6689999.5 26.4, 356112 6689999.2 26.4, 356110.7 6690000.4 26.4, 356110.9 6690000.6 26.4, 356106.2 6690004.5 26.4, 356106 6690004.2 26.4, 356105.4 6690004.8 26.4, 356105.6 6690005 26.4, 356100.2 6690009.5 26.4, 356100 6690009.2 26.4, 356099.3 6690009.8 26.4, 356099.5 6690010 26.4, 356093.9 6690014.6 26.4, 356093.7 6690014.4 26.4, 356092.9 6690015.1 26.4, 356093.1 6690015.3 26.4, 356087.3 6690020.1 26.4, 356087.1 6690019.9 26.4, 356086.4 6690020.5 26.4, 356086.6 6690020.7 26.4, 356081.3 6690025 26.4, 356081.2 6690024.8 26.4, 356080.4 6690025.5 26.4, 356080.5 6690025.7 26.4, 356074.9 6690030.3 26.4, 356074.7 6690030.2 26.4, 356074.2 6690030.6 26.4, 356074.3 6690030.8 26.4, 356076.5 6690033.3 26.4, 356075.5 6690034.1 26.4, 356075.7 6690034.3 26.4, 356070.2 6690039 26.4, 356071.2 6690040.6 26.4, 356078 6690034.7 26.4))
BATIMENT0000000303963074;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:05:20;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.9;20.7;32.6;35.9;22.0;Cadastre;;POLYGON Z ((356174.2 6689997.5 32.6, 356161.9 6690006 32.6, 356128.3 6690031.9 32.6, 356130.9 6690035.2 32.6, 356136.6 6690042.5 32.6, 356181.4 6690006.7 32.6, 356177.5 6690002 32.6, 356177.8 6690001.8 32.6, 356174.2 6689997.5 32.6))
BATIMENT0000000303967634;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;10;20;12.3;21.0;33.3;35.3;21.0;Cadastre;A 1.0;POLYGON Z ((356043 6690031 33.3, 356047.2 6690036.2 33.3, 356050.5 6690033.3 33.3, 356051.6 6690033.7 33.3, 356064.8 6690023.6 33.3, 356060 6690017.5 33.3, 356055.2 6690021.7 33.3, 356056.8 6690023.6 33.3, 356055.8 6690024.7 33.3, 356055.3 6690023.7 33.3, 356053.9 6690024.4 33.3, 356054.4 6690025.9 33.3, 356053.3 6690026.2 33.3, 356052.2 6690024 33.3, 356043.7 6690030.6 33.3, 356043 6690031 33.3))
BATIMENT0000000303969718;Eglise;Religieux;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;24.4;22.0;46.4;;;Cadastre;;POLYGON Z ((356069.8 6690041.5 46.4, 356070.9 6690042.7 46.4, 356069.7 6690043.8 46.4, 356070.6 6690044.9 46.4, 356071.4 6690044.2 46.4, 356074.2 6690047.7 46.4, 356073.4 6690048.3 46.4, 356074.5 6690049.6 46.4, 356075.3 6690049 46.4, 356079.7 6690054.5 46.4, 356079 6690055.1 46.4, 356080.1 6690056.4 46.4, 356080.9 6690055.8 46.4, 356083.5 6690059.1 46.4, 356082.9 6690059.8 46.4, 356083.8 6690060.8 46.4, 356084.9 6690059.9 46.4, 356086.4 6690061.7 46.4, 356086.8 6690061.4 46.4, 356087.5 6690062.2 46.4, 356088.6 6690061.4 46.4, 356088.4 6690061.2 46.4, 356094.2 6690056.5 46.4, 356094.4 6690056.7 46.4, 356095.9 6690055.5 46.4, 356095.2 6690054.8 46.4, 356095.6 6690054.5 46.4, 356095.3 6690054.1 46.4, 356095.6 6690053.9 46.4, 356095.3 6690053.4 46.4, 356099.8 6690049.7 46.4, 356100.1 6690050.1 46.4, 356100.5 6690049.8 46.4, 356100.8 6690050.2 46.4, 356101.6 6690049.5 46.4, 356101.3 6690049.2 46.4, 356101.6 6690048.8 46.4, 356101.3 6690048.4 46.4, 356105.7 6690044.8 46.4, 356106 6690045.2 46.4, 356106.4 6690044.9 46.4, 356106.7 6690045.3 46.4, 356107.6 6690044.6 46.4, 356107.2 6690044.1 46.4, 356107.6 6690043.9 46.4, 356107.3 6690043.5 46.4, 356111.7 6690039.8 46.4, 356112 6690040.3 46.4, 356112.4 6690040 46.4, 356112.7 6690040.4 46.4, 356113.4 6690039.9 46.4, 356113.2 6690039.5 46.4, 356113.4 6690039.3 46.4, 356113.2 6690038.9 46.4, 356113.8 6690038.6 46.4, 356113.9 6690039.2 46.4, 356114.3 6690039.2 46.4, 356114.4 6690039.7 46.4, 356115.3 6690039.7 46.4, 356115.3 6690039.2 46.4, 356116.2 6690039.2 46.4, 356116.2 6690038.5 46.4, 356117.9 6690037.1 46.4, 356118.5 6690037.1 46.4, 356118.6 6690036.6 46.4, 356119.1 6690036.6 46.4, 356119.3 6690035.6 46.4, 356118.7 6690035.5 46.4, 356118.3 6690035.4 46.4, 356117.1 6690029 46.4, 356114.3 6690025.7 46.4, 356119.7 6690021.4 46.4, 356121.2 6690016.7 46.4, 356118.3 6690012.3 46.4, 356112.5 6690013.1 46.4, 356107.2 6690017.3 46.4, 356103.7 6690013.2 46.4, 356099.3 6690012 46.4, 356094.8 6690015.5 46.4, 356095.6 6690020.7 46.4, 356098.6 6690024.5 46.4, 356081.1 6690038.9 46.4, 356078 6690034.7 46.4, 356071.2 6690040.6 46.4, 356070.2 6690039 46.4, 356070 6690038.7 46.4, 356068.9 6690039.5 46.4, 356069.7 6690040.5 46.4, 356069.8 6690041.5 46.4))
BATIMENT0000000303967684;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;15.2;20.4;35.7;40.6;21.4;Cadastre;A 0.9;POLYGON Z ((356036.8 6690074.2 35.7, 356039.9 6690078 35.7, 356043.4 6690074.6 35.7, 356042.7 6690073.8 35.7, 356043.5 6690072.9 35.7, 356042.9 6690072.1 35.7, 356045.9 6690069.7 35.7, 356051.2 6690075.8 35.7, 356047.8 6690079 35.7, 356046.2 6690077.5 35.7, 356042.6 6690080.7 35.7, 356045.7 6690083.9 35.7, 356049.1 6690080.7 35.7, 356053.1 6690077 35.7, 356054.6 6690075.7 35.7, 356056.7 6690073.9 35.7, 356059.3 6690076.5 35.7, 356064.8 6690071.7 35.7, 356053.9 6690058.6 35.7, 356036.8 6690074.2 35.7))
BATIMENT0000000303969106;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;16.6;22.2;38.8;41.9;22.4;Cadastre;;POLYGON Z ((356142.4 6690077.5 38.8, 356143.5 6690076.4 38.8, 356135.3 6690067 38.8, 356134.2 6690067.8 38.8, 356123.4 6690055.6 38.8, 356118.7 6690050 38.8, 356116.1 6690047 38.8, 356113.5 6690044 38.8, 356103.1 6690053.1 38.8, 356123.6 6690076.5 38.8, 356120.6 6690079 38.8, 356120.8 6690079.4 38.8, 356120.5 6690079.6 38.8, 356129.3 6690089.6 38.8, 356129.4 6690089.4 38.8, 356129.8 6690089.7 38.8, 356132.7 6690087.2 38.8, 356154.1 6690111.9 38.8, 356164.4 6690102.8 38.8, 356142.4 6690077.5 38.8))
BATIMENT0000000303967689;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;20;20;12.2;20.8;33.1;39.0;21.7;Cadastre;A 1.0;POLYGON Z ((356049.1 6690080.7 33.1, 356054.8 6690086 33.1, 356063.1 6690078.3 33.1, 356066.2 6690081.6 33.1, 356069.1 6690079.2 33.1, 356070.4 6690078.1 33.1, 356064.8 6690071.7 33.1, 356059.3 6690076.5 33.1, 356056.7 6690073.9 33.1, 356054.6 6690075.7 33.1, 356058 6690079.3 33.1, 356056.7 6690080.5 33.1, 356053.1 6690077 33.1, 356049.1 6690080.7 33.1))
BATIMENT0000000303967690;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;5.0;12;20;13.7;20.7;34.5;39.5;21.5;Cadastre;A 1.0;POLYGON Z ((356056.2 6690087.6 34.5, 356059.1 6690084.4 34.5, 356063.2 6690089.2 34.5, 356060.1 6690091.8 34.5, 356062.3 6690094.6 34.5, 356058.9 6690097.6 34.5, 356060.6 6690099.6 34.5, 356065.6 6690094.8 34.5, 356067.8 6690097.3 34.5, 356077.6 6690088.6 34.5, 356077.5 6690088.5 34.5, 356069.1 6690079.2 34.5, 356066.2 6690081.6 34.5, 356063.1 6690078.3 34.5, 356054.8 6690086 34.5, 356049.1 6690080.7 34.5, 356045.7 6690083.9 34.5, 356045 6690084.7 34.5, 356051.9 6690091.5 34.5, 356056.2 6690087.6 34.5))
BATIMENT0000000303969072;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;18.7;23.2;24.5;21.3;Cadastre;;POLYGON Z ((356203.8 6690064.2 23.2, 356197 6690055.8 23.2, 356193.1 6690059 23.2, 356199.9 6690067.3 23.2, 356203.8 6690064.2 23.2))
BATIMENT0000000291511145;Indifférenciée;Commercial et services;;Non;En service;2011-11-16 12:28:21;2019-07-01 11:22:50;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;6.2;19.3;;;;Imagerie aérienne;;POLYGON Z ((356178.6 6690060.2 25.5, 356182.1 6690064.9 25.5, 356184.5 6690068.1 25.5, 356189.6 6690064.8 25.5, 356186.5 6690061.4 25.5, 356182.7 6690057.1 25.5, 356178.6 6690060.2 25.5))
BATIMENT0000000303969740;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;20.2;25.2;36.4;20.7;Cadastre;;POLYGON Z ((356268.4 6690070.6 25.2, 356270.7 6690073.8 25.2, 356274.9 6690071.3 25.2, 356270.3 6690059.1 25.2, 356263.4 6690063.9 25.2, 356268.4 6690070.6 25.2))
BATIMENT0000000303969741;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;05;20;16.6;19.3;36.0;38.7;20.7;Cadastre;C 0.6;POLYGON Z ((356279.3 6690078.5 36, 356288.1 6690072.5 36, 356277 6690054.4 36, 356270.3 6690059.1 36, 356274.9 6690071.3 36, 356279.3 6690078.5 36))
BATIMENT0000000303969068;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;20.9;23.2;31.1;21.3;Cadastre;;POLYGON Z ((356208 6690065.7 23.2, 356206.3 6690067 23.2, 356208.1 6690069.3 23.2, 356209.8 6690067.9 23.2, 356208 6690065.7 23.2))
BATIMENT0000000303969325;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;3.1;18.5;21.6;22.2;21.5;Cadastre;C 0.2;POLYGON Z ((356177.2 6690076.7 21.6, 356188.8 6690067.2 21.6, 356188.9 6690067.2 21.6, 356189 6690067 21.6, 356189.1 6690067 21.6, 356189.2 6690066.9 21.6, 356189.2 6690066.8 21.6, 356189.3 6690066.7 21.6, 356189.4 6690066.6 21.6, 356189.5 6690066.5 21.6, 356189.7 6690066.2 21.6, 356189.8 6690065.9 21.6, 356190 6690065.5 21.6, 356190.2 6690065 21.6, 356190.2 6690064.9 21.6, 356190.2 6690064.7 21.6, 356190.3 6690064.2 21.6, 356190.3 6690064 21.6, 356190.2 6690063.8 21.6, 356190.2 6690063.7 21.6, 356190.2 6690063.6 21.6, 356190.2 6690063.5 21.6, 356190.2 6690063.4 21.6, 356190.2 6690063.2 21.6, 356190.1 6690063.1 21.6, 356190.1 6690063 21.6, 356190.1 6690062.9 21.6, 356190 6690062.7 21.6, 356189.9 6690062.5 21.6, 356189.8 6690062.3 21.6, 356189.7 6690062.1 21.6, 356189.6 6690062 21.6, 356189.4 6690061.7 21.6, 356189.4 6690061.6 21.6, 356188.1 6690060.1 21.6, 356186.5 6690061.4 21.6, 356189.6 6690064.8 21.6, 356184.5 6690068.1 21.6, 356182.1 6690064.9 21.6, 356173.4 6690072 21.6, 356174.5 6690073.4 21.6, 356177.2 6690076.7 21.6))
BATIMENT0000000303969069;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;20.7;30.5;33.4;21.3;Cadastre;A 1.0;POLYGON Z ((356219.4 6690071.4 30.5, 356219.6 6690071.7 30.5, 356220 6690071.3 30.5, 356214.5 6690064.3 30.5, 356209.8 6690067.9 30.5, 356208.1 6690069.3 30.5, 356213.5 6690075.8 30.5, 356216 6690073.8 30.5, 356219.4 6690071.4 30.5))
BATIMENT0000000303969070;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.8;20.2;28.0;31.2;21.4;Cadastre;;POLYGON Z ((356208.6 6690091.1 28, 356214.2 6690086.8 28, 356209.1 6690080.1 28, 356213.2 6690076.9 28, 356213.9 6690076.3 28, 356213.5 6690075.8 28, 356208.1 6690069.3 28, 356206.3 6690067 28, 356204 6690064.1 28, 356203.8 6690064.2 28, 356199.9 6690067.3 28, 356193.9 6690071.9 28, 356208.6 6690091.1 28))
BATIMENT0000000303969079;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1950-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;6.0;15;10;16.6;19.3;36.0;38.2;20.8;Cadastre;A 1.0;POLYGON Z ((356278 6690079.5 36, 356282.4 6690084.8 36, 356283.4 6690084.1 36, 356285 6690086.2 36, 356291.6 6690081.5 36, 356288.1 6690072.5 36, 356279.3 6690078.5 36, 356278 6690079.5 36))
BATIMENT0000000303969739;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.2;21.2;27.4;30.7;21.6;Cadastre;;POLYGON Z ((356230.9 6690086.9 27.4, 356238.2 6690081.7 27.4, 356239.9 6690084.1 27.4, 356242.7 6690082.2 27.4, 356245.6 6690086.2 27.4, 356242.9 6690088.2 27.4, 356251 6690099.6 27.4, 356244.5 6690089.6 27.4, 356268 6690070.9 27.4, 356268.4 6690070.6 27.4, 356263.4 6690063.9 27.4, 356261.2 6690065.5 27.4, 356258.7 6690067.2 27.4, 356248.8 6690074.1 27.4, 356241.4 6690064.9 27.4, 356237.5 6690060 27.4, 356227.2 6690067.9 27.4, 356227.5 6690068.3 27.4, 356220.3 6690074.1 27.4, 356225.9 6690080.9 27.4, 356230.9 6690086.9 27.4))
BATIMENT0000000303969335;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;3.0;20.3;23.4;24.7;21.4;Cadastre;A 1.0;POLYGON Z ((356213.6 6690078.5 23.4, 356211.3 6690080.3 23.4, 356214.2 6690084.2 23.4, 356218.5 6690081 23.4, 356215.5 6690077 23.4, 356213.6 6690078.5 23.4))
BATIMENT0000000303969212;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;20.4;25.4;26.5;21.6;Cadastre;;POLYGON Z ((356187.6 6690084.2 25.4, 356186 6690082.2 25.4, 356190.6 6690078.6 25.4, 356190.8 6690076.7 25.4, 356189.1 6690074.8 25.4, 356181.6 6690080.6 25.4, 356183.9 6690085.8 25.4, 356184.6 6690086.7 25.4, 356187.6 6690084.2 25.4))
BATIMENT0000000303969213;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;21.1;24.5;25.0;21.5;Cadastre;;POLYGON Z ((356191.4 6690081.2 24.5, 356191.4 6690081 24.5, 356191.3 6690080.4 24.5, 356191.3 6690080.1 24.5, 356191.2 6690079.8 24.5, 356191.1 6690079.5 24.5, 356190.9 6690079.2 24.5, 356190.8 6690079 24.5, 356190.6 6690078.6 24.5, 356186 6690082.2 24.5, 356187.6 6690084.2 24.5, 356191.4 6690081.2 24.5))
BATIMENT0000000303969076;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.1;20.7;27.8;33.1;21.6;Cadastre;;POLYGON Z ((356255.1 6690096.5 27.8, 356275.8 6690081 27.8, 356273.1 6690077.1 27.8, 356273 6690077.1 27.8, 356269.9 6690079.4 27.8, 356267.4 6690076 27.8, 356270.7 6690073.8 27.8, 356268.4 6690070.6 27.8, 356268 6690070.9 27.8, 356244.5 6690089.6 27.8, 356251 6690099.6 27.8, 356255.1 6690096.5 27.8), (356264.1 6690083.8 27.8, 356258.3 6690088.1 27.8, 356255.8 6690084.7 27.8, 356261.5 6690080.4 27.8, 356264.1 6690083.8 27.8), (356252.2 6690092.7 27.8, 356250.2 6690094.2 27.8, 356247.6 6690090.9 27.8, 356249.7 6690089.3 27.8, 356252.2 6690092.7 27.8))
BATIMENT0000000303969214;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;20.4;25.4;25.7;21.7;Cadastre;;POLYGON Z ((356186.3 6690088.6 25.4, 356184.6 6690086.7 25.4, 356183.9 6690085.8 25.4, 356181.4 6690088 25.4, 356183.8 6690090.7 25.4, 356186.3 6690088.6 25.4))
BATIMENT0000000303969094;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;20.3;22.7;23.7;21.4;Cadastre;;POLYGON Z ((356216.5 6690089.9 22.7, 356215.6 6690088.6 22.7, 356213.6 6690090.1 22.7, 356214.6 6690091.4 22.7, 356216.5 6690089.9 22.7))
BATIMENT0000000303969080;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;5.7;19.5;25.2;29.5;20.7;Cadastre;A 1.0;POLYGON Z ((356282.9 6690087.8 25.2, 356281.9 6690088.1 25.2, 356281.3 6690088.3 25.2, 356280.3 6690087.6 25.2, 356275.1 6690091.5 25.2, 356277.7 6690095 25.2, 356284.4 6690090 25.2, 356291.1 6690099.7 25.2, 356296.8 6690095.7 25.2, 356298.3 6690094.6 25.2, 356297.2 6690092 25.2, 356295.1 6690094.2 25.2, 356290 6690086.9 25.2, 356294.1 6690084.3 25.2, 356292.6 6690080.7 25.2, 356291.6 6690081.5 25.2, 356285 6690086.2 25.2, 356282.9 6690087.8 25.2))
BATIMENT0000000303969215;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;21.5;24.2;25.5;21.9;Cadastre;;POLYGON Z ((356175.6 6690093 24.2, 356173.3 6690095 24.2, 356175.1 6690097.2 24.2, 356178.2 6690094.7 24.2, 356178.6 6690095.1 24.2, 356183.8 6690090.7 24.2, 356181.4 6690088 24.2, 356175.6 6690093 24.2))
BATIMENT0000000303969095;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;20.4;23.8;25.7;21.4;Cadastre;;POLYGON Z ((356208.5 6690096.3 23.8, 356214.6 6690091.4 23.8, 356213.6 6690090.1 23.8, 356207.4 6690094.8 23.8, 356208.5 6690096.3 23.8))
BATIMENT0000000303969075;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;3.0;10;20;11.6;20.4;32.0;33.8;21.6;Cadastre;A 1.0;POLYGON Z ((356243.7 6690105 32, 356247.8 6690102 32, 356251 6690099.6 32, 356242.9 6690088.2 32, 356239.9 6690084.1 32, 356238.2 6690081.7 32, 356230.9 6690086.9 32, 356243.7 6690105 32))
BATIMENT0000000303969168;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;18.5;21.7;28.2;19.4;Cadastre;;POLYGON Z ((356324.3 6690047.5 21.7, 356321.4 6690050.5 21.7, 356323.1 6690052.2 21.7, 356326 6690049.2 21.7, 356324.3 6690047.5 21.7))
BATIMENT0000000303969169;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;29.0;5.0;00;00;6.0;18.5;24.6;32.9;19.9;Cadastre;C 0.5;POLYGON Z ((356309.1 6690044.7 24.6, 356303.4 6690050.3 24.6, 356298 6690055.7 24.6, 356300 6690057.7 24.6, 356297.4 6690060.5 24.6, 356299.5 6690062.6 24.6, 356300.3 6690062.5 24.6, 356300.2 6690062.7 24.6, 356304.4 6690067 24.6, 356301.8 6690069.5 24.6, 356304.4 6690072.1 24.6, 356309.5 6690067.3 24.6, 356310.1 6690068 24.6, 356305 6690072.8 24.6, 356309.7 6690077.4 24.6, 356311.3 6690075.7 24.6, 356311.6 6690076.1 24.6, 356329.5 6690058.1 24.6, 356328.7 6690057.4 24.6, 356331.5 6690054.7 24.6, 356333.8 6690053.8 24.6, 356352.7 6690034.9 24.6, 356348.9 6690031.2 24.6, 356346.3 6690033.9 24.6, 356345.1 6690032.7 24.6, 356345.5 6690032.4 24.6, 356344.2 6690031.1 24.6, 356335.6 6690039.7 24.6, 356331.1 6690035.3 24.6, 356321.6 6690044.9 24.6, 356324.3 6690047.5 24.6, 356326 6690049.2 24.6, 356323.1 6690052.2 24.6, 356317.2 6690058 24.6, 356318.5 6690059.3 24.6, 356315.3 6690062.5 24.6, 356305.4 6690052.3 24.6, 356310.9 6690046.5 24.6, 356309.1 6690044.7 24.6))
BATIMENT0000000303969160;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;39.0;7.0;00;00;16.1;15.6;31.7;37.2;18.8;Cadastre;C 0.4;POLYGON Z ((356395.3 6690041.7 31.7, 356396 6690040.3 31.7, 356389.9 6690037 31.7, 356387 6690042.3 31.7, 356379.8 6690038.4 31.7, 356376.8 6690043.9 31.7, 356376.2 6690043.6 31.7, 356375.1 6690045.5 31.7, 356380 6690048.2 31.7, 356377.6 6690050.7 31.7, 356365 6690063.3 31.7, 356375.2 6690073.5 31.7, 356378.8 6690069.8 31.7, 356377.8 6690068.8 31.7, 356386.7 6690059.8 31.7, 356383 6690056.1 31.7, 356386.3 6690052.8 31.7, 356391.9 6690055.9 31.7, 356391.3 6690056.9 31.7, 356408.1 6690066.1 31.7, 356408.8 6690064.8 31.7, 356409.9 6690062.8 31.7, 356411.3 6690063.5 31.7, 356416.8 6690066.6 31.7, 356417.2 6690065.7 31.7, 356418 6690064.2 31.7, 356419.2 6690063 31.7, 356423.4 6690055.4 31.7, 356423 6690055.1 31.7, 356422.2 6690056.4 31.7, 356395.3 6690041.7 31.7))
BATIMENT0000000303969159;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;18.0;23.0;24.2;19.2;Cadastre;;POLYGON Z ((356376.4 6690049.7 23, 356363.9 6690062.2 23, 356365 6690063.3 23, 356377.6 6690050.7 23, 356376.4 6690049.7 23))
BATIMENT0000000303969164;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;20.4;15.5;35.9;36.3;15.9;Cadastre;;POLYGON Z ((356409.9 6690062.8 35.9, 356408.8 6690064.8 35.9, 356410.2 6690065.5 35.9, 356411.3 6690063.5 35.9, 356409.9 6690062.8 35.9))
BATIMENT0000000303969163;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;22.0;6.0;00;00;15.0;15.5;30.5;35.6;17.4;Cadastre;A 0.5;POLYGON Z ((356445.2 6690067.4 30.5, 356423.4 6690055.4 30.5, 356419.2 6690063 30.5, 356418.4 6690063.6 30.5, 356418 6690064.2 30.5, 356417.2 6690065.7 30.5, 356437.5 6690076.7 30.5, 356438.6 6690074.8 30.5, 356440.6 6690075.9 30.5, 356445.2 6690067.4 30.5))
BATIMENT0000000303969167;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;13.1;14.3;27.5;30.0;17.4;Cadastre;A 0.1;POLYGON Z ((356437.5 6690076.7 27.5, 356439.5 6690077.8 27.5, 356440.6 6690075.9 27.5, 356438.6 6690074.8 27.5, 356437.5 6690076.7 27.5))
BATIMENT0000000303969162;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.6;16.4;20.0;23.9;19.3;Cadastre;C 0.1;POLYGON Z ((356368.6 6690105.9 20, 356372.1 6690109.4 20, 356388.5 6690093 20, 356384.9 6690089.5 20, 356368.6 6690105.9 20))
BATIMENT0000000303969158;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2004-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.1;17.2;24.3;32.1;20.7;Cadastre;C 0.4;POLYGON Z ((356351.2 6690075 24.3, 356366.7 6690090.4 24.3, 356344.8 6690112.4 24.3, 356342.9 6690110.5 24.3, 356344 6690109.3 24.3, 356344 6690109.4 24.3, 356345.3 6690107.9 24.3, 356346 6690106.6 24.3, 356346.8 6690104.1 24.3, 356346.9 6690101.6 24.3, 356346.3 6690099.2 24.3, 356344.3 6690095.7 24.3, 356343 6690092.4 24.3, 356342.2 6690088.6 24.3, 356342.1 6690085.9 24.3, 356342.3 6690083.6 24.3, 356342.1 6690081.6 24.3, 356341.7 6690080 24.3, 356340.9 6690078.4 24.3, 356339.7 6690076.8 24.3, 356338.1 6690075.5 24.3, 356336.4 6690074.7 24.3, 356333.8 6690074.2 24.3, 356331.1 6690074.5 24.3, 356328.8 6690075.4 24.3, 356329.6 6690076.2 24.3, 356328.6 6690077.4 24.3, 356327.4 6690076.3 24.3, 356320.1 6690083.1 24.3, 356334.1 6690097.7 24.3, 356332.9 6690099 24.3, 356317.9 6690085.1 24.3, 356310.9 6690091.6 24.3, 356330.3 6690109.2 24.3, 356329.2 6690110.3 24.3, 356328.9 6690110 24.3, 356327.7 6690109.5 24.3, 356326.6 6690109.5 24.3, 356323.3 6690111.2 24.3, 356322.7 6690111.4 24.3, 356321.6 6690111.4 24.3, 356320.4 6690111 24.3, 356319.7 6690110 24.3, 356318.6 6690108.9 24.3, 356317.4 6690108.4 24.3, 356315.8 6690108.3 24.3, 356314.6 6690108.6 24.3, 356313.6 6690109.3 24.3, 356312.7 6690110.4 24.3, 356312.3 6690111.3 24.3, 356312.2 6690113.2 24.3, 356312.6 6690114.2 24.3, 356313.2 6690115.2 24.3, 356312.4 6690115.5 24.3, 356327 6690157.3 24.3, 356334.7 6690152.1 24.3, 356337 6690149.7 24.3, 356333.9 6690140.6 24.3, 356368.6 6690105.9 24.3, 356384.9 6690089.5 24.3, 356388.1 6690086.3 24.3, 356375.2 6690073.5 24.3, 356365 6690063.3 24.3, 356363.9 6690062.2 24.3, 356351.2 6690075 24.3))
BATIMENT0000000327813127;Indifférenciée;Indifférencié;;Non;En service;2013-09-26 18:18:05;2018-09-18 13:52:34;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;15.3;15.1;;31.3;17.2;Imagerie aérienne;;POLYGON Z ((356494.1 6690094.5 30.4, 356484.7 6690111 30.4, 356506.81139568595 6690123.275365576 30.4, 356506.81139568595 6690101.38533933 30.4, 356494.1 6690094.5 30.4))
BATIMENT0000000303969096;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.9;22.1;26.0;;;Cadastre;;POLYGON Z ((356205.7 6690092.5 26, 356199.6 6690097.2 26, 356198.9 6690097.9 26, 356198.6 6690098.2 26, 356198.4 6690098.5 26, 356198.2 6690098.9 26, 356198 6690099.2 26, 356197.8 6690099.6 26, 356197.7 6690100 26, 356197.6 6690100.3 26, 356197.5 6690100.7 26, 356197.5 6690101.1 26, 356197.5 6690101.5 26, 356197.7 6690102.3 26, 356197.8 6690103.1 26, 356197.9 6690103.8 26, 356198.2 6690104.5 26, 356198.4 6690105.2 26, 356198.8 6690105.9 26, 356199.2 6690106.6 26, 356199.6 6690107.2 26, 356200.1 6690107.9 26, 356204.3 6690105.1 26, 356204 6690104.6 26, 356202.8 6690102.9 26, 356203.1 6690101.8 26, 356206.6 6690097.8 26, 356208.5 6690096.3 26, 356207.4 6690094.8 26, 356205.7 6690092.5 26))
BATIMENT0000000303969126;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;20.8;;;;Cadastre;;POLYGON Z ((356179 6690097.4 -1000, 356177.3 6690098.7 -1000, 356181 6690103.1 -1000, 356182.5 6690101.7 -1000, 356179 6690097.4 -1000))
BATIMENT0000000303969097;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;6.0;10;20;21.2;20.4;41.7;43.8;22.1;Cadastre;A 1.0;POLYGON Z ((356232.3 6690097.2 41.7, 356226.8 6690089 41.7, 356204 6690104.6 41.7, 356204.3 6690105.1 41.7, 356209.5 6690112.6 41.7, 356232.3 6690097.2 41.7))
BATIMENT0000000303969144;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.3;19.8;30.2;32.9;21.1;Cadastre;A 1.0;POLYGON Z ((356300.3 6690109.1 30.2, 356300.3 6690108.9 30.2, 356296.8 6690103.8 30.2, 356297.7 6690103.2 30.2, 356294.7 6690099.2 30.2, 356285.4 6690105.6 30.2, 356291.9 6690114.8 30.2, 356292.3 6690114.6 30.2, 356293.2 6690115.9 30.2, 356294.1 6690115.2 30.2, 356293.3 6690113.9 30.2, 356294.2 6690113.1 30.2, 356296.4 6690116.2 30.2, 356302.1 6690112.1 30.2, 356300.3 6690109.1 30.2))
BATIMENT0000000303969081;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1949-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;50;10;7.6;21.0;28.6;30.7;21.6;Cadastre;A 1.0;POLYGON Z ((356250.9 6690115.1 28.6, 356258.5 6690109.7 28.6, 356254.3 6690103.9 28.6, 356251 6690106.3 28.6, 356247.8 6690102 28.6, 356243.7 6690105 28.6, 356250.9 6690115.1 28.6))
BATIMENT0000000303969119;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;6.6;20.4;27.0;29.0;22.0;Cadastre;C 0.1;POLYGON Z ((356181.5 6690103.7 27, 356178.1 6690106.5 27, 356186.3 6690115.8 27, 356182.2 6690118.7 27, 356178.7 6690121.2 27, 356174.3 6690124.4 27, 356175.8 6690126 27, 356178.3 6690128.8 27, 356194.4 6690117 27, 356194.7 6690115.8 27, 356182.8 6690101.4 27, 356182.5 6690101.7 27, 356181 6690103.1 27, 356181.5 6690103.7 27))
BATIMENT0000000303969120;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.4;21.5;25.0;27.6;22.0;Cadastre;C 0.4;POLYGON Z ((356178.7 6690121.2 25, 356182.2 6690118.7 25, 356186.3 6690115.8 25, 356178.1 6690106.5 25, 356172.7 6690110.9 25, 356176.5 6690115.5 25, 356176.4 6690115.6 25, 356176.6 6690115.7 25, 356174.7 6690117.4 25, 356175.4 6690118.1 25, 356171.8 6690121.7 25, 356174.3 6690124.4 25, 356178.7 6690121.2 25))
BATIMENT0000000303969145;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1836-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;09;02;5.0;19.7;24.8;28.5;21.0;Cadastre;C 0.4;POLYGON Z ((356295.2 6690117 24.8, 356297.4 6690120 24.8, 356303.4 6690115.7 24.8, 356302.1 6690112.1 24.8, 356296.4 6690116.2 24.8, 356295.2 6690117 24.8))
BATIMENT0000000303969336;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;00;00;5.8;21.2;27.0;34.5;22.1;Cadastre;A 1.0;POLYGON Z ((356235.1 6690114 27, 356236.8 6690116.7 27, 356234.3 6690118.5 27, 356238.1 6690123.6 27, 356246 6690118.1 27, 356240.6 6690110.3 27, 356235.1 6690114 27))
BATIMENT0000000303969098;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.5;22.0;26.5;31.7;22.2;Cadastre;;POLYGON Z ((356198.4 6690109.1 26.5, 356212.9 6690130.3 26.5, 356213.2 6690130 26.5, 356216.4 6690134.4 26.5, 356218.6 6690137.5 26.5, 356224.2 6690133.6 26.5, 356218.8 6690126 26.5, 356209.5 6690112.6 26.5, 356204.3 6690105.1 26.5, 356200.1 6690107.9 26.5, 356198.4 6690109.1 26.5))
BATIMENT0000000303967691;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;20;20;14.8;20.6;35.5;37.0;21.3;Cadastre;A 1.0;POLYGON Z ((356061 6690100.1 35.5, 356060.6 6690099.6 35.5, 356058.9 6690097.6 35.5, 356062.3 6690094.6 35.5, 356060.1 6690091.8 35.5, 356056.2 6690087.6 35.5, 356051.9 6690091.5 35.5, 356053 6690092.7 35.5, 356048.8 6690096.7 35.5, 356055.7 6690104.8 35.5, 356061 6690100.1 35.5))
BATIMENT0000000303967692;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1879-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;15.8;20.6;36.5;40.5;21.7;Cadastre;C 0.7;POLYGON Z ((356088.8 6690100 36.5, 356078 6690088.5 36.5, 356077.6 6690088.6 36.5, 356067.8 6690097.3 36.5, 356062.6 6690101.9 36.5, 356057.3 6690106.6 36.5, 356052.2 6690111.2 36.5, 356055.4 6690114.7 36.5, 356060.1 6690110.5 36.5, 356059.4 6690109.6 36.5, 356061.7 6690107.7 36.5, 356062.5 6690108.5 36.5, 356069.6 6690102.4 36.5, 356069.3 6690101.9 36.5, 356071 6690100.5 36.5, 356073 6690100.7 36.5, 356075.5 6690103 36.5, 356075.5 6690105.1 36.5, 356073.8 6690106.5 36.5, 356073.3 6690106 36.5, 356066.3 6690112.1 36.5, 356069.7 6690115.9 36.5, 356088.8 6690100 36.5))
BATIMENT0000000303969107;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.8;21.6;28.4;33.7;22.3;Cadastre;;POLYGON Z ((356160.6 6690119.3 28.4, 356171.2 6690110.4 28.4, 356164.4 6690102.8 28.4, 356154.1 6690111.9 28.4, 356160.6 6690119.3 28.4))
BATIMENT0000000303967693;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;10;20;14.2;20.7;35.0;39.6;21.9;Cadastre;A 0.9;POLYGON Z ((356069.7 6690115.9 35, 356067.9 6690117.3 35, 356062.5 6690122 35, 356066.6 6690126.6 35, 356068.9 6690124.4 35, 356077.6 6690116.2 35, 356082 6690111.3 35, 356083.9 6690113.1 35, 356093.8 6690104.4 35, 356088.8 6690100 35, 356069.7 6690115.9 35))
BATIMENT0000000303967702;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;10;20;13.2;21.2;34.4;39.4;21.9;Cadastre;C 0.7;POLYGON Z ((356083.9 6690113.1 34.4, 356084.3 6690113.4 34.4, 356085.8 6690112 34.4, 356089.1 6690115.3 34.4, 356088.9 6690116.9 34.4, 356087.9 6690116.8 34.4, 356085.6 6690119.2 34.4, 356085.1 6690118.7 34.4, 356083.5 6690119.1 34.4, 356077 6690125.3 34.4, 356077.1 6690126.8 34.4, 356074.2 6690129.7 34.4, 356077.4 6690132.9 34.4, 356100.6 6690110.5 34.4, 356093.8 6690104.4 34.4, 356083.9 6690113.1 34.4))
BATIMENT0000000303967701;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.8;20.9;30.7;33.2;21.1;Cadastre;;POLYGON Z ((356069.6 6690125.2 30.7, 356070.9 6690126.5 30.7, 356072.6 6690124.8 30.7, 356071.3 6690123.7 30.7, 356069.6 6690125.2 30.7))
BATIMENT0000000303967703;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;6.0;10;20;7.5;21.4;29.0;42.1;22.1;Cadastre;C 0.6;POLYGON Z ((356072.7 6690132.5 29, 356073.3 6690132.1 29, 356075.8 6690134.4 29, 356075.6 6690134.8 29, 356079.7 6690139.1 29, 356091.9 6690127.8 29, 356089 6690124.9 29, 356093.8 6690120.5 29, 356097.3 6690124.2 29, 356096.4 6690124.8 29, 356097.7 6690126 29, 356097.1 6690126.6 29, 356084.7 6690138.8 29, 356087 6690141.2 29, 356100 6690129.3 29, 356101.2 6690127.8 29, 356110.7 6690119.2 29, 356100.6 6690110.5 29, 356077.4 6690132.9 29, 356074.2 6690129.7 29, 356073.6 6690129.2 29, 356071.6 6690131.2 29, 356072.7 6690132.5 29))
BATIMENT0000000303969113;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1889-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;10;20;8.3;21.0;29.3;33.0;22.2;Cadastre;A 1.0;POLYGON Z ((356153.7 6690123.8 29.3, 356153.9 6690123.6 29.3, 356149.5 6690118.8 29.3, 356149.3 6690119 29.3, 356147.2 6690116.9 29.3, 356147.1 6690116.6 29.3, 356144.3 6690119.1 29.3, 356140.8 6690122.8 29.3, 356137.8 6690128.7 29.3, 356146.1 6690135.2 29.3, 356155.6 6690125.6 29.3, 356153.7 6690123.8 29.3))
BATIMENT0000000303969118;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.4;21.5;30.0;31.0;21.8;Cadastre;;POLYGON Z ((356160.4 6690127.3 30, 356158.4 6690129.3 30, 356161.4 6690132 30, 356163.5 6690130 30, 356160.4 6690127.3 30))
BATIMENT0000000303967714;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;19.6;23.5;27.0;21.1;Cadastre;;POLYGON Z ((356058 6690130.9 23.5, 356055.6 6690128.1 23.5, 356050.2 6690132.6 23.5, 356049.6 6690133.1 23.5, 356052.2 6690135.8 23.5, 356058 6690130.9 23.5))
BATIMENT0000000303969341;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.5;21.1;23.6;24.9;21.6;Cadastre;;POLYGON Z ((356281.3 6690123.9 23.6, 356282.7 6690125.8 23.6, 356287.2 6690122.6 23.6, 356285.9 6690120.6 23.6, 356281.3 6690123.9 23.6))
BATIMENT0000000303969117;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;21.5;24.2;26.2;21.9;Cadastre;;POLYGON Z ((356170.2 6690123.3 24.2, 356172.5 6690125.9 24.2, 356170.5 6690127.9 24.2, 356172.5 6690129.6 24.2, 356175.8 6690126 24.2, 356174.3 6690124.4 24.2, 356171.8 6690121.7 24.2, 356170.2 6690123.3 24.2))
BATIMENT0000000303969100;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.9;21.7;27.7;36.5;22.1;Cadastre;A 1.0;POLYGON Z ((356232.1 6690128.4 27.7, 356228.6 6690123.3 27.7, 356226.2 6690124.8 27.7, 356224.2 6690122.2 27.7, 356218.8 6690126 27.7, 356224.2 6690133.6 27.7, 356232.1 6690128.4 27.7))
BATIMENT0000000303969111;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;7.7;22.2;29.9;;;Cadastre;A 1.0;POLYGON Z ((356262.4 6690121.2 29.9, 356257.5 6690124.6 29.9, 356266.5 6690137.4 29.9, 356271.2 6690134 29.9, 356262.4 6690121.2 29.9))
BATIMENT0000000303969121;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;21.9;27.0;27.5;22.3;Cadastre;;POLYGON Z ((356180 6690130.6 27, 356178.4 6690132.4 27, 356179.2 6690133.4 27, 356182.9 6690137.4 27, 356184.7 6690135.8 27, 356180 6690130.6 27))
BATIMENT0000000303969048;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.4;21.3;30.8;34.9;21.8;Cadastre;A 1.0;POLYGON Z ((356258.1 6690138.8 30.8, 356260.3 6690141.7 30.8, 356262.6 6690140 30.8, 356261 6690137.7 30.8, 356263 6690136.3 30.8, 356257.6 6690128.6 30.8, 356255.7 6690129.9 30.8, 356255 6690128.8 30.8, 356246.9 6690134.4 30.8, 356252.5 6690142.6 30.8, 356258.1 6690138.8 30.8))
BATIMENT0000000303969116;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;5.0;10;20;5.7;21.7;27.5;37.6;22.4;Cadastre;A 1.0;POLYGON Z ((356172.5 6690129.6 27.5, 356168.5 6690134.1 27.5, 356158.7 6690144.8 27.5, 356163.5 6690148.5 27.5, 356171.3 6690140 27.5, 356171.8 6690139.6 27.5, 356174.5 6690136.6 27.5, 356171.7 6690134.2 27.5, 356173.7 6690132 27.5, 356176.5 6690134.5 27.5, 356178.4 6690132.4 27.5, 356180 6690130.6 27.5, 356178.3 6690128.8 27.5, 356175.8 6690126 27.5, 356172.5 6690129.6 27.5))
BATIMENT0000000303969047;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;21.6;31.7;36.1;21.8;Cadastre;A 1.0;POLYGON Z ((356240.6 6690138.6 31.7, 356246.4 6690147 31.7, 356246.8 6690147.5 31.7, 356253 6690143.4 31.7, 356252.5 6690142.6 31.7, 356246.9 6690134.4 31.7, 356240.6 6690138.6 31.7))
BATIMENT0000002244337852;Indifférenciée;Indifférencié;;Oui;En service;2021-06-09 10:34:30;2023-01-31 17:56:55;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.6;21.7;26.3;26.6;22.5;Cadastre;;POLYGON Z ((356217.3 6690140.2 26.3, 356211.3 6690131.7 26.3, 356196.6 6690142 26.3, 356202.5 6690150.5 26.3, 356217.3 6690140.2 26.3))
BATIMENT0000000303969112;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1836-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.6;21.1;28.7;31.0;21.7;Cadastre;C 0.4;POLYGON Z ((356275.3 6690149.9 28.7, 356280.1 6690146.5 28.7, 356271.2 6690134 28.7, 356266.5 6690137.4 28.7, 356275.3 6690149.9 28.7))
BATIMENT0000000303969123;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;9.1;21.9;31.0;38.3;22.3;Cadastre;A 1.0;POLYGON Z ((356168.8 6690152.7 31, 356178.9 6690143.5 31, 356182.8 6690140 31, 356181.6 6690138.7 31, 356182.9 6690137.4 31, 356179.2 6690133.4 31, 356172.2 6690140.9 31, 356171.3 6690140 31, 356163.5 6690148.5 31, 356168.8 6690152.7 31))
BATIMENT0000000303969122;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.2;21.2;28.4;30.4;22.5;Cadastre;;POLYGON Z ((356187.1 6690149 28.4, 356189 6690147.5 28.4, 356194.5 6690154 28.4, 356192.6 6690155.5 28.4, 356193.1 6690156.1 28.4, 356200.3 6690151.1 28.4, 356186 6690134.5 28.4, 356184.7 6690135.8 28.4, 356182.9 6690137.4 28.4, 356181.6 6690138.7 28.4, 356182.8 6690140 28.4, 356178.9 6690143.5 28.4, 356181.7 6690146.4 28.4, 356185.6 6690150.2 28.4, 356187.1 6690149 28.4))
BATIMENT0000000303969046;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.8;21.6;31.5;35.9;21.9;Cadastre;A 1.0;POLYGON Z ((356233.1 6690143.7 31.5, 356240.8 6690155 31.5, 356242.7 6690153.6 31.5, 356240.6 6690150.7 31.5, 356246.4 6690147 31.5, 356240.6 6690138.6 31.5, 356233.1 6690143.7 31.5))
BATIMENT0000000303969128;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1840-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;20;20;15.0;21.9;37.0;39.8;22.5;Cadastre;A 1.0;POLYGON Z ((356174.1 6690159.5 37, 356181.9 6690153.2 37, 356178.2 6690148.6 37, 356178.7 6690148.2 37, 356179.1 6690148.7 37, 356181.7 6690146.4 37, 356178.9 6690143.5 37, 356168.8 6690152.7 37, 356174.1 6690159.5 37))
BATIMENT0000000303969045;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;10;20;10.4;21.6;32.0;35.1;22.3;Cadastre;A 1.0;POLYGON Z ((356225.9 6690148.6 32, 356232.7 6690158.5 32, 356233.7 6690159.9 32, 356240.8 6690155 32, 356233.1 6690143.7 32, 356225.9 6690148.6 32))
BATIMENT0000000303969124;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;6.5;21.8;28.3;30.9;22.5;Cadastre;A 1.0;POLYGON Z ((356184.8 6690156 28.3, 356184.3 6690157.1 28.3, 356186.7 6690159.9 28.3, 356192.6 6690155.5 28.3, 356194.5 6690154 28.3, 356189 6690147.5 28.3, 356187.1 6690149 28.3, 356185.6 6690150.2 28.3, 356182.2 6690153 28.3, 356184.8 6690156 28.3))
BATIMENT0000000303969043;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.1;21.8;30.0;34.8;22.8;Cadastre;C 0.8;POLYGON Z ((356232.7 6690158.5 30, 356225.9 6690148.6 30, 356220.2 6690152.4 30, 356227.4 6690162.4 30, 356230.1 6690160.5 30, 356232.7 6690158.5 30))
BATIMENT0000000303969125;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;90;20;9.3;21.4;30.7;38.0;22.6;Cadastre;A 1.0;POLYGON Z ((356177.4 6690163.7 30.7, 356184.3 6690157.1 30.7, 356184.8 6690156 30.7, 356182.2 6690153 30.7, 356181.9 6690153.2 30.7, 356174.1 6690159.5 30.7, 356177.4 6690163.7 30.7))
BATIMENT0000000303969127;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;2.0;00;00;8.0;21.4;29.4;30.4;22.6;Cadastre;A 1.0;POLYGON Z ((356178.5 6690165.1 29.4, 356179.9 6690165.4 29.4, 356187 6690160.4 29.4, 356186.7 6690159.9 29.4, 356184.3 6690157.1 29.4, 356177.4 6690163.7 29.4, 356178.5 6690165.1 29.4))
BATIMENT0000000303969028;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;3.5;21.9;25.5;28.1;22.6;Cadastre;C 0.4;POLYGON Z ((356210.4 6690164.1 25.5, 356207 6690159.5 25.5, 356204 6690161.5 25.5, 356205.5 6690163.6 25.5, 356207.3 6690166.3 25.5, 356210.4 6690164.1 25.5))
BATIMENT0000000303969114;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;3.0;00;00;9.1;21.0;30.1;32.3;22.2;Cadastre;C 0.9;POLYGON Z ((356157.2 6690124 30.1, 356155.6 6690125.6 30.1, 356146.1 6690135.2 30.1, 356153 6690140.4 30.1, 356161.4 6690132 30.1, 356158.4 6690129.3 30.1, 356160.4 6690127.3 30.1, 356157.2 6690124 30.1))
BATIMENT0000000303969115;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;4.0;10;20;10.3;21.0;31.3;35.2;22.4;Cadastre;C 0.8;POLYGON Z ((356165.6 6690131.4 31.3, 356168 6690128.8 31.3, 356166.3 6690127.1 31.3, 356163.5 6690130 31.3, 356161.4 6690132 31.3, 356153 6690140.4 31.3, 356154.8 6690141.9 31.3, 356154.5 6690142.1 31.3, 356156.7 6690143.8 31.3, 356157 6690143.6 31.3, 356158.7 6690144.8 31.3, 356168.5 6690134.1 31.3, 356165.6 6690131.4 31.3))
BATIMENT0000000303967715;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;10;20;6.8;19.3;26.2;27.9;20.6;Cadastre;C 0.2;POLYGON Z ((356044.2 6690137.5 26.2, 356053 6690147.9 26.2, 356058.2 6690143.3 26.2, 356052.2 6690135.8 26.2, 356049.6 6690133.1 26.2, 356044.2 6690137.5 26.2))
BATIMENT0000000303967704;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;00;00;4.7;21.1;25.8;41.0;22.2;Cadastre;C 0.5;POLYGON Z ((356100 6690129.3 25.8, 356087 6690141.2 25.8, 356084.7 6690138.8 25.8, 356083.2 6690137.3 25.8, 356071.6 6690148.4 25.8, 356075.9 6690153.5 25.8, 356083 6690147.2 25.8, 356085 6690145.2 25.8, 356087.5 6690147.3 25.8, 356090 6690144.6 25.8, 356094 6690148.5 25.8, 356088.7 6690153.4 25.8, 356082.2 6690160.1 25.8, 356086.7 6690164.9 25.8, 356093.7 6690158.8 25.8, 356099.2 6690154 25.8, 356102.3 6690151.2 25.8, 356102.6 6690151.4 25.8, 356110 6690142.9 25.8, 356111.1 6690143.9 25.8, 356112.2 6690142.6 25.8, 356120.4 6690133 25.8, 356122.9 6690130.1 25.8, 356110.7 6690119.2 25.8, 356101.2 6690127.8 25.8, 356100 6690129.3 25.8), (356105.6 6690128.9 25.8, 356111.3 6690134 25.8, 356113.6 6690135.3 25.8, 356112.2 6690138 25.8, 356111 6690137 25.8, 356109.3 6690136.5 25.8, 356104.2 6690142.2 25.8, 356099.2 6690136.6 25.8, 356104.4 6690131.4 25.8, 356104.5 6690130 25.8, 356105.6 6690128.9 25.8))
BATIMENT0000000303967716;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1904-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;23;3.6;19.7;23.3;27.0;20.8;Cadastre;C 0.3;POLYGON Z ((356056.3 6690151.2 23.3, 356057.2 6690152.5 23.3, 356062.2 6690148.1 23.3, 356058.2 6690143.3 23.3, 356053 6690147.9 23.3, 356052.1 6690148.6 23.3, 356048.7 6690151.4 23.3, 356046.2 6690153.6 23.3, 356049.3 6690157.4 23.3, 356051.8 6690155.2 23.3, 356056.3 6690151.2 23.3))
BATIMENT0000000303967718;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;20.7;23.5;27.2;21.5;Cadastre;;POLYGON Z ((356071.6 6690148.4 23.5, 356067.3 6690152.2 23.5, 356071.6 6690157.2 23.5, 356075.9 6690153.5 23.5, 356071.6 6690148.4 23.5))
BATIMENT0000000303967720;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;7.0;30;20;19.1;21.9;41.1;42.2;22.8;Cadastre;C 0.8;POLYGON Z ((356127.8 6690140.6 41.1, 356124.3 6690136.9 41.1, 356120.4 6690133 41.1, 356112.2 6690142.6 41.1, 356115.2 6690145.6 41.1, 356119 6690149.4 41.1, 356136.3 6690167.1 41.1, 356125.5 6690177.9 41.1, 356129.8 6690182.5 41.1, 356130.8 6690183.9 41.1, 356148.7 6690169.4 41.1, 356146.9 6690167.3 41.1, 356150.7 6690163.8 41.1, 356127.8 6690140.6 41.1))
BATIMENT0000000303967721;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;22.1;29.2;32.3;22.9;Cadastre;;POLYGON Z ((356150.7 6690163.8 29.2, 356146.9 6690167.3 29.2, 356148.7 6690169.4 29.2, 356149.1 6690169 29.2, 356153.3 6690174.3 29.2, 356158.5 6690170.1 29.2, 356160.4 6690172.7 29.2, 356164.6 6690169.2 29.2, 356155.6 6690159.3 29.2, 356150.7 6690163.8 29.2))
BATIMENT0000000303969334;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;20.0;23.0;25.5;20.6;Cadastre;;POLYGON Z ((356053.6 6690169 23, 356055.2 6690170.6 23, 356055.3 6690170.6 23, 356057.6 6690168.5 23, 356056.3 6690166.7 23, 356053.6 6690169 23))
BATIMENT0000000303969333;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.3;20.1;23.5;28.0;20.8;Cadastre;;POLYGON Z ((356055.3 6690170.6 23.5, 356060.6 6690177.7 23.5, 356063.2 6690175.8 23.5, 356057.6 6690168.5 23.5, 356055.3 6690170.6 23.5))
BATIMENT0000000303969139;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.3;19.0;22.3;;;Cadastre;C 0.1;POLYGON Z ((356456.3 6690119.1 22.3, 356447.1 6690111.9 22.3, 356443.3 6690116.9 22.3, 356454.7 6690126.1 22.3, 356454.4 6690126.5 22.3, 356464.6 6690134.5 22.3, 356464.9 6690134.3 22.3, 356479.5 6690145.8 22.3, 356483.3 6690140.9 22.3, 356477.2 6690136.1 22.3, 356483.3 6690128.3 22.3, 356462.2 6690111.5 22.3, 356456.3 6690119.1 22.3))
BATIMENT0000000303969752;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;9.6;18.0;27.6;35.0;22.1;Cadastre;C 0.1;POLYGON Z ((356359.8 6690215.5 27.6, 356384.5 6690184.7 27.6, 356386.8 6690186.7 27.6, 356387.5 6690186.7 27.6, 356389.1 6690185.1 27.6, 356399.4 6690193.3 27.6, 356397.8 6690195.5 27.6, 356399.7 6690197.1 27.6, 356408.9 6690185.9 27.6, 356402 6690180.4 27.6, 356402.7 6690179.1 27.6, 356402.4 6690177.9 27.6, 356401.6 6690177.1 27.6, 356417.2 6690157.6 27.6, 356418 6690158.2 27.6, 356418.8 6690158.5 27.6, 356419.8 6690158.3 27.6, 356420.6 6690157.6 27.6, 356440.2 6690173.3 27.6, 356439.7 6690174.6 27.6, 356439.9 6690175.8 27.6, 356440.6 6690176.7 27.6, 356433.9 6690184.9 27.6, 356432.3 6690183.6 27.6, 356428.3 6690188.6 27.6, 356429.8 6690189.9 27.6, 356425 6690196 27.6, 356424.6 6690195.7 27.6, 356423.7 6690195.4 27.6, 356422.4 6690195.6 27.6, 356421.7 6690196.2 27.6, 356415.3 6690191.2 27.6, 356406.1 6690202.3 27.6, 356408.4 6690204.1 27.6, 356410.1 6690202 27.6, 356420.5 6690210.2 27.6, 356419.4 6690211.9 27.6, 356419.3 6690213.1 27.6, 356421.4 6690214.6 27.6, 356415.5 6690222.2 27.6, 356418 6690224 27.6, 356451.7 6690182.2 27.6, 356457.2 6690186.8 27.6, 356455.7 6690188.5 27.6, 356455.8 6690189.8 27.6, 356458.5 6690192 27.6, 356459.6 6690190.6 27.6, 356460.9 6690191.6 27.6, 356460.5 6690192.1 27.6, 356460.9 6690195.8 27.6, 356465.8 6690200 27.6, 356468.9 6690199.5 27.6, 356472.7 6690194.7 27.6, 356472.7 6690191.5 27.6, 356471.5 6690190.5 27.6, 356476.6 6690184.2 27.6, 356477.2 6690184.3 27.6, 356479.4 6690181.8 27.6, 356479 6690181 27.6, 356481.1 6690178.6 27.6, 356481.9 6690178.7 27.6, 356483.9 6690176.2 27.6, 356483.6 6690175.4 27.6, 356485.2 6690173.2 27.6, 356486.1 6690173.4 27.6, 356488.1 6690171 27.6, 356487.9 6690170.1 27.6, 356491.8 6690165.1 27.6, 356492.7 6690165.3 27.6, 356494.7 6690162.8 27.6, 356494.3 6690161.9 27.6, 356496.3 6690159.6 27.6, 356497.1 6690159.9 27.6, 356499 6690157.3 27.6, 356498.8 6690156.3 27.6, 356500.7 6690153.9 27.6, 356501.7 6690154.1 27.6, 356503.5 6690151.8 27.6, 356503.2 6690150.8 27.6, 356506.1 6690147.4 27.6, 356506.6 6690147.8 27.6, 356506.81139568595 6690147.5388641525 27.6, 356506.81139568595 6690137.635446046 27.6, 356504.7 6690135.7 27.6, 356504.6 6690134.9 27.6, 356502.2 6690132.9 27.6, 356501.5 6690133.2 27.6, 356500.1 6690132 27.6, 356495.4 6690138 27.6, 356495.7 6690138.4 27.6, 356495.1 6690139.3 27.6, 356494.3 6690139.2 27.6, 356492.1 6690142.1 27.6, 356492.5 6690142.9 27.6, 356490.8 6690144.7 27.6, 356490 6690144.8 27.6, 356487.6 6690147.7 27.6, 356488 6690148.4 27.6, 356486.2 6690150.5 27.6, 356485.4 6690150.3 27.6, 356483.1 6690153.2 27.6, 356483.4 6690153.9 27.6, 356475.3 6690163.9 27.6, 356474.4 6690163.7 27.6, 356472.2 6690166.6 27.6, 356472.5 6690167.4 27.6, 356470.7 6690169.5 27.6, 356469.9 6690169.4 27.6, 356468.1 6690171.8 27.6, 356468.2 6690172.9 27.6, 356466.5 6690174.8 27.6, 356465.4 6690174.9 27.6, 356463.4 6690177.5 27.6, 356463.7 6690178.5 27.6, 356462.5 6690179.6 27.6, 356457.4 6690175.1 27.6, 356459 6690173.1 27.6, 356417.1 6690139.1 27.6, 356410.6 6690147.3 27.6, 356405.2 6690142.9 27.6, 356409.3 6690137.8 27.6, 356410.3 6690137.6 27.6, 356412 6690135.3 27.6, 356411.9 6690134.6 27.6, 356413.8 6690132.3 27.6, 356414.8 6690132 27.6, 356416.7 6690129.7 27.6, 356416.4 6690128.9 27.6, 356418.2 6690126.7 27.6, 356419.1 6690126.7 27.6, 356421.1 6690124.3 27.6, 356420.9 6690123.3 27.6, 356429.4 6690113.1 27.6, 356430.2 6690113.1 27.6, 356432.1 6690110.6 27.6, 356431.9 6690109.9 27.6, 356436.5 6690104.3 27.6, 356437.4 6690104.3 27.6, 356440.1 6690100.8 27.6, 356438.9 6690099.7 27.6, 356438.8 6690098.9 27.6, 356436.5 6690097.1 27.6, 356435.7 6690097.2 27.6, 356433.4 6690095.2 27.6, 356433.2 6690094.5 27.6, 356430.8 6690092.6 27.6, 356430 6690092.6 27.6, 356428.9 6690091.5 27.6, 356424 6690097.6 27.6, 356424.3 6690097.8 27.6, 356423.4 6690099.1 27.6, 356422.9 6690099.1 27.6, 356420.3 6690102.1 27.6, 356420.7 6690102.7 27.6, 356419 6690104.7 27.6, 356418.3 6690104.5 27.6, 356416.3 6690107 27.6, 356416.5 6690107.9 27.6, 356412.5 6690112.6 27.6, 356411.8 6690112.7 27.6, 356409.6 6690115.4 27.6, 356410 6690116 27.6, 356408.3 6690118 27.6, 356407.5 6690118 27.6, 356405.4 6690120.4 27.6, 356405.4 6690121.5 27.6, 356403.7 6690123.7 27.6, 356403.2 6690123.4 27.6, 356401 6690125.9 27.6, 356401.2 6690126.7 27.6, 356399.5 6690128.9 27.6, 356398.8 6690128.9 27.6, 356396.6 6690131.5 27.6, 356396.8 6690132.2 27.6, 356393.5 6690136.1 27.6, 356392.3 6690135.1 27.6, 356389.3 6690135.8 27.6, 356385.4 6690140.2 27.6, 356385.8 6690143.4 27.6, 356390.6 6690147.3 27.6, 356393.8 6690146.7 27.6, 356395.8 6690144.3 27.6, 356397.1 6690145.4 27.6, 356395.2 6690147.9 27.6, 356395.2 6690149.2 27.6, 356397.8 6690151.2 27.6, 356399 6690150.8 27.6, 356400.9 6690148.4 27.6, 356406.1 6690152.8 27.6, 356383.9 6690180.4 27.6, 356382.3 6690179 27.6, 356355.6 6690212.3 27.6, 356359.2 6690215.1 27.6, 356359.8 6690215.5 27.6))
BATIMENT0000000303969161;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.4;18.6;25.0;28.5;20.9;Cadastre;A 1.0;POLYGON Z ((356334.4 6690177.2 25, 356340.4 6690172.1 25, 356342.5 6690169.7 25, 356341.1 6690167.6 25, 356339 6690168.8 25, 356335.8 6690160.9 25, 356338.6 6690159.2 25, 356334.9 6690156 25, 356336.4 6690153.6 25, 356338.6 6690155.5 25, 356344.3 6690151.7 25, 356338.5 6690148.1 25, 356337 6690149.7 25, 356334.7 6690152.1 25, 356327 6690157.3 25, 356334.4 6690177.2 25))
BATIMENT0000000303969138;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;30;40;3.5;22.0;25.5;;;Cadastre;C 0.7;POLYGON Z ((356319.2 6690185.7 25.5, 356326.2 6690180.5 25.5, 356317.7 6690168.5 25.5, 356319.2 6690167.4 25.5, 356316.2 6690162.9 25.5, 356319.9 6690160.4 25.5, 356318.4 6690156.4 25.5, 356310.7 6690162 25.5, 356312.6 6690164.8 25.5, 356305.7 6690169.8 25.5, 356309.8 6690175.4 25.5, 356311.1 6690174.6 25.5, 356311.9 6690175.8 25.5, 356319.2 6690185.7 25.5))
BATIMENT0000000303969751;Eglise;Religieux;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.6;19.8;25.4;;;Cadastre;;POLYGON Z ((356403.7 6690205.9 25.4, 356404.4 6690205.2 25.4, 356403.9 6690204.8 25.4, 356406.1 6690202.3 25.4, 356415.3 6690191.2 25.4, 356415.7 6690190.7 25.4, 356416 6690188.9 25.4, 356415.7 6690187.5 25.4, 356414.7 6690186 25.4, 356413.5 6690185.2 25.4, 356411.8 6690184.8 25.4, 356410.4 6690185.1 25.4, 356408.9 6690185.9 25.4, 356399.7 6690197.1 25.4, 356397.8 6690199.7 25.4, 356397.2 6690199.4 25.4, 356396.6 6690200.2 25.4, 356403.7 6690205.9 25.4))
BATIMENT0000000303969132;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;10;3.0;21.7;24.7;;;Cadastre;A 1.0;POLYGON Z ((356346.1 6690194.4 24.7, 356349.2 6690201.9 24.7, 356359.3 6690197.9 24.7, 356356.1 6690190.3 24.7, 356346.1 6690194.4 24.7))
BATIMENT0000000303969022;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;20.8;27.0;39.0;21.4;Cadastre;;POLYGON Z ((356343.8 6690222.6 27, 356339.2 6690214.9 27, 356336.2 6690206.7 27, 356331.5 6690210 27, 356341.4 6690224.4 27, 356343.8 6690222.6 27))
BATIMENT0000000303969082;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;4.3;21.0;25.3;27.1;21.2;Cadastre;C 0.2;POLYGON Z ((356354.1 6690221.2 25.3, 356358.6 6690225 25.3, 356363.8 6690218.6 25.3, 356359.8 6690215.5 25.3, 356359.2 6690215.1 25.3, 356354.1 6690221.2 25.3))
BATIMENT0000000303969143;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;21.7;25.5;;;Cadastre;;POLYGON Z ((356365.5 6690220.9 25.5, 356360.9 6690226.9 25.5, 356370.9 6690234.8 25.5, 356373.7 6690231.3 25.5, 356371.9 6690229.9 25.5, 356373.6 6690227.6 25.5, 356365.5 6690220.9 25.5))
BATIMENT0000000303969142;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;20.9;24.5;25.2;21.2;Cadastre;;POLYGON Z ((356371.9 6690229.9 24.5, 356373.7 6690231.3 24.5, 356375.5 6690229.1 24.5, 356373.6 6690227.6 24.5, 356371.9 6690229.9 24.5))
BATIMENT0000000303967630;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;7.7;18.9;26.7;28.7;20.0;Cadastre;A 1.0;POLYGON Z ((356004.8 6690023 26.7, 356002.8 6690025 26.7, 356004.4 6690026.4 26.7, 356003.6 6690027.5 26.7, 356007.7 6690030.3 26.7, 356010.1 6690026.8 26.7, 356004.8 6690023 26.7))
BATIMENT0000000304020546;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;10.0;18.4;28.4;32.0;20.5;Cadastre;A 0.1;POLYGON Z ((355991 6690027.1 28.4, 355990 6690025.8 28.4, 355988.6 6690027.3 28.4, 355992.6 6690031.2 28.4, 355994 6690029.8 28.4, 355991 6690027.1 28.4))
BATIMENT0000000303967686;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;;;15.9;19.3;35.2;37.0;20.6;Cadastre;A 1.0;POLYGON Z ((356029.9 6690029.8 35.2, 356025.3 6690024.6 35.2, 356022.1 6690024.7 35.2, 356015.7 6690034.3 35.2, 356019.7 6690038.1 35.2, 356022.5 6690034.4 35.2, 356023.8 6690035.8 35.2, 356029.9 6690029.8 35.2))
BATIMENT0000000303967592;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;23;9.7;18.5;28.2;31.4;19.6;Cadastre;A 1.0;POLYGON Z ((355998.1 6690033.9 28.2, 356002.4 6690038 28.2, 356007.7 6690030.3 28.2, 356003.6 6690027.5 28.2, 355998.1 6690033.9 28.2))
BATIMENT0000000303967679;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;11.3;19.2;30.5;34.5;20.7;Cadastre;A 1.0;POLYGON Z ((356023.8 6690035.8 30.5, 356020.6 6690038.9 30.5, 356018.7 6690040.8 30.5, 356020.9 6690043.2 30.5, 356024.2 6690039.9 30.5, 356024.9 6690040.5 30.5, 356025.5 6690039.6 30.5, 356026.8 6690040.9 30.5, 356022.3 6690044.9 30.5, 356022.5 6690045 30.5, 356025 6690047.9 30.5, 356025.3 6690047.6 30.5, 356028 6690045.3 30.5, 356036.4 6690037.6 30.5, 356029.9 6690029.8 30.5, 356023.8 6690035.8 30.5))
BATIMENT0000000303967591;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;12;20;16.3;17.7;34.0;35.6;19.8;Cadastre;A 1.0;POLYGON Z ((355987.4 6690036.6 34, 355990.4 6690039.3 34, 355989.7 6690041.3 34, 355989.1 6690042.1 34, 355988.8 6690041.9 34, 355987.2 6690043.6 34, 355987.6 6690044 34, 355987.1 6690045 34, 355987.7 6690045.4 34, 355989.9 6690047 34, 355994.3 6690050 34, 356002.4 6690038 34, 355998.1 6690033.9 34, 355996.1 6690036.2 34, 355994.5 6690037.8 34, 355990.3 6690033.6 34, 355987.4 6690036.6 34))
BATIMENT0000000303967681;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;5.0;00;00;10.3;18.6;29.0;32.9;19.6;Cadastre;A 1.0;POLYGON Z ((356010.5 6690041.9 29, 356018.4 6690047.7 29, 356022.8 6690050.8 29, 356025 6690047.9 29, 356022.5 6690045 29, 356022.3 6690044.9 29, 356020 6690046.5 29, 356019 6690045.5 29, 356020.9 6690043.2 29, 356018.7 6690040.8 29, 356020.6 6690038.9 29, 356019.7 6690038.1 29, 356015.7 6690034.3 29, 356010.5 6690041.9 29))
BATIMENT0000000303967678;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;20;20;14.8;18.6;33.5;36.8;20.8;Cadastre;A 1.0;POLYGON Z ((356036.4 6690037.6 33.5, 356028 6690045.3 33.5, 356025.3 6690047.6 33.5, 356029.8 6690053.3 33.5, 356030.9 6690052.4 33.5, 356032.9 6690050.8 33.5, 356041.4 6690043.6 33.5, 356036.4 6690037.6 33.5))
BATIMENT0000000304020552;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.7;17.7;30.5;35.0;18.4;Cadastre;;POLYGON Z ((355987.7 6690045.4 30.5, 355986.5 6690046.8 30.5, 355988.8 6690048.4 30.5, 355989.9 6690047 30.5, 355987.7 6690045.4 30.5))
BATIMENT0000000304020547;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;30;10.2;16.9;27.2;31.2;19.9;Cadastre;A 1.0;POLYGON Z ((355990.4 6690039.3 27.2, 355987.4 6690036.6 27.2, 355987.2 6690036.5 27.2, 355986.7 6690037.1 27.2, 355977.7 6690047.1 27.2, 355981.2 6690050.6 27.2, 355980.7 6690051.1 27.2, 355988.7 6690058.1 27.2, 355994.3 6690050 27.2, 355989.9 6690047 27.2, 355988.8 6690048.4 27.2, 355986.5 6690046.8 27.2, 355986.2 6690047 27.2, 355983.9 6690044.8 27.2, 355988.1 6690040.1 27.2, 355989.7 6690041.3 27.2, 355990.4 6690039.3 27.2))
BATIMENT0000000303967688;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;11.5;18.0;29.5;33.0;19.4;Cadastre;A 1.0;POLYGON Z ((356005.5 6690049.1 29.5, 356015.3 6690055.5 29.5, 356016.5 6690056.3 29.5, 356017.5 6690055.2 29.5, 356016.6 6690054.4 29.5, 356018.4 6690052.1 29.5, 356017.6 6690051.3 29.5, 356018.4 6690050.2 29.5, 356021.1 6690052.5 29.5, 356022.8 6690050.8 29.5, 356018.4 6690047.7 29.5, 356010.5 6690041.9 29.5, 356005.5 6690049.1 29.5))
BATIMENT0000000303967680;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;16.7;19.2;36.0;38.4;21.2;Cadastre;A 1.0;POLYGON Z ((356032.9 6690050.8 36, 356036.5 6690055.6 36, 356038.8 6690058.3 36, 356047.5 6690050.7 36, 356041.4 6690043.6 36, 356032.9 6690050.8 36))
BATIMENT0000000303967682;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.3;18.6;26.0;34.0;20.2;Cadastre;A 1.0;POLYGON Z ((356030.9 6690052.4 26, 356029.8 6690053.3 26, 356024.3 6690058 26, 356027.7 6690062.7 26, 356028 6690062.8 26, 356036.5 6690055.6 26, 356032.9 6690050.8 26, 356030.9 6690052.4 26))
BATIMENT0000000303967612;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;10;20;13.8;16.2;30.0;34.4;19.2;Cadastre;A 1.0;POLYGON Z ((356005.5 6690049.1 30, 355999.5 6690058.1 30, 356007.6 6690063.7 30, 356013.9 6690067.6 30, 356018.1 6690062.7 30, 356020.8 6690059.2 30, 356017.5 6690057.1 30, 356015.3 6690060.3 30, 356016.2 6690061.1 30, 356014.6 6690063.3 30, 356011.6 6690061.2 30, 356015.3 6690055.5 30, 356005.5 6690049.1 30))
BATIMENT0000000303967687;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;04;01;5.4;18.5;24.0;25.5;19.6;Cadastre;A 1.0;POLYGON Z ((356020.8 6690059.2 24, 356018.1 6690062.7 24, 356022.4 6690067.3 24, 356028 6690062.8 24, 356027.7 6690062.7 24, 356024.3 6690058 24, 356023 6690057.1 24, 356020.8 6690059.2 24))
BATIMENT0000000303967683;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;14.3;19.9;34.2;38.4;21.2;Cadastre;A 1.0;POLYGON Z ((356038.8 6690058.3 34.2, 356039.1 6690058.7 34.2, 356037 6690060.5 34.2, 356036.7 6690061.3 34.2, 356038.2 6690063 34.2, 356038.9 6690062.8 34.2, 356040.1 6690064.2 34.2, 356033.1 6690070.3 34.2, 356036.8 6690074.2 34.2, 356053.9 6690058.6 34.2, 356047.5 6690050.7 34.2, 356038.8 6690058.3 34.2))
BATIMENT0000000303967613;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;12;20;9.7;16.3;26.0;31.5;18.0;Cadastre;A 1.0;POLYGON Z ((356005.5 6690071.4 26, 356003.3 6690070 26, 356007.6 6690063.7 26, 355999.5 6690058.1 26, 355994.1 6690066.2 26, 356004.3 6690073.2 26, 356005.5 6690071.4 26))
BATIMENT0000000303967697;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;45;20;5.1;18.3;23.4;29.5;19.3;Cadastre;A 1.0;POLYGON Z ((356013.9 6690067.6 23.4, 356013.4 6690068.2 23.4, 356017.2 6690072.2 23.4, 356022.4 6690067.3 23.4, 356018.1 6690062.7 23.4, 356013.9 6690067.6 23.4))
BATIMENT0000000303967695;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;18.6;23.8;28.1;19.1;Cadastre;;POLYGON Z ((356011.4 6690070.6 23.8, 356014.6 6690074.3 23.8, 356017.2 6690072.2 23.8, 356013.4 6690068.2 23.8, 356011.4 6690070.6 23.8))
BATIMENT0000000303967685;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;50;20;6.2;19.2;25.4;29.5;20.7;Cadastre;A 1.0;POLYGON Z ((356031.1 6690068.2 25.4, 356025 6690074 25.4, 356030.7 6690079.9 25.4, 356036.6 6690074.4 25.4, 356036.8 6690074.2 25.4, 356033.1 6690070.3 25.4, 356031.1 6690068.2 25.4))
BATIMENT0000000304020502;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;14.8;18.2;21.2;16.1;Cadastre;;POLYGON Z ((355856.6 6690064.5 18.2, 355858 6690065.2 18.2, 355860.3 6690061.8 18.2, 355859 6690060.9 18.2, 355856.6 6690064.5 18.2))
BATIMENT0000000304020508;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.4;14.8;20.3;23.2;18.1;Cadastre;;POLYGON Z ((355873.6 6690067.2 20.3, 355874.2 6690066.3 20.3, 355869.9 6690063.8 20.3, 355860.8 6690058 20.3, 355859 6690060.9 20.3, 355860.3 6690061.8 20.3, 355864.4 6690064.2 20.3, 355864.2 6690064.7 20.3, 355867.5 6690066.6 20.3, 355867.9 6690066.3 20.3, 355871.3 6690068 20.3, 355872.6 6690068.9 20.3, 355873.6 6690067.2 20.3))
BATIMENT0000000304020497;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1858-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;05;23;4.8;14.1;19.0;26.0;17.3;Cadastre;A 1.0;POLYGON Z ((355831.7 6690065.6 19, 355850.5 6690074.5 19, 355856.1 6690065.3 19, 355848.8 6690061.6 19, 355847.5 6690063.6 19, 355838.8 6690059.4 19, 355841.7 6690054.9 19, 355840.7 6690054.3 19, 355831.7 6690065.6 19))
BATIMENT0000000304020515;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;15.0;20.7;25.0;16.7;Cadastre;;POLYGON Z ((355885.5 6690069.5 20.7, 355885.9 6690068.6 20.7, 355879.8 6690064.2 20.7, 355877.5 6690067.3 20.7, 355880.8 6690069.6 20.7, 355881.1 6690071.4 20.7, 355883.2 6690072.5 20.7, 355885.5 6690069.5 20.7))
BATIMENT0000000304020516;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.9;15.5;18.4;18.7;16.6;Cadastre;A 0.3;POLYGON Z ((355886.7 6690067.6 18.4, 355885.9 6690068.6 18.4, 355885.5 6690069.5 18.4, 355886.3 6690070.1 18.4, 355887.6 6690068.2 18.4, 355886.7 6690067.6 18.4))
BATIMENT0000000304020510;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.1;14.6;25.7;28.2;16.2;Cadastre;;POLYGON Z ((355872.6 6690068.9 25.7, 355871.3 6690068 25.7, 355870.1 6690069.6 25.7, 355871.5 6690070.5 25.7, 355872.6 6690068.9 25.7))
BATIMENT0000000304020520;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;15.4;18.2;18.7;16.5;Cadastre;;POLYGON Z ((355888.8 6690072 18.2, 355890.1 6690070.2 18.2, 355887.6 6690068.2 18.2, 355886.3 6690070.1 18.2, 355888.8 6690072 18.2))
BATIMENT0000000304020503;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;13.9;13.8;27.7;29.7;15.7;Cadastre;C 0.9;POLYGON Z ((355856.1 6690065.3 27.7, 355850.5 6690074.5 27.7, 355863.9 6690080.9 27.7, 355863.3 6690082.1 27.7, 355863.9 6690082.4 27.7, 355871.5 6690070.5 27.7, 355870.1 6690069.6 27.7, 355869 6690071.4 27.7, 355858 6690065.2 27.7, 355856.6 6690064.5 27.7, 355856.1 6690065.3 27.7))
BATIMENT0000000304020524;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;15.2;22.7;26.0;16.4;Cadastre;A 1.0;POLYGON Z ((355907.6 6690076.7 22.7, 355908.1 6690076 22.7, 355899.2 6690067.8 22.7, 355895.1 6690072.7 22.7, 355903.7 6690080.4 22.7, 355907.6 6690076.7 22.7))
BATIMENT0000000304020509;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;4.0;10;20;14.0;13.6;27.6;29.6;16.5;Cadastre;A 1.0;POLYGON Z ((355879.5 6690073.7 27.6, 355874.5 6690071.3 27.6, 355876.3 6690068.7 27.6, 355875.3 6690068 27.6, 355873.6 6690067.2 27.6, 355872.6 6690068.9 27.6, 355871.5 6690070.5 27.6, 355863.9 6690082.4 27.6, 355874.2 6690086.2 27.6, 355881.9 6690074.7 27.6, 355882.3 6690073.9 27.6, 355883.2 6690072.5 27.6, 355881.1 6690071.4 27.6, 355879.5 6690073.7 27.6))
BATIMENT0000000304020541;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;15;20;16.1;15.5;31.6;32.7;17.7;Cadastre;A 1.0;POLYGON Z ((355961.6 6690047.7 31.6, 355969.1 6690054.7 31.6, 355982.8 6690066.8 31.6, 355986.3 6690061.6 31.6, 355965.7 6690043.5 31.6, 355961.6 6690047.7 31.6))
BATIMENT0000000304020537;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;10;20;13.6;15.6;29.2;31.5;17.3;Cadastre;A 1.0;POLYGON Z ((355966.8 6690057.3 29.2, 355972.2 6690061.9 29.2, 355970.6 6690063.9 29.2, 355979.1 6690072.1 29.2, 355982.8 6690066.8 29.2, 355969.1 6690054.7 29.2, 355966.8 6690057.3 29.2))
BATIMENT0000000304020535;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;16.4;14.3;30.7;32.0;17.4;Cadastre;C 0.2;POLYGON Z ((355975.1 6690078.1 30.7, 355979.1 6690072.1 30.7, 355970.6 6690063.9 30.7, 355969 6690065.9 30.7, 355966.7 6690063.7 30.7, 355968.3 6690061.6 30.7, 355964.3 6690057.8 30.7, 355960.3 6690062.4 30.7, 355961.4 6690063.4 30.7, 355966.2 6690067 30.7, 355964.3 6690070.7 30.7, 355969.8 6690074.7 30.7, 355975.1 6690078.1 30.7))
BATIMENT0000000304020534;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;19.0;5.0;10;20;15.1;14.3;29.4;32.4;17.4;Cadastre;C 0.9;POLYGON Z ((355952.9 6690083 29.4, 355954.9 6690084.1 29.4, 355964.6 6690090.5 29.4, 355965.9 6690091.4 29.4, 355975.1 6690078.1 29.4, 355969.8 6690074.7 29.4, 355968.7 6690075 29.4, 355967.6 6690076.3 29.4, 355962.9 6690073.6 29.4, 355964.3 6690070.7 29.4, 355966.2 6690067 29.4, 355961.4 6690063.4 29.4, 355950.9 6690081.5 29.4, 355952.9 6690083 29.4), (355961.1 6690077.3 29.4, 355965 6690079.9 29.4, 355962.5 6690083.6 29.4, 355958.9 6690081.3 29.4, 355961.1 6690077.3 29.4))
BATIMENT0000000291510766;Indifférenciée;Résidentiel;;Non;En service;2011-11-16 12:28:21;2019-03-15 08:35:34;2005-01-01;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;7.0;2.0;00;00;10.0;15.7;;;;Imagerie aérienne;C 0.5;POLYGON Z ((355940.5 6690077.8 19.7, 355920.1 6690068.8 19.7, 355915.3 6690078.2 19.7, 355930.5 6690085.5 19.7, 355926.9 6690091.5 19.7, 355927.2 6690091.5 25.4, 355932.6 6690094.3 25.7, 355940.5 6690077.8 19.7))
BATIMENT0000000304020533;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;14.3;14.9;29.2;30.2;15.1;Cadastre;A 1.0;POLYGON Z ((355949.9 6690091.7 29.2, 355959.8 6690098.1 29.2, 355960.1 6690097.5 29.2, 355964.6 6690090.5 29.2, 355954.9 6690084.1 29.2, 355949.9 6690091.7 29.2))
BATIMENT0000000304020532;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;00;00;16.5;12.4;28.9;30.2;14.5;Cadastre;C 0.1;POLYGON Z ((355958.8 6690102 28.9, 355958.7 6690101.6 28.9, 355957.9 6690101.1 28.9, 355959.8 6690098.1 28.9, 355949.9 6690091.7 28.9, 355948.2 6690094.4 28.9, 355947.7 6690094.1 28.9, 355945.6 6690097.5 28.9, 355946.1 6690097.8 28.9, 355944.4 6690100.6 28.9, 355944.7 6690100.8 28.9, 355948.8 6690102.5 28.9, 355955.5 6690107.1 28.9, 355958.8 6690102 28.9))
BATIMENT0000000304020527;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;10;20;5.9;11.9;17.9;26.8;15.2;Cadastre;A 1.0;POLYGON Z ((355925.6 6690099.8 17.9, 355924.9 6690099.5 17.9, 355924.7 6690098.9 17.9, 355921.4 6690097.5 17.9, 355921.8 6690096.5 17.9, 355919 6690095.4 17.9, 355915.7 6690102.4 17.9, 355916 6690102.6 17.9, 355923 6690105.1 17.9, 355930.9 6690107.9 17.9, 355931.3 6690107.9 17.9, 355936.1 6690096.9 17.9, 355933.3 6690095.7 17.9, 355928.4 6690093.5 17.9, 355925.6 6690099.8 17.9))
BATIMENT0000000304020529;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;19;20;13.9;11.8;25.7;27.9;15.1;Cadastre;A 1.0;POLYGON Z ((355936.1 6690096.9 25.7, 355931.3 6690107.9 25.7, 355930.9 6690107.9 25.7, 355930.1 6690109.5 25.7, 355935.4 6690111.7 25.7, 355939.3 6690112.4 25.7, 355939.9 6690111.1 25.7, 355941.2 6690111.6 25.7, 355943.6 6690104.5 25.7, 355939.7 6690103.6 25.7, 355938.2 6690103.5 25.7, 355940.3 6690098.9 25.7, 355936.1 6690096.9 25.7))
BATIMENT0000000304020530;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;20;20;15.1;12.0;27.1;29.1;12.7;Cadastre;A 1.0;POLYGON Z ((355943.6 6690104.5 27.1, 355941.2 6690111.6 27.1, 355949.1 6690114.3 27.1, 355950.6 6690114.1 27.1, 355955.5 6690107.1 27.1, 355948.8 6690102.5 27.1, 355944.7 6690100.8 27.1, 355943.6 6690104.5 27.1))
BATIMENT0000000303967618;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;20;20;9.0;15.4;24.4;28.6;18.4;Cadastre;A 1.0;POLYGON Z ((355987.4 6690075.9 24.4, 355995.9 6690081 24.4, 356000.9 6690073.8 24.4, 356001.9 6690074.4 24.4, 356000.7 6690076.1 24.4, 356002.5 6690077.4 24.4, 355997.6 6690083.4 24.4, 355998.3 6690084.3 24.4, 356002.6 6690081.1 24.4, 356004.3 6690078.8 24.4, 356007.5 6690075.3 24.4, 356004.3 6690073.2 24.4, 355994.1 6690066.2 24.4, 355987.4 6690075.9 24.4))
BATIMENT0000000303967722;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.4;18.6;22.0;23.0;19.0;Cadastre;A 1.0;POLYGON Z ((356007.5 6690075.3 22, 356004.3 6690078.8 22, 356006.6 6690081.2 22, 356011.9 6690076.7 22, 356009 6690073.4 22, 356007.5 6690075.3 22))
BATIMENT0000000303967694;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;6.1;18.9;25.0;26.4;20.5;Cadastre;A 1.0;POLYGON Z ((356018.9 6690080.2 25, 356024.4 6690086 25, 356030.7 6690079.9 25, 356025 6690074 25, 356018.9 6690080.2 25))
BATIMENT0000000303967705;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.4;18.6;22.0;22.5;19.0;Cadastre;;POLYGON Z ((356002.6 6690081.1 22, 356004.3 6690083.2 22, 356006.6 6690081.2 22, 356004.3 6690078.8 22, 356002.6 6690081.1 22))
BATIMENT0000000304020886;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;50;20;8.4;14.8;23.2;26.0;17.2;Cadastre;A 1.0;POLYGON Z ((355997.7 6690084.6 23.2, 355997.4 6690084.6 23.2, 355995.9 6690081 23.2, 355987.4 6690075.9 23.2, 355986.4 6690078.6 23.2, 355985.4 6690083.3 23.2, 355985.7 6690083.4 23.2, 355985.1 6690087.3 23.2, 355991.8 6690088.2 23.2, 355992 6690086.6 23.2, 355993 6690086.9 23.2, 355997.7 6690084.6 23.2))
BATIMENT0000000303967696;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;50;20;5.3;18.7;24.1;26.3;19.7;Cadastre;A 1.0;POLYGON Z ((356012.7 6690086.2 24.1, 356018.2 6690091.8 24.1, 356024.4 6690086 24.1, 356018.9 6690080.2 24.1, 356012.7 6690086.2 24.1))
BATIMENT0000000303967699;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;4.6;18.6;23.2;23.8;19.5;Cadastre;A 1.0;POLYGON Z ((356009.4 6690089.2 23.2, 356015.4 6690094.5 23.2, 356018.2 6690091.8 23.2, 356012.7 6690086.2 23.2, 356009.4 6690089.2 23.2))
BATIMENT0000000303967616;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;10.9;14.5;25.5;26.9;18.8;Cadastre;A 1.0;POLYGON Z ((355993 6690086.9 25.5, 355993.4 6690088.4 25.5, 355996.3 6690096.8 25.5, 355996.7 6690097.6 25.5, 356003.2 6690094 25.5, 355997.7 6690084.6 25.5, 355993 6690086.9 25.5))
BATIMENT0000000303967700;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;3.8;18.6;22.5;23.8;19.4;Cadastre;A 1.0;POLYGON Z ((356006.6 6690091.9 22.5, 356012.3 6690097.5 22.5, 356015.4 6690094.5 22.5, 356009.4 6690089.2 22.5, 356006.6 6690091.9 22.5))
BATIMENT0000000304020884;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;3.0;50;20;8.6;14.1;22.8;25.2;16.2;Cadastre;A 1.0;POLYGON Z ((355993.4 6690104.5 22.8, 355989.8 6690097.2 22.8, 355991.3 6690089.6 22.8, 355992.2 6690089.7 22.8, 355992.7 6690094.5 22.8, 355993.1 6690094.5 22.8, 355993.8 6690097.3 22.8, 355996.3 6690096.8 22.8, 355993.4 6690088.4 22.8, 355991.8 6690088.2 22.8, 355985.1 6690087.3 22.8, 355982.6 6690102.6 22.8, 355993.4 6690104.5 22.8))
BATIMENT0000000304020519;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;14.3;19.2;22.4;15.3;Cadastre;;POLYGON Z ((355890.1 6690078.3 19.2, 355892.2 6690080 19.2, 355894.3 6690077.5 19.2, 355892.4 6690075.8 19.2, 355890.1 6690078.3 19.2))
BATIMENT0000000304020834;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;19;23;12.4;13.8;26.2;27.7;14.8;Cadastre;A 1.0;POLYGON Z ((355820.6 6690081.4 26.2, 355831.5 6690086.7 26.2, 355835.9 6690077.9 26.2, 355836.4 6690077.3 26.2, 355824.9 6690071.5 26.2, 355824.4 6690072.4 26.2, 355823.4 6690074.5 26.2, 355820.1 6690081.2 26.2, 355820.6 6690081.4 26.2))
BATIMENT0000000304020512;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;4.0;10;20;12.7;13.2;26.0;28.3;15.3;Cadastre;A 0.3;POLYGON Z ((355874.2 6690086.2 26, 355882.8 6690089.4 26, 355887 6690083.3 26, 355889.1 6690080.1 26, 355889.8 6690079.2 26, 355889.7 6690079.1 26, 355888.2 6690078 26, 355888 6690078.8 26, 355881.9 6690074.7 26, 355874.2 6690086.2 26))
BATIMENT0000000304020513;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;13.9;18.5;22.0;14.6;Cadastre;;POLYGON Z ((355887 6690083.3 18.5, 355888.8 6690084.5 18.5, 355890.9 6690081.3 18.5, 355889.1 6690080.1 18.5, 355887 6690083.3 18.5))
BATIMENT0000000304020528;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.6;14.1;23.7;27.4;15.4;Cadastre;;POLYGON Z ((355899.2 6690082.1 23.7, 355897.2 6690084.3 23.7, 355898.9 6690085.8 23.7, 355901.2 6690083.5 23.7, 355899.2 6690082.1 23.7))
BATIMENT0000000304020514;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.7;12.9;17.7;24.5;14.4;Cadastre;;POLYGON Z ((355882.8 6690089.4 17.7, 355886.7 6690090.7 17.7, 355890 6690085.3 17.7, 355888.8 6690084.5 17.7, 355887 6690083.3 17.7, 355882.8 6690089.4 17.7))
BATIMENT0000000304020525;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;4.0;20;20;12.8;12.6;25.5;27.1;15.8;Cadastre;A 1.0;POLYGON Z ((355903.8 6690080.5 25.5, 355901.2 6690083.5 25.5, 355898.9 6690085.8 25.5, 355898 6690086.9 25.5, 355896.3 6690089.7 25.5, 355894.4 6690094 25.5, 355904.1 6690097.9 25.5, 355908.4 6690089.7 25.5, 355911.9 6690091.4 25.5, 355914.7 6690085.7 25.5, 355903.7 6690080.4 25.5, 355903.8 6690080.5 25.5))
BATIMENT0000000304020531;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.7;12.7;18.5;25.7;14.3;Cadastre;;POLYGON Z ((355894.6 6690088.3 18.5, 355891.1 6690092.7 18.5, 355894.4 6690094 18.5, 355896.3 6690089.7 18.5, 355894.6 6690088.3 18.5))
BATIMENT0000000304020837;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;10.9;13.0;23.9;26.1;13.8;Cadastre;A 1.0;POLYGON Z ((355850.2 6690098.5 23.9, 355857.4 6690101.9 23.9, 355860 6690103.1 23.9, 355866.1 6690091.2 23.9, 355856.4 6690086.7 23.9, 355850.2 6690098.5 23.9))
BATIMENT0000000304020835;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;13.0;3.0;20;20;8.0;10.2;18.2;24.7;14.5;Cadastre;C 0.7;POLYGON Z ((355831.5 6690086.7 18.2, 355823.3 6690102.2 18.2, 355818.2 6690111.2 18.2, 355817.9 6690111.7 18.2, 355818.4 6690112 18.2, 355826.8 6690117.5 18.2, 355834.5 6690122.4 18.2, 355839.5 6690115.3 18.2, 355832 6690110.5 18.2, 355830.6 6690112.5 18.2, 355825.3 6690109.2 18.2, 355827.4 6690105.7 18.2, 355826 6690104.9 18.2, 355836.1 6690086.5 18.2, 355839.6 6690088.2 18.2, 355830.2 6690105.6 18.2, 355833.8 6690107.8 18.2, 355834.2 6690108.2 18.2, 355842 6690096.3 18.2, 355846.6 6690099.1 18.2, 355842.9 6690104.9 18.2, 355845.3 6690106.4 18.2, 355847.6 6690102.7 18.2, 355850.2 6690098.5 18.2, 355856.4 6690086.7 18.2, 355848.5 6690083 18.2, 355848 6690083.5 18.2, 355835.9 6690077.9 18.2, 355831.5 6690086.7 18.2))
BATIMENT0000000303967614;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;8.3;13.6;21.9;24.2;19.3;Cadastre;A 1.0;POLYGON Z ((356003.2 6690094 21.9, 355996.7 6690097.6 21.9, 355998.9 6690102.5 21.9, 356007.6 6690096.9 21.9, 356010.4 6690099.5 21.9, 356012.3 6690097.5 21.9, 356006.6 6690091.9 21.9, 356003.2 6690094 21.9))
BATIMENT0000000303967706;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;16.6;21.5;23.7;19.0;Cadastre;;POLYGON Z ((356003.1 6690103.8 21.5, 356001.1 6690105.8 21.5, 356002.2 6690107.3 21.5, 356004.6 6690105.1 21.5, 356003.1 6690103.8 21.5))
BATIMENT0000000303967709;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;19.1;22.5;23.2;19.9;Cadastre;;POLYGON Z ((356022.1 6690103.7 22.5, 356019.3 6690106.7 22.5, 356021.8 6690109.1 22.5, 356023.3 6690107.7 22.5, 356024.7 6690106.1 22.5, 356022.1 6690103.7 22.5))
BATIMENT0000000303967619;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;4.0;20;20;15.3;12.7;28.0;31.1;19.0;Cadastre;A 1.0;POLYGON Z ((355990.8 6690115.6 28, 355998.1 6690117.3 28, 356003.5 6690110.9 28, 356002.2 6690107.3 28, 356001.1 6690105.8 28, 355993.4 6690104.5 28, 355982.6 6690102.6 28, 355982 6690102.6 28, 355980.2 6690113.1 28, 355990.8 6690115.6 28), (355992.4 6690106.7 28, 355994.8 6690107.1 28, 355994.9 6690106.8 28, 355998 6690107.5 28, 355997.4 6690110.1 28, 355999.2 6690110.5 28, 355998.9 6690112.6 28, 355991.6 6690111.3 28, 355992.4 6690106.7 28))
BATIMENT0000000303967698;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;18.0;3.0;10;20;10.2;19.2;29.4;33.5;20.8;Cadastre;A 1.0;POLYGON Z ((356043.2 6690098.9 29.4, 356045 6690100.9 29.4, 356036.5 6690108.6 29.4, 356027.6 6690116.4 29.4, 356030.6 6690119.1 29.4, 356028 6690121.9 29.4, 356034 6690127.5 29.4, 356040.2 6690121.9 29.4, 356034.6 6690115.1 29.4, 356045.9 6690104.9 29.4, 356052.2 6690111.2 29.4, 356057.3 6690106.6 29.4, 356055.7 6690104.8 29.4, 356048.8 6690096.7 29.4, 356047.2 6690095.1 29.4, 356043.2 6690098.9 29.4))
BATIMENT0000000303967708;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;2.0;09;02;6.9;18.6;25.6;31.0;20.2;Cadastre;C 0.3;POLYGON Z ((356034 6690127.5 25.6, 356028 6690121.9 25.6, 356030.6 6690119.1 25.6, 356027.6 6690116.4 25.6, 356036.5 6690108.6 25.6, 356030.4 6690103.5 25.6, 356025.1 6690109.2 25.6, 356023.3 6690107.7 25.6, 356021.8 6690109.1 25.6, 356020.7 6690110.2 25.6, 356018.5 6690112.5 25.6, 356025 6690118.7 25.6, 356027.6 6690121.5 25.6, 356027 6690122.1 25.6, 356028.6 6690123.7 25.6, 356027 6690125 25.6, 356026.8 6690128.8 25.6, 356029.6 6690131.4 25.6, 356034 6690127.5 25.6))
BATIMENT0000000304020885;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;12.0;5.0;10;20;15.6;12.7;28.3;30.0;14.7;Cadastre;A 1.0;POLYGON Z ((355980.2 6690113.1 28.3, 355977.2 6690129.9 28.3, 355981.2 6690134.5 28.3, 355987.6 6690128.7 28.3, 355989.3 6690127 28.3, 355986.2 6690125.9 28.3, 355987.6 6690119.3 28.3, 355989.8 6690119.7 28.3, 355990.8 6690115.6 28.3, 355980.2 6690113.1 28.3))
BATIMENT0000000303967615;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;38.0;5.0;09;02;16.2;12.7;28.9;33.7;19.3;Cadastre;C 0.9;POLYGON Z ((356009.1 6690138.7 28.9, 356009.6 6690138 28.9, 356009.6 6690137.3 28.9, 356009.4 6690137 28.9, 356010.4 6690135.7 28.9, 356004 6690128.5 28.9, 356002.8 6690129.5 28.9, 356002.6 6690129.5 28.9, 356002.4 6690129.1 28.9, 356001.5 6690129 28.9, 356000.8 6690129.4 28.9, 355995.7 6690123.6 28.9, 355996.9 6690123.1 28.9, 356002.5 6690118 28.9, 356002.7 6690118.1 28.9, 356014.4 6690107.2 28.9, 356016.1 6690105.4 28.9, 356010.4 6690099.5 28.9, 356004.6 6690105.1 28.9, 356002.2 6690107.3 28.9, 356003.5 6690110.9 28.9, 355998.1 6690117.3 28.9, 355989.3 6690127 28.9, 355987.6 6690128.7 28.9, 355997.5 6690140.2 28.9, 356001.4 6690144.9 28.9, 356005.4 6690149.5 28.9, 355999.5 6690154.9 28.9, 356001.9 6690157.6 28.9, 356015.2 6690145.1 28.9, 356009.1 6690138.7 28.9))
BATIMENT0000000303967707;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;4.4;19.0;23.4;28.2;20.2;Cadastre;C 0.3;POLYGON Z ((356034.3 6690131.7 23.4, 356037.9 6690135.3 23.4, 356032.7 6690140.1 23.4, 356032.8 6690140.7 23.4, 356036.1 6690144.3 23.4, 356041.1 6690140 23.4, 356043.1 6690138.4 23.4, 356044.2 6690137.5 23.4, 356049.6 6690133.1 23.4, 356050.2 6690132.6 23.4, 356048 6690130.1 23.4, 356045.8 6690131.9 23.4, 356044.1 6690130.1 23.4, 356043.6 6690130.1 23.4, 356042.3 6690131.2 23.4, 356040.9 6690129.7 23.4, 356042.4 6690128.3 23.4, 356040.5 6690126.1 23.4, 356042.5 6690124.2 23.4, 356040.2 6690121.9 23.4, 356034 6690127.5 23.4, 356029.6 6690131.4 23.4, 356034.3 6690131.7 23.4))
BATIMENT0000000303967617;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;5.0;12;30;15.2;13.5;28.7;33.2;15.3;Cadastre;A 1.0;POLYGON Z ((355987.6 6690128.7 28.7, 355981.2 6690134.5 28.7, 355999.5 6690154.9 28.7, 356005.4 6690149.5 28.7, 356001.4 6690144.9 28.7, 356000.1 6690146 28.7, 355996 6690141.6 28.7, 355997.5 6690140.2 28.7, 355987.6 6690128.7 28.7))
BATIMENT0000000304020839;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;12;20;13.2;11.0;24.2;25.8;13.5;Cadastre;A 1.0;POLYGON Z ((355863.5 6690105 24.2, 355869.8 6690107.9 24.2, 355875.9 6690095.9 24.2, 355869.6 6690093 24.2, 355863.5 6690105 24.2))
BATIMENT0000000304020838;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1878-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;20;7.8;11.1;19.0;26.0;13.8;Cadastre;A 1.0;POLYGON Z ((355860 6690103.1 19, 355858.5 6690105.9 19, 355858.5 6690107 19, 355858.6 6690107.1 19, 355857 6690110.4 19, 355859.9 6690111.8 19, 355863.5 6690105 19, 355869.6 6690093 19, 355866.1 6690091.2 19, 355860 6690103.1 19))
BATIMENT0000000304020836;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;10.8;14.7;21.7;12.1;Cadastre;;POLYGON Z ((355847.6 6690102.7 14.7, 355855.3 6690106.3 14.7, 355857.4 6690101.9 14.7, 355850.2 6690098.5 14.7, 355847.6 6690102.7 14.7))
BATIMENT0000000304020842;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;15;20;13.1;10.0;23.2;25.7;13.1;Cadastre;A 1.0;POLYGON Z ((355876.2 6690106.9 23.2, 355875 6690109.2 23.2, 355877.5 6690110.4 23.2, 355875.7 6690114.5 23.2, 355877 6690115.4 23.2, 355880.3 6690117.3 23.2, 355884.6 6690110.3 23.2, 355886 6690105.6 23.2, 355888.7 6690100.6 23.2, 355880.4 6690097.6 23.2, 355876.2 6690106.9 23.2))
BATIMENT0000000304020844;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;10.5;10.3;20.8;23.7;12.9;Cadastre;A 1.0;POLYGON Z ((355886.3 6690110.8 20.8, 355888.5 6690111.8 20.8, 355889.4 6690110.2 20.8, 355893.8 6690112.1 20.8, 355896.5 6690107.5 20.8, 355898.2 6690103.8 20.8, 355888.7 6690100.6 20.8, 355886 6690105.6 20.8, 355884.6 6690110.3 20.8, 355880.3 6690117.3 20.8, 355877.9 6690121.6 20.8, 355878.8 6690122.3 20.8, 355886.3 6690110.8 20.8))
BATIMENT0000000304020840;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;4.0;14;23;12.3;8.3;20.7;25.0;13.1;Cadastre;C 1.0;POLYGON Z ((355870.8 6690117.8 20.7, 355869.1 6690116.8 20.7, 355875.3 6690106.5 20.7, 355876.2 6690106.9 20.7, 355880.4 6690097.6 20.7, 355875.9 6690095.9 20.7, 355869.8 6690107.9 20.7, 355859 6690124.7 20.7, 355855.6 6690128.8 20.7, 355860.4 6690132 20.7, 355863.8 6690127.9 20.7, 355864.2 6690128.1 20.7, 355870.8 6690117.8 20.7))
BATIMENT0000000304020841;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;90;90;15.0;7.9;23.0;25.0;11.0;Cadastre;A 1.0;POLYGON Z ((355876.5 6690116.3 23, 355875.7 6690115.9 23, 355875.1 6690116.8 23, 355872.3 6690115.2 23, 355870.8 6690117.8 23, 355864.2 6690128.1 23, 355870.9 6690132.5 23, 355873.5 6690129 23, 355877.9 6690121.6 23, 355880.3 6690117.3 23, 355877 6690115.4 23, 355876.5 6690116.3 23))
BATIMENT0000000304020843;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;6.1;7.3;13.5;21.7;10.6;Cadastre;A 1.0;POLYGON Z ((355874.9 6690129.1 13.5, 355878.9 6690122.5 13.5, 355878.8 6690122.3 13.5, 355877.9 6690121.6 13.5, 355873.5 6690129 13.5, 355870.9 6690132.5 13.5, 355870.9 6690132.6 13.5, 355866.7 6690137.6 13.5, 355869.5 6690139.4 13.5, 355873.6 6690134.4 13.5, 355876.8 6690136.7 13.5, 355880 6690132.7 13.5, 355874.9 6690129.1 13.5))
BATIMENT0000000304020967;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2022-07-30 23:16:38;2003-01-01;;;;BDParcellaire;5.0;Pas de Z;9999.0;0.0;1.0;05;20;;9.7;;;;Cadastre;C 0.2;POLYGON Z ((355849.6 6690145 -1000, 355845.2 6690141.7 -1000, 355839.7 6690148.7 -1000, 355844.6 6690151 -1000, 355849.6 6690145 -1000))
BATIMENT0000000304020846;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;54.0;6.0;00;00;7.0;9.1;16.2;29.5;12.2;Cadastre;A 1.0;POLYGON Z ((355878.4 6690149.3 16.2, 355877.2 6690148.6 16.2, 355875.1 6690153.3 16.2, 355873.7 6690152.5 16.2, 355867.1 6690160.4 16.2, 355866.2 6690161.4 16.2, 355888.5 6690172.3 16.2, 355889.9 6690170.9 16.2, 355895.3 6690165.9 16.2, 355897.3 6690164 16.2, 355896.3 6690163.5 16.2, 355898.4 6690158.8 16.2, 355901.3 6690160.2 16.2, 355909.6 6690150.8 16.2, 355911.5 6690150.7 16.2, 355913 6690148.7 16.2, 355913.4 6690148.9 16.2, 355916 6690146.5 16.2, 355925.9 6690137.2 16.2, 355924.8 6690136.7 16.2, 355918.6 6690133.7 16.2, 355904 6690126.6 16.2, 355894.4 6690121.9 16.2, 355878.4 6690149.3 16.2))
BATIMENT0000000304020845;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;117.0;6.0;35;09;13.4;12.1;25.5;29.5;12.6;Cadastre;A 1.0;POLYGON Z ((355896.5 6690107.5 25.5, 355893.8 6690112.1 25.5, 355890.7 6690117.7 25.5, 355890.2 6690117.5 25.5, 355889.1 6690119.3 25.5, 355894.4 6690121.9 25.5, 355904 6690126.6 25.5, 355918.6 6690133.7 25.5, 355924.8 6690136.7 25.5, 355927.2 6690134.2 25.5, 355927.6 6690134.9 25.5, 355928.1 6690135.1 25.5, 355933.2 6690130.3 25.5, 355939.1 6690124.8 25.5, 355938.7 6690123.8 25.5, 355928.4 6690118.7 25.5, 355898.2 6690103.8 25.5, 355896.5 6690107.5 25.5))
BATIMENT0000000304020858;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;46.0;6.0;00;00;16.7;11.2;27.9;31.6;15.6;Cadastre;A 1.0;POLYGON Z ((355938 6690142 27.9, 355943.4 6690147.9 27.9, 355944.8 6690146.8 27.9, 355948.7 6690151.2 27.9, 355951.5 6690148.8 27.9, 355956.9 6690154.8 27.9, 355959 6690152.9 27.9, 355968.6 6690163.8 27.9, 355981.6 6690150.9 27.9, 355971.6 6690139.8 27.9, 355963.1 6690136.4 27.9, 355955.3 6690132.5 27.9, 355950.8 6690130.3 27.9, 355938 6690142 27.9))
BATIMENT0000000304020857;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;5.0;00;00;3.3;12.1;15.4;30.5;15.8;Cadastre;A 1.0;POLYGON Z ((355968.6 6690163.8 15.4, 355963.3 6690169.1 15.4, 355962.1 6690170.7 15.4, 355958 6690173.9 15.4, 355962.2 6690179.4 15.4, 355966.4 6690176 15.4, 355972 6690170.3 15.4, 355977.7 6690176.7 15.4, 355981 6690173.5 15.4, 355991.4 6690161.9 15.4, 355986 6690155.7 15.4, 355981.6 6690150.9 15.4, 355968.6 6690163.8 15.4))
BATIMENT0000000029192391;Indifférenciée;Commercial et services;;Non;En service;2006-10-04 09:41:10;2019-07-01 11:22:15;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;4.7;11.6;;;;Imagerie aérienne;;POLYGON Z ((355930 6690165.2 16.3, 355927.5 6690166.1 16.3, 355925 6690168 16.3, 355924.2 6690170.9 16.3, 355924.6 6690174.5 16.3, 355925.8 6690176.5 16.3, 355928.4 6690177.9 16.3, 355932.4 6690178.2 16.3, 355934.8 6690177.6 16.3, 355937 6690175.7 16.3, 355938 6690172.6 16.3, 355937.7 6690169.6 16.3, 355936 6690167.6 16.3, 355933.5 6690165.6 16.3, 355930 6690165.2 16.3))
BATIMENT0000000304020855;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 21:01:44;2019-07-01 11:22:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.0;14.5;16.5;19.0;15.4;Cadastre;;POLYGON Z ((355978.9 6690178.1 16.5, 355982.4 6690175.1 16.5, 355981 6690173.5 16.5, 355977.7 6690176.7 16.5, 355978.9 6690178.1 16.5))
BATIMENT0000000304020963;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;8.5;13.9;22.5;24.6;15.7;Cadastre;C 0.7;POLYGON Z ((355979.1 6690202.4 22.5, 355984.2 6690208.1 22.5, 355988.3 6690204.6 22.5, 355988.2 6690204.4 22.5, 355983.5 6690198.7 22.5, 355979.1 6690202.4 22.5))
BATIMENT0000000304020854;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-07-01 11:22:15;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;10.3;19.0;25.6;15.4;Cadastre;;POLYGON Z ((355976.7 6690180.4 19, 355972.2 6690174.9 19, 355964.2 6690181.4 19, 355963.4 6690180.7 19, 355937.1 6690202.2 19, 355936.9 6690202 19, 355936.7 6690201.7 19, 355936.4 6690201.4 19, 355936.1 6690201.2 19, 355935.8 6690201 19, 355935.4 6690200.8 19, 355935.1 6690200.6 19, 355934.7 6690200.5 19, 355934.3 6690200.4 19, 355934 6690200.3 19, 355933.6 6690200.3 19, 355933.2 6690200.3 19, 355932.8 6690200.4 19, 355932.4 6690200.4 19, 355932.1 6690200.6 19, 355931.7 6690200.7 19, 355931.4 6690200.9 19, 355931 6690201.1 19, 355930.7 6690201.3 19, 355930.4 6690201.6 19, 355930.2 6690201.9 19, 355929.9 6690202.2 19, 355929.7 6690202.5 19, 355929.5 6690202.8 19, 355929.4 6690203.2 19, 355929.3 6690203.6 19, 355929.2 6690203.9 19, 355929.2 6690204.3 19, 355929.1 6690204.7 19, 355929.2 6690205.1 19, 355929.2 6690205.5 19, 355929.3 6690205.8 19, 355929.4 6690206.2 19, 355929.6 6690206.6 19, 355929.8 6690206.9 19, 355930 6690207.2 19, 355930.2 6690207.5 19, 355930.4 6690207.7 19, 355924.4 6690212.6 19, 355923.4 6690211.5 19, 355898.3 6690180.8 19, 355882.5 6690212.9 19, 355908.5 6690225.5 19, 355913.1 6690221.8 19, 355919.5 6690229.7 19, 355921.2 6690231.8 19, 355921.6 6690232.2 19, 355932.9 6690223 19, 355930.9 6690220.5 19, 355930.4 6690220 19, 355955.9 6690199.1 19, 355956.2 6690199.4 19, 355956.4 6690199.5 19, 355956.7 6690199.7 19, 355956.8 6690199.8 19, 355956.9 6690199.9 19, 355957.4 6690200 19, 355957.5 6690200.1 19, 355957.6 6690200.1 19, 355957.9 6690200.2 19, 355958.2 6690200.2 19, 355958.6 6690200.2 19, 355958.9 6690200.2 19, 355959.2 6690200.2 19, 355959.3 6690200.1 19, 355959.6 6690200.1 19, 355960.2 6690199.8 19, 355960.6 6690199.6 19, 355968.9 6690192.8 19, 355968.6 6690192.5 19, 355970.7 6690190.7 19, 355971.1 6690191.2 19, 355971.6 6690190.8 19, 355979.4 6690184.4 19, 355981.5 6690186.9 19, 355982 6690186.5 19, 355988.2 6690181.5 19, 355985.4 6690178.3 19, 355982.4 6690175.1 19, 355978.9 6690178.1 19, 355976.7 6690180.4 19))
BATIMENT0000000304020957;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;7.6;13.6;21.2;24.9;15.7;Cadastre;A 1.0;POLYGON Z ((355973.9 6690206.6 21.2, 355979.6 6690213.1 21.2, 355983.5 6690217.9 21.2, 355986.3 6690215.6 21.2, 355982.7 6690211.3 21.2, 355984.9 6690209.1 21.2, 355984.2 6690208.1 21.2, 355979.1 6690202.4 21.2, 355973.9 6690206.6 21.2))
BATIMENT0000000304020954;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;19;20;11.5;13.3;24.8;27.4;14.5;Cadastre;A 1.0;POLYGON Z ((355973.9 6690206.6 24.8, 355968.8 6690210.9 24.8, 355974.2 6690217.4 24.8, 355976.5 6690215.7 24.8, 355979.6 6690213.1 24.8, 355973.9 6690206.6 24.8))
BATIMENT0000000304020952;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;9.7;12.9;22.7;25.5;13.6;Cadastre;A 1.0;POLYGON Z ((355974.2 6690217.4 22.7, 355968.8 6690210.9 22.7, 355964.6 6690214.3 22.7, 355970.3 6690221.2 22.7, 355974.5 6690217.8 22.7, 355974.2 6690217.4 22.7))
BATIMENT0000000303967710;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2002-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;14.8;21.6;28.2;19.4;Cadastre;A 1.0;POLYGON Z ((356015.2 6690145.1 21.6, 356001.9 6690157.6 21.6, 356010 6690166.7 21.6, 356018.8 6690159.2 21.6, 356029.3 6690150.2 21.6, 356020.6 6690140.1 21.6, 356015.2 6690145.1 21.6))
BATIMENT0000000303967713;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;18.1;23.3;25.0;20.4;Cadastre;;POLYGON Z ((356038.6 6690160.1 23.3, 356042.8 6690156.5 23.3, 356046.2 6690153.6 23.3, 356048.7 6690151.4 23.3, 356052.1 6690148.6 23.3, 356048.1 6690144.1 23.3, 356042.6 6690148.7 23.3, 356042.3 6690148.6 23.3, 356020.2 6690167.5 23.3, 356024.1 6690172.4 23.3, 356038.6 6690160.1 23.3))
BATIMENT0000000303967717;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;90;20;3.7;19.5;23.3;24.5;20.3;Cadastre;C 0.2;POLYGON Z ((356042.8 6690156.5 23.3, 356044.2 6690158.1 23.3, 356041.7 6690160.2 23.3, 356041.4 6690159.9 23.3, 356039.8 6690161.5 23.3, 356042.7 6690164.9 23.3, 356050.3 6690158.6 23.3, 356049.6 6690157.7 23.3, 356049.3 6690157.4 23.3, 356046.2 6690153.6 23.3, 356042.8 6690156.5 23.3))
BATIMENT0000000303967711;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;13.9;14.1;28.0;31.4;18.9;Cadastre;;POLYGON Z ((356018 6690165.1 28, 356021.4 6690162.4 28, 356018.8 6690159.2 28, 356010 6690166.7 28, 356018.9 6690176.8 28, 356024.1 6690172.4 28, 356020.2 6690167.5 28, 356018 6690165.1 28))
BATIMENT0000000304020856;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;10;20;12.9;14.8;27.7;30.4;15.4;Cadastre;A 1.0;POLYGON Z ((355983.1 6690173.2 27.7, 355986.5 6690177.1 27.7, 355996.2 6690167.3 27.7, 355992.3 6690162.9 27.7, 355983.1 6690173.2 27.7))
BATIMENT0000000303967712;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;00;00;10.6;16.1;26.7;30.0;18.9;Cadastre;C 0.7;POLYGON Z ((356018.9 6690176.8 26.7, 356024.2 6690182.6 26.7, 356029 6690178.2 26.7, 356028.2 6690177.2 26.7, 356024.1 6690172.4 26.7, 356018.9 6690176.8 26.7))
BATIMENT0000000303967723;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;5.0;10;20;16.3;16.7;33.0;34.7;20.0;Cadastre;A 1.0;POLYGON Z ((356029 6690178.2 33, 356024.2 6690182.6 33, 356031.4 6690192.6 33, 356040.3 6690183.9 33, 356040.7 6690183.6 33, 356032.8 6690174.6 33, 356029 6690178.2 33))
BATIMENT0000000303967736;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;15;20;12.3;15.3;27.7;30.6;16.7;Cadastre;A 1.0;POLYGON Z ((356004.7 6690181.3 27.7, 356006 6690182.8 27.7, 356001 6690187.1 27.7, 356004.3 6690191.6 27.7, 356006.1 6690193.7 27.7, 356011.4 6690189 27.7, 356010.6 6690187.8 27.7, 356013.3 6690185.4 27.7, 356007.6 6690178.9 27.7, 356004.7 6690181.3 27.7))
BATIMENT0000000303967724;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;5.0;12;20;14.1;17.3;31.5;34.7;20.4;Cadastre;A 1.0;POLYGON Z ((356040.8 6690205.9 31.5, 356044.5 6690202.6 31.5, 356043.7 6690201.1 31.5, 356046.8 6690199 31.5, 356050 6690196.9 31.5, 356041.9 6690186.1 31.5, 356043.2 6690184.9 31.5, 356044.5 6690185.4 31.5, 356048.5 6690181.9 31.5, 356046.1 6690178.7 31.5, 356040.7 6690183.6 31.5, 356040.3 6690183.9 31.5, 356031.4 6690192.6 31.5, 356040.8 6690205.9 31.5))
BATIMENT0000000303967627;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.9;14.5;22.4;24.6;15.4;Cadastre;A 1.0;POLYGON Z ((355998.6 6690199.6 22.4, 355996.5 6690196.8 22.4, 356001.1 6690192.9 22.4, 355997 6690187.6 22.4, 355989.9 6690193.4 22.4, 355994.2 6690198.7 22.4, 355995.8 6690200.7 22.4, 355996.3 6690201.3 22.4, 355998.6 6690199.6 22.4))
BATIMENT0000000303969039;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;20.5;23.3;27.2;22.3;Cadastre;;POLYGON Z ((356239.2 6690178.6 23.3, 356275.1 6690153.5 23.3, 356272.8 6690150.3 23.3, 356262.5 6690157.5 23.3, 356256.5 6690161.6 23.3, 356248.8 6690166.9 23.3, 356241.9 6690171.7 23.3, 356240.4 6690172.8 23.3, 356236.8 6690175.3 23.3, 356238.1 6690177.1 23.3, 356239.2 6690178.6 23.3))
BATIMENT0000000303969027;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.8;21.6;27.4;27.9;22.6;Cadastre;;POLYGON Z ((356197.4 6690166.1 27.4, 356199.1 6690168.3 27.4, 356201.9 6690166.3 27.4, 356201.8 6690166.1 27.4, 356205.5 6690163.6 27.4, 356204 6690161.5 27.4, 356197.4 6690166.1 27.4))
BATIMENT0000000303969044;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;21.2;26.2;27.0;22.1;Cadastre;;POLYGON Z ((356241.1 6690170.5 26.2, 356239.5 6690171.6 26.2, 356240.4 6690172.8 26.2, 356241.9 6690171.7 26.2, 356241.1 6690170.5 26.2))
BATIMENT0000000303969026;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;7.3;22.3;29.6;32.1;22.8;Cadastre;C 0.6;POLYGON Z ((356212.8 6690174.2 29.6, 356213.8 6690175.5 29.6, 356217 6690180.2 29.6, 356219.3 6690178.6 29.6, 356229.9 6690171.1 29.6, 356232.4 6690169.3 29.6, 356231 6690167.3 29.6, 356228.3 6690163.5 29.6, 356224.5 6690166 29.6, 356223.6 6690164.9 29.6, 356215.8 6690170.4 29.6, 356216.6 6690171.6 29.6, 356212.9 6690174.2 29.6, 356212.8 6690174.2 29.6))
BATIMENT0000000303969014;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.1;22.3;28.5;33.2;22.6;Cadastre;;POLYGON Z ((356200.4 6690173.9 28.5, 356199.9 6690175.5 28.5, 356200.7 6690176.4 28.5, 356205.8 6690171.7 28.5, 356204.8 6690170.2 28.5, 356200.2 6690173.6 28.5, 356200.4 6690173.9 28.5))
BATIMENT0000000303969137;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.6;22.0;25.6;;;Cadastre;;POLYGON Z ((356310.7 6690176.7 25.6, 356311.9 6690175.8 25.6, 356311.1 6690174.6 25.6, 356309.8 6690175.4 25.6, 356310.7 6690176.7 25.6))
BATIMENT0000000303969015;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1840-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;10;20;12.0;21.6;33.6;37.6;22.6;Cadastre;C 0.9;POLYGON Z ((356199.9 6690175.5 33.6, 356200.4 6690173.9 33.6, 356200.2 6690173.6 33.6, 356198.5 6690171.1 33.6, 356197.1 6690171.2 33.6, 356194.9 6690167.9 33.6, 356184.8 6690174.8 33.6, 356191.6 6690185.9 33.6, 356202 6690178.3 33.6, 356200.7 6690176.4 33.6, 356199.9 6690175.5 33.6))
BATIMENT0000000303969016;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;10;20;8.6;22.3;31.0;38.6;22.7;Cadastre;A 1.0;POLYGON Z ((356207.8 6690186.7 31, 356206.3 6690184.7 31, 356206.4 6690184.5 31, 356206.4 6690184.3 31, 356206.4 6690184.2 31, 356206.4 6690184.1 31, 356206.4 6690184 31, 356206.4 6690183.9 31, 356206.3 6690183.7 31, 356206.3 6690183.6 31, 356206.2 6690183.6 31, 356206.2 6690183.5 31, 356206.1 6690183.5 31, 356205.9 6690183.4 31, 356205.7 6690183.3 31, 356205.6 6690183.3 31, 356205.5 6690183.3 31, 356205.4 6690183.3 31, 356203.2 6690180.1 31, 356206.1 6690178.1 31, 356207.4 6690179.8 31, 356210.3 6690177.9 31, 356213.5 6690182.7 31, 356217 6690180.2 31, 356213.8 6690175.5 31, 356212.8 6690174.2 31, 356212.9 6690174.2 31, 356207.3 6690166.3 31, 356205.5 6690163.6 31, 356201.8 6690166.1 31, 356201.9 6690166.3 31, 356204.8 6690170.2 31, 356205.8 6690171.7 31, 356200.7 6690176.4 31, 356202 6690178.3 31, 356191.6 6690185.9 31, 356196.9 6690194.5 31, 356207.8 6690186.7 31))
BATIMENT0000000303969041;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;21.4;27.8;31.7;23.0;Cadastre;;POLYGON Z ((356233.5 6690187.7 27.8, 356234.7 6690189.5 27.8, 356241.7 6690184.5 27.8, 356240.7 6690183 27.8, 356233.5 6690187.7 27.8))
BATIMENT0000000303967729;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;10.4;22.5;32.9;33.0;22.9;Cadastre;;POLYGON Z ((356177.8 6690189.5 32.9, 356170.3 6690194.2 32.9, 356184.1 6690216.5 32.9, 356191.6 6690212.1 32.9, 356177.8 6690189.5 32.9))
BATIMENT0000000303969042;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;21.9;28.0;32.5;23.0;Cadastre;;POLYGON Z ((356226.2 6690222.2 28, 356243 6690210.4 28, 356236.5 6690201.2 28, 356243.8 6690196.1 28, 356244.1 6690196.5 28, 356244.7 6690196 28, 356244.5 6690195.8 28, 356248.6 6690193.1 28, 356248.8 6690193.3 28, 356249.3 6690192.8 28, 356249 6690192.5 28, 356257 6690186.7 28, 356254.9 6690183.8 28, 356254.4 6690183.1 28, 356231.6 6690199.3 28, 356238.6 6690209.3 28, 356221.6 6690221.5 28, 356229.1 6690232.1 28, 356231.9 6690230.1 28, 356226.2 6690222.2 28))
BATIMENT0000000303969017;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;21.1;30.0;40.4;23.5;Cadastre;;POLYGON Z ((356306.4 6690132.7 30, 356278.2 6690153.4 30, 356279.3 6690155.2 30, 356240.7 6690183 30, 356241.7 6690184.5 30, 356234.7 6690189.5 30, 356227.1 6690194.7 30, 356226.1 6690193.5 30, 356210.2 6690204.8 30, 356207 6690199.7 30, 356228.9 6690184.5 30, 356228.6 6690183.8 30, 356238.1 6690177.1 30, 356236.8 6690175.3 30, 356232.4 6690169.3 30, 356229.9 6690171.1 30, 356219.3 6690178.6 30, 356217 6690180.2 30, 356213.5 6690182.7 30, 356207.8 6690186.7 30, 356196.9 6690194.5 30, 356261.1 6690299.8 30, 356269.6 6690294.6 30, 356268.3 6690292.6 30, 356268.8 6690292.4 30, 356260 6690277.9 30, 356259.6 6690278.2 30, 356258.7 6690276.7 30, 356258.2 6690277 30, 356256.7 6690274.7 30, 356276.4 6690261.6 30, 356290.7 6690281.7 30, 356307.8 6690268.9 30, 356315.5 6690263.2 30, 356323.1 6690257.5 30, 356328.7 6690253.4 30, 356333.9 6690249.5 30, 356334.5 6690249 30, 356354.3 6690276 30, 356366.9 6690266.3 30, 356367.7 6690261.3 30, 356354 6690242.3 30, 356348.8 6690234.7 30, 356346.6 6690231.5 30, 356341.4 6690224.4 30, 356331.5 6690210 30, 356327.6 6690204.8 30, 356314.4 6690214.1 30, 356315.1 6690215.1 30, 356303.4 6690223 30, 356302.9 6690222.1 30, 356288.8 6690232.3 30, 356265.6 6690248.1 30, 356259.4 6690239.3 30, 356242.5 6690251.2 30, 356235 6690240.6 30, 356237.7 6690238.8 30, 356238.1 6690236.2 30, 356234.1 6690230.6 30, 356231.9 6690230.1 30, 356229.1 6690232.1 30, 356221.6 6690221.5 30, 356238.6 6690209.3 30, 356231.6 6690199.3 30, 356254.4 6690183.1 30, 356254.9 6690183.8 30, 356292.9 6690156.8 30, 356295 6690159.7 30, 356314.1 6690146.3 30, 356309.2 6690133 30, 356306.4 6690132.7 30), (356253.3 6690254.6 30, 356255 6690257 30, 356250.1 6690260.5 30, 356248.2 6690258 30, 356250.1 6690256.7 30, 356253.3 6690254.6 30))
BATIMENT0000000303969040;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.5;22.2;27.7;31.9;23.0;Cadastre;;POLYGON Z ((356287 6690229.8 27.7, 356266.6 6690244 27.7, 356260.4 6690234.9 27.7, 356243.4 6690246.8 27.7, 356237.7 6690238.8 27.7, 356235 6690240.6 27.7, 356242.5 6690251.2 27.7, 356259.4 6690239.3 27.7, 356265.6 6690248.1 27.7, 356288.8 6690232.3 27.7, 356287 6690229.8 27.7))
BATIMENT0000000303969050;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;1.0;00;00;4.4;22.4;26.8;32.0;22.9;Cadastre;C 0.6;POLYGON Z ((356189.1 6690245.5 26.8, 356191 6690248.7 26.8, 356193.3 6690247.3 26.8, 356197.1 6690254.3 26.8, 356199 6690257.7 26.8, 356203.8 6690254.8 26.8, 356202.1 6690251.9 26.8, 356205.9 6690249.3 26.8, 356204.8 6690247.1 26.8, 356211.4 6690242.9 26.8, 356206.4 6690234.6 26.8, 356189.1 6690245.5 26.8))
BATIMENT0000000303969051;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;4.5;23.0;27.5;;;Cadastre;A 1.0;POLYGON Z ((356184.8 6690252.4 27.5, 356183 6690249.4 27.5, 356168 6690259 27.5, 356172.1 6690265.8 27.5, 356193.4 6690252.7 27.5, 356191 6690248.7 27.5, 356184.8 6690252.4 27.5))
BATIMENT0000000303969337;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;22.6;25.2;27.6;23.0;Cadastre;;POLYGON Z ((356212.5 6690256.8 25.2, 356211.9 6690258.4 25.2, 356213.3 6690260.9 25.2, 356219.4 6690257.6 25.2, 356217.3 6690254.1 25.2, 356212.5 6690256.8 25.2))
BATIMENT0000000303969338;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;02;09;2.3;22.6;25.0;26.7;23.1;Cadastre;C 0.4;POLYGON Z ((356214.4 6690262 25, 356216.3 6690265.4 25, 356222.3 6690262.2 25, 356220.2 6690258.9 25, 356214.4 6690262 25))
BATIMENT0000000303969340;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;02;09;6.0;22.5;28.5;31.2;23.1;Cadastre;A 0.5;POLYGON Z ((356222.4 6690270.6 28.5, 356223.1 6690273.7 28.5, 356226.5 6690272.6 28.5, 356225.5 6690268.8 28.5, 356222.4 6690270.6 28.5))
BATIMENT0000000303969339;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;8.5;22.4;31.0;32.9;23.2;Cadastre;;POLYGON Z ((356225.5 6690278.3 31, 356223.2 6690282.5 31, 356224.2 6690284.5 31, 356229.1 6690282 31, 356227.8 6690277.3 31, 356225.5 6690278.3 31))
BATIMENT0000000303969146;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;8.3;22.1;30.4;32.7;22.5;Cadastre;C 0.3;POLYGON Z ((356186.8 6690278.5 30.4, 356185.1 6690279.5 30.4, 356182.9 6690275.7 30.4, 356178 6690278.5 30.4, 356186 6690291.7 30.4, 356192.6 6690287.8 30.4, 356186.8 6690278.5 30.4))
BATIMENT0000000303967726;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.2;18.1;25.3;26.4;21.3;Cadastre;C 0.3;POLYGON Z ((356065 6690178.1 25.3, 356069.1 6690183.9 25.3, 356079.2 6690174.5 25.3, 356078.1 6690173 25.3, 356074.9 6690169 25.3, 356065 6690178.1 25.3))
BATIMENT0000000303967719;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;17.0;7.0;30;20;5.2;19.1;24.3;27.7;22.9;Cadastre;C 0.1;POLYGON Z ((356094.8 6690160 24.3, 356087.8 6690166.2 24.3, 356079.2 6690174.5 24.3, 356069.1 6690183.9 24.3, 356066.6 6690185.5 24.3, 356064.4 6690187.1 24.3, 356069.1 6690192.3 24.3, 356071.9 6690189.9 24.3, 356079.8 6690198.3 24.3, 356112.1 6690167.7 24.3, 356100.2 6690155 24.3, 356094.8 6690160 24.3))
BATIMENT0000000303967727;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;19.9;24.2;27.6;21.0;Cadastre;;POLYGON Z ((356069.1 6690183.9 24.2, 356065 6690178.1 24.2, 356062.6 6690180 24.2, 356066.6 6690185.5 24.2, 356069.1 6690183.9 24.2))
BATIMENT0000000303967725;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1976-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;33.0;7.0;30;20;20.6;17.7;38.4;38.9;20.4;Cadastre;C 0.2;POLYGON Z ((356061.9 6690221.8 38.4, 356071.6 6690217.4 38.4, 356074.8 6690216 38.4, 356058.1 6690191.3 38.4, 356050 6690196.9 38.4, 356046.8 6690199 38.4, 356061.9 6690221.8 38.4))
BATIMENT0000000303969742;Eglise;Religieux;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;11.7;22.4;34.1;;;Cadastre;;POLYGON Z ((356129 6690215.8 34.1, 356139.2 6690209.6 34.1, 356136.6 6690204.9 34.1, 356135.2 6690205.8 34.1, 356134.9 6690205.3 34.1, 356133.8 6690206 34.1, 356131.9 6690202.7 34.1, 356132.7 6690202.2 34.1, 356132.2 6690201.2 34.1, 356131.3 6690201.8 34.1, 356130.4 6690200.4 34.1, 356131.9 6690200.5 34.1, 356133.4 6690199.5 34.1, 356132.3 6690198.1 34.1, 356122 6690204.7 34.1, 356125.8 6690211 34.1, 356129 6690215.8 34.1))
BATIMENT0000000303969743;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.6;21.3;36.0;41.5;23.0;Cadastre;;POLYGON Z ((356139.1 6690257.1 36, 356197.3 6690221.4 36, 356191.6 6690212.1 36, 356184.1 6690216.5 36, 356174.7 6690222.2 36, 356161 6690200 36, 356170.3 6690194.2 36, 356177.8 6690189.5 36, 356171.1 6690178.6 36, 356148.6 6690192.5 36, 356146.6 6690189.1 36, 356147.6 6690188.3 36, 356147.2 6690187.6 36, 356146 6690188.4 36, 356142.1 6690182.2 36, 356143.2 6690181.5 36, 356142.7 6690180.6 36, 356141.5 6690181.3 36, 356141 6690180.5 36, 356138.4 6690182.6 36, 356137.5 6690181.4 36, 356137 6690181.7 36, 356137 6690182.5 36, 356135.2 6690181.9 36, 356133.4 6690183.1 36, 356133.4 6690184 36, 356131.6 6690185.1 36, 356130.6 6690184.9 36, 356128.8 6690185.9 36, 356128.7 6690187.1 36, 356126.9 6690188 36, 356126.3 6690187.6 36, 356124.3 6690189 36, 356123.8 6690190.9 36, 356123.4 6690190.3 36, 356122.8 6690190.7 36, 356123.4 6690191.8 36, 356117.4 6690195.6 36, 356116.6 6690194.5 36, 356115.6 6690195.1 36, 356116.1 6690196 36, 356105.1 6690202.8 36, 356139.1 6690257.1 36), (356128.7 6690219.9 36, 356151.3 6690206 36, 356165.3 6690228.1 36, 356142.5 6690242 36, 356128.7 6690219.9 36), (356114.2 6690211.9 36, 356117.2 6690209.9 36, 356116.3 6690208.3 36, 356122 6690204.7 36, 356132.3 6690198.1 36, 356133.4 6690199.5 36, 356133.4 6690198.3 36, 356134.6 6690197.4 36, 356136 6690197.8 36, 356137.9 6690196.6 36, 356138.2 6690195.1 36, 356139.6 6690194.2 36, 356140.8 6690194.9 36, 356142.5 6690193.7 36, 356142.7 6690192.4 36, 356143.2 6690192.1 36, 356149.4 6690201.7 36, 356144.8 6690204.8 36, 356142.5 6690201.1 36, 356136.6 6690204.9 36, 356139.2 6690209.6 36, 356129 6690215.8 36, 356125.8 6690211 36, 356120.2 6690214.6 36, 356119.1 6690212.9 36, 356116 6690214.9 36, 356114.2 6690211.9 36))
BATIMENT0000000303968990;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.0;18.0;26.0;27.7;18.0;Cadastre;A 1.0;POLYGON Z ((356044.9 6690250 26, 356050.1 6690259.1 26, 356050.9 6690258.6 26, 356058.7 6690254.3 26, 356056.4 6690250.2 26, 356054.1 6690251.4 26, 356051.5 6690246.2 26, 356046 6690249.3 26, 356044.9 6690250 26))
BATIMENT0000000303968991;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;7.6;18.1;25.7;;;Cadastre;A 1.0;POLYGON Z ((356057 6690269.9 25.7, 356061.1 6690264.9 25.7, 356058.5 6690260.1 25.7, 356059.8 6690259.4 25.7, 356060.3 6690257.2 25.7, 356058.7 6690254.3 25.7, 356050.9 6690258.6 25.7, 356057 6690269.9 25.7))
BATIMENT0000000303969083;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;4.9;21.0;25.9;;;Cadastre;A 1.0;POLYGON Z ((356098.1 6690262.2 25.9, 356090.9 6690266.3 25.9, 356099.3 6690280.9 25.9, 356106.4 6690276.7 25.9, 356098.1 6690262.2 25.9))
BATIMENT0000000303969086;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;19.5;23.1;25.0;19.9;Cadastre;;POLYGON Z ((356096.4 6690282.5 23.1, 356097.2 6690283.9 23.1, 356100.1 6690282.1 23.1, 356099.3 6690280.9 23.1, 356096.4 6690282.5 23.1))
BATIMENT0000000303969023;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;20.9;27.2;39.7;21.5;Cadastre;;POLYGON Z ((356350.5 6690233.4 27.2, 356348.6 6690230.2 27.2, 356346.6 6690231.5 27.2, 356348.8 6690234.7 27.2, 356350.5 6690233.4 27.2))
BATIMENT0000000303969136;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1967-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.9;21.5;25.4;27.1;21.5;Cadastre;C 0.3;POLYGON Z ((356376.4 6690239.1 25.4, 356384.4 6690245.5 25.4, 356389 6690239.8 25.4, 356380.9 6690233.4 25.4, 356376.4 6690239.1 25.4))
BATIMENT0000000303969049;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;3.5;21.7;25.2;;;Cadastre;C 0.7;POLYGON Z ((356397.4 6690244.5 25.2, 356392.9 6690241 25.2, 356388.3 6690246.7 25.2, 356387.7 6690247.5 25.2, 356392.3 6690251.2 25.2, 356392.6 6690250.9 25.2, 356394.3 6690252.2 25.2, 356394 6690252.6 25.2, 356394.6 6690252.9 25.2, 356401 6690244.7 25.2, 356401.6 6690245.1 25.2, 356413 6690230.5 25.2, 356410.1 6690228.2 25.2, 356397.4 6690244.5 25.2))
BATIMENT0000000303969342;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.3;19.3;21.7;24.0;20.0;Cadastre;;POLYGON Z ((356472.8 6690240.8 21.7, 356466.4 6690250.1 21.7, 356469.1 6690252 21.7, 356475.5 6690242.7 21.7, 356472.9 6690240.8 21.7, 356472.8 6690240.8 21.7))
BATIMENT0000000303969018;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;09;09;5.3;22.1;27.5;34.7;22.8;Cadastre;A 1.0;POLYGON Z ((356335.6 6690254.4 27.5, 356336.9 6690253.4 27.5, 356333.9 6690249.5 27.5, 356328.7 6690253.4 27.5, 356331.8 6690257.3 27.5, 356335.6 6690254.4 27.5))
BATIMENT0000000303969020;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;22.1;27.3;33.5;22.5;Cadastre;;POLYGON Z ((356326.3 6690261.6 27.3, 356331.8 6690257.3 27.3, 356328.7 6690253.4 27.3, 356323.1 6690257.5 27.3, 356326.3 6690261.6 27.3))
BATIMENT0000000303969108;Indifférenciée;Annexe;;Oui;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;3.2;22.0;25.2;;;Cadastre;C 0.3;POLYGON Z ((356387.5 6690259.8 25.2, 356387.3 6690260.1 25.2, 356385.4 6690261.3 25.2, 356383.6 6690262.5 25.2, 356382.6 6690263 25.2, 356381.8 6690263.4 25.2, 356394 6690274 25.2, 356398.2 6690269.4 25.2, 356387.5 6690259.8 25.2))
BATIMENT0000000303968887;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.3;19.5;20.9;23.7;20.6;Cadastre;;POLYGON Z ((356475.9 6690270.7 20.9, 356480.2 6690273.8 20.9, 356482.5 6690270.5 20.9, 356483.5 6690269.1 20.9, 356479.1 6690266 20.9, 356475.9 6690270.7 20.9))
BATIMENT0000000303969019;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;00;00;9.2;21.8;31.0;33.4;22.4;Cadastre;B 1.0;POLYGON Z ((356353.1 6690277 31, 356348.7 6690269.2 31, 356344.8 6690264 31, 356339.4 6690268.2 31, 356342.2 6690271.9 31, 356337.4 6690275.7 31, 356344 6690284 31, 356353.1 6690277 31))
BATIMENT0000000303969030;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.9;22.0;27.0;30.7;22.5;Cadastre;;POLYGON Z ((356331.4 6690278.2 27, 356328.8 6690280.1 27, 356330.4 6690282 27, 356332.8 6690280.1 27, 356331.4 6690278.2 27))
BATIMENT0000000303969025;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;09;4.1;22.5;26.7;32.5;23.0;Cadastre;C 0.4;POLYGON Z ((356285 6690285.1 26.7, 356287.1 6690288.2 26.7, 356292.6 6690284.9 26.7, 356290.7 6690281.7 26.7, 356285 6690285.1 26.7))
BATIMENT0000000303969038;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;22.6;26.6;28.7;23.0;Cadastre;;POLYGON Z ((356282.5 6690286.7 26.6, 356285.6 6690291.6 26.6, 356286.7 6690290.9 26.6, 356287.1 6690288.2 26.6, 356285 6690285.1 26.6, 356282.5 6690286.7 26.6))
BATIMENT0000000303969021;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.0;22.3;28.3;32.4;23.0;Cadastre;;POLYGON Z ((356295.3 6690289.3 28.3, 356296.4 6690291.1 28.3, 356300.9 6690298.3 28.3, 356303.5 6690302.6 28.3, 356308.7 6690311.1 28.3, 356328.9 6690295.6 28.3, 356326.8 6690293 28.3, 356320.6 6690285.2 28.3, 356307.8 6690268.9 28.3, 356290.7 6690281.7 28.3, 356292.6 6690284.9 28.3, 356295.3 6690289.3 28.3))
BATIMENT0000000303969033;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.1;22.8;30.0;31.9;23.1;Cadastre;;POLYGON Z ((356294.3 6690289.8 30, 356294 6690289.3 30, 356293.6 6690289.6 30, 356295.3 6690292.4 30, 356295.7 6690292.1 30, 356295.4 6690291.6 30, 356296.4 6690291.1 30, 356295.3 6690289.3 30, 356294.3 6690289.8 30))
BATIMENT0000000303969361;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.9;22.2;32.2;36.2;22.6;Cadastre;;POLYGON Z ((356217.1 6690292.2 32.2, 356220 6690295.4 32.2, 356223.5 6690291.9 32.2, 356220.6 6690288.9 32.2, 356217.1 6690292.2 32.2))
BATIMENT0000000303969148;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.2;22.0;27.2;30.0;22.7;Cadastre;;POLYGON Z ((356196 6690288.2 27.2, 356193.6 6690289.7 27.2, 356197.7 6690296.6 27.2, 356200 6690295.1 27.2, 356196 6690288.2 27.2))
BATIMENT0000000303969147;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;8.2;22.1;30.3;32.7;22.8;Cadastre;A 0.3;POLYGON Z ((356192.6 6690303 30.3, 356199.2 6690299.1 30.3, 356201.6 6690297.7 30.3, 356200 6690295.1 30.3, 356197.7 6690296.6 30.3, 356193.6 6690289.7 30.3, 356196 6690288.2 30.3, 356196.5 6690287.9 30.3, 356195.5 6690286.1 30.3, 356192.6 6690287.8 30.3, 356186 6690291.7 30.3, 356192.6 6690303 30.3))
BATIMENT0000000303969024;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;4.8;22.9;27.7;34.8;23.5;Cadastre;A 0.7;POLYGON Z ((356263.2 6690303.2 27.7, 356269.7 6690299.1 27.7, 356270.6 6690300.5 27.7, 356279.1 6690295.4 27.7, 356278.9 6690295.1 27.7, 356279.3 6690294.9 27.7, 356276.4 6690290.4 27.7, 356269.6 6690294.6 27.7, 356261.1 6690299.8 27.7, 356263.2 6690303.2 27.7))
BATIMENT0000000303969149;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;8.1;22.1;30.2;32.5;22.8;Cadastre;C 1.0;POLYGON Z ((356200.1 6690315.6 30.2, 356205.8 6690310.1 30.2, 356199.2 6690299.1 30.2, 356192.6 6690303 30.2, 356200.1 6690315.6 30.2))
BATIMENT0000000303969034;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.8;21.9;30.7;33.5;23.5;Cadastre;C 0.9;POLYGON Z ((356271.2 6690316.2 30.7, 356277.6 6690312.3 30.7, 356275.4 6690308.6 30.7, 356270.6 6690300.5 30.7, 356269.7 6690299.1 30.7, 356263.2 6690303.2 30.7, 356271.2 6690316.2 30.7))
BATIMENT0000000303969029;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;50;30;9.9;21.8;31.7;32.3;22.5;Cadastre;A 1.0;POLYGON Z ((356336.5 6690289.7 31.7, 356344 6690284 31.7, 356337.4 6690275.7 31.7, 356333.3 6690278.8 31.7, 356333.7 6690279.3 31.7, 356332.8 6690280.1 31.7, 356330.4 6690282 31.7, 356334.5 6690287.2 31.7, 356336.5 6690289.7 31.7))
BATIMENT0000000303969133;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;3.9;21.9;25.8;;;Cadastre;C 0.1;POLYGON Z ((356420.4 6690283.1 25.8, 356430.1 6690290.4 25.8, 356437.2 6690281.3 25.8, 356432.4 6690277.7 25.8, 356430.2 6690280.3 25.8, 356425.3 6690276.7 25.8, 356420.4 6690283.1 25.8))
BATIMENT0000000303969031;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;7.8;22.1;30.0;31.6;22.6;Cadastre;A 1.0;POLYGON Z ((356334.5 6690287.2 30, 356330.4 6690282 30, 356328.8 6690280.1 30, 356328.3 6690279.4 30, 356320.6 6690285.2 30, 356326.8 6690293 30, 356334.5 6690287.2 30))
BATIMENT0000000303969135;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.5;22.0;24.5;29.5;22.0;Cadastre;;POLYGON Z ((356416.1 6690286.3 24.5, 356415.2 6690287.3 24.5, 356412.6 6690285.2 24.5, 356410.1 6690288 24.5, 356416 6690293.2 24.5, 356419.5 6690289.3 24.5, 356416.1 6690286.3 24.5))
BATIMENT0000000303969057;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;3.0;;;9.4;22.5;31.9;35.6;22.7;Cadastre;C 0.6;POLYGON Z ((356364.3 6690291.2 31.9, 356368.2 6690296.2 31.9, 356366.7 6690297.2 31.9, 356370.1 6690301.9 31.9, 356371.5 6690300.7 31.9, 356372.2 6690301.4 31.9, 356377.5 6690297.2 31.9, 356379.9 6690300 31.9, 356386 6690295.3 31.9, 356381.9 6690290.1 31.9, 356382.5 6690289.5 31.9, 356382.8 6690288.5 31.9, 356380.9 6690286 31.9, 356380 6690285.8 31.9, 356379.2 6690286.4 31.9, 356375.7 6690282.1 31.9, 356364.3 6690291.2 31.9))
BATIMENT0000000303969134;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;22.0;24.6;;;Cadastre;;POLYGON Z ((356416 6690293.2 24.6, 356422.3 6690298.6 24.6, 356425.7 6690294.6 24.6, 356419.5 6690289.3 24.6, 356416 6690293.2 24.6))
BATIMENT0000000303969055;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;22.1;25.7;30.1;22.4;Cadastre;;POLYGON Z ((356338 6690300.4 25.7, 356333.7 6690303.7 25.7, 356334.8 6690305.5 25.7, 356339.1 6690302.4 25.7, 356338 6690300.4 25.7))
BATIMENT0000000303969056;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;3.0;20;20;7.8;23.4;31.2;;;Cadastre;C 0.7;POLYGON Z ((356343.3 6690319.3 31.2, 356350.5 6690313.9 31.2, 356350.9 6690314.5 31.2, 356361.2 6690307.1 31.2, 356360.8 6690306.6 31.2, 356367.7 6690301.8 31.2, 356358.8 6690287.1 31.2, 356354.3 6690290.6 31.2, 356359.2 6690298.3 31.2, 356356.4 6690300.2 31.2, 356356 6690299.7 31.2, 356345.9 6690307.1 31.2, 356346.2 6690307.6 31.2, 356343.5 6690309.6 31.2, 356339.1 6690302.4 31.2, 356334.8 6690305.5 31.2, 356341 6690315.6 31.2, 356343.3 6690319.3 31.2))
BATIMENT0000000303969366;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;21.8;;;;Cadastre;;POLYGON Z ((356416.5 6690304.7 -1000, 356418.2 6690306.2 -1000, 356420.9 6690303.5 -1000, 356419.4 6690302.2 -1000, 356416.5 6690304.7 -1000))
BATIMENT0000000303969364;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.3;22.3;27.6;30.2;22.9;Cadastre;;POLYGON Z ((356369.2 6690305 27.6, 356371.8 6690309.2 27.6, 356376.3 6690306.4 27.6, 356377.2 6690304.8 27.6, 356375.7 6690302.4 27.6, 356373.6 6690302.3 27.6, 356369.2 6690305 27.6))
BATIMENT0000000303969084;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;7.6;19.6;27.2;30.5;20.1;Cadastre;A 1.0;POLYGON Z ((356109 6690297.8 27.2, 356116.3 6690293.8 27.2, 356106.4 6690276.7 27.2, 356099.3 6690280.9 27.2, 356100.1 6690282.1 27.2, 356109 6690297.8 27.2))
BATIMENT0000000303968675;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;5.0;34;30;17.4;15.3;32.8;33.8;17.3;Cadastre;A 1.0;POLYGON Z ((356071.2 6690275.7 32.8, 356056.6 6690280.9 32.8, 356055.6 6690281.7 32.8, 356066.2 6690303.1 32.8, 356071.7 6690299.7 32.8, 356080.3 6690294.1 32.8, 356071.2 6690275.7 32.8))
BATIMENT0000000303969085;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.1;19.1;29.2;32.1;20.1;Cadastre;A 1.0;POLYGON Z ((356108 6690298.4 29.2, 356110 6690301.8 29.2, 356109.7 6690302 29.2, 356112 6690306.1 29.2, 356112.5 6690305.9 29.2, 356114.4 6690309.5 29.2, 356115.2 6690309 29.2, 356122.9 6690304.8 29.2, 356116.3 6690293.8 29.2, 356109 6690297.8 29.2, 356108 6690298.4 29.2))
BATIMENT0000000303968676;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1860-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;4.0;10;20;12.3;14.9;27.2;29.3;17.2;Cadastre;A 1.0;POLYGON Z ((356075.7 6690307.9 27.2, 356074.7 6690308.4 27.2, 356076.4 6690311.5 27.2, 356077.2 6690311 27.2, 356081.4 6690319.5 27.2, 356089.8 6690313.5 27.2, 356080.3 6690294.1 27.2, 356071.7 6690299.7 27.2, 356075.7 6690307.9 27.2))
BATIMENT0000000303969357;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.6;14.3;16.9;17.2;15.2;Cadastre;;POLYGON Z ((356052.2 6690306.3 16.9, 356055.2 6690310.8 16.9, 356057.6 6690309.1 16.9, 356054.5 6690304.6 16.9, 356052.2 6690306.3 16.9))
BATIMENT0000000303969087;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;10;20;10.5;19.0;29.5;31.8;19.7;Cadastre;C 0.1;POLYGON Z ((356120.2 6690317.5 29.5, 356120.5 6690317.3 29.5, 356127.7 6690313.4 29.5, 356122.9 6690304.8 29.5, 356115.2 6690309 29.5, 356120.2 6690317.5 29.5))
BATIMENT0000000303969354;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.4;13.2;15.6;16.5;14.5;Cadastre;;POLYGON Z ((356048.9 6690314.8 15.6, 356051.6 6690318.1 15.6, 356053.3 6690316.9 15.6, 356051 6690313.4 15.6, 356048.9 6690314.8 15.6))
BATIMENT0000000303968677;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1890-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;20;20;11.4;15.0;26.4;28.6;16.8;Cadastre;A 1.0;POLYGON Z ((356083.8 6690324.1 26.4, 356085.6 6690327.6 26.4, 356085.7 6690327.6 26.4, 356094.5 6690323.1 26.4, 356089.8 6690313.5 26.4, 356081.4 6690319.5 26.4, 356083.8 6690324.1 26.4))
BATIMENT0000000303969088;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;4.0;10;20;7.2;19.9;27.1;;;Cadastre;A 1.0;POLYGON Z ((356134.9 6690333.4 27.1, 356135.7 6690334.7 27.1, 356138.9 6690332.8 27.1, 356130.7 6690318.6 27.1, 356128.2 6690319.9 27.1, 356126.5 6690317 27.1, 356129 6690315.7 27.1, 356127.7 6690313.4 27.1, 356120.5 6690317.3 27.1, 356123.4 6690322.5 27.1, 356122.9 6690322.8 27.1, 356128.2 6690332.2 27.1, 356129.5 6690331.5 27.1, 356132.7 6690329.5 27.1, 356133.6 6690331.1 27.1, 356134.9 6690333.4 27.1))
BATIMENT0000000303969353;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.9;16.7;26.7;27.5;18.8;Cadastre;;POLYGON Z ((356106.2 6690325.9 26.7, 356107.2 6690327.9 26.7, 356111.4 6690325.7 26.7, 356110.6 6690324.3 26.7, 356110.2 6690324.6 26.7, 356109.7 6690323.9 26.7, 356106.2 6690325.9 26.7))
BATIMENT0000000303969367;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;9.2;21.7;30.9;32.7;22.2;Cadastre;;POLYGON Z ((356423.4 6690310.3 30.9, 356428 6690314.3 30.9, 356430.4 6690311.9 30.9, 356425.8 6690307.8 30.9, 356423.4 6690310.3 30.9))
BATIMENT0000000303969054;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.4;22.2;26.7;32.2;22.8;Cadastre;A 1.0;POLYGON Z ((356332.3 6690320.9 26.7, 356334.9 6690325.3 26.7, 356340.2 6690322.1 26.7, 356337.4 6690317.7 26.7, 356341 6690315.6 26.7, 356334.8 6690305.5 26.7, 356333.7 6690303.7 26.7, 356332.6 6690304.6 26.7, 356334.5 6690307.3 26.7, 356333.9 6690307.7 26.7, 356333.6 6690309 26.7, 356334.6 6690310.4 26.7, 356329.8 6690313.4 26.7, 356326.9 6690309 26.7, 356325.7 6690309.9 26.7, 356332.3 6690320.9 26.7))
BATIMENT0000000303969750;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.8;20.3;26.2;29.0;21.1;Cadastre;;POLYGON Z ((356493.3 6690320.7 26.2, 356494.4 6690319.4 26.2, 356486.9 6690313.1 26.2, 356485.6 6690314.6 26.2, 356493.3 6690320.7 26.2))
BATIMENT0000000303969749;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;;;8.1;19.8;27.9;32.5;21.9;Cadastre;C 0.6;POLYGON Z ((356450.5 6690324 27.9, 356454.6 6690318.1 27.9, 356461.4 6690323.5 27.9, 356456.9 6690329.6 27.9, 356465 6690336.6 27.9, 356468.9 6690331.8 27.9, 356470.1 6690332.9 27.9, 356470 6690333 27.9, 356470.6 6690333.6 27.9, 356470 6690334.3 27.9, 356470.9 6690335.1 27.9, 356471.5 6690334.4 27.9, 356476.7 6690338.9 27.9, 356476.1 6690339.5 27.9, 356476.8 6690340.1 27.9, 356477.4 6690339.5 27.9, 356478 6690339.9 27.9, 356478.6 6690339.3 27.9, 356478 6690338.8 27.9, 356479.4 6690337.1 27.9, 356479.9 6690337.6 27.9, 356480.5 6690336.9 27.9, 356480 6690336.4 27.9, 356482.9 6690333.1 27.9, 356483.4 6690333.5 27.9, 356484.1 6690332.8 27.9, 356483.6 6690332.3 27.9, 356486.3 6690329 27.9, 356472.1 6690316.7 27.9, 356470.7 6690318.4 27.9, 356468.9 6690316.8 27.9, 356466.9 6690318.9 27.9, 356454 6690308 27.9, 356450.2 6690313 27.9, 356437 6690303.4 27.9, 356440.7 6690298.5 27.9, 356434.7 6690294.1 27.9, 356427.7 6690304.2 27.9, 356450.5 6690324 27.9))
BATIMENT0000000303969053;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;20;6.6;22.3;29.0;32.3;23.1;Cadastre;A 1.0;POLYGON Z ((356324.5 6690310.8 29, 356327.1 6690314.9 29, 356321.3 6690318.5 29, 356319 6690315.1 29, 356317.7 6690316.1 29, 356323.8 6690326.2 29, 356326.6 6690324.5 29, 356328.4 6690327.3 29, 356331.4 6690325.4 29, 356329.8 6690322.5 29, 356332.3 6690320.9 29, 356325.7 6690309.9 29, 356324.5 6690310.8 29))
BATIMENT0000000303969748;Eglise;Religieux;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;8.1;19.8;27.9;;;Cadastre;;POLYGON Z ((356472.1 6690316.7 27.9, 356486.3 6690329 27.9, 356486.8 6690329.4 27.9, 356487.5 6690328.6 27.9, 356487 6690328.3 27.9, 356487.3 6690328 27.9, 356487.6 6690328.2 27.9, 356487.9 6690328.5 27.9, 356488.4 6690328.7 27.9, 356489 6690328.9 27.9, 356489.5 6690329 27.9, 356489.9 6690328.9 27.9, 356490.5 6690328.9 27.9, 356490.7 6690328.7 27.9, 356491.1 6690328.6 27.9, 356491.4 6690328.3 27.9, 356491.9 6690327.9 27.9, 356492.1 6690327.4 27.9, 356492.3 6690327 27.9, 356492.5 6690326.2 27.9, 356492.5 6690325.5 27.9, 356492.1 6690324.5 27.9, 356491.7 6690324 27.9, 356491.3 6690323.6 27.9, 356491 6690323.5 27.9, 356491.3 6690323.1 27.9, 356491.9 6690323.6 27.9, 356492.6 6690322.8 27.9, 356492 6690322.3 27.9, 356493.3 6690320.7 27.9, 356485.6 6690314.6 27.9, 356484.3 6690313.6 27.9, 356483.3 6690314.7 27.9, 356482.4 6690313.9 27.9, 356482.9 6690313.4 27.9, 356482.2 6690312.8 27.9, 356481.7 6690313.3 27.9, 356478.6 6690310.7 27.9, 356479 6690310.1 27.9, 356478.3 6690309.4 27.9, 356477.9 6690309.9 27.9, 356477.2 6690309.4 27.9, 356476.5 6690310.3 27.9, 356477.2 6690310.8 27.9, 356472.8 6690316 27.9, 356472.1 6690315.3 27.9, 356471.5 6690316.1 27.9, 356472.1 6690316.7 27.9))
BATIMENT0000000303968992;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;22.1;;;;Cadastre;;POLYGON Z ((356437.1 6690324.4 -1000, 356440.4 6690320.7 -1000, 356437.6 6690318.2 -1000, 356434.3 6690322 -1000, 356437.1 6690324.4 -1000))
BATIMENT0000000303968423;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire recalée;3.0;Pas de Z;9999.0;;;;;;22.9;;;;Cadastre;;POLYGON Z ((356403 6690317 -1000, 356401.3 6690314.4 -1000, 356400.9 6690314.2 -1000, 356400.7 6690314.2 -1000, 356400.5 6690314.1 -1000, 356400.3 6690314.1 -1000, 356400.1 6690314.1 -1000, 356399.7 6690314.1 -1000, 356399.4 6690314.1 -1000, 356399.2 6690314.2 -1000, 356399 6690314.2 -1000, 356398.6 6690314.4 -1000, 356382.4 6690325 -1000, 356383.3 6690326.6 -1000, 356385.4 6690329.8 -1000, 356388.3 6690327.7 -1000, 356403 6690317 -1000))
BATIMENT0000000303969052;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;01;02;3.0;22.4;25.4;27.7;23.1;Cadastre;C 0.3;POLYGON Z ((356313.6 6690321.7 25.4, 356317.5 6690326.8 25.4, 356321.1 6690324 25.4, 356317.1 6690319 25.4, 356313.6 6690321.7 25.4))
BATIMENT0000000303968993;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;05;09;2.6;23.0;25.6;;;Cadastre;B 0.3;POLYGON Z ((356434.3 6690322 25.6, 356437.6 6690318.2 25.6, 356434.2 6690315.3 25.6, 356428.3 6690321.9 25.6, 356427.2 6690321 25.6, 356419.4 6690329.8 25.6, 356423.8 6690333.8 25.6, 356427.5 6690329.6 25.6, 356431.5 6690325.1 25.6, 356434.3 6690322 25.6))
BATIMENT0000000303969032;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;90;20;6.2;22.4;28.7;32.7;23.1;Cadastre;A 1.0;POLYGON Z ((356303.5 6690302.6 28.7, 356299.1 6690305.1 28.7, 356296.5 6690300.9 28.7, 356293.9 6690302.5 28.7, 356302.2 6690316.1 28.7, 356308.7 6690311.1 28.7, 356303.5 6690302.6 28.7))
BATIMENT0000000303969037;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;22.8;26.8;28.2;23.1;Cadastre;;POLYGON Z ((356281.8 6690309.8 26.8, 356280.3 6690307.4 26.8, 356278.4 6690306.9 26.8, 356275.4 6690308.6 26.8, 356277.6 6690312.3 26.8, 356281.8 6690309.8 26.8))
BATIMENT0000000303969035;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;20;3.9;22.5;26.5;32.5;23.1;Cadastre;A 1.0;POLYGON Z ((356293.9 6690302.5 26.5, 356291.4 6690304 26.5, 356294.1 6690308.3 26.5, 356289.5 6690311 26.5, 356295.6 6690321.2 26.5, 356302.2 6690316.1 26.5, 356293.9 6690302.5 26.5))
BATIMENT0000000303969104;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;22.2;26.2;;;Cadastre;;POLYGON Z ((356186.2 6690309.9 26.2, 356192.9 6690321.7 26.2, 356197.9 6690316.8 26.2, 356191.9 6690306.5 26.2, 356186.2 6690309.9 26.2))
BATIMENT0000000303969013;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;14;20;12.4;22.7;35.1;36.0;23.4;Cadastre;A 1.0;POLYGON Z ((356252.8 6690310.5 35.1, 356248.8 6690312.2 35.1, 356251.6 6690322.8 35.1, 356253 6690325.7 35.1, 356253.2 6690326.1 35.1, 356259.8 6690322.2 35.1, 356252.8 6690310.5 35.1))
BATIMENT0000000303969036;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1980-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;10;20;6.1;22.8;28.9;32.9;23.2;Cadastre;A 1.0;POLYGON Z ((356280.5 6690331.6 28.9, 356281.5 6690332 28.9, 356287.1 6690327.7 28.9, 356282.9 6690320.9 28.9, 356284.2 6690320.1 28.9, 356284.3 6690319.3 28.9, 356283.6 6690318.3 28.9, 356282.8 6690318.2 28.9, 356281.7 6690318.7 28.9, 356279.6 6690315.4 28.9, 356280.8 6690314.6 28.9, 356279.4 6690312.2 28.9, 356278 6690312.9 28.9, 356277.6 6690312.3 28.9, 356271.2 6690316.2 28.9, 356280.5 6690331.6 28.9))
BATIMENT0000000303969360;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;23.0;;;;Cadastre;;POLYGON Z ((356241.2 6690324.6 -1000, 356239.6 6690318.6 -1000, 356233.8 6690320.3 -1000, 356235.4 6690326.2 -1000, 356241.2 6690324.6 -1000))
BATIMENT0000000303969011;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1800-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;3.0;20;20;9.6;22.8;32.5;34.5;23.5;Cadastre;A 1.0;POLYGON Z ((356265 6690346.5 32.5, 356271.5 6690341.6 32.5, 356259.8 6690322.2 32.5, 356253.2 6690326.1 32.5, 356265 6690346.5 32.5))
BATIMENT0000000303969359;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;22.2;;;;Cadastre;;POLYGON Z ((356243 6690331.6 -1000, 356238.5 6690335.7 -1000, 356240.1 6690340.9 -1000, 356245.1 6690339.4 -1000, 356243 6690331.6 -1000))
BATIMENT0000000303969179;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1820-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.5;22.7;30.2;33.5;23.4;Cadastre;C 0.6;POLYGON Z ((356292 6690334.8 30.2, 356285.7 6690339.5 30.2, 356295.4 6690355.3 30.2, 356302.2 6690351.2 30.2, 356292 6690334.8 30.2))
BATIMENT0000000303968421;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;20;20;4.3;23.0;27.3;28.7;23.6;Cadastre;C 0.3;POLYGON Z ((356382.4 6690325 27.3, 356380.3 6690321.5 27.3, 356368.3 6690329 27.3, 356371.4 6690333.9 27.3, 356383.3 6690326.6 27.3, 356382.4 6690325 27.3))
BATIMENT0000000303968430;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;22.5;27.1;32.7;23.3;Cadastre;;POLYGON Z ((356365.7 6690337.4 27.1, 356365.8 6690337.3 27.1, 356368.6 6690335.6 27.1, 356365.6 6690330.6 27.1, 356354.7 6690337.1 27.1, 356356.8 6690340.4 27.1, 356357.9 6690342.2 27.1, 356365.7 6690337.4 27.1))
BATIMENT0000000303968425;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.0;23.0;28.0;33.7;23.6;Cadastre;B 0.3;POLYGON Z ((356389.9 6690337.3 28, 356390.7 6690338.6 28, 356391.8 6690337.9 28, 356398.4 6690345.5 28, 356398.2 6690345.7 28, 356402.1 6690350.1 28, 356409.3 6690343.8 28, 356409.3 6690341.3 28, 356407.6 6690339.5 28, 356407.4 6690339.6 28, 356395.6 6690326.7 28, 356394.1 6690327.9 28, 356393.8 6690329.8 28, 356396.3 6690332.7 28, 356395.3 6690333.6 28, 356394.5 6690332.7 28, 356392 6690332.2 28, 356388.3 6690327.7 28, 356385.4 6690329.8 28, 356387.2 6690333 28, 356389.9 6690337.3 28))
BATIMENT0000000303968426;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.5;22.9;24.5;26.5;23.5;Cadastre;;POLYGON Z ((356392.6 6690341.7 24.5, 356390.7 6690338.6 24.5, 356389.9 6690337.3 24.5, 356387.2 6690339 24.5, 356392.2 6690347.2 24.5, 356394.9 6690345.6 24.5, 356392.6 6690341.7 24.5))
BATIMENT0000000303968431;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.4;22.0;25.4;31.2;23.2;Cadastre;;POLYGON Z ((356346.5 6690343.6 25.4, 356347.9 6690345.9 25.4, 356354.2 6690342 25.4, 356353.3 6690340.2 25.4, 356352.2 6690340 25.4, 356346.5 6690343.6 25.4))
BATIMENT0000000291511042;Indifférenciée;Indifférencié;;Non;En service;2011-11-16 12:28:21;2018-09-18 13:52:34;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.2;22.6;;31.7;23.4;Imagerie aérienne;;POLYGON Z ((356324.3 6690336.9 25.8, 356334.1 6690352.2 25.8, 356341.4 6690348.4 25.8, 356338.8 6690344.5 25.8, 356335.8 6690345.6 25.8, 356328.6 6690334.5 25.8, 356324.3 6690336.9 25.8))
BATIMENT0000000303968429;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;09;02;1.9;23.0;24.9;26.2;23.2;Cadastre;B 0.1;POLYGON Z ((356354.6 6690341.7 24.9, 356358.7 6690348.2 24.9, 356360.8 6690346.9 24.9, 356359.7 6690345.2 24.9, 356357.9 6690342.2 24.9, 356356.8 6690340.4 24.9, 356354.6 6690341.7 24.9))
BATIMENT0000000303968998;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;4.0;50;20;8.6;21.3;30.0;36.8;22.2;Cadastre;C 0.7;POLYGON Z ((356454.4 6690347.2 30, 356454.4 6690344.2 30, 356445.5 6690336.5 30, 356440.7 6690341.9 30, 356445 6690345.6 30, 356441.3 6690349.9 30, 356439.6 6690348.5 30, 356438.4 6690349.8 30, 356443.9 6690354.3 30, 356454.4 6690347.2 30))
BATIMENT0000000303968997;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;21.9;24.6;25.2;22.3;Cadastre;;POLYGON Z ((356437.6 6690349.2 24.6, 356440.2 6690346.1 24.6, 356439.9 6690345.9 24.6, 356440.2 6690345.6 24.6, 356440.7 6690345.2 24.6, 356440.8 6690343.8 24.6, 356439.7 6690343 24.6, 356437.4 6690345.6 24.6, 356435.7 6690347.6 24.6, 356437.6 6690349.2 24.6))
BATIMENT0000000303968427;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.5;22.8;24.4;25.5;23.2;Cadastre;;POLYGON Z ((356394.9 6690345.6 24.4, 356392.2 6690347.2 24.4, 356394.5 6690351.1 24.4, 356397.3 6690349.5 24.4, 356394.9 6690345.6 24.4))
BATIMENT0000000303967735;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;6.7;15.2;22.0;26.4;16.5;Cadastre;A 1.0;POLYGON Z ((356001.6 6690193.3 22, 356006.6 6690199.4 22, 356009.1 6690197.5 22, 356006.1 6690193.7 22, 356004.3 6690191.6 22, 356001.6 6690193.3 22))
BATIMENT0000000304020961;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.0;14.1;23.2;25.2;15.7;Cadastre;B 1.0;POLYGON Z ((355989.9 6690193.4 23.2, 355983.5 6690198.7 23.2, 355988.2 6690204.4 23.2, 355992.6 6690200.6 23.2, 355992.3 6690200.3 23.2, 355994.2 6690198.7 23.2, 355989.9 6690193.4 23.2))
BATIMENT0000000303967737;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1958-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;50;10;13.6;15.8;29.5;31.6;17.2;Cadastre;A 1.0;POLYGON Z ((356009.6 6690196.9 29.5, 356010.8 6690197.1 29.5, 356015.1 6690203.7 29.5, 356006 6690210.6 29.5, 356006.7 6690211.4 29.5, 356012.9 6690219.4 29.5, 356023.3 6690211.9 29.5, 356027.2 6690204.2 29.5, 356013.3 6690185.4 29.5, 356010.6 6690187.8 29.5, 356011.4 6690189 29.5, 356006.1 6690193.7 29.5, 356009.1 6690197.5 29.5, 356009.6 6690196.9 29.5))
BATIMENT0000000304020958;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1914-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;04;04;5.2;14.6;19.9;22.6;15.7;Cadastre;B 0.4;POLYGON Z ((355989.7 6690206 19.9, 355991.3 6690207.8 19.9, 355993.1 6690210.1 19.9, 355999.5 6690205.2 19.9, 355996.3 6690201.3 19.9, 355995.8 6690200.7 19.9, 355989.7 6690206 19.9))
BATIMENT0000000304020962;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;4.0;14.8;18.8;21.7;15.6;Cadastre;C 0.5;POLYGON Z ((355986.8 6690211.3 18.8, 355988.7 6690213.8 18.8, 355993.1 6690210.1 18.8, 355991.3 6690207.8 18.8, 355986.8 6690211.3 18.8))
BATIMENT0000002322196657;Indifférenciée;Résidentiel;;Non;En service;2022-10-24 12:09:39;2023-01-31 17:49:05;;;DGFiP;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.1;14.5;18.7;22.2;15.6;Cadastre;;POLYGON Z ((355986.3 6690215.6 18.7, 355986.7 6690215.5 18.7, 355988.7 6690213.9 18.7, 355984.9 6690209.1 18.7, 355982.5 6690211 18.7, 355986.3 6690215.6 18.7))
BATIMENT0000000303967626;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;2.0;25;20;6.2;14.9;21.1;22.6;17.0;Cadastre;C 0.4;POLYGON Z ((355997.3 6690216.1 21.1, 355996.2 6690214.7 21.1, 356004.1 6690208.2 21.1, 356000.9 6690204.1 21.1, 355999.5 6690205.2 21.1, 355993.1 6690210.1 21.1, 355988.7 6690213.8 21.1, 355986.7 6690215.5 21.1, 355986.3 6690215.6 21.1, 355991 6690221.1 21.1, 355997.3 6690216.1 21.1))
BATIMENT0000000303967628;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;11.0;3.0;25;20;9.4;14.7;24.1;26.2;16.7;Cadastre;C 1.0;POLYGON Z ((355997.8 6690230.3 24.1, 356012.9 6690219.4 24.1, 356006.7 6690211.4 24.1, 356004.2 6690213.6 24.1, 356003.3 6690212.6 24.1, 356001.9 6690214 24.1, 356002.6 6690214.8 24.1, 355992.2 6690222.8 24.1, 355997.8 6690230.3 24.1))
BATIMENT0000000303968987;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;17.9;25.5;;;Cadastre;A 1.0;POLYGON Z ((356041.3 6690223.3 25.5, 356039.1 6690222.8 25.5, 356038.1 6690223.4 25.5, 356035.6 6690218.8 25.5, 356029.2 6690219.8 25.5, 356035 6690230.5 25.5, 356042.9 6690226.1 25.5, 356041.3 6690223.3 25.5))
BATIMENT0000000304020956;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;3.0;20;20;5.5;13.6;19.1;25.4;15.3;Cadastre;A 1.0;POLYGON Z ((355986.3 6690238.6 19.1, 355997.8 6690230.3 19.1, 355992.2 6690222.8 19.1, 355991 6690221.1 19.1, 355986.3 6690215.6 19.1, 355983.5 6690217.9 19.1, 355979.9 6690220.7 19.1, 355978.1 6690222.3 19.1, 355973.9 6690225.7 19.1, 355977.1 6690229.7 19.1, 355978.9 6690228.4 19.1, 355984.6 6690223.9 19.1, 355983.8 6690223 19.1, 355985.3 6690221.8 19.1, 355990.9 6690228.8 19.1, 355989.5 6690229.9 19.1, 355988.7 6690228.9 19.1, 355985.5 6690231.2 19.1, 355984.2 6690229.9 19.1, 355981.8 6690232 19.1, 355981.4 6690232.3 19.1, 355986.3 6690238.6 19.1))
BATIMENT0000000304020953;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.6;13.3;19.0;23.5;14.2;Cadastre;;POLYGON Z ((355974.5 6690217.8 19, 355976.2 6690219.8 19, 355978 6690218.7 19, 355978.6 6690218.1 19, 355976.5 6690215.7 19, 355974.2 6690217.4 19, 355974.5 6690217.8 19))
BATIMENT0000000304020951;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.6;12.6;23.2;25.5;13.3;Cadastre;A 1.0;POLYGON Z ((355970.3 6690221.2 23.2, 355964.6 6690214.3 23.2, 355959.9 6690218.2 23.2, 355965.8 6690225 23.2, 355970.3 6690221.2 23.2))
BATIMENT0000000304020955;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.2;13.3;16.6;17.7;14.3;Cadastre;;POLYGON Z ((355978.1 6690222.3 16.6, 355979.9 6690220.7 16.6, 355978 6690218.7 16.6, 355976.2 6690219.8 16.6, 355978.1 6690222.3 16.6))
BATIMENT0000000304020950;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;20;11.2;12.3;23.5;25.8;13.1;Cadastre;A 1.0;POLYGON Z ((355955.8 6690221.6 23.5, 355960.9 6690227.8 23.5, 355962.7 6690229.9 23.5, 355966.9 6690226.6 23.5, 355965.8 6690225 23.5, 355959.9 6690218.2 23.5, 355955.8 6690221.6 23.5))
BATIMENT0000000304020947;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.6;12.0;21.6;24.0;12.5;Cadastre;A 1.0;POLYGON Z ((355950.2 6690226.2 21.6, 355955.3 6690232.3 21.6, 355960.9 6690227.8 21.6, 355955.8 6690221.6 21.6, 355950.2 6690226.2 21.6))
BATIMENT0000000304020964;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.9;12.7;16.7;22.2;13.6;Cadastre;;POLYGON Z ((355970.1 6690231 16.7, 355970.8 6690230.4 16.7, 355970.5 6690230 16.7, 355969.7 6690228.9 16.7, 355969.2 6690229.2 16.7, 355967.5 6690230.6 16.7, 355968.8 6690232.1 16.7, 355970.1 6690231 16.7))
BATIMENT0000000304020959;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;13.6;18.2;24.0;14.1;Cadastre;;POLYGON Z ((355980 6690233.7 18.2, 355981.4 6690232.3 18.2, 355981.8 6690232 18.2, 355978.9 6690228.4 18.2, 355977.1 6690229.7 18.2, 355980 6690233.7 18.2))
BATIMENT0000000304020960;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;10.4;13.0;23.5;25.0;14.0;Cadastre;A 1.0;POLYGON Z ((355970.5 6690230 23.5, 355970.8 6690230.4 23.5, 355976.1 6690236.7 23.5, 355977.7 6690235.4 23.5, 355982.3 6690241.5 23.5, 355986.3 6690238.6 23.5, 355981.4 6690232.3 23.5, 355980 6690233.7 23.5, 355977.1 6690229.7 23.5, 355973.9 6690225.7 23.5, 355969.7 6690228.9 23.5, 355970.5 6690230 23.5))
BATIMENT0000000304020943;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;11.4;10.7;22.1;24.8;11.8;Cadastre;A 1.0;POLYGON Z ((355942.4 6690232.6 22.1, 355936.2 6690237.7 22.1, 355941.8 6690244.7 22.1, 355942.9 6690243.9 22.1, 355944.3 6690245.6 22.1, 355946 6690244.3 22.1, 355945.5 6690243.6 22.1, 355946.4 6690242.6 22.1, 355945.8 6690241.6 22.1, 355948.1 6690239.5 22.1, 355942.4 6690232.6 22.1))
BATIMENT0000000304020946;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1909-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;3.0;10;20;6.0;11.0;17.1;24.9;12.3;Cadastre;B 0.8;POLYGON Z ((355958.7 6690249.9 17.1, 355954.9 6690245.2 17.1, 355957.1 6690243.3 17.1, 355953.6 6690239 17.1, 355953.2 6690239.2 17.1, 355951.2 6690236.9 17.1, 355954.3 6690234.5 17.1, 355948.8 6690227.3 17.1, 355942.4 6690232.6 17.1, 355948.1 6690239.5 17.1, 355949.8 6690241.7 17.1, 355953 6690245.5 17.1, 355957.2 6690250.9 17.1, 355958.7 6690249.9 17.1))
BATIMENT0000000304020897;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2000-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;90.0;7.0;00;00;17.7;9.6;27.3;30.3;10.8;Cadastre;A 1.0;POLYGON Z ((355857.9 6690225.1 27.3, 355860.4 6690226.3 27.3, 355860.9 6690226.5 27.3, 355861.7 6690226.9 27.3, 355864.2 6690221.6 27.3, 355865.5 6690222.2 27.3, 355869.4 6690214.2 27.3, 355868.1 6690213.6 27.3, 355873.3 6690202.9 27.3, 355874.5 6690203.6 27.3, 355875.8 6690200.9 27.3, 355873.9 6690199.9 27.3, 355878.4 6690190.5 27.3, 355875.8 6690189.2 27.3, 355872.3 6690178.7 27.3, 355873.3 6690176.5 27.3, 355864.1 6690172.1 27.3, 355865.1 6690169.9 27.3, 355862.4 6690168.6 27.3, 355861.7 6690169.9 27.3, 355855.2 6690166.8 27.3, 355854.8 6690167.6 27.3, 355850.1 6690165.1 27.3, 355850.5 6690164.3 27.3, 355844.1 6690161.2 27.3, 355837.9 6690174.2 27.3, 355850.2 6690180.1 27.3, 355850.9 6690178.8 27.3, 355858.3 6690182.2 27.3, 355857.6 6690183.4 27.3, 355861.6 6690194.9 27.3, 355862.5 6690195.2 27.3, 355859.5 6690201.4 27.3, 355856.4 6690207.7 27.3, 355855.3 6690207.2 27.3, 355851.3 6690215.3 27.3, 355852.4 6690215.8 27.3, 355849.8 6690221.1 27.3, 355857.9 6690225.1 27.3))
BATIMENT0000000304020898;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;13.7;10.0;23.7;25.7;10.5;Cadastre;;POLYGON Z ((355856.4 6690207.7 23.7, 355859.5 6690201.4 23.7, 355858.4 6690200.9 23.7, 355855.3 6690207.2 23.7, 355856.4 6690207.7 23.7))
BATIMENT0000000304020852;Indifférenciée;Sportif;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;11.7;10.4;22.1;22.1;11.0;Cadastre;A 1.0;POLYGON Z ((355893.3 6690249.5 22.1, 355894.2 6690249.9 22.1, 355894.6 6690250.1 22.1, 355897.7 6690251.7 22.1, 355898.2 6690251.3 22.1, 355897.9 6690251 22.1, 355921.2 6690231.8 22.1, 355919.5 6690229.7 22.1, 355913.1 6690221.8 22.1, 355908.5 6690225.5 22.1, 355882.5 6690212.9 22.1, 355870.3 6690238 22.1, 355893.3 6690249.5 22.1))
BATIMENT0000000304020895;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;59.0;8.0;00;00;17.7;9.5;27.2;29.9;10.5;Cadastre;A 1.0;POLYGON Z ((355829.7 6690278.6 27.2, 355834.9 6690281.1 27.2, 355836.5 6690281.9 27.2, 355841.7 6690271.3 27.2, 355840.4 6690270.5 27.2, 355843.5 6690263.9 27.2, 355844.9 6690264.6 27.2, 355849.1 6690256 27.2, 355846.9 6690254.9 27.2, 355848.1 6690252.5 27.2, 355849.5 6690249.7 27.2, 355850.2 6690250.2 27.2, 355853.6 6690242.9 27.2, 355853 6690242.7 27.2, 355856.3 6690236.1 27.2, 355857.1 6690236.4 27.2, 355860.3 6690229.3 27.2, 355859.7 6690229 27.2, 355860.9 6690226.5 27.2, 355860.4 6690226.3 27.2, 355857.9 6690225.1 27.2, 355849.8 6690221.1 27.2, 355848.1 6690224.5 27.2, 355845.1 6690222.8 27.2, 355844.2 6690223.1 27.2, 355841.7 6690228.3 27.2, 355842 6690229.2 27.2, 355842.6 6690229.4 27.2, 355839.2 6690236.1 27.2, 355838.7 6690235.7 27.2, 355837.8 6690235.9 27.2, 355835.3 6690241.1 27.2, 355835.9 6690242 27.2, 355838.8 6690243.4 27.2, 355837 6690247.2 27.2, 355823.2 6690275.4 27.2, 355829.7 6690278.6 27.2))
BATIMENT0000000304020896;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.4;9.5;25.0;27.4;10.1;Cadastre;;POLYGON Z ((355849.1 6690256 25, 355850.3 6690253.6 25, 355848.1 6690252.5 25, 355846.9 6690254.9 25, 355849.1 6690256 25))
BATIMENT0000000304020853;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.9;8.8;24.7;28.1;9.8;Cadastre;;POLYGON Z ((355850.4 6690279.3 24.7, 355852 6690280.2 24.7, 355848.8 6690282.6 24.7, 355852.6 6690287.1 24.7, 355859.8 6690281.2 24.7, 355860.6 6690281.9 24.7, 355869.8 6690274.6 24.7, 355869.2 6690273.7 24.7, 355873.3 6690270.2 24.7, 355874 6690271 24.7, 355897.7 6690251.7 24.7, 355894.6 6690250.1 24.7, 355894.2 6690249.9 24.7, 355893.3 6690249.5 24.7, 355870.3 6690238 24.7, 355850.4 6690279.3 24.7))
BATIMENT0000000304020938;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1988-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;15.0;4.0;30;20;13.8;7.5;21.3;24.7;10.0;Cadastre;A 1.0;POLYGON Z ((355903.3 6690283.5 21.3, 355918.9 6690270.8 21.3, 355909.2 6690259.9 21.3, 355893.8 6690272.6 21.3, 355900.5 6690280.4 21.3, 355903.3 6690283.5 21.3))
BATIMENT0000000304020937;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;30;10;12.5;8.0;20.5;22.2;9.4;Cadastre;A 1.0;POLYGON Z ((355879.3 6690284.5 20.5, 355885.9 6690292.3 20.5, 355891.7 6690287.6 20.5, 355892.2 6690288.1 20.5, 355893.8 6690286.8 20.5, 355893.5 6690286.3 20.5, 355900.5 6690280.4 20.5, 355893.8 6690272.6 20.5, 355879.3 6690284.5 20.5))
BATIMENT0000000304020850;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.1;8.4;14.5;17.7;9.4;Cadastre;A 1.0;POLYGON Z ((355902.3 6690297.7 14.5, 355906.1 6690301.6 14.5, 355907.8 6690299 14.5, 355904.1 6690295.1 14.5, 355902.3 6690297.7 14.5))
BATIMENT0000000304020851;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;4.0;60;90;8.7;8.5;17.3;19.6;9.4;Cadastre;A 1.0;POLYGON Z ((355896.9 6690305.5 17.3, 355900.4 6690309.8 17.3, 355906.1 6690301.6 17.3, 355902.3 6690297.7 17.3, 355896.9 6690305.5 17.3))
BATIMENT0000000303968988;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.6;17.9;25.5;28.2;17.9;Cadastre;A 1.0;POLYGON Z ((356034.3 6690230.9 25.5, 356039.6 6690240.4 25.5, 356040.9 6690239.7 25.5, 356046.1 6690236.7 25.5, 356043.4 6690231.9 25.5, 356045.5 6690230.9 25.5, 356042.9 6690226.1 25.5, 356035 6690230.5 25.5, 356034.3 6690230.9 25.5))
BATIMENT0000000303969109;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.6;14.9;20.5;24.1;17.0;Cadastre;A 1.0;POLYGON Z ((356019.6 6690232 20.5, 356016.3 6690227.3 20.5, 356006.6 6690234.7 20.5, 356008.5 6690237.3 20.5, 356010 6690239.4 20.5, 356012.4 6690237.6 20.5, 356019.6 6690232 20.5))
BATIMENT0000000303968989;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.6;17.6;28.2;30.4;18.0;Cadastre;A 1.0;POLYGON Z ((356046 6690249.3 28.2, 356051.5 6690246.2 28.2, 356052.7 6690245.5 28.2, 356053 6690244.1 28.2, 356051.6 6690241.8 28.2, 356050.3 6690241.6 28.2, 356049.7 6690240.1 28.2, 356050.1 6690239.1 28.2, 356048.7 6690236.5 28.2, 356047.2 6690236.1 28.2, 356046.1 6690236.7 28.2, 356040.9 6690239.7 28.2, 356046 6690249.3 28.2))
BATIMENT0000000303969332;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2022-07-30 23:16:38;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;;;;16.7;;;;Cadastre;;POLYGON Z ((356025.8 6690260.2 -1000, 356027.4 6690263.1 -1000, 356029.9 6690261.6 -1000, 356028.3 6690258.8 -1000, 356025.8 6690260.2 -1000))
BATIMENT0000002011296057;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;47.0;4.0;00;00;15.4;12.1;;;;Imagerie aérienne;C 0.6;POLYGON Z ((356010 6690239.4 19.7, 356008.5 6690237.3 19.7, 356006.6 6690234.7 19.7, 356002.2 6690237.7 19.5, 355998 6690240.7 18.9, 355998.8 6690241.9 22.8, 355991.5 6690247.7 24.5, 355991.1 6690247.2 24.5, 355986 6690251.2 24.5, 355987.1 6690253.2 24.5, 355983.9 6690255.9 23, 355987.5 6690260.7 22.9, 355988.8 6690260.1 26.7, 355990.2 6690262 26.7, 355992 6690260.7 26.7, 355994.3 6690264.2 24.6, 355993.5 6690264.9 24.6, 355997.5 6690270.6 24.6, 355998.5 6690270 24.6, 356001 6690273.2 24.5, 356004.7 6690278.1 25.3, 356007.5 6690282.2 24.9, 356006.4 6690283.1 24.9, 356011.2 6690289.4 27.5, 356010.6 6690289.9 27.5, 356014.5 6690295.2 27.5, 356016.8 6690293.5 27.5, 356019.7 6690297.4 25.2, 356028.1 6690292.7 23, 356038.4 6690285.5 23, 356032.6 6690274.8 23, 356023.9 6690281.4 25.2, 356018.5 6690274 25.2, 356012 6690265.3 22.9, 356009.1 6690260.5 24.3, 356004.6 6690254.6 24.3, 356008.3 6690252.1 24.3, 356006.3 6690249.2 24.3, 356015.2 6690242.8 19, 356012.4 6690237.6 19.7, 356010 6690239.4 19.7))
BATIMENT0000000303969103;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;01;01;5.7;15.5;21.2;22.7;17.2;Cadastre;A 1.0;POLYGON Z ((356044.5 6690273.8 21.2, 356037.6 6690279 21.2, 356040.5 6690283.9 21.2, 356047.9 6690278.6 21.2, 356044.5 6690273.8 21.2))
BATIMENT0000000303969062;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1950-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;13;13;5.2;15.8;21.0;;;Cadastre;A 1.0;POLYGON Z ((356036.4 6690296.4 21, 356041.5 6690304 21, 356042.4 6690305.3 21, 356043.1 6690306.4 21, 356049 6690301.9 21, 356047.3 6690299.6 21, 356048.2 6690298.9 21, 356043.1 6690291.3 21, 356036.4 6690296.4 21))
BATIMENT0000000303969061;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;7.6;13.0;20.7;23.1;14.8;Cadastre;A 1.0;POLYGON Z ((356028.2 6690302.6 20.7, 356033.1 6690310.5 20.7, 356041.5 6690304 20.7, 356036.4 6690296.4 20.7, 356028.2 6690302.6 20.7))
BATIMENT0000000303969060;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;8.5;11.7;20.3;22.2;14.3;Cadastre;A 1.0;POLYGON Z ((356016.5 6690311.4 20.3, 356018.8 6690316.9 20.3, 356024.2 6690312.9 20.3, 356026.7 6690316.5 20.3, 356033.6 6690311.2 20.3, 356033.1 6690310.5 20.3, 356028.2 6690302.6 20.3, 356016.5 6690311.4 20.3))
BATIMENT0000000303969058;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.7;11.1;22.9;23.9;13.3;Cadastre;;POLYGON Z ((356006.7 6690318.8 22.9, 356009.9 6690323 22.9, 356013 6690320.7 22.9, 356014.1 6690321.9 22.9, 356015.1 6690321.3 22.9, 356017.1 6690323.9 22.9, 356020.9 6690321.3 22.9, 356019.6 6690318.6 22.9, 356018.8 6690316.9 22.9, 356016.5 6690311.4 22.9, 356006.7 6690318.8 22.9))
BATIMENT0000000304020945;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.2;10.7;16.9;17.3;11.8;Cadastre;;POLYGON Z ((355953 6690245.5 16.9, 355949.8 6690241.7 16.9, 355948.2 6690242.9 16.9, 355951.2 6690246.9 16.9, 355953 6690245.5 16.9))
BATIMENT0000000304020944;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.0;10.9;14.0;15.5;12.3;Cadastre;;POLYGON Z ((355961.6 6690256.5 14, 355964.4 6690254.5 14, 355960.7 6690249.8 14, 355957.9 6690251.9 14, 355961.6 6690256.5 14))
BATIMENT0000000304020942;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;30;90;6.7;10.3;17.1;22.2;12.1;Cadastre;A 1.0;POLYGON Z ((355951.2 6690246.9 17.1, 355946.6 6690250.5 17.1, 355954.9 6690261.3 17.1, 355961.6 6690256.5 17.1, 355957.9 6690251.9 17.1, 355957.2 6690250.9 17.1, 355953 6690245.5 17.1, 355951.2 6690246.9 17.1))
BATIMENT0000000304020941;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.1;9.6;14.7;18.5;11.7;Cadastre;A 1.0;POLYGON Z ((355935.9 6690262.9 14.7, 355933.7 6690264.7 14.7, 355939.4 6690272.6 14.7, 355954.9 6690261.3 14.7, 355946.6 6690250.5 14.7, 355941.8 6690244.7 14.7, 355936.2 6690237.7 14.7, 355929 6690243.6 14.7, 355935 6690250.5 14.7, 355938.1 6690248 14.7, 355944.8 6690256.3 14.7, 355941.6 6690258.5 14.7, 355935.9 6690262.9 14.7))
BATIMENT0000000304020949;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.8;9.8;18.6;19.5;10.4;Cadastre;;POLYGON Z ((355934.9 6690254.4 18.6, 355937.1 6690256.8 18.6, 355933.6 6690259.8 18.6, 355935.9 6690262.9 18.6, 355941.6 6690258.5 18.6, 355936.9 6690252.8 18.6, 355934.9 6690254.4 18.6))
BATIMENT0000000304020940;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;;;9.0;9.1;18.2;21.6;10.8;Cadastre;A 1.0;POLYGON Z ((355909.2 6690259.9 18.2, 355918.9 6690270.8 18.2, 355924.2 6690276.9 18.2, 355927.6 6690281.2 18.2, 355939.4 6690272.6 18.2, 355933.7 6690264.7 18.2, 355935.9 6690262.9 18.2, 355933.6 6690259.8 18.2, 355937.1 6690256.8 18.2, 355934.9 6690254.4 18.2, 355936.9 6690252.8 18.2, 355935 6690250.5 18.2, 355929 6690243.6 18.2, 355909.2 6690259.9 18.2))
BATIMENT0000000304020848;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 19:18:06;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;3.3;10.0;13.3;;;Cadastre;A 1.0;POLYGON Z ((355911.8 6690293.3 13.3, 355908.2 6690289.3 13.3, 355906.1 6690292.2 13.3, 355904.1 6690295.1 13.3, 355907.8 6690299 13.3, 355909.8 6690296.2 13.3, 355911.8 6690293.3 13.3))
BATIMENT0000002011296061;Indifférenciée;Résidentiel;Annexe;Non;En service;2018-06-04 12:14:25;2019-03-15 08:35:34;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;56.0;4.0;00;00;18.3;8.7;;;;Imagerie aérienne;C 0.5;POLYGON Z ((355997.9 6690301.8 22.8, 355996.8 6690302.5 27, 355995.6 6690300.9 27, 355994.8 6690301.5 27, 355990.2 6690295.1 24.3, 355983.2 6690286.1 22.4, 355982.3 6690286.7 22.4, 355980.2 6690283.3 22.4, 355981.2 6690282.6 22.4, 355977.2 6690276.6 22.4, 355975.7 6690277.6 22.4, 355973.7 6690274.1 24.8, 355975.3 6690273.2 24.6, 355973.9 6690271 24.6, 355975.2 6690270.3 20.2, 355971.4 6690265.2 20.2, 355967.7 6690267.7 22.4, 355966.3 6690265.5 22.4, 355961.3 6690269.1 22.4, 355942.4 6690282.6 20.3, 355952.7 6690293.5 20.3, 355956.1 6690291 20.3, 355956.4 6690291.5 20.3, 355964.7 6690285.5 22.4, 355968.1 6690290.4 22.4, 355969.3 6690289.5 22.4, 355972.4 6690293.7 22.3, 355971.9 6690294.4 22.2, 355976 6690298.6 24.7, 355979.1 6690303 24.7, 355978.1 6690303.8 24.7, 355980.4 6690307 24.7, 355975.7 6690311 22.6, 355976.4 6690311.9 22.6, 355972.8 6690314.7 22.6, 355982.3 6690324.2 22.6, 355987.9 6690319.5 24.5, 355990.8 6690317.3 24.5, 355991.4 6690318 24.5, 355999.8 6690311.7 24.2, 355998.3 6690309.6 24.2, 356001.8 6690307 22.4, 355997.9 6690301.8 22.8))
BATIMENT0000000304020887;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;8.0;30;40;2.6;9.6;12.2;20.2;11.6;Cadastre;C 0.1;POLYGON Z ((355952.8 6690298.4 12.2, 355982.8 6690329.3 12.2, 355985.1 6690328.1 12.2, 355954.6 6690296.5 12.2, 355952.8 6690298.4 12.2))
BATIMENT0000000304020860;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;8.0;30;40;13.2;7.9;21.1;21.6;8.8;Cadastre;C 0.3;POLYGON Z ((355945.1 6690321.8 21.1, 355948.9 6690327.8 21.1, 355961.7 6690318.6 21.1, 355957.8 6690312.6 21.1, 355945.1 6690321.8 21.1))
BATIMENT0000000303969355;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.6;12.2;13.8;15.0;13.6;Cadastre;;POLYGON Z ((356037.5 6690317.5 13.8, 356039.4 6690320.6 13.8, 356042.4 6690318.6 13.8, 356041.5 6690317.1 13.8, 356039.6 6690316.2 13.8, 356037.5 6690317.5 13.8))
BATIMENT0000000303969059;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.9;11.3;20.2;22.5;12.0;Cadastre;;POLYGON Z ((356022.5 6690320 20.2, 356020.9 6690317.6 20.2, 356019.6 6690318.6 20.2, 356020.9 6690321.3 20.2, 356022.5 6690320 20.2))
BATIMENT0000000303969352;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;3.4;11.8;15.3;17.3;13.3;Cadastre;;POLYGON Z ((356035.9 6690322.8 15.3, 356038.2 6690326.6 15.3, 356040.1 6690325.4 15.3, 356037.8 6690321.5 15.3, 356035.9 6690322.8 15.3))
BATIMENT0000000303967610;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;12.5;15.8;15.9;12.5;Cadastre;;POLYGON Z ((356002.8 6690329.2 15.8, 356006.6 6690326.6 15.8, 356003.3 6690321.4 15.8, 355999.8 6690324 15.8, 356002.8 6690329.2 15.8))
BATIMENT0000000303967609;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.6;10.3;21.0;23.4;12.2;Cadastre;;POLYGON Z ((355994.6 6690335.3 21, 355997.5 6690333.3 21, 355999.8 6690337.1 21, 356000.7 6690336.6 21, 356004.5 6690334.8 21, 356003.2 6690332.2 21, 355998.3 6690325.1 21, 355991 6690330.6 21, 355994.6 6690335.3 21))
BATIMENT0000000304020876;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;10.4;13.2;18.5;11.7;Cadastre;;POLYGON Z ((355989 6690332.2 13.2, 355988.3 6690335.4 13.2, 355989.4 6690336.8 13.2, 355992.3 6690334.7 13.2, 355989.9 6690331.5 13.2, 355989 6690332.2 13.2))
BATIMENT0000000303967677;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.9;10.3;17.2;21.0;11.1;Cadastre;;POLYGON Z ((356000.7 6690336.6 17.2, 356002.2 6690339.4 17.2, 356005.8 6690337.4 17.2, 356004.5 6690334.8 17.2, 356000.7 6690336.6 17.2))
BATIMENT0000000303969065;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.4;11.0;13.5;14.0;11.7;Cadastre;;POLYGON Z ((356027.5 6690335.3 13.5, 356025.4 6690336.5 13.5, 356027.5 6690339.8 13.5, 356029.5 6690338.5 13.5, 356027.5 6690335.3 13.5))
BATIMENT0000000303969154;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1965-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;60;20;4.2;10.7;15.0;17.5;11.1;Cadastre;A 1.0;POLYGON Z ((356010 6690338.1 15, 356014.8 6690345.2 15, 356022.5 6690339.9 15, 356018.1 6690332.8 15, 356010 6690338.1 15))
BATIMENT0000000303967676;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.6;11.0;12.6;14.0;11.0;Cadastre;;POLYGON Z ((356005.9 6690346.1 12.6, 356009.2 6690344 12.6, 356005.8 6690337.4 12.6, 356002.2 6690339.4 12.6, 356005.9 6690346.1 12.6))
BATIMENT0000000304020948;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;8.9;17.2;19.0;9.2;Cadastre;;POLYGON Z ((355891.9 6690313.7 17.2, 355893.1 6690311.9 17.2, 355891.2 6690310.7 17.2, 355890 6690312.3 17.2, 355891.9 6690313.7 17.2))
BATIMENT0000000304020939;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1992-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;200.0;6.0;90;90;15.0;7.8;22.8;27.7;10.4;Cadastre;A 1.0;POLYGON Z ((355886.6 6690330.1 22.8, 355890.3 6690324.4 22.8, 355892.8 6690320.9 22.8, 355895.9 6690316.4 22.8, 355891.9 6690313.7 22.8, 355890 6690312.3 22.8, 355885.2 6690309 22.8, 355873.6 6690326.1 22.8, 355873.7 6690326.8 22.8, 355872.2 6690327.1 22.8, 355872.2 6690326.2 22.8, 355859.5 6690315.2 22.8, 355886.6 6690293.2 22.8, 355885.9 6690292.3 22.8, 355879.3 6690284.5 22.8, 355843.9 6690313.7 22.8, 355844.7 6690319.4 22.8, 355852.5 6690326 22.8, 355853.7 6690327.1 22.8, 355854.6 6690326.1 22.8, 355858 6690330.8 22.8, 355872.8 6690343.5 22.8, 355877.1 6690343.2 22.8, 355877.7 6690343 22.8, 355886.6 6690330.1 22.8))
BATIMENT0000000304020822;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;3.0;30;20;9.6;10.6;20.2;;;Cadastre;C 0.7;POLYGON Z ((355846.2 6690345.3 20.2, 355858.2 6690355.4 20.2, 355858.7 6690360 20.2, 355853.9 6690366.7 20.2, 355859.3 6690371.3 20.2, 355865.8 6690361.7 20.2, 355864.6 6690360.8 20.2, 355865.6 6690358.9 20.2, 355865.7 6690357.7 20.2, 355865.5 6690356.2 20.2, 355865 6690354.5 20.2, 355863.8 6690353.3 20.2, 355865 6690351.9 20.2, 355848.1 6690337.4 20.2, 355840.1 6690346.4 20.2, 355843.1 6690348.8 20.2, 355844.6 6690347.1 20.2, 355846.2 6690345.3 20.2))
BATIMENT0000000304020821;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;9.8;10.6;20.4;;;Cadastre;;POLYGON Z ((355858.7 6690360 20.4, 355858.2 6690355.4 20.4, 355846.2 6690345.3 20.4, 355844.6 6690347.1 20.4, 355856.3 6690356.9 20.4, 355856.9 6690359.5 20.4, 355852.8 6690365.8 20.4, 355853.9 6690366.7 20.4, 355858.7 6690360 20.4))
BATIMENT0000000304020826;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.4;9.3;12.7;13.5;10.5;Cadastre;C 0.4;POLYGON Z ((355845.4 6690358.2 12.7, 355839.4 6690353.1 12.7, 355836.3 6690350.6 12.7, 355834.9 6690352.3 12.7, 355833.1 6690354.3 12.7, 355835 6690356.4 12.7, 355842.1 6690362.3 12.7, 355845.4 6690358.2 12.7))
BATIMENT0000000304020819;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.9;10.1;15.0;16.7;11.3;Cadastre;A 1.0;POLYGON Z ((355824.8 6690363.9 15, 355839.5 6690376.5 15, 355849.8 6690385.3 15, 355857 6690374.7 15, 355850.1 6690369 15, 355842.1 6690362.3 15, 355835 6690356.4 15, 355833.1 6690354.3 15, 355824.8 6690363.9 15))
BATIMENT0000000304020820;Industriel, agricole ou commercial;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;60;20;11.1;10.0;21.2;24.0;10.6;Cadastre;A 1.0;POLYGON Z ((355859.3 6690371.3 21.2, 355853.9 6690366.7 21.2, 355852.8 6690365.8 21.2, 355850.1 6690369 21.2, 355857 6690374.7 21.2, 355859.3 6690371.3 21.2))
BATIMENT0000000304020572;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1994-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;2.0;;;6.3;11.2;17.5;20.4;11.4;Cadastre;A 1.0;POLYGON Z ((355862.3 6690384.3 17.5, 355870.1 6690390.1 17.5, 355872.6 6690391.9 17.5, 355873.2 6690391 17.5, 355873.6 6690390.3 17.5, 355875.6 6690387.6 17.5, 355877.5 6690384.8 17.5, 355878.4 6690383.5 17.5, 355887.1 6690371.1 17.5, 355880.1 6690365.1 17.5, 355874.9 6690365.6 17.5, 355862.3 6690384.3 17.5))
BATIMENT0000000304020577;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2005-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;5.0;00;00;12.7;10.7;23.5;24.9;12.2;Cadastre;B 0.5;POLYGON Z ((355878.4 6690383.5 23.5, 355877.5 6690384.8 23.5, 355879.1 6690386.2 23.5, 355879.3 6690386.4 23.5, 355879.5 6690386.5 23.5, 355879.7 6690386.5 23.5, 355879.9 6690386.6 23.5, 355880 6690386.6 23.5, 355880.3 6690386.6 23.5, 355880.4 6690386.6 23.5, 355880.5 6690386.6 23.5, 355880.6 6690386.5 23.5, 355880.8 6690386.5 23.5, 355880.9 6690386.4 23.5, 355881 6690386.3 23.5, 355881.1 6690386.3 23.5, 355881.2 6690386.2 23.5, 355881.3 6690386.2 23.5, 355881.4 6690386 23.5, 355882 6690385.1 23.5, 355883.1 6690383.5 23.5, 355887.9 6690387.6 23.5, 355888 6690387.5 23.5, 355888.7 6690386.6 23.5, 355895.2 6690378.1 23.5, 355887.1 6690371.1 23.5, 355878.4 6690383.5 23.5))
BATIMENT0000000304020584;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;1924-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;10;8.1;11.0;19.2;20.6;12.6;Cadastre;A 1.0;POLYGON Z ((355896.8 6690393.2 19.2, 355897.5 6690392.4 19.2, 355903.5 6690385.3 19.2, 355895.2 6690378.1 19.2, 355888.7 6690386.6 19.2, 355896.8 6690393.2 19.2))
BATIMENT0000000303969063;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;13;20;5.3;11.9;17.2;20.2;12.8;Cadastre;A 1.0;POLYGON Z ((356049.8 6690342.3 17.2, 356047 6690337.5 17.2, 356042.3 6690340.5 17.2, 356042.9 6690341.4 17.2, 356035.3 6690346.9 17.2, 356037.9 6690350.7 17.2, 356045.6 6690345.2 17.2, 356049.8 6690342.3 17.2))
BATIMENT0000000303967675;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.8;10.6;12.4;13.4;10.9;Cadastre;;POLYGON Z ((356009.2 6690353.3 12.4, 356012.8 6690350.8 12.4, 356009.2 6690344 12.4, 356005.9 6690346.1 12.4, 356004.8 6690346.8 12.4, 356009.2 6690353.3 12.4))
BATIMENT0000000303969064;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1982-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;90;3.1;12.2;15.3;15.3;12.7;Cadastre;B 0.3;POLYGON Z ((356029.6 6690349.7 15.3, 356023.3 6690353.9 15.3, 356024.3 6690355.6 15.3, 356018.6 6690359.4 15.3, 356019.8 6690361.2 15.3, 356020.8 6690362.8 15.3, 356036.6 6690351.6 15.3, 356030.3 6690340.3 15.3, 356026 6690343.1 15.3, 356029.6 6690349.7 15.3))
BATIMENT0000000304020873;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.0;10.2;14.2;15.5;10.6;Cadastre;;POLYGON Z ((355993.6 6690354.8 14.2, 355995 6690354 14.2, 355991.5 6690348.5 14.2, 355988.9 6690350.2 14.2, 355992.4 6690355.7 14.2, 355993.6 6690354.8 14.2))
BATIMENT0000000303969067;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;10.6;12.9;15.2;11.3;Cadastre;;POLYGON Z ((356016.7 6690349 12.9, 356015.8 6690349.5 12.9, 356015.1 6690352.1 12.9, 356014.8 6690352.3 12.9, 356014.1 6690352.7 12.9, 356016.6 6690356.5 12.9, 356019.9 6690354.1 12.9, 356016.7 6690349 12.9))
BATIMENT0000000304020874;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1983-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;20;4.6;10.7;15.3;18.7;10.8;Cadastre;A 1.0;POLYGON Z ((355987 6690347.1 15.3, 355984.8 6690358.7 15.3, 355988.1 6690362.2 15.3, 355991.8 6690366 15.3, 355997 6690362.5 15.3, 355992.4 6690355.7 15.3, 355988.9 6690350.2 15.3, 355987 6690347.1 15.3))
BATIMENT0000000304020872;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.7;10.7;15.4;;;Cadastre;;POLYGON Z ((355998.2 6690361.7 15.4, 355993.6 6690354.8 15.4, 355992.4 6690355.7 15.4, 355997 6690362.5 15.4, 355998.2 6690361.7 15.4))
BATIMENT0000000303969066;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.3;10.6;20.0;23.1;10.9;Cadastre;B 0.4;POLYGON Z ((356018.6 6690359.4 20, 356016.6 6690356.5 20, 356014.1 6690352.7 20, 356007.4 6690357.4 20, 356013 6690365.9 20, 356019.8 6690361.2 20, 356018.6 6690359.4 20))
BATIMENT0000000304020875;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.1;10.2;12.3;13.7;10.4;Cadastre;;POLYGON Z ((355984.8 6690358.7 12.3, 355984.5 6690359.8 12.3, 355984 6690361.5 12.3, 355987.5 6690363.3 12.3, 355988.1 6690362.2 12.3, 355984.8 6690358.7 12.3))
BATIMENT0000000029192331;Indifférenciée;Commercial et services;;Non;En service;2006-10-04 09:41:10;2022-01-04 14:06:39;1970-01-01;;;;BDTopo;2.5;BDTopo;1.5;1.0;2.0;;;5.5;12.0;;;;Imagerie aérienne;A 1.0;POLYGON Z ((356047.5 6690372.2 17.4, 356057.4 6690364.3 17.4, 356048.3 6690351.2 17.4, 356021 6690370 17.5, 356022.9 6690373.4 17.5, 356015.6 6690377.5 17.3, 356019.9 6690385.6 17.2, 356047.5 6690372.2 17.4))
BATIMENT0000000304020847;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1955-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;8.0;30;40;11.9;10.0;21.9;22.0;10.2;Cadastre;C 0.1;POLYGON Z ((355957.3 6690337.8 21.9, 355959.7 6690344.4 21.9, 355974.7 6690338.8 21.9, 355972.4 6690332.3 21.9, 355957.3 6690337.8 21.9))
BATIMENT0000002275364690;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:13:00;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;18.8;8.2;;;;Imagerie aérienne;;POLYGON Z ((355927 6690349.4 26.9, 355900.1 6690351.8 27, 355901.1 6690362.3 27, 355927.7 6690360.1 27, 355927 6690349.4 26.9))
BATIMENT0000002275364182;Indifférenciée;Indifférencié;;Non;En service;2021-12-05 17:13:00;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;24.3;10.9;;;;Imagerie aérienne;;POLYGON Z ((355958.5 6690361.9 35.1, 355927.5 6690364.7 35.1, 355928.5 6690375.7 35.1, 355959.7 6690372.5 35.2, 355958.5 6690361.9 35.1))
BATIMENT0000000304020624;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;18.0;5.0;50;20;13.2;10.6;23.8;27.2;11.3;Cadastre;A 1.0;POLYGON Z ((355978.9 6690389.9 23.8, 355980.8 6690385.7 23.8, 355983 6690381.5 23.8, 355984.1 6690382 23.8, 355982.7 6690385.1 23.8, 355989.2 6690388.5 23.8, 355990.9 6690386.9 23.8, 355994.4 6690379.3 23.8, 355986.3 6690375.2 23.8, 355989 6690369.6 23.8, 355982.3 6690366.2 23.8, 355978.3 6690374.4 23.8, 355978.2 6690374.6 23.8, 355973 6690384.7 23.8, 355972.7 6690385.1 23.8, 355977 6690387.9 23.8, 355978.9 6690389.9 23.8))
BATIMENT0000000304020623;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1969-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;20;8.1;10.5;18.6;20.5;11.7;Cadastre;A 1.0;POLYGON Z ((355977 6690387.9 18.6, 355972.7 6690385.1 18.6, 355965.9 6690394.2 18.6, 355969.9 6690397.3 18.6, 355970.4 6690396.6 18.6, 355970.7 6690396.2 18.6, 355977 6690387.9 18.6))
BATIMENT0000002275364336;Indifférenciée;Indifférencié;;Non;En construction;2021-12-05 17:13:00;;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;7.5;10.3;;;;Imagerie aérienne;;POLYGON Z ((355937.6 6690382.3 17.2, 355928.9 6690392.7 17.8, 355941.4 6690403.5 17.8, 355946.5 6690403 17.8, 355952.2 6690395.3 17.8, 355963.7 6690379.9 17.4, 355937.6 6690382.3 17.2))
BATIMENT0000000304020925;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1936-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;12.5;11.7;24.2;26.1;13.1;Cadastre;B 1.0;POLYGON Z ((355913.5 6690404.7 24.2, 355918.8 6690398.3 24.2, 355911.4 6690391.9 24.2, 355905.3 6690399.3 24.2, 355909.5 6690402.7 24.2, 355912.8 6690405.5 24.2, 355913.5 6690404.7 24.2))
BATIMENT0000000304020621;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1918-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;7.8;10.6;18.4;21.0;12.3;Cadastre;A 0.6;POLYGON Z ((355960.4 6690401.7 18.4, 355966.4 6690407.4 18.4, 355972.4 6690399.5 18.4, 355969.9 6690397.3 18.4, 355965.9 6690394.2 18.4, 355960.4 6690401.7 18.4))
BATIMENT0000000304020622;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1918-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.2;11.7;13.9;14.2;12.0;Cadastre;A 0.4;POLYGON Z ((355973.5 6690400.5 13.9, 355972 6690402 13.9, 355976.4 6690406.3 13.9, 355978 6690404.9 13.9, 355973.5 6690400.5 13.9))
BATIMENT0000000304020923;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.8;12.1;21.0;25.0;13.8;Cadastre;A 1.0;POLYGON Z ((355913.5 6690404.7 21, 355916.6 6690407.3 21, 355914.7 6690409.7 21, 355917.7 6690412 21, 355920.3 6690408.9 21, 355924.8 6690403.5 21, 355918.8 6690398.3 21, 355913.5 6690404.7 21))
BATIMENT0000000303967600;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.3;10.3;16.7;23.2;10.6;Cadastre;;POLYGON Z ((356002.3 6690375.9 16.7, 356005.4 6690373.7 16.7, 356001.9 6690370.1 16.7, 356000.1 6690369.7 16.7, 355998.1 6690371.6 16.7, 356002.3 6690375.9 16.7))
BATIMENT0000000303967599;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1912-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;2.7;10.2;13.0;17.7;10.6;Cadastre;B 0.2;POLYGON Z ((356002.3 6690375.9 13, 355998.1 6690371.6 13, 355997.7 6690371.2 13, 355995.5 6690373.3 13, 355999.5 6690377.9 13, 356001.6 6690376.4 13, 356002.3 6690375.9 13))
BATIMENT0000000303967598;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.3;13.0;13.1;10.6;Cadastre;A 1.0;POLYGON Z ((355996.8 6690380.8 13, 355998.8 6690382.9 13, 356003.4 6690378.3 13, 356001.6 6690376.4 13, 355999.5 6690377.9 13, 355996.8 6690380.8 13))
BATIMENT0000000303967597;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.0;13.1;10.6;Cadastre;A 1.0;POLYGON Z ((356000.9 6690385 13, 356005.5 6690380.4 13, 356003.4 6690378.3 13, 355998.8 6690382.9 13, 356000.9 6690385 13))
BATIMENT0000000303967648;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;10.4;12.9;13.1;10.6;Cadastre;A 1.0;POLYGON Z ((356002.9 6690387.2 12.9, 356007.5 6690382.5 12.9, 356005.5 6690380.4 12.9, 356000.9 6690385 12.9, 356002.9 6690387.2 12.9))
BATIMENT0000000303967647;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.0;13.3;10.6;Cadastre;A 1.0;POLYGON Z ((356005 6690389.3 13, 356009.7 6690384.8 13, 356007.5 6690382.5 13, 356002.9 6690387.2 13, 356005 6690389.3 13))
BATIMENT0000000303967646;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.6;9.2;13.8;16.2;10.6;Cadastre;A 1.0;POLYGON Z ((356007.3 6690391.7 13.8, 356012 6690387.2 13.8, 356009.7 6690384.8 13.8, 356005 6690389.3 13.8, 356007.3 6690391.7 13.8))
BATIMENT0000000303967645;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.6;9.2;13.8;14.4;10.6;Cadastre;A 1.0;POLYGON Z ((356009.3 6690393.7 13.8, 356014 6690389.2 13.8, 356012 6690387.2 13.8, 356007.3 6690391.7 13.8, 356009.3 6690393.7 13.8))
BATIMENT0000000303967644;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.5;10.4;13.9;13.9;10.9;Cadastre;A 1.0;POLYGON Z ((356011.7 6690396.2 13.9, 356017.6 6690393 13.9, 356014 6690389.2 13.9, 356009.3 6690393.7 13.9, 356011.7 6690396.2 13.9))
BATIMENT0000000304020560;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.4;10.4;12.8;13.2;11.7;Cadastre;A 1.0;POLYGON Z ((355989.7 6690392.4 12.8, 355986.2 6690396 12.8, 355985.4 6690396.8 12.8, 355987.4 6690398.9 12.8, 355991.6 6690394.4 12.8, 355989.7 6690392.4 12.8))
BATIMENT0000000303968678;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;20;10.2;14.7;25.0;27.7;16.8;Cadastre;A 1.0;POLYGON Z ((356090.2 6690337.1 25, 356098.7 6690331.5 25, 356094.5 6690323.1 25, 356085.7 6690327.6 25, 356085.6 6690327.6 25, 356084.5 6690328.3 25, 356082.7 6690329.5 25, 356084.4 6690332.9 25, 356087.3 6690331.2 25, 356090.2 6690337.1 25))
BATIMENT0000000303969089;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;10.0;18.8;28.9;29.9;19.2;Cadastre;;POLYGON Z ((356130.4 6690333.1 28.9, 356133.6 6690331.1 28.9, 356132.7 6690329.5 28.9, 356129.5 6690331.5 28.9, 356130.4 6690333.1 28.9))
BATIMENT0000000303969091;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.3;19.8;27.1;;;Cadastre;;POLYGON Z ((356134.9 6690333.4 27.1, 356131.2 6690335.6 27.1, 356132 6690336.9 27.1, 356135.7 6690334.7 27.1, 356134.9 6690333.4 27.1))
BATIMENT0000000303968679;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.6;14.7;25.4;27.4;16.9;Cadastre;A 1.0;POLYGON Z ((356090.2 6690337.1 25.4, 356089.8 6690337.2 25.4, 356091.1 6690339.9 25.4, 356092.9 6690343.7 25.4, 356097.3 6690341.2 25.4, 356102.1 6690338.5 25.4, 356098.7 6690331.5 25.4, 356090.2 6690337.1 25.4))
BATIMENT0000000303968680;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.6;14.5;23.2;25.7;15.5;Cadastre;;POLYGON Z ((356087.3 6690339 23.2, 356088.5 6690341.4 23.2, 356091.1 6690339.9 23.2, 356089.8 6690337.2 23.2, 356087.3 6690339 23.2))
BATIMENT0000000303969090;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.4;19.7;27.1;;;Cadastre;A 1.0;POLYGON Z ((356131.2 6690337.3 27.1, 356136.5 6690346.8 27.1, 356137.2 6690346.4 27.1, 356144.4 6690342.2 27.1, 356138.9 6690332.8 27.1, 356135.7 6690334.7 27.1, 356132 6690336.9 27.1, 356131.2 6690337.3 27.1))
BATIMENT0000000303968681;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.6;16.5;24.1;25.0;16.9;Cadastre;;POLYGON Z ((356098.1 6690343 24.1, 356103 6690340.2 24.1, 356102.1 6690338.5 24.1, 356097.3 6690341.2 24.1, 356098.1 6690343 24.1))
BATIMENT0000000303969140;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.8;19.1;23.0;23.4;19.7;Cadastre;;POLYGON Z ((356160.1 6690346.6 23, 356158.9 6690347.3 23, 356159.8 6690348.6 23, 356161 6690347.9 23, 356160.1 6690346.6 23))
BATIMENT0000000303968682;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;2.0;00;00;8.5;14.4;22.9;25.7;16.9;Cadastre;A 1.0;POLYGON Z ((356095.9 6690344.2 22.9, 356097.5 6690347.5 22.9, 356096.2 6690348.3 22.9, 356095.9 6690349.1 22.9, 356096.5 6690350.2 22.9, 356097.7 6690350.2 22.9, 356098.7 6690349.7 22.9, 356099.3 6690350.8 22.9, 356096.6 6690352.5 22.9, 356097.9 6690355.1 22.9, 356098.9 6690354.2 22.9, 356098.3 6690353 22.9, 356100 6690352 22.9, 356100.5 6690352.9 22.9, 356101.4 6690352.3 22.9, 356107.5 6690348.6 22.9, 356103 6690340.2 22.9, 356098.1 6690343 22.9, 356095.9 6690344.2 22.9))
BATIMENT0000000303969092;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;7.4;19.7;27.1;;;Cadastre;A 1.0;POLYGON Z ((356142 6690355 27.1, 356142.1 6690355 27.1, 356149.2 6690350.9 27.1, 356144.4 6690342.2 27.1, 356137.2 6690346.4 27.1, 356142 6690355 27.1))
BATIMENT0000000303969141;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;1.0;00;00;6.2;19.5;25.7;26.9;19.7;Cadastre;A 1.0;POLYGON Z ((356157 6690350.7 25.7, 356156.5 6690350.1 25.7, 356151.8 6690353.1 25.7, 356155.2 6690358.9 25.7, 356163.6 6690350.7 25.7, 356161 6690347.9 25.7, 356159.8 6690348.6 25.7, 356157 6690350.7 25.7))
BATIMENT0000000303968683;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;14.4;22.7;24.4;15.8;Cadastre;;POLYGON Z ((356100.7 6690354.6 22.7, 356102 6690357 22.7, 356103.5 6690356.2 22.7, 356102.1 6690353.7 22.7, 356100.7 6690354.6 22.7))
BATIMENT0000000303968684;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;20;20;10.6;14.7;25.4;26.5;16.7;Cadastre;A 1.0;POLYGON Z ((356102.1 6690353.7 25.4, 356103.5 6690356.2 25.4, 356104.4 6690358 25.4, 356105.4 6690359.9 25.4, 356106.2 6690361.5 25.4, 356106.8 6690362.5 25.4, 356113.1 6690359 25.4, 356107.5 6690348.6 25.4, 356101.4 6690352.3 25.4, 356102.1 6690353.7 25.4))
BATIMENT0000000303969093;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.8;18.4;23.2;28.1;18.9;Cadastre;;POLYGON Z ((356148 6690361.4 23.2, 356150.3 6690359.1 23.2, 356152.8 6690356.7 23.2, 356150.9 6690353.5 23.2, 356149.2 6690350.9 23.2, 356142.1 6690355 23.2, 356148 6690361.4 23.2))
BATIMENT0000000303968688;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;14.1;16.4;17.7;14.7;Cadastre;;POLYGON Z ((356095.4 6690357.2 16.4, 356094.6 6690357.7 16.4, 356095.6 6690359.4 16.4, 356098.5 6690357.5 16.4, 356097.5 6690355.4 16.4, 356095.4 6690357.2 16.4))
BATIMENT0000000303968686;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.1;14.4;19.5;22.0;15.8;Cadastre;;POLYGON Z ((356102.3 6690359.3 19.5, 356103.3 6690361.1 19.5, 356105.4 6690359.9 19.5, 356104.4 6690358 19.5, 356102.3 6690359.3 19.5))
BATIMENT0000000303968685;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.6;14.4;19.0;23.7;15.4;Cadastre;;POLYGON Z ((356101.7 6690363.9 19, 356102.3 6690365.2 19, 356104.5 6690363.9 19, 356106.8 6690362.5 19, 356106.2 6690361.5 19, 356101.7 6690363.9 19))
BATIMENT0000000303968687;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;9.6;14.6;24.3;26.0;16.7;Cadastre;A 1.0;POLYGON Z ((356108.5 6690370.5 24.3, 356116.7 6690365.3 24.3, 356115 6690362.7 24.3, 356113.1 6690359 24.3, 356106.8 6690362.5 24.3, 356104.5 6690363.9 24.3, 356108.5 6690370.5 24.3))
BATIMENT0000000303969356;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.5;13.2;14.7;16.2;13.9;Cadastre;;POLYGON Z ((356080.7 6690366.2 14.7, 356082 6690368.3 14.7, 356084.3 6690366.9 14.7, 356083 6690364.8 14.7, 356080.7 6690366.2 14.7))
BATIMENT0000000303968612;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.0;17.0;21.0;23.2;18.5;Cadastre;A 1.0;POLYGON Z ((356139.1 6690366.8 21, 356136.7 6690362.8 21, 356130.2 6690366.5 21, 356132.7 6690370.5 21, 356139.1 6690366.8 21))
BATIMENT0000000303968428;Indifférenciée;Annexe;Résidentiel;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;2.0;00;00;5.4;22.8;28.3;28.4;23.6;Cadastre;C 0.1;POLYGON Z ((356386 6690370.8 28.3, 356396 6690365 28.3, 356380.1 6690339.3 28.3, 356369.9 6690345.5 28.3, 356386 6690370.8 28.3))
BATIMENT0000000303969365;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.3;22.7;24.0;24.4;23.3;Cadastre;;POLYGON Z ((356400 6690355.6 24, 356401.8 6690358.6 24, 356404.2 6690355.9 24, 356402.8 6690353.7 24, 356400 6690355.6 24))
BATIMENT0000000303968049;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.9;21.4;28.3;;;Cadastre;A 1.0;POLYGON Z ((356505.8 6690356.5 28.3, 356506.2 6690356.9 28.3, 356502.8 6690361.1 28.3, 356506.81139568595 6690363.591927623 28.3, 356506.81139568595 6690355.263849717 28.3, 356505.8 6690356.5 28.3))
BATIMENT0000000303969308;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1977-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;30;10;4.0;23.2;27.2;27.6;23.4;Cadastre;C 0.3;POLYGON Z ((356355.7 6690362.3 27.2, 356358.8 6690367.4 27.2, 356361.4 6690365.9 27.2, 356358.2 6690360.7 27.2, 356355.7 6690362.3 27.2))
BATIMENT0000000303968623;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;6.2;22.5;28.7;;;Cadastre;A 1.0;POLYGON Z ((356479.3 6690361 28.7, 356474.7 6690368.2 28.7, 356483.4 6690373.6 28.7, 356487.8 6690366.4 28.7, 356479.3 6690361 28.7))
BATIMENT0000000303969188;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;15;12;5.6;21.2;26.9;32.4;22.4;Cadastre;A 1.0;POLYGON Z ((356460.5 6690373.5 26.9, 356468.7 6690385.4 26.9, 356471.1 6690383.7 26.9, 356469.3 6690381 26.9, 356468.4 6690381.6 26.9, 356467.3 6690380 26.9, 356467.8 6690379.7 26.9, 356464.2 6690374.4 26.9, 356466.3 6690373 26.9, 356464.6 6690370 26.9, 356465 6690369.5 26.9, 356461.5 6690364.8 26.9, 356468.9 6690359.6 26.9, 356465 6690354.3 26.9, 356452.9 6690362.6 26.9, 356458.3 6690370.4 26.9, 356460.5 6690373.5 26.9))
BATIMENT0000000303969175;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;4.0;22.7;26.7;32.9;23.1;Cadastre;A 1.0;POLYGON Z ((356309.8 6690378.7 26.7, 356319.6 6690372.7 26.7, 356319.8 6690372.6 26.7, 356317.7 6690369.5 26.7, 356318 6690368.6 26.7, 356316.4 6690365.8 26.7, 356315.3 6690365.6 26.7, 356313.7 6690362.7 26.7, 356313.5 6690362.8 26.7, 356303.6 6690368.7 26.7, 356309.8 6690378.7 26.7))
BATIMENT0000000303969187;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;20;6.0;22.7;28.7;31.7;22.8;Cadastre;A 1.0;POLYGON Z ((356440 6690371.3 28.7, 356445.3 6690378.9 28.7, 356458.3 6690370.4 28.7, 356452.9 6690362.6 28.7, 356440 6690371.3 28.7))
BATIMENT0000000303968624;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;6.8;21.9;28.7;30.6;22.5;Cadastre;A 1.0;POLYGON Z ((356491.8 6690378.9 28.7, 356496.2 6690371.7 28.7, 356487.8 6690366.4 28.7, 356483.4 6690373.6 28.7, 356491.8 6690378.9 28.7))
BATIMENT0000000303969216;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.2;23.0;25.2;27.0;23.4;Cadastre;C 0.3;POLYGON Z ((356355.1 6690378.3 25.2, 356348.7 6690367.9 25.2, 356343.5 6690371.1 25.2, 356350.1 6690381.3 25.2, 356353 6690379.5 25.2, 356355.1 6690378.3 25.2))
BATIMENT0000000303969131;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.4;21.3;27.7;31.8;22.7;Cadastre;;POLYGON Z ((356210.9 6690343.1 27.7, 356210.6 6690342.7 27.7, 356207.8 6690343.8 27.7, 356208 6690344.2 27.7, 356205.2 6690345.2 27.7, 356205.5 6690346.1 27.7, 356199.4 6690348.5 27.7, 356202.7 6690356.4 27.7, 356208.7 6690354 27.7, 356209.2 6690354.9 27.7, 356217.5 6690351.5 27.7, 356217.1 6690350.2 27.7, 356223 6690347.6 27.7, 356234.4 6690342.6 27.7, 356231.2 6690335.1 27.7, 356219.7 6690339.9 27.7, 356213.9 6690342.2 27.7, 356213.7 6690341.9 27.7, 356210.9 6690343.1 27.7))
BATIMENT0000000303969010;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.7;23.0;31.7;33.4;23.6;Cadastre;;POLYGON Z ((356264.6 6690350.8 31.7, 356265.5 6690352.2 31.7, 356266.6 6690351.5 31.7, 356266.7 6690351.5 31.7, 356265.8 6690350.1 31.7, 356264.6 6690350.8 31.7))
BATIMENT0000000303969007;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;3.0;00;00;11.4;21.7;33.2;36.0;23.6;Cadastre;A 1.0;POLYGON Z ((356264.6 6690350.8 33.2, 356265.8 6690350.1 33.2, 356266.7 6690351.5 33.2, 356266.6 6690351.5 33.2, 356270.1 6690357.4 33.2, 356273.1 6690362.6 33.2, 356281.1 6690357.4 33.2, 356271.5 6690341.6 33.2, 356265 6690346.5 33.2, 356260.1 6690350.2 33.2, 356262 6690352.3 33.2, 356264.6 6690350.8 33.2))
BATIMENT0000000303969358;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;4.6;19.3;24.0;25.5;20.5;Cadastre;;POLYGON Z ((356180.5 6690354.5 24, 356181.6 6690356.8 24, 356182.3 6690356.6 24, 356182.2 6690356.2 24, 356183.9 6690355.6 24, 356184.1 6690356 24, 356184.6 6690355.8 24, 356183 6690352.1 24, 356180.5 6690354.5 24))
BATIMENT0000000303969178;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.9;23.3;29.2;32.6;23.3;Cadastre;B 0.8;POLYGON Z ((356303.6 6690368.7 29.2, 356313.5 6690362.8 29.2, 356313.7 6690362.7 29.2, 356316.1 6690361.2 29.2, 356313.1 6690356.7 29.2, 356309.2 6690359.1 29.2, 356308.1 6690357.6 29.2, 356306.6 6690358.4 29.2, 356303 6690352.7 29.2, 356306.3 6690350.8 29.2, 356305.4 6690349.2 29.2, 356302.2 6690351.2 29.2, 356295.4 6690355.3 29.2, 356303.6 6690368.7 29.2))
BATIMENT0000000303969006;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.6;21.6;28.2;36.5;23.4;Cadastre;;POLYGON Z ((356270.1 6690357.4 28.2, 356267.7 6690358.5 28.2, 356269.1 6690361.7 28.2, 356270.3 6690364.4 28.2, 356273.1 6690362.6 28.2, 356270.1 6690357.4 28.2))
BATIMENT0000000303969002;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2011-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;00;00;13.3;21.6;35.0;38.7;23.2;Cadastre;A 1.0;POLYGON Z ((356273.1 6690362.6 35, 356270.3 6690364.4 35, 356277 6690379.6 35, 356283.8 6690376 35, 356290.3 6690372.6 35, 356281.1 6690357.4 35, 356273.1 6690362.6 35))
BATIMENT0000000303969001;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;20;20;10.1;22.0;32.2;35.3;23.1;Cadastre;A 1.0;POLYGON Z ((356290.2 6690386.7 32.2, 356296.5 6690382.9 32.2, 356290.3 6690372.6 32.2, 356283.8 6690376 32.2, 356285.2 6690378.4 32.2, 356290.2 6690386.7 32.2))
BATIMENT0000000303969004;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;6.5;21.9;28.4;31.2;23.2;Cadastre;;POLYGON Z ((356279.3 6690383.7 28.4, 356283.1 6690382.3 28.4, 356283 6690381.6 28.4, 356284.7 6690380.8 28.4, 356284.1 6690379.2 28.4, 356285.2 6690378.4 28.4, 356283.8 6690376 28.4, 356277 6690379.6 28.4, 356279.3 6690383.7 28.4))
BATIMENT0000000303969003;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1957-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;6.0;50;20;15.5;21.6;37.2;39.4;22.9;Cadastre;A 1.0;POLYGON Z ((356288.5 6690387.7 37.2, 356296 6690400.3 37.2, 356304 6690395.4 37.2, 356296.5 6690382.9 37.2, 356290.2 6690386.7 37.2, 356288.5 6690387.7 37.2))
BATIMENT0000000303968625;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;6.5;22.2;28.7;;;Cadastre;A 1.0;POLYGON Z ((356500.1 6690384.1 28.7, 356504.5 6690377 28.7, 356496.2 6690371.7 28.7, 356491.8 6690378.9 28.7, 356500.1 6690384.1 28.7))
BATIMENT0000000303969190;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.2;22.2;24.4;25.2;22.4;Cadastre;A 1.0;POLYGON Z ((356476.1 6690380.3 24.4, 356473.1 6690375.8 24.4, 356470.3 6690377.8 24.4, 356473.4 6690382.1 24.4, 356476.1 6690380.3 24.4))
BATIMENT0000000303968433;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;14.0;3.0;00;00;7.8;21.9;29.7;33.0;23.6;Cadastre;C 0.7;POLYGON Z ((356389.7 6690394.2 29.7, 356415.1 6690378.6 29.7, 356406.8 6690364.5 29.7, 356398.8 6690369.3 29.7, 356401.5 6690374.2 29.7, 356396.2 6690377.7 29.7, 356394.1 6690375.2 29.7, 356389.7 6690378.1 29.7, 356390.5 6690380.4 29.7, 356387.9 6690382.1 29.7, 356384.7 6690378.2 29.7, 356381.2 6690380.4 29.7, 356384.3 6690385.3 29.7, 356389.7 6690394.2 29.7))
BATIMENT0000000303969174;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;20;5.8;22.7;28.5;32.8;23.0;Cadastre;B 0.7;POLYGON Z ((356315.8 6690388.6 28.5, 356326.8 6690381.9 28.5, 356320.8 6690372 28.5, 356319.8 6690372.6 28.5, 356319.6 6690372.7 28.5, 356309.8 6690378.7 28.5, 356315.8 6690388.6 28.5))
BATIMENT0000000303969189;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.2;22.2;24.4;25.3;22.4;Cadastre;;POLYGON Z ((356473.4 6690382.1 24.4, 356470.3 6690377.8 24.4, 356468.2 6690379.3 24.4, 356469.3 6690381 24.4, 356471.1 6690383.7 24.4, 356473.4 6690382.1 24.4))
BATIMENT0000000303969217;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.2;23.0;25.2;26.1;23.1;Cadastre;;POLYGON Z ((356353.4 6690386.6 25.2, 356356.3 6690384.8 25.2, 356353 6690379.5 25.2, 356350.1 6690381.3 25.2, 356353.4 6690386.6 25.2))
BATIMENT0000000303968626;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;25;20;6.3;22.4;28.7;;;Cadastre;A 1.0;POLYGON Z ((356499.8 6690384.6 28.7, 356506.81139568595 6690388.894479858 28.7, 356506.81139568595 6690378.42678746 28.7, 356504.5 6690377 28.7, 356500.1 6690384.1 28.7, 356499.8 6690384.6 28.7))
BATIMENT0000000303969218;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.2;23.0;25.2;25.5;23.2;Cadastre;;POLYGON Z ((356350.7 6690388.2 25.2, 356352.3 6690391 25.2, 356360 6690386.2 25.2, 356358.3 6690383.6 25.2, 356356.3 6690384.8 25.2, 356353.4 6690386.6 25.2, 356350.7 6690388.2 25.2))
BATIMENT0000000303969172;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;8.0;4.0;00;00;12.4;22.5;35.0;36.9;23.1;Cadastre;C 0.7;POLYGON Z ((356322.2 6690399 35, 356328.8 6690395 35, 356331.1 6690393.6 35, 356331.8 6690393.2 35, 356335.2 6690391.1 35, 356328.7 6690380.8 35, 356326.8 6690381.9 35, 356315.8 6690388.6 35, 356322.2 6690399 35))
BATIMENT0000000303968432;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1880-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.0;24.0;29.0;;;Cadastre;A 1.0;POLYGON Z ((356380 6690387.9 29, 356377.5 6690383.8 29, 356372.8 6690386.7 29, 356375.7 6690391.5 29, 356380.6 6690399.5 29, 356389.7 6690394.2 29, 356384.3 6690385.3 29, 356380 6690387.9 29))
BATIMENT0000000303968611;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.9;17.0;20.9;20.9;18.4;Cadastre;A 1.0;POLYGON Z ((356132.7 6690370.5 20.9, 356135.2 6690374.4 20.9, 356140 6690374.9 20.9, 356138.6 6690372.4 20.9, 356141.3 6690370.6 20.9, 356139.1 6690366.8 20.9, 356132.7 6690370.5 20.9))
BATIMENT0000000303968689;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1874-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;7.8;16.1;23.9;26.0;16.7;Cadastre;A 1.0;POLYGON Z ((356112.4 6690376.9 23.9, 356120.6 6690371.3 23.9, 356116.7 6690365.3 23.9, 356108.5 6690370.5 23.9, 356112.4 6690376.9 23.9))
BATIMENT0000000303968690;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;9.9;14.8;24.7;27.2;15.6;Cadastre;;POLYGON Z ((356110.2 6690378.4 24.7, 356112 6690381.9 24.7, 356114.1 6690380.4 24.7, 356112.1 6690377.1 24.7, 356110.2 6690378.4 24.7))
BATIMENT0000000303968691;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;7.0;4.0;10;20;12.5;15.2;27.7;30.9;16.8;Cadastre;A 1.0;POLYGON Z ((356112.1 6690377.1 27.7, 356114.1 6690380.4 27.7, 356116.6 6690384.9 27.7, 356120.9 6690391.8 27.7, 356126.6 6690386.2 27.7, 356127 6690381.2 27.7, 356120.6 6690371.3 27.7, 356112.4 6690376.9 27.7, 356112.1 6690377.1 27.7))
BATIMENT0000000303968616;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;1.7;14.0;15.7;;;Cadastre;;POLYGON Z ((356063.1 6690371.9 15.7, 356073.8 6690391.5 15.7, 356072.9 6690391.9 15.7, 356080.6 6690407.8 15.7, 356084.7 6690405.7 15.7, 356085.7 6690405.1 15.7, 356078.3 6690390.4 15.7, 356077.8 6690389.5 15.7, 356078.8 6690389 15.7, 356067.9 6690369.1 15.7, 356063.1 6690371.9 15.7))
BATIMENT0000000303968698;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.0;14.9;27.0;29.0;16.6;Cadastre;;POLYGON Z ((356113.9 6690387.4 27, 356119.6 6690393.1 27, 356120.9 6690391.8 27, 356116.6 6690384.9 27, 356113.9 6690387.4 27))
BATIMENT0000000303968692;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1908-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;14;20;11.9;14.0;25.9;29.0;16.6;Cadastre;A 1.0;POLYGON Z ((356112.4 6690386.2 25.9, 356105.1 6690392.9 25.9, 356107.7 6690395.9 25.9, 356105 6690399.6 25.9, 356108.7 6690403.7 25.9, 356119.6 6690393.1 25.9, 356113.9 6690387.4 25.9, 356112.4 6690386.2 25.9))
BATIMENT0000000303969150;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;15.4;13.0;28.4;;;Cadastre;C 0.1;POLYGON Z ((356034.7 6690400.5 28.4, 356038.8 6690408.2 28.4, 356067.2 6690393 28.4, 356063.1 6690385.4 28.4, 356034.7 6690400.5 28.4))
BATIMENT0000000303968693;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;02;02;3.3;15.8;19.1;20.5;16.4;Cadastre;A 0.4;POLYGON Z ((356100.8 6690401.6 19.1, 356105.6 6690406.8 19.1, 356108.7 6690403.7 19.1, 356105 6690399.6 19.1, 356100.8 6690401.6 19.1))
BATIMENT0000000303968694;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;02;02;3.3;15.4;18.8;19.4;16.3;Cadastre;A 1.0;POLYGON Z ((356097.1 6690403.5 18.8, 356098.2 6690404.7 18.8, 356102.7 6690409.6 18.8, 356105.6 6690406.8 18.8, 356100.8 6690401.6 18.8, 356097.1 6690403.5 18.8))
BATIMENT0000000303968530;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1873-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;3.9;21.8;25.7;32.0;22.9;Cadastre;A 1.0;POLYGON Z ((356407.8 6690404.2 25.7, 356419.5 6690397 25.7, 356416.6 6690392.1 25.7, 356421.5 6690389.2 25.7, 356422.8 6690391.4 25.7, 356424.1 6690390.6 25.7, 356428.5 6690397.9 25.7, 356435.2 6690394.1 25.7, 356428.2 6690382.6 25.7, 356428 6690382.3 25.7, 356427.7 6690382 25.7, 356427.4 6690381.7 25.7, 356427 6690381.5 25.7, 356426.7 6690381.2 25.7, 356426.4 6690381 25.7, 356426 6690380.8 25.7, 356425.6 6690380.7 25.7, 356425.2 6690380.6 25.7, 356402 6690394.2 25.7, 356405.6 6690400.4 25.7, 356407.8 6690404.2 25.7))
BATIMENT0000000303968604;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;5.5;22.2;27.7;30.6;23.1;Cadastre;A 1.0;POLYGON Z ((356448.6 6690384.1 27.7, 356439.6 6690390.1 27.7, 356445.7 6690402.1 27.7, 356455.2 6690397.4 27.7, 356448.6 6690384.1 27.7))
BATIMENT0000000303968434;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1995-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;35;39;4.8;24.0;28.8;;;Cadastre;C 0.7;POLYGON Z ((356360.7 6690395.7 28.8, 356360.4 6690395.1 28.8, 356357.1 6690397.1 28.8, 356356.8 6690396.8 28.8, 356355.3 6690397.7 28.8, 356359.7 6690405.1 28.8, 356364.4 6690402.5 28.8, 356369.2 6690400 28.8, 356371.9 6690404.6 28.8, 356377.4 6690401.4 28.8, 356372.5 6690393.4 28.8, 356375.7 6690391.5 28.8, 356372.8 6690386.7 28.8, 356370.5 6690382.8 28.8, 356366.5 6690385.2 28.8, 356369.5 6690390.2 28.8, 356360.7 6690395.7 28.8))
BATIMENT0000000303968435;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;22.6;27.7;31.0;23.0;Cadastre;;POLYGON Z ((356352.3 6690395 27.7, 356352.1 6690396.5 27.7, 356353.6 6690398.8 27.7, 356355.3 6690397.7 27.7, 356356.8 6690396.8 27.7, 356354.8 6690393.5 27.7, 356352.3 6690395 27.7))
BATIMENT0000000303968061;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;01;02;3.0;22.9;25.9;;;Cadastre;B 0.2;POLYGON Z ((356502 6690396.9 25.9, 356506.4 6690403.3 25.9, 356506.81139568595 6690403.035531345 25.9, 356506.81139568595 6690393.549206576 25.9, 356502 6690396.9 25.9))
BATIMENT0000000303968529;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;03;04;3.0;22.0;25.0;31.2;22.7;Cadastre;C 0.4;POLYGON Z ((356398.2 6690396.4 25, 356402.1 6690402.6 25, 356405.6 6690400.4 25, 356402 6690394.2 25, 356398.2 6690396.4 25))
BATIMENT0000000303969170;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1895-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;20;6.9;24.0;30.9;;;Cadastre;C 0.6;POLYGON Z ((356328.8 6690395 30.9, 356322.2 6690399 30.9, 356325.4 6690404.3 30.9, 356332 6690400.2 30.9, 356334.6 6690398.7 30.9, 356335.2 6690398.3 30.9, 356335 6690396.8 30.9, 356333.4 6690394.1 30.9, 356331.8 6690393.2 30.9, 356331.1 6690393.6 30.9, 356328.8 6690395 30.9))
BATIMENT0000000303968531;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;10;20;5.8;22.1;28.0;30.5;23.2;Cadastre;A 1.0;POLYGON Z ((356427.8 6690398.3 28, 356430.4 6690403.4 28, 356438 6690399.7 28, 356435.2 6690394.1 28, 356428.5 6690397.9 28, 356427.8 6690398.3 28))
BATIMENT0000000303968603;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1934-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.2;22.3;29.6;33.8;23.0;Cadastre;A 1.0;POLYGON Z ((356455.9 6690399 29.6, 356458.6 6690397.5 29.6, 356457.8 6690396.2 29.6, 356455.2 6690397.4 29.6, 356445.7 6690402.1 29.6, 356449.6 6690409.8 29.6, 356458.7 6690405 29.6, 356455.9 6690399 29.6))
BATIMENT0000000303968532;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.2;22.2;30.5;33.7;23.6;Cadastre;A 1.0;POLYGON Z ((356432.9 6690408.7 30.5, 356440.8 6690404.9 30.5, 356438 6690399.7 30.5, 356430.4 6690403.4 30.5, 356432.9 6690408.7 30.5))
BATIMENT0000000303969177;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.6;24.0;26.6;;;Cadastre;;POLYGON Z ((356355.8 6690407.4 26.6, 356351.4 6690400.1 26.6, 356347.9 6690402.2 26.6, 356352.3 6690409.4 26.6, 356355.8 6690407.4 26.6))
BATIMENT0000000303969171;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.9;22.5;31.4;34.0;23.0;Cadastre;A 1.0;POLYGON Z ((356330.6 6690412.7 31.4, 356339.9 6690407.1 31.4, 356334.6 6690398.7 31.4, 356332 6690400.2 31.4, 356325.4 6690404.3 31.4, 356330.6 6690412.7 31.4))
BATIMENT0000000303969176;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;2.7;24.0;26.7;;;Cadastre;A 1.0;POLYGON Z ((356352.3 6690409.4 26.7, 356347.9 6690402.2 26.7, 356344.7 6690404.1 26.7, 356349.3 6690411.3 26.7, 356352.3 6690409.4 26.7))
BATIMENT0000000303968590;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;5.6;22.9;28.5;30.3;23.3;Cadastre;C 0.8;POLYGON Z ((356382.4 6690406.1 28.5, 356387.8 6690415 28.5, 356400.4 6690407.9 28.5, 356394.7 6690398.8 28.5, 356382.4 6690406.1 28.5))
BATIMENT0000000303969173;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1870-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;20;20;3.5;24.0;27.5;;;Cadastre;A 1.0;POLYGON Z ((356333.2 6690416.9 27.5, 356343.5 6690410.2 27.5, 356345.6 6690413.5 27.5, 356349.3 6690411.3 27.5, 356344.7 6690404.1 27.5, 356339.9 6690407.1 27.5, 356330.6 6690412.7 27.5, 356333.2 6690416.9 27.5))
BATIMENT0000000303968605;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;10.6;22.6;33.2;35.4;23.0;Cadastre;A 1.0;POLYGON Z ((356458.7 6690405 33.2, 356449.6 6690409.8 33.2, 356453.2 6690416.9 33.2, 356459.8 6690412.2 33.2, 356461.7 6690410.9 33.2, 356458.7 6690405 33.2))
BATIMENT0000000303968533;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;7.9;22.5;30.5;34.2;23.6;Cadastre;A 1.0;POLYGON Z ((356431.8 6690409.2 30.5, 356435.2 6690416.3 30.5, 356438.5 6690414.7 30.5, 356441.2 6690419.9 30.5, 356446.6 6690416.9 30.5, 356440.8 6690404.9 30.5, 356432.9 6690408.7 30.5, 356431.8 6690409.2 30.5))
BATIMENT0000000303969186;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;5.0;23.4;28.4;;;Cadastre;B 0.8;POLYGON Z ((356505.9 6690410 28.4, 356504.8 6690408.6 28.4, 356503.3 6690409.6 28.4, 356504.3 6690411.1 28.4, 356506.81139568595 6690414.793228949 28.4, 356506.81139568595 6690409.427122711 28.4, 356505.9 6690410 28.4))
BATIMENT0000000303968589;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1935-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;23;9.1;22.1;31.2;38.7;23.3;Cadastre;A 1.0;POLYGON Z ((356386.4 6690415.3 31.2, 356382.2 6690408 31.2, 356378.2 6690410.3 31.2, 356377.3 6690409.1 31.2, 356373.1 6690411.5 31.2, 356375 6690414.5 31.2, 356378.2 6690420 31.2, 356386.4 6690415.3 31.2))
BATIMENT0000000303969185;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;4.8;23.3;28.1;;;Cadastre;A 1.0;POLYGON Z ((356493.8 6690418 28.1, 356494.4 6690418.9 28.1, 356499 6690425.6 28.1, 356506.81139568595 6690420.342329826 28.1, 356506.81139568595 6690414.793228949 28.1, 356504.3 6690411.1 28.1, 356493.8 6690418 28.1))
BATIMENT0000000303968606;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1913-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;4.4;22.7;27.2;34.2;23.5;Cadastre;A 1.0;POLYGON Z ((356467.2 6690422.8 27.2, 356470 6690420.9 27.2, 356468.1 6690418.2 27.2, 356465.2 6690420.3 27.2, 356462.3 6690416.1 27.2, 356464.4 6690414.5 27.2, 356464.9 6690415.1 27.2, 356467 6690413.6 27.2, 356466.9 6690412.5 27.2, 356467.6 6690412 27.2, 356465 6690408.6 27.2, 356461.7 6690410.9 27.2, 356459.8 6690412.2 27.2, 356453.2 6690416.9 27.2, 356457.8 6690423.2 27.2, 356458.9 6690422.4 27.2, 356459.8 6690423.8 27.2, 356458.6 6690424.7 27.2, 356457.6 6690425.5 27.2, 356459.2 6690428.5 27.2, 356461.7 6690426.7 27.2, 356467.2 6690422.8 27.2))
BATIMENT0000000303969182;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;22.9;25.9;;;Cadastre;;POLYGON Z ((356480.3 6690412 25.9, 356478.2 6690413.5 25.9, 356483.2 6690421.5 25.9, 356485.4 6690425.1 25.9, 356487.5 6690423.7 25.9, 356480.3 6690412 25.9))
BATIMENT0000000303969009;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;15;20;9.5;22.4;32.0;33.2;23.0;Cadastre;A 1.0;POLYGON Z ((356313.6 6690410.8 32, 356307.1 6690414.8 32, 356309 6690417.9 32, 356306.6 6690419.2 32, 356307.8 6690421.7 32, 356306.7 6690422.6 32, 356307.8 6690424.3 32, 356311.3 6690422 32, 356313.2 6690424.7 32, 356315 6690428.1 32, 356319.5 6690427.2 32, 356322.9 6690426.7 32, 356319.5 6690420.8 32, 356313.6 6690410.8 32))
BATIMENT0000000303969184;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;23.4;28.0;;;Cadastre;;POLYGON Z ((356497.6 6690426.5 28, 356499 6690425.6 28, 356494.4 6690418.9 28, 356493.1 6690419.8 28, 356497.6 6690426.5 28))
BATIMENT0000000303968607;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;5.0;22.9;27.9;30.5;23.2;Cadastre;;POLYGON Z ((356458.6 6690424.7 27.9, 356459.8 6690423.8 27.9, 356458.9 6690422.4 27.9, 356457.8 6690423.2 27.9, 356458.6 6690424.7 27.9))
BATIMENT0000000303968588;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;6.0;13;30;16.4;22.2;38.7;40.2;23.0;Cadastre;C 0.3;POLYGON Z ((356358 6690424.6 38.7, 356362.8 6690433.2 38.7, 356369.5 6690429.3 38.7, 356369.8 6690430 38.7, 356374.4 6690427.5 38.7, 356374.1 6690426.7 38.7, 356380.1 6690423.1 38.7, 356378.2 6690420 38.7, 356375 6690414.5 38.7, 356358 6690424.6 38.7))
BATIMENT0000000303968534;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1946-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;20;7.3;22.1;29.4;32.1;23.3;Cadastre;A 1.0;POLYGON Z ((356438.3 6690421.5 29.4, 356440.7 6690425.7 29.4, 356434.1 6690429.2 29.4, 356435.2 6690431.3 29.4, 356441.6 6690427.8 29.4, 356449.7 6690423.2 29.4, 356446.6 6690416.9 29.4, 356441.2 6690419.9 29.4, 356438.3 6690421.5 29.4))
BATIMENT0000000303969362;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;7.5;23.2;30.7;33.5;23.5;Cadastre;;POLYGON Z ((356409.6 6690424.3 30.7, 356410.5 6690426 30.7, 356413.2 6690424.6 30.7, 356412.4 6690422.9 30.7, 356409.6 6690424.3 30.7))
BATIMENT0000000303968587;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;22.2;26.3;29.2;22.7;Cadastre;;POLYGON Z ((356356.2 6690425.3 26.3, 356354.4 6690422.3 26.3, 356348.8 6690423.7 26.3, 356351.4 6690428.2 26.3, 356356.2 6690425.3 26.3))
BATIMENT0000000303969183;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;4.9;23.1;28.0;;;Cadastre;A 1.0;POLYGON Z ((356497.6 6690426.5 28, 356493.1 6690419.8 28, 356487.5 6690423.7 28, 356485.4 6690425.1 28, 356489.7 6690431.8 28, 356497.6 6690426.5 28))
BATIMENT0000000303968695;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;7.5;14.5;22.0;25.4;16.3;Cadastre;A 1.0;POLYGON Z ((356095.3 6690407.6 22, 356094.9 6690407.1 22, 356090.1 6690412 22, 356094.9 6690417.2 22, 356102.7 6690409.6 22, 356098.2 6690404.7 22, 356095.3 6690407.6 22))
BATIMENT0000000303968714;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;4.0;20;20;10.0;15.5;25.5;28.5;17.0;Cadastre;A 1.0;POLYGON Z ((356127.8 6690405.6 25.5, 356141.7 6690428.1 25.5, 356151.1 6690422.1 25.5, 356140.6 6690405.1 25.5, 356136.5 6690407.8 25.5, 356132.3 6690401.3 25.5, 356127.8 6690405.6 25.5))
BATIMENT0000000303968696;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;24;10;7.6;13.3;21.0;23.7;16.2;Cadastre;A 1.0;POLYGON Z ((356088.9 6690411 21, 356081.3 6690418.3 21, 356087.3 6690424.7 21, 356094.9 6690417.2 21, 356090.1 6690412 21, 356088.9 6690411 21))
BATIMENT0000000303967643;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;11.0;14.1;15.5;13.1;Cadastre;;POLYGON Z ((356054.9 6690424.8 14.1, 356065.3 6690419.7 14.1, 356066.7 6690419 14.1, 356064.3 6690413.6 14.1, 356043.2 6690424.2 14.1, 356045 6690429.7 14.1, 356054.9 6690424.8 14.1))
BATIMENT0000000303968697;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1959-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;50;90;17.3;13.1;30.5;31.6;16.2;Cadastre;C 0.9;POLYGON Z ((356080.7 6690417.9 30.5, 356073 6690425.4 30.5, 356074.3 6690426.9 30.5, 356079.5 6690432.3 30.5, 356087.3 6690424.7 30.5, 356081.3 6690418.3 30.5, 356080.7 6690417.9 30.5))
BATIMENT0000000303968668;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;12;20;9.5;14.2;23.7;26.9;16.3;Cadastre;A 1.0;POLYGON Z ((356114.6 6690434 23.7, 356121.2 6690427.6 23.7, 356121 6690426.1 23.7, 356114.3 6690418.9 23.7, 356106.9 6690426.1 23.7, 356113.3 6690432.6 23.7, 356114.6 6690434 23.7))
BATIMENT0000000303968568;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;7.6;15.3;23.0;25.7;17.2;Cadastre;A 1.0;POLYGON Z ((356152.5 6690424.4 23, 356145.4 6690429 23, 356147.6 6690432.5 23, 356145 6690434 23, 356145.1 6690434.8 23, 356148.2 6690440.3 23, 356152.5 6690437.9 23, 356151.9 6690436.8 23, 356153.2 6690436 23, 356155 6690439.2 23, 356160.1 6690436.7 23, 356152.5 6690424.4 23))
BATIMENT0000000303968667;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;50;10;9.4;14.2;23.6;24.7;16.3;Cadastre;A 1.0;POLYGON Z ((356099.9 6690432.9 23.6, 356106.3 6690439.4 23.6, 356113.3 6690432.6 23.6, 356106.9 6690426.1 23.6, 356099.9 6690432.9 23.6))
BATIMENT0000000303968699;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1931-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;9.5;11.6;21.2;27.2;16.0;Cadastre;A 1.0;POLYGON Z ((356066.5 6690434.4 21.2, 356071.7 6690439.9 21.2, 356079.5 6690432.3 21.2, 356074.3 6690426.9 21.2, 356066.5 6690434.4 21.2))
BATIMENT0000000303968669;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;11.7;13.3;25.0;27.6;16.1;Cadastre;A 1.0;POLYGON Z ((356094.3 6690438.4 25, 356100.8 6690445.1 25, 356106.3 6690439.4 25, 356099.9 6690432.9 25, 356094.3 6690438.4 25))
BATIMENT0000000302944568;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;11.0;4.0;00;00;10.9;8.3;19.2;;;Cadastre;A 1.0;POLYGON Z ((355610 6690289.4 19.2, 355613.7 6690288.4 19.2, 355615.4 6690268.1 19.2, 355606.9 6690267.7 19.2, 355604.5 6690267.6 19.2, 355596.3 6690275 19.2, 355610 6690289.4 19.2))
BATIMENT0000000302944682;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;16.0;4.0;10;20;12.9;7.5;20.4;23.9;9.7;Cadastre;A 1.0;POLYGON Z ((355558.6 6690269.8 20.4, 355565.4 6690278.5 20.4, 355565.1 6690278.8 20.4, 355571.8 6690287 20.4, 355572.2 6690286.6 20.4, 355573.8 6690286.7 20.4, 355576.2 6690289.9 20.4, 355579.3 6690287.4 20.4, 355581 6690289.3 20.4, 355577 6690292.7 20.4, 355580 6690296.6 20.4, 355593 6690286.1 20.4, 355569.6 6690261 20.4, 355560.7 6690268.1 20.4, 355558.6 6690269.8 20.4), (355564.2 6690271.2 20.4, 355573.8 6690281.5 20.4, 355572.3 6690282.8 20.4, 355565.7 6690273.9 20.4, 355564.2 6690274.1 20.4, 355562.8 6690272.4 20.4, 355563.5 6690271.8 20.4, 355564.2 6690271.2 20.4))
BATIMENT0000000302944824;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;2.0;2.0;00;00;8.0;7.4;15.5;39.2;10.0;Cadastre;A 1.0;POLYGON Z ((355589.3 6690294.8 15.5, 355590.8 6690296.7 15.5, 355588.1 6690299 15.5, 355590.4 6690301.8 15.5, 355599.6 6690294.1 15.5, 355595.4 6690289.6 15.5, 355589.3 6690294.8 15.5))
BATIMENT0000000302944837;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;5.0;7.2;12.2;22.7;10.0;Cadastre;;POLYGON Z ((355595.8 6690299.5 12.2, 355599.2 6690304.1 12.2, 355605.1 6690299.6 12.2, 355600.9 6690295.4 12.2, 355595.8 6690299.5 12.2))
BATIMENT0000000302944353;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;10;20;7.6;7.1;14.7;16.9;9.8;Cadastre;A 1.0;POLYGON Z ((355611.6 6690315.7 14.7, 355611.7 6690314 14.7, 355612.1 6690308.1 14.7, 355609.8 6690309.5 14.7, 355606.9 6690311.4 14.7, 355603.2 6690314.6 14.7, 355611.6 6690315.7 14.7))
BATIMENT0000000302944352;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;8.2;7.2;15.5;16.9;10.7;Cadastre;A 0.8;POLYGON Z ((355602.5 6690320 15.5, 355599.4 6690324 15.5, 355607 6690324.9 15.5, 355610.5 6690320.9 15.5, 355611.1 6690320.7 15.5, 355611.6 6690315.7 15.5, 355603.2 6690314.6 15.5, 355602.5 6690320 15.5))
BATIMENT0000000302944351;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;4.0;3.0;10;20;6.1;9.3;15.4;16.4;10.8;Cadastre;A 1.0;POLYGON Z ((355610.5 6690320.9 15.4, 355607 6690324.9 15.4, 355601 6690331.7 15.4, 355599.8 6690333.1 15.4, 355608.9 6690335.3 15.4, 355610.1 6690327.8 15.4, 355611.1 6690320.7 15.4, 355610.5 6690320.9 15.4))
BATIMENT0000000302944350;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;9.4;12.7;15.0;11.3;Cadastre;;POLYGON Z ((355596.7 6690328.4 12.7, 355597.1 6690331.5 12.7, 355599.8 6690333.1 12.7, 355601 6690331.7 12.7, 355596.7 6690328.4 12.7))
BATIMENT0000000302944349;Indifférenciée;Commercial et services;Résidentiel;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;2.0;3.0;;;8.6;7.4;16.0;16.7;10.9;Cadastre;A 1.0;POLYGON Z ((355594.3 6690339.4 16, 355607.3 6690342.5 16, 355608.9 6690335.3 16, 355599.8 6690333.1 16, 355594.3 6690339.4 16))
BATIMENT0000000302944337;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1852-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;10;23;11.4;14.0;25.5;28.4;15.1;Cadastre;C 0.4;POLYGON Z ((355564.4 6690334.1 25.5, 355561.4 6690336.5 25.5, 355571.7 6690349.4 25.5, 355582.5 6690340.9 25.5, 355572.1 6690327.9 25.5, 355565.8 6690332.9 25.5, 355564.4 6690334.1 25.5))
BATIMENT0000000304020894;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;32.0;5.0;00;00;15.6;7.0;22.6;24.5;10.9;Cadastre;A 1.0;POLYGON Z ((355815.6 6690277.7 22.6, 355810.3 6690273.2 22.6, 355811.7 6690271.9 22.6, 355795.5 6690258 22.6, 355787.1 6690263.7 22.6, 355788.1 6690264.7 22.6, 355786.4 6690268.4 22.6, 355788.1 6690269.9 22.6, 355795.8 6690276.5 22.6, 355796.5 6690276.6 22.6, 355798.5 6690278.1 22.6, 355798.1 6690278.5 22.6, 355816.7 6690294.4 22.6, 355819.7 6690291 22.6, 355829.7 6690278.6 22.6, 355823.2 6690275.4 22.6, 355820.9 6690274.4 22.6, 355819.2 6690273.5 22.6, 355815.6 6690277.7 22.6))
BATIMENT0000000304020861;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1990-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;35.0;5.0;35;20;11.7;8.1;19.8;;;Cadastre;A 1.0;POLYGON Z ((355743.9 6690272.8 19.8, 355764.5 6690290.2 19.8, 355766.3 6690291.9 19.8, 355771.4 6690293 19.8, 355776.4 6690297.1 19.8, 355777.2 6690296.1 19.8, 355785.4 6690286.2 19.8, 355755 6690260 19.8, 355743.9 6690272.8 19.8))
BATIMENT0000000304020862;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;23.0;5.0;00;00;11.9;8.1;20.0;;;Cadastre;A 1.0;POLYGON Z ((355789.3 6690306.5 20, 355788.3 6690307.7 20, 355792.4 6690311.4 20, 355793.5 6690310.1 20, 355797.6 6690313.7 20, 355800.3 6690310.5 20, 355806 6690303.9 20, 355785.4 6690286.2 20, 355777.2 6690296.1 20, 355789.3 6690306.5 20))
BATIMENT0000000304020642;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.2;6.7;14.0;16.8;7.0;Cadastre;;POLYGON Z ((355750.2 6690314.3 14, 355751.1 6690314.5 14, 355762.1 6690316.5 14, 355767.2 6690317.5 14, 355761.4 6690311.5 14, 355762 6690309.3 14, 355753.7 6690306.7 14, 355753.5 6690307.2 14, 355750.6 6690306.3 14, 355751.1 6690305.1 14, 355748.9 6690304.3 14, 355748.6 6690305.4 14, 355742.2 6690303.5 14, 355741.3 6690307.8 14, 355741.2 6690308.5 14, 355740.7 6690310.7 14, 355743.8 6690311.1 14, 355743.8 6690311.5 14, 355743.8 6690311.8 14, 355743.8 6690312.1 14, 355743.9 6690312.3 14, 355744 6690312.7 14, 355744.2 6690312.9 14, 355744.3 6690313.1 14, 355744.4 6690313.2 14, 355750.2 6690314.3 14))
BATIMENT0000000304020643;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2015-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.4;6.5;14.0;16.6;7.0;Cadastre;C 0.3;POLYGON Z ((355762.1 6690316.5 14, 355751.1 6690314.5 14, 355750.2 6690314.3 14, 355744.4 6690313.2 14, 355744.6 6690313.4 14, 355744.9 6690313.7 14, 355745.1 6690313.8 14, 355745.3 6690313.9 14, 355745.4 6690314 14, 355745.6 6690314 14, 355744.6 6690317.7 14, 355747.3 6690318.4 14, 355748.1 6690315 14, 355755.4 6690317.2 14, 355754.3 6690318.2 14, 355758.3 6690321.9 14, 355757.9 6690322.2 14, 355759.5 6690325 14, 355759.8 6690325.3 14, 355760 6690325.5 14, 355760.2 6690325.6 14, 355760.4 6690325.7 14, 355760.5 6690325.8 14, 355760.9 6690325.9 14, 355761.2 6690326 14, 355761.6 6690326 14, 355761.8 6690326 14, 355761.9 6690326 14, 355762.2 6690326 14, 355762.6 6690325.9 14, 355764.1 6690327.5 14, 355762.3 6690329.2 14, 355762.1 6690331.1 14, 355771.3 6690331.8 14, 355775.6 6690332.1 14, 355775.9 6690328 14, 355775.8 6690327.9 14, 355773.2 6690325.3 14, 355773.9 6690324.5 14, 355767.2 6690317.5 14, 355762.1 6690316.5 14))
BATIMENT0000000304020935;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;6.7;6.5;13.2;15.7;9.1;Cadastre;A 1.0;POLYGON Z ((355816.8 6690332.5 13.2, 355827.2 6690320.5 13.2, 355812.7 6690308.1 13.2, 355790.4 6690334.3 13.2, 355787.2 6690337.7 13.2, 355800.3 6690349.8 13.2, 355807.3 6690342.5 13.2, 355816.8 6690332.5 13.2))
BATIMENT0000000304020644;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1991-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.3;6.0;10.3;13.7;8.0;Cadastre;C 0.3;POLYGON Z ((355786.2 6690361.4 10.3, 355787.2 6690348.8 10.3, 355737.6 6690344.5 10.3, 355737.1 6690344.4 10.3, 355736.5 6690351.2 10.3, 355733.2 6690350.9 10.3, 355729.4 6690350.6 10.3, 355717.1 6690349.8 10.3, 355716.6 6690355.9 10.3, 355749.2 6690358.3 10.3, 355786.2 6690361.4 10.3))
BATIMENT0000000304020825;Industriel, agricole ou commercial;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;5.5;9.5;15.0;16.7;11.6;Cadastre;A 1.0;POLYGON Z ((355784.7 6690373 15, 355791.3 6690378.7 15, 355795.8 6690382.5 15, 355795.2 6690383.2 15, 355803 6690389.8 15, 355807.5 6690384.4 15, 355807.2 6690384.3 15, 355824.8 6690363.9 15, 355833.1 6690354.3 15, 355834.9 6690352.3 15, 355831.4 6690349.4 15, 355827.6 6690353.8 15, 355818.6 6690346.2 15, 355813.6 6690341.9 15, 355784.7 6690373 15))
BATIMENT0000000304020652;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;1830-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;01;02;10.3;6.3;16.7;28.5;7.8;Cadastre;C 0.3;POLYGON Z ((355751 6690362.7 16.7, 355748.9 6690362.6 16.7, 355748.6 6690366.1 16.7, 355748.3 6690370 16.7, 355774.2 6690371.8 16.7, 355774.8 6690363.6 16.7, 355760.1 6690362.5 16.7, 355759.8 6690362.8 16.7, 355751 6690362.1 16.7, 355751 6690362.7 16.7))
BATIMENT0000000304020651;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.3;6.0;10.3;27.5;7.0;Cadastre;;POLYGON Z ((355748.6 6690366.1 10.3, 355739.1 6690365.5 10.3, 355738.7 6690370.5 10.3, 355748.2 6690371.2 10.3, 355748.3 6690370 10.3, 355748.6 6690366.1 10.3))
BATIMENT0000000304020645;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.3;6.1;10.5;21.5;7.0;Cadastre;;POLYGON Z ((355710.6 6690350.2 10.5, 355698 6690349.4 10.5, 355698 6690346.3 10.5, 355696 6690346.1 10.5, 355696.1 6690344.1 10.5, 355689.4 6690343.5 10.5, 355688.5 6690353.8 10.5, 355688.6 6690353.8 10.5, 355703.2 6690354.9 10.5, 355716.6 6690355.9 10.5, 355717.1 6690349.8 10.5, 355717.5 6690343.7 10.5, 355711.2 6690343.3 10.5, 355710.6 6690350.2 10.5))
BATIMENT0000000304020646;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;14.0;5.0;35;20;14.3;6.0;20.3;23.5;7.1;Cadastre;B 0.6;POLYGON Z ((355688.6 6690366.6 20.3, 355701.4 6690367.6 20.3, 355701.8 6690360.7 20.3, 355703 6690359.7 20.3, 355703.2 6690354.9 20.3, 355688.6 6690353.8 20.3, 355688.5 6690353.8 20.3, 355687.5 6690366.5 20.3, 355688.6 6690366.6 20.3))
BATIMENT0000000304020648;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.5;6.0;9.5;10.0;6.8;Cadastre;;POLYGON Z ((355712.9 6690368.5 9.5, 355716.9 6690368.8 9.5, 355717.3 6690364 9.5, 355710.5 6690363.4 9.5, 355710.3 6690365.7 9.5, 355706.4 6690365.5 9.5, 355706.1 6690367.9 9.5, 355712.9 6690368.5 9.5))
BATIMENT0000000304020650;Indifférenciée;Annexe;Commercial et services;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;3.6;6.0;9.6;9.9;7.0;Cadastre;B 0.2;POLYGON Z ((355739.1 6690365.5 9.6, 355739.2 6690364.6 9.6, 355717.4 6690363 9.6, 355717.3 6690364 9.6, 355716.9 6690368.8 9.6, 355731.5 6690369.9 9.6, 355736.9 6690370.3 9.6, 355738.7 6690370.5 9.6, 355739.1 6690365.5 9.6))
BATIMENT0000000304020649;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;6.6;10.7;12.9;6.8;Cadastre;;POLYGON Z ((355705.7 6690376.9 10.7, 355707.1 6690377 10.7, 355707.6 6690372 10.7, 355706.4 6690371.9 10.7, 355705.7 6690376.9 10.7))
BATIMENT0000000304020647;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;5.0;10;20;7.4;6.5;14.0;22.5;7.1;Cadastre;A 1.0;POLYGON Z ((355707.9 6690377.1 14, 355706.4 6690379.7 14, 355706.2 6690381.5 14, 355731.6 6690383.5 14, 355732.3 6690375.2 14, 355730.9 6690375.1 14, 355726.5 6690374.7 14, 355712.5 6690373.8 14, 355712.9 6690368.5 14, 355706.1 6690367.9 14, 355701.4 6690367.6 14, 355688.6 6690366.6 14, 355687.5 6690366.5 14, 355686.4 6690379.8 14, 355699.8 6690381 14, 355701 6690380.8 14, 355702.4 6690379.7 14, 355702.7 6690375.6 14, 355700.2 6690375.5 14, 355700.6 6690371.5 14, 355706.4 6690371.9 14, 355707.6 6690372 14, 355707.1 6690377 14, 355707.9 6690377.1 14))
BATIMENT0000000304020769;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;4.4;8.2;12.6;;;Cadastre;C 0.1;POLYGON Z ((355686.1 6690384.8 12.6, 355685.4 6690392.4 12.6, 355712.9 6690394.6 12.6, 355713.6 6690387 12.6, 355686.1 6690384.8 12.6))
BATIMENT0000000304020770;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.3;8.3;11.6;;;Cadastre;;POLYGON Z ((355712.9 6690395.2 11.6, 355717.3 6690395.5 11.6, 355717.9 6690395.6 11.6, 355718.7 6690387.4 11.6, 355718.2 6690387.3 11.6, 355713.6 6690387 11.6, 355712.9 6690394.6 11.6, 355712.9 6690395.2 11.6))
BATIMENT0000000304020984;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:07;;;;;BDTopo;2.5;BDTopo;1.5;;;;;3.5;8.3;;15.7;9.2;Imagerie aérienne;;POLYGON Z ((355722.4 6690396 11.8, 355722.6 6690392.9 11.8, 355756.2 6690395.8 11.8, 355759.8 6690391.3 11.8, 355718.7 6690387.4 11.8, 355717.9 6690395.6 11.8, 355722.4 6690396 11.8))
BATIMENT0000000304020908;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.1;6.4;11.5;16.1;7.0;Cadastre;C 0.7;POLYGON Z ((355684 6690410.3 11.5, 355696.1 6690411.2 11.5, 355696.7 6690399.9 11.5, 355691.2 6690399.4 11.5, 355691.3 6690397.4 11.5, 355689.8 6690397.3 11.5, 355689.8 6690397.2 11.5, 355685.1 6690396.8 11.5, 355685.1 6690397.3 11.5, 355684 6690410.3 11.5))
BATIMENT0000000304020768;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1830-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;04;03;1.6;8.6;10.2;18.2;9.2;Cadastre;C 0.1;POLYGON Z ((355756.4 6690388.3 10.2, 355759.8 6690391.3 10.2, 355760.2 6690391.3 10.2, 355760.6 6690391.4 10.2, 355771.7 6690379.8 10.2, 355767.5 6690376.5 10.2, 355756.4 6690388.3 10.2))
BATIMENT0000002011294680;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:49:07;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;7.8;7.6;;15.6;11.2;Imagerie aérienne;;POLYGON Z ((355795.2 6690383.2 15, 355795.8 6690382.5 15, 355791.3 6690378.7 15, 355784.7 6690373 15, 355775.2 6690381.9 15.3, 355787.3 6690392.6 15.4, 355794 6690398.7 11.3, 355803 6690389.8 15, 355795.2 6690383.2 15))
BATIMENT0000000304020968;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;;;2.4;8.7;11.2;12.5;10.4;Cadastre;B 0.2;POLYGON Z ((355783.5 6690410.9 11.2, 355786.2 6690412.9 11.2, 355790 6690408.5 11.2, 355787.2 6690406.5 11.2, 355783.5 6690410.9 11.2))
BATIMENT0000000304020813;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1966-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;50;10;7.4;10.7;18.1;22.2;11.9;Cadastre;A 1.0;POLYGON Z ((355815.3 6690416.4 18.1, 355816.5 6690417.3 18.1, 355823.6 6690422.7 18.1, 355829.9 6690414.3 18.1, 355821.7 6690407.2 18.1, 355815.3 6690416.4 18.1))
BATIMENT0000002011292350;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;2023-01-31 17:49:07;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;3.2;8.3;;12.0;8.8;Imagerie aérienne;;POLYGON Z ((355758.2 6690419.1 11.5, 355748.3 6690412.1 11.5, 355744.9 6690416.6 11.5, 355755 6690423.6 11.5, 355758.2 6690419.1 11.5))
BATIMENT0000000304020818;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.7;11.4;14.1;15.5;11.6;Cadastre;;POLYGON Z ((355812.9 6690419.6 14.1, 355810.9 6690418.2 14.1, 355809.9 6690419.9 14.1, 355811.7 6690421.3 14.1, 355812.9 6690419.6 14.1))
BATIMENT0000000304020817;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.3;11.4;13.7;17.2;11.7;Cadastre;;POLYGON Z ((355811.5 6690423.3 13.7, 355811.9 6690423.6 13.7, 355812.6 6690422.6 13.7, 355811.5 6690421.8 13.7, 355811.7 6690421.3 13.7, 355809.9 6690419.9 13.7, 355808 6690418.4 13.7, 355806.8 6690420 13.7, 355811.5 6690423.3 13.7))
BATIMENT0000000304020815;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;19;7.4;10.7;18.1;20.7;11.8;Cadastre;A 1.0;POLYGON Z ((355823.6 6690422.7 18.1, 355816.5 6690417.3 18.1, 355815.3 6690416.4 18.1, 355813.3 6690414.9 18.1, 355810.9 6690418.2 18.1, 355812.9 6690419.6 18.1, 355811.7 6690421.3 18.1, 355811.5 6690421.8 18.1, 355812.6 6690422.6 18.1, 355811.9 6690423.6 18.1, 355819.1 6690428.6 18.1, 355823.6 6690422.7 18.1))
BATIMENT0000000304020816;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;25;10;8.9;11.5;20.5;23.2;12.0;Cadastre;B 1.0;POLYGON Z ((355808 6690427.8 20.5, 355815.6 6690433.3 20.5, 355819.1 6690428.6 20.5, 355811.9 6690423.6 20.5, 355811.5 6690423.3 20.5, 355808 6690427.8 20.5))
BATIMENT0000000304020823;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1929-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;5.0;24;20;13.0;11.4;24.5;26.8;12.0;Cadastre;A 1.0;POLYGON Z ((355802.8 6690434.6 24.5, 355810.4 6690440.1 24.5, 355815.6 6690433.3 24.5, 355808 6690427.8 24.5, 355802.8 6690434.6 24.5))
BATIMENT0000000302944348;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2023-01-31 17:49:05;1880-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;2.0;;;8.5;7.4;15.9;23.7;10.9;Cadastre;A 1.0;POLYGON Z ((355591.2 6690342.8 15.9, 355606.1 6690346.6 15.9, 355607.3 6690342.5 15.9, 355594.3 6690339.4 15.9, 355591.2 6690342.8 15.9))
BATIMENT0000000302944347;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;7.0;3.0;20;20;5.7;9.3;15.0;24.2;12.1;Cadastre;A 1.0;POLYGON Z ((355591.2 6690342.8 15, 355586.4 6690348.3 15, 355585.2 6690349.8 15, 355593.3 6690353.5 15, 355593.6 6690352.4 15, 355594.9 6690348.5 15, 355597.9 6690349.5 15, 355596.8 6690353.5 15, 355596.3 6690354.9 15, 355602.3 6690357.7 15, 355606.1 6690346.6 15, 355591.2 6690342.8 15))
BATIMENT0000000302944343;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;3.0;3.0;00;00;6.5;9.3;15.8;17.7;13.9;Cadastre;A 1.0;POLYGON Z ((355579.2 6690356.6 15.8, 355590.6 6690362 15.8, 355599.1 6690365.7 15.8, 355602.3 6690357.7 15.8, 355596.3 6690354.9 15.8, 355593.3 6690353.5 15.8, 355585.2 6690349.8 15.8, 355579.2 6690356.6 15.8))
BATIMENT0000000302944341;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;8.2;11.8;15.6;14.1;Cadastre;;POLYGON Z ((355579.2 6690356.6 11.8, 355570.1 6690366.9 11.8, 355571.2 6690368.2 11.8, 355577.4 6690376.1 11.8, 355581.3 6690381.1 11.8, 355590.6 6690362 11.8, 355579.2 6690356.6 11.8))
BATIMENT0000000302944344;Indifférenciée;Résidentiel;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;1962-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;30;40;8.5;7.1;15.7;16.2;10.9;Cadastre;A 0.5;POLYGON Z ((355582 6690381.9 15.7, 355586.4 6690387.5 15.7, 355587.8 6690385.7 15.7, 355590.2 6690382.1 15.7, 355592.4 6690378.4 15.7, 355594.6 6690374.7 15.7, 355596.5 6690370.8 15.7, 355598.4 6690366.9 15.7, 355599.1 6690365.7 15.7, 355590.6 6690362 15.7, 355581.3 6690381.1 15.7, 355582 6690381.9 15.7))
BATIMENT0000000302944345;Indifférenciée;Annexe;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;5.4;7.3;12.7;16.1;7.9;Cadastre;C 0.5;POLYGON Z ((355579.4 6690383.9 12.7, 355584.3 6690390.2 12.7, 355586.4 6690387.5 12.7, 355582 6690381.9 12.7, 355579.4 6690383.9 12.7))
BATIMENT0000000302944299;Indifférenciée;Indifférencié;;Non;En service;2012-06-19 19:54:10;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.3;6.5;14.8;17.5;7.1;Cadastre;;POLYGON Z ((355593.1 6690459.5 14.8, 355598.5 6690459.8 14.8, 355598.7 6690456.5 14.8, 355593.2 6690456.1 14.8, 355593.1 6690459.5 14.8))
BATIMENT0000000302944520;Indifférenciée;Indifférencié;;Oui;En service;2012-06-19 19:54:10;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.4;6.0;9.4;17.2;7.0;Cadastre;;POLYGON Z ((355612 6690469.6 9.4, 355615.3 6690469.8 9.4, 355615.5 6690464 9.4, 355612.4 6690463.8 9.4, 355612 6690469.6 9.4))
BATIMENT0000000302944521;Indifférenciée;Commercial et services;;Non;En service;2012-06-19 19:54:10;2019-03-15 08:35:34;2014-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.9;4.7;10.7;13.3;7.1;Cadastre;A 1.0;POLYGON Z ((355608.8 6690469.4 10.7, 355608.665575557 6690471.022695063 10.7, 355621.03369855834 6690471.022695063 10.7, 355621.1 6690470.1 10.7, 355620 6690470 10.7, 355615.3 6690469.8 10.7, 355612 6690469.6 10.7, 355608.8 6690469.4 10.7))
BATIMENT0000000304020907;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;7.9;13.0;;;Cadastre;;POLYGON Z ((355706.2 6690412 13, 355707 6690400.7 13, 355696.7 6690399.9 13, 355696.1 6690411.2 13, 355706.2 6690412 13))
BATIMENT0000000304020909;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;7.8;13.0;;;Cadastre;;POLYGON Z ((355713.7 6690412.6 13, 355714.5 6690401.3 13, 355707 6690400.7 13, 355706.2 6690412 13, 355713.7 6690412.6 13))
BATIMENT0000000304020910;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.2;7.9;13.1;;;Cadastre;;POLYGON Z ((355721.1 6690414.2 13.1, 355722 6690401.9 13.1, 355714.5 6690401.3 13.1, 355713.7 6690412.6 13.1, 355721.1 6690414.2 13.1))
BATIMENT0000000304020911;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.9;7.9;12.8;13.3;9.1;Cadastre;;POLYGON Z ((355738.1 6690417.8 12.8, 355740.2 6690412.9 12.8, 355747 6690405.7 12.8, 355748.6 6690404 12.8, 355722 6690401.9 12.8, 355721.1 6690414.2 12.8, 355738.1 6690417.8 12.8))
BATIMENT0000000304020997;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1986-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;38.0;6.0;30;20;4.9;6.3;11.2;26.3;7.5;Cadastre;C 0.4;POLYGON Z ((355697 6690441.1 11.2, 355699 6690441.3 11.2, 355702 6690441.5 11.2, 355703.8 6690419.9 11.2, 355703.9 6690419.2 11.2, 355695.4 6690418.5 11.2, 355696.1 6690411.2 11.2, 355684 6690410.3 11.2, 355681.6 6690439.6 11.2, 355697 6690441.1 11.2))
BATIMENT0000000304020996;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:07;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.0;5.2;9.2;9.7;7.5;Cadastre;;POLYGON Z ((355711.9 6690442.3 9.2, 355713.8 6690420.9 9.2, 355703.8 6690419.9 9.2, 355702 6690441.5 9.2, 355711.9 6690442.3 9.2))
BATIMENT0000000304020906;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1910-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;20;20;10.4;7.0;17.5;21.3;7.5;Cadastre;A 1.0;POLYGON Z ((355680.4 6690455.2 17.5, 355691.2 6690456 17.5, 355691.9 6690446.5 17.5, 355695.6 6690446.8 17.5, 355695.9 6690445 17.5, 355696.7 6690445 17.5, 355697 6690441.1 17.5, 355681.6 6690439.6 17.5, 355680.4 6690455.2 17.5))
BATIMENT0000000304020905;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;5.0;5.0;00;00;13.7;7.8;21.5;25.0;7.9;Cadastre;A 1.0;POLYGON Z ((355679.17733719974 6690471.022695063 21.5, 355692.9230065148 6690471.022695063 21.5, 355693.9 6690459.9 21.5, 355690.9 6690459.8 21.5, 355691.2 6690456 21.5, 355680.4 6690455.2 21.5, 355679.17733719974 6690471.022695063 21.5))
BATIMENT0000000304020707;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;7.6;10.4;12.0;11.0;Cadastre;A 1.0;POLYGON Z ((355735.2 6690470.2 10.4, 355732.9 6690468 10.4, 355730.8 6690466 10.4, 355726.0670758065 6690471.022695063 10.4, 355734.4332162524 6690471.022695063 10.4, 355735.2 6690470.2 10.4))
BATIMENT0000002011292668;Indifférenciée;Indifférencié;;Non;En service;2018-06-04 12:14:25;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;;;8.3;10.5;;;;Imagerie aérienne;;POLYGON Z ((355797.9 6690441.1 18.8, 355784.9 6690433.2 13.9, 355782.4 6690436.8 13.9, 355794.5 6690445.6 13.9, 355797.9 6690441.1 18.8))
BATIMENT0000000304020824;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;3.0;4.0;10;20;11.4;11.3;22.7;26.0;12.0;Cadastre;A 1.0;POLYGON Z ((355798 6690441.2 22.7, 355805.4 6690446.7 22.7, 355810.4 6690440.1 22.7, 355802.8 6690434.6 22.7, 355798 6690441.2 22.7))
BATIMENT0000000304020729;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;28.0;2.0;00;00;6.0;9.1;15.1;17.4;9.2;Cadastre;C 0.3;POLYGON Z ((355736.3 6690459.5 15.1, 355739 6690460.5 15.1, 355742.5 6690452 15.1, 355745.7 6690444.1 15.1, 355749 6690442.1 15.1, 355758.8 6690442.9 15.1, 355758.7 6690443.7 15.1, 355761.9 6690445.8 15.1, 355765.6 6690440.2 15.1, 355768 6690435.4 15.1, 355760.3 6690430 15.1, 355742.6 6690428.6 15.1, 355742.1 6690429.2 15.1, 355741.8 6690429 15.1, 355741.7 6690429 15.1, 355741.5 6690428.9 15.1, 355741.2 6690428.9 15.1, 355741 6690428.9 15.1, 355740.8 6690428.9 15.1, 355740.6 6690429 15.1, 355740.5 6690429 15.1, 355740.3 6690429.1 15.1, 355740.2 6690429.2 15.1, 355740.1 6690429.3 15.1, 355740 6690429.4 15.1, 355739.9 6690429.5 15.1, 355739.8 6690429.7 15.1, 355739.7 6690429.9 15.1, 355739.7 6690430.1 15.1, 355739.7 6690430.2 15.1, 355739.7 6690430.3 15.1, 355739.7 6690430.5 15.1, 355739.7 6690430.7 15.1, 355739.8 6690430.8 15.1, 355739.9 6690431 15.1, 355739.9 6690431.1 15.1, 355737.6 6690432.6 15.1, 355737.3 6690432 15.1, 355737.1 6690432 15.1, 355737.1 6690432.1 15.1, 355732.2 6690443.5 15.1, 355725 6690460.5 15.1, 355730.8 6690466 15.1, 355732.9 6690468 15.1, 355736.3 6690459.5 15.1))
BATIMENT0000000304020579;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.1;11.3;16.4;18.1;12.4;Cadastre;;POLYGON Z ((355817.7 6690445.9 16.4, 355814.1 6690450.6 16.4, 355820.3 6690456.9 16.4, 355821.4 6690458 16.4, 355825.7 6690452.3 16.4, 355817.7 6690445.9 16.4))
BATIMENT0000000304020746;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;10;10;8.1;10.2;18.3;21.2;12.1;Cadastre;A 1.0;POLYGON Z ((355789.2 6690447.4 18.3, 355788.6 6690447 18.3, 355784 6690453.7 18.3, 355785 6690453.8 18.3, 355788.1 6690454.2 18.3, 355795.3 6690459.9 18.3, 355799.3 6690454.7 18.3, 355789.2 6690447.4 18.3))
BATIMENT0000000304020578;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.0;10.8;18.8;25.9;13.1;Cadastre;;POLYGON Z ((355800.7 6690467.7 18.8, 355800.1 6690468.9 18.8, 355800.7 6690469.4 18.8, 355802.8696709261 6690471.022695063 18.8, 355820.57741692563 6690471.022695063 18.8, 355820.9 6690470.6 18.8, 355814 6690465.5 18.8, 355820.3 6690456.9 18.8, 355814.1 6690450.6 18.8, 355800.7 6690467.7 18.8))
BATIMENT0000000304020742;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1997-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;26.0;5.0;00;00;13.2;11.0;24.2;28.6;12.2;Cadastre;C 0.4;POLYGON Z ((355795.3 6690459.9 24.2, 355788.1 6690454.2 24.2, 355785 6690453.8 24.2, 355781.1 6690459.1 24.2, 355777.5 6690456.3 24.2, 355776.9 6690456.6 24.2, 355776.3 6690457 24.2, 355775.8 6690457.4 24.2, 355775.5 6690457.6 24.2, 355775 6690458 24.2, 355774.5 6690458.4 24.2, 355774 6690458.8 24.2, 355773.6 6690459.3 24.2, 355773.1 6690459.8 24.2, 355772.9 6690460.1 24.2, 355772.7 6690460.3 24.2, 355772.2 6690461.1 24.2, 355771.8 6690461.7 24.2, 355771.5 6690462.2 24.2, 355771.3 6690462.5 24.2, 355771 6690463.1 24.2, 355770.8 6690463.7 24.2, 355770.5 6690464.3 24.2, 355770.4 6690464.6 24.2, 355770.2 6690465.3 24.2, 355770.1 6690465.9 24.2, 355769.9 6690466.5 24.2, 355771.2 6690467.5 24.2, 355773.6 6690469.2 24.2, 355772.22438108484 6690471.022695063 24.2, 355787.2062531464 6690471.022695063 24.2, 355795.3 6690459.9 24.2))
BATIMENT0000000304020745;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.9;10.2;18.1;23.7;11.9;Cadastre;;POLYGON Z ((355773.6 6690469.2 18.1, 355771.2 6690467.5 18.1, 355768.5061743636 6690471.022695063 18.1, 355772.22438108484 6690471.022695063 18.1, 355773.6 6690469.2 18.1))
BATIMENT0000000304020580;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;12.0;4.0;00;00;14.0;9.7;23.7;26.5;12.2;Cadastre;A 1.0;POLYGON Z ((355800.7 6690469.4 23.7, 355799.5327982884 6690471.022695063 23.7, 355802.8696709261 6690471.022695063 23.7, 355800.7 6690469.4 23.7))
BATIMENT0000000304020583;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;11.4;10.8;22.2;24.3;12.2;Cadastre;;POLYGON Z ((355886.7 6690389.1 22.2, 355887.9 6690387.6 22.2, 355883.1 6690383.5 22.2, 355882 6690385.1 22.2, 355886.7 6690389.1 22.2))
BATIMENT0000000304020576;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;15;10;4.3;11.3;15.6;18.0;12.5;Cadastre;A 1.0;POLYGON Z ((355857.1 6690391.9 15.6, 355865.1 6690397.4 15.6, 355870.1 6690390.1 15.6, 355862.3 6690384.3 15.6, 355857.1 6690391.9 15.6))
BATIMENT0000000304020588;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;6.3;10.3;16.6;19.3;13.2;Cadastre;A 1.0;POLYGON Z ((355897.5 6690392.4 16.6, 355896.8 6690393.2 16.6, 355894.8 6690395.6 16.6, 355901.8 6690401.4 16.6, 355910.5 6690391.3 16.6, 355903.5 6690385.3 16.6, 355897.5 6690392.4 16.6))
BATIMENT0000000304020814;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1993-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;51.0;5.0;30;20;12.2;10.7;23.0;26.6;11.8;Cadastre;A 1.0;POLYGON Z ((355839.5 6690376.5 23, 355838.3 6690378.3 23, 355837 6690377.4 23, 355833.8 6690382 23, 355832.9 6690381.5 23, 355831 6690381.7 23, 355829.3 6690384.1 23, 355829.8 6690386.3 23, 355823.8 6690394.7 23, 355821.6 6690395.1 23, 355820 6690397.6 23, 355813.8 6690392.1 23, 355809.6 6690396.9 23, 355821.7 6690407.2 23, 355829.9 6690414.3 23, 355835.5 6690406.1 23, 355838.1 6690402.3 23, 355849.8 6690385.3 23, 355839.5 6690376.5 23))
BATIMENT0000000304020571;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.6;11.3;15.9;16.2;12.8;Cadastre;;POLYGON Z ((355876 6690403.1 15.9, 355881.5 6690395.9 15.9, 355873.6 6690390.3 15.9, 355873.2 6690391 15.9, 355872.6 6690391.9 15.9, 355867.5 6690399.1 15.9, 355876 6690403.1 15.9))
BATIMENT0000000304020575;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;14.5;10.8;25.4;25.5;11.9;Cadastre;;POLYGON Z ((355853.5 6690400.7 25.4, 355855 6690398.7 25.4, 355853.2 6690397.5 25.4, 355851.7 6690399.7 25.4, 355853.5 6690400.7 25.4))
BATIMENT0000000304020566;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;1989-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;10.0;5.0;05;02;9.6;10.8;20.5;27.2;13.7;Cadastre;A 1.0;POLYGON Z ((355853.2 6690397.5 20.5, 355855 6690398.7 20.5, 355853.5 6690400.7 20.5, 355851.7 6690399.7 20.5, 355847.9 6690405.2 20.5, 355859.3 6690412.1 20.5, 355868.7 6690415.3 20.5, 355869.7 6690415.8 20.5, 355874.7 6690405.6 20.5, 355869.3 6690404.6 20.5, 355865.5 6690401.8 20.5, 355867.5 6690399.1 20.5, 355865.1 6690397.4 20.5, 355857.1 6690391.9 20.5, 355853.2 6690397.5 20.5))
BATIMENT0000000304020969;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.9;12.6;15.6;17.0;13.4;Cadastre;;POLYGON Z ((355896.7 6690406.3 15.6, 355895.1 6690404.9 15.6, 355892.9 6690407.4 15.6, 355894.5 6690408.8 15.6, 355896.7 6690406.3 15.6))
BATIMENT0000000304020970;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;2.1;12.6;14.7;15.6;13.4;Cadastre;;POLYGON Z ((355889 6690404.2 14.7, 355888.3 6690405 14.7, 355891 6690407.3 14.7, 355890.1 6690408.4 14.7, 355893 6690410.6 14.7, 355894.5 6690408.8 14.7, 355892.9 6690407.4 14.7, 355889 6690404.2 14.7))
BATIMENT0000000304020926;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;2.0;3.0;10;20;7.4;12.9;20.3;22.9;13.7;Cadastre;B 0.1;POLYGON Z ((355894.5 6690412.6 20.3, 355901.7 6690418.8 20.3, 355907.9 6690411.3 20.3, 355900.5 6690405.2 20.3, 355894.5 6690412.6 20.3))
BATIMENT0000000304020561;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;10.5;13.1;13.2;11.6;Cadastre;;POLYGON Z ((355985.4 6690395 13.1, 355984.6 6690395.9 13.1, 355985.4 6690396.8 13.1, 355986.2 6690396 13.1, 355985.4 6690395 13.1))
BATIMENT0000000304020559;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.4;10.3;12.8;13.2;11.8;Cadastre;A 1.0;POLYGON Z ((355991.6 6690394.4 12.8, 355987.4 6690398.9 12.8, 355989.6 6690401.3 12.8, 355993.9 6690396.8 12.8, 355991.6 6690394.4 12.8))
BATIMENT0000000303967642;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1956-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.1;14.2;11.1;Cadastre;A 1.0;POLYGON Z ((356011.9 6690396.4 13.1, 356012.2 6690399.3 13.1, 356017.7 6690403.2 13.1, 356022.4 6690397.8 13.1, 356017.6 6690393 13.1, 356011.7 6690396.2 13.1, 356011.9 6690396.4 13.1))
BATIMENT0000000304020558;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.0;13.2;11.9;Cadastre;A 1.0;POLYGON Z ((355993.9 6690396.8 13, 355989.6 6690401.3 13, 355991.6 6690403.4 13, 355995.8 6690398.9 13, 355993.9 6690396.8 13))
BATIMENT0000000304020556;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.1;13.3;11.9;Cadastre;A 1.0;POLYGON Z ((355995.8 6690398.9 13.1, 355991.6 6690403.4 13.1, 355992.1 6690403.8 13.1, 355993.9 6690405.7 13.1, 355998 6690401.2 13.1, 355995.8 6690398.9 13.1))
BATIMENT0000000303967641;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.1;13.6;10.8;Cadastre;A 1.0;POLYGON Z ((356010.3 6690401.3 13.1, 356014.3 6690406.8 13.1, 356017.7 6690403.2 13.1, 356012.2 6690399.3 13.1, 356010.3 6690401.3 13.1))
BATIMENT0000000303967596;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.4;10.6;13.1;13.4;11.9;Cadastre;A 1.0;POLYGON Z ((355998 6690401.2 13.1, 355993.9 6690405.7 13.1, 355994.3 6690406.2 13.1, 355995.8 6690407.8 13.1, 356000 6690403.3 13.1, 355998 6690401.2 13.1))
BATIMENT0000000303967640;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.7;10.4;13.1;13.6;11.0;Cadastre;A 1.0;POLYGON Z ((356008 6690403.7 13.1, 356012.3 6690409 13.1, 356014.3 6690406.8 13.1, 356010.3 6690401.3 13.1, 356008 6690403.7 13.1))
BATIMENT0000000304020557;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.2;11.4;13.6;14.5;12.0;Cadastre;;POLYGON Z ((355988.5 6690407.5 13.6, 355990.5 6690409.6 13.6, 355994.3 6690406.2 13.6, 355993.9 6690405.7 13.6, 355992.1 6690403.8 13.6, 355988.5 6690407.5 13.6))
BATIMENT0000000303967595;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.5;10.5;13.1;13.9;12.1;Cadastre;A 1.0;POLYGON Z ((356000 6690403.3 13.1, 355995.8 6690407.8 13.1, 355999.5 6690411.6 13.1, 356002.7 6690406.2 13.1, 356000 6690403.3 13.1))
BATIMENT0000000304020924;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;12.2;16.5;21.8;13.5;Cadastre;;POLYGON Z ((355908.1 6690404.4 16.5, 355909.3 6690405.5 16.5, 355907.6 6690407.7 16.5, 355908.4 6690408.4 16.5, 355907.9 6690409.2 16.5, 355909 6690410 16.5, 355912.8 6690405.5 16.5, 355909.5 6690402.7 16.5, 355908.1 6690404.4 16.5))
BATIMENT0000000304020922;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;10;20;13.6;12.2;25.8;28.0;12.9;Cadastre;A 1.0;POLYGON Z ((355920.3 6690408.9 25.8, 355922.5 6690410.7 25.8, 355922.8 6690410.6 25.8, 355926.1 6690413.4 25.8, 355930.4 6690408.3 25.8, 355924.8 6690403.5 25.8, 355920.3 6690408.9 25.8))
BATIMENT0000000304020620;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;5.1;12.1;17.2;19.4;13.6;Cadastre;A 1.0;POLYGON Z ((355954.6 6690409.5 17.2, 355954.7 6690414.6 17.2, 355972.9 6690430.2 17.2, 355978.7 6690423.9 17.2, 355981 6690421.2 17.2, 355979.2 6690419.3 17.2, 355966.4 6690407.4 17.2, 355960.4 6690401.7 17.2, 355954.6 6690409.5 17.2))
BATIMENT0000000304020921;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;6.0;3.0;50;20;11.6;11.1;22.7;26.4;13.6;Cadastre;A 1.0;POLYGON Z ((355927.9 6690415.1 22.7, 355925.1 6690418.3 22.7, 355923.2 6690416.8 22.7, 355920.8 6690419.7 22.7, 355929.3 6690425.6 22.7, 355935.3 6690417.7 22.7, 355935.1 6690412.3 22.7, 355930.4 6690408.3 22.7, 355926.1 6690413.4 22.7, 355927.9 6690415.1 22.7))
BATIMENT0000000304020619;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.0;12.1;14.1;15.7;12.5;Cadastre;;POLYGON Z ((355982.6 6690420 14.1, 355980.4 6690418 14.1, 355979.2 6690419.3 14.1, 355981 6690421.2 14.1, 355981.5 6690421.5 14.1, 355982.6 6690420 14.1))
BATIMENT0000000304020971;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire;5.0;Corrélation;1.0;;;;;1.8;13.4;15.2;15.5;14.1;Cadastre;;POLYGON Z ((355908.9 6690423.5 15.2, 355910.9 6690424.9 15.2, 355913.9 6690421.4 15.2, 355911.8 6690420 15.2, 355908.9 6690423.5 15.2))
BATIMENT0000000304020920;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1937-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;40;20;8.9;13.3;22.2;25.7;13.8;Cadastre;A 1.0;POLYGON Z ((355918.1 6690423.3 22.2, 355918.6 6690423.6 22.2, 355926.7 6690429.2 22.2, 355929.3 6690425.6 22.2, 355920.8 6690419.7 22.2, 355918.1 6690423.3 22.2))
BATIMENT0000000304020918;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1928-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;20;7.4;13.5;20.9;23.2;14.1;Cadastre;A 1.0;POLYGON Z ((355916 6690427.3 20.9, 355916.5 6690427.7 20.9, 355917.7 6690428.5 20.9, 355923.9 6690432.8 20.9, 355926.7 6690429.2 20.9, 355918.6 6690423.6 20.9, 355916 6690427.3 20.9))
BATIMENT0000000304020919;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.5;13.7;18.2;20.5;14.0;Cadastre;;POLYGON Z ((355915.6 6690428.9 18.2, 355916.8 6690429.7 18.2, 355917.7 6690428.5 18.2, 355916.5 6690427.7 18.2, 355915.6 6690428.9 18.2))
BATIMENT0000000304020804;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;8.4;13.4;21.8;25.4;14.3;Cadastre;A 0.9;POLYGON Z ((355939.9 6690438 21.8, 355943.1 6690441.2 21.8, 355944.1 6690441.7 21.8, 355952.3 6690430.9 21.8, 355943.7 6690424 21.8, 355943.5 6690424 21.8, 355935.9 6690434.2 21.8, 355939.9 6690438 21.8))
BATIMENT0000000304020564;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;21.0;4.0;20;40;1.8;11.5;13.3;24.1;13.6;Cadastre;C 0.5;POLYGON Z ((355830.3 6690429.9 13.3, 355841 6690437.8 13.3, 355843.5 6690434.3 13.3, 355852.2 6690440.6 13.3, 355870.2 6690416 13.3, 355869.7 6690415.8 13.3, 355868.7 6690415.3 13.3, 355859.3 6690412.1 13.3, 355847.9 6690405.2 13.3, 355830.3 6690429.9 13.3))
BATIMENT0000000304020674;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;5.0;13.5;18.5;20.8;15.1;Cadastre;;POLYGON Z ((355893.1 6690433.8 18.5, 355891.1 6690437.3 18.5, 355897.8 6690444.1 18.5, 355903.8 6690438 18.5, 355899.9 6690435.4 18.5, 355895.3 6690432.4 18.5, 355893.1 6690433.8 18.5))
BATIMENT0000000304020563;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.2;11.5;15.8;16.1;12.0;Cadastre;;POLYGON Z ((355823.5 6690438.5 15.8, 355825.2 6690439.8 15.8, 355826 6690438.7 15.8, 355824.4 6690437.5 15.8, 355823.5 6690438.5 15.8))
BATIMENT0000000304020562;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;7.7;11.3;19.0;20.2;12.6;Cadastre;;POLYGON Z ((355840.5 6690449.9 19, 355848.1 6690443 19, 355841 6690437.8 19, 355830.3 6690429.9 19, 355824.4 6690437.5 19, 355826 6690438.7 19, 355840.5 6690449.9 19))
BATIMENT0000000304020669;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;14.6;18.7;22.2;15.3;Cadastre;;POLYGON Z ((355901.1 6690444.2 18.7, 355900.3 6690445 18.7, 355899.5 6690444.3 18.7, 355898.7 6690445.1 18.7, 355901.2 6690447.6 18.7, 355902.8 6690446 18.7, 355901.1 6690444.2 18.7))
BATIMENT0000000304020570;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;9.0;4.0;20;40;11.9;12.9;24.8;;;Cadastre;C 0.1;POLYGON Z ((355859 6690451.2 24.8, 355867.5 6690457.4 24.8, 355869.8 6690455.4 24.8, 355867.2 6690453.6 24.8, 355875.3 6690444.2 24.8, 355869.3 6690439 24.8, 355859 6690451.2 24.8))
BATIMENT0000000304020573;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;7.7;12.4;20.2;22.5;13.7;Cadastre;;POLYGON Z ((355872.9 6690448.9 20.2, 355875.2 6690450.6 20.2, 355878.2 6690447.9 20.2, 355875.6 6690445.9 20.2, 355872.9 6690448.9 20.2))
BATIMENT0000000304020663;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;14;10;7.8;15.0;22.8;25.7;15.5;Cadastre;A 1.0;POLYGON Z ((355896.4 6690454 22.8, 355902.5 6690460.1 22.8, 355908.2 6690454.7 22.8, 355902.2 6690448.6 22.8, 355896.4 6690454 22.8))
BATIMENT0000000304020574;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;8.2;12.7;21.0;22.9;14.5;Cadastre;;POLYGON Z ((355870.3 6690455 21, 355871.7 6690456.3 21, 355874.2 6690454.1 21, 355872.8 6690452.7 21, 355870.3 6690455 21))
BATIMENT0000000304020569;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.5;11.3;17.8;19.5;12.9;Cadastre;;POLYGON Z ((355828.7 6690448.5 17.8, 355825.7 6690452.3 17.8, 355821.4 6690458 17.8, 355826.3 6690462.9 17.8, 355836 6690454.2 17.8, 355828.7 6690448.5 17.8))
BATIMENT0000000303967639;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.6;10.4;13.0;13.6;11.5;Cadastre;A 1.0;POLYGON Z ((356005.9 6690406 13, 356008.7 6690412.9 13, 356012.3 6690409 13, 356008 6690403.7 13, 356005.9 6690406 13))
BATIMENT0000000303967593;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.8;10.6;13.4;13.7;12.1;Cadastre;A 1.0;POLYGON Z ((356002.7 6690406.2 13.4, 355999.5 6690411.6 13.4, 356002 6690414.3 13.4, 356004.7 6690417.1 13.4, 356008.7 6690412.9 13.4, 356005.9 6690406 13.4, 356002.7 6690406.2 13.4))
BATIMENT0000000303967638;Industriel, agricole ou commercial;Commercial et services;Résidentiel;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;1961-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;;;4.9;9.3;14.2;14.9;12.0;Cadastre;C 0.5;POLYGON Z ((356004.8 6690425.2 14.2, 356021.8 6690406.7 14.2, 356024.2 6690407 14.2, 356038.1 6690426.1 14.2, 356040.8 6690433.9 14.2, 356048.8 6690441.7 14.2, 356052.7 6690437.7 14.2, 356045 6690429.7 14.2, 356043.2 6690424.2 14.2, 356043.2 6690423.8 14.2, 356025.1 6690398.6 14.2, 356023.6 6690396.7 14.2, 356022.4 6690397.8 14.2, 356017.7 6690403.2 14.2, 356014.3 6690406.8 14.2, 356012.3 6690409 14.2, 356008.7 6690412.9 14.2, 356004.7 6690417.1 14.2, 356000.8 6690421.4 14.2, 356004.8 6690425.2 14.2))
BATIMENT0000000303969732;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.5;11.6;14.1;17.2;12.5;Cadastre;B 0.2;POLYGON Z ((355997 6690425.6 14.1, 355998.8 6690423.7 14.1, 356000.8 6690421.4 14.1, 356004.7 6690417.1 14.1, 356002 6690414.3 14.1, 355997.7 6690419.2 14.1, 355996.8 6690418.3 14.1, 355993.3 6690422.3 14.1, 355997 6690425.6 14.1))
BATIMENT0000000304021000;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;20;20;7.1;12.1;19.2;22.0;12.8;Cadastre;B 0.4;POLYGON Z ((355991.8 6690431.3 19.2, 355995.8 6690427 19.2, 355997 6690425.6 19.2, 355993.3 6690422.3 19.2, 355991.7 6690420.7 19.2, 355986.4 6690426 19.2, 355991.8 6690431.3 19.2))
BATIMENT0000000304020555;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1862-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;90;7.9;12.4;20.4;22.9;14.1;Cadastre;A 1.0;POLYGON Z ((355984 6690428.6 20.4, 355978.2 6690434.8 20.4, 355984.1 6690439.8 20.4, 355989.8 6690433.7 20.4, 355991.8 6690431.3 20.4, 355986.4 6690426 20.4, 355984 6690428.6 20.4))
BATIMENT0000000303967594;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;36.0;7.0;50;90;20.1;12.1;32.2;33.7;14.0;Cadastre;C 0.1;POLYGON Z ((355994.7 6690438.1 32.2, 355993.9 6690439.3 32.2, 355996.6 6690441.6 32.2, 355997.6 6690440.6 32.2, 356006.4 6690448 32.2, 356005.4 6690449.4 32.2, 356009.1 6690452.6 32.2, 356010.2 6690451.4 32.2, 356020.8 6690460.5 32.2, 356019.7 6690461.8 32.2, 356023.5 6690465 32.2, 356024.6 6690463.7 32.2, 356030.1 6690468.2 32.2, 356033.7 6690463.9 32.2, 356034.3 6690464.4 32.2, 356035.1 6690463.5 32.2, 356034.6 6690462.9 32.2, 356035.6 6690461.7 32.2, 355995.8 6690427 32.2, 355991.8 6690431.3 32.2, 355989.8 6690433.7 32.2, 355994.7 6690438.1 32.2))
BATIMENT0000000303968702;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1963-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;12.0;10.7;22.7;28.2;15.4;Cadastre;C 0.2;POLYGON Z ((356038.9 6690459.9 22.7, 356044.9 6690466.2 22.7, 356047.3 6690463.8 22.7, 356041 6690457.6 22.7, 356038.9 6690459.9 22.7))
BATIMENT0000000303967608;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1960-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;24.0;5.0;34;90;13.6;14.3;27.9;28.1;14.9;Cadastre;C 0.8;POLYGON Z ((355969 6690454.2 27.9, 355974.2 6690458.9 27.9, 355973.8 6690459.4 27.9, 355977.6 6690463 27.9, 355978.4 6690462.3 27.9, 355978.8 6690462.6 27.9, 355978.6 6690462.7 27.9, 355986.8 6690469.8 27.9, 355986.5 6690470.3 27.9, 355987.35022948566 6690471.022695063 27.9, 356002.2670562696 6690471.022695063 27.9, 355975.1 6690447.5 27.9, 355969 6690454.2 27.9))
BATIMENT0000000304020917;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;7.8;13.7;21.5;23.4;14.9;Cadastre;A 1.0;POLYGON Z ((355911.1 6690437.2 21.5, 355917.3 6690441.7 21.5, 355923.9 6690432.8 21.5, 355917.7 6690428.5 21.5, 355916.8 6690429.7 21.5, 355911.1 6690437.2 21.5))
BATIMENT0000000304020801;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2003-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;10.0;3.0;00;00;9.7;13.0;22.7;26.6;15.1;Cadastre;A 1.0;POLYGON Z ((355926.6 6690453.4 22.7, 355931.1 6690457.7 22.7, 355932.3 6690458.8 22.7, 355936 6690454 22.7, 355936.4 6690454.3 22.7, 355938.2 6690453.9 22.7, 355941.6 6690449.3 22.7, 355941.6 6690447.5 22.7, 355941.1 6690447.1 22.7, 355944.7 6690442.4 22.7, 355944.1 6690441.7 22.7, 355943.1 6690441.2 22.7, 355939.9 6690438 22.7, 355935.9 6690434.2 22.7, 355923.7 6690450.3 22.7, 355926.6 6690453.4 22.7))
BATIMENT0000000304020670;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;8.3;15.0;23.3;25.8;15.9;Cadastre;C 0.6;POLYGON Z ((355902.2 6690448.6 23.3, 355908.2 6690454.7 23.3, 355912.7 6690450.3 23.3, 355914.3 6690448.2 23.3, 355907 6690442 23.3, 355902.8 6690446 23.3, 355901.2 6690447.6 23.3, 355902.2 6690448.6 23.3))
BATIMENT0000000304020589;Indifférenciée;Annexe;;Oui;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;5.7;13.0;18.7;26.5;14.5;Cadastre;A 0.3;POLYGON Z ((355969.5 6690456.8 18.7, 355956.6 6690446.8 18.7, 355953.8 6690450 18.7, 355961.6 6690457.3 18.7, 355965.6 6690461.1 18.7, 355969.5 6690456.8 18.7))
BATIMENT0000000304020802;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2023-01-31 17:49:05;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;5.0;3.0;00;00;12.0;14.7;26.7;28.3;15.4;Cadastre;C 0.9;POLYGON Z ((355925.4 6690466.9 26.7, 355929.3 6690462.9 26.7, 355932.9 6690459.3 26.7, 355932.3 6690458.8 26.7, 355931.1 6690457.7 26.7, 355926.6 6690453.4 26.7, 355923.7 6690450.3 26.7, 355918.8 6690456.9 26.7, 355917.9 6690457.7 26.7, 355917 6690458.6 26.7, 355925.4 6690466.9 26.7))
BATIMENT0000000304020800;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.3;14.7;18.1;25.0;15.3;Cadastre;;POLYGON Z ((355933.1 6690466.7 18.1, 355936.7 6690463 18.1, 355932.9 6690459.3 18.1, 355929.3 6690462.9 18.1, 355933.1 6690466.7 18.1))
BATIMENT0000000304020803;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;15;10;6.1;15.0;21.1;23.2;15.6;Cadastre;A 1.0;POLYGON Z ((355922.1 6690466.1 21.1, 355916.1 6690459.4 21.1, 355909.7 6690465.6 21.1, 355914.794046877 6690471.022695063 21.1, 355917.09660501836 6690471.022695063 21.1, 355922.1 6690466.1 21.1))
BATIMENT0000000304020805;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1938-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;15;13;5.7;15.0;20.7;24.2;15.6;Cadastre;A 1.0;POLYGON Z ((355909.7 6690465.6 20.7, 355904.2040252742 6690471.022695063 20.7, 355914.794046877 6690471.022695063 20.7, 355909.7 6690465.6 20.7))
BATIMENT0000000304020596;Indifférenciée;Annexe;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;3.4;14.9;18.3;20.2;15.2;Cadastre;C 0.3;POLYGON Z ((355937.9 6690470.9 18.3, 355937.77048854536 6690471.022695063 18.3, 355938.02269506233 6690471.022695063 18.3, 355937.9 6690470.9 18.3))
BATIMENT0000000304020565;Indifférenciée;Commercial et services;;Oui;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.4;11.3;18.7;22.2;14.4;Cadastre;A 0.3;POLYGON Z ((355836 6690454.2 18.7, 355826.3 6690462.9 18.7, 355827.7 6690464.4 18.7, 355830.1 6690466.7 18.7, 355834.3 6690470.9 18.7, 355846.4 6690460.1 18.7, 355852.7 6690454.4 18.7, 355857.5 6690450 18.7, 355848.1 6690443 18.7, 355840.5 6690449.9 18.7, 355836 6690454.2 18.7))
BATIMENT0000000304020658;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1926-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;9.1;14.6;23.7;25.7;15.3;Cadastre;A 1.0;POLYGON Z ((355890.3 6690459.8 23.7, 355896.3 6690466 23.7, 355902.5 6690460.1 23.7, 355896.4 6690454 23.7, 355890.3 6690459.8 23.7))
BATIMENT0000000304020656;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;14.5;18.3;20.0;15.1;Cadastre;;POLYGON Z ((355881.1 6690461.3 18.3, 355880.1 6690462.2 18.3, 355880.8 6690463 18.3, 355883.2 6690465.4 18.3, 355884.2 6690464.4 18.3, 355881.1 6690461.3 18.3))
BATIMENT0000000304020654;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1925-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;50;10;8.9;14.7;23.6;25.4;15.5;Cadastre;A 1.0;POLYGON Z ((355884.8 6690465 23.6, 355890.6284145766 6690471.022695063 23.6, 355890.98753406847 6690471.022695063 23.6, 355896.3 6690466 23.6, 355890.3 6690459.8 23.6, 355884.8 6690465 23.6))
BATIMENT0000000304020653;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.7;14.2;18.0;18.5;15.1;Cadastre;;POLYGON Z ((355883.2 6690465.4 18, 355880.8 6690463 18, 355876.7 6690466.9 18, 355879.1 6690469.3 18, 355883.2 6690465.4 18))
BATIMENT0000000304020568;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 21:01:44;2018-09-18 13:45:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;6.7;11.3;18.0;21.2;13.5;Cadastre;;POLYGON Z ((355827.7 6690464.4 18, 355823.1357101594 6690471.022695063 18, 355827.398315586 6690471.022695063 18, 355830.1 6690466.7 18, 355827.7 6690464.4 18))
BATIMENT0000000304020655;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1952-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;25;20;6.3;15.0;21.3;23.7;15.3;Cadastre;A 1.0;POLYGON Z ((355884.8 6690465 21.3, 355884.2 6690464.4 21.3, 355883.2 6690465.4 21.3, 355879.1 6690469.3 21.3, 355879.4 6690469.7 21.3, 355880.7020279523 6690471.022695063 21.3, 355890.6284145766 6690471.022695063 21.3, 355884.8 6690465 21.3))
BATIMENT0000000304020567;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 21:01:44;2018-09-18 13:45:52;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;4.1;12.8;17.0;21.0;14.5;Cadastre;;POLYGON Z ((355834.3 6690470.9 17, 355830.1 6690466.7 17, 355827.398315586 6690471.022695063 17, 355834.4206501446 6690471.022695063 17, 355834.3 6690470.9 17))
BATIMENT0000000304020657;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 21:01:44;2019-03-15 08:35:34;1927-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;10;20;6.4;15.0;21.4;23.8;15.1;Cadastre;A 1.0;POLYGON Z ((355878.0122543606 6690471.022695063 21.4, 355880.7020279523 6690471.022695063 21.4, 355879.4 6690469.7 21.4, 355878.0122543606 6690471.022695063 21.4))
BATIMENT0000000303968535;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;50;10;8.9;22.8;31.8;32.8;23.5;Cadastre;C 0.7;POLYGON Z ((356444 6690431.9 31.8, 356451.9 6690427.6 31.8, 356449.7 6690423.2 31.8, 356441.6 6690427.8 31.8, 356444 6690431.9 31.8))
BATIMENT0000000303969181;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1922-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;10;5.2;23.0;28.2;29.2;23.0;Cadastre;A 1.0;POLYGON Z ((356481.1 6690422.8 28.2, 356483.1 6690426.1 28.2, 356481.3 6690427.3 28.2, 356482 6690428.1 28.2, 356477.5 6690431 28.2, 356479.8 6690434.6 28.2, 356484.2 6690431.7 28.2, 356485.5 6690433.7 28.2, 356486.5 6690434 28.2, 356489.7 6690431.8 28.2, 356485.4 6690425.1 28.2, 356483.2 6690421.5 28.2, 356481.1 6690422.8 28.2))
BATIMENT0000000303968586;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;00;00;5.4;22.2;27.7;28.7;22.7;Cadastre;C 0.5;POLYGON Z ((356338.1 6690426.3 27.7, 356337.9 6690427.2 27.7, 356342 6690433.9 27.7, 356347 6690430.7 27.7, 356347.8 6690431.4 27.7, 356350.3 6690429.9 27.7, 356349.9 6690429.1 27.7, 356351.4 6690428.2 27.7, 356348.8 6690423.7 27.7, 356338.1 6690426.3 27.7))
BATIMENT0000000303968608;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.6;22.8;25.5;28.6;23.5;Cadastre;;POLYGON Z ((356463.8 6690430.6 25.5, 356461.7 6690426.7 25.5, 356459.2 6690428.5 25.5, 356461.1 6690432.3 25.5, 356463.8 6690430.6 25.5))
BATIMENT0000000303969363;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1970-01-01;;;;BDParcellaire;5.0;Corrélation;1.0;0.0;1.0;05;09;5.1;23.1;28.2;30.5;23.7;Cadastre;A 0.5;POLYGON Z ((356400.2 6690429.1 28.2, 356401.7 6690432.2 28.2, 356404.7 6690430.8 28.2, 356403 6690427.7 28.2, 356400.2 6690429.1 28.2))
BATIMENT0000000303968109;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1906-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;10;20;5.3;24.0;29.3;;;Cadastre;A 1.0;POLYGON Z ((356502 6690430.3 29.3, 356506.81139568595 6690437.471703004 29.3, 356506.81139568595 6690427.047852916 29.3, 356502 6690430.3 29.3))
BATIMENT0000000303969180;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;22.5;25.4;26.8;22.8;Cadastre;;POLYGON Z ((356474.6 6690432.9 25.4, 356477.8 6690438 25.4, 356479.8 6690434.6 25.4, 356477.5 6690431 25.4, 356474.6 6690432.9 25.4))
BATIMENT0000000303968519;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;30;30;2.2;25.0;27.2;;;Cadastre;C 0.3;POLYGON Z ((356397.6 6690436.2 27.2, 356395.2 6690431.8 27.2, 356391.4 6690433.8 27.2, 356393.4 6690438.2 27.2, 356397.6 6690436.2 27.2))
BATIMENT0000000303968108;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;19;20;9.2;22.3;31.6;32.4;22.7;Cadastre;A 0.7;POLYGON Z ((356497.6 6690433.3 31.6, 356502.7 6690441 31.6, 356504.4 6690443.7 31.6, 356506.81139568595 6690442.12735064 31.6, 356506.81139568595 6690437.471703004 31.6, 356502 6690430.3 31.6, 356497.6 6690433.3 31.6))
BATIMENT0000000303968521;Industriel, agricole ou commercial;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;2.1;22.7;24.9;25.3;23.3;Cadastre;C 0.3;POLYGON Z ((356383.3 6690438 24.9, 356388.2 6690435.5 24.9, 356385.3 6690430.7 24.9, 356369.7 6690439 24.9, 356371.1 6690440.4 24.9, 356372.8 6690443.4 24.9, 356383.3 6690438 24.9))
BATIMENT0000000303968511;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;02;2.4;23.2;25.7;30.2;23.5;Cadastre;C 0.4;POLYGON Z ((356431.5 6690438.3 25.7, 356429.2 6690434.2 25.7, 356425.6 6690436.2 25.7, 356428 6690440.3 25.7, 356431.5 6690438.3 25.7))
BATIMENT0000000303968510;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1915-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;20;6.7;23.2;30.0;32.4;23.6;Cadastre;A 0.8;POLYGON Z ((356428.1 6690440.5 30, 356428 6690440.3 30, 356425.6 6690436.2 30, 356424.1 6690433.8 30, 356416.8 6690437.2 30, 356420.2 6690444.2 30, 356428.1 6690440.5 30))
BATIMENT0000000303968107;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;20;20;7.5;22.4;30.0;32.9;22.7;Cadastre;A 1.0;POLYGON Z ((356489.9 6690438.6 30, 356489.4 6690439.7 30, 356490.8 6690441.9 30, 356493.9 6690446.8 30, 356502.7 6690441 30, 356497.6 6690433.3 30, 356489.9 6690438.6 30))
BATIMENT0000000303968517;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2012-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;3.7;22.7;26.5;28.6;23.4;Cadastre;C 0.2;POLYGON Z ((356388.7 6690449.5 26.5, 356393.5 6690447.2 26.5, 356396.9 6690445.5 26.5, 356393.4 6690438.2 26.5, 356391.4 6690433.8 26.5, 356388.2 6690435.5 26.5, 356383.3 6690438 26.5, 356388.7 6690449.5 26.5))
BATIMENT0000000303968512;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1930-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;10;8.4;22.7;31.1;33.1;23.6;Cadastre;A 1.0;POLYGON Z ((356468 6690445 31.1, 356468.6 6690444.6 31.1, 356470.5 6690447.7 31.1, 356477.5 6690443.3 31.1, 356472.6 6690435.8 31.1, 356465 6690440.8 31.1, 356468 6690445 31.1))
BATIMENT0000000303968515;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1970-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.3;23.2;30.6;31.9;23.6;Cadastre;A 0.8;POLYGON Z ((356416.4 6690436.4 30.6, 356407 6690440.8 30.6, 356410.8 6690448.6 30.6, 356420.2 6690444.2 30.6, 356416.8 6690437.2 30.6, 356416.4 6690436.4 30.6))
BATIMENT0000000303968527;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;6.0;3.0;10;20;9.2;22.2;31.5;34.0;23.0;Cadastre;C 0.8;POLYGON Z ((356355 6690432.3 31.5, 356345.2 6690438.1 31.5, 356354.3 6690453.1 31.5, 356364.5 6690447.8 31.5, 356355 6690432.3 31.5))
BATIMENT0000000303968522;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.5;22.7;26.3;29.5;23.3;Cadastre;;POLYGON Z ((356365.9 6690443 26.3, 356367.6 6690446.2 26.3, 356372.8 6690443.4 26.3, 356371.1 6690440.4 26.3, 356365.9 6690443 26.3))
BATIMENT0000000303968506;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;25;20;7.8;22.6;30.4;32.7;23.2;Cadastre;A 1.0;POLYGON Z ((356314.1 6690442.3 30.4, 356313.2 6690440.4 30.4, 356305.1 6690443.6 30.4, 356308.5 6690451.4 30.4, 356316.5 6690448.3 30.4, 356318.5 6690447.8 30.4, 356317.9 6690445.3 30.4, 356319.6 6690444.5 30.4, 356317.8 6690440.7 30.4, 356314.1 6690442.3 30.4))
BATIMENT0000000303968508;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1998-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;2.0;56;23;3.5;24.0;27.5;;;Cadastre;A 1.0;POLYGON Z ((356433 6690451 27.5, 356436.2 6690458.1 27.5, 356436.7 6690457.8 27.5, 356465.8 6690442.4 27.5, 356465 6690440.8 27.5, 356463.6 6690438.1 27.5, 356454 6690443.1 27.5, 356448.7 6690440.7 27.5, 356446.6 6690445.3 27.5, 356442.3 6690447.6 27.5, 356439.1 6690446.6 27.5, 356434.4 6690436.7 27.5, 356433.2 6690437.4 27.5, 356431.5 6690438.3 27.5, 356428 6690440.3 27.5, 356428.1 6690440.5 27.5, 356430.1 6690444.7 27.5, 356433 6690451 27.5))
BATIMENT0000000303968516;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;7.6;23.1;30.7;32.0;23.6;Cadastre;C 0.5;POLYGON Z ((356397.4 6690446.6 30.7, 356398.1 6690448.2 30.7, 356400.6 6690453.5 30.7, 356409.4 6690449.3 30.7, 356406.3 6690442.6 30.7, 356397.4 6690446.6 30.7))
BATIMENT0000000303968513;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1948-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;3.0;19;20;6.3;24.0;30.3;;;Cadastre;A 1.0;POLYGON Z ((356481.2 6690449 30.3, 356477.5 6690443.3 30.3, 356470.5 6690447.7 30.3, 356474.2 6690453.4 30.3, 356476 6690452.3 30.3, 356481.2 6690449 30.3))
BATIMENT0000000303968505;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;3.0;20;20;9.1;22.6;31.7;32.7;22.8;Cadastre;C 0.8;POLYGON Z ((356316.5 6690448.3 31.7, 356317.1 6690449.2 31.7, 356318.6 6690448.5 31.7, 356318.5 6690447.8 31.7, 356316.5 6690448.3 31.7))
BATIMENT0000000303968479;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.9;22.2;24.2;29.7;22.8;Cadastre;;POLYGON Z ((356333.8 6690443.8 24.2, 356328.3 6690445.2 24.2, 356333.4 6690453.4 24.2, 356338.7 6690451.9 24.2, 356333.8 6690443.8 24.2))
BATIMENT0000000303968509;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;02;02;3.5;24.0;27.5;;;Cadastre;B 0.4;POLYGON Z ((356428 6690453.4 27.5, 356433 6690451 27.5, 356430.1 6690444.7 27.5, 356425 6690447.1 27.5, 356428 6690453.4 27.5))
BATIMENT0000000303968106;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;24;3.2;22.6;25.9;30.6;23.1;Cadastre;A 1.0;POLYGON Z ((356485.1 6690445.4 25.9, 356484.7 6690444.9 25.9, 356482.3 6690446.5 25.9, 356485.3 6690452.4 25.9, 356490.2 6690449.5 25.9, 356496.4 6690460 25.9, 356499.9 6690457.8 25.9, 356493.9 6690446.8 25.9, 356490.8 6690441.9 25.9, 356485.1 6690445.4 25.9))
BATIMENT0000000303968487;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1850-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;3.0;20;20;10.2;22.5;32.8;34.8;23.2;Cadastre;C 0.8;POLYGON Z ((356310.8 6690456.6 32.8, 356321.2 6690452.2 32.8, 356325 6690450.6 32.8, 356324.9 6690446.1 32.8, 356318.5 6690447.8 32.8, 356318.6 6690448.5 32.8, 356317.1 6690449.2 32.8, 356316.5 6690448.3 32.8, 356308.5 6690451.4 32.8, 356310.8 6690456.6 32.8))
BATIMENT0000000303968524;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.0;23.2;26.2;;;Cadastre;;POLYGON Z ((356382.8 6690452.3 26.2, 356384.6 6690451.5 26.2, 356382.7 6690447.3 26.2, 356374.3 6690451.5 26.2, 356375.3 6690453.4 26.2, 356376.2 6690455.5 26.2, 356382.8 6690452.3 26.2))
BATIMENT0000000303968518;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2007-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;00;00;6.0;22.8;28.9;29.5;23.4;Cadastre;A 1.0;POLYGON Z ((356394.8 6690449.7 28.9, 356397.2 6690455 28.9, 356400.6 6690453.5 28.9, 356398.1 6690448.2 28.9, 356394.8 6690449.7 28.9))
BATIMENT0000000303968514;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.1;23.1;26.2;29.0;23.7;Cadastre;;POLYGON Z ((356469 6690448.6 26.2, 356473.4 6690457.2 26.2, 356477.5 6690454.6 26.2, 356476 6690452.3 26.2, 356474.2 6690453.4 26.2, 356470.5 6690447.7 26.2, 356469 6690448.6 26.2))
BATIMENT0000000303968526;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2013-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;03;02;8.8;22.1;31.0;33.0;23.0;Cadastre;C 0.9;POLYGON Z ((356360.4 6690463.1 31, 356369.6 6690458.7 31, 356372.5 6690457.3 31, 356371.4 6690455.3 31, 356366.3 6690446.8 31, 356364.5 6690447.8 31, 356354.3 6690453.1 31, 356360.4 6690463.1 31))
BATIMENT0000000303968520;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;3.8;22.3;26.1;26.9;23.2;Cadastre;;POLYGON Z ((356384.4 6690455.4 26.1, 356386.4 6690460.1 26.1, 356391.6 6690457.7 26.1, 356388 6690449.8 26.1, 356387.7 6690450 26.1, 356384.6 6690451.5 26.1, 356382.8 6690452.3 26.1, 356384.4 6690455.4 26.1))
BATIMENT0000000303968525;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.5;22.6;25.1;28.0;22.9;Cadastre;;POLYGON Z ((356376.2 6690455.5 25.1, 356375.3 6690453.4 25.1, 356371.4 6690455.3 25.1, 356372.5 6690457.3 25.1, 356376.2 6690455.5 25.1))
BATIMENT0000000303968105;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;2.8;22.7;25.6;26.4;23.4;Cadastre;;POLYGON Z ((356483.1 6690453.8 25.6, 356485.5 6690458.4 25.6, 356487.8 6690457.5 25.6, 356485.4 6690452.6 25.6, 356483.1 6690453.8 25.6))
BATIMENT0000000303968478;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;3.6;22.3;26.0;29.7;22.8;Cadastre;;POLYGON Z ((356333.4 6690453.4 26, 356330.9 6690454.1 26, 356330.4 6690454.3 26, 356331.6 6690456.5 26, 356333.7 6690460.2 26, 356336.4 6690458.6 26, 356333.4 6690453.4 26))
BATIMENT0000000303968523;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;04;1.4;22.5;24.0;25.3;23.0;Cadastre;C 0.3;POLYGON Z ((356381.3 6690456.8 24, 356383.4 6690461.6 24, 356386.4 6690460.1 24, 356384.4 6690455.4 24, 356381.3 6690456.8 24))
BATIMENT0000000303968469;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;03;02;6.7;23.1;29.9;32.7;24.2;Cadastre;B 0.6;POLYGON Z ((356422 6690466.1 29.9, 356419.7 6690461.5 29.9, 356420.6 6690461.2 29.9, 356416.2 6690451.7 29.9, 356409.9 6690454.7 29.9, 356414.4 6690464 29.9, 356416.6 6690468.9 29.9, 356417 6690468.8 29.9, 356420.9 6690466.7 29.9, 356422 6690466.1 29.9))
BATIMENT0000000303968507;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;2.9;23.8;26.7;;;Cadastre;;POLYGON Z ((356436.9 6690464 26.7, 356439.4 6690462.6 26.7, 356436.7 6690457.8 26.7, 356436.2 6690458.1 26.7, 356434.1 6690459.2 26.7, 356436.9 6690464 26.7))
BATIMENT0000000303968463;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1909-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;3.9;23.1;27.0;30.4;24.2;Cadastre;A 1.0;POLYGON Z ((356399.6 6690459.5 27, 356400.2 6690460.9 27, 356404.6 6690470.2 27, 356405.00131466467 6690471.022695063 27, 356412.6199467572 6690471.022695063 27, 356416.6 6690468.9 27, 356414.4 6690464 27, 356409.9 6690454.7 27, 356399.6 6690459.5 27))
BATIMENT0000000303968528;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;8.9;22.1;31.0;33.0;22.9;Cadastre;C 0.6;POLYGON Z ((356364.6 6690470.4 31, 356371.6 6690467.1 31, 356369.9 6690464 31, 356372.1 6690462.9 31, 356369.6 6690458.7 31, 356360.4 6690463.1 31, 356364.6 6690470.4 31))
BATIMENT0000000303968700;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1953-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;15;13;8.8;11.3;20.2;22.7;15.8;Cadastre;A 1.0;POLYGON Z ((356065.9 6690433.9 20.2, 356058.2 6690441.2 20.2, 356064.1 6690447.4 20.2, 356071.7 6690439.9 20.2, 356066.5 6690434.4 20.2, 356065.9 6690433.9 20.2))
BATIMENT0000000303968566;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1920-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;1.0;1.0;00;00;5.2;17.6;22.8;;;Cadastre;A 1.0;POLYGON Z ((356153.8 6690439.9 22.8, 356155.9 6690444.1 22.8, 356154.2 6690445.1 22.8, 356156 6690448.4 22.8, 356156.9 6690448 22.8, 356163.8 6690444.4 22.8, 356160.1 6690436.7 22.8, 356155 6690439.2 22.8, 356153.8 6690439.9 22.8))
BATIMENT0000000303968670;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;13.0;25.2;27.6;16.0;Cadastre;;POLYGON Z ((356088.9 6690443.7 25.2, 356095.5 6690450.8 25.2, 356096.1 6690450.1 25.2, 356095.8 6690449.8 25.2, 356100.8 6690445.1 25.2, 356094.3 6690438.4 25.2, 356088.9 6690443.7 25.2))
BATIMENT0000000303968558;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1939-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;10.5;16.0;26.5;27.9;17.1;Cadastre;A 1.0;POLYGON Z ((356160.8 6690455.7 26.5, 356167.8 6690452.3 26.5, 356163.8 6690444.4 26.5, 356156.9 6690448 26.5, 356160.8 6690455.7 26.5))
BATIMENT0000000303968671;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:55;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;3.0;10;20;12.4;13.1;25.5;28.0;15.9;Cadastre;A 1.0;POLYGON Z ((356081.3 6690451.2 25.5, 356088 6690458.1 25.5, 356095.5 6690450.8 25.5, 356088.9 6690443.7 25.5, 356081.3 6690451.2 25.5))
BATIMENT0000000303968701;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1961-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;9.0;6.0;50;90;20.1;10.4;30.5;31.5;15.8;Cadastre;C 0.8;POLYGON Z ((356057.5 6690440.5 30.5, 356042 6690455.6 30.5, 356048.6 6690462.5 30.5, 356064.1 6690447.4 30.5, 356058.2 6690441.2 30.5, 356057.5 6690440.5 30.5))
BATIMENT0000000303968553;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;13.1;15.0;28.1;30.7;17.3;Cadastre;A 1.0;POLYGON Z ((356145.5 6690463.3 28.1, 356146.5 6690465.7 28.1, 356146.6 6690465.9 28.1, 356154.9 6690468.1 28.1, 356162.4 6690464.4 28.1, 356163.5 6690463.9 28.1, 356171.5 6690459.8 28.1, 356167.8 6690452.3 28.1, 356160.8 6690455.7 28.1, 356145.5 6690463.3 28.1))
BATIMENT0000000303968552;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.6;15.0;30.7;32.5;17.3;Cadastre;;POLYGON Z ((356143.8 6690467 30.7, 356145.8113475314 6690471.022695063 30.7, 356156.3803260709 6690471.022695063 30.7, 356154.9 6690468.1 30.7, 356146.6 6690465.9 30.7, 356146.5 6690465.7 30.7, 356143.8 6690467 30.7))
BATIMENT0000000303968551;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;2006-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;12.4;15.3;27.7;28.1;17.0;Cadastre;A 1.0;POLYGON Z ((356142.8 6690464.6 27.7, 356140.6 6690460.4 27.7, 356131.3 6690465.1 27.7, 356132.2 6690466.8 27.7, 356130.9 6690467.5 27.7, 356130.5 6690466.7 27.7, 356122.13349342765 6690471.022695063 27.7, 356145.8113475314 6690471.022695063 27.7, 356143.8 6690467 27.7, 356146.5 6690465.7 27.7, 356145.5 6690463.3 27.7, 356142.8 6690464.6 27.7))
BATIMENT0000000303968462;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1932-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;10;20;6.5;22.7;29.2;32.0;23.6;Cadastre;A 1.0;POLYGON Z ((356394.6 6690463.5 29.2, 356390.9 6690465.2 29.2, 356393.7754049693 6690471.022695063 29.2, 356402.81749403133 6690471.022695063 29.2, 356404.6 6690470.2 29.2, 356400.2 6690460.9 29.2, 356394.6 6690463.5 29.2))
BATIMENT0000000303968480;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1900-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;19.0;3.0;10;20;8.7;22.2;31.0;35.1;23.4;Cadastre;A 1.0;MULTIPOLYGON Z (((356310.1 6690456.9 31, 356316.3858238139 6690471.022695063 31, 356323.92119780555 6690471.022695063 31, 356319.2 6690460.4 31, 356323.9 6690458.3 31, 356322.5 6690455.1 31, 356321.2 6690452.2 31, 356310.8 6690456.6 31, 356310.1 6690456.9 31)), ((356338.7 6690451.9 31, 356333.4 6690453.4 31, 356336.4 6690458.6 31, 356337.2 6690460.1 31, 356334 6690462.2 31, 356337.2 6690467.9 31, 356340.6 6690465.9 31, 356342.3 6690468.6 31, 356337.9646509401 6690471.022695063 31, 356350.868987767 6690471.022695063 31, 356338.7 6690451.9 31)), ((356326 6690470.8 31, 356325.55460987444 6690471.022695063 31, 356326.1091642465 6690471.022695063 31, 356326 6690470.8 31)))
BATIMENT0000000303968465;Indifférenciée;Indifférencié;;Oui;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;1.4;23.8;25.2;26.2;24.2;Cadastre;;POLYGON Z ((356422.1 6690468.9 25.2, 356420.9 6690466.7 25.2, 356417 6690468.8 25.2, 356418.4 6690471 25.2, 356422.1 6690468.9 25.2))
BATIMENT0000000303968614;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 19:18:06;1989-01-01;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;26.0;4.0;39;20;8.2;24.0;32.2;;;Cadastre;C 0.3;POLYGON Z ((356471.5 6690470.3 32.2, 356470.9 6690470.6 32.2, 356468.1 6690466 32.2, 356467.7 6690466.2 32.2, 356466.1 6690463.5 32.2, 356466.4 6690463.3 32.2, 356463.5 6690458.5 32.2, 356464.2 6690458.2 32.2, 356461.9 6690454.4 32.2, 356461 6690455.1 32.2, 356460.9 6690454.8 32.2, 356455.8 6690457.6 32.2, 356455 6690456.3 32.2, 356451 6690458.6 32.2, 356451.9 6690460.3 32.2, 356449.6 6690461.6 32.2, 356453.9 6690468.9 32.2, 356453.4 6690469.3 32.2, 356454.5146850406 6690471.022695063 32.2, 356471.9687751759 6690471.022695063 32.2, 356471.5 6690470.3 32.2))
BATIMENT0000000303969307;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;;;;;4.2;22.9;27.1;27.4;23.8;Cadastre;;POLYGON Z ((356438.5 6690466.9 27.1, 356437.8 6690467.3 27.1, 356437.4 6690466.5 27.1, 356430.3 6690470.8 27.1, 356430.4305453817 6690471.022695063 27.1, 356442.8577080555 6690471.022695063 27.1, 356444.2 6690470.2 27.1, 356441.3 6690465 27.1, 356438.4 6690466.7 27.1, 356438.5 6690466.9 27.1))
BATIMENT0000000303968464;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1940-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;14;10;5.9;22.5;28.5;31.3;23.2;Cadastre;A 1.0;POLYGON Z ((356386.8 6690467 28.5, 356380.8 6690470 28.5, 356381.35783367074 6690471.022695063 28.5, 356393.7754049693 6690471.022695063 28.5, 356390.9 6690465.2 28.5, 356386.8 6690467 28.5))
BATIMENT0000000303968466;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;2009-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;;;7.0;23.2;30.2;35.0;24.2;Cadastre;C 0.1;MULTIPOLYGON Z (((356426.6 6690468.7 30.2, 356422.5777719646 6690471.022695063 30.2, 356427.9837332288 6690471.022695063 30.2, 356426.6 6690468.7 30.2)), ((356418.4 6690471 30.2, 356417 6690468.8 30.2, 356416.6 6690468.9 30.2, 356412.6199467572 6690471.022695063 30.2, 356418.413869205 6690471.022695063 30.2, 356418.4 6690471 30.2)))
BATIMENT0000000303968474;Indifférenciée;Résidentiel;Commercial et services;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;1.0;00;00;7.8;22.1;30.0;32.9;22.9;Cadastre;A 1.0;POLYGON Z ((356380 6690468.7 30, 356375.0227962943 6690471.022695063 30, 356381.35783367074 6690471.022695063 30, 356380.8 6690470 30, 356380 6690468.7 30))
BATIMENT0000000303969005;Indifférenciée;Résidentiel;Annexe;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;4.0;4.0;00;00;13.5;22.2;35.8;38.4;23.3;Cadastre;C 0.9;POLYGON Z ((356295 6690400.9 35.8, 356300.8 6690410.2 35.8, 356301.7 6690409.6 35.8, 356309.6 6690404.6 35.8, 356304 6690395.4 35.8, 356296 6690400.3 35.8, 356295 6690400.9 35.8))
BATIMENT0000000303969211;Industriel, agricole ou commercial;Indifférencié;;Non;En service;2012-06-26 20:08:31;2023-01-31 17:56:57;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;;;7.3;19.7;27.0;27.2;20.1;Cadastre;C 0.2;POLYGON Z ((356168.5 6690365.1 27, 356145.2 6690387.6 27, 356144.9 6690392.6 27, 356152.8 6690405.6 27, 356162.6 6690401.5 27, 356184.1 6690451.1 27, 356202 6690443.4 27, 356202.6 6690443.2 27, 356202 6690441.8 27, 356168.5 6690365.1 27))
BATIMENT0000000303969000;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;0.0;1.0;00;00;4.1;24.0;28.1;;;Cadastre;C 0.4;POLYGON Z ((356298.9 6690411.4 28.1, 356293.1 6690402.1 28.1, 356287.9 6690405.3 28.1, 356292.2 6690415.6 28.1, 356296.6 6690412.9 28.1, 356298.9 6690411.4 28.1))
BATIMENT0000000303969008;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;1.0;2.0;15;20;8.8;22.4;31.3;34.0;22.9;Cadastre;B 0.8;POLYGON Z ((356305.5 6690415.7 31.3, 356307.1 6690414.8 31.3, 356313.6 6690410.8 31.3, 356309.6 6690404.6 31.3, 356301.7 6690409.6 31.3, 356305.5 6690415.7 31.3))
BATIMENT0000000303968999;Indifférenciée;Annexe;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;1933-01-01;;;;BDParcellaire recalée;3.0;Corrélation;1.0;0.0;1.0;05;09;2.3;22.7;25.0;26.0;23.2;Cadastre;B 0.3;POLYGON Z ((356293.4 6690418.4 25, 356298.2 6690415.4 25, 356296.6 6690412.9 25, 356292.2 6690415.6 25, 356293.4 6690418.4 25))
BATIMENT0000000303969012;Indifférenciée;Résidentiel;;Non;En service;2012-06-26 20:08:31;2019-03-15 08:35:34;;;;;BDParcellaire recalée;3.0;Interpolation bâti BDTopo;2.5;8.0;4.0;00;00;12.7;24.0;36.7;;;Cadastre;A 1.0;POLYGON Z ((356295 6690422.2 36.7, 356297.8 6690429 36.7, 356301.4 6690430.8 36.7, 356302.5 6690431 36.7, 356309.1 6690428.6 36.7, 356309.4 6690428.6 36.7, 356304.2 6690420 36.7, 356300.8 6690420.8 36.7, 356299.8 6690419.3 36.7, 356295 6690422.2 36.7))
BATIMENT0000000303968557;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.6;15.8;28.5;31.1;17.6;Cadastre;;POLYGON Z ((356169.8 6690470.4 28.5, 356175.4 6690467.7 28.5, 356171.5 6690459.8 28.5, 356163.5 6690463.9 28.5, 356162.4 6690464.4 28.5, 356154.9 6690468.1 28.5, 356156.3803260709 6690471.022695063 28.5, 356168.5546098751 6690471.022695063 28.5, 356169.8 6690470.4 28.5))
BATIMENT0000000303968559;Indifférenciée;Indifférencié;;Non;En service;2012-06-26 20:08:31;2018-09-18 13:52:32;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;12.1;16.8;29.0;31.0;17.6;Cadastre;;POLYGON Z ((356176.1 6690471 29, 356176 6690470.9 29, 356174.8 6690468.8 29, 356175.7 6690468.3 29, 356175.4 6690467.7 29, 356169.8 6690470.4 29, 356168.5546098751 6690471.022695063 29, 356176.1453901255 6690471.022695063 29, 356176.1 6690471 29))
BATIMENT0000000303969726;Indifférenciée;Commercial et services;;Non;En service;2012-06-26 20:08:31;2019-07-01 11:22:50;;;;;BDParcellaire recalée;3.0;Corrélation;1.0;;;;;15.2;19.5;34.7;39.4;24.1;Cadastre;;POLYGON Z ((356295 6690448.1 34.7, 356295.2 6690447.6 34.7, 356290.8 6690437.5 34.7, 356290.4 6690437.7 34.7, 356277.2 6690407.4 34.7, 356267.1 6690389.4 34.7, 356262.8 6690391.9 34.7, 356264.2 6690394.4 34.7, 356263 6690395.1 34.7, 356270.6 6690408.3 34.7, 356271.1 6690408 34.7, 356271.9 6690409.4 34.7, 356247.8 6690419.8 34.7, 356245.8 6690415.2 34.7, 356248.6 6690413.8 34.7, 356241.3 6690397 34.7, 356224.9 6690403.7 34.7, 356232 6690420.7 34.7, 356234.8 6690419.4 34.7, 356236.8 6690424.5 34.7, 356214.4 6690433.9 34.7, 356205.8 6690414 34.7, 356198.3 6690416.9 34.7, 356208 6690439.8 34.7, 356207.3 6690440.1 34.7, 356207.8 6690441.4 34.7, 356206 6690442.1 34.7, 356209.5 6690450.2 34.7, 356212 6690449.1 34.7, 356217 6690460.6 34.7, 356201.9 6690466.8 34.7, 356202.3 6690467.9 34.7, 356200.1 6690468.7 34.7, 356201.0480388011 6690471.022695063 34.7, 356235.16618126334 6690471.022695063 34.7, 356223.6 6690443.9 34.7, 356270.9 6690424 34.7, 356290.9 6690470.5 34.7, 356289.6820947554 6690471.022695063 34.7, 356305.2059794519 6690471.022695063 34.7, 356295 6690448.1 34.7))
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def roads(roi=None):
        roads = NantesBDT.__roads()
        if roi is not None:
            roads = clip(roads, roi, keep_geom_type=True)
        return roads

    @staticmethod
    def __roads():
        '''
        # SOURCE:
        # https://geoservices.ign.fr/bdtopo
        from geopandas import clip, read_file
        from t4gpd.demos.GeoDataFrameDemosA import GeoDataFrameDemosA
        from t4gpd.morph.STBBox import STBBox

        roi = STBBox(GeoDataFrameDemosA.psmv(), buffDist=350.0).run()
        # roi = GeoDataFrameDemosA.intraPeripheriqueNantes()

        roads = read_file('/home/tleduc/data/bdtopo/\
BDTOPO_3-3_TOUSTHEMES_SHP_LAMB93_D044_2023-06-15/\
BDTOPO/1_DONNEES_LIVRAISON_2023-06-00117/\
BDT_3-3_SHP_LAMB93_D044-ED2023-06-15\
/TRANSPORT/TRONCON_DE_ROUTE.shp', mask=roi)
        roads = clip(roads, roi, keep_geom_type=True)
        roads.to_csv('/tmp/roads.csv', sep=';', index=False)
        '''
        _sio = StringIO("""ID;NATURE;NOM_COLL_G;NOM_COLL_D;IMPORTANCE;FICTIF;POS_SOL;ETAT;DATE_CREAT;DATE_MAJ;DATE_APP;DATE_CONF;SOURCE;ID_SOURCE;ACQU_PLANI;PREC_PLANI;ACQU_ALTI;PREC_ALTI;NB_VOIES;LARGEUR;IT_VERT;PRIVE;SENS;BUS;URBAIN;VIT_MOY_VL;ACCES_VL;ACCES_PED;FERMETURE;NAT_RESTR;RESTR_H;RESTR_P;RESTR_PPE;RESTR_LAR;RESTR_LON;RESTR_MAT;BORNEDEB_G;BORNEDEB_D;BORNEFIN_G;BORNEFIN_D;INSEECOM_G;INSEECOM_D;ALIAS_G;ALIAS_D;DATE_SERV;ID_VOIE_G;ID_VOIE_D;ID_RN;ID_ITI;NUMERO;NUM_EUROP;CL_ADMIN;GESTION;TOPONYME;ITI_CYCL;VOIE_VERTE;NATURE_ITI;NOM_ITI;DELESTAGE;SRC_BAN_G;SRC_BAN_D;NOM_BAN_G;NOM_BAN_D;LD_BAN_G;LD_BAN_D;ID_BAN_G;ID_BAN_D;SENS_CYC_G;SENS_CYC_D;CYCLABLE_G;CYCLABLE_D;geometry
TRONROUT0000002215594115;Bac ou liaison maritime;;;6;Oui;0;En service;2020-11-02 11:32:34;2023-06-13 11:24:08;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;0.0;0.0;Non;Non;Sans objet;;Oui;0;Physiquement impossible;A péage;;;;;;;;;;;;;44143;44143;;;;;;ROUTNOMM0000002215594114;;;;;;Gare Maritime : Trentemoult Roquios;;;;;;;;;;;;;;;;;;LINESTRING Z (354068.3354357484 6688312.003221275 -1000, 354078.9 6688346.9 -1000, 354073.3 6688386.8 -1000, 354068.6 6688405.5 -1000, 354054.9 6688425.1 -1000, 354038.3 6688440.6 -1000)
TRONROUT0000000029478319;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Calculé;20.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;19;;22;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (353897.1 6688346.9 8.2, 353892.0022898072 6688336.138167371 8.030076326905645)
TRONROUT0000000029477602;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Calculé;20.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (353892.0022898072 6688313.729261446 7.769115768070408, 353896.4 6688324.2 7.9, 353905.1 6688342.9 8.2, 353908 6688348.3 8, 353915 6688358.1 8, 353942.1 6688392 8, 353946.4 6688396.9 8, 353977.7 6688437.9 8, 353994.8 6688458.6 8, 354010.5 6688473.6 8, 354022.4 6688483.3 8, 354025 6688486 7.9)
TRONROUT0000000029477897;Route à 1 chaussée;R BISSON;R BISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;15;2;1;44109;44109;;;;441090840;441090840;;;;;;;;;;;;;commune;commune;Rue Bisson;Rue Bisson;;;44109_0840;44109_0840;;;;;LINESTRING Z (353892.0022898072 6688352.3343514325 8.29618321118751, 353897.1 6688346.9 8.2)
TRONROUT0000000029477598;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Calculé;20.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;15;;18;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354025.9 6688506.1 7.8, 354013.6 6688494.6 8, 354001.8 6688482.6 8, 353988.2 6688464.7 8, 353970.6 6688443.5 8, 353938.9 6688402.3 8, 353935.1 6688397.6 8, 353907.7 6688363.4 8, 353900.2 6688353.1 8, 353897.1 6688346.9 8.2)
TRONROUT0000000295266746;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2020-11-02 11:32:34;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354038.3 6688440.6 7.5, 354051.4 6688456 7)
TRONROUT0000000295266747;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-17 20:06:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354051.4 6688456 7, 354038.7 6688474.8 7, 354036.3 6688472.2 7, 354033 6688476.2 7.3)
TRONROUT0000000295264785;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2014-06-16 18:46:18;;;;;Levé non GPS;5.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354033 6688476.2 7.3, 354024 6688468.4 7.4)
TRONROUT0000000295264968;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2019-09-26 21:09:31;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (354033 6688476.2 7.3, 354025 6688486 7.9)
TRONROUT0000000295266748;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2022-05-17 20:06:43;;;;;Levé non GPS;5.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354042.8 6688497.3 7.6, 354044.7 6688491.6 7.5, 354044.5 6688487.4 7.5, 354041 6688483.1 7.4, 354033 6688476.2 7.3)
TRONROUT0000000329622517;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354420.922649746 6688312.003221275 -1000, 354463.3 6688321 -1000)
TRONROUT0000000295264838;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354454.6 6688360.7 6.4, 354242.7767915867 6688312.003221275 -776.4823978961318)
TRONROUT0000000224965227;Sentier;;;6;Non;0;En service;2009-10-15 13:29:33;2012-02-13 08:57:14;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354454.6 6688360.7 -1000, 354447.1 6688379.5 -1000, 354256.2 6688409.4 -1000)
TRONROUT0000000332255660;Route à 1 chaussée;QU FERNAND CROUAN;QU FERNAND CROUAN;5;Non;0;En service;2014-02-25 17:13:51;2015-03-12 20:24:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#09D;44109#09D;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354334.6 6688436.9 -1000, 354416.8 6688480.6 -1000)
TRONROUT0000000328211059;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2013-10-08 14:41:26;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354122.6 6688570.3 7.1, 354136.1 6688577.8 7.1, 354175.9 6688599.4 7, 354182.9 6688602.9 7)
TRONROUT0000000029478190;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;99;;100;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354156.1 6688604 7.3, 354132.4 6688591.9 7)
TRONROUT0000000029478375;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;95;;98;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354218.6 6688636.1 7.7, 354159.9 6688606.1 7.5, 354156.1 6688604 7.3)
TRONROUT0000000295264950;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-17 20:06:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354535.5 6688728.8 7.4, 354531.3 6688723.9 8, 354528 6688721.2 8, 354503.1 6688712.5 7.6, 354465.5 6688699.4 7.6, 354399.4 6688672.1 7.5, 354346.6 6688652.7 7.5, 354283.6 6688626.5 7.5, 354235.7 6688604.3 7.5, 354188.2 6688574.8 7.2, 354151.9 6688551.3 7.2)
TRONROUT0000000029478017;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354182.9 6688602.9 7, 354223.4 6688622.8 7.1, 354244.4 6688632.3 7.2, 354315.4 6688662.7 6.9, 354358.3 6688679.8 7)
TRONROUT0000000328211060;Route à 1 chaussée;;;5;Non;0;En service;2013-10-08 14:41:26;2023-06-09 18:25:32;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354410.7 6688695.6 7, 354413.2 6688690.6 7, 354413.6 6688689.1 7, 354413.6 6688687.4 7, 354413.1 6688685.1 7, 354411.5 6688682.7 7, 354408.6 6688681.3 7, 354406.2 6688681.2 7, 354398.1 6688681.5 7, 354395.3 6688681.4 7, 354392 6688680.7 7, 354379.3 6688676.8 7, 354368.3 6688672.9 7, 354357.6 6688668.5 7, 354351.3 6688665.2 7, 354327 6688654.9 7, 354272.2 6688631.7 7, 354222.1 6688609.2 7.5, 354198.8 6688598.7 7.5, 354191.3 6688595.4 7.5, 354189.6 6688595 7.5, 354188.1 6688595.2 7.5, 354187.6 6688595.4 7.5, 354187 6688596.1 7.5, 354182.9 6688602.9 7)
TRONROUT0000000224965230;Sentier;MAIL DES CHANTIERS;MAIL DES CHANTIERS;6;Non;0;En service;2009-10-15 13:29:33;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091631;441091631;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;;;;;LINESTRING Z (354530.5 6688318.1 -1000, 354504.5084696476 6688312.003221275 -1000)
TRONROUT0000000329622519;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354465.32174802804 6688312.003221275 6.4, 354463.3 6688321 6.4)
TRONROUT0000000332255658;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;5;Non;0;En service;2014-02-25 17:13:51;2019-09-27 21:08:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354472.1 6688345.3 -1000, 354468.30369268695 6688312.003221275 -1000)
TRONROUT0000000295264930;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354463.3 6688321 6.4, 354454.6 6688360.7 6.4)
TRONROUT0000000332255659;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;5;Non;0;En service;2014-02-25 17:13:51;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;ROUTNOMM0000000325297519/ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354488.2 6688354.8 -1000, 354472.1 6688345.3 -1000)
TRONROUT0000000224965228;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;5;Non;0;En service;2009-10-15 13:29:33;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354472.1 6688345.3 -1000, 354454.6 6688360.7 6.4)
TRONROUT0000000332255656;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;5;Non;0;En service;2014-02-25 17:13:51;2018-02-28 15:51:21;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354416.8 6688480.6 -1000, 354488.2 6688354.8 -1000)
TRONROUT0000000328211058;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2013-10-08 14:41:26;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354358.3 6688679.8 7, 354379.6 6688688.7 7, 354396.6 6688694.7 7)
TRONROUT0000002329079194;Route à 1 chaussée;;;3;Non;0;En service;2023-02-03 11:35:45;2023-06-09 18:25:32;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354396.6 6688694.7 7, 354410.7 6688695.6 7)
TRONROUT0000000029478227;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354396.6 6688694.7 7, 354427.9 6688706.1 7.4)
TRONROUT0000000295264788;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;;;;Calculé;20.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354025 6688486 7.9, 354032.8 6688494 7.8, 354034.3 6688497.5 7.7)
TRONROUT0000000243341168;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2010-09-02 10:22:09;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354034.3 6688497.5 7.7, 354034.4 6688497.4 7.7, 354038.6 6688496.6 7.7, 354042.8 6688497.3 7.6)
TRONROUT0000000029478396;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354042.8 6688497.3 7.6, 354046.5 6688499.2 7.6, 354049.5 6688502.2 7.5, 354051.5 6688505.9 7.1)
TRONROUT0000000029478592;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354025.9 6688506.1 7.8, 354027.7 6688502.3 7.7, 354030.7 6688499.3 7.7, 354034.3 6688497.5 7.7)
TRONROUT0000000295265084;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-17 20:06:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285776843;;;;;;la Loire à Vélo;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354151.9 6688551.3 7.2, 354130.1 6688533.7 7, 354117.9 6688522 7, 354111.6 6688516.1 7, 354093.1 6688494.1 7, 354066 6688463.8 7.3, 354058.3 6688455.6 7.1, 354055.6 6688454.1 7, 354055.2 6688454.3 7, 354051.4 6688456 7)
TRONROUT0000000029477924;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354051.5 6688505.9 7.1, 354052.2 6688510 7.4, 354051.5 6688514.2 7.4, 354049.7 6688517.9 7.5, 354049.4 6688518.1 7.5)
TRONROUT0000000029477923;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354028.4 6688518.7 7.6, 354027.9 6688518.1 7.6, 354025.9 6688514.4 7.7, 354025.2 6688510.2 7.8, 354025.9 6688506.1 7.8)
TRONROUT0000000029477939;Route à 2 chaussées;BD SALVADOR ALLENDE;BD SALVADOR ALLENDE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441097803;441097803;;;;;;;;;;;;;commune;commune;Boulevard Salvador Allende;Boulevard Salvador Allende;;;44109_7803;44109_7803;;;;;LINESTRING Z (353892.0022898072 6688516.301098336 11.678685207764529, 353937.9 6688525.8 10, 353959.8 6688530.1 9.7, 353971.3 6688531.5 9.5, 353991 6688531.6 8.8, 353999 6688530.8 8.5, 354008 6688528.9 8.3, 354015.1 6688526.6 8, 354022.2 6688523.2 7.7, 354028.4 6688518.7 7.6)
TRONROUT0000000029478374;Rond-point;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354049.4 6688518.1 7.5, 354046.7 6688521 7.5, 354043 6688522.9 7.6, 354038.8 6688523.6 7.6, 354034.6 6688523 7.7, 354030.9 6688521.1 7.7, 354028.4 6688518.7 7.6)
TRONROUT0000000029478320;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;;;;;;;;;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354051.5 6688505.9 7.1, 354055.1 6688509.4 7.1, 354060.6 6688515.4 7.1, 354069.8 6688524.6 7, 354078.2 6688532.1 7.1, 354084.2 6688538.2 7.2, 354091 6688545.6 6.9, 354094.8 6688550.1 7, 354100.1 6688556.4 7.2)
TRONROUT0000000029478530;Route à 2 chaussées;BD SALVADOR ALLENDE;BD SALVADOR ALLENDE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097803;441097803;;;;;;;;;;;;;commune;commune;Boulevard Salvador Allende;Boulevard Salvador Allende;;;44109_7803;44109_7803;;;;;LINESTRING Z (353966.7 6688548.5 8.2, 353892.0022898072 6688531.256037521 11.256884257627942)
TRONROUT0000000029478383;Route à 2 chaussées;QU ERNEST RENAUD;QU ERNEST RENAUD;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092890;441092890;;;;;;;;;;;;;commune;commune;Quai Ernest Renaud;Quai Ernest Renaud;;;44109_2890;44109_2890;;;;;LINESTRING Z (354086 6688563.1 7.1, 354082.6 6688556.8 7.1, 354082.5 6688553.1 7.1, 354081.9 6688549.7 7, 354080.4 6688546.5 7.1, 354077.5 6688542.6 7.2, 354071.6 6688536.6 6.9, 354059.9 6688526.4 7, 354054 6688521 7.4, 354050.2 6688518.8 7.5, 354049.4 6688518.1 7.5)
TRONROUT0000000029478223;Route à 1 chaussée;R EUGENE VARLIN;R EUGENE VARLIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092981;441092981;;;;;;;;;;;;;commune;commune;Rue Eugène Varlin;Rue Eugène Varlin;;;44109_2981;44109_2981;;;;;LINESTRING Z (353963.1 6688556.2 8, 353946.3 6688551.6 9.2, 353916.9 6688544.6 10)
TRONROUT0000000029478684;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (353963.1 6688556.2 8, 353966.7 6688548.5 8.2)
TRONROUT0000000029478533;Route à 2 chaussées;BD SALVADOR ALLENDE;BD SALVADOR ALLENDE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097803;441097803;;;;;;;;;;;;;commune;commune;Boulevard Salvador Allende;Boulevard Salvador Allende;;;44109_7803;44109_7803;;;;;LINESTRING Z (354056.6 6688569.3 7.7, 353997.3 6688555.6 8, 353966.7 6688548.5 8.2)
TRONROUT0000000029478098;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354086 6688563.1 7.1, 354087.6 6688559.9 7, 354091.7 6688557.1 7, 354094.4 6688556.5 7, 354097.9 6688555.8 7, 354100.1 6688556.4 7.2)
TRONROUT0000000295264964;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:25:32;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354151.9 6688551.3 7.2, 354146.5 6688550.5 7.2, 354138.1 6688550.9 7.2, 354132.3 6688552.6 7.2, 354126.2 6688555.7 7.2, 354121.7 6688559.1 7.2, 354117.4 6688563 7.2, 354124.4 6688568.1 6.9, 354122.6 6688570.3 7.1)
TRONROUT0000000029478605;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354100.1 6688556.4 7.2, 354102.3 6688557 7.1, 354106.8 6688560.2 7, 354109.7 6688564.2 7, 354111.2 6688566.4 7.1)
TRONROUT0000000029478057;Route à 1 chaussée;R EUGENE VARLIN;R EUGENE VARLIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;1;;2;44109;44109;;;;441092981;441092981;;;;;;;;;;;;;commune;commune;Rue Eugène Varlin;Rue Eugène Varlin;;;44109_2981;44109_2981;;;;;LINESTRING Z (354056.6 6688569.3 7.7, 354042 6688573.7 8.3, 353966 6688557.1 8.3, 353963.1 6688556.2 8)
TRONROUT0000000295264845;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354111.2 6688566.4 7.1, 354118.3 6688569.5 7.1, 354122.6 6688570.3 7.1)
TRONROUT0000000029478604;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354087.4 6688578 7.2, 354086.9 6688577.5 7.1, 354085.2 6688573.2 7.1, 354084.9 6688568.5 7.1, 354085.8 6688563.6 7.1, 354086 6688563.1 7.1)
TRONROUT0000000029478596;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354111.2 6688566.4 7.1, 354110 6688574.6 7, 354106.6 6688579.5 6.9)
TRONROUT0000000029478118;Route à 2 chaussées;BD SALVADOR ALLENDE;BD SALVADOR ALLENDE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097803;441097803;;;;;;;;;;;;;commune;commune;Boulevard Salvador Allende;Boulevard Salvador Allende;;;44109_7803;44109_7803;;;;;LINESTRING Z (354087.4 6688578 7.2, 354056.6 6688569.3 7.7)
TRONROUT0000000029478603;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354093.7 6688581.6 7, 354089.8 6688580.3 7.1, 354087.4 6688578 7.2)
TRONROUT0000000227748757;Rond-point;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2009-12-14 09:55:50;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354106.6 6688579.5 6.9, 354103.4 6688581.6 7, 354099.8 6688582.3 7, 354093.7 6688581.6 7)
TRONROUT0000000029478211;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354132.4 6688591.9 7, 354120.9 6688586.5 7.1, 354106.6 6688579.5 6.9)
TRONROUT0000000029478541;Route à 1 chaussée;R MEURIS;R MEURIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;1;2;1;44109;44109;;;;441095616;441095616;;;;;;;;;;;;;commune;commune;Rue Meuris;Rue Meuris;;;44109_5616;44109_5616;;;;;LINESTRING Z (354053.3 6688625.6 7, 354088.4 6688589.6 7, 354093.7 6688581.6 7)
TRONROUT0000000029477600;Route à 1 chaussée;CRS DES DORIDES;CRS DES DORIDES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#021;44109#021;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354132.4 6688591.9 7, 354114.4 6688610.4 7.1, 354100.5 6688620.7 7.1)
TRONROUT0000000295265212;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354012.7 6688612.5 7.3, 353994.3 6688633 7.3, 353979.7 6688616.9 7.3, 353996.4 6688599.1 7.3, 353999 6688596.3 7.3, 353999.3 6688594.7 7.3, 353997.8 6688591.9 7.3, 353996.6 6688591.1 7.3)
TRONROUT0000000029478279;Route à 1 chaussée;COUR AUX CHAIS;COUR AUX CHAIS;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;1;;5;44109;44109;;;;44109A022;44109A022;;;;;;;;;;;;;commune;commune;Cour aux Chais;Cour aux Chais;;;44109_a022;44109_a022;;;;;LINESTRING Z (354053.3 6688625.6 7, 354029.8 6688604.4 7.3, 354017.8 6688616.3 7.3, 354012.7 6688612.5 7.3)
TRONROUT0000000029477859;Route à 1 chaussée;R GABRIEL PERI;R GABRIEL PERI;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;38;27;38;44109;44109;;;;441093422;441093422;;;;;;;;;;;;;commune;commune;Rue Gabriel Péri;Rue Gabriel Péri;;;44109_3422;44109_3422;;;;;LINESTRING Z (353963.1 6688556.2 8, 353955.7 6688587.4 8, 353944.7 6688618.9 7.4, 353940.6 6688642.1 7.4, 353940 6688655.7 7.3, 353943.3 6688667.7 7.3, 353950.4 6688688.5 7.5)
TRONROUT0000000295265171;Route à 1 chaussée;COUR DES PALUDIERS;COUR DES PALUDIERS;5;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:25:32;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A117;44109A117;;;;;;;;;;;;;commune;commune;Cour des Paludiers;Cour des Paludiers;;;44109_a117;44109_a117;;;;;LINESTRING Z (354156.1 6688604 7.3, 354138.9 6688622.8 7.3, 354097.8 6688665.5 7.3)
TRONROUT0000000029478623;Route à 1 chaussée;COUR DES PALUDIERS;COUR DES PALUDIERS;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;1;;4;44109;44109;;;;44109A117;44109A117;;;;;;;;;;;;;commune;commune;Cour des Paludiers;Cour des Paludiers;;;44109_a117;44109_a117;;;;;LINESTRING Z (354081.1 6688658.7 6.3, 354073.3 6688649.9 6, 354084.6 6688638.5 6, 354093.8 6688647 6, 354081.1 6688658.7 6.3)
TRONROUT0000000029478567;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (353950.4 6688688.5 7.5, 353920.7 6688675 8.5, 353892.0022898072 6688659.965253169 9.37794142081155)
TRONROUT0000000029478591;Route à 1 chaussée;R BABONNEAU;R BABONNEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;2;;22;44109;44109;;;;441090500;441090500;;;;;;;;;;;;;commune;commune;Rue Babonneau;Rue Babonneau;;;44109_0500;44109_0500;;;;;LINESTRING Z (353956 6688707.9 7.1, 353930.8 6688698.9 7.6, 353892.0022898072 6688682.748163568 8.52771961834611)
TRONROUT0000000029477594;Route à 1 chaussée;COUR DES PALUDIERS;COUR DES PALUDIERS;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A117;44109A117;;;;;;;;;;;;;commune;commune;Cour des Paludiers;Cour des Paludiers;;;44109_a117;44109_a117;;;;;LINESTRING Z (354081.1 6688658.7 6.3, 354090.2 6688667.6 6.4, 354091.5 6688668 6.4, 354093.4 6688668 6.4, 354095.2 6688667.6 6.4, 354097.1 6688666.3 6.4, 354097.8 6688665.5 7.3)
TRONROUT0000000029478697;Route à 1 chaussée;R MEURIS;R MEURIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;6;11;10;44109;44109;;;;441095616;441095616;;;;;;;;;;;;;commune;commune;Rue Meuris;Rue Meuris;;;44109_5616;44109_5616;;;;;LINESTRING Z (354053.3 6688625.6 7, 353972.5 6688710.7 7.1, 353970.2 6688713 7.1)
TRONROUT0000000029478395;Route à 1 chaussée;R GABRIEL PERI;R GABRIEL PERI;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441093422;441093422;;;;;;;;;;;;;commune;commune;Rue Gabriel Péri;Rue Gabriel Péri;;;44109_3422;44109_3422;;;;;LINESTRING Z (353956 6688707.9 7.1, 353954.4 6688702.4 7.2, 353950.4 6688688.5 7.5)
TRONROUT0000000295264993;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-09-28 17:33:06;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354155.1 6688724.3 7.5, 354119.8 6688708.9 7.6, 354124.6 6688696.2 7.5, 354091.1 6688686 7.6, 354083.7 6688685.4 7.6, 354076.1 6688684.5 7.6, 354067.3 6688686 7.6, 354049.9 6688696.5 7.5)
TRONROUT0000000029478154;Route à 1 chaussée;R BABONNEAU;R BABONNEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;15;;15;44109;44109;;;;441090500;441090500;;;;;;;;;;;;;commune;commune;Rue Babonneau;Rue Babonneau;;;44109_0500;44109_0500;;;;;LINESTRING Z (353956 6688707.9 7.1, 353970.2 6688713 7.1)
TRONROUT0000000029477978;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;92;;87;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354341.2 6688690.5 7.3, 354278 6688662.4 7.6, 354242.9 6688646.6 7.3, 354218.6 6688636.1 7.7)
TRONROUT0000000029477902;Route à 1 chaussée;R MICHEL LE LOU DU BREIL;R MICHEL LE LOU DU BREIL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;6;3;2;1;44109;44109;;;;441095640;441095640;;;;;;;;;;;;;commune;commune;Rue Michel le Lou du Breil;Rue Michel le Lou du Breil;;;44109_5640;44109_5640;;;;;LINESTRING Z (354218.6 6688636.1 7.7, 354213.6 6688644.4 7.3, 354171.7 6688701.8 7.4)
TRONROUT0000000029478542;Route à 1 chaussée;;;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354341.2 6688690.5 7.3, 354349.1 6688684.4 7, 354358.3 6688679.8 7)
TRONROUT0000000029478099;Route à 1 chaussée;R MICHEL LE LOU DU BREIL;R MICHEL LE LOU DU BREIL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;5;8;5;44109;44109;;;;441095640;441095640;;;;;;;;;;;;;commune;commune;Rue Michel le Lou du Breil;Rue Michel le Lou du Breil;;;44109_5640;44109_5640;;;;;LINESTRING Z (354171.7 6688701.8 7.4, 354155.1 6688724.3 7.5)
TRONROUT0000000029478296;Route à 1 chaussée;R MATHURIN BRISSONNEAU;R MATHURIN BRISSONNEAU;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;4;7;2;1;44109;44109;;;;441095492;441095492;;;;;;;;;;;;;commune;commune;Rue Mathurin Brissonneau;Rue Mathurin Brissonneau;;;44109_5492;44109_5492;;;;;LINESTRING Z (354262.7 6688736.2 6.4, 354341.2 6688690.5 7.3)
TRONROUT0000000029478583;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354171.7 6688701.8 7.4, 354178.2 6688705.9 7.4, 354203.3 6688721.9 7.9, 354219.2 6688748.7 6, 354220.2 6688750.4 6, 354224.7 6688758 6.5)
TRONROUT0000000029478221;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354261.4 6688741.9 6.1, 354262.7 6688736.2 6.4)
TRONROUT0000000029477962;Route à 1 chaussée;R MATHURIN BRISSONNEAU;R MATHURIN BRISSONNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;;9;;44109;44109;;;;441095492;441095492;;;;;;;;;;;;;commune;commune;Rue Mathurin Brissonneau;Rue Mathurin Brissonneau;;;44109_5492;44109_5492;;;;;LINESTRING Z (354224.7 6688758 6.5, 354262.7 6688736.2 6.4)
TRONROUT0000000029478308;Route à 1 chaussée;R JULES VALLES;R JULES VALLES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;2;7B;6;44109;44109;;;;441094656;441094656;;;;;;;;;;;;;commune;commune;Rue Jules Vallès;Rue Jules Vallès;;;44109_4656;44109_4656;;;;;LINESTRING Z (354336.7 6688778.8 7.1, 354331.9 6688775.6 7.1, 354287.6 6688754.4 6.3, 354261.4 6688741.9 6.1)
TRONROUT0000000029478328;Route à 1 chaussée;R CHARLES BRUNELLIERE;R CHARLES BRUNELLIERE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;3;6;5;8;44109;44109;;;;441091688;441091688;;;;;;;;;;;;;commune;commune;Rue Charles Brunellière;Rue Charles Brunellière;;;44109_1688;44109_1688;;;;;LINESTRING Z (354400.7 6688748.7 7.1, 354336.7 6688778.8 7.1)
TRONROUT0000000029478084;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;86;;84;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354426.9 6688725.4 7.1, 354341.2 6688690.5 7.3)
TRONROUT0000000295265001;Route à 1 chaussée;;;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:25:32;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354410.7 6688695.6 7, 354445.1 6688705 7, 354464.5 6688711 7, 354508.4 6688728 7, 354518.1 6688731.2 7, 354522.2 6688732.1 7, 354527.8 6688731.9 7, 354531.3 6688730.8 7, 354535.5 6688728.8 7.4)
TRONROUT0000000029478569;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens inverse;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354426.9 6688725.4 7.1, 354427.9 6688706.1 7.4)
TRONROUT0000000029478063;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354427.9 6688706.1 7.4, 354489.4 6688729.3 7.5, 354507 6688735.4 7.6, 354517.2 6688737.3 7.7, 354523.4 6688738 8.2)
TRONROUT0000000329622524;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2013-11-15 09:02:56;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;3.0;8.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354459.4 6688738.2 7.6, 354426.9 6688725.4 7.1)
TRONROUT0000000029478033;Route à 1 chaussée;PL COMMANDANT JEAN L'HERMINIER;PL COMMANDANT JEAN L'HERMINIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;9;;9;;44109;44109;;;;441092066;441092066;;;;;;;;;;;;;commune;commune;Place Commandant Jean l'Herminier;Place Commandant Jean l'Herminier;;;44109_2066;44109_2066;;;;;LINESTRING Z (354426.9 6688725.4 7.1, 354422.4 6688741.1 7.3)
TRONROUT0000000029477996;Route à 1 chaussée;R CHARLES BRUNELLIERE;R CHARLES BRUNELLIERE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441091688;441091688;;;;;;;;;;;;;commune;commune;Rue Charles Brunellière;Rue Charles Brunellière;;;44109_1688;44109_1688;;;;;LINESTRING Z (354422.4 6688741.1 7.3, 354416.9 6688743.2 7.1, 354400.7 6688748.7 7.1)
TRONROUT0000000029478725;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;3.0;8.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354503.1 6688754.8 8.4, 354459.4 6688738.2 7.6)
TRONROUT0000000029478032;Route à 1 chaussée;PL COMMANDANT JEAN L'HERMINIER;PL COMMANDANT JEAN L'HERMINIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;5;;5;44109;44109;;;;441092066;441092066;;;;;;;;;;;;;commune;commune;Place Commandant Jean l'Herminier;Place Commandant Jean l'Herminier;;;44109_2066;44109_2066;;;;;LINESTRING Z (354422.4 6688741.1 7.3, 354416.2 6688766 8.1)
TRONROUT0000000029478537;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354416.2 6688766 8.1, 354414.9 6688760.8 6.4, 354413.1 6688757.6 6, 354400.7 6688748.7 7.1)
TRONROUT0000000029478043;Route à 1 chaussée;R DE LA BRASSERIE;R DE LA BRASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;14B;13;20;44109;44109;;;;441091200;441091200;;;;;;;;;;;;;commune;commune;Rue de la Brasserie;Rue de la Brasserie;;;44109_1200;44109_1200;;;;;LINESTRING Z (354044.2 6688741.8 6.8, 353970.2 6688713 7.1)
TRONROUT0000000029478629;Route à 1 chaussée;R DAUBENTON;R DAUBENTON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;4;1;8;44109;44109;;;;441092392;441092392;;;;;;;;;;;;;commune;commune;Rue Daubenton;Rue Daubenton;;;44109_2392;44109_2392;;;;;LINESTRING Z (353970.2 6688713 7.1, 353926.2 6688761.9 8.6)
TRONROUT0000000295264847;Route à 1 chaussée;R MICHEL LE LOU DU BREIL;R MICHEL LE LOU DU BREIL;5;Non;0;En service;2012-02-08 10:00:49;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;12;9;10;7;44109;44109;;;;441095640;441095640;;;;;;;;;;;;;commune;commune;Rue Michel le Lou du Breil;Rue Michel le Lou du Breil;;;44109_5640;44109_5640;;;;;LINESTRING Z (354155.1 6688724.3 7.5, 354127.4 6688762 8.1, 354120.9 6688773.1 7.5)
TRONROUT0000000029478126;Route à 1 chaussée;R DE LA BRASSERIE;R DE LA BRASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;12;9;14;44109;44109;;;;441091200;441091200;;;;;;;;;;;;;commune;commune;Rue de la Brasserie;Rue de la Brasserie;;;44109_1200;44109_1200;;;;;LINESTRING Z (354120.9 6688773.1 7.5, 354067.7 6688750.9 7.8, 354044.2 6688741.8 6.8)
TRONROUT0000000029478014;Route à 1 chaussée;R DE LA BRASSERIE;R DE LA BRASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1B;10;1B;12;44109;44109;;;;441091200;441091200;;;;;;;;;;;;;commune;commune;Rue de la Brasserie;Rue de la Brasserie;;;44109_1200;44109_1200;;;;;LINESTRING Z (354152.6 6688786.3 11.2, 354120.9 6688773.1 7.5)
TRONROUT0000000029478233;Route à 1 chaussée;R DAUBENTON;R DAUBENTON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;9;10;3;44109;44109;;;;441092392;441092392;;;;;;;;;;;;;commune;commune;Rue Daubenton;Rue Daubenton;;;44109_2392;44109_2392;;;;;LINESTRING Z (353892.0022898072 6688789.18327599 10.338504789651587, 353904.3 6688783.5 9.6, 353914.5 6688774.5 9.1, 353926.2 6688761.9 8.6)
TRONROUT0000000029478349;Route à 1 chaussée;R CHAPTAL;R CHAPTAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;23;10;21;44109;44109;;;;441091668;441091668;;;;;;;;;;;;;commune;commune;Rue Chaptal;Rue Chaptal;;;44109_1668;44109_1668;;;;;LINESTRING Z (353926.2 6688761.9 8.6, 353955.5 6688821.4 8.9)
TRONROUT0000000029478443;Route empierrée;R BASILE VALENTIN;R BASILE VALENTIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;2;1;4;1;44109;44109;;;;441090570;441090570;;;;;;;;;;;;;commune;commune;Rue Basile Valentin;Rue Basile Valentin;;;44109_0570;44109_0570;;;;;LINESTRING Z (354019.7 6688858.5 8.9, 353997.1 6688812.2 8.4, 354044.2 6688741.8 6.8)
TRONROUT0000000029478343;Route à 1 chaussée;R FREDERIC KUHLMANN;R FREDERIC KUHLMANN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;4;5;14;44109;44109;PASSAGE LAVOISIER;PASSAGE LAVOISIER;;441093347;441093347;;;;;;;;;;;;;commune;commune;Rue Frédéric Kuhlmann;Rue Frédéric Kuhlmann;;;44109_3347;44109_3347;;;;;LINESTRING Z (354139.9 6688795.2 6.8, 354133.3 6688799.8 11.2, 354111.6 6688811.9 11.2, 354071.5 6688831.9 11.2, 354019.7 6688858.5 8.9)
TRONROUT0000000029478438;Route à 1 chaussée;R DUDREZENE;R DUDREZENE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441092600;441092600;;;;;;;;;;;;;commune;commune;Rue Dudrézène;Rue Dudrézène;;;44109_2600;44109_2600;;;;;LINESTRING Z (353892.0022898072 6688820.092773702 10.868609935007312, 353916 6688837.6 10.1, 353919 6688838 9.7, 353924.1 6688837.2 9.8)
TRONROUT0000002200361542;Sentier;ESP DES RIVEURS;ESP DES RIVEURS;6;Non;0;En service;2019-01-15 14:19:07;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RP;44109#0RP;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354605.7 6688335.8 -1000, 354611.80113874964 6688312.003221275 -1000)
TRONROUT0000000331917259;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2014-02-11 16:20:55;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;15;6;15;6;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354751.1 6688346.9 6.7, 354771.67692126974 6688312.003221275 6.82598115063123)
TRONROUT0000002200361541;Sentier;;;6;Non;0;En service;2019-01-15 14:19:07;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354681.13791808486 6688312.003221275 -1000, 354651.3 6688403.6 -1000, 354628.5 6688442.2 -1000)
TRONROUT0000000224176716;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;4;;4B;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354705.9 6688433 6.4, 354727.3 6688398.2 6.5, 354751.1 6688346.9 6.7)
TRONROUT0000000224176724;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;7;;7;;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354692 6688458.5 6.4, 354705.9 6688433 6.4)
TRONROUT0000000329622518;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;6;Non;0;En service;2013-11-15 09:02:56;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;ROUTNOMM0000000325297519/ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354692 6688458.5 6.4, 354628.5 6688442.2 -1000)
TRONROUT0000000029477634;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;38;;40;44109;44109;;;;441094796;441094796;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (354750.9 6688476.6 6.1, 354746.5 6688476.1 6.2, 354716.8 6688467.8 6.2, 354692 6688458.5 6.4)
TRONROUT0000002005205142;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2017-08-29 15:05:33;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;2B;;2;;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354692 6688458.5 6.4, 354674.4 6688485.8 6.6, 354667.8 6688498.7 6.7)
TRONROUT0000000029477753;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094796;441094796;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (354796.4 6688481.3 6.1, 354779 6688480.2 6.1, 354750.9 6688476.6 6.1)
TRONROUT0000002004822291;Route à 1 chaussée;R SOURDEAC;R SOURDEAC;5;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097956;441097956;;;;;;;;;;;;;commune;commune;Rue Sourdéac;Rue Sourdéac;;;44109_7956;44109_7956;;;;;LINESTRING Z (354750.9 6688476.6 6.1, 354748.7 6688483.1 5.8, 354741.6 6688500.8 5.8, 354732.7 6688516.7 5.8)
TRONROUT0000000224176717;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;10;11;10;11;44109;44109;;;;44109#0EA;44109#0EA;;;;;;;;;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354873.0868589397 6688312.003221275 6.8206651937565415, 354868.6 6688361.8 6.6)
TRONROUT0000000224176715;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (354868.6 6688361.8 6.6, 354805.5 6688356 6.6, 354762 6688352 6.4, 354759.7 6688351.6 6.4, 354751.1 6688346.9 6.7)
TRONROUT0000000084093559;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2007-07-12 11:22:41;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;42;47;42;47;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (354868.6 6688361.8 6.6, 354872.8 6688362.2 6.6, 354928.1 6688366.7 7.5, 354936.6 6688367 7.4)
TRONROUT0000002000615688;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2016-12-19 12:06:24;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EA;44109#0EA;;;;;;;;;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354868.6 6688361.8 6.6, 354864.8 6688397.3 6.8)
TRONROUT0000002003976220;Route à 1 chaussée;ALL NIKI DE SAINT-PHALLE;ALL NIKI DE SAINT-PHALLE;5;Non;0;En service;2017-06-01 17:22:06;2017-11-30 19:26:50;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QW;44109#0QW;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354864.8 6688397.3 9.5, 354933.4 6688403.9 8.6)
TRONROUT0000000224176726;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;9;;5;44109;44109;;;;44109#0EA;44109#0EA;;;;;;;;;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354864.8 6688397.3 6.8, 354860.4 6688448.6 7.5)
TRONROUT0000000224176723;Route à 1 chaussée;MAIL DU FRONT POPULAIRE;MAIL DU FRONT POPULAIRE;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0ID;44109#0ID;;;;;;;;;;;;;commune;commune;Mail du Front Populaire;Mail du Front Populaire;;;44109_3391;44109_3391;;;;;LINESTRING Z (354860.4 6688448.6 7.5, 354727 6688437.5 6.5, 354705.9 6688433 6.4)
TRONROUT0000000224176714;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;44109#0EA;44109#0EA;;;;;;;;;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354860.4 6688448.6 7.4, 354857 6688485.5 6.1)
TRONROUT0000002004822290;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2017-07-28 17:55:21;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;32;;36;44109;44109;;;;441094796;441094796;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (354857 6688485.5 6.1, 354796.4 6688481.3 6.1)
TRONROUT0000000029474860;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;6;;8;44109;44109;;;;44109#0EA;44109#0EA;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354849.9 6688574.8 6.3, 354851.5 6688555.7 6.2, 354857 6688485.5 6.1)
TRONROUT0000000320084030;Route à 1 chaussée;ESP EDOUARD GLISSANT;ESP EDOUARD GLISSANT;5;Non;0;En service;2013-03-12 15:44:43;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;5;44109;44109;;;;44109#0PL;44109#0PL;;;;;;;;;;;;;commune;commune;Esplanade Edouard Glissant;Esplanade Edouard Glissant;;;44109_2734;44109_2734;;;;;LINESTRING Z (354530.5 6688318.1 -1000, 354531.7029057517 6688312.003221275 -1000)
TRONROUT0000000332255639;Sentier;MAIL DES CHANTIERS;MAIL DES CHANTIERS;6;Non;0;En service;2014-02-25 17:13:18;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091631;441091631;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Mail des Chantiers;Mail des Chantiers;;;44109_1631;44109_1631;;;;;LINESTRING Z (354530.5 6688318.1 -1000, 354605.7 6688335.8 -1000)
TRONROUT0000000332255657;Route à 1 chaussée;ESP DES TRACEURS DE COQUE;ESP DES TRACEURS DE COQUE;5;Non;0;En service;2014-02-25 17:13:51;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RO;44109#0RO;ROUTNOMM0000000325297519/ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354628.5 6688442.2 -1000, 354592.6 6688417 -1000, 354488.2 6688354.8 -1000)
TRONROUT0000000329622516;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354623.6 6688582.1 -1000, 354613.1 6688576.9 -1000, 354624.9 6688526.9 -1000, 354614.6 6688519.5 -1000, 354622.7 6688473.2 -1000, 354628.5 6688442.2 -1000)
TRONROUT0000000329622527;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2013-11-15 09:02:56;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354644.7 6688537.1 7.1, 354623.6 6688582.1 8.1)
TRONROUT0000000332255636;Route à 1 chaussée;R JULIEN VIDEMENT;R JULIEN VIDEMENT;5;Non;0;En service;2014-02-25 17:13:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;7;;9;44109;44109;;;;441094684;441094684;;;;;;;;;;;;;commune;commune;Rue Julien Videment;Rue Julien Videment;;;44109_4684;44109_4684;;;;;LINESTRING Z (354657.5 6688549.3 6.7, 354638.8 6688581.1 6.6, 354637.7 6688584 6.6)
TRONROUT0000000029477686;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354623.6 6688582.1 8.1, 354615.1 6688598.2 8.6)
TRONROUT0000000029477651;Route à 1 chaussée;PONT ANNE DE BRETAGNE;PONT ANNE DE BRETAGNE;3;Non;1;En service;2006-10-04 09:41:10;2023-02-03 11:35:45;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08T;44109#08T;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354545.5 6688723.9 8.4, 354546.3 6688722.2 8.7, 354584.1 6688654.4 8.9, 354610.5 6688607 9, 354615.1 6688598.2 8.6)
TRONROUT0000000029477694;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354535.5 6688728.8 7.4, 354545.5 6688723.9 8.4)
TRONROUT0000000295264831;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo;;Sentier de découverte;Voyage à Nantes;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354545.5 6688723.9 8.4, 354547.1 6688727.1 8.3, 354546.9 6688729.7 8.2, 354546.4 6688733.9 7.8)
TRONROUT0000002004822289;Sentier;ALL ANDREE PUTMAN;ALL ANDREE PUTMAN;6;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0R3;44109#0R3;;;;;;;;;;;;;commune;commune;Allée Andrée Putman;Allée Andrée Putman;;;44109_0283;44109_0283;;;;;LINESTRING Z (354796.4 6688481.3 6.1, 354789.2 6688525.4 6, 354749.6 6688522.1 5.9, 354740.4 6688520.1 5.8, 354732.7 6688516.7 5.8)
TRONROUT0000002005205140;Route à 1 chaussée;ALL ASSIA DJEBAR;ALL ASSIA DJEBAR;5;Non;0;En service;2017-08-29 15:05:33;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;5;6;44109;44109;;;;44109#0RJ;44109#0RJ;;;;;;;;;;;;;commune;commune;Allée Assia Djebar;Allée Assia Djebar;;;44109_0421;44109_0421;;;;;LINESTRING Z (354725.2 6688530.1 5.8, 354667.8 6688498.7 6.7)
TRONROUT0000000029477828;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;5;;1;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354667.8 6688498.7 6.7, 354656.9 6688519.7 6.9, 354644.7 6688537.1 7.1)
TRONROUT0000002005205141;Route à 1 chaussée;R SOURDEAC;R SOURDEAC;5;Non;0;En service;2017-08-29 15:05:33;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097956;441097956;;;;;;;;;;;;;commune;commune;Rue Sourdéac;Rue Sourdéac;;;44109_7956;44109_7956;;;;;LINESTRING Z (354732.7 6688516.7 5.8, 354725.2 6688530.1 5.8)
TRONROUT0000000029477811;Route à 1 chaussée;R JULIEN VIDEMENT;R JULIEN VIDEMENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;12;;12;44109;44109;;;;441094684;441094684;;;;;;;;;;;;;commune;commune;Rue Julien Videment;Rue Julien Videment;;;44109_4684;44109_4684;;;;;LINESTRING Z (354644.7 6688537.1 7.1, 354657.5 6688549.3 6.7)
TRONROUT0000000029477666;Route à 1 chaussée;R SOURDEAC;R SOURDEAC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441097956;441097956;;;;;;;;;;;;;commune;commune;Rue Sourdéac;Rue Sourdéac;;;44109_7956;44109_7956;;;;;LINESTRING Z (354725.2 6688530.1 5.8, 354714.1 6688550 5.9, 354705.7 6688565.2 5.9, 354701 6688572.6 6.7)
TRONROUT0000000029477644;Route à 1 chaussée;R JULIEN VIDEMENT;R JULIEN VIDEMENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;5;10;3;6;44109;44109;;;;441094684;441094684;;;;;;;;;;;;;commune;commune;Rue Julien Videment;Rue Julien Videment;;;44109_4684;44109_4684;;;;;LINESTRING Z (354657.5 6688549.3 6.7, 354701 6688572.6 6.7)
TRONROUT0000000224176729;Route à 1 chaussée;R MAGIN;R MAGIN;5;Non;0;En service;2009-09-09 16:24:10;2012-02-08 10:00:49;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EF;44109#0EF;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354754.2 6688574.5 6.5, 354787.8 6688564.3 6.2, 354790 6688563.9 6.2, 354798.2 6688565.3 6.2)
TRONROUT0000000029477630;Route à 1 chaussée;R JULIEN VIDEMENT;R JULIEN VIDEMENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;4;1B;2;44109;44109;;;;441094684;441094684;;;;;;;;;;;;;commune;commune;Rue Julien Videment;Rue Julien Videment;;;44109_4684;44109_4684;;;;;LINESTRING Z (354701 6688572.6 6.7, 354718.2 6688581.6 6.8, 354721.6 6688582.9 6.8, 354727 6688582.5 6.8, 354754.2 6688574.5 6.5)
TRONROUT0000000029477822;Route à 1 chaussée;R MARGUERITE DURAS;R MARGUERITE DURAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;;11;;44109;44109;;;;44109#0IC;44109#0IC;;;;;;;;;;;;;commune;commune;Rue Marguerite Duras;Rue Marguerite Duras;;;44109_5377;44109_5377;;;;;LINESTRING Z (354736.5 6688624.1 6.6, 354754.2 6688574.5 6.5)
TRONROUT0000000029477717;Route à 1 chaussée;R MAGIN;R MAGIN;5;Non;0;En service;2006-10-04 09:41:10;2012-02-08 10:00:49;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EF;44109#0EF;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354798.2 6688565.3 6.2, 354849.9 6688574.8 6.3)
TRONROUT0000000224176727;Sentier;R LOUISE WEISS;R LOUISE WEISS;6;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0II;44109#0II;;;;;;;;;;;;;commune;commune;Rue Louise Weiss;Rue Louise Weiss;;;44109_5090;44109_5090;;;;;LINESTRING Z (354776.7 6688635.5 6.7, 354798.2 6688565.3 6.2)
TRONROUT0000000029475287;Route à 1 chaussée;R ARTHUR III;R ARTHUR III;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;2;1;4;44109;44109;;;;44109#0EA;44109#0EA;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;;;;commune;commune;Rue Arthur III;Rue Arthur III;;;44109_0408;44109_0408;;;;;LINESTRING Z (354843.1 6688642.7 6.7, 354849.9 6688574.8 6.3)
TRONROUT0000000029477621;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;25;;20;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354776.7 6688635.5 6.7, 354798.9 6688642 6.9, 354807.8 6688643 6.9, 354843.1 6688642.7 6.7)
TRONROUT0000000029473502;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;19;;19;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354927.1 6688638 6.7, 354915.7 6688640.3 6.9, 354903.7 6688641 6.9, 354903 6688641 6.9, 354872.1 6688641.4 6.9, 354843.1 6688642.7 6.7)
TRONROUT0000000295264929;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2019-09-27 21:08:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (354907.9 6688811.8 7.2, 354891.2 6688805.7 7.2, 354827.4 6688818.1 7.2)
TRONROUT0000000295264743;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354827.4 6688818.1 7.2, 354801.8 6688821.7 7.2, 354793 6688821.6 7.2, 354777.7 6688819.8 7.2, 354769 6688816.4 7.2)
TRONROUT0000000295264960;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354827.4 6688818.1 7.2, 354831.8 6688843.6 6.9)
TRONROUT0000000029477636;Route à 1 chaussée;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;;;;;;;;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354831.8 6688843.6 6.9, 354842.5 6688842.4 7, 354854.8 6688840.5 7.1, 354868.7 6688837.1 7.2, 354884.8 6688831.1 7.2, 354898.4 6688825.3 7.3, 354908.3 6688820.5 7.4)
TRONROUT0000000295264842;Route à 1 chaussée;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;;;;;;;;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354777.5 6688838.1 7, 354783.1 6688838.8 7, 354793.9 6688841 6.8, 354803.4 6688842.5 6.8, 354813.9 6688843.4 6.9, 354826.5 6688843.6 6.9, 354831.8 6688843.6 6.9)
TRONROUT0000000029477725;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;29;;26;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354637.7 6688584 6.6, 354638.4 6688587.1 6.6, 354641.1 6688591 6.6, 354646 6688593.9 6.6, 354676.7 6688606.2 6.6, 354680.2 6688607.7 6.6, 354705.7 6688615.1 6.6, 354736.5 6688624.1 6.6)
TRONROUT0000000224176728;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354736.5 6688624.1 6.6, 354770.7 6688633.8 6.7, 354776.7 6688635.5 6.7)
TRONROUT0000000295264976;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-02-03 11:35:38;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354769 6688816.4 7.2, 354765.9 6688815.2 7.2, 354751.5 6688807.4 7.2, 354727.1 6688798.5 7, 354696.1 6688798.9 7, 354565.4 6688748.2 7, 354562.4 6688744.8 7, 354561.6 6688741 7, 354561.5 6688738.2 7, 354561 6688736.6 7, 354559.6 6688735.1 7, 354556.7 6688734.4 7, 354546.4 6688733.9 7.8)
TRONROUT0000000029477737;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354544.3 6688744.8 7.6, 354548.4 6688747.9 7.4, 354554 6688751.9 7.2, 354564 6688757.2 7.2, 354580.9 6688764.6 7, 354623.6 6688780.9 6.9, 354707.7 6688812.1 6.9, 354760.8 6688832 6.9)
TRONROUT0000000029477755;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;56;;63;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354716.3 6688832.5 7.3, 354645.6 6688805.6 7.2)
TRONROUT0000000295264889;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:24:36;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354769 6688816.4 7.2, 354760.8 6688832 6.9)
TRONROUT0000000295264848;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354760.8 6688832 6.9, 354777.5 6688838.1 7)
TRONROUT0000000029477771;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;54;;54;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354733.2 6688839 7.1, 354716.3 6688832.5 7.3)
TRONROUT0000000029477661;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;53;;53;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354756 6688847.9 6.9, 354733.2 6688839 7.1)
TRONROUT0000000029477809;Route à 1 chaussée;R MONTAUDOUINE;R MONTAUDOUINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.0;;;;;Non;;1;;1;44109;44109;;;;441095744;441095744;;;;;;;;;;;;;commune;commune;Rue Montaudouine;Rue Montaudouine;;;44109_5744;44109_5744;;;;;LINESTRING Z (354690.2 6688865.5 8, 354694.2 6688863.4 8.1, 354704 6688850.9 7.5, 354712.2 6688840.5 7.1, 354716.3 6688832.5 7.3)
TRONROUT0000000295264997;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;5;Non;0;En service;2012-02-08 10:00:49;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354523.4 6688738 8.2, 354535.5 6688728.8 7.4)
TRONROUT0000000029477735;Route à 1 chaussée;BD LEON BUREAU;BD LEON BUREAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094904;441094904;;;;;;;;;;;;;commune;commune;Boulevard Léon Bureau;Boulevard Léon Bureau;;;44109_4904;44109_4904;;;;;LINESTRING Z (354546.4 6688733.9 7.8, 354545.7 6688737 7.8, 354544.3 6688744.8 7.6)
TRONROUT0000000029477820;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354523.4 6688738 8.2, 354529.6 6688739.3 8, 354534.5 6688740.9 7.8, 354544.3 6688744.8 7.5)
TRONROUT0000000029477836;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354503.1 6688754.8 7.9, 354509.7 6688749.2 7.1, 354523.4 6688738 8.2)
TRONROUT0000000029477829;Route à 1 chaussée;;;3;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354544.3 6688744.8 8.2, 354541.6 6688760.9 7.1, 354540.4 6688767.5 7.9)
TRONROUT0000000029477692;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:25:32;;;;;BDTopo;2.5;BDTopo;1.5;3.0;8.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;74;;74;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354540.4 6688767.5 7.6, 354526.2 6688762.7 7.9, 354503.1 6688754.8 8.4)
TRONROUT0000000029477669;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;71;;73;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354575.6 6688779.5 7.5, 354540.4 6688767.5 7.6)
TRONROUT0000000029477625;Route à 1 chaussée;R DE LA VERRERIE;R DE LA VERRERIE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;2;3;2;1;44109;44109;;;;441098356;441098356;;;;;;;;;;;;;commune;commune;Rue de la Verrerie;Rue de la Verrerie;;;44109_8356;44109_8356;;;;;LINESTRING Z (354540.4 6688767.5 7.6, 354531.7 6688816.4 9.1)
TRONROUT0000000029477759;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;64;;70;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354645.6 6688805.6 7.2, 354583.9 6688782.4 7.5, 354575.6 6688779.5 7.5)
TRONROUT0000000029478266;Route à 1 chaussée;R BATONNIER GUINAUDEAU;R BATONNIER GUINAUDEAU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;13;10;15;14;44109;44109;;;;441090624;441090624;;;;;;;;;;;;;commune;commune;Rue Bâtonnier Guinaudeau;Rue Bâtonnier Guinaudeau;;;44109_0624;44109_0624;;;;;LINESTRING Z (354531.7 6688816.4 9.1, 354512.3 6688797.6 8.3, 354496.4 6688783.4 7.9)
TRONROUT0000000029477593;Sentier;R CARDINE;R CARDINE;6;Non;0;En service;2006-10-04 09:41:10;2013-01-03 14:09:11;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0FS;44109#0FS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354560.3 6688826.6 15.7, 354567.3 6688803.5 27.9, 354572.9 6688787.2 26.5, 354575.6 6688779.5 7.5)
TRONROUT0000000029477646;Route à 1 chaussée;R FLANDRES DUNKERQUE 40;R FLANDRES DUNKERQUE 40;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;3;2;44109;44109;;;;441093140;441093140;;;;;;;;;;;;;commune;commune;Rue Flandres Dunkerque 40;Rue Flandres Dunkerque 40;;;44109_gynn5q;44109_gynn5q;;;;;LINESTRING Z (354645.6 6688805.6 7.2, 354632.6 6688840.9 9.3)
TRONROUT0000000029477633;Route à 1 chaussée;R BATONNIER GUINAUDEAU;R BATONNIER GUINAUDEAU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;9;8;11;8;44109;44109;;;;441090624;441090624;;;;;;;;;;;;;commune;commune;Rue Bâtonnier Guinaudeau;Rue Bâtonnier Guinaudeau;;;44109_0624;44109_0624;;;;;LINESTRING Z (354558.9 6688837.9 10.2, 354531.7 6688816.4 9.6)
TRONROUT0000000029477773;Escalier;R CARDINE;R CARDINE;6;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0FS;44109#0FS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354558.9 6688837.9 10.2, 354560.3 6688826.6 15.7)
TRONROUT0000000029477592;Route à 1 chaussée;R MONTAUDOUINE;R MONTAUDOUINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.0;;;;;Non;;8;;8;44109;44109;;;;441095744;441095744;;;;;;;;;;;;;commune;commune;Rue Montaudouine;Rue Montaudouine;;;44109_5744;44109_5744;;;;;LINESTRING Z (354643.8 6688846 8.5, 354632.6 6688840.9 9.3)
TRONROUT0000000029477647;Route à 1 chaussée;R BATONNIER GUINAUDEAU;R BATONNIER GUINAUDEAU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;441090624;441090624;;;;;;;;;;;;;commune;commune;Rue Bâtonnier Guinaudeau;Rue Bâtonnier Guinaudeau;;;44109_0624;44109_0624;;;;;LINESTRING Z (354615.9 6688886.2 12, 354575.6 6688851.2 10.6, 354558.9 6688837.9 10.2)
TRONROUT0000000029477668;Route à 1 chaussée;R FLANDRES DUNKERQUE 40;R FLANDRES DUNKERQUE 40;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;4;5;4;44109;44109;;;;441093140;441093140;;;;;;;;;;;;;commune;commune;Rue Flandres Dunkerque 40;Rue Flandres Dunkerque 40;;;44109_gynn5q;44109_gynn5q;;;;;LINESTRING Z (354632.6 6688840.9 9.3, 354615.9 6688886.2 12)
TRONROUT0000000029477631;Route à 1 chaussée;R DE LA VERRERIE;R DE LA VERRERIE;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:23:30;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;12;11;8;5;44109;44109;;;;441098356;441098356;;;;;;;;;;;;;commune;commune;Rue de la Verrerie;Rue de la Verrerie;;;44109_8356;44109_8356;;;;;LINESTRING Z (354514.9 6688918.7 15.5, 354515.2 6688918.1 15.4, 354517.8 6688908.7 15.4, 354531.7 6688816.4 9.6)
TRONROUT0000000029477664;Route à 1 chaussée;R MAURICE SIBILLE;R MAURICE SIBILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;11;10;11B;12;44109;44109;;;;441095520;441095520;;;;;;;;;;;;;commune;commune;Rue Maurice Sibille;Rue Maurice Sibille;;;44109_5520;44109_5520;;;;;LINESTRING Z (354637.4 6688903.6 12.7, 354615.9 6688886.2 12)
TRONROUT0000000029477801;Escalier;R DES VIGNES;R DES VIGNES;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441098484;441098484;;;;;;;;;;;;;commune;commune;Rue des Vignes;Rue des Vignes;;;44109_8484;44109_8484;;;;;LINESTRING Z (354643.4 6688894.6 11.6, 354637.4 6688903.6 12.7)
TRONROUT0000000029477674;Route à 1 chaussée;R MONTAUDOUINE;R MONTAUDOUINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.0;;;;;Non;6;;6;;44109;44109;;;;441095744;441095744;;;;;;;;;;;;;commune;commune;Rue Montaudouine;Rue Montaudouine;;;44109_5744;44109_5744;;;;;LINESTRING Z (354643.8 6688846 8.5, 354667.5 6688856.7 8.6)
TRONROUT0000000029477763;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;49;;51;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354789.1 6688863.5 7.4, 354778 6688858.8 7.3, 354756 6688847.9 6.9)
TRONROUT0000000029477855;Sentier;R FALCONET;R FALCONET;6;Non;0;En service;2006-10-04 09:41:10;2013-01-04 18:30:31;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CE;44109#0CE;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354733.2 6688839 -1000, 354729.2 6688846.5 -1000, 354720.1 6688865.8 -1000, 354711.8 6688876.5 -1000)
TRONROUT0000000029477783;Route à 1 chaussée;R MONTAUDOUINE;R MONTAUDOUINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.0;;;;;Non;4;3;2;3;44109;44109;;;;441095744;441095744;;;;;;;;;;;;;commune;commune;Rue Montaudouine;Rue Montaudouine;;;44109_5744;44109_5744;;;;;LINESTRING Z (354667.5 6688856.7 8.6, 354686.5 6688865.2 8.1, 354690.2 6688865.5 8)
TRONROUT0000000029477722;Route à 1 chaussée;R DES CAP-HORNIERS;R DES CAP-HORNIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;1;;2;44109;44109;;;;441091396;441091396;;;;;;;;;;;;;commune;commune;Rue des Cap-Horniers;Rue des Cap-Horniers;;;44109_1396;44109_1396;;;;;LINESTRING Z (354756 6688847.9 6.9, 354751 6688860.5 7.2, 354745.2 6688871.1 7.2, 354732.1 6688879.3 7.2)
TRONROUT0000000029477762;Route à 1 chaussée;R DES VIGNES;R DES VIGNES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441098484;441098484;;;;;;;;;;;;;commune;commune;Rue des Vignes;Rue des Vignes;;;44109_8484;44109_8484;;;;;LINESTRING Z (354667.5 6688856.7 8.6, 354660.9 6688868.6 8.6, 354643.4 6688894.6 11.6)
TRONROUT0000000029477695;Escalier;R DE L'HERONNIERE;R DE L'HERONNIERE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;39;;41;;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354720.3 6688892 7.1, 354718 6688890.1 7.1, 354696.5 6688872.4 8.1, 354690.2 6688865.5 8)
TRONROUT0000000029477590;Escalier;R DES MARINS;R DES MARINS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095392;441095392;;;;;;;;;;;;;commune;commune;Rue des Marins;Rue des Marins;;;44109_5392;44109_5392;;;;;LINESTRING Z (354759.3 6688899 -1000, 354781.4 6688884.4 -1000, 354789.1 6688863.5 -1000)
TRONROUT0000000029477720;Escalier;R DES CAP-HORNIERS;R DES CAP-HORNIERS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091396;441091396;;;;;;;;;;;;;commune;commune;Rue des Cap-Horniers;Rue des Cap-Horniers;;;44109_1396;44109_1396;;;;;LINESTRING Z (354732.1 6688879.3 7.2, 354727.2 6688882.5 7.1, 354723 6688886.6 7.1, 354720.3 6688892 7.1)
TRONROUT0000000029477844;Escalier;R DES CAP-HORNIERS;R DES CAP-HORNIERS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091396;441091396;;;;;;;;;;;;;commune;commune;Rue des Cap-Horniers;Rue des Cap-Horniers;;;44109_1396;44109_1396;;;;;LINESTRING Z (354759.3 6688899 -1000, 354737.4 6688880.7 -1000, 354732.1 6688879.3 -1000)
TRONROUT0000000295266737;Route à 2 chaussées;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;3.0;8.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;;;;;;;;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354912.3 6688829.4 7.3, 354862.9 6688850.5 7.5, 354859.4 6688852.1 7.5, 354839.3 6688861.1 7)
TRONROUT0000000029477709;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354777.5 6688838.1 7, 354785.8 6688841.7 6.9, 354819.3 6688855 6.8, 354823 6688859.3 7, 354825.4 6688865 6.8)
TRONROUT0000000295264982;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:24:36;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354831.8 6688843.6 6.9, 354832.2 6688846.1 6.9, 354839.3 6688861.1 7)
TRONROUT0000000029477798;Route à 2 chaussées;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;3.0;8.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354839.3 6688861.1 7, 354832.5 6688863.6 6.9, 354825.4 6688865 6.8)
TRONROUT0000000029477739;Route à 2 chaussées;QU DE LA FOSSE;QU DE LA FOSSE;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;44;;48;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354806.2 6688868 7, 354792.8 6688865.2 7.5, 354789.1 6688863.5 7.4)
TRONROUT0000000029477815;Route à 2 chaussées;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;;;;;;;;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354825.4 6688865 6.8, 354818.2 6688866.8 7.4, 354806.2 6688868 7)
TRONROUT0000000029477810;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354825.4 6688865 6.8, 354825.4 6688867.2 6.8, 354825.7 6688870.3 7.3, 354828.4 6688879.2 7)
TRONROUT0000000029477757;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;42;;42;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354828.4 6688879.2 7, 354806.2 6688868 7)
TRONROUT0000000029477738;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;40;;40;44109;44109;;;;441093235;441093235;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354852.5 6688891.6 7.1, 354828.4 6688879.2 7)
TRONROUT0000000029473856;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354934.9 6688932.9 7, 354931.9 6688930.5 7.2, 354896.4 6688912.5 7.4, 354894.2 6688911.4 7.4, 354852.5 6688891.6 7.1)
TRONROUT0000000029474731;Route à 1 chaussée;R ALAIN BARBE TORTE;R ALAIN BARBE TORTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;12;19;10;15;44109;44109;;;;441090068;441090068;;;;;;;;;;;;;commune;commune;Rue Alain Barbe Torte;Rue Alain Barbe Torte;;;44109_0068;44109_0068;;;;;LINESTRING Z (355271.4 6688330.2 7, 355272.548340405 6688312.003221275 7.088333877304951)
TRONROUT0000000224176722;Route à 1 chaussée;R PIERRE LANDAIS;R PIERRE LANDAIS;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441096608;441096608;;;;;;;;;;;;;commune;commune;Rue Pierre Landais;Rue Pierre Landais;;;44109_6608;44109_6608;;;;;LINESTRING Z (355271.4 6688330.2 7, 355218.5 6688325.4 6.9, 355193.3 6688323.7 6.8)
TRONROUT0000000029473632;Route à 1 chaussée;R ALAIN BARBE TORTE;R ALAIN BARBE TORTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;13;8;9;8;44109;44109;;;;441090068;441090068;;;;;;;;;;;;;commune;commune;Rue Alain Barbe Torte;Rue Alain Barbe Torte;;;44109_0068;44109_0068;;;;;LINESTRING Z (355266.6 6688382.5 6.8, 355267.1 6688377.6 6.9, 355271.4 6688330.2 7)
TRONROUT0000000224176720;Route à 1 chaussée;R DE LA SAVONNERIE;R DE LA SAVONNERIE;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;44109#0IE;44109#0IE;;;;;;;;;;;;;commune;commune;Rue de la Savonnerie;Rue de la Savonnerie;;;44109_7853;44109_7853;;;;;LINESTRING Z (355188 6688390.8 5.9, 355193.3 6688323.7 6.9)
TRONROUT0000000029474516;Rond-point;PL FRANCOIS II;PL FRANCOIS II;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;4;;8;44109;44109;;;;441093304;441093304;;;;;;;;;;;;;commune;commune;Place François II;Place François II;;;44109_3304;44109_3304;;;;;LINESTRING Z (355249.3 6688395.7 6.7, 355252.1 6688390.9 6.7, 355255.5 6688387 6.8, 355259.4 6688384.8 6.8, 355263.2 6688382.8 6.8, 355266.6 6688382.5 6.8)
TRONROUT0000000029473545;Rond-point;PL FRANCOIS II;PL FRANCOIS II;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;6C;;6A;44109;44109;;;;441093304;441093304;;;;;;;;;;;;;commune;commune;Place François II;Place François II;;;44109_3304;44109_3304;;;;;LINESTRING Z (355266.6 6688382.5 6.8, 355272 6688385.7 6.8, 355275.8 6688388.5 6.8, 355278.2 6688391 6.8, 355279.5 6688394.3 6.8, 355280.2 6688400.3 6.8)
TRONROUT0000000029473631;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;31;;31;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355188 6688390.8 5.8, 355219.1 6688393.6 5.5, 355249.3 6688395.7 6.7)
TRONROUT0000000029473834;Rond-point;PL FRANCOIS II;PL FRANCOIS II;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441093304;441093304;;;;;;;;;;;;;commune;commune;Place François II;Place François II;;;44109_3304;44109_3304;;;;;LINESTRING Z (355255.2 6688410.5 6.5, 355252.8 6688408.3 6.6, 355250.8 6688405.7 6.5, 355249.7 6688400.7 6.5, 355249.3 6688395.7 6.7)
TRONROUT0000000029473851;Rond-point;PL FRANCOIS II;PL FRANCOIS II;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;2A;;2B;44109;44109;;;;441093304;441093304;;;;;;;;;;;;;commune;commune;Place François II;Place François II;;;44109_3304;44109_3304;;;;;LINESTRING Z (355280.2 6688400.3 6.8, 355278.8 6688403.9 6.8, 355275 6688408.3 6.8, 355269.5 6688412.5 6.6, 355263.6 6688414.4 6.5)
TRONROUT0000000029473669;Rond-point;PL FRANCOIS II;PL FRANCOIS II;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093304;441093304;;;;;;;;;;;;;commune;commune;Place François II;Place François II;;;44109_3304;44109_3304;;;;;LINESTRING Z (355263.6 6688414.4 6.5, 355259.2 6688414 6.5, 355255.2 6688410.5 6.5)
TRONROUT0000002003976213;Sentier;R MADAME DE STOLZ;R MADAME DE STOLZ;6;Non;0;En service;2017-06-01 17:22:06;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;4;;10;44109;44109;;;;44109#0QI;44109#0QI;;;;;;;;;;;;;commune;commune;Rue Madame de Stolz;Rue Madame de Stolz;;;44109_5186;44109_5186;;;;;LINESTRING Z (355089.3 6688314 6.8, 355089.5394980262 6688312.003221275 6.808656555164913)
TRONROUT0000000222675264;Route à 1 chaussée;R PIERRE LANDAIS;R PIERRE LANDAIS;5;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;19;;19;;44109;44109;;;;441096608;441096608;;;;;;;;;;;;;commune;commune;Rue Pierre Landais;Rue Pierre Landais;;;44109_6608;44109_6608;;;;;LINESTRING Z (355089.3 6688314 6.8, 355078.7 6688313.2 6.7)
TRONROUT0000002003976214;Route à 1 chaussée;R PIERRE LANDAIS;R PIERRE LANDAIS;5;Non;0;En service;2017-06-01 17:22:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;11;6;17;10;44109;44109;;;;441096608;441096608;;;;;;;;;;;;;commune;commune;Rue Pierre Landais;Rue Pierre Landais;;;44109_6608;44109_6608;;;;;LINESTRING Z (355146.2 6688318.6 6.8, 355089.3 6688314 6.8)
TRONROUT0000000039836663;Route à 1 chaussée;R PIERRE LANDAIS;R PIERRE LANDAIS;5;Non;0;En service;2006-11-15 11:31:12;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;5;;9;;44109;44109;;;;441096608;441096608;;;;;;;;;;;;;commune;commune;Rue Pierre Landais;Rue Pierre Landais;;;44109_6608;44109_6608;;;;;LINESTRING Z (355193.3 6688323.7 6.8, 355146.2 6688318.6 6.8)
TRONROUT0000000222675262;Route à 1 chaussée;R DES FERBLANTIERS;R DES FERBLANTIERS;5;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;44109#0IM;44109#0IM;;;;;;;;;;;;;commune;commune;Rue des Ferblantiers;Rue des Ferblantiers;;;44109_3105;44109_3105;;;;;LINESTRING Z (355073.8 6688380.1 7.3, 355078.7 6688313.2 6.8)
TRONROUT0000000039834801;Route à 1 chaussée;R JULIEN LE PANSE;R JULIEN LE PANSE;5;Non;0;En service;2006-11-14 10:15:41;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441094677;441094677;;;;;;;;;;;;;commune;commune;Rue Julien Le Panse;Rue Julien Le Panse;;;44109_4677;44109_4677;;;;;LINESTRING Z (355139.4 6688386.4 9.1, 355146.2 6688318.6 7.9)
TRONROUT0000000029474207;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355073.8 6688380.1 7.2, 355087.9 6688381.5 7.2)
TRONROUT0000000039836662;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-11-15 11:31:12;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;37;;37;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355087.9 6688381.5 7.2, 355139.4 6688386.4 6.5)
TRONROUT0000000224176721;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355139.4 6688386.4 6.5, 355188 6688390.8 5.8)
TRONROUT0000000029474124;Route à 1 chaussée;R DE L'ILE MABON;R DE L'ILE MABON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094279;441094279;;;;;;;;;;;;;commune;commune;Rue de l'Ile Mabon;Rue de l'Ile Mabon;;;44109_4279;44109_4279;;;;;LINESTRING Z (355079.5 6688467.6 6.7, 355087.9 6688381.5 7.2)
TRONROUT0000002003976212;Route à 1 chaussée;R PIERRE LANDAIS;R PIERRE LANDAIS;5;Non;0;En service;2017-06-01 17:22:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;21;16;45;20;44109;44109;;;;441096608;441096608;;;;;;;;;;;;;commune;commune;Rue Pierre Landais;Rue Pierre Landais;;;44109_6608;44109_6608;;;;;LINESTRING Z (355078.7 6688313.2 6.7, 355063.81831672596 6688312.003221275 6.7)
TRONROUT0000000029474043;Route à 1 chaussée;R LEON DUROCHER;R LEON DUROCHER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;2;7;2;1;44109;44109;;;;441094906;441094906;;;;;;;;;;;;;commune;commune;Rue Léon Durocher;Rue Léon Durocher;;;44109_4906;44109_4906;;;;;LINESTRING Z (354942.2870795132 6688312.003221275 6.9, 354938 6688357.1 6.9, 354936.6 6688367 7.2)
TRONROUT0000002000615691;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2016-12-19 12:06:24;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;40;45T;40;41;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (354936.6 6688367 7.4, 355042.4 6688377.1 7.3)
TRONROUT0000000222675263;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;39;;37;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355042.4 6688377.1 7.3, 355073.8 6688380.1 7.2)
TRONROUT0000002003976219;Sentier;ALL LOUISE BOURGEOIS;ALL LOUISE BOURGEOIS;6;Non;0;En service;2017-06-01 17:22:06;2022-01-04 14:06:02;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#0QV;44109#0QV;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354936.6 6688367 7.1, 354934.9 6688375.6 7.8, 354933.4 6688403.9 8.6)
TRONROUT0000002000615685;Route à 1 chaussée;ALL FRIDA KAHLO;ALL FRIDA KAHLO;5;Non;0;En service;2016-12-19 12:06:24;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QG;44109#0QG;;;;;;;;;;;;;commune;commune;Allée Frida Kahlo;Allée Frida Kahlo;;;44109_3383;44109_3383;;;;;LINESTRING Z (355039 6688414.2 7.2, 355042.4 6688377.1 7.3)
TRONROUT0000002000615686;Route à 1 chaussée;ALL NIKI DE SAINT-PHALLE;ALL NIKI DE SAINT-PHALLE;5;Non;0;En service;2016-12-19 12:06:24;2017-11-30 19:26:50;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QW;44109#0QW;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354933.4 6688403.9 8.6, 355039 6688414.2 7.2)
TRONROUT0000002000615687;Route à 1 chaussée;ALL FRIDA KAHLO;ALL FRIDA KAHLO;5;Non;0;En service;2016-12-19 12:06:24;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;2;44109;44109;;;;44109#0QG;44109#0QG;;;;;;;;;;;;;commune;commune;Allée Frida Kahlo;Allée Frida Kahlo;;;44109_3383;44109_3383;;;;;LINESTRING Z (355034.4 6688465.7 7.2, 355039 6688414.2 7.2)
TRONROUT0000000224176725;Route à 1 chaussée;MAIL DU FRONT POPULAIRE;MAIL DU FRONT POPULAIRE;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0ID;44109#0ID;;;;;;;;;;;;;commune;commune;Mail du Front Populaire;Mail du Front Populaire;;;44109_3391;44109_3391;;;;;LINESTRING Z (355034.4 6688465.7 7.2, 354860.4 6688448.6 7.5)
TRONROUT0000002000615689;Route à 1 chaussée;ALL FRIDA KAHLO;ALL FRIDA KAHLO;5;Non;0;En service;2016-12-19 12:06:24;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QG;44109#0QG;;;;;;;;;;;;;commune;commune;Allée Frida Kahlo;Allée Frida Kahlo;;;44109_3383;44109_3383;;;;;LINESTRING Z (355031.4 6688499.2 7.2, 355034.4 6688465.7 7.2)
TRONROUT0000002004822299;Route à 1 chaussée;PL DES ERABLES;PL DES ERABLES;5;Non;0;En service;2017-07-28 17:55:21;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0IJ;44109#0IJ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355165.7 6688459.7 7.8, 355183.6 6688450.2 8.1)
TRONROUT0000002004822298;Sentier;R DES ARCHITECTES;R DES ARCHITECTES;6;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;6;;6;44109;44109;;;;44109#0IL;44109#0IL;;;;;;;;;;;;;commune;commune;Rue des Architectes;Rue des Architectes;;;44109_0351;44109_0351;;;;;LINESTRING Z (355165.7 6688459.7 7.8, 355149.5 6688463.8 7.5, 355142 6688468.1 7.5, 355134.6 6688471.5 7.3, 355123.9 6688471.7 7.1, 355111.5 6688470 6.9, 355079.5 6688467.6 6.7)
TRONROUT0000000222675267;Route à 1 chaussée;PL DES ERABLES;PL DES ERABLES;5;Non;0;En service;2009-07-06 17:39:41;2021-11-18 18:07:39;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0IJ;44109#0IJ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355183.6 6688450.2 8.1, 355182.7 6688455.2 8, 355181.6 6688471 7.8, 355181 6688485 9.2, 355181.3 6688510.1 8.6)
TRONROUT0000000029473528;Route à 1 chaussée;PL DES ERABLES;PL DES ERABLES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0IJ;44109#0IJ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355160.9 6688509.7 8.5, 355162.1 6688493.9 8.6, 355163.5 6688472.7 8.7, 355165.7 6688459.7 7.8)
TRONROUT0000002004822300;Route à 1 chaussée;R DE L'ILE MABON;R DE L'ILE MABON;5;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094279;441094279;;;;;;;;;;;;;commune;commune;Rue de l'Ile Mabon;Rue de l'Ile Mabon;;;44109_4279;44109_4279;;;;;LINESTRING Z (355076 6688502.9 6.6, 355079.5 6688467.6 6.7)
TRONROUT0000000029473642;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;11;12;13;16;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (355131.6 6688508.4 7.7, 355126.7 6688507.8 7.7, 355121 6688507.3 7.7, 355115 6688506.7 7.6, 355108.9 6688506.3 7.6, 355102.7 6688505.8 7.6, 355096.3 6688505.4 7.5, 355089.8 6688504.8 7.5, 355083.1 6688504.2 7.4, 355076 6688502.9 7.5)
TRONROUT0000000224176719;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2009-09-09 16:24:10;2023-04-07 14:37:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;5;8;9;8;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (355160.9 6688509.7 7.7, 355155.5 6688510 7.7, 355151.1 6688509.9 7.6, 355146.8 6688509.7 7.7, 355142.2 6688509.4 7.7, 355137.3 6688509 7.7, 355132.2 6688508.5 7.8, 355131.6 6688508.4 7.7)
TRONROUT0000000029474175;Route à 1 chaussée;PL DES ERABLES;PL DES ERABLES;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0IJ;44109#0IJ;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355181.3 6688510.1 8.6, 355174.5 6688510 8.6, 355160.9 6688509.7 8.5)
TRONROUT0000000222675265;Route à 1 chaussée;;;5;Non;0;En service;2009-07-06 17:39:41;2017-11-03 16:27:30;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355181.3 6688510.1 8.6, 355179.2 6688550.9 6.1)
TRONROUT0000000222675266;Route à 1 chaussée;R DE L'ANGELIQUE DES ESTUAIRES;R DE L'ANGELIQUE DES ESTUAIRES;5;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0IP;44109#0IP;;;;;;;;;;;;;commune;commune;Rue de l'Angélique des Estuaires;Rue de l'Angélique des Estuaires;;;44109_0286;44109_0286;;;;;LINESTRING Z (355127.1 6688568.2 6.1, 355131.6 6688508.4 7.8)
TRONROUT0000000029474240;Route à 1 chaussée;R DES ARCHITECTES;R DES ARCHITECTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;44109#0IL;44109#0IL;;;;;;;;;;;;;commune;commune;Rue des Architectes;Rue des Architectes;;;44109_0351;44109_0351;;;;;LINESTRING Z (355255.2 6688410.5 6.5, 355249.2 6688414.2 6.6, 355219.4 6688430.3 7.3, 355183.6 6688450.2 8.1)
TRONROUT0000000029474203;Route à 1 chaussée;R ALAIN BARBE TORTE;R ALAIN BARBE TORTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;21;;21;;44109;44109;;;;441090068;441090068;;;;;;;;;;;;;commune;commune;Rue Alain Barbe Torte;Rue Alain Barbe Torte;;;44109_0068;44109_0068;;;;;LINESTRING Z (355255.8 6688514.9 6.6, 355256.6 6688502.5 6.6, 355258.1 6688486.8 6.6, 355261.1 6688472.5 6.5, 355263.6 6688414.4 6.5)
TRONROUT0000000222675269;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2009-07-06 17:39:41;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (355181.3 6688510.1 8.6, 355255.8 6688514.9 6.6)
TRONROUT0000000222675270;Route à 1 chaussée;R ALAIN BARBE TORTE;R ALAIN BARBE TORTE;5;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;21;;21;;44109;44109;;;;441090068;441090068;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Alain Barbe Torte;Rue Alain Barbe Torte;;;44109_0068;44109_0068;;;;;LINESTRING Z (355254.6 6688533.6 6.6, 355255.8 6688514.9 6.6)
TRONROUT0000002200207676;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2018-12-18 17:48:46;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;4;;4;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355254.6 6688533.6 7, 355295.3 6688523.4 6.6)
TRONROUT0000000295264885;Sentier;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;6;;6;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355254.6 6688533.6 7, 355226 6688539.9 6.8, 355220.3 6688541.8 6.6, 355217.1 6688543 6.6, 355196.7 6688547.3 6.1, 355191.5 6688548.6 6)
TRONROUT0000000222675268;Sentier;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;6;Non;0;En service;2009-07-06 17:39:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355191.5 6688548.6 6, 355179.2 6688550.9 6.1)
TRONROUT0000000029474738;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2016-10-10 15:04:37;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355175.4 6688758.2 6.9, 355177.8 6688753.7 6.9, 355181.6 6688751.8 6.6, 355197 6688748.3 6.4, 355263.6 6688733.7 6.3, 355329.8 6688719.1 6.1, 355361.4 6688711.6 4.9)
TRONROUT0000000287826388;Route à 1 chaussée;QU DE TOURVILLE;QU DE TOURVILLE;5;Non;0;En service;2011-08-25 15:33:41;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441098161;441098161;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai de Tourville;Quai de Tourville;;;44109_8161;44109_8161;;;;;LINESTRING Z (355308.3 6688738.6 6.5, 355257.6 6688749.5 6.7, 355250.7 6688750.9 6.7)
TRONROUT0000000029474598;Route à 1 chaussée;QU DE TOURVILLE;QU DE TOURVILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;4;;7;44109;44109;;;;441098161;441098161;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai de Tourville;Quai de Tourville;;;44109_8161;44109_8161;;;;;LINESTRING Z (355250.7 6688750.9 6.7, 355227 6688755.9 6.7, 355212.4 6688758.7 6.7, 355193.2 6688761.8 6.7, 355185.8 6688762.6 6.7)
TRONROUT0000000029474407;Route à 1 chaussée;R DE L'ILE MABON;R DE L'ILE MABON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441094279;441094279;;;;;;;;;;;;;commune;commune;Rue de l'Ile Mabon;Rue de l'Ile Mabon;;;44109_4279;44109_4279;;;;;LINESTRING Z (355068.4 6688588.5 6.1, 355076 6688502.9 6.6)
TRONROUT0000000224176718;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2009-09-09 16:24:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;8;;8B;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355179.2 6688550.9 6.1, 355162.6 6688556 6.1, 355127.1 6688568.2 6.1)
TRONROUT0000000029474582;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;10;;11;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355127.1 6688568.2 6.1, 355087.6 6688581.8 6.1, 355068.4 6688588.5 6.1)
TRONROUT0000002000167888;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2016-10-10 15:04:37;2016-12-13 13:42:35;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355129.9 6688755.7 6.7, 355138.6 6688749.6 6.6, 355144.7 6688747.3 6.7)
TRONROUT0000002000167886;Route à 1 chaussée;;;6;Non;0;En service;2016-10-10 15:04:37;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (355144.7 6688747.3 6.7, 355148.1 6688755.1 6.7, 355153.8 6688755.3 6.7, 355157.1 6688757.1 6.8, 355160.2 6688759.6 6.8, 355175.4 6688758.2 6.9)
TRONROUT0000000029474639;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355111.7 6688760.9 7, 355112.6 6688757.4 7.6, 355114.1 6688755.4 7.5, 355116.7 6688752.9 7.3, 355119.7 6688751.7 7.3, 355121.1 6688751.6 7.3, 355123.6 6688751.7 7.3, 355125.3 6688752.2 7.3, 355128.2 6688753.4 7.5, 355129.9 6688755.7 6.7)
TRONROUT0000000029475132;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355129.9 6688755.7 6.7, 355130.8 6688759.5 7.8, 355131 6688761.9 7.9, 355130.4 6688764.4 7.3)
TRONROUT0000002000167889;Route à 1 chaussée;;;5;Non;0;En service;2016-10-10 15:04:37;2019-04-04 22:00:01;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (355173 6688764.5 6.9, 355175.4 6688758.2 6.9)
TRONROUT0000000029473646;Route à 1 chaussée;QU DE TOURVILLE;QU DE TOURVILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098161;441098161;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai de Tourville;Quai de Tourville;;;44109_8161;44109_8161;;;;;LINESTRING Z (355185.8 6688762.6 6.7, 355173 6688764.5 6.9)
TRONROUT0000000295265202;Route à 1 chaussée;QU DE TOURVILLE;QU DE TOURVILLE;5;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;8;;8;44109;44109;;;;441098161;441098161;;;;;;;;;;;;;commune;commune;Quai de Tourville;Quai de Tourville;;;44109_8161;44109_8161;;;;;LINESTRING Z (355173 6688764.5 6.9, 355160.3 6688765.7 6.9, 355149.2 6688766.3 6.9, 355141.2 6688766.5 6.9, 355135.1 6688765.5 6.9, 355130.4 6688764.4 7.3)
TRONROUT0000000029474611;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;19;;21;;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (354988.8 6688496.2 6.8, 354857 6688485.5 6.1)
TRONROUT0000000029473499;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;17;22;17;28;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (355031.4 6688499.2 7.2, 355005 6688497.1 7, 354988.8 6688496.2 6.8)
TRONROUT0000002000615690;Route à 1 chaussée;R LA NOUE BRAS DE FER;R LA NOUE BRAS DE FER;5;Non;0;En service;2016-12-19 12:06:24;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;15;14;15;18;44109;44109;;;;441094796;441094796;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue La Noue Bras de Fer;Rue La Noue Bras de Fer;;;44109_4796;44109_4796;;;;;LINESTRING Z (355076 6688502.9 6.6, 355039.3 6688499.9 7.2, 355031.4 6688499.2 7.2)
TRONROUT0000000029474302;Route à 1 chaussée;R OLYMPE DE GOUGES;R OLYMPE DE GOUGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;5;;5;;44109;44109;;;;441096027;441096027;;;;;;;;;;;;;commune;commune;Rue Olympe de Gouges;Rue Olympe de Gouges;;;44109_6027;44109_6027;;;;;LINESTRING Z (354974.3 6688621 6.3, 354988.8 6688496.2 6.8)
TRONROUT0000000295265066;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355191.5 6688548.6 6, 355178.5 6688562.4 6.3, 355168 6688573.3 5.3, 355162.9 6688580.5 5.3, 355160.1 6688582.6 5.3, 355151.4 6688584.6 5.3, 355116.3 6688592.7 5.3, 355079.6 6688601.1 5.3, 355061.4 6688605.4 5.3, 355038.7 6688611.9 5.3, 355002.8 6688624.5 5.3, 354969.4 6688636.4 5.3, 354931.8 6688648.7 5.3, 354926 6688649.7 6.9)
TRONROUT0000000029474082;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;18;;15;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354974.3 6688621 6.3, 354998.6 6688613 6.2, 355029.8 6688602.1 6, 355037.7 6688599.3 6, 355068.4 6688588.5 6.1)
TRONROUT0000000029474268;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (354927.1 6688638 6.7, 354974.3 6688621 6.3)
TRONROUT0000000295264844;Route à 1 chaussée;PLE VICTOR SCHOELCHER;PLE VICTOR SCHOELCHER;6;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H5;44109#0H5;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354926 6688649.7 6.9, 354927.1 6688638 8.6)
TRONROUT0000000029473557;Route à 1 chaussée;PLE VICTOR SCHOELCHER;PLE VICTOR SCHOELCHER;6;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H5;44109#0H5;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354925.8 6688653.6 6.6, 354926 6688649.7 6.9)
TRONROUT0000000223318873;Route à 1 chaussée;PLE VICTOR SCHOELCHER;PLE VICTOR SCHOELCHER;6;Non;1;En service;2009-08-14 12:59:03;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H5;44109#0H5;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354909.3 6688800.6 6.6, 354913.6 6688766.7 4.5, 354916 6688739.8 2.7, 354921.1 6688696.9 2.4, 354924.3 6688666.1 2.1, 354925.8 6688653.6 6.6)
TRONROUT0000002000167887;Route à 1 chaussée;;;6;Non;0;En service;2016-10-10 15:04:37;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (354907.9 6688811.8 7.2, 354917.3 6688808 7.1, 354932 6688801.4 7.1, 354947.5 6688794.2 7, 354965.3 6688787 7, 354989.8 6688778.8 6.9, 355047.3 6688765.8 6.9, 355102.3 6688755.9 6.9, 355109.6 6688752.2 6.8, 355117.4 6688747.8 6.8, 355126 6688747.2 6.7, 355142.3 6688741.4 6.7, 355144.7 6688747.3 6.7)
TRONROUT0000000029473518;Route à 1 chaussée;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;;;;;;;;;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354939.3 6688811 7.3, 354948.1 6688802.4 7.7, 354953.7 6688798.6 7.4, 354964.9 6688793.1 7.2, 354984.4 6688785.2 6.9, 355039.5 6688771.9 6.9, 355082.5 6688763.5 7, 355107.8 6688761 7.1, 355111.7 6688760.9 7)
TRONROUT0000000295264839;Route à 1 chaussée;PLE VICTOR SCHOELCHER;PLE VICTOR SCHOELCHER;6;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H5;44109#0H5;ROUTNOMM0000002333266497/ROUTNOMM0000000325297519;ITI_AUT_0000002285710202;;;;;;la Loire à Vélo/Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354907.9 6688811.8 7.2, 354909.3 6688800.6 6.6)
TRONROUT0000000029474760;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354923.4 6688814.2 7.3, 354924.3 6688812.5 7.3, 354925.5 6688811 7.3, 354927 6688809.8 7.2, 354928.7 6688808.9 7.2, 354930.5 6688808.3 7.2, 354934.3 6688808.3 7.2, 354936.1 6688808.9 7.3, 354939.3 6688811 7.3)
TRONROUT0000000029474756;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354939.3 6688811 7.3, 354940.5 6688812.5 7.6, 354941.4 6688814.2 7.6, 354942 6688816 7.6, 354942.2 6688817.9 7.6, 354941.5 6688821.1 7.7)
TRONROUT0000000223318874;Route à 1 chaussée;PLE VICTOR SCHOELCHER;PLE VICTOR SCHOELCHER;6;Non;0;En service;2009-08-14 12:59:03;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H5;44109#0H5;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354908.3 6688820.5 7.6, 354907.9 6688811.8 7.2)
TRONROUT0000002245069380;Route à 1 chaussée;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2021-08-25 15:33:16;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354908.3 6688820.5 7.4, 354915.8 6688817.1 7.5, 354923.4 6688814.2 7.3)
TRONROUT0000002245069381;Rond-point;;;3;Non;0;En service;2021-08-25 15:33:16;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354925.5 6688824.8 7.3, 354924.3 6688823.3 7.3, 354923.4 6688821.6 7.3, 354922.8 6688819.8 7.3, 354922.8 6688816 7.3, 354923.4 6688814.2 7.3)
TRONROUT0000000029475300;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354941.5 6688821.1 7.7, 354940.5 6688823.3 7.7, 354937.8 6688826 7.5, 354936.1 6688826.9 7, 354932.4 6688827.7 7)
TRONROUT0000000295265048;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354908.3 6688820.5 7.4, 354912.3 6688829.4 7.3)
TRONROUT0000000029474813;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355122.9 6688770.8 6.8, 355119.9 6688770.5 7.2, 355117.5 6688769.9 7.2, 355114.7 6688768.1 7.2, 355112.9 6688766.3 7.2, 355111.9 6688764.2 7.2, 355111.4 6688762.5 7.2, 355111.7 6688760.9 7)
TRONROUT0000000029474704;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355130.4 6688764.4 7.3, 355129.2 6688767.2 7.8, 355128.8 6688767.9 7.8, 355127.9 6688768.7 7.8, 355126.8 6688769.4 7.8, 355126.5 6688769.9 7.8, 355122.9 6688770.8 6.8)
TRONROUT0000000029473968;Route à 1 chaussée;R DEURBROUCQ;R DEURBROUCQ;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;10;;2;;44109;44109;;;;441092448;441092448;;;;;;;;;;;;;commune;commune;Rue Deurbroucq;Rue Deurbroucq;;;44109_2448;44109_2448;;;;;LINESTRING Z (355082 6688864 7, 355122.6 6688780.8 6.9, 355122.9 6688770.8 6.8)
TRONROUT0000000029475259;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2008-11-15 06:12:08;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355073.4 6688881.8 7.2, 355082 6688864 7)
TRONROUT0000000029473951;Route à 1 chaussée;R ALBERT DE MUN;R ALBERT DE MUN;5;Non;0;En service;2006-10-04 09:41:10;2013-04-16 17:06:42;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090076;441090076;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355077.8 6688893 7.6, 355073.4 6688881.8 7.2)
TRONROUT0000000287826387;Route à 1 chaussée;ALL DE L'ILE GLORIETTE;ALL DE L'ILE GLORIETTE;5;Non;0;En service;2011-08-25 15:33:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094272;441094272;;;;;;;;;;;;;commune;commune;Allée de l'Ile Gloriette;Allée de l'Ile Gloriette;;;44109_4272;44109_4272;;;;;LINESTRING Z (355082 6688864 7, 355090.8 6688868.6 6.9, 355154.3 6688901 6.6, 355166.5 6688907.3 6.6, 355178.1 6688916.3 6.5, 355195.4 6688921.7 6.7)
TRONROUT0000000029474234;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355074.4 6688893.8 7.6, 355076.2 6688893.3 7.6, 355077.8 6688893 7.6)
TRONROUT0000000029474508;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355069.6 6688900.2 7.4, 355070.7 6688896.6 7.4, 355072.8 6688894.8 7.6, 355074.4 6688893.8 7.6)
TRONROUT0000000029473507;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355077.8 6688893 7.6, 355079.6 6688892.9 7.5, 355081.1 6688893.2 7.5, 355082.9 6688894 7.5, 355084.1 6688894.9 7.5, 355085.1 6688896.3 7.5, 355085.8 6688897.7 7.5, 355086.3 6688899.5 7.5, 355085.9 6688903.9 7.6)
TRONROUT0000000029474818;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355076.1 6688907.3 6.9, 355074.2 6688906.3 6.9, 355071.5 6688904.6 7, 355070.4 6688903.2 7.1, 355069.7 6688902.1 7.1, 355069.5 6688901.4 7.3, 355069.6 6688900.2 7.4)
TRONROUT0000000029475078;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354932.4 6688827.7 7, 354929.6 6688827.1 7, 354927 6688826 7, 354925.5 6688824.8 7.3)
TRONROUT0000000295264811;Route à 2 chaussées;R GASTON MICHEL;R GASTON MICHEL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A1;44109#0A1;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Michel;Rue Gaston Michel;;;44109_3512;44109_3512;;;;;LINESTRING Z (354925.5 6688824.8 7.3, 354912.3 6688829.4 7.3)
TRONROUT0000000029473814;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (354941.5 6688821.1 7.5, 354953.9 6688830.4 7.5, 354982.8 6688844.8 7.5, 355040.7 6688874.4 8.6)
TRONROUT0000000029474431;Route à 1 chaussée;R ALBERT DE MUN;R ALBERT DE MUN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;9;;9;;44109;44109;;;;441090076;441090076;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355082 6688864 7, 354999.5 6688825 7.2, 354994.4 6688824.4 7.2, 354991.6 6688824.9 7.2, 354989.3 6688826.7 7.2, 354986.5 6688832.8 7.3, 354987.2 6688834.7 6.2, 354989.7 6688837.8 6.2, 354997.7 6688843.7 6.3, 355021.6 6688856.2 6.6, 355073.4 6688881.8 7.2)
TRONROUT0000000029473749;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355031.7 6688879.4 7.4, 354977.2 6688851.1 7.5, 354943.1 6688833.6 7.1, 354932.4 6688827.7 7)
TRONROUT0000000295265039;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:24:36;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354912.3 6688829.4 7.3, 354958.2 6688922.2 7.3)
TRONROUT0000000029474213;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355031.7 6688879.4 7.4, 355033 6688877.9 7.4, 355034.9 6688876 7.4, 355036.7 6688874.6 8.6, 355038.8 6688874.2 8.6, 355040.7 6688874.4 8.6)
TRONROUT0000000029473866;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355040.7 6688874.4 8.6, 355043.2 6688875 8.6, 355046.1 6688876.5 8.6, 355047.9 6688879.3 8.6)
TRONROUT0000000029474118;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355047.9 6688879.3 8.6, 355047.6 6688882.9 8.6, 355046.4 6688884.6 8.6)
TRONROUT0000000029473584;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355046.4 6688884.6 8, 355044.5 6688886.4 8, 355042.9 6688887.5 8, 355041.9 6688888.1 8, 355040.3 6688888.2 8, 355038.5 6688888.2 7.8, 355036.4 6688887.5 7.7, 355035.7 6688887.2 7.7, 355033.3 6688885.3 7.4, 355032.7 6688883.9 7.4, 355031.7 6688879.4 8.6)
TRONROUT0000000287826384;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2011-08-25 15:33:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;11;;13;;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355258.3 6688809.2 6.4, 355250.7 6688750.9 6.7)
TRONROUT0000000054044881;Route à 1 chaussée;R PROFESSEUR YVES BOQUIEN;R PROFESSEUR YVES BOQUIEN;5;Non;0;En service;2007-01-26 07:37:34;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441091050;441091050;;;;;;;;;;;;;commune;commune;Rue Professeur Yves Boquien;Rue Professeur Yves Boquien;;;44109_1050;44109_1050;;;;;LINESTRING Z (355185.8 6688762.6 6.7, 355187.5 6688778.8 6.7, 355190.1 6688802.3 6.7, 355192.8 6688829.7 6.7)
TRONROUT0000002002203254;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2017-03-08 17:36:06;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355261.9 6688836.4 6.4, 355258.3 6688809.2 6.4)
TRONROUT0000002002203252;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2017-03-08 17:36:06;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355240.1 6688832.3 6.3, 355192.8 6688829.7 6.7)
TRONROUT0000000029474105;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;9;;9;;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355261.9 6688836.4 6.4, 355240.1 6688832.3 6.3)
TRONROUT0000000287826385;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2011-08-25 15:33:41;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;5;2;7;8;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355290.5 6688842.2 6.4, 355261.9 6688836.4 6.4)
TRONROUT0000000287826386;Route à 1 chaussée;PAS JEAN-PIERRE KERNEIS;PAS JEAN-PIERRE KERNEIS;5;Non;0;En service;2011-08-25 15:33:41;2017-07-28 17:55:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QP;44109#0QP;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355240.1 6688832.3 6.3, 355228.4 6688858.4 6.3, 355220.8 6688877 6.4, 355209.6 6688894.4 6.5, 355201.3 6688907.1 6.6, 355195.4 6688921.7 6.7)
TRONROUT0000000029474169;Route à 1 chaussée;ALL DE L'ILE GLORIETTE;ALL DE L'ILE GLORIETTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094272;441094272;;;;;;;;;;;;;commune;commune;Allée de l'Ile Gloriette;Allée de l'Ile Gloriette;;;44109_4272;44109_4272;;;;;LINESTRING Z (355195.4 6688921.7 6.7, 355206.9 6688925.3 6.9, 355223.5 6688931.8 7.2, 355230.4 6688934.5 7.3, 355262.2 6688943.9 7.3, 355293.1 6688950.2 7.6, 355314.8 6688953.1 8.1)
TRONROUT0000000029475007;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355203.9 6688968.7 7.5, 355224.6 6688971.9 7.5, 355239.7 6688975.4 7.5, 355254.2 6688981.1 7.5, 355263.7 6688985.3 7.5, 355270.5 6688987.2 7.6, 355274.1 6688988 7.5)
TRONROUT0000000029475005;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355271.1 6688997.7 7.5, 355264 6688993.6 7.5, 355251.9 6688987.2 7.5, 355234 6688979.2 7.5, 355217.6 6688972.6 7.5, 355203.9 6688968.7 7.5)
TRONROUT0000000029473573;Rond-point;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355085.9 6688903.9 7.6, 355085.6 6688903.7 7.6, 355082.5 6688906.8 7.7, 355078.4 6688907.4 6.9, 355076.1 6688907.3 6.9)
TRONROUT0000000029473756;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355085.9 6688903.9 7.6, 355094.6 6688914.4 7.7, 355113 6688937.1 8.5, 355131.6 6688956.7 9.4)
TRONROUT0000000029474223;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355117 6688964.5 9, 355107.5 6688947.6 8.2, 355098.3 6688932.3 7.7, 355088.2 6688919.3 7.7, 355076.1 6688907.3 6.9)
TRONROUT0000000029474888;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355131.6 6688956.7 9.4, 355136.5 6688958.8 9.5)
TRONROUT0000000029474883;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355117 6688964.5 9, 355119.2 6688961.1 9, 355123.3 6688958 9.2, 355131.6 6688956.7 9.4)
TRONROUT0000000029473972;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355136.5 6688958.8 9.5, 355148.9 6688961.2 8.3, 355161.1 6688965 8.2)
TRONROUT0000000029474900;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355136.5 6688958.8 9.5, 355140.5 6688962.2 9.6, 355142.2 6688966.6 9.6, 355142.1 6688971.1 9.6, 355141.5 6688972.5 9.6)
TRONROUT0000000029474495;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355203.9 6688968.7 7.5, 355190 6688966 7.5, 355175.6 6688964.8 7.7, 355161.1 6688965 8.2)
TRONROUT0000000029474442;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355161.1 6688965 8.2, 355150.7 6688967.3 8, 355144.4 6688970.3 8.2, 355141.5 6688972.5 9.6)
TRONROUT0000000029474901;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355118.2 6688973 9, 355117.3 6688969.9 9, 355116.9 6688966.8 8.9, 355117 6688964.5 9)
TRONROUT0000000029474275;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355047.9 6688879.3 8.6, 355052.9 6688881 8.3, 355067.2 6688889.5 7.4, 355074.4 6688893.8 7.6)
TRONROUT0000000029474402;Route à 2 chaussées;BD DES NATIONS UNIES;BD DES NATIONS UNIES;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Calculé;20.0;Z corrigé;2.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#011;44109#011;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355069.6 6688900.2 7.3, 355064.3 6688896.2 7.4, 355050.5 6688887.1 7.9, 355046.4 6688884.6 8)
TRONROUT0000000329622508;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354952.3 6688946.8 -1000, 354958.2 6688922.2 -1000)
TRONROUT0000000029474480;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;23;;23;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354952.3 6688946.8 7.2, 354943.7 6688942.3 7.2, 354937.5 6688934.9 7.2, 354934.9 6688932.9 7)
TRONROUT0000000329622509;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2013-11-15 09:02:56;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;20;;22;44109;44109;;;;441093235;441093235;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (354977.1 6688960.1 7.2, 354952.3 6688946.8 7.2)
TRONROUT0000000029473636;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;14;;19;44109;44109;;;;441093235;441093235;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (355016.5 6688975.7 6.9, 355007.4 6688974 7.3, 355003.3 6688972.6 7.2, 354977.1 6688960.1 7.2)
TRONROUT0000000029473466;Route à 1 chaussée;R FOURCROY;R FOURCROY;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;2.8;;;;;Non;;5;;3;44109;44109;;;;441093248;441093248;;;;;;;;;;;;;commune;commune;Rue Fourcroy;Rue Fourcroy;;;44109_3248;44109_3248;;;;;LINESTRING Z (354977.1 6688960.1 7.2, 354968.5 6688977 7)
TRONROUT0000000029473977;Route à 1 chaussée;R FOURCROY;R FOURCROY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.8;;;;;Non;7;2;7;2;44109;44109;;;;441093248;441093248;;;;;;;;;;;;;commune;commune;Rue Fourcroy;Rue Fourcroy;;;44109_3248;44109_3248;;;;;LINESTRING Z (354968.5 6688977 7, 354959.2 6688995 8.9)
TRONROUT0000000029474271;Route à 1 chaussée;QU DE LA FOSSE;QU DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;8;;13;44109;44109;;;;441093235;441093235;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (355071.8 6689004.5 7.2, 355048.4 6688989.5 7.3, 355023.3 6688977.1 7, 355016.5 6688975.7 6.9)
TRONROUT0000000029475311;Sentier;R LEVEQUE;R LEVEQUE;6;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CM;44109#0CM;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355016.5 6688975.7 6.9, 355004.7 6688995.4 6.8, 354994.8 6689007.6 9.7)
TRONROUT0000000029474635;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355274.1 6688988 7.5, 355281.5 6688987.5 7.5)
TRONROUT0000000295264874;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355281.5 6688987.5 7.5, 355283.2 6688987.6 7.6, 355287.7 6688991 7.5, 355289.6 6688994.2 7.7)
TRONROUT0000000029475172;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355271.1 6688997.7 7.5, 355271.1 6688995.1 7.5, 355271.4 6688992.5 7.5, 355272.5 6688989.9 7.5, 355274.1 6688988 7.5)
TRONROUT0000000295264875;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355205.7 6688995.4 6.9, 355211.1 6688993.7 6.9, 355216.1 6688993 7, 355224 6688993.7 7.1, 355230.6 6688995.5 7.1, 355234.9 6688997.5 7.1)
TRONROUT0000000029475136;Escalier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355232.5 6689002.8 5.8, 355234.9 6688997.5 7.1)
TRONROUT0000000295264908;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355289.6 6688994.2 7.7, 355290.5 6688995.7 7.8, 355289 6689001.4 7.8, 355288 6689002.5 7.8, 355287.2 6689003.7 7.8, 355285.7 6689004.6 7.8, 355282.2 6689006.7 7.7)
TRONROUT0000000029475101;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355273.4 6689003.5 7.5, 355271.9 6689000.8 7.5, 355271.1 6688997.7 7.5)
TRONROUT0000000295264873;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355234.9 6688997.5 7.1, 355263.8 6689008.3 5.1)
TRONROUT0000000295264933;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355213.8 6689013.4 5, 355205.7 6688995.4 6.9)
TRONROUT0000000029475305;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355282.2 6689006.7 7.7, 355278 6689006.4 7.7, 355275.3 6689005.4 7.7, 355273.4 6689003.5 7.5)
TRONROUT0000000029474882;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355141.5 6688972.5 9.6, 355139.5 6688976 9.7, 355135 6688979.3 9.2, 355132.6 6688980.2 9.8)
TRONROUT0000000029474897;Rond-point;R FELIX EBOUE;R FELIX EBOUE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355132.6 6688980.2 9.8, 355123.8 6688978.9 9.6, 355119.5 6688975 9.1, 355118.2 6688973 9)
TRONROUT0000000029474889;Route à 1 chaussée;R FELIX EBOUE;R FELIX EBOUE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HB;44109#0HB;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355071.8 6689004.5 7.2, 355079 6688998.6 7.1, 355084.1 6688995.3 7.1, 355101.2 6688984.3 7.3, 355118.2 6688973 7.5)
TRONROUT0000000029474867;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;8.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;Sens inverse;Sens direct;Bande cyclable;Bande cyclable;LINESTRING Z (355132.6 6688980.2 8.5, 355133.7 6688986.2 8.4, 355134.2 6688988.4 6.7, 355135 6688991.5 8.8, 355136.2 6688997 8.2, 355137.8 6689002.2 8.1, 355138.8 6689008.3 8, 355139.6 6689015.6 7.9, 355138.3 6689022.1 7.8, 355136.7 6689025.5 7.4)
TRONROUT0000000029474444;Sentier;QU DE LA FOSSE;QU DE LA FOSSE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;5;;5;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (355071.8 6689004.5 7.2, 355079.5 6689012.1 7.1)
TRONROUT0000000029474774;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355071.8 6689004.5 7.2, 355084.2 6689012.3 7.1, 355091.8 6689016.7 7.2, 355105.3 6689027 6.5, 355119.2 6689037.6 7.3)
TRONROUT0000000295265258;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-09 18:24:36;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355136.7 6689025.5 6.7, 355147.5 6689021.1 5.7, 355153.3 6689019.6 5, 355160.2 6689017.7 5.1, 355167.4 6689017.9 5.1, 355168.7 6689019 5.1, 355174 6689023.9 5.1, 355176.9 6689027.6 5.1, 355181.5 6689029.4 5.1, 355187.6 6689029.1 7.1)
TRONROUT0000000029473471;Sentier;RLE DE DESSOUS LE CHENE;RLE DE DESSOUS LE CHENE;6;Non;0;En service;2006-10-04 09:41:10;2012-09-27 15:32:48;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0AA;44109#0AA;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355056.4 6689037.1 -1000, 355079.5 6689012.1 -1000)
TRONROUT0000000029473569;Sentier;QU DE LA FOSSE;QU DE LA FOSSE;6;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;4;;1;;44109;44109;;;;441093235;441093235;;;;;;;;;;;;;commune;commune;Quai de la Fosse;Quai de la Fosse;;;44109_3235;44109_3235;;;;;LINESTRING Z (355079.5 6689012.1 7.1, 355093 6689028.3 6.9, 355098.2 6689039.2 7.1, 355099.7 6689044.8 7.1, 355100.8 6689049.1 7.2)
TRONROUT0000000029474755;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094472;441094472;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355136.7 6689025.5 7.4, 355119.2 6689037.6 7.3)
TRONROUT0000000227876292;Sentier;;;6;Non;0;En service;2010-01-08 14:34:21;2013-01-10 10:47:38;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355263.8 6689008.3 5.1, 355273.4 6689003.5 6.9)
TRONROUT0000000295265269;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355232.5 6689002.8 5.8, 355224.3 6689015.1 5.1)
TRONROUT0000000029475270;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355187.6 6689029.1 7.1, 355187.2 6689022.6 7, 355187.6 6689017.6 7, 355189 6689012.6 7, 355191.9 6689007 6.9, 355195.2 6689002.8 6.9, 355199.7 6688999 6.9, 355205.7 6688995.4 6.9)
TRONROUT0000000295265094;Route à 1 chaussée;PL DE LA PETITE HOLLANDE;PL DE LA PETITE HOLLANDE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096464;441096464;;;;;;;;;;;;;commune;commune;Place de la Petite Hollande;Place de la Petite Hollande;;;44109_6464;44109_6464;;;;;LINESTRING Z (355274.3 6689021.5 6.9, 355274.5 6689016.6 7.6, 355274.6 6689012.3 7.8, 355274.3 6689007.9 7.8, 355273.4 6689003.5 7.5)
TRONROUT0000000295265265;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355213.8 6689013.4 5.1, 355215 6689013 5.1, 355219.4 6689013.1 5.1, 355223.2 6689014.4 5.1, 355224.3 6689015.1 5.1)
TRONROUT0000000295265075;Route à 1 chaussée;PL DE LA PETITE HOLLANDE;PL DE LA PETITE HOLLANDE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096464;441096464;;;;;;;;;;;;;commune;commune;Place de la Petite Hollande;Place de la Petite Hollande;;;44109_6464;44109_6464;;;;;LINESTRING Z (355282.2 6689006.7 7.7, 355279.9 6689013.1 7.7, 355278.1 6689017.3 7.3, 355274.3 6689021.5 6.9)
TRONROUT0000000295265264;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355207 6689025.9 5.1, 355206.5 6689024 5.1, 355207.4 6689019.9 5.1, 355208.5 6689017.5 5.1, 355211.3 6689014.4 5.1, 355213.8 6689013.4 5.1)
TRONROUT0000000295265266;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355239.7 6689031.7 5, 355250.1 6689014.5 5.1, 355263.8 6689008.3 5.1)
TRONROUT0000000295265257;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355224.3 6689015.1 5.1, 355225.4 6689016 5.1, 355226 6689016.7 5.1, 355227.3 6689019.3 5.1, 355228 6689022.8 5.1, 355227.8 6689024.4 5.1, 355227.5 6689026 5.1)
TRONROUT0000000295265107;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355227.5 6689026 5.1, 355227.1 6689028 5.1, 355225.5 6689030.7 5.1, 355224.5 6689031.4 5.1)
TRONROUT0000000295265104;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355227.5 6689026 5, 355239.7 6689031.7 5.1)
TRONROUT0000000295264952;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355207 6689025.9 5, 355188.7 6689032.6 7.1)
TRONROUT0000000295265268;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355214.8 6689033.9 5, 355212.2 6689032.9 5.1, 355209.1 6689030.2 5.1, 355207.5 6689027.5 5.1, 355207 6689025.9 5.1)
TRONROUT0000000295264877;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355188.7 6689032.6 7.1, 355187.6 6689029.1 7.1)
TRONROUT0000000295265050;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355224.5 6689031.4 5.1, 355222.6 6689032.8 5.1, 355219.1 6689034 5.1, 355214.8 6689033.9 5)
TRONROUT0000000227876294;Route à 1 chaussée;PL DE LA PETITE HOLLANDE;PL DE LA PETITE HOLLANDE;5;Non;0;En service;2010-01-08 14:34:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;Sens inverse;Non;35;Libre;;;;;;;;;Non;3;;3;;44109;44109;;;;441096464;441096464;;;;;;;;;;;;;commune;commune;Place de la Petite Hollande;Place de la Petite Hollande;;;44109_6464;44109_6464;;;;;LINESTRING Z (355259.2 6689045 6.9, 355265.8 6689034.8 6.9, 355272.5 6689024.3 6.9, 355274.3 6689021.5 6.9)
TRONROUT0000000295264947;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355224.5 6689031.4 5, 355237.2 6689036.7 5.1)
TRONROUT0000000295264984;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355237.2 6689036.7 5, 355239.7 6689031.7 5.1)
TRONROUT0000000295265037;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355209.1 6689046.9 5.5, 355214.8 6689033.9 5.1)
TRONROUT0000000329622510;Escalier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355237.2 6689036.7 -1000, 355259.2 6689045 -1000)
TRONROUT0000000029475197;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354994.8 6689007.6 9.7, 354992.8 6689010.1 10.3, 354973.5 6689002 10.2, 354959.2 6688995 8.9)
TRONROUT0000000029474052;Route à 1 chaussée;R FOURCROY;R FOURCROY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.8;;;;;Non;9;4;17;4;44109;44109;;;;441093248;441093248;;;;;;;;;;;;;commune;commune;Rue Fourcroy;Rue Fourcroy;;;44109_3248;44109_3248;;;;;LINESTRING Z (354959.2 6688995 8.9, 354930.3 6689044.2 13.7, 354918.4 6689058.6 15.5)
TRONROUT0000000029474204;Route à 1 chaussée;R MARECHAL DE LATTRE DE TASSIGNY;R MARECHAL DE LATTRE DE TASSIGNY;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 20:52:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;11B;;1;44109;44109;;;;441095356;441095356;;;;;;;;;;;;;commune;commune;Rue Maréchal de Lattre de Tassigny;Rue Maréchal de Lattre de Tassigny;;;44109_5356;44109_5356;;;;;LINESTRING Z (354932.6 6689070.8 16, 354938.9 6689063 15.9, 354946.3 6689054.9 15.5, 354957.1 6689045.4 13.5, 354965.7 6689039.7 13.3, 354973.7 6689035.4 12.8, 354987.4 6689030.1 11.9, 355041.1 6689015.6 8.2, 355049.7 6689012.6 7.4, 355061.3 6689008.8 7.2, 355071.8 6689004.5 7.2)
TRONROUT0000000029474424;Route à 1 chaussée;R DE BLOIS;R DE BLOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;4;44109;44109;;;;44109#0BY;44109#0BY;;;;;;;;;;;;;commune;commune;Rue de Blois;Rue de Blois;;;44109_0896;44109_0896;;;;;LINESTRING Z (355054.8 6689041.1 6.3, 355069.6 6689068.7 9.1)
TRONROUT0000000029473572;Route à 1 chaussée;R DU CHENE D'ARON;R DU CHENE D'ARON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;4;44109;44109;;;;441091840;441091840;;;;;;;;;;;;;commune;commune;Rue du Chêne d'Aron;Rue du Chêne d'Aron;;;44109_1840;44109_1840;;;;;LINESTRING Z (355051.1 6689080.3 11.7, 355036.7 6689056.6 11.4, 355036.6 6689055 11.4, 355036.7 6689053.1 11.4, 355037.6 6689051.2 11.4, 355050.1 6689045.4 10.7, 355054.8 6689041.1 6.3)
TRONROUT0000000029473598;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;7;6;7;44109;44109;;;;441094180;441094180;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354918.4 6689058.6 15.5, 354932.6 6689070.8 16)
TRONROUT0000000029474256;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;3;4;3;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355069.6 6689068.7 9.1, 355051.1 6689080.3 11.7)
TRONROUT0000000029473554;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;4;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354948 6689096.1 16.3, 354932.6 6689070.8 16)
TRONROUT0000000029473533;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;5;6;5;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355051.1 6689080.3 11.7, 355036.4 6689089.6 11.8)
TRONROUT0000000029474415;Route à 1 chaussée;R PIRON;R PIRON;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;3;2;44109;44109;;;;441096664;441096664;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Piron;Rue Piron;;;44109_6664;44109_6664;;;;;LINESTRING Z (354894 6689116.7 18.9, 354932.6 6689070.8 16)
TRONROUT0000000295264878;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355206.6 6689052.5 6.8, 355201.6 6689049.6 7.3, 355194 6689043.2 7.2, 355189.2 6689034.5 7.2, 355188.7 6689032.6 7.1)
TRONROUT0000000295264747;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355237.2 6689036.7 5, 355226.6 6689054.9 5.1)
TRONROUT0000000029475179;Escalier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355209.1 6689046.9 5.5, 355206.6 6689052.5 6.8)
TRONROUT0000000029474215;Route à 1 chaussée;PL DE LA PETITE HOLLANDE;PL DE LA PETITE HOLLANDE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;Sens inverse;Non;35;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441096464;441096464;;;;;;;;;;;;;commune;commune;Place de la Petite Hollande;Place de la Petite Hollande;;;44109_6464;44109_6464;;;;;LINESTRING Z (355241.3 6689078.8 6.8, 355255.6 6689051.8 6.6, 355259.2 6689045 6.9)
TRONROUT0000000029474944;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2013-04-03 17:23:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355235.7 6689089.6 7.2, 355227.6 6689079.8 7, 355205.9 6689065.2 7, 355181.8 6689045.8 7, 355175.2 6689040.5 6.9)
TRONROUT0000000227876291;Sentier;;;6;Non;0;En service;2010-01-08 14:34:21;2012-02-13 08:57:14;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355206.6 6689052.5 6.8, 355241.3 6689078.8 6.8)
TRONROUT0000000227876293;Route à 1 chaussée;PL DE LA PETITE HOLLANDE;PL DE LA PETITE HOLLANDE;5;Non;0;En service;2010-01-08 14:34:21;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;Sens inverse;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096464;441096464;;;;;;;;;;;;;commune;commune;Place de la Petite Hollande;Place de la Petite Hollande;;;44109_6464;44109_6464;;;;;LINESTRING Z (355235.7 6689089.6 7.2, 355241.3 6689078.8 6.8)
TRONROUT0000000029474713;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2013-04-03 17:23:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355220 6689107.3 7, 355235.7 6689089.6 7.2)
TRONROUT0000000029473758;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;Sens inverse;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355235.7 6689089.6 7.2, 355236.5 6689093.6 7.1, 355231 6689115.1 7)
TRONROUT0000000029474730;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2013-04-03 17:23:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;Sens direct;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355231 6689115.1 6.9, 355220 6689107.3 7)
TRONROUT0000000029475204;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355175.2 6689040.5 6.9, 355165.2 6689031.9 6.9, 355160.3 6689028.4 6.9, 355148 6689028.8 6.9, 355136.7 6689025.5 6.9)
TRONROUT0000000029474927;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355119.2 6689037.6 7.3, 355100.8 6689049.1 7.2)
TRONROUT0000000029474198;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;1;2;1;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355100.8 6689049.1 7.2, 355069.6 6689068.7 9.1)
TRONROUT0000000029474915;Route à 1 chaussée;ALL DE LA BOURSE;ALL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0D8;44109#0D8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355175.4 6689089.3 6.8, 355160.3 6689074.2 6.9, 355155.4 6689070 6.9, 355127.4 6689045.8 8.7, 355119.2 6689037.6 7.3)
TRONROUT0000000029474868;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-09 18:24:36;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355220 6689107.3 7, 355213.6 6689102 7.9, 355210.4 6689099.9 7.8, 355207.3 6689096.9 7.9, 355203.8 6689093.5 7.9, 355199.9 6689089.6 7.9, 355195.9 6689085.9 8.4, 355192.2 6689082.2 8.4, 355188.5 6689078.3 8.2, 355184.5 6689074.2 8.1, 355180.5 6689070 8.3, 355176.6 6689066 8.1, 355173 6689062.4 8, 355169.6 6689058.9 8.1, 355166.3 6689055.6 8, 355162.2 6689049.7 10, 355157.5 6689044.4 9.2, 355154.6 6689042 9.1, 355152.1 6689040.1 9, 355149.5 6689038.3 8.6, 355145.8 6689034.9 8.2, 355142.3 6689031.8 8.8, 355136.7 6689025.5 7.4)
TRONROUT0000000029474034;Route à 1 chaussée;PL DE LA BOURSE;PL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;8;;12;44109;44109;;;;441091168;441091168;;;;;;;;;;;;;commune;commune;Place de la Bourse;Place de la Bourse;;;44109_1168;44109_1168;;;;;LINESTRING Z (355100.8 6689049.1 7.2, 355103.7 6689056.5 7, 355118.1 6689093.2 6.4)
TRONROUT0000000029475165;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2008-11-15 06:12:08;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355175.4 6689089.3 6.8, 355182.8 6689103.7 7.2)
TRONROUT0000000029475222;Route à 1 chaussée;PL DE LA BOURSE;PL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091168;441091168;;;;;;;;;;;;;commune;commune;Place de la Bourse;Place de la Bourse;;;44109_1168;44109_1168;;;;;LINESTRING Z (355118.1 6689093.2 6.4, 355133.3 6689112.2 6.8, 355148.6 6689130 6.5)
TRONROUT0000000029473939;Route à 1 chaussée;PL DE LA BOURSE;PL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;;2;;44109;44109;;;;441091168;441091168;;;;;;;;;;;;;commune;commune;Place de la Bourse;Place de la Bourse;;;44109_1168;44109_1168;;;;;LINESTRING Z (355118.1 6689093.2 6.4, 355129.2 6689138.3 6.7)
TRONROUT0000000029475257;Route à 1 chaussée;PL DE LA BOURSE;PL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441091168;441091168;;;;;;;;;;;;;commune;commune;Place de la Bourse;Place de la Bourse;;;44109_1168;44109_1168;;;;;LINESTRING Z (355129.2 6689138.3 6.7, 355138.6 6689135.2 6.7, 355145.4 6689132 6.7, 355148.6 6689130 6.5)
TRONROUT0000000029478137;Route à 1 chaussée;R MATHURIN BRISSONNEAU;R MATHURIN BRISSONNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;11;;17;;44109;44109;;;;441095492;441095492;;;;;;;;;;;;;commune;commune;Rue Mathurin Brissonneau;Rue Mathurin Brissonneau;;;44109_5492;44109_5492;;;;;LINESTRING Z (354167.5 6688792.6 6.8, 354174.9 6688786.6 6.8, 354224.7 6688758 6.5)
TRONROUT0000000029478078;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;5;;7;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354249.7 6688811.5 6.6, 354252 6688795.9 6.5, 354258.3 6688760.4 6.5, 354261.4 6688741.9 6.1)
TRONROUT0000000029478515;Route à 1 chaussée;R DE LA BRASSERIE;R DE LA BRASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;6;1B;12;44109;44109;;;;441091200;441091200;;;;;;;;;;;;;commune;commune;Rue de la Brasserie;Rue de la Brasserie;;;44109_1200;44109_1200;;;;;LINESTRING Z (354167.5 6688792.6 6.8, 354152.6 6688786.3 11.2)
TRONROUT0000000029478182;Route à 1 chaussée;R LAVOISIER;R LAVOISIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094844;441094844;;;;;;;;;;;;;commune;commune;Rue Lavoisier;Rue Lavoisier;;;44109_4844;44109_4844;;;;;LINESTRING Z (354152.6 6688786.3 11.2, 354151.6 6688787.2 10.3, 354139.9 6688795.2 6.8)
TRONROUT0000000029478030;Route à 1 chaussée;R CHARLES BRUNELLIERE;R CHARLES BRUNELLIERE;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;7;10;13;14;44109;44109;;;;441091688;441091688;;;;;;;;;;;;;commune;commune;Rue Charles Brunellière;Rue Charles Brunellière;;;44109_1688;44109_1688;;;;;LINESTRING Z (354336.7 6688778.8 7.1, 354274.4 6688812.2 6.7, 354261.4 6688819.9 6.7)
TRONROUT0000000029478065;Route à 1 chaussée;R DE LA BRASSERIE;R DE LA BRASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2;;6;44109;44109;;;;441091200;441091200;;;;;;;;;;;;;commune;commune;Rue de la Brasserie;Rue de la Brasserie;;;44109_1200;44109_1200;;;;;LINESTRING Z (354235.5 6688818.5 6.6, 354167.5 6688792.6 6.8)
TRONROUT0000000029478159;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354235.5 6688818.5 6.6, 354240.1 6688814 6.6, 354242.7 6688812.6 6.7, 354249.7 6688811.5 6.7)
TRONROUT0000000029478152;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354249.7 6688811.5 6.6, 354253.9 6688812.6 6.6, 354258.7 6688815.8 6.6, 354261.4 6688819.9 6.7)
TRONROUT0000000029478234;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354234.7 6688831.8 6.5, 354233.6 6688826.2 6.5, 354233.9 6688823.4 6.5, 354235.5 6688818.5 6.6)
TRONROUT0000000029478575;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354261.4 6688819.9 6.7, 354251.8 6688824 6.7, 354234.7 6688831.8 6.5)
TRONROUT0000000329622523;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2023-06-15 17:14:22;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354459.4 6688738.2 -1000, 354448.1 6688776.6 -1000)
TRONROUT0000000029477999;Route à 1 chaussée;R BATONNIER GUINAUDEAU;R BATONNIER GUINAUDEAU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;15;;15;;44109;44109;;;;441090624;441090624;;;;;;;;;;;;;commune;commune;Rue Bâtonnier Guinaudeau;Rue Bâtonnier Guinaudeau;;;44109_0624;44109_0624;;;;;LINESTRING Z (354496.4 6688783.4 7.9, 354495.1 6688779.3 7.9, 354495.3 6688775.6 7.8, 354503.1 6688754.8 8.4)
TRONROUT0000000029478264;Sentier;PL COMMANDANT JEAN L'HERMINIER;PL COMMANDANT JEAN L'HERMINIER;6;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;4;;4;;44109;44109;;;;441092066;441092066;;;;;;;;;;;;;commune;commune;Place Commandant Jean l'Herminier;Place Commandant Jean l'Herminier;;;44109_2066;44109_2066;;;;;LINESTRING Z (354416.2 6688766 8.1, 354448.1 6688776.6 7.4)
TRONROUT0000000029478393;Route à 1 chaussée;PL COMMANDANT JEAN L'HERMINIER;PL COMMANDANT JEAN L'HERMINIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;4.2;;;;;Non;;3;;3;44109;44109;;;;441092066;441092066;;;;;;;;;;;;;commune;commune;Place Commandant Jean l'Herminier;Place Commandant Jean l'Herminier;;;44109_2066;44109_2066;;;;;LINESTRING Z (354448.1 6688776.6 7.4, 354478.4 6688787.5 6.8)
TRONROUT0000000029478265;Route à 1 chaussée;PL COMMANDANT JEAN L'HERMINIER;PL COMMANDANT JEAN L'HERMINIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441092066;441092066;;;;;;;;;;;;;commune;commune;Place Commandant Jean l'Herminier;Place Commandant Jean l'Herminier;;;44109_2066;44109_2066;;;;;LINESTRING Z (354478.4 6688787.5 6.8, 354482.7 6688789 6.6, 354484.1 6688789 6.6, 354485.3 6688788.6 6.7, 354496.4 6688783.4 7.9)
TRONROUT0000000029478378;Route à 1 chaussée;R FERREOL BOLO;R FERREOL BOLO;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;4.0;;;;;Non;3;2;5;2;44109;44109;;;;441093128;441093128;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Ferréol Bolo;Rue Ferréol Bolo;;;44109_3128;44109_3128;;;;;LINESTRING Z (354439.5 6688802.9 9, 354448.1 6688776.6 7.4)
TRONROUT0000000029478373;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:14:22;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354467.9 6688813.1 9.8, 354478.4 6688787.5 6.8)
TRONROUT0000000029478401;Route à 1 chaussée;R DE MAZAGRAN;R DE MAZAGRAN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;10;7;2;1;44109;44109;;;;441095560;441095560;;;;;;;;;;;;;commune;commune;Rue de Mazagran;Rue de Mazagran;;;44109_5560;44109_5560;;;;;LINESTRING Z (354390.8 6688837.2 10.4, 354416.2 6688766 8.1)
TRONROUT0000000029478702;Route à 1 chaussée;IMP DU SANITAT;IMP DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097810;441097810;;;;;;;;;;;;;commune;commune;Impasse du Sanitat;Impasse du Sanitat;;;44109_7810;44109_7810;;;;;LINESTRING Z (354439.5 6688802.9 9, 354467.9 6688813.1 9.7)
TRONROUT0000000029478700;Route à 1 chaussée;IMP DU SANITAT;IMP DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441097810;441097810;;;;;;;;;;;;;commune;commune;Impasse du Sanitat;Impasse du Sanitat;;;44109_7810;44109_7810;;;;;LINESTRING Z (354467.9 6688813.1 9.7, 354495.6 6688823.8 10.5)
TRONROUT0000000029478220;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354261.4 6688819.9 6.7, 354262.7 6688823.4 6.7, 354262.7 6688829 6.8, 354261.5 6688833 7)
TRONROUT0000000029478054;Route à 1 chaussée;R LAVOISIER;R LAVOISIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;3;4;7;6;44109;44109;;;;441094844;441094844;;;;;;;;;;;;;commune;commune;Rue Lavoisier;Rue Lavoisier;;;44109_4844;44109_4844;;;;;LINESTRING Z (354139.9 6688795.2 6.8, 354174 6688862.2 6.4)
TRONROUT0000000029478628;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354245.5 6688840.6 6.2, 354242.7 6688839.8 6.5, 354237.9 6688836.6 6.7, 354234.7 6688831.8 6.5)
TRONROUT0000000029478262;Route à 1 chaussée;PL RENE BOUHIER;PL RENE BOUHIER;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441097228;441097228;;;;;;;;;;;;;commune;commune;Place René Bouhier;Place René Bouhier;;;44109_7228;44109_7228;;;;;LINESTRING Z (354261.5 6688833 7, 354256.5 6688838.4 6.8, 354253.9 6688839.8 6.8, 354245.5 6688840.6 6.7)
TRONROUT0000000029478630;Route à 1 chaussée;BD DE LAUNAY;BD DE LAUNAY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;1;2;1T;4;44109;44109;;;;441094816;441094816;;;;;;;;;;;;;commune;commune;Boulevard de Launay;Boulevard de Launay;;;44109_4816;44109_4816;;;;;LINESTRING Z (354234.7 6688831.8 6.5, 354174 6688862.2 6.4)
TRONROUT0000000029478252;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354242.7 6688855.4 5.6, 354245.5 6688840.6 6.2)
TRONROUT0000002333156068;Route à 1 chaussée;R DE CONSTANTINE;R DE CONSTANTINE;5;Non;0;En service;2023-06-01 18:30:51;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;3;2;1;44109;44109;;;;441092116;441092116;;;;;;;;;;;;;commune;commune;Rue de Constantine;Rue de Constantine;;;44109_2116;44109_2116;;Sens direct;;Bande cyclable;LINESTRING Z (354261.5 6688833 7, 354292.2 6688843 7.8, 354354.3 6688864.1 11)
TRONROUT0000000029478385;Route à 1 chaussée;PL DU SANITAT;PL DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097808;441097808;;;;;;;;;;;;;commune;commune;Place du Sanitat;Place du Sanitat;;;44109_7808;44109_7808;;;;;LINESTRING Z (354359.1 6688865.3 10.6, 354363.2 6688849.9 10.6, 354363.3 6688849.7 10.6, 354366.6 6688843.8 10.6, 354370.9 6688839.4 10.6, 354377.1 6688837.2 10.6, 354383.7 6688836 10.6, 354390.8 6688837.2 10.4)
TRONROUT0000000029478640;Route à 1 chaussée;PL DU SANITAT;PL DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097808;441097808;;;;;;;;;;;;;commune;commune;Place du Sanitat;Place du Sanitat;;;44109_7808;44109_7808;;Sens direct;;Bande cyclable;LINESTRING Z (354354.3 6688864.1 6.7, 354356.2 6688864.8 6.7, 354359.1 6688865.3 10.6)
TRONROUT0000000029478051;Route à 1 chaussée;BD DE LAUNAY;BD DE LAUNAY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;3;6;9;8B;44109;44109;;;;441094816;441094816;;;;;;;;;;;;;commune;commune;Boulevard de Launay;Boulevard de Launay;;;44109_4816;44109_4816;;;;;LINESTRING Z (354174 6688862.2 6.4, 354124.9 6688886.8 7.2)
TRONROUT0000000029477884;Route à 1 chaussée;R FERREOL BOLO;R FERREOL BOLO;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;4.0;;;;;Non;5;6;11;10;44109;44109;;;;441093128;441093128;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Ferréol Bolo;Rue Ferréol Bolo;;;44109_3128;44109_3128;;;;;LINESTRING Z (354431.1 6688856.9 11.5, 354439.5 6688802.9 9)
TRONROUT0000000029478390;Route à 1 chaussée;PL DU SANITAT;PL DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097808;441097808;;;;;;;;;;;;;commune;commune;Place du Sanitat;Place du Sanitat;;;44109_7808;44109_7808;;;;;LINESTRING Z (354390.8 6688837.2 10.4, 354395.6 6688839.1 10.6, 354399.9 6688842.3 10.6, 354403.5 6688846.5 10.6, 354406.2 6688852.3 10.6, 354407.1 6688858.5 10.6, 354407 6688864.6 10.6, 354405.7 6688871.5 10.6, 354402.2 6688879.8 10.6)
TRONROUT0000000029478606;Route à 1 chaussée;CRS CORBILO;CRS CORBILO;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GL;44109#0GL;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354490.4 6688871.9 13.1, 354431.1 6688856.9 11.5)
TRONROUT0000000029478509;Route à 1 chaussée;R FERREOL BOLO;R FERREOL BOLO;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;4.0;;;;;Non;;8;;10;44109;44109;;;;441093128;441093128;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Ferréol Bolo;Rue Ferréol Bolo;;;44109_3128;44109_3128;;;;;LINESTRING Z (354425.8 6688887.7 11.8, 354425.7 6688887.5 11.8, 354427.1 6688881.4 11.8, 354429.1 6688870 11.8, 354431.1 6688856.9 11.5)
TRONROUT0000000029478257;Route à 1 chaussée;PL DU SANITAT;PL DU SANITAT;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097808;441097808;;;;;;;;;;;;;commune;commune;Place du Sanitat;Place du Sanitat;;;44109_7808;44109_7808;;Sens direct;;Bande cyclable;LINESTRING Z (354359.1 6688865.3 10.6, 354402.2 6688879.8 10.6)
TRONROUT0000000029478148;Route à 1 chaussée;R D'ALGER;R D'ALGER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;17;16;17;18;44109;44109;;;;441090144;441090144;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue d'Alger;Rue d'Alger;;;44109_0144;44109_0144;;Sens direct;;Bande cyclable;LINESTRING Z (354402.2 6688879.8 11.4, 354425.8 6688887.7 11.8)
TRONROUT0000000029478646;Route à 1 chaussée;R D'ALGER;R D'ALGER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;8;15;16;44109;44109;;;;441090144;441090144;;;;;;;;;;;;;commune;commune;Rue d'Alger;Rue d'Alger;;;44109_0144;44109_0144;;Sens direct;;Bande cyclable;LINESTRING Z (354425.8 6688887.7 11.8, 354514.9 6688918.7 15.5)
TRONROUT0000000029478617;Route à 1 chaussée;R DE MASCARA;R DE MASCARA;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441095464;441095464;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue de Mascara;Rue de Mascara;;;44109_5464;44109_5464;;;;;LINESTRING Z (354402.2 6688879.8 11.4, 354375.4 6688956.4 14.7)
TRONROUT0000000029478251;Route à 1 chaussée;R DOBREE;R DOBREE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;9;10;44109;44109;;;;441092488;441092488;;;;;;;;;;;;;commune;commune;Rue Dobrée;Rue Dobrée;;;44109_2488;44109_2488;;;;;LINESTRING Z (354485.5 6689004.5 20.6, 354375.4 6688956.4 14.7)
TRONROUT0000000029478468;Route à 1 chaussée;R DE LA VERRERIE;R DE LA VERRERIE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;17;18;19;18;44109;44109;;;;441098356;441098356;;;;;;;;;;;;;commune;commune;Rue de la Verrerie;Rue de la Verrerie;;;44109_8356;44109_8356;;;;;LINESTRING Z (354499.3 6689010.1 21, 354505 6688973.7 17.1, 354508.8 6688954.8 17)
TRONROUT0000000029478086;Route à 1 chaussée;R DOBREE;R DOBREE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;15;12B;21;18;44109;44109;;;;441092488;441092488;;;;;;;;;;;;;commune;commune;Rue Dobrée;Rue Dobrée;;;44109_2488;44109_2488;;;;;LINESTRING Z (354335 6688928.7 11.8, 354281.8 6688884.7 6.9, 354242.7 6688855.4 5.6)
TRONROUT0000002333156067;Route à 1 chaussée;R DAMREMONT;R DAMREMONT;5;Non;0;En service;2023-06-01 18:30:51;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;;1;;44109;44109;;;;441092368;441092368;;;;;;;;;;;;;commune;commune;Rue Damremont;Rue Damremont;;;44109_2368;44109_2368;;;;;LINESTRING Z (354335 6688928.7 11.8, 354354.3 6688864.1 11)
TRONROUT0000000029478090;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;7;2B;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354242.7 6688855.4 5.6, 354221.1 6688965.4 6.7)
TRONROUT0000000029478644;Route à 1 chaussée;R DE BROSSES;R DE BROSSES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-15 21:58:56;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;8;5;2;1;44109;44109;;;;441091264;441091264;;;;;;;;;;;;;commune;commune;Rue de Brosses;Rue de Brosses;;;44109_1264;44109_1264;;;;;LINESTRING Z (354124.9 6688886.8 7.2, 354157.1 6688956.2 6.4)
TRONROUT0000000029478540;Route à 1 chaussée;IMP LEMERCIER;IMP LEMERCIER;5;Non;0;En service;2006-10-04 09:41:10;2021-09-30 14:14:09;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GD;44109#0GD;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354335 6688928.7 11.8, 354330.5 6688932.2 11.4, 354317.7 6688953.4 9.3)
TRONROUT0000000029477919;Route à 1 chaussée;R DOBREE;R DOBREE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;11;12;13;12;44109;44109;;;;441092488;441092488;;;;;;;;;;;;;commune;commune;Rue Dobrée;Rue Dobrée;;;44109_2488;44109_2488;;;;;LINESTRING Z (354375.4 6688956.4 14.7, 354366.5 6688952.3 14.4, 354360.8 6688948.7 14, 354335 6688928.7 11.8)
TRONROUT0000000029478012;Route à 1 chaussée;IMP FERDINAND ARNODIN;IMP FERDINAND ARNODIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441093101;441093101;;;;;;;;;;;;;commune;commune;Impasse Ferdinand Arnodin;Impasse Ferdinand Arnodin;;;44109_3101;44109_3101;;;;;LINESTRING Z (354184.2 6688962 6.3, 354190.9 6688925.7 6.8)
TRONROUT0000002245477734;Sentier;ALL DES NEUF PREUSES;ALL DES NEUF PREUSES;6;Non;0;En service;2021-09-30 14:14:09;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;44109#0V1;44109#0V1;;;;;;;;;;;;;commune;commune;Allée des Neuf Preuses;Allée des Neuf Preuses;;;44109_5919;44109_5919;;;;;LINESTRING Z (354287.9 6688979.9 6.4, 354301.1 6688926.1 6.4, 354300.8 6688923.4 6.4, 354287.9 6688911.3 6.4)
TRONROUT0000000029478434;Route à 1 chaussée;R BAYARD;R BAYARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;4B;5;6;44109;44109;;;;441090636;441090636;;;;;;;;;;;;;commune;commune;Rue Bayard;Rue Bayard;;;44109_0636;44109_0636;;;;;LINESTRING Z (354184.2 6688962 6.3, 354161.2 6688956.5 6.5, 354157.1 6688956.2 6.4)
TRONROUT0000000029478246;Route à 1 chaussée;R BAYARD;R BAYARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441090636;441090636;;;;;;;;;;;;;commune;commune;Rue Bayard;Rue Bayard;;;44109_0636;44109_0636;;;;;LINESTRING Z (354221.1 6688965.4 6.7, 354184.2 6688962 6.3)
TRONROUT0000000029478719;Route à 1 chaussée;R DUDREZENE;R DUDREZENE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092600;441092600;;;;;;;;;;;;;commune;commune;Rue Dudrézène;Rue Dudrézène;;;44109_2600;44109_2600;;;;;LINESTRING Z (353924.1 6688837.2 9.8, 353955.5 6688821.4 8.9)
TRONROUT0000000029478639;Route à 1 chaussée;R CHAPTAL;R CHAPTAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;21;4B;7;44109;44109;;;;441091668;441091668;;;;;;;;;;;;;commune;commune;Rue Chaptal;Rue Chaptal;;;44109_1668;44109_1668;;;;;LINESTRING Z (353955.5 6688821.4 8.9, 353983.2 6688877.3 10.4)
TRONROUT0000000029478717;Route à 1 chaussée;R DUDREZENE;R DUDREZENE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;6;;4;44109;44109;;;;441092600;441092600;;;;;;;;;;;;;commune;commune;Rue Dudrézène;Rue Dudrézène;;;44109_2600;44109_2600;;;;;LINESTRING Z (353930.8 6688885.5 11.6, 353924.1 6688837.2 9.8)
TRONROUT0000000029477933;Route à 1 chaussée;R FREDERIC KUHLMANN;R FREDERIC KUHLMANN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;15;;15;;44109;44109;PASSAGE LAVOISIER;PASSAGE LAVOISIER;;441093347;441093347;;;;;;;;;;;;;commune;commune;Rue Frédéric Kuhlmann;Rue Frédéric Kuhlmann;;;44109_3347;44109_3347;;;;;LINESTRING Z (353983.2 6688877.3 10.4, 354019.7 6688858.5 8.9)
TRONROUT0000000295264787;Route à 1 chaussée;R CHAPTAL;R CHAPTAL;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4B;3;2;1;44109;44109;;;;441091668;441091668;;;;;;;;;;;;;commune;commune;Rue Chaptal;Rue Chaptal;;;44109_1668;44109_1668;;;;;LINESTRING Z (353983.2 6688877.3 10.4, 354011.7 6688934.9 9.8)
TRONROUT0000000029478503;Route à 1 chaussée;BD DE LAUNAY;BD DE LAUNAY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-15 17:51:07;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;20B;15;10;9;44109;44109;;;;441094816;441094816;;;;;;;;;;;;;commune;commune;Boulevard de Launay;Boulevard de Launay;;;44109_4816;44109_4816;;;;;LINESTRING Z (354013.8 6688941.5 9.8, 354103.2 6688897.4 7.7, 354124.9 6688886.8 7.2)
TRONROUT0000000029478653;Route à 1 chaussée;R CHAPTAL;R CHAPTAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091668;441091668;;;;;;;;;;;;;commune;commune;Rue Chaptal;Rue Chaptal;;;44109_1668;44109_1668;;;;;LINESTRING Z (354011.7 6688934.9 9.8, 354014.9 6688941.3 9.8)
TRONROUT0000000029478241;Route à 1 chaussée;R CUVIER;R CUVIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;10B;;22;44109;44109;;;;441092356;441092356;;;;;;;;;;;;;commune;commune;Rue Cuvier;Rue Cuvier;;;44109_2356;44109_2356;;;;;LINESTRING Z (354048.6 6689010.7 7.9, 354014.9 6688941.3 9.8)
TRONROUT0000000029478324;Route à 1 chaussée;BD DE LAUNAY;BD DE LAUNAY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;17;22;31;36;44109;44109;;;;441094816;441094816;;;;;;;;;;;;;commune;commune;Boulevard de Launay;Boulevard de Launay;;;44109_4816;44109_4816;;;;;LINESTRING Z (354014.9 6688941.3 9.8, 353934.6 6688980.9 12, 353911.7 6688992.3 12.6, 353892.0022898072 6689002.059047907 13.138843135969507)
TRONROUT0000000029478338;Route à 1 chaussée;R LINNE;R LINNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;9;6;44109;44109;;;;441095002;441095002;;;;;;;;;;;;;commune;commune;Rue Linné;Rue Linné;;;44109_5002;44109_5002;;;;;LINESTRING Z (354157.1 6688956.2 6.4, 354155 6688957 6.4, 354147.8 6688964.2 6.4, 354060.6 6689005.5 7.4, 354048.6 6689010.7 7.9)
TRONROUT0000000029478535;Route à 1 chaussée;R BAYARD;R BAYARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1B;2B;1T;2;44109;44109;;;;441090636;441090636;;;;;;;;;;;;;commune;commune;Rue Bayard;Rue Bayard;;;44109_0636;44109_0636;;;;;LINESTRING Z (354287.9 6688979.9 6.4, 354221.1 6688965.4 6.7)
TRONROUT0000002245477735;Route à 1 chaussée;R BAYARD;R BAYARD;5;Non;0;En service;2021-09-30 14:14:09;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090636;441090636;;;;;;;;;;;;;commune;commune;Rue Bayard;Rue Bayard;;;44109_0636;44109_0636;;;;;LINESTRING Z (354299.7 6688982.5 6.4, 354287.9 6688979.9 6.4)
TRONROUT0000000029478417;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;4;11B;8;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354221.1 6688965.4 6.7, 354209.6 6689028.4 6.4)
TRONROUT0000000029478238;Route à 1 chaussée;R ARSENE LELOUP;R ARSENE LELOUP;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;13;2;1;44109;44109;;;;441090391;441090391;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Arsène Leloup;Rue Arsène Leloup;;;44109_0391;44109_0391;;;;;LINESTRING Z (354375.4 6688956.4 14.7, 354347.9 6689051.6 15.6)
TRONROUT0000000029478170;Route à 1 chaussée;R CHEVERT;R CHEVERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091868;441091868;;;;;;;;;;;;;commune;commune;Rue Chevert;Rue Chevert;;;44109_1868;44109_1868;;;;;LINESTRING Z (354184.2 6688962 6.3, 354173.8 6689024.5 6.6, 354166.2 6689062.5 6.2)
TRONROUT0000000029478001;Route à 1 chaussée;R MARECHAL DE GASSION;R MARECHAL DE GASSION;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;5;8;44109;44109;;;;441095352;441095352;;;;;;;;;;;;;commune;commune;Rue Maréchal de Gassion;Rue Maréchal de Gassion;;;44109_5352;44109_5352;;;;;LINESTRING Z (354209.6 6689028.4 6.4, 354290.2 6689042.9 6.2)
TRONROUT0000000029478409;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;13;10;13B;12;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354209.6 6689028.4 6.4, 354198.4 6689089.4 7.1)
TRONROUT0000000029478578;Route à 1 chaussée;R CHEVERT;R CHEVERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091868;441091868;;;;;;;;;;;;;commune;commune;Rue Chevert;Rue Chevert;;;44109_1868;44109_1868;;;;;LINESTRING Z (354166.2 6689062.5 6.2, 354162.5 6689081.2 7)
TRONROUT0000000029478576;Route à 1 chaussée;R VILLARS;R VILLARS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098508;441098508;;;;;;;;;;;;;commune;commune;Rue Villars;Rue Villars;;;44109_8508;44109_8508;;;;;LINESTRING Z (354162.5 6689081.2 7, 354198.4 6689089.4 7.1)
TRONROUT0000000029478151;Route à 1 chaussée;R FABERT;R FABERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;9;;1;44109;44109;;;;441093000;441093000;;;;;;;;;;;;;commune;commune;Rue Fabert;Rue Fabert;;;44109_3000;44109_3000;;;;;LINESTRING Z (354112.2 6689124.9 6.9, 354148.8 6689074.6 6.7, 354166.2 6689062.5 6.2)
TRONROUT0000000029478153;Route à 1 chaussée;R CUVIER;R CUVIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10B;11;2;1;44109;44109;;;;441092356;441092356;;;;;;;;;;;;;commune;commune;Rue Cuvier;Rue Cuvier;;;44109_2356;44109_2356;;;;;LINESTRING Z (354048.6 6689010.7 7.9, 354100.1 6689118.3 7.8)
TRONROUT0000000029478140;Route à 1 chaussée;R DE BELLEVILLE;R DE BELLEVILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;28;23;2;3;44109;44109;;;;441090728;441090728;;;;;;;;;;;;;commune;commune;Rue de Belleville;Rue de Belleville;;;44109_0728;44109_0728;;;;;LINESTRING Z (354088.4 6689128.7 7.3, 353950.7 6689084.4 13.5, 353907.9 6689071.3 19.9, 353892.0022898072 6689066.380977564 18.759357116205347)
TRONROUT0000000029478621;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354100.1 6689118.3 7.8, 354107.1 6689121.2 6.7, 354112.2 6689124.9 6.9)
TRONROUT0000000029478624;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354088.4 6689128.7 7.3, 354093.3 6689122.3 7.4, 354095.3 6689120.7 7.4, 354100.1 6689118.3 7.8)
TRONROUT0000000029478072;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354112.2 6689124.9 6.9, 354112.4 6689129.4 6.7, 354111.1 6689133.6 7.5)
TRONROUT0000000029478136;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354090.8 6689138.3 8, 354087.8 6689132.4 7.7, 354088.4 6689128.7 7.3)
TRONROUT0000000029478608;Route à 1 chaussée;R CATINAT;R CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0DN;44109#0DN;;;;;;;;;;;;;commune;commune;Rue Catinat;Rue Catinat;;;44109_1512;44109_1512;;;;;LINESTRING Z (354149.6 6689142.9 7.6, 354111.1 6689133.6 7.5)
TRONROUT0000000029478134;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354111.1 6689133.6 7.5, 354108.5 6689140.1 6.7, 354105.7 6689142.1 6.7, 354103.4 6689142.8 6.7, 354099.2 6689144.2 7.2)
TRONROUT0000000029478219;Rond-point;PL CATINAT;PL CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091508;441091508;;;;;;;;;;;;;commune;commune;Place Catinat;Place Catinat;;;44109_1508;44109_1508;;;;;LINESTRING Z (354099.2 6689144.2 7.2, 354093.6 6689141.8 7.6, 354090.8 6689138.3 8)
TRONROUT0000000029478210;Route à 1 chaussée;R LAMOTTE PICQUET;R LAMOTTE PICQUET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441094761;441094761;;;;;;;;;;;;;commune;commune;Rue La Motte-Picquet;Rue La Motte-Picquet;;;44109_4761;44109_4761;;;;;LINESTRING Z (354059.8 6689154.6 9.7, 354090.8 6689138.3 8)
TRONROUT0000000029478439;Route à 1 chaussée;PL EUGENE LIVET;PL EUGENE LIVET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;9;4;9;4;44109;44109;;;;441092972;441092972;;;;;;;;;;;;;commune;commune;Place Eugène Livet;Place Eugène Livet;;;44109_2972;44109_2972;;;;;LINESTRING Z (354499.3 6689010.1 21, 354485.5 6689004.5 20.6)
TRONROUT0000000029478631;Route à 1 chaussée;PL EUGENE LIVET;PL EUGENE LIVET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;4;1;4;44109;44109;;;;441092972;441092972;;;;;;;;;;;;;commune;commune;Place Eugène Livet;Place Eugène Livet;;;44109_2972;44109_2972;;;;;LINESTRING Z (354505.6 6689012.7 20.9, 354499.3 6689010.1 21)
TRONROUT0000000029477690;Route à 1 chaussée;PL EUGENE LIVET;PL EUGENE LIVET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441092972;441092972;;;;;;;;;;;;;commune;commune;Place Eugène Livet;Place Eugène Livet;;;44109_2972;44109_2972;;;;;LINESTRING Z (354517 6689017.5 21.1, 354505.6 6689012.7 20.9)
TRONROUT0000000029478217;Route à 1 chaussée;R MASSILLON;R MASSILLON;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;10;;2;44109;44109;;;;441095484;441095484;;;;;;;;;;;;;commune;commune;Rue Massillon;Rue Massillon;;;44109_5484;44109_5484;;;;;LINESTRING Z (354452.8 6689074.9 22.2, 354485.5 6689004.5 20.6)
TRONROUT0000000029478554;Route à 1 chaussée;R DE BELSUNCE;R DE BELSUNCE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090740;441090740;;;;;;;;;;;;;commune;commune;Rue de Belsunce;Rue de Belsunce;;;44109_0740;44109_0740;;;;;LINESTRING Z (354505.6 6689012.7 20.9, 354475.4 6689081 22.8)
TRONROUT0000000029478479;Route à 1 chaussée;R DESIRE COLOMBE;R DESIRE COLOMBE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;5;4;3;44109;44109;;;;441092428;441092428;;;;;;;;;;;;;commune;commune;Rue Désiré Colombe;Rue Désiré Colombe;;;44109_2428;44109_2428;;;;;LINESTRING Z (354347.9 6689051.6 15.6, 354404.1 6689065.5 19.1, 354413.1 6689064.9 19.6, 354452.8 6689074.9 22.2)
TRONROUT0000000029478237;Route à 1 chaussée;R DESIRE COLOMBE;R DESIRE COLOMBE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441092428;441092428;;;;;;;;;;;;;commune;commune;Rue Désiré Colombe;Rue Désiré Colombe;;;44109_2428;44109_2428;;;;;LINESTRING Z (354475.4 6689081 22.8, 354452.8 6689074.9 22.2)
TRONROUT0000000029478010;Route à 1 chaussée;R DESIRE COLOMBE;R DESIRE COLOMBE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441092428;441092428;;;;;;;;;;;;;commune;commune;Rue Désiré Colombe;Rue Désiré Colombe;;;44109_2428;44109_2428;;;;;LINESTRING Z (354516.6 6689092.6 23.5, 354511.6 6689090.5 24.2, 354475.4 6689081 22.8)
TRONROUT0000002100424852;Route à 1 chaussée;PASSAGE EUGENE LIVET;PASSAGE EUGENE LIVET;5;Non;0;En service;2018-09-27 17:24:04;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0S4;44109#0S4;;;;;;;;;;;;;commune;commune;Passage Eugène Livet;Passage Eugène Livet;;;44109_2971;44109_2971;;;;;LINESTRING Z (354452.8 6689074.9 -1000, 354448.6 6689085.9 -1000, 354442.5 6689119.6 -1000)
TRONROUT0000002100424851;Sentier;;;6;Non;0;En service;2018-09-27 17:24:04;2020-02-12 17:33:37;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354442.5 6689119.6 -1000, 354386.5 6689111.6 -1000, 354378.7 6689155.3 -1000, 354354.4 6689154.9 -1000, 354352.1 6689170.9 -1000)
TRONROUT0000000029478261;Route à 1 chaussée;R VILLARS;R VILLARS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;;6;;44109;44109;;;;441098508;441098508;;;;;;;;;;;;;commune;commune;Rue Villars;Rue Villars;;;44109_8508;44109_8508;;;;;LINESTRING Z (354272.5 6689102.8 5.8, 354198.4 6689089.4 7.1)
TRONROUT0000000029477892;Route à 1 chaussée;R ARSENE LELOUP;R ARSENE LELOUP;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;21;8;13;44109;44109;;;;441090391;441090391;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Arsène Leloup;Rue Arsène Leloup;;;44109_0391;44109_0391;;;;;LINESTRING Z (354347.9 6689051.6 15.6, 354329.9 6689116.5 15.3, 354318.2 6689159.2 15.2, 354316.3 6689164.1 14.6)
TRONROUT0000000029478584;Route à 1 chaussée;R CHEVERT;R CHEVERT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;11;;13;;44109;44109;;;;441091868;441091868;;;;;;;;;;;;;commune;commune;Rue Chevert;Rue Chevert;;;44109_1868;44109_1868;;;;;LINESTRING Z (354149.6 6689142.9 7.6, 354162.5 6689081.2 7)
TRONROUT0000000029478408;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;15;14;15;14;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354198.4 6689089.4 7.1, 354187.2 6689151 7.1)
TRONROUT0000000029478545;Route à 1 chaussée;R CATINAT;R CATINAT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;44109#0DN;44109#0DN;;;;;;;;;;;;;commune;commune;Rue Catinat;Rue Catinat;;;44109_1512;44109_1512;;;;;LINESTRING Z (354177.3 6689153.8 7.1, 354149.6 6689142.9 7.6)
TRONROUT0000000029478059;Rond-point;PL BEAUMANOIR;PL BEAUMANOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090648;441090648;;;;;;;;;;;;;commune;commune;Place Beaumanoir;Place Beaumanoir;;;44109_0648;44109_0648;;;;;LINESTRING Z (354177.3 6689153.8 7.1, 354180.2 6689151.7 7.1, 354183.3 6689151 7.1, 354187.2 6689151 7.1)
TRONROUT0000000029478574;Rond-point;PL BEAUMANOIR;PL BEAUMANOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090648;441090648;;;;;;;;;;;;;commune;commune;Place Beaumanoir;Place Beaumanoir;;;44109_0648;44109_0648;;;;;LINESTRING Z (354187.2 6689151 7.1, 354191.2 6689152.3 7.2, 354193.5 6689155.8 7.2, 354194.1 6689159.1 7.2)
TRONROUT0000002004805878;Route à 1 chaussée;R EVARISTE LUMINAIS;R EVARISTE LUMINAIS;5;Non;0;En service;2017-07-26 18:16:17;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;;12;;44109;44109;;;;441092988;441092988;;;;;;;;;;;;;commune;commune;Rue Evariste Luminais;Rue Evariste Luminais;;;44109_2988;44109_2988;;;;;LINESTRING Z (354244.2 6689162.6 10.2, 354194.1 6689159.1 7.2)
TRONROUT0000000029478129;Route à 1 chaussée;R EVARISTE LUMINAIS;R EVARISTE LUMINAIS;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;5;2;5;44109;44109;;;;441092988;441092988;;;;;;;;;;;;;commune;commune;Rue Evariste Luminais;Rue Evariste Luminais;;;44109_2988;44109_2988;;;;;LINESTRING Z (354316.3 6689164.1 14.6, 354312.6 6689165.7 13.9, 354309.8 6689166.5 13.9, 354301.3 6689166.8 13.7, 354244.2 6689162.6 10.2)
TRONROUT0000000029478091;Rond-point;PL BEAUMANOIR;PL BEAUMANOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090648;441090648;;;;;;;;;;;;;commune;commune;Place Beaumanoir;Place Beaumanoir;;;44109_0648;44109_0648;;;;;LINESTRING Z (354173.9 6689176.1 7.1, 354175.1 6689164.9 7.1, 354175.8 6689158.5 7.1, 354177.3 6689153.8 7.1)
TRONROUT0000000029477687;Escalier;R DE L'HERONNIERE;R DE L'HERONNIERE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;37;;35;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354720.3 6688892 7.1, 354745.6 6688912.2 11.7, 354753.6 6688918.6 13.2)
TRONROUT0000000029477589;Escalier;R DES MARINS;R DES MARINS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;6;;6;;44109;44109;;;;441095392;441095392;;;;;;;;;;;;;commune;commune;Rue des Marins;Rue des Marins;;;44109_5392;44109_5392;;;;;LINESTRING Z (354753.6 6688918.6 -1000, 354759.8 6688907.3 -1000, 354759.3 6688899 -1000)
TRONROUT0000000029477688;Escalier;R DE L'HERONNIERE;R DE L'HERONNIERE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;33;;33;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354753.6 6688918.6 13.2, 354767.5 6688929.7 15.7)
TRONROUT0000000029477767;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;31;;31;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354767.5 6688929.7 15.7, 354781.5 6688940.8 18.3)
TRONROUT0000000029477616;Route à 1 chaussée;R MAURICE SIBILLE;R MAURICE SIBILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;9;8;44109;44109;;;;441095520;441095520;;;;;;;;;;;;;commune;commune;Rue Maurice Sibille;Rue Maurice Sibille;;;44109_5520;44109_5520;;;;;LINESTRING Z (354740.4 6688987.3 19.6, 354707.4 6688960.6 18.1, 354637.4 6688903.6 12.7)
TRONROUT0000000029477643;Route à 1 chaussée;R DES CADENIERS;R DES CADENIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;3;2B;44109;44109;;;;441091328;441091328;;;;;;;;;;;;;commune;commune;Rue des Cadeniers;Rue des Cadeniers;;;44109_1328;44109_1328;;;;;LINESTRING Z (354781.5 6688940.8 18.3, 354764 6688960.6 18.9, 354740.4 6688987.3 19.6)
TRONROUT0000000029477672;Route à 1 chaussée;R DES CADENIERS;R DES CADENIERS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;5;;7;;44109;44109;;;;441091328;441091328;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Cadeniers;Rue des Cadeniers;;;44109_1328;44109_1328;;;;;LINESTRING Z (354698.8 6689034.4 21.4, 354740.4 6688987.3 19.6)
TRONROUT0000000029477740;Route à 1 chaussée;R DES CADENIERS;R DES CADENIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;4;13;6;44109;44109;;;;441091328;441091328;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Cadeniers;Rue des Cadeniers;;;44109_1328;44109_1328;;;;;LINESTRING Z (354698.8 6689034.4 21.4, 354659.5 6689080.2 23.8)
TRONROUT0000000029477683;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;14;15;14;15;44109;44109;;;;441098568;441098568;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354659.5 6689080.2 23.8, 354642.9 6689073.2 23.6)
TRONROUT0000000029477693;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;11;14;11;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354682.3 6689090.2 23.8, 354659.5 6689080.2 23.8)
TRONROUT0000000029477612;Route à 1 chaussée;R FLANDRES DUNKERQUE 40;R FLANDRES DUNKERQUE 40;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;13;6;11;44109;44109;;;;441093140;441093140;;;;;;;;;;;;;commune;commune;Rue Flandres Dunkerque 40;Rue Flandres Dunkerque 40;;;44109_gynn5q;44109_gynn5q;;;;;LINESTRING Z (354615.9 6688886.2 12, 354594.7 6688944.7 16.5, 354593.6 6688947.6 16.7)
TRONROUT0000000029477711;Route à 1 chaussée;R D'ALGER;R D'ALGER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;5;4;44109;44109;;;;441090144;441090144;;;;;;;;;;;;;commune;commune;Rue d'Alger;Rue d'Alger;;;44109_0144;44109_0144;;;;;LINESTRING Z (354514.9 6688918.7 15.5, 354593.6 6688947.6 16.7)
TRONROUT0000000029477632;Route à 1 chaussée;R DE LA VERRERIE;R DE LA VERRERIE;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:23:30;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;15;16;15;16;44109;44109;;;;441098356;441098356;;;;;;;;;;;;;commune;commune;Rue de la Verrerie;Rue de la Verrerie;;;44109_8356;44109_8356;;;;;LINESTRING Z (354508.8 6688954.8 17, 354511 6688943.6 17.1, 354514.9 6688918.7 15.5)
TRONROUT0000000029477618;Route à 1 chaussée;PL JEAN BAPTISTE DARBEFEUILLE;PL JEAN BAPTISTE DARBEFEUILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;4;5;6;44109;44109;;;;441094376;441094376;;;;;;;;;;;;;commune;commune;Rue Jean Baptiste Darbefeuille;Rue Jean Baptiste Darbefeuille;;;44109_4376;44109_4376;;;;;LINESTRING Z (354508.8 6688954.8 17, 354550.5 6688954.4 17.1)
TRONROUT0000000029477799;Route à 1 chaussée;R DE BREA;R DE BREA;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;11;10;44109;44109;;;;441091204;441091204;;;;;;;;;;;;;commune;commune;Rue de Bréa;Rue de Bréa;;;44109_1204;44109_1204;;;;;LINESTRING Z (354593.6 6688947.6 16.7, 354698.8 6689034.4 21.4)
TRONROUT0000000029477649;Route à 1 chaussée;R FLANDRES DUNKERQUE 40;R FLANDRES DUNKERQUE 40;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;18;23;16;17;44109;44109;;;;441093140;441093140;;;;;;;;;;;;;commune;commune;Rue Flandres Dunkerque 40;Rue Flandres Dunkerque 40;;;44109_gynn5q;44109_gynn5q;;;;;LINESTRING Z (354593.6 6688947.6 16.7, 354588.9 6688957.6 22.5, 354579.7 6688982.9 22.5, 354567.9 6689015.4 22.5, 354561.1 6689037 22.5)
TRONROUT0000000029477816;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;21;32;25;34;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354561.1 6689037 22.5, 354517 6689017.5 21.1)
TRONROUT0000000029477662;Route à 1 chaussée;R DE LA ROSIERE D'ARTOIS;R DE LA ROSIERE D'ARTOIS;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;441097476;441097476;;;;;;;;;;;;;commune;commune;Rue de la Rosière d'Artois;Rue de la Rosière d'Artois;;;44109_7476;44109_7476;;;;;LINESTRING Z (354517 6689017.5 21.1, 354518.1 6689088.2 23.3, 354516.6 6689092.6 23.5)
TRONROUT0000000029477800;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;15;;19;;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354642.9 6689073.2 23.6, 354561.1 6689037 22.5)
TRONROUT0000000029477652;Route à 1 chaussée;R DE LA ROSIERE D'ARTOIS;R DE LA ROSIERE D'ARTOIS;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;9;8;15;10;44109;44109;;;;441097476;441097476;;;;;;;;;;;;;commune;commune;Rue de la Rosière d'Artois;Rue de la Rosière d'Artois;;;44109_7476;44109_7476;;;;;LINESTRING Z (354516.6 6689092.6 23.5, 354517.3 6689095.5 23.6, 354519.2 6689165.1 26.3)
TRONROUT0000000029477779;Escalier;R D'ANCIN;R D'ANCIN;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;7;;1;44109;44109;;;;441090268;441090268;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue d'Ancin;Rue d'Ancin;;;44109_0268;44109_0268;;;;;LINESTRING Z (354806.5 6688962.3 18.4, 354808 6688959.5 18.1, 354816.5 6688946.8 14.4, 354831.7 6688926.1 8.7, 354852.5 6688891.6 7.1)
TRONROUT0000000029477768;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;22;29;20;27;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354781.5 6688940.8 18.3, 354803.3 6688959.7 18.4, 354806.5 6688962.3 18.4)
TRONROUT0000000029474568;Route à 1 chaussée;R NEUVE DES CAPUCINS;R NEUVE DES CAPUCINS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;;6;;44109;44109;;;;441095912;441095912;;;;;;;;;;;;;commune;commune;Rue Neuve des Capucins;Rue Neuve des Capucins;;;44109_5912;44109_5912;;;;;LINESTRING Z (354934.9 6688932.9 7, 354879.3 6689025 15)
TRONROUT0000000029477728;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;20;15;10;15;44109;44109;;;;441094180;441094180;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354806.5 6688962.3 18.4, 354835.3 6688987.2 17, 354859.2 6689007.7 15.9, 354879.3 6689025 15)
TRONROUT0000000029474186;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;10;13;6;9;44109;44109;;;;441094180;441094180;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354879.3 6689025 15, 354896.8 6689040.1 15.3, 354918.4 6689058.6 15.5)
TRONROUT0000000029477814;Route empierrée;CRS CAMBRONNE;CRS CAMBRONNE;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#020;44109#020;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (354894 6689116.7 18.9, 354886.9 6689110.8 18.9, 354812.3 6689048.6 19.9, 354749.5 6688995.1 19.6, 354740.4 6688987.3 19.6)
TRONROUT0000000029474997;Route à 1 chaussée;R PIRON;R PIRON;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096664;441096664;;;;;;;;;;;;;commune;commune;Rue Piron;Rue Piron;;;44109_6664;44109_6664;;;;;LINESTRING Z (354888.4 6689148.3 19.5, 354888.7 6689143.9 19.4, 354887.5 6689128.7 19.3, 354887.3 6689126 19.3, 354889.1 6689123.2 19.4, 354894 6689116.7 18.9)
TRONROUT0000000029477802;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;5;10;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354853.6 6689161.4 20.3, 354806.3 6689143.3 21.7, 354731.1 6689111.1 23.2)
TRONROUT0000000029475238;Sentier;PL GRASLIN;PL GRASLIN;6;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;4;;4;44109;44109;;;;441093832;441093832;;;;;;;;;;;;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354888.4 6689148.3 19.5, 354901.8 6689154.7 19.4)
TRONROUT0000000029474617;Route à 1 chaussée;PL GRASLIN;PL GRASLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2T;;3;44109;44109;;;;441093832;441093832;;;;;;;;;;;;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354877.2 6689169.6 19.9, 354879.9 6689161.7 19.9, 354882.3 6689156.9 19.6, 354885.1 6689152.9 19.6, 354888.4 6689148.3 19.5)
TRONROUT0000000029477675;Route à 1 chaussée;R GRESSET;R GRESSET;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;15;12;44109;44109;;;;441093864;441093864;;;;;;;;;;;;;commune;commune;Rue Gresset;Rue Gresset;;;44109_3864;44109_3864;;;;;LINESTRING Z (354698.8 6689034.4 21.4, 354853.6 6689161.4 20.3)
TRONROUT0000000029477817;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;12;11;12;7;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354731.1 6689111.1 23.2, 354682.3 6689090.2 23.8)
TRONROUT0000000029477843;Route à 1 chaussée;R ATHENAS;R ATHENAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;6;;1;44109;44109;;;;441090424;441090424;;;;;;;;;;;;;commune;commune;Rue Athénas;Rue Athénas;;;44109_0424;44109_0424;;;;;LINESTRING Z (354659.4 6689144.2 24.5, 354682.3 6689090.2 23.8)
TRONROUT0000000029477778;Route à 1 chaussée;R LESAGE;R LESAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CL;44109#0CL;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354731.1 6689111.1 23.2, 354720.1 6689136.9 24.3)
TRONROUT0000000029477719;Route à 1 chaussée;PL DE LA MONNAIE;PL DE LA MONNAIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;5;;5;44109;44109;;;;441095728;441095728;;;;;;;;;;;;;commune;commune;Place de la Monnaie;Place de la Monnaie;;;44109_5728;44109_5728;;;;;LINESTRING Z (354640.5 6689188.7 25.6, 354659.4 6689144.2 24.5)
TRONROUT0000000029477736;Route à 1 chaussée;PL DE LA MONNAIE;PL DE LA MONNAIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441095728;441095728;;;;;;;;;;;;;commune;commune;Place de la Monnaie;Place de la Monnaie;;;44109_5728;44109_5728;;;;;LINESTRING Z (354720.1 6689136.9 24.3, 354708 6689165.5 24.8, 354688.9 6689210.5 25.2)
TRONROUT0000000029477699;Route à 1 chaussée;R MARIVAUX;R MARIVAUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;7;4;1;44109;44109;;;;441095396;441095396;;;;;;;;;;;;;commune;commune;Rue Marivaux;Rue Marivaux;;;44109_5396;44109_5396;;;;;LINESTRING Z (354720.1 6689136.9 24.3, 354745.6 6689224.4 26.1)
TRONROUT0000000029477793;Route à 1 chaussée;PL DE LA MONNAIE;PL DE LA MONNAIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;3;;3;;44109;44109;;;;441095728;441095728;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place de la Monnaie;Place de la Monnaie;;;44109_5728;44109_5728;;;;;LINESTRING Z (354664 6689199.3 25.6, 354640.5 6689188.7 25.6)
TRONROUT0000000029477713;Route à 1 chaussée;PL DE LA MONNAIE;PL DE LA MONNAIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441095728;441095728;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place de la Monnaie;Place de la Monnaie;;;44109_5728;44109_5728;;;;;LINESTRING Z (354688.9 6689210.5 25.2, 354664 6689199.3 25.6)
TRONROUT0000000029477788;Route à 1 chaussée;R ANIZON;R ANIZON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;3;2B;3;44109;44109;;;;441090300;441090300;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Anizon;Rue Anizon;;;44109_0300;44109_0300;;;;;LINESTRING Z (354718.9 6689240.1 26.3, 354693.3 6689212.5 25.4, 354688.9 6689210.5 25.2)
TRONROUT0000000029477721;Route à 1 chaussée;R HIPPOLYTE DURAND GASSELIN;R HIPPOLYTE DURAND GASSELIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;6;44109;44109;;;;441094204;441094204;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Hippolyte Durand Gasselin;Rue Hippolyte Durand Gasselin;;;44109_4204;44109_4204;;;;;LINESTRING Z (354642.9 6689073.2 23.6, 354632 6689089.3 24.4, 354616 6689116.1 25.3, 354613.6 6689124.1 25.6, 354612.9 6689130.6 25.8, 354613.5 6689171 26.8, 354613 6689178.5 26.8, 354610.3 6689186 27.2)
TRONROUT0000000029477642;Route à 1 chaussée;R DE LA ROSIERE D'ARTOIS;R DE LA ROSIERE D'ARTOIS;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;17;12;17;12;44109;44109;;;;441097476;441097476;;;;;;;;;;;;;commune;commune;Rue de la Rosière d'Artois;Rue de la Rosière d'Artois;;;44109_7476;44109_7476;;;;;LINESTRING Z (354519.2 6689165.1 26.3, 354519.6 6689179.1 27.4)
TRONROUT0000000029477680;Route à 1 chaussée;R MONTESQUIEU;R MONTESQUIEU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:15:49;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;;4;;44109;44109;;;;441095764;441095764;;;;;;;;;;;;;commune;commune;Rue Montesquieu;Rue Montesquieu;;;44109_5764;44109_5764;;;;;LINESTRING Z (354519.6 6689179.1 27.4, 354610.3 6689186 27.2)
TRONROUT0000000029477733;Route à 1 chaussée;R MONTESQUIEU;R MONTESQUIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441095764;441095764;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Montesquieu;Rue Montesquieu;;;44109_5764;44109_5764;;;;;LINESTRING Z (354610.3 6689186 27.2, 354640.5 6689188.7 25.6)
TRONROUT0000000029477629;Route à 1 chaussée;R URVOY DE SAINT-BEDAN;R URVOY DE SAINT-BEDAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;5;2;7;6;44109;44109;;;;441098276;441098276;;;;;;;;;;;;;commune;commune;Rue Urvoy de Saint Bedan;Rue Urvoy de Saint Bedan;;;44109_8276;44109_8276;;;;;LINESTRING Z (354610.3 6689186 27.2, 354565.8 6689233.6 28.9)
TRONROUT0000000029477628;Route à 1 chaussée;R DE LA ROSIERE D'ARTOIS;R DE LA ROSIERE D'ARTOIS;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;17;14;31;24;44109;44109;;;;441097476;441097476;;;;;;;;;;;;;commune;commune;Rue de la Rosière d'Artois;Rue de la Rosière d'Artois;;;44109_7476;44109_7476;;;;;LINESTRING Z (354519.6 6689179.1 27.4, 354516.7 6689223 28.7, 354514.4 6689247 28.7, 354510.7 6689290.9 28.7)
TRONROUT0000000029477682;Route à 1 chaussée;R KLEBER;R KLEBER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;5;8;44109;44109;;;;441094716;441094716;;;;;;;;;;;;;commune;commune;Rue Kléber;Rue Kléber;;;44109_4716;44109_4716;;;;;LINESTRING Z (354664 6689199.3 25.6, 354621.3 6689298.9 28.5)
TRONROUT0000000029477727;Route à 1 chaussée;R URVOY DE SAINT-BEDAN;R URVOY DE SAINT-BEDAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;9;8;13;16;44109;44109;;;;441098276;441098276;;;;;;;;;;;;;commune;commune;Rue Urvoy de Saint Bedan;Rue Urvoy de Saint Bedan;;;44109_8276;44109_8276;;;;;LINESTRING Z (354565.8 6689233.6 28.9, 354510.7 6689290.9 28.7)
TRONROUT0000000029477659;Route à 1 chaussée;R DE LA GALISSONNIERE;R DE LA GALISSONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;7;4;3;44109;44109;;;;441093444;441093444;;;;;;;;;;;;;commune;commune;Rue de la Galissonnière;Rue de la Galissonnière;;;44109_3444;44109_3444;;;;;LINESTRING Z (354621.3 6689298.9 28.5, 354565.8 6689233.6 28.9)
TRONROUT0000000029477723;Route à 1 chaussée;R DE LA GALISSONNIERE;R DE LA GALISSONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2B;1;2;1;44109;44109;;;;441093444;441093444;;;;;;;;;;;;;commune;commune;Rue de la Galissonnière;Rue de la Galissonnière;;;44109_3444;44109_3444;;;;;LINESTRING Z (354650 6689332.6 29, 354621.3 6689298.9 28.5)
TRONROUT0000000029474291;Route à 1 chaussée;PL GRASLIN;PL GRASLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093832;441093832;;;;;;;;;;;;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354901.8 6689154.7 19.4, 354904 6689157.7 19.3, 354908.1 6689163.2 19.4, 354911.4 6689169.3 19.4)
TRONROUT0000000029473931;Route à 1 chaussée;R VOLTAIRE;R VOLTAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098568;441098568;;;;;;;;;;;;;commune;commune;Rue Voltaire;Rue Voltaire;;;44109_8568;44109_8568;;;;;LINESTRING Z (354877.2 6689169.6 19.9, 354853.6 6689161.4 20.3)
TRONROUT0000002333155911;Route à 1 chaussée;;;5;Non;0;En service;2023-06-01 18:27:33;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354877.2 6689169.6 -1000, 354911.4 6689169.3 -1000)
TRONROUT0000000029473635;Route à 1 chaussée;PL GRASLIN;PL GRASLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2;;2B;44109;44109;;;;441093832;441093832;;;;;;;;;;;;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354872.9 6689191.5 20.1, 354877.2 6689169.6 19.9)
TRONROUT0000002333155909;Route à 1 chaussée;PL GRASLIN;PL GRASLIN;5;Non;0;En service;2023-06-01 18:27:33;2023-06-03 01:10:35;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;1T;;1T;44109;44109;;;;441093832;441093832;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354912.7 6689190 20.1, 354904.1 6689190.4 20.1, 354883.4 6689191.6 20.1, 354874.3 6689199.4 20.4)
TRONROUT0000000029474146;Sentier;R CORNEILLE;R CORNEILLE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;3;;3;44109;44109;;;;441092176;441092176;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Corneille;Rue Corneille;;;44109_2176;44109_2176;;;;;LINESTRING Z (354874.3 6689199.4 20.4, 354872.9 6689191.5 20.5)
TRONROUT0000000029474141;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;2;3;2;44109;44109;;;;441097100;441097100;;;;;;;;;;;;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354872.9 6689191.5 20.5, 354840.1 6689213.3 22)
TRONROUT0000002333155910;Route à 1 chaussée;R CORNEILLE;R CORNEILLE;5;Non;0;En service;2023-06-01 18:27:33;2023-06-03 01:10:35;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;3;44109;44109;;;;441092176;441092176;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Corneille;Rue Corneille;;;44109_2176;44109_2176;;;;;LINESTRING Z (354879.2 6689273.7 24.6, 354874.6 6689204.9 21.1, 354874.3 6689199.4 20.4)
TRONROUT0000000029477775;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;4;11;8;44109;44109;;;;441097100;441097100;;;;;;;;;;;;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354757.6 6689265.1 27, 354840.1 6689213.3 22)
TRONROUT0000000029477839;Route à 1 chaussée;R FRANKLIN;R FRANKLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1B;2;1B;4;44109;44109;;;;441093328;441093328;;;;;;;;;;;;;commune;commune;Rue Franklin;Rue Franklin;;;44109_3328;44109_3328;;;;;LINESTRING Z (354840.1 6689213.3 22, 354828.8 6689272 25.1)
TRONROUT0000000029477758;Route à 1 chaussée;PL PAUL EMILE LADMIRAULT;PL PAUL EMILE LADMIRAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441096228;441096228;;;;;;;;;;;;;commune;commune;Place Paul Emile Ladmirault;Place Paul Emile Ladmirault;;;44109_6228;44109_6228;;;;;LINESTRING Z (354718.9 6689240.1 26.3, 354745.6 6689224.4 26.1)
TRONROUT0000000029477670;Route à 1 chaussée;PL PAUL EMILE LADMIRAULT;PL PAUL EMILE LADMIRAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;4;;5;44109;44109;;;;441096228;441096228;;;;;;;;;;;;;commune;commune;Place Paul Emile Ladmirault;Place Paul Emile Ladmirault;;;44109_6228;44109_6228;;;;;LINESTRING Z (354745.6 6689224.4 26.1, 354757.6 6689265.1 27)
TRONROUT0000000029477724;Route à 1 chaussée;PL PAUL EMILE LADMIRAULT;PL PAUL EMILE LADMIRAULT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;1;;44109;44109;;;;441096228;441096228;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Paul Emile Ladmirault;Place Paul Emile Ladmirault;;;44109_6228;44109_6228;;;;;LINESTRING Z (354747.7 6689271.3 27.4, 354718.9 6689240.1 26.3)
TRONROUT0000000029477681;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;8;;8;44109;44109;;;;441097100;441097100;;;;;;;;;;;;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354757.6 6689265.1 27, 354754.2 6689267.2 27.1)
TRONROUT0000000029477786;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097100;441097100;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354754.2 6689267.2 27.1, 354747.7 6689271.3 27.4)
TRONROUT0000000029477654;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;15;24;23;44109;44109;;;;441097100;441097100;;;;;;;;;;;;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354650 6689332.6 29, 354747.7 6689271.3 27.4)
TRONROUT0000000029477746;Route à 1 chaussée;R CASSINI;R CASSINI;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;1;4;1;44109;44109;;;;441091492;441091492;;;;;;;;;;;;;commune;commune;Rue Cassini;Rue Cassini;;;44109_1492;44109_1492;;;;;LINESTRING Z (354684.3 6689372.3 29.3, 354650 6689332.6 29)
TRONROUT0000000029477776;Route à 1 chaussée;R BUFFON;R BUFFON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;15;2;1;44109;44109;;;;441091296;441091296;;;;;;;;;;;;;commune;commune;Rue Buffon;Rue Buffon;;;44109_1296;44109_1296;;;;;LINESTRING Z (354817.8 6689329.2 27.2, 354739.1 6689382.8 28.8)
TRONROUT0000000029477819;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;14;9;10;5;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354625.3 6689363.4 30.5, 354684.3 6689372.3 29.3)
TRONROUT0000000029477697;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;5;2;3;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354684.3 6689372.3 29.3, 354739.1 6689382.8 28.8)
TRONROUT0000000029477696;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;21;28;21;32;44109;44109;;;;441097856;441097856;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354754.2 6689267.2 27.1, 354768.7 6689268.7 26.8, 354828.8 6689272 25.1)
TRONROUT0000000029477712;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;19;26B;19;26B;44109;44109;;;;441097856;441097856;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354858.4 6689274.1 24.3, 354854.9 6689274.1 24.3, 354828.8 6689272 25.1)
TRONROUT0000000029474130;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;18;;22;44109;44109;;;;441097856;441097856;;;;;;;;;;;;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354921 6689272.9 22.9, 354879.2 6689273.7 24.6)
TRONROUT0000000029475286;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;24;;26;44109;44109;;;;441097856;441097856;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354879.2 6689273.7 24.6, 354858.4 6689274.1 24.3)
TRONROUT0000000029477585;Sentier;R LEKAIN;R LEKAIN;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441094880;441094880;;;;;;;;;;;;;commune;commune;Rue Lekain;Rue Lekain;;;44109_4880;44109_4880;;;;;LINESTRING Z (354858.4 6689274.1 -1000, 354858.4 6689288.6 -1000)
TRONROUT0000000029477701;Route à 1 chaussée;R FRANKLIN;R FRANKLIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;3;6;9;16;44109;44109;;;;441093328;441093328;;;;;;;;;;;;;commune;commune;Rue Franklin;Rue Franklin;;;44109_3328;44109_3328;;;;;LINESTRING Z (354828.8 6689272 25.1, 354817.8 6689329.2 27.2)
TRONROUT0000000029473456;Route à 1 chaussée;R LEKAIN;R LEKAIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;7;4;3;44109;44109;;;;441094880;441094880;;;;;;;;;;;;;commune;commune;Rue Lekain;Rue Lekain;;;44109_4880;44109_4880;;;;;LINESTRING Z (354856.4 6689339.5 27.4, 354858.7 6689299.9 25.9, 354858.4 6689288.6 25.1)
TRONROUT0000000321061194;Route à 1 chaussée;R LEKAIN;R LEKAIN;5;Non;0;En service;2013-04-16 17:06:04;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441094880;441094880;;;;;;;;;;;;;commune;commune;Rue Lekain;Rue Lekain;;;44109_4880;44109_4880;;;;;LINESTRING Z (354856.4 6689339.5 27.4, 354853.2 6689355.3 27.6)
TRONROUT0000000029474781;Route à 1 chaussée;R LOUIS PREAUBERT;R LOUIS PREAUBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;1;44109;44109;;;;441095132;441095132;;;;;;;;;;;;;commune;commune;Rue Louis Préaubert;Rue Louis Préaubert;;;44109_5132;44109_5132;;;;;LINESTRING Z (354853.2 6689355.3 27.6, 354906.4 6689360.9 24.8, 354909.5 6689359.5 24.6)
TRONROUT0000000029477671;Route à 1 chaussée;R FRANKLIN;R FRANKLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;11;16;11;20;44109;44109;;;;441093328;441093328;;;;;;;;;;;;;commune;commune;Rue Franklin;Rue Franklin;;;44109_3328;44109_3328;;;;;LINESTRING Z (354817.8 6689329.2 27.2, 354801.2 6689396.1 28.4)
TRONROUT0000000029474440;Route à 1 chaussée;R LEKAIN;R LEKAIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;9;10;7;44109;44109;;;;441094880;441094880;;;;;;;;;;;;;commune;commune;Rue Lekain;Rue Lekain;;;44109_4880;44109_4880;;;;;LINESTRING Z (354840.5 6689401.5 27.3, 354853.2 6689355.3 27.6)
TRONROUT0000000029477716;Route à 1 chaussée;PL DELORME;PL DELORME;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441092400;441092400;;;;;;;;;;;;;commune;commune;Place Delorme;Place Delorme;;;44109_2400;44109_2400;;;;;LINESTRING Z (354792.3 6689394.6 28.6, 354801.2 6689396.1 28.6)
TRONROUT0000000029477743;Route à 1 chaussée;PL DELORME;PL DELORME;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;1;3;1;44109;44109;;;;441092400;441092400;;;;;;;;;;;;;commune;commune;Place Delorme;Place Delorme;;;44109_2400;44109_2400;;;;;LINESTRING Z (354801.2 6689396.1 28.4, 354821.7 6689399 27.8)
TRONROUT0000000326872125;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2013-09-09 18:38:44;2023-06-01 18:33:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;29;;29;;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (354821.7 6689399 27.8, 354840.5 6689401.5 27.3)
TRONROUT0000000029477789;Route à 1 chaussée;PL DELORME;PL DELORME;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092400;441092400;;;;;;;;;;;;;commune;commune;Place Delorme;Place Delorme;;;44109_2400;44109_2400;;;;;LINESTRING Z (354801.2 6689396.1 28.4, 354799.3 6689408.6 28.6)
TRONROUT0000000029474090;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;19;20;27;32;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (354950 6689421.2 21.4, 354840.5 6689401.5 27.3)
TRONROUT0000000029477726;Route à 1 chaussée;R CAMILLE BERRUYER;R CAMILLE BERRUYER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;3;4;44109;44109;;;;441091376;441091376;;;;;;;;;;;;;commune;commune;Rue Camille Berruyer;Rue Camille Berruyer;;;44109_1376;44109_1376;;;;;LINESTRING Z (354799.3 6689408.6 28.4, 354784.9 6689487.2 27.7, 354784.8 6689487.4 27.7)
TRONROUT0000000029477780;Rond-point;PL NEWTON;PL NEWTON;5;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CS;44109#0CS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354778.7 6689487.7 28.1, 354779.2 6689487.2 28, 354781.8 6689486.4 27.9, 354784.4 6689487.1 27.8, 354784.8 6689487.4 27.7)
TRONROUT0000000029477787;Rond-point;PL NEWTON;PL NEWTON;5;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CS;44109#0CS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354784.8 6689487.4 27.7, 354786.2 6689488.9 27.7, 354786.7 6689490.6 27.7)
TRONROUT0000000029477813;Rond-point;PL NEWTON;PL NEWTON;5;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CS;44109#0CS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354786.7 6689490.6 27.7, 354786.9 6689491.5 27.8, 354786.2 6689494.1 27.9, 354784.9 6689495.4 28.1)
TRONROUT0000000029477706;Route à 1 chaussée;R KLEBER;R KLEBER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;10;11;12;44109;44109;;;;441094716;441094716;;;;;;;;;;;;;commune;commune;Rue Kléber;Rue Kléber;;;44109_4716;44109_4716;;;;;LINESTRING Z (354621.3 6689298.9 28.5, 354600.2 6689348.6 29.2, 354598.8 6689356.9 28.8)
TRONROUT0000000029477818;Route à 1 chaussée;R RACINE;R RACINE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;25;;27;;44109;44109;;;;441097100;441097100;;;;;;;;;;;;;commune;commune;Rue Racine;Rue Racine;;;44109_7100;44109_7100;;;;;LINESTRING Z (354598.8 6689356.9 28.8, 354627.3 6689346.6 28.8, 354650 6689332.6 29)
TRONROUT0000000029477752;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;22;13;20;11;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354551 6689357.6 28.4, 354586.7 6689355.6 28.7, 354598.8 6689356.9 28.8)
TRONROUT0000000029478453;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;24;12;24;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354551 6689357.6 28.4, 354521.3 6689359.4 28.2, 354506.6 6689357.7 27.9)
TRONROUT0000000029477673;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;9;16;9;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354598.8 6689356.9 28.8, 354625.3 6689363.4 30.5)
TRONROUT0000000029477796;Route à 1 chaussée;R SEVIGNE;R SEVIGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441097896;441097896;;;;;;;;;;;;;commune;commune;Rue Sévigné;Rue Sévigné;;;44109_7896;44109_7896;;;;;LINESTRING Z (354551 6689357.6 28.4, 354551.3 6689411.4 28.4)
TRONROUT0000000029478236;Route à 1 chaussée;R BERTRAND GESLIN;R BERTRAND GESLIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;;1T;;44109;44109;;;;441090816;441090816;;;;;;;;;;;;;commune;commune;Rue Bertrand Geslin;Rue Bertrand Geslin;;;44109_0816;44109_0816;;;;;LINESTRING Z (354506.6 6689357.7 27.9, 354551.3 6689411.4 28.4)
TRONROUT0000000029477732;Route à 1 chaussée;IMP COPERNIC;IMP COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;5;8;1;44109;44109;;;;441092136;441092136;;;;;;;;;;;;;commune;commune;Impasse Copernic;Impasse Copernic;;;44109_2136;44109_2136;;;;;LINESTRING Z (354623.8 6689426 30.5, 354628.1 6689424.9 30.5, 354625.3 6689363.4 30.5)
TRONROUT0000000029477765;Route à 1 chaussée;R BERTRAND GESLIN;R BERTRAND GESLIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;3;2;13;6;44109;44109;;;;441090816;441090816;;;;;;;;;;;;;commune;commune;Rue Bertrand Geslin;Rue Bertrand Geslin;;;44109_0816;44109_0816;;;;;LINESTRING Z (354551.3 6689411.4 28.4, 354640.9 6689519.2 30.5)
TRONROUT0000000029478482;Route à 1 chaussée;R SEVIGNE;R SEVIGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;10;27;8;3;44109;44109;;;;441097896;441097896;;;;;;;;;;;;;commune;commune;Rue Sévigné;Rue Sévigné;;;44109_7896;44109_7896;;;;;LINESTRING Z (354501.6 6689595.2 30.7, 354515.3 6689544.5 30, 354536 6689468.2 29.1, 354551.3 6689411.4 28.4)
TRONROUT0000000029473910;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;13;8;5;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (355036.4 6689089.6 11.8, 354969.8 6689131.6 16.3)
TRONROUT0000000029474255;Route à 1 chaussée;R DE L'HERONNIERE;R DE L'HERONNIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;3;2;44109;44109;;;;441094180;441094180;;;;;;;;;;;;;commune;commune;Rue de l'Héronnière;Rue de l'Héronnière;;;44109_4180;44109_4180;;;;;LINESTRING Z (354969.8 6689131.6 16.3, 354953.1 6689104.2 16.6, 354948 6689096.1 16.3)
TRONROUT0000000029473464;Route à 1 chaussée;R REGNARD;R REGNARD;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;4.0;;;;;Non;4;5;2;1;44109;44109;;;;441097176;441097176;;;;;;;;;;;;;commune;commune;Rue Régnard;Rue Régnard;;;44109_7176;44109_7176;;;;;LINESTRING Z (354901.8 6689154.7 19.4, 354915.2 6689131.2 18.5, 354948 6689096.1 16.3)
TRONROUT0000000029473949;Route à 1 chaussée;R SANTEUIL;R SANTEUIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;3;2;1;44109;44109;;;;441097816;441097816;;;;;;;;;;;;;commune;commune;Rue Santeuil;Rue Santeuil;;;44109_7816;44109_7816;;;;;LINESTRING Z (355037.9 6689179.9 15.2, 355036.4 6689089.6 11.8)
TRONROUT0000000029473736;Route à 1 chaussée;R JEAN JACQUES ROUSSEAU;R JEAN JACQUES ROUSSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;16;17;14;13B;44109;44109;;;;441094472;441094472;;;;;;;;;;;;;commune;commune;Rue Jean Jacques Rousseau;Rue Jean Jacques Rousseau;;;44109_4472;44109_4472;;;;;LINESTRING Z (354969.8 6689131.6 16.3, 354911.4 6689169.3 19.4)
TRONROUT0000000029474219;Route à 1 chaussée;R SUFFREN;R SUFFREN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;5;4;44109;44109;;;;441097992;441097992;;;;;;;;;;;;;commune;commune;Rue Suffren;Rue Suffren;;;44109_7992;44109_7992;;;;;LINESTRING Z (354969.8 6689131.6 16.3, 354996.1 6689175.3 17.1)
TRONROUT0000000029474020;Route à 1 chaussée;R RAMEAU;R RAMEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;3;2;1;44109;44109;;;;441097120;441097120;;;;;;;;;;;;;commune;commune;Rue Rameau;Rue Rameau;;;44109_7120;44109_7120;;;;;LINESTRING Z (354996.1 6689175.3 17.1, 355037.9 6689179.9 15.2)
TRONROUT0000000029474293;Route à 1 chaussée;PL GRASLIN;PL GRASLIN;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;1;44109;44109;;;;441093832;441093832;;;;;;;;;;;;;commune;commune;Place Graslin;Place Graslin;;;44109_3832;44109_3832;;;;;LINESTRING Z (354911.4 6689169.3 19.4, 354912.7 6689190 20.1)
TRONROUT0000000357587958;Route à 1 chaussée;R SANTEUIL;R SANTEUIL;5;Non;0;En service;2016-06-01 17:33:32;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;10;5A;10;44109;44109;;;;441097816;441097816;;;;;;;;;;;;;commune;commune;Rue Santeuil;Rue Santeuil;;;44109_7816;44109_7816;;;;;LINESTRING Z (355037.9 6689179.9 15.2, 355038 6689192.3 15.1)
TRONROUT0000000357587957;Sentier;PAS COEUR DE NANTES;PAS COEUR DE NANTES;6;Non;0;En service;2016-06-01 17:33:32;;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355038 6689192.3 15.1, 355052.6 6689191.9 14.3, 355075 6689183.8 13.5, 355081.8 6689194.7 12.7, 355088.7 6689204.5 11.9)
TRONROUT0000000029474951;Route à 1 chaussée;R THUROT;R THUROT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;2;;44109;44109;;;;441098104;441098104;;;;;;;;;;;;;commune;commune;Rue Thurot;Rue Thurot;;;44109_8104;44109_8104;;;;;LINESTRING Z (355173.1 6689159.4 6.5, 355150.4 6689131.9 6.5, 355148.6 6689130 6.5)
TRONROUT0000000228331536;Sentier;PAS DU COMMERCE;PAS DU COMMERCE;6;Non;0;En service;2010-02-01 16:20:39;2022-12-10 14:57:12;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092089;441092089;;;;;;;;;;;;;commune;commune;Passage du Commerce;Passage du Commerce;;;44109_2089;44109_2089;;;;;LINESTRING Z (355129.2 6689138.3 6.7, 355127 6689144.2 -1000, 355090.3 6689158.1 -1000, 355079.2 6689161 -1000)
TRONROUT0000000029473634;Route à 1 chaussée;R DE LA FOSSE;R DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;26;25;22;25;44109;44109;;;;441093236;441093236;;;;;;;;;;;;;commune;commune;Rue de la Fosse;Rue de la Fosse;;;44109_3236;44109_3236;;;;;LINESTRING Z (355129.2 6689138.3 6.7, 355137.4 6689170 6.7, 355139.7 6689179.3 6.5)
TRONROUT0000000029473474;Sentier;PAS DU COMMERCE;PAS DU COMMERCE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092089;441092089;;;;;;;;;;;;;commune;commune;Passage du Commerce;Passage du Commerce;;;44109_2089;44109_2089;;;;;LINESTRING Z (355079.2 6689161 -1000, 355071.6 6689162.5 -1000, 355056.9 6689167.1 -1000)
TRONROUT0000000228331537;Sentier;PAS DU COMMERCE;PAS DU COMMERCE;6;Non;0;En service;2010-02-01 16:20:39;2022-12-10 14:57:12;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092089;441092089;;;;;;;;;;;;;commune;commune;Passage du Commerce;Passage du Commerce;;;44109_2089;44109_2089;;;;;LINESTRING Z (355079.2 6689161 -1000, 355081.7 6689170.5 -1000, 355082.4 6689174.6 -1000)
TRONROUT0000000029474030;Route à 1 chaussée;R FRANCOIS SALIERES;R FRANCOIS SALIERES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441093316;441093316;;;;;;;;;;;;;commune;commune;Rue François Salières;Rue François Salières;;;44109_3316;44109_3316;;;;;LINESTRING Z (355140.7 6689182.4 6.5, 355173.1 6689159.4 6.5)
TRONROUT0000000029474652;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355139.7 6689179.3 6.5, 355140.7 6689182.4 6.5)
TRONROUT0000000029473555;Sentier;PAS POMMERAYE;PAS POMMERAYE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;11;2;3;44109;44109;;;;441095813;441095813;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Passage Pommeraye;Passage Pommeraye;;;44109_5813;44109_5813;;;;;LINESTRING Z (355088.7 6689204.5 11.9, 355139.7 6689179.3 6.5)
TRONROUT0000000029473908;Route à 1 chaussée;R DE LA FOSSE;R DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;20;13;14;13;44109;44109;;;;441093236;441093236;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Fosse;Rue de la Fosse;;;44109_3236;44109_3236;;;;;LINESTRING Z (355140.7 6689182.4 6.5, 355149.1 6689213.4 6.7)
TRONROUT0000000200678091;Sentier;R DU PUITS D'ARGENT;R DU PUITS D'ARGENT;6;Non;0;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;4;;2;44109;44109;;;;441097052;441097052;;;;;;;;;;;;;commune;commune;Rue du Puits d'Argent;Rue du Puits d'Argent;;;44109_7052;44109_7052;;;;;LINESTRING Z (355149.1 6689213.4 6.7, 355135 6689218.7 6.6, 355125.8 6689221.2 7.5)
TRONROUT0000000029475063;Route à 1 chaussée;ALL DE LA BOURSE;ALL DE LA BOURSE;5;Non;0;En service;2006-10-04 09:41:10;2012-09-12 15:05:04;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0D8;44109#0D8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355175.4 6689089.3 6.8, 355181.8 6689095.6 8.2, 355205 6689122.6 8.6, 355225.4 6689142.4 7.1, 355226.3 6689142.5 7.1)
TRONROUT0000000029475249;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2010-01-08 14:34:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;Sens direct;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355231 6689115.1 6.9, 355225.4 6689121.8 7.2, 355225.1 6689129.2 7.4, 355225.1 6689130.6 6.5, 355226.3 6689142.5 7.1)
TRONROUT0000000029475156;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355226.3 6689142.5 7.1, 355247.4 6689163.6 6.9, 355265 6689174.1 6.7)
TRONROUT0000000029474873;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;10;;10;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355265 6689174.1 6.7, 355295 6689191.8 6.3)
TRONROUT0000000029473877;Route à 1 chaussée;PL DU COMMERCE;PL DU COMMERCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;PL SARAJEVO;PL SARAJEVO;;441092092;441092092;;;;;;;;;;;;;commune;commune;Place du Commerce;Place du Commerce;;;44109_2092;44109_2092;;;;;LINESTRING Z (355173.1 6689159.4 6.5, 355178.2 6689164.5 6.5, 355225.8 6689216.2 7.2, 355225.8 6689216.7 7.2)
TRONROUT0000000029475023;Route à 1 chaussée;PL DU COMMERCE;PL DU COMMERCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;PL SARAJEVO;PL SARAJEVO;;441092092;441092092;;;;;;;;;;;;;commune;commune;Place du Commerce;Place du Commerce;;;44109_2092;44109_2092;;;;;LINESTRING Z (355265 6689174.1 6.7, 355258 6689182.1 6.4, 355225.8 6689216.7 7.2)
TRONROUT0000000029474094;Route à 1 chaussée;R DU PORT AU VIN;R DU PORT AU VIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;8;1;8;44109;44109;;;;441096808;441096808;;;;;;;;;;;;;commune;commune;Rue du Port au Vin;Rue du Port au Vin;;;44109_6808;44109_6808;;;;;LINESTRING Z (355225.8 6689216.7 7.4, 355200 6689224 7.2)
TRONROUT0000000029475068;Route à 1 chaussée;R LA PEROUSE;R LA PEROUSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;13;;1;44109;44109;;;;44109#0CK;44109#0CK;;;;;;;;;;;;;commune;commune;Rue la Pérouse;Rue la Pérouse;;;44109_3p9ugv;44109_3p9ugv;;;;;LINESTRING Z (355255.4 6689252.8 7.4, 355295 6689191.8 6.3)
TRONROUT0000000029474257;Route à 1 chaussée;R DE GORGES;R DE GORGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;5;8;44109;44109;;;;441093768;441093768;;;;;;;;;;;;;commune;commune;Rue de Gorges;Rue de Gorges;;;44109_3768;44109_3768;;;;;LINESTRING Z (355225.8 6689216.7 7.2, 355217.1 6689226.4 8.1, 355197 6689257.6 8.4, 355187.3 6689276.6 8.6)
TRONROUT0000000326872123;Route à 1 chaussée;R DU COUEDIC;R DU COUEDIC;5;Non;0;En service;2013-09-09 18:38:40;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;4;44109;44109;;;;441092228;441092228;;;;;;;;;;;;;commune;commune;Rue du Couédic;Rue du Couédic;;;44109_2228;44109_2228;;;;;LINESTRING Z (355286.8 6689245.1 6.7, 355275.3 6689264.3 7)
TRONROUT0000000029474122;Route à 1 chaussée;R GRETRY;R GRETRY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441093868;441093868;;;;;;;;;;;;;commune;commune;Rue Grétry;Rue Grétry;;;44109_3868;44109_3868;;;;;LINESTRING Z (354996.1 6689175.3 17.1, 354977.9 6689216.5 17.9)
TRONROUT0000000029473875;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;19;20;23;24;44109;44109;;;;441092300;441092300;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (354977.9 6689216.5 17.9, 354924.2 6689194.2 19.6, 354912.7 6689190 19.9)
TRONROUT0000000029473833;Route à 1 chaussée;R SANTEUIL;R SANTEUIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;12;7;14;44109;44109;;;;441097816;441097816;;;;;;;;;;;;;commune;commune;Rue Santeuil;Rue Santeuil;;;44109_7816;44109_7816;;;;;LINESTRING Z (355038 6689192.3 15.1, 355038.3 6689216.7 14.7, 355038.6 6689231 14.5)
TRONROUT0000000228146083;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2010-01-25 16:32:51;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092300;441092300;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (354977.9 6689216.5 17.9, 354980.9 6689217.8 17.7)
TRONROUT0000000029473709;Sentier;PAS POMMERAYE;PAS POMMERAYE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;20;25;16;25;44109;44109;;;;441095813;441095813;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Passage Pommeraye;Passage Pommeraye;;;44109_5813;44109_5813;;;;;LINESTRING Z (355038.6 6689231 14.5, 355088.7 6689204.5 11.9)
TRONROUT0000000029474056;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;20;17;14;15;44109;44109;;;;441092300;441092300;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (354980.9 6689217.8 17.7, 355038.7 6689242.9 14.7)
TRONROUT0000000029474894;Route à 1 chaussée;R MOLIERE;R MOLIERE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;1;2;1;44109;44109;;;;441095704;441095704;;;;;;;;;;;;;commune;commune;Rue Molière;Rue Molière;;;44109_5704;44109_5704;;;;;LINESTRING Z (354921 6689272.9 22.9, 354912.7 6689190 19.9)
TRONROUT0000000029474221;Route à 1 chaussée;R DU PUITS D'ARGENT;R DU PUITS D'ARGENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;10;5B;16;44109;44109;;;;441097052;441097052;;;;;;;;;;;;;commune;commune;Rue du Puits d'Argent;Rue du Puits d'Argent;;;44109_7052;44109_7052;;;;;LINESTRING Z (355091.3 6689230.7 11.2, 355038.6 6689234.6 14.6)
TRONROUT0000000029474642;Route à 1 chaussée;R SANTEUIL;R SANTEUIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097816;441097816;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Santeuil;Rue Santeuil;;;44109_7816;44109_7816;;;;;LINESTRING Z (355038.6 6689231 14.5, 355038.6 6689234.6 14.6)
TRONROUT0000000029475217;Route à 1 chaussée;R SANTEUIL;R SANTEUIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097816;441097816;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Santeuil;Rue Santeuil;;;44109_7816;44109_7816;;;;;LINESTRING Z (355038.6 6689234.6 14.6, 355038.7 6689242.9 14.7)
TRONROUT0000000029473484;Sentier;PAS POMMERAYE;PAS POMMERAYE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095813;441095813;;;;;;;;;;;;;commune;commune;Passage Pommeraye;Passage Pommeraye;;;44109_5813;44109_5813;;;;;LINESTRING Z (355091.3 6689230.7 11.2, 355088.7 6689204.5 11.9)
TRONROUT0000000029474478;Route à 1 chaussée;R DU PUITS D'ARGENT;R DU PUITS D'ARGENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;8;44109;44109;;;;441097052;441097052;;;;;;;;;;;;;commune;commune;Rue du Puits d'Argent;Rue du Puits d'Argent;;;44109_7052;44109_7052;;;;;LINESTRING Z (355125.8 6689221.2 7.5, 355091.3 6689230.7 11.2)
TRONROUT0000000029474107;Route à 1 chaussée;R DE LA FOSSE;R DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;9;4;7;44109;44109;;;;441093236;441093236;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Fosse;Rue de la Fosse;;;44109_3236;44109_3236;;;;;LINESTRING Z (355149.1 6689213.4 6.7, 355157.7 6689243.4 6.8)
TRONROUT0000000029473672;Sentier;R DU PORT AU VIN;R DU PORT AU VIN;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;3;10;5;10;44109;44109;;;;441096808;441096808;;;;;;;;;;;;;commune;commune;Rue du Port au Vin;Rue du Port au Vin;;;44109_6808;44109_6808;;;;;LINESTRING Z (355200 6689224 7.2, 355180.3 6689235.5 6.9, 355157.7 6689243.4 6.8)
TRONROUT0000000029474441;Route à 1 chaussée;R REGNIER;R REGNIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;2;44109;44109;;;;44109#0CX;44109#0CX;;;;;;;;;;;;;commune;commune;Rue Régnier;Rue Régnier;;;44109_7180;44109_7180;;;;;LINESTRING Z (355096.8 6689268 11.2, 355091.3 6689230.7 11.2)
TRONROUT0000000029473794;Route à 1 chaussée;R DE LA FOSSE;R DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;5;2;5;44109;44109;;;;441093236;441093236;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Fosse;Rue de la Fosse;;;44109_3236;44109_3236;;;;;LINESTRING Z (355157.7 6689243.4 6.8, 355162 6689255.7 7.8)
TRONROUT0000000029473899;Route à 1 chaussée;R DE LA FOSSE;R DE LA FOSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;3;44109;44109;;;;441093236;441093236;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Fosse;Rue de la Fosse;;;44109_3236;44109_3236;;;;;LINESTRING Z (355162 6689255.7 7.8, 355169.7 6689276.7 8.5)
TRONROUT0000000029474116;Route à 1 chaussée;R DE GUERANDE;R DE GUERANDE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;9;;44109;44109;;;;441093912;441093912;;;;;;;;;;;;;commune;commune;Rue de Guérande;Rue de Guérande;;;44109_3912;44109_3912;;;;;LINESTRING Z (355162 6689255.7 7.8, 355127.2 6689272.5 9.5, 355123.2 6689279.4 9.5)
TRONROUT0000000029474350;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;5;4;3;44109;44109;;;;441092300;441092300;;;;;;;;;;;;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (355096.8 6689268 11.2, 355121.2 6689278.5 9.6, 355123.2 6689279.4 9.5)
TRONROUT0000000029474976;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;9;;9;44109;44109;;;;441097500;441097500;;;;;;;;;;;;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355169.7 6689276.7 8.5, 355177.6 6689275.6 8.6, 355182.7 6689275.8 8.6, 355187.3 6689276.6 8.6)
TRONROUT0000000029473473;Sentier;PAS DE LA CHATELAINE;PAS DE LA CHATELAINE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;PAS CREBILLON SCRIBE;PAS CREBILLON SCRIBE;;441091771;441091771;;;;;;;;;;;;;commune;commune;Passage de la Châtelaine;Passage de la Châtelaine;;;44109_1771;44109_1771;;;;;LINESTRING Z (354955.8 6689277.5 -1000, 354957.7 6689251.9 -1000, 354965 6689252.8 -1000, 354966.7 6689240.7 -1000, 354970.5 6689240.7 -1000, 354980.9 6689217.8 -1000)
TRONROUT0000000029473892;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;13;6;7;44109;44109;;;;441092300;441092300;;;;;;;;;;;;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (355038.7 6689242.9 14.7, 355096.8 6689268 11.2)
TRONROUT0000000029473786;Route à 1 chaussée;R BOILEAU;R BOILEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;3;2;1;44109;44109;;;;441090912;441090912;;;;;;;;;;;;;commune;commune;Rue Boileau;Rue Boileau;;;44109_0912;44109_0912;;;;;LINESTRING Z (355031 6689287 15.9, 355032.5 6689273 14.7, 355038.7 6689242.9 14.7)
TRONROUT0000000029473953;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;13;10;13;44109;44109;;;;441097856;441097856;;;;;;;;;;;;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354921 6689272.9 22.9, 354943.3 6689275.8 21.5)
TRONROUT0000000029474995;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;11;8B;11;44109;44109;;;;441097856;441097856;;;;;;;;;;;;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354943.3 6689275.8 21.5, 354955.8 6689277.5 19.8)
TRONROUT0000000029475017;Route à 1 chaussée;R SCRIBE;R SCRIBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;9;2;5;44109;44109;;;;441097856;441097856;;;;;;;;;;;;;commune;commune;Rue Scribe;Rue Scribe;;;44109_7856;44109_7856;;;;;LINESTRING Z (354955.8 6689277.5 19.8, 355031 6689287 15.9)
TRONROUT0000000029474999;Route à 1 chaussée;R BOILEAU;R BOILEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090912;441090912;;;;;;;;;;;;;commune;commune;Rue Boileau;Rue Boileau;;;44109_0912;44109_0912;;;;;LINESTRING Z (355030.7 6689290.6 16.4, 355031 6689287 15.9)
TRONROUT0000000029475031;Route à 1 chaussée;R RUBENS;R RUBENS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097504;441097504;;;;;;;;;;;;;commune;commune;Rue Rubens;Rue Rubens;;;44109_7504;44109_7504;;;;;LINESTRING Z (355038.8 6689295.5 16.1, 355030.7 6689290.6 16.4)
TRONROUT0000000029473676;Route à 1 chaussée;R JEAN DE LA FONTAINE;R JEAN DE LA FONTAINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441094444;441094444;;;;;;;;;;;;;commune;commune;Rue Jean de la Fontaine;Rue Jean de la Fontaine;;;44109_4444;44109_4444;;;;;LINESTRING Z (354926 6689328.6 24.4, 354921 6689272.9 22.9)
TRONROUT0000000029473486;Sentier;PAS DES ECOLES;PAS DES ECOLES;6;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;2;;4;44109;44109;;;;44109#0CC;44109#0CC;;;;;;;;;;;;;commune;commune;Passage des Ecoles;Passage des Ecoles;;;44109_2737;44109_2737;;;;;LINESTRING Z (354943.3 6689275.8 21.5, 354942.3 6689280.3 25.4, 354939.4 6689292.5 26.8, 354938.1 6689298.2 27.5, 354935.9 6689304.4 24.6, 354926 6689328.6 24.4)
TRONROUT0000000326872122;Sentier;SQ FLEURIOT DE L'ANGLE;SQ FLEURIOT DE L'ANGLE;6;Non;0;En service;2013-09-09 18:38:40;2015-03-12 20:24:00;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441093152;441093152;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355255.4 6689252.8 7.4, 355275.3 6689264.3 7)
TRONROUT0000000326872124;Route à 1 chaussée;R LA PEROUSE;R LA PEROUSE;5;Non;0;En service;2013-09-09 18:38:40;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;21;;15;44109;44109;;;;44109#0CK;44109#0CK;;;;;;;;;;;;;commune;commune;Rue la Pérouse;Rue la Pérouse;;;44109_3p9ugv;44109_3p9ugv;;;;;LINESTRING Z (355242.1 6689273.3 7.7, 355255.4 6689252.8 7.4)
TRONROUT0000000301054080;Route à 1 chaussée;SQ LA PEROUSE;SQ LA PEROUSE;5;Non;0;En service;2012-05-04 16:23:22;2015-03-12 20:24:00;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0B5;44109#0B5;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355242.1 6689273.3 7.7, 355224 6689265.1 8)
TRONROUT0000000029473905;Route à 1 chaussée;R DU COUEDIC;R DU COUEDIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;4;5;6;44109;44109;;;;441092228;441092228;;;;;;;;;;;;;commune;commune;Rue du Couédic;Rue du Couédic;;;44109_2228;44109_2228;;;;;LINESTRING Z (355275.3 6689264.3 7, 355250.5 6689306 7.7)
TRONROUT0000000029474747;Route à 1 chaussée;R LA PEROUSE;R LA PEROUSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;29;;27;44109;44109;;;;44109#0CK;44109#0CK;;;;;;;;;;;;;commune;commune;Rue la Pérouse;Rue la Pérouse;;;44109_3p9ugv;44109_3p9ugv;;;;;LINESTRING Z (355226.8 6689297.1 8, 355242.1 6689273.3 7.7)
TRONROUT0000000029474328;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;10;;11;44109;44109;;;;441097500;441097500;;;;;;;;;;;;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355187.3 6689276.6 8.6, 355197.5 6689280.4 8.6, 355212.9 6689288.4 8.6, 355226.8 6689297.1 8)
TRONROUT0000000029474934;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355250.5 6689306 7.7, 355238.5 6689299.6 7.7, 355226.8 6689297.1 8)
TRONROUT0000000029474451;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;13;18;13;20;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355279.3 6689318.9 7.6, 355250.5 6689306 7.7)
TRONROUT0000000029473599;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;1;;44109;44109;;;;441097500;441097500;;;;;;;;;;;;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355205 6689344.8 8.4, 355213.9 6689323.9 8.4, 355221.8 6689305.1 8.4, 355226.8 6689297.1 8)
TRONROUT0000000029473649;Route à 1 chaussée;R DU COUEDIC;R DU COUEDIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;10;9;10;44109;44109;;;;441092228;441092228;;;;;;;;;;;;;commune;commune;Rue du Couédic;Rue du Couédic;;;44109_2228;44109_2228;;;;;LINESTRING Z (355250.5 6689306 7.7, 355228.6 6689347.2 7.7, 355226.9 6689352.6 8.1, 355226.3 6689355 8.2)
TRONROUT0000000029474482;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;7;;8;44109;44109;;;;441097500;441097500;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355152.9 6689292.2 9, 355156.9 6689286.4 9.1, 355160.9 6689282.3 9, 355165.9 6689278.2 8.6, 355169.7 6689276.7 8.5)
TRONROUT0000000295266736;Route à 1 chaussée;R CREBILLON;R CREBILLON;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441092300;441092300;;;;;;;;;;;;;commune;commune;Rue Crébillon;Rue Crébillon;;;44109_2300;44109_2300;;;;;LINESTRING Z (355123.2 6689279.4 9.5, 355152.9 6689292.2 9)
TRONROUT0000000029474341;Route à 1 chaussée;R CONTRESCARPE;R CONTRESCARPE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;7;4;44109;44109;;;;441092124;441092124;;;;;;;;;;;;;commune;commune;Rue Contrescarpe;Rue Contrescarpe;;;44109_2124;44109_2124;;;;;LINESTRING Z (355123.2 6689279.4 9.5, 355120 6689327.3 12.6)
TRONROUT0000000295265262;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097500;441097500;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355152.3 6689315.3 8.5, 355150.6 6689308.6 8.6, 355150.4 6689300.3 8.6, 355151.6 6689294.5 8.6, 355152.9 6689292.2 9)
TRONROUT0000000029474473;Route à 1 chaussée;R RUBENS;R RUBENS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;4;15;12;44109;44109;;;;441097504;441097504;;;;;;;;;;;;;commune;commune;Rue Rubens;Rue Rubens;;;44109_7504;44109_7504;;;;;LINESTRING Z (355120 6689327.3 12.6, 355084.9 6689318 14.5, 355062.7 6689310 15.1, 355038.8 6689295.5 16.1)
TRONROUT0000000295265261;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441097500;441097500;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355162.7 6689327.3 8.7, 355156.8 6689321.6 8.7, 355153.3 6689317.2 8.7, 355152.3 6689315.3 8.6)
TRONROUT0000000029474485;Route à 1 chaussée;PL ROYALE;PL ROYALE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;;3;;44109;44109;;;;441097500;441097500;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Royale;Place Royale;;;44109_7500;44109_7500;;;;;LINESTRING Z (355162.7 6689327.3 8.7, 355182.4 6689336.3 8.7, 355205 6689344.8 8.4)
TRONROUT0000000029473755;Route à 1 chaussée;R SAINT-JULIEN;R SAINT-JULIEN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441097664;441097664;;;;;;;;;;;;;commune;commune;Rue Saint Julien;Rue Saint Julien;;;44109_7664;44109_7664;;;;;LINESTRING Z (355162.7 6689327.3 8.7, 355152.1 6689353.8 8.9)
TRONROUT0000000029474453;Route à 1 chaussée;R CONTRESCARPE;R CONTRESCARPE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;9;4;7;44109;44109;;;;441092124;441092124;;;;;;;;;;;;;commune;commune;Rue Contrescarpe;Rue Contrescarpe;;;44109_2124;44109_2124;;;;;LINESTRING Z (355118.1 6689358.8 12.9, 355120 6689327.3 12.6)
TRONROUT0000000119652106;Route à 1 chaussée;R DES VIEILLES DOUVES;R DES VIEILLES DOUVES;5;Non;0;En service;2008-03-19 10:56:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;13;5;1;44109;44109;;;;441098440;441098440;;;;;;;;;;;;;commune;commune;Rue des Vieilles Douves;Rue des Vieilles Douves;;;44109_8440;44109_8440;;;;;LINESTRING Z (355143.5 6689374.6 8.6, 355138.6 6689362.7 8.7, 355136.3 6689350.2 8.7, 355136.7 6689338 8.7, 355138.2 6689325.1 8.7, 355140 6689322.9 8.7, 355150.4 6689315.9 8.7, 355152.3 6689315.3 8.5)
TRONROUT0000000029473883;Route à 1 chaussée;R BOILEAU;R BOILEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;7;4;5;44109;44109;;;;441090912;441090912;;;;;;;;;;;;;commune;commune;Rue Boileau;Rue Boileau;;;44109_0912;44109_0912;;;;;LINESTRING Z (355024 6689352.2 16.7, 355030.7 6689290.6 16.4)
TRONROUT0000000029474231;Route à 1 chaussée;R JEAN DE LA FONTAINE;R JEAN DE LA FONTAINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;6;3;8;44109;44109;;;;441094444;441094444;;;;;;;;;;;;;commune;commune;Rue Jean de la Fontaine;Rue Jean de la Fontaine;;;44109_4444;44109_4444;;;;;LINESTRING Z (354926 6689328.6 24.4, 354925.2 6689339.1 24.3, 354923.9 6689345.6 24.3, 354919.8 6689350.8 24.3)
TRONROUT0000000029474963;Rond-point;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (354919.8 6689350.8 24.3, 354921.8 6689352.8 24.2, 354922.7 6689356.3 24.2, 354922.3 6689357.8 24.2)
TRONROUT0000000029474924;Rond-point;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (354909.5 6689359.5 24.6, 354908.7 6689356.4 24.5, 354909.6 6689352.9 24.4, 354912.2 6689350.3 24.4, 354915.6 6689349.3 24.3, 354919.1 6689350.2 24.3, 354919.8 6689350.8 24.3)
TRONROUT0000000029474383;Rond-point;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;17;;17;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (354922.3 6689357.8 24.2, 354921.8 6689359.8 24.2, 354919.2 6689362.4 24.3, 354915.8 6689363.3 24.4, 354912.2 6689362.5 24.5, 354909.6 6689359.9 24.6, 354909.5 6689359.5 24.6)
TRONROUT0000000029473799;Route à 1 chaussée;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;15;;13;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (354922.3 6689357.8 24.2, 354960 6689366.6 20.7)
TRONROUT0000000321061329;Route à 1 chaussée;R BOILEAU;R BOILEAU;5;Non;0;En service;2013-04-16 17:07:07;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090912;441090912;;;;;;;;;;;;;commune;commune;Rue Boileau;Rue Boileau;;;44109_0912;44109_0912;;;;;LINESTRING Z (355024 6689352.2 16.7, 355020.6 6689373.4 16.7)
TRONROUT0000000029474187;Route à 1 chaussée;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;8;13;8;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (355020.6 6689373.4 16.7, 354960.7 6689362.9 20.7, 354960 6689366.6 20.7)
TRONROUT0000000029474185;Route à 1 chaussée;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;4;7;6;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (355089.2 6689383.2 14, 355084.7 6689383.4 14, 355020.6 6689373.4 16.7)
TRONROUT0000000029473701;Route à 1 chaussée;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;17;12;21;16;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (354950 6689421.2 21.4, 354960 6689366.6 20.7)
TRONROUT0000000029473465;Sentier;PAS D'ORLEANS;PAS D'ORLEANS;6;Non;0;En service;2006-10-04 09:41:10;2012-09-27 15:32:50;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;18;;16;44109;44109;;;;441096051;441096051;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355279.3 6689318.9 -1000, 355266.9 6689350.1 -1000)
TRONROUT0000000029474258;Route à 1 chaussée;R COMMANDANT BOULAY;R COMMANDANT BOULAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C1;44109#0C1;;;;;;;;;;;;;commune;commune;Rue Commandant Boulay;Rue Commandant Boulay;;;44109_2044;44109_2044;;;;;LINESTRING Z (355205 6689344.8 8.4, 355209.7 6689347.4 8.4, 355226.3 6689355 8.2)
TRONROUT0000000029474092;Route à 1 chaussée;PL FELIX FOURNIER;PL FELIX FOURNIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;3;7;2;44109;44109;;;;441093068;441093068;;;;;;;;;;;;;commune;commune;Place Félix Fournier;Place Félix Fournier;;;44109_3068;44109_3068;;;;;LINESTRING Z (355226.3 6689355 8.2, 355227 6689354.9 7.9, 355266.9 6689350.1 7.8)
TRONROUT0000000029473713;Route à 1 chaussée;R DE L'ARCHE SECHE;R DE L'ARCHE SECHE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;2;;44109;44109;;;;441090348;441090348;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de l'Arche Sèche;Rue de l'Arche Sèche;;;44109_0348;44109_0348;;;;;LINESTRING Z (355200.5 6689373.1 8.8, 355202 6689363 8.7, 355204.8 6689351.1 8.3, 355205 6689344.8 8.4)
TRONROUT0000000029474216;Route à 1 chaussée;R SAINT-NICOLAS;R SAINT-NICOLAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097704;441097704;;;;;;;;;;;;;commune;commune;Rue Saint Nicolas;Rue Saint Nicolas;;;44109_7704;44109_7704;;;;;LINESTRING Z (355305.2 6689371.7 7, 355301.8 6689365.9 7.3, 355291 6689357.1 7.9, 355284.3 6689352.9 7.9, 355278.6 6689350.6 7.9, 355269.9 6689350.3 7.7, 355266.9 6689350.1 7.8)
TRONROUT0000000029475266;Route à 1 chaussée;R DUVOISIN;R DUVOISIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;5;44109;44109;;;;441092658;441092658;;;;;;;;;;;;;commune;commune;Rue Duvoisin;Rue Duvoisin;;;44109_2658;44109_2658;;;;;LINESTRING Z (355224.5 6689383.4 9.1, 355224.2 6689373.6 8.8, 355224.7 6689365.9 8.5, 355225.1 6689360 8.6, 355226.3 6689355 8.2)
TRONROUT0000000029474826;Route à 1 chaussée;R VAUBAN;R VAUBAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098308;441098308;;;;;;;;;;;;;commune;commune;Rue Vauban;Rue Vauban;;;44109_8308;44109_8308;;;;;LINESTRING Z (355200.5 6689373.1 8.8, 355197.6 6689373.1 8.8, 355192.7 6689371.8 8.9)
TRONROUT0000002007790876;Escalier;R DUVOISIN;R DUVOISIN;6;Non;0;En service;2017-12-19 17:58:08;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092658;441092658;;;;;;;;;;;;;commune;commune;Rue Duvoisin;Rue Duvoisin;;;44109_2658;44109_2658;;;;;LINESTRING Z (355224.5 6689389.8 9.4, 355224.5 6689383.4 9.1)
TRONROUT0000000029474833;Route à 1 chaussée;R AFFRE;R AFFRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441090045;441090045;;;;;;;;;;;;;commune;commune;Rue Affre;Rue Affre;;;44109_0045;44109_0045;;;;;LINESTRING Z (355266.1 6689424.1 7.6, 355264.6 6689368.9 8.3, 355266.9 6689350.1 7.8)
TRONROUT0000000029474501;Route à 1 chaussée;R DE L'ECHELLE;R DE L'ECHELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;3;44109;44109;;;;441092672;441092672;;;;;;;;;;;;;commune;commune;Rue de l'Echelle;Rue de l'Echelle;;;44109_2672;44109_2672;;;;;LINESTRING Z (355176.3 6689410.3 9.3, 355192.7 6689371.8 8.9)
TRONROUT0000000029478539;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:15:30;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354345.3 6689169.6 16.8, 354323.5 6689165.3 15.5, 354316.3 6689164.1 14.6)
TRONROUT0000000029478321;Rond-point;PL BEAUMANOIR;PL BEAUMANOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441090648;441090648;;;;;;;;;;;;;commune;commune;Place Beaumanoir;Place Beaumanoir;;;44109_0648;44109_0648;;;;;LINESTRING Z (354194.1 6689159.1 7.2, 354192.8 6689173.6 7.2, 354191.8 6689177.1 7.2, 354189 6689180.6 7.2, 354186.9 6689181.2 7.2, 354181.5 6689181.2 7.2)
TRONROUT0000000329622521;Escalier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354352.1 6689170.9 -1000, 354345.3 6689169.6 -1000)
TRONROUT0000000029478517;Rond-point;PL BEAUMANOIR;PL BEAUMANOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090648;441090648;;;;;;;;;;;;;commune;commune;Place Beaumanoir;Place Beaumanoir;;;44109_0648;44109_0648;;;;;LINESTRING Z (354181.5 6689181.2 7.2, 354178.2 6689180.9 7.1, 354175.1 6689179.3 6.9, 354174.1 6689178 7, 354173.9 6689176.1 7.1)
TRONROUT0000000029478212;Route à 1 chaussée;R ALFRED RIOM;R ALFRED RIOM;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;5;2;1;44109;44109;;;;441090140;441090140;;;;;;;;;;;;;commune;commune;Rue Alfred Riom;Rue Alfred Riom;;;44109_0140;44109_0140;;;;;LINESTRING Z (354126.6 6689219.5 6.6, 354173.9 6689176.1 7.1)
TRONROUT0000002004805877;Route à 1 chaussée;ALL DE L'ANCIENNE USINE ELECTRIQUE;ALL DE L'ANCIENNE USINE ELECTRIQUE;5;Non;0;En service;2017-07-26 18:16:17;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;44109#0R6;44109#0R6;;;;;;;;;;;;;commune;commune;Allée de l'Ancienne Usine Electrique;Allée de l'Ancienne Usine Electrique;;;44109_0257;44109_0257;;;;;LINESTRING Z (354244.2 6689162.6 -1000, 354239.5 6689227.7 -1000, 354238 6689237.5 -1000)
TRONROUT0000000329622522;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2013-11-15 09:02:56;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;21;;25;;44109;44109;;;;441094760;441094760;;;;;;;;;;;;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354181.5 6689181.2 7.2, 354172.7 6689226.6 8.3)
TRONROUT0000000329622520;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354323 6689237.5 -1000, 354323.3 6689207.6 -1000, 354351.2 6689209 -1000, 354352.1 6689170.9 -1000)
TRONROUT0000002221646387;Sentier;;;6;Non;0;En service;2020-12-07 10:51:53;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354172.7 6689226.6 -1000, 354215.8 6689233.5 -1000)
TRONROUT0000002221646388;Escalier;;;6;Non;0;En service;2020-12-07 10:51:53;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354215.8 6689233.5 -1000, 354230.5 6689236.1 -1000, 354238 6689237.5 -1000)
TRONROUT0000000029478249;Route à 1 chaussée;R FABERT;R FABERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;;5;;44109;44109;;;;441093000;441093000;;;;;;;;;;;;;commune;commune;Rue Fabert;Rue Fabert;;;44109_3000;44109_3000;;;;;LINESTRING Z (354082.4 6689176.6 7.3, 354099.2 6689144.2 7.2)
TRONROUT0000000029478167;Route à 1 chaussée;R GUICHEN;R GUICHEN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;8;;8;44109;44109;;;;441093936;441093936;;;;;;;;;;;;;commune;commune;Rue Guichen;Rue Guichen;;;44109_3936;44109_3936;;;;;LINESTRING Z (354082.4 6689176.6 7.3, 354059.8 6689154.6 9.7)
TRONROUT0000000029477918;Route à 1 chaussée;R LAMOTTE PICQUET;R LAMOTTE PICQUET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;4;29;16;44109;44109;;;;441094761;441094761;;;;;;;;;;;;;commune;commune;Rue La Motte-Picquet;Rue La Motte-Picquet;;;44109_4761;44109_4761;;;;;LINESTRING Z (353908.7 6689234.2 12.5, 354059.8 6689154.6 9.7)
TRONROUT0000000029478704;Route à 1 chaussée;R GUICHEN;R GUICHEN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;6;7;8;44109;44109;;;;441093936;441093936;;;;;;;;;;;;;commune;commune;Rue Guichen;Rue Guichen;;;44109_3936;44109_3936;;;;;LINESTRING Z (354126.6 6689219.5 6.6, 354082.4 6689176.6 7.3)
TRONROUT0000000029478484;Route à 1 chaussée;BD PAUL LANGEVIN;BD PAUL LANGEVIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;11;24;11;28;44109;44109;;;;441096244;441096244;;;;;;;;;;;;;commune;commune;Boulevard Paul Langevin;Boulevard Paul Langevin;;;44109_6244;44109_6244;;;;;LINESTRING Z (353908.7 6689234.2 12.5, 353892.0022898072 6689200.435569444 13.422525425023565)
TRONROUT0000000029477961;Route à 1 chaussée;R ALFRED RIOM;R ALFRED RIOM;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;40;43;10;15;44109;44109;;;;441090140;441090140;;;;;;;;;;;;;commune;commune;Rue Alfred Riom;Rue Alfred Riom;;;44109_0140;44109_0140;;;;;LINESTRING Z (353997.6 6689345.4 9.9, 354046.4 6689298.4 7.6, 354126.6 6689219.5 6.6)
TRONROUT0000000029478008;Route à 1 chaussée;BD PAUL LANGEVIN;BD PAUL LANGEVIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;2;9;22;44109;44109;;;;441096244;441096244;;;;;;;;;;;;;commune;commune;Boulevard Paul Langevin;Boulevard Paul Langevin;;;44109_6244;44109_6244;;;;;LINESTRING Z (353958.7 6689340.5 10.6, 353908.7 6689234.2 12.5)
TRONROUT0000000029477889;Route à 1 chaussée;R DE LA VILLE EN BOIS;R DE LA VILLE EN BOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;6;19;24;44109;44109;;;;441098520;441098520;;;;;;;;;;;;;commune;commune;Rue de la Ville en Bois;Rue de la Ville en Bois;;;44109_8520;44109_8520;;;;;LINESTRING Z (353913.3 6689357.9 12.9, 353896.4 6689331.7 14.7, 353892.0022898072 6689328.08874163 15.053100818396262)
TRONROUT0000000029478461;Rond-point;PL CANCLAUX;PL CANCLAUX;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;11;;12;44109;44109;;;;441091392;441091392;;;;;;;;;;;;;commune;commune;Place Canclaux;Place Canclaux;;;44109_1392;44109_1392;;;;;LINESTRING Z (353958.7 6689340.5 10.6, 353969.9 6689337.4 10.2, 353976.4 6689336.9 10.1, 353982 6689337.4 10, 353987.6 6689339 10, 353992.9 6689341.5 9.9, 353997.6 6689345.4 9.9)
TRONROUT0000000029478299;Rond-point;PL CANCLAUX;PL CANCLAUX;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;8;;10;44109;44109;;;;441091392;441091392;;;;;;;;;;;;;commune;commune;Place Canclaux;Place Canclaux;;;44109_1392;44109_1392;;;;;LINESTRING Z (353941.8 6689380.8 11.1, 353941 6689374.4 11.2, 353942 6689367.9 10.8, 353945 6689356.9 10.6, 353947.8 6689351.5 10.6, 353950.8 6689347.1 10.6, 353954.5 6689343.2 10.6, 353958.7 6689340.5 10.6)
TRONROUT0000002011476024;Route à 1 chaussée;IMP DE LA ROSIERE D'ARTOIS;IMP DE LA ROSIERE D'ARTOIS;5;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;5;4;1;44109;44109;;;;441097472;441097472;;;;;;;;;;;;;commune;commune;Impasse de la Rosière d'Artois;Impasse de la Rosière d'Artois;;;44109_7472;44109_7472;;;;;LINESTRING Z (354445.7 6689157.3 25.8, 354491.8 6689163.9 26.3, 354511.6 6689166.2 26.3, 354519.2 6689165.1 26.3)
TRONROUT0000000029477856;Rond-point;R HUCHETTE;R HUCHETTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;9;;5;44109;44109;;;;441094253;441094253;;;;;;;;;;;;;commune;commune;Rue Huchette;Rue Huchette;;;44109_4253;44109_4253;;;;;LINESTRING Z (354373.4 6689237.8 21.1, 354371.7 6689232.5 21.1, 354371.6 6689227.8 21.1, 354373.2 6689222.9 21.1, 354376 6689218.4 21.3, 354379.7 6689215.3 21.3, 354384.6 6689213.6 21.3, 354389.1 6689212.8 21.4, 354393.7 6689213.2 21.5, 354397.5 6689215.4 21.5, 354401.7 6689219.3 21.5, 354404.1 6689223.6 21.5, 354405.2 6689229 21.5, 354405.4 6689233.6 21.5, 354404.5 6689238.1 21.5, 354402.6 6689241.1 21.5, 354398.7 6689244.9 21.6, 354393.7 6689247.3 22.3, 354388.1 6689248.1 21.6)
TRONROUT0000002004822287;Rond-point;R HUCHETTE;R HUCHETTE;5;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;6;;6;44109;44109;;;;441094253;441094253;;;;;;;;;;;;;commune;commune;Rue Huchette;Rue Huchette;;;44109_4253;44109_4253;;;;;LINESTRING Z (354388.1 6689248.1 21.6, 354382.5 6689247.2 21.6, 354379.2 6689245 21.4, 354375.1 6689241.1 21.3, 354373.4 6689237.8 21.1)
TRONROUT0000000029478536;Route à 1 chaussée;R HUCHETTE;R HUCHETTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;5;2;44109;44109;;;;441094253;441094253;;;;;;;;;;;;;commune;commune;Rue Huchette;Rue Huchette;;;44109_4253;44109_4253;;;;;LINESTRING Z (354386.3 6689333.1 23.5, 354388.1 6689248.1 21.6)
TRONROUT0000000029477886;Route à 1 chaussée;R DE LA ROSIERE D'ARTOIS;R DE LA ROSIERE D'ARTOIS;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;33;26;35B;28;44109;44109;;;;441097476;441097476;;;;;;;;;;;;;commune;commune;Rue de la Rosière d'Artois;Rue de la Rosière d'Artois;;;44109_7476;44109_7476;;;;;LINESTRING Z (354510.7 6689290.9 28.7, 354506.6 6689357.7 27.9)
TRONROUT0000000029478312;Route à 1 chaussée;R HUCHETTE;R HUCHETTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;5;2;44109;44109;;;;441094253;441094253;;;;;;;;;;;;;commune;commune;Rue Huchette;Rue Huchette;;;44109_4253;44109_4253;;;;;LINESTRING Z (354382 6689345.5 21.4, 354386.3 6689333.1 23.5)
TRONROUT0000000029478568;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;8;;10;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354413 6689349.2 24.2, 354403.9 6689348.4 23.9, 354382 6689345.5 22.4)
TRONROUT0000000029478633;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;6;5B;4;3;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354413 6689349.2 24.2, 354465.6 6689354 26.1)
TRONROUT0000000029478682;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354465.6 6689354 26.1, 354506.6 6689357.7 27.9)
TRONROUT0000000029478286;Route à 1 chaussée;PL DE L'EDIT DE NANTES;PL DE L'EDIT DE NANTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441092712;441092712;;;;;;;;;;;;;commune;commune;Place de l'Edit de Nantes;Place de l'Edit de Nantes;;;44109_2712;44109_2712;;;;;LINESTRING Z (354506.6 6689357.7 27.9, 354504.7 6689375 27.9, 354504.6 6689375.6 27.9)
TRONROUT0000002004822285;Sentier;;;6;Non;0;En service;2017-07-28 17:55:21;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354341.6 6689237 -1000, 354323 6689237.5 -1000)
TRONROUT0000002004822286;Route à 1 chaussée;R HUCHETTE;R HUCHETTE;5;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094253;441094253;;;;;;;;;;;;;commune;commune;Rue Huchette;Rue Huchette;;;44109_4253;44109_4253;;;;;LINESTRING Z (354373.4 6689237.8 -1000, 354341.6 6689237 -1000)
TRONROUT0000002004805876;Sentier;;;6;Non;0;En service;2017-07-26 18:16:17;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354238 6689237.5 -1000, 354282 6689239.1 -1000, 354323 6689237.5 -1000)
TRONROUT0000000029477976;Route à 1 chaussée;R LAMORICIERE;R LAMORICIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;27;16;43;22;44109;44109;;;;441094760;441094760;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Lamoricière;Rue Lamoricière;;;44109_4760;44109_4760;;;;;LINESTRING Z (354172.7 6689226.6 8.3, 354165.6 6689263.3 9.3, 354146.8 6689367.6 12.7)
TRONROUT0000000029478405;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;17;;11;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354237.1 6689348.8 17.5, 354237.7 6689341.6 17.7, 354238.7 6689336.5 17.8, 354241.6 6689332.7 17.7, 354261.2 6689330.1 18.2, 354286.4 6689329.9 19.4, 354362 6689331.1 22.2, 354383.9 6689332.7 23.5, 354386.3 6689333.1 23.5)
TRONROUT0000000029478386;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;26;;8;;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354237.1 6689348.8 17.5, 354263.1 6689343.9 18.5, 354303.5 6689343.6 19.9, 354339.3 6689343.4 21.2, 354368.4 6689345 22.4, 354382 6689345.5 22.4)
TRONROUT0000000029478421;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;19;26;21;32;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354237.1 6689348.8 17.5, 354178.8 6689361.2 13.6)
TRONROUT0000000029478352;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;23;34;23;36;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354178.8 6689361.2 13.6, 354146.8 6689367.6 12.7)
TRONROUT0000000029478657;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354178 6689416.1 12.1, 354178.8 6689361.2 13.6)
TRONROUT0000000029477967;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;25;34;27;34;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354145.7 6689441.4 8.9, 354158.1 6689458.4 10.1)
TRONROUT0000000029478277;Route à 1 chaussée;R DE LA VILLE EN BOIS;R DE LA VILLE EN BOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;4;5;4;44109;44109;;;;441098520;441098520;;;;;;;;;;;;;commune;commune;Rue de la Ville en Bois;Rue de la Ville en Bois;;;44109_8520;44109_8520;;;;;LINESTRING Z (353927.9 6689377.4 11.5, 353913.3 6689357.9 12.9)
TRONROUT0000000029478436;Rond-point;PL CANCLAUX;PL CANCLAUX;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;13;;14;44109;44109;;;;441091392;441091392;;;;;;;;;;;;;commune;commune;Place Canclaux;Place Canclaux;;;44109_1392;44109_1392;;;;;LINESTRING Z (353997.6 6689345.4 9.9, 354000.9 6689349.2 9.9, 354003.8 6689354.7 9.9, 354005.7 6689360 9.9, 354006.8 6689365.1 10, 354007 6689371.6 10, 354006 6689378.4 10.2, 354003.8 6689384.7 10.4, 354000.1 6689390.2 10.3, 353994.2 6689395.3 10.3, 353988 6689398.6 10.6)
TRONROUT0000000029478619;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;25B;38;25B;38;44109;44109;;;;441093720;441093720;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354146.8 6689367.6 12.7, 354100.9 6689377 11.3)
TRONROUT0000000029477995;Route à 1 chaussée;R DE LA VILLE EN BOIS;R DE LA VILLE EN BOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441098520;441098520;;;;;;;;;;;;;commune;commune;Rue de la Ville en Bois;Rue de la Ville en Bois;;;44109_8520;44109_8520;;;;;LINESTRING Z (353941.8 6689380.8 11.1, 353936 6689381.1 11.3, 353932.1 6689380.4 11.2, 353928.7 6689378.5 11.4, 353927.9 6689377.4 11.5)
TRONROUT0000000029478706;Route à 1 chaussée;AV MOZART;AV MOZART;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;25;26;44109;44109;;;;441095876;441095876;;;;;;;;;;;;;commune;commune;Avenue Mozart;Avenue Mozart;;;44109_5876;44109_5876;;;;;LINESTRING Z (353913.3 6689357.9 12.9, 353892.0022898072 6689369.22497288 14.400136333020301)
TRONROUT0000000029478460;Route à 1 chaussée;R DE GIGANT;R DE GIGANT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;25;40;39;48;44109;44109;;;;441093720;441093720;;;;;;;;;;;;;commune;commune;Rue de Gigant;Rue de Gigant;;;44109_3720;44109_3720;;;;;LINESTRING Z (354100.9 6689377 11.3, 354086.4 6689379.3 10.8, 354014.7 6689394.3 10.2, 353988 6689398.6 10.6)
TRONROUT0000000029477998;Rond-point;PL CANCLAUX;PL CANCLAUX;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;4;;7;44109;44109;;;;441091392;441091392;;;;;;;;;;;;;commune;commune;Place Canclaux;Place Canclaux;;;44109_1392;44109_1392;;;;;LINESTRING Z (353969 6689400.2 10.8, 353961.8 6689398.5 10.5, 353953.4 6689394.7 10.7, 353947.8 6689390.6 10.9, 353944.3 6689386.5 10.9, 353941.8 6689380.8 11.1)
TRONROUT0000000029478642;Route à 1 chaussée;R RICHEUX;R RICHEUX;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;5;2;1;44109;44109;;;;441097312;441097312;;;;;;;;;;;;;commune;commune;Rue Richeux;Rue Richeux;;;44109_7312;44109_7312;;;;;LINESTRING Z (353927.9 6689377.4 11.5, 353892.0022898072 6689399.609710906 14.802163252161728)
TRONROUT0000000029478215;Rond-point;PL CANCLAUX;PL CANCLAUX;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;1;;3;44109;44109;;;;441091392;441091392;;;;;;;;;;;;;commune;commune;Place Canclaux;Place Canclaux;;;44109_1392;44109_1392;;;;;LINESTRING Z (353988 6689398.6 10.6, 353982.2 6689400.3 10.5, 353975 6689401 10.5, 353969 6689400.2 10.8)
TRONROUT0000000029478301;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;27;36;35;44;44109;44109;;;;441095387;441095387;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354100.9 6689377 11.3, 354114.8 6689400.5 9.9, 354145.7 6689441.4 8.9)
TRONROUT0000000029478521;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;1;2;1;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (353960 6689451.9 12.2, 353969 6689400.2 10.8)
TRONROUT0000000029477914;Route à 1 chaussée;IMP DESGREES DU LOU;IMP DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 19:59:35;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#02P;44109#02P;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354006.6 6689490.9 10, 354019.7 6689469.8 10, 354022.9 6689462.7 9.9, 353993.6 6689456.8 10.2, 353960 6689451.9 12.2)
TRONROUT0000000029478101;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;14;1;8B;1;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (353951.7 6689498.1 13, 353954.3 6689480.6 12.8, 353960 6689451.9 12.2)
TRONROUT0000000029478029;Route à 1 chaussée;AV EMILE BOISSIER;AV EMILE BOISSIER;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;11B;8;44109;44109;;;;441092766;441092766;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;commune;commune;Avenue Emile Boissier;Avenue Emile Boissier;;;44109_2766;44109_2766;;;;;LINESTRING Z (354145.7 6689441.4 8.9, 354142.1 6689447 8.9, 354092.4 6689525.3 7.3, 354089.1 6689531.2 7.3, 354082.8 6689542.8 7.3)
TRONROUT0000000029478231;Route à 1 chaussée;R LAMARTINE;R LAMARTINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;4;15;18;44109;44109;;;;441094752;441094752;;;;;;;;;;;;;commune;commune;Rue Lamartine;Rue Lamartine;;;44109_4752;44109_4752;;;;;LINESTRING Z (353951.7 6689498.1 13, 353933.4 6689505.5 14, 353892.0022898072 6689525.776429482 16.18253234009219)
TRONROUT0000000312797818;Sentier;;;6;Non;0;En service;2012-09-10 12:40:22;2022-05-17 20:06:43;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354023.8 6689537.7 6.2, 354040.4 6689527.8 6.4, 354056 6689521.3 6.6, 354064.3 6689520.6 6.8, 354072.3 6689525.1 7, 354082.8 6689542.8 7.3)
TRONROUT0000000029478302;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;30;13;16;3;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (353932.4 6689600.8 11.9, 353951.7 6689498.1 13)
TRONROUT0000000029478341;Route à 1 chaussée;AV EMILE BOISSIER;AV EMILE BOISSIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;29;40;36B;37;44109;44109;;;;441092766;441092766;;;;;;;;;;;;;commune;commune;Avenue Emile Boissier;Avenue Emile Boissier;;;44109_2766;44109_2766;;;;;LINESTRING Z (354082.8 6689542.8 7.3, 354073.8 6689551 7.1, 354052.6 6689570.1 6.6, 354015.2 6689607.3 6.2)
TRONROUT0000000029478681;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-17 20:06:43;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354055.6 6689656.2 5.9, 354048.3 6689646.9 6.2, 354044.3 6689641.8 6.2, 354038.1 6689636.4 6.2, 354018 6689626.2 6.2, 354011.5 6689621.2 6.2, 354009.3 6689618.4 6.2, 354008 6689615.5 6.2, 354005.4 6689607.2 6.2, 354001.2 6689582.2 6.2, 354000.8 6689572.9 6.2, 354003 6689568.1 6.2, 354005.9 6689558.4 6.2, 354010.4 6689551.1 5.9, 354015.3 6689545.6 6.2, 354023.8 6689537.7 6.2)
TRONROUT0000000029477925;Route à 1 chaussée;AV EMILE BOISSIER;AV EMILE BOISSIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;13;10;27;26;44109;44109;;;;441092766;441092766;;;;;;;;;;;;;commune;commune;Avenue Emile Boissier;Avenue Emile Boissier;;;44109_2766;44109_2766;;;;;LINESTRING Z (354082.8 6689542.8 7.3, 354090.7 6689556.4 8, 354095.9 6689562.7 8.5, 354158.2 6689632.6 11.9, 354173.9 6689651.6 13, 354174.5 6689652.1 13.1)
TRONROUT0000000029478551;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354465.6 6689354 26.1, 354463.3 6689378.8 27.9, 354462.6 6689379.7 27.7)
TRONROUT0000000029478636;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354462.6 6689379.7 27.7, 354457.2 6689386.1 27.8, 354456 6689389 27.8, 354456 6689393.9 27.9, 354457.1 6689396.3 28, 354460.1 6689399.8 28.1, 354462.3 6689401.1 28.1, 354466 6689401.4 28.1, 354470.5 6689400 28.1, 354475.5 6689396.3 28.2, 354476.7 6689394.4 27.9, 354477.1 6689392.2 27.9, 354475.3 6689387.5 27.9, 354470.7 6689382.1 27.8, 354468.3 6689380.6 27.8, 354462.6 6689379.7 27.7)
TRONROUT0000000029478205;Route à 1 chaussée;R COLBERT;R COLBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;19;2;44109;44109;;;;441092004;441092004;;;;;;;;;;;;;commune;commune;Rue Colbert;Rue Colbert;;;44109_2004;44109_2004;;;;;LINESTRING Z (354413 6689349.2 24.2, 354387.4 6689469.8 26.6, 354372.8 6689538.7 28)
TRONROUT0000000029477891;Route à 1 chaussée;R BONNE LOUISE;R BONNE LOUISE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091020;441091020;;;;;;;;;;;;;commune;commune;Rue Bonne Louise;Rue Bonne Louise;;;44109_1020;44109_1020;;;;;LINESTRING Z (354504.6 6689375.6 27.9, 354485.6 6689460.7 29, 354462.3 6689564 30.2, 354454.6 6689574.6 30.1)
TRONROUT0000000029477866;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;5;10;5;10B;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354372.8 6689538.7 28, 354417 6689558.4 28.9)
TRONROUT0000000029478303;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;2T;3;4;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354417 6689558.4 28.9, 354454.6 6689574.6 30.1)
TRONROUT0000000029478275;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;1;2T;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354454.6 6689574.6 30.1, 354501.6 6689595.2 30.7)
TRONROUT0000000029478122;Route à 1 chaussée;R MONDESIR;R MONDESIR;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;5;2;5;2T;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354399 6689625.1 30.2, 354417 6689558.4 28.9)
TRONROUT0000000029478585;Route à 1 chaussée;R MONDESIR;R MONDESIR;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;2T;7B;6;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354388.1 6689667.2 29.6, 354399 6689625.1 30.2)
TRONROUT0000000029477927;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;28;;36;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354547.9 6689619.9 31.5, 354445 6689708.3 30.6)
TRONROUT0000000290071093;Sentier;PAS DES OBERLE;PAS DES OBERLE;6;Non;0;En service;2011-10-14 08:01:03;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095995;441095995;;;;;;;;;;;;;commune;commune;Passage des Oberle;Passage des Oberle;;;44109_5995;44109_5995;;;;;LINESTRING Z (354158.1 6689458.4 10.1, 354155.3 6689464 10.1)
TRONROUT0000000029478093;Route à 1 chaussée;PAS DES OBERLE;PAS DES OBERLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;27;44;27;44;44109;44109;;;;441095995;441095995;;;;;;;;;;;;;commune;commune;Passage des Oberle;Passage des Oberle;;;44109_5995;44109_5995;;;;;LINESTRING Z (354145.4 6689524.6 12.4, 354140.3 6689495.8 10, 354140.2 6689495.2 10, 354155.3 6689464 10.1)
TRONROUT0000000029478092;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;10B;25;32;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354158.1 6689458.4 10.1, 354162 6689463.1 9.8, 354164.4 6689464.4 9.8, 354216.2 6689469.3 12.8, 354265.4 6689474 16.9, 354266.2 6689474.2 17.2, 354270.9 6689475.4 18, 354277.8 6689478.7 18.3, 354294.2 6689489.5 20.2, 354312 6689501.2 22.3, 354359.4 6689532 27.2, 354372.8 6689538.7 28)
TRONROUT0000002274979825;Route à 1 chaussée;AV RENE BAZIN;AV RENE BAZIN;5;Non;0;En service;2021-11-17 13:01:43;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;6;27;44;44109;44109;;;;441097224;441097224;;;;;;;;;;;;;commune;commune;Avenue René Bazin;Avenue René Bazin;;;44109_7224;44109_7224;;;;;LINESTRING Z (354399 6689625.1 30.2, 354388.1 6689620.3 30.1, 354330.2 6689594.9 28.5, 354327.7 6689593.8 28.5, 354310.1 6689585.1 27.2, 354282.8 6689571.7 24.7, 354273 6689567.1 24.5, 354271.5 6689566.5 24.5, 354263.4 6689565.4 23.5, 354260.1 6689565.8 23.3, 354252.5 6689568.5 22.7, 354242.8 6689573.3 21.7, 354235.1 6689573.9 21.5, 354233 6689573.7 21.1, 354228.9 6689573.3 20.5, 354147.3 6689535 13.2, 354145.4 6689524.6 12.4)
TRONROUT0000000029477951;Route à 1 chaussée;IMP DE CHAVAGNES;IMP DE CHAVAGNES;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091828;441091828;;;;;;;;;;;;;commune;commune;Impasse de Chavagnes;Impasse de Chavagnes;;;44109_1828;44109_1828;;;;;LINESTRING Z (354248.4 6689605.6 25, 354269.4 6689620.1 26.3, 354268.6 6689625.9 26.4, 354268 6689629.3 26.5, 354295.7 6689636.2 28.8, 354323.4 6689644.2 29.6, 354345.4 6689651.3 30.3, 354384.1 6689665.7 29.6, 354388.1 6689667.2 29.6)
TRONROUT0000000029478049;Escalier;AV DES ACACIAS;AV DES ACACIAS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441090028;441090028;;;;;;;;;;;;;commune;commune;Avenue des Acacias;Avenue des Acacias;;;44109_0028;44109_0028;;;;;LINESTRING Z (354174.5 6689652.1 13.1, 354182.2 6689659.4 14, 354195.1 6689671.7 13, 354198.2 6689675 15.9, 354204.9 6689679.8 17.2, 354211.1 6689684.2 17.9, 354211.7 6689684.7 18, 354216.3 6689688.5 19.1, 354220.8 6689693.5 20.1, 354223.3 6689697.4 20.8)
TRONROUT0000000029478278;Route à 1 chaussée;AV DES ACACIAS;AV DES ACACIAS;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;7;2;7;44109;44109;;;;441090028;441090028;;;;;;;;;;;;;commune;commune;Avenue des Acacias;Avenue des Acacias;;;44109_0028;44109_0028;;;;;LINESTRING Z (354223.3 6689697.4 20.8, 354224.9 6689699.8 21.3, 354229.2 6689706.9 22.5, 354244.8 6689738.7 23.6, 354249.1 6689748.9 24.2, 354253.3 6689758.8 24.8, 354279 6689820.1 26.7, 354282 6689827.1 26.8)
TRONROUT0000000029478708;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354302.4 6689742.7 27.7, 354310.7 6689760.2 28.4, 354319.4 6689756.7 28.7, 354326.4 6689760 29, 354328.1 6689769.5 29.2, 354340.1 6689798.4 27.8)
TRONROUT0000000029478407;Route à 1 chaussée;AV CAMUS;AV CAMUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;2;5;4;44109;44109;;;;441091388;441091388;;;;;;;;;;;;;commune;commune;Avenue Camus;Avenue Camus;;;44109_1388;44109_1388;;;;;LINESTRING Z (354372.4 6689784.8 29.5, 354368.8 6689785.3 29.4, 354361.1 6689788.1 28.9, 354340.1 6689798.4 27.8)
TRONROUT0000000029478247;Route à 1 chaussée;AV CAMUS;AV CAMUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;6;11;10;44109;44109;;;;441091388;441091388;;;;;;;;;;;;;commune;commune;Avenue Camus;Avenue Camus;;;44109_1388;44109_1388;;;;;LINESTRING Z (354340.1 6689798.4 27.8, 354282 6689827.1 26.8)
TRONROUT0000000029478095;Route à 1 chaussée;AV PERE DE FOUCAULD;AV PERE DE FOUCAULD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;11;4;3;44109;44109;;;;441096336;441096336;;;;;;;;;;;;;commune;commune;Avenue Père de Foucauld;Avenue Père de Foucauld;;;44109_6336;44109_6336;;;;;LINESTRING Z (353892.0022898072 6689603.175051575 12.460772777028954, 353898.9 6689595.7 12.4, 353911.4 6689597 12.3, 353932.4 6689600.8 11.9)
TRONROUT0000000029478329;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;32;17;30B;15;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (353928.3 6689630.4 11.8, 353932.4 6689600.8 11.9)
TRONROUT0000000029478107;Route à 1 chaussée;R DES MARTYRS;R DES MARTYRS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;14;13;2;1;44109;44109;;;;441095444;441095444;;;;;;;;;;;;;commune;commune;Rue des Martyrs;Rue des Martyrs;;;44109_5444;44109_5444;;;;;LINESTRING Z (353892.0022898072 6689661.367635152 13.75439676577778, 353914.4 6689641.2 12.3, 353928.3 6689630.4 11.8)
TRONROUT0000000029478214;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;19;34;35;48;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (353928.3 6689630.4 11.8, 353935 6689641.6 11.7, 353972.5 6689695.3 9.7, 353993.6 6689723.6 8.3)
TRONROUT0000000312797819;Sentier;;;6;Non;0;En service;2012-09-10 12:40:43;2022-05-17 20:06:43;;;;;Fichier numérique non métrique;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354043.3 6689790.5 8.2, 354056 6689776.7 7.8, 354064.4 6689759.2 7.5, 354068.8 6689733.3 7.2, 354067.1 6689706 6.8, 354061.7 6689688.1 6.5, 354055.6 6689656.2 5.9)
TRONROUT0000000029478185;Route à 1 chaussée;R DES ROSES;R DES ROSES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;15;20;29;28;44109;44109;;;;441097464;441097464;;;;;;;;;;;;;commune;commune;Rue des Roses;Rue des Roses;;;44109_7464;44109_7464;;;;;LINESTRING Z (353892.0022898072 6689755.754369134 14.112889646472555, 353921.9 6689789 12.4)
TRONROUT0000000029478039;Route à 1 chaussée;R DE LA CHEZINE;R DE LA CHEZINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;1;10;17;44109;44109;;;;441091892;441091892;;;;;;;;;;;;;commune;commune;Rue de la Chézine;Rue de la Chézine;;;44109_1892;44109_1892;;;;;LINESTRING Z (353993.6 6689723.6 8.3, 353970.9 6689743.4 9.8, 353941 6689770.4 11)
TRONROUT0000000029478133;Route à 1 chaussée;R COLONEL DESGREES DU LOU;R COLONEL DESGREES DU LOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;54;47;50;39;44109;44109;;;;441092032;441092032;;;;;;;;;;;;;commune;commune;Rue Colonel Desgrées du Lou;Rue Colonel Desgrées du Lou;;;44109_2032;44109_2032;;;;;LINESTRING Z (354035.4 6689782 8.2, 353993.6 6689723.6 8.3)
TRONROUT0000000029477985;Route à 1 chaussée;R DE LA CHEZINE;R DE LA CHEZINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;10;19;12;23;44109;44109;;;;441091892;441091892;;;;;;;;;;;;;commune;commune;Rue de la Chézine;Rue de la Chézine;;;44109_1892;44109_1892;;;;;LINESTRING Z (353941 6689770.4 11, 353921.9 6689789 12.4)
TRONROUT0000000359013664;Route à 1 chaussée;;;5;Non;1;En service;2016-09-08 18:07:33;;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354043.3 6689790.5 8.2, 354035.4 6689782 8.2)
TRONROUT0000000029478340;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;39;;25;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354381.9 6689736.4 29.8, 354433 6689693.6 30.4, 354438.4 6689689.2 30.5, 354533.9 6689609 31.5)
TRONROUT0000000029478272;Route à 1 chaussée;R MONDESIR;R MONDESIR;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;9;6;11;6;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354381.9 6689736.4 29.8, 354382.1 6689734.2 29.9, 354382.2 6689721.1 29.9, 354386.9 6689687.7 30, 354386.9 6689679.3 29.9, 354388.1 6689667.2 29.6)
TRONROUT0000000029478492;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;38;;46B;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354445 6689708.3 30.6, 354392.2 6689749.9 29.5)
TRONROUT0000000029478250;Route à 1 chaussée;R MONDESIR;R MONDESIR;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:57;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354380.5 6689741.4 29.7, 354381.9 6689736.4 29.8)
TRONROUT0000000029478565;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:57;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354392.2 6689749.9 29.5, 354388.9 6689748 29.5, 354386 6689746.2 29.6, 354383.7 6689744.3 29.6, 354380.5 6689741.4 29.7)
TRONROUT0000000029478040;Route à 1 chaussée;R DU 14 JUILLET;R DU 14 JUILLET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;13;12;1;44109;44109;;;;441097076;441097076;;;;;;;;;;;;;commune;commune;Rue du 14 Juillet;Rue du 14 Juillet;;;44109_7076;44109_7076;;;;;LINESTRING Z (354525 6689810.9 31.1, 354523.3 6689801.2 31.5, 354445 6689708.3 30.6)
TRONROUT0000000029478431;Route à 1 chaussée;R MONDESIR;R MONDESIR;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:57;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;10;15;10;13;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354372.4 6689784.8 29.5, 354373.1 6689775.5 29.5, 354377.5 6689754.4 29.6, 354380.5 6689741.4 29.7)
TRONROUT0000000029478076;Route à 1 chaussée;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354392.2 6689749.9 29.5, 354382.5 6689760.8 29.6, 354372.4 6689784.8 29.5)
TRONROUT0000000029477950;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;52;35;42;25;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354525 6689810.9 31.1, 354485.8 6689819.7 30.9, 354413.9 6689853.6 29.9)
TRONROUT0000000029478276;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;58;39;54;35;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354413.9 6689853.6 29.9, 354361.8 6689876.9 28.7, 354357.5 6689878.8 28.7)
TRONROUT0000000029474916;Route à 1 chaussée;R VAUBAN;R VAUBAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;3;4;44109;44109;;;;441098308;441098308;;;;;;;;;;;;;commune;commune;Rue Vauban;Rue Vauban;;;44109_8308;44109_8308;;;;;LINESTRING Z (355192.7 6689371.8 8.9, 355152.1 6689353.8 8.9)
TRONROUT0000000029475230;Route à 1 chaussée;R SAINT-JULIEN;R SAINT-JULIEN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097664;441097664;;;;;;;;;;;;;commune;commune;Rue Saint Julien;Rue Saint Julien;;;44109_7664;44109_7664;;;;;LINESTRING Z (355152.1 6689353.8 8.9, 355143.5 6689374.6 8.6)
TRONROUT0000000029473716;Route à 1 chaussée;R DU CHAPEAU ROUGE;R DU CHAPEAU ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441091644;441091644;;;;;;;;;;;;;commune;commune;Rue du Chapeau Rouge;Rue du Chapeau Rouge;;;44109_1644;44109_1644;;;;;LINESTRING Z (355118.1 6689358.8 12.9, 355093.7 6689381 13.9, 355089.2 6689383.2 14)
TRONROUT0000000029473782;Route à 1 chaussée;R CONTRESCARPE;R CONTRESCARPE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;22;13;12;11;44109;44109;;;;441092124;441092124;;;;;;;;;;;;;commune;commune;Rue Contrescarpe;Rue Contrescarpe;;;44109_2124;44109_2124;;;;;LINESTRING Z (355150.8 6689422 14.7, 355134.6 6689393.3 13.2, 355118.1 6689358.8 12.9)
TRONROUT0000000029473699;Route à 1 chaussée;R DES VIEILLES DOUVES;R DES VIEILLES DOUVES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;17;14;13;44109;44109;;;;441098440;441098440;;;;;;;;;;;;;commune;commune;Rue des Vieilles Douves;Rue des Vieilles Douves;;;44109_8440;44109_8440;;;;;LINESTRING Z (355176.3 6689410.3 9.3, 355148.6 6689381.1 8.9, 355143.5 6689374.6 8.6)
TRONROUT0000000029475115;Escalier;R DE L'ECHELLE;R DE L'ECHELLE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092672;441092672;;;;;;;;;;;;;commune;commune;Rue de l'Echelle;Rue de l'Echelle;;;44109_2672;44109_2672;;;;;LINESTRING Z (355168.6 6689427 13.7, 355176.3 6689410.3 9.3)
TRONROUT0000000029475015;Route à 1 chaussée;PL DU BON PASTEUR;PL DU BON PASTEUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;4;44109;44109;;;;441091040;441091040;;;;;;;;;;;;;commune;commune;Place du Bon Pasteur;Place du Bon Pasteur;;;44109_1040;44109_1040;;;;;LINESTRING Z (355150.8 6689422 14.7, 355168.6 6689427 13.7)
TRONROUT0000000029474545;Route à 1 chaussée;PL DU BON PASTEUR;PL DU BON PASTEUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;5;;5;44109;44109;;;;441091040;441091040;;;;;;;;;;;;;commune;commune;Place du Bon Pasteur;Place du Bon Pasteur;;;44109_1040;44109_1040;;;;;LINESTRING Z (355144.3 6689454.7 15.9, 355150.8 6689422 14.7)
TRONROUT0000000029473566;Route à 1 chaussée;PL DU BON PASTEUR;PL DU BON PASTEUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441091040;441091040;;;;;;;;;;;;;commune;commune;Place du Bon Pasteur;Place du Bon Pasteur;;;44109_1040;44109_1040;;;;;LINESTRING Z (355162.2 6689457.5 15.6, 355166.4 6689431.7 15, 355168.6 6689427 13.7)
TRONROUT0000000029474013;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;7;4;1;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (355017.1 6689433.1 20.1, 355139.1 6689453.8 15.8)
TRONROUT0000000029473546;Route à 1 chaussée;R DE L'ARCHE SECHE;R DE L'ARCHE SECHE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;6;44109;44109;;;;441090348;441090348;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de l'Arche Sèche;Rue de l'Arche Sèche;;;44109_0348;44109_0348;;;;;LINESTRING Z (355200.7 6689432.9 9, 355200.5 6689373.1 8.8)
TRONROUT0000002007790875;Route à 1 chaussée;R DUVOISIN;R DUVOISIN;6;Non;0;En service;2017-12-19 17:58:08;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092658;441092658;;;;;;;;;;;;;commune;commune;Rue Duvoisin;Rue Duvoisin;;;44109_2658;44109_2658;;;;;LINESTRING Z (355224.9 6689432.9 11.1, 355224.5 6689389.8 9.4)
TRONROUT0000000029473742;Route à 1 chaussée;R DES VIEILLES DOUVES;R DES VIEILLES DOUVES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;19;;19;44109;44109;;;;441098440;441098440;;;;;;;;;;;;;commune;commune;Rue des Vieilles Douves;Rue des Vieilles Douves;;;44109_8440;44109_8440;;;;;LINESTRING Z (355176.3 6689410.3 9.3, 355200.7 6689432.9 9)
TRONROUT0000000029474817;Route à 1 chaussée;R DU PRE NIAN;R DU PRE NIAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;5;2;3;44109;44109;;;;441096948;441096948;;;;;;;;;;;;;commune;commune;Rue du Pré Nian;Rue du Pré Nian;;;44109_6948;44109_6948;;;;;LINESTRING Z (355266.1 6689424.1 7.6, 355306.1 6689434.6 7)
TRONROUT0000000029475096;Escalier;SQ ARTHUR COLINET;SQ ARTHUR COLINET;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C7;44109#0C7;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355200.7 6689432.9 9, 355224.9 6689432.9 11.1)
TRONROUT0000000029474134;Route à 1 chaussée;R DUVOISIN;R DUVOISIN;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;1;;1;;44109;44109;;;;441092658;441092658;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Duvoisin;Rue Duvoisin;;;44109_2658;44109_2658;;;;;LINESTRING Z (355224.9 6689432.9 11.1, 355225.6 6689460.7 12.5)
TRONROUT0000000029475285;Route à 1 chaussée;R AFFRE;R AFFRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441090045;441090045;;;;;;;;;;;;;commune;commune;Rue Affre;Rue Affre;;;44109_0045;44109_0045;;;;;LINESTRING Z (355266.1 6689424.1 7.6, 355267.4 6689473.5 10.6)
TRONROUT0000000200678099;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;1;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355195.9 6689462.7 14.1, 355201.2 6689463.7 14.1, 355208.4 6689464.8 13.7)
TRONROUT0000000029475226;Escalier;R DUVOISIN;R DUVOISIN;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092658;441092658;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Duvoisin;Rue Duvoisin;;;44109_2658;44109_2658;;;;;LINESTRING Z (355225.6 6689460.7 12.5, 355225.8 6689467.7 12.9)
TRONROUT0000000029474782;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;7;8;7;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355208.4 6689464.8 13.7, 355225.8 6689467.7 12.9)
TRONROUT0000000029473785;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;2;;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (355139.1 6689453.8 15.8, 355144.3 6689454.7 15.9)
TRONROUT0000000029474740;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;2;;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (355144.3 6689454.7 15.9, 355158.9 6689457.1 15.8)
TRONROUT0000000029475269;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355158.9 6689457.1 15.8, 355162.2 6689457.5 15.6)
TRONROUT0000000200678098;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;9;10;9;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355162.2 6689457.5 15.6, 355195.9 6689462.7 14.1)
TRONROUT0000000029474150;Route à 1 chaussée;R PARE;R PARE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2B;7;2;1;44109;44109;;;;441096144;441096144;;;;;;;;;;;;;commune;commune;Rue Paré;Rue Paré;;;44109_6144;44109_6144;;;;;LINESTRING Z (355123.4 6689503.4 16.8, 355130.1 6689478.9 15.9, 355139.1 6689453.8 15.8)
TRONROUT0000000029474670;Route à 1 chaussée;R PARE;R PARE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096144;441096144;;;;;;;;;;;;;commune;commune;Rue Paré;Rue Paré;;;44109_6144;44109_6144;;;;;LINESTRING Z (355122 6689508.5 16.7, 355084.9 6689496.1 15, 355077.6 6689512.3 15.7)
TRONROUT0000000029474824;Route à 1 chaussée;R GUEPIN;R GUEPIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;7;2;1;44109;44109;;;;441093908;441093908;;;;;;;;;;;;;commune;commune;Rue Guépin;Rue Guépin;;;44109_3908;44109_3908;;;;;LINESTRING Z (355158.9 6689457.1 15.8, 355168.6 6689547.8 19.3, 355167.3 6689554 19.3)
TRONROUT0000000029473757;Route à 1 chaussée;COUR SAINTE-MARIE;COUR SAINTE-MARIE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098600;441098600;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355122 6689508.5 16.7, 355123.4 6689503.4 16.8)
TRONROUT0000000029474693;Route à 1 chaussée;R PARE;R PARE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;2;17;4;44109;44109;;;;441096144;441096144;;;;;;;;;;;;;commune;commune;Rue Paré;Rue Paré;;;44109_6144;44109_6144;;;;;LINESTRING Z (355123.4 6689503.4 16.8, 355132.6 6689517.2 17.5, 355152.3 6689546.4 18, 355157.8 6689550.2 19.2, 355167.3 6689554 19.3)
TRONROUT0000000029474199;Route à 1 chaussée;COUR SAINTE-MARIE;COUR SAINTE-MARIE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;7T;7;7B;44109;44109;;;;441098600;441098600;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355122 6689508.5 16.7, 355121.2 6689511.6 16.8, 355102.7 6689539.7 16.1, 355116.2 6689555.5 15.9)
TRONROUT0000000029473885;Route à 1 chaussée;R BOILEAU;R BOILEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;11;12;9;44109;44109;;;;441090912;441090912;;;;;;;;;;;;;commune;commune;Rue Boileau;Rue Boileau;;;44109_0912;44109_0912;;;;;LINESTRING Z (355020.6 6689373.4 16.7, 355013.1 6689432.4 20.1)
TRONROUT0000000029474001;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;17;12;11;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (354950 6689421.2 21.4, 355013.1 6689432.4 20.1)
TRONROUT0000000029474886;Route à 1 chaussée;R DU CALVAIRE;R DU CALVAIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091352;441091352;;;;;;;;;;;;;commune;commune;Rue du Calvaire;Rue du Calvaire;;;44109_1352;44109_1352;;;;;LINESTRING Z (355013.1 6689432.4 20.1, 355017.1 6689433.1 20.1)
TRONROUT0000000029473860;Route à 1 chaussée;PL DES VOLONTAIRES DE LA DEFENSE PASSIVE;PL DES VOLONTAIRES DE LA DEFENSE PASSIVE;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 20:43:48;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08C;44109#08C;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355008.9 6689445.1 20, 355017.1 6689433.1 20.1)
TRONROUT0000000029473973;Route à 1 chaussée;R LA FAYETTE;R LA FAYETTE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;7;2;1;44109;44109;;;;441094748;441094748;;;;;;;;;;;;;commune;commune;Rue la Fayette;Rue la Fayette;;;44109_4748;44109_4748;;;;;LINESTRING Z (355008.9 6689445.1 20, 354955.1 6689524.5 21.3)
TRONROUT0000000029474177;Route à 1 chaussée;R DE BUDAPEST;R DE BUDAPEST;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;13;4;1;44109;44109;;;;441091292;441091292;;;;;;;;;;;;;commune;commune;Rue de Budapest;Rue de Budapest;;;44109_1292;44109_1292;;;;;LINESTRING Z (355125.2 6689598.7 20.1, 355084.7 6689551.6 19.2, 355076.6 6689541 19.1, 355018.3 6689457.6 20, 355008.9 6689445.1 20)
TRONROUT0000000029474812;Route à 1 chaussée;R LA FAYETTE;R LA FAYETTE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;18;13;10;9;44109;44109;;;;441094748;441094748;;;;;;;;;;;;;commune;commune;Rue la Fayette;Rue la Fayette;;;44109_4748;44109_4748;;;;;LINESTRING Z (354955.1 6689524.5 21.3, 354893 6689613.1 23.2)
TRONROUT0000000029474027;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354921.2 6689630.5 23, 354917.8 6689628.8 23.3, 354902.9 6689619.7 23.1)
TRONROUT0000000029474517;Sentier;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;1;;1;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354921.2 6689630.5 23, 354898.9 6689662.9 24.2)
TRONROUT0000000029473603;Route à 1 chaussée;R GENERAL MEUSNIER;R GENERAL MEUSNIER;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;1;2;1;6;44109;44109;;;;441093620;441093620;;;;;;;;;;;;;commune;commune;Rue Général Meusnier;Rue Général Meusnier;;;44109_3620;44109_3620;;;;;LINESTRING Z (354989.9 6689668 23.2, 354938.6 6689640.3 22.7, 354921.2 6689630.5 23)
TRONROUT0000000029474057;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093092;441093092;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355225.8 6689467.7 12.9, 355227.9 6689468 12.8, 355243.3 6689470.5 11.9)
TRONROUT0000000029473992;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355267.4 6689473.5 10.6, 355243.3 6689470.5 11.9)
TRONROUT0000000029474523;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;3;4;44109;44109;;;;441093092;441093092;;;;;;;;;;;;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355301.8 6689478.1 8.6, 355267.4 6689473.5 10.6)
TRONROUT0000000029475284;Route à 1 chaussée;R CACAULT;R CACAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;;2;;44109;44109;;;;441091324;441091324;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Cacault;Rue Cacault;;;44109_1324;44109_1324;;;;;LINESTRING Z (355242 6689548.6 15.9, 355243.3 6689470.5 11.9)
TRONROUT0000000295265255;Route à 1 chaussée;R DE LA BOUCHERIE;R DE LA BOUCHERIE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;24;15;30;44109;44109;;;;441091088;441091088;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Boucherie;Rue de la Boucherie;;;44109_1088;44109_1088;;;;;LINESTRING Z (355255.7 6689551.9 15.1, 355259.3 6689547.3 14.5, 355263.2 6689542 14.1, 355266.5 6689535.6 12.4, 355270.8 6689527.8 12, 355276.5 6689517.7 11.2, 355283.5 6689506.6 10.6, 355291.9 6689494.5 10, 355297.2 6689486 9.9, 355300.7 6689480.8 9.5, 355301.8 6689478.1 8.6)
TRONROUT0000000029474206;Route à 1 chaussée;R DE L'ARCHE SECHE;R DE L'ARCHE SECHE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;3.9;;;;;Non;3;10;13;20;44109;44109;;;;441090348;441090348;;;;;;;;;;;;;commune;commune;Rue de l'Arche Sèche;Rue de l'Arche Sèche;;;44109_0348;44109_0348;;;;;LINESTRING Z (355278.6 6689651.6 7.8, 355274.9 6689652.3 8.4, 355270.5 6689651.6 8.5, 355266.5 6689650.2 8.7, 355259.5 6689645.1 9.2, 355248.3 6689634.8 10.2, 355237.2 6689624 11.6, 355227 6689614.7 12.1, 355219 6689606.2 12.1, 355210.7 6689595.8 11.9, 355207.8 6689590 11.6, 355206.6 6689583.7 11.6, 355205.2 6689570.1 11.4, 355203.8 6689548.8 10.8, 355202.8 6689522.7 10.5, 355202 6689496.4 9.7, 355201.3 6689473.3 9, 355200.7 6689432.9 9)
TRONROUT0000000295266794;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355242 6689548.6 15.9, 355249.6 6689551 15.5, 355253.4 6689552.7 15.3, 355255.7 6689551.9 15.1)
TRONROUT0000000295265209;Route à 1 chaussée;R CACAULT;R CACAULT;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;10;;12;44109;44109;;;;441091324;441091324;;;;;;;;;;;;;commune;commune;Rue Cacault;Rue Cacault;;;44109_1324;44109_1324;;;;;LINESTRING Z (355242 6689548.6 15.9, 355238.3 6689550.3 15.3, 355235.2 6689552.7 15.2, 355232.5 6689555.7 15.2, 355229.8 6689560.4 15.2, 355229.2 6689564.1 15.2, 355228.6 6689568.7 15.2)
TRONROUT0000000295265279;Sentier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355190.1 6689560.6 19, 355196.2 6689558.5 18.8)
TRONROUT0000000200678093;Sentier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;1;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355196.2 6689558.5 18.8, 355211.3 6689562 17.7, 355216.1 6689563.2 15.9)
TRONROUT0000000295265277;Sentier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355190.1 6689560.6 19, 355196.8 6689565.3 18.8)
TRONROUT0000000329622507;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355255.7 6689551.9 -1000, 355255.3 6689558.2 -1000, 355241.9 6689577 -1000)
TRONROUT0000000295265281;Escalier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355228.6 6689568.7 15.2, 355221.5 6689564.7 15.7, 355216.1 6689563.2 15.9)
TRONROUT0000000295265278;Sentier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;1;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355196.8 6689565.3 18.8, 355212.1 6689568.6 17.9, 355216.5 6689569.5 16.1)
TRONROUT0000000029473754;Escalier;R DES DEUX PONTS;R DES DEUX PONTS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355216.5 6689569.5 16.1, 355225.2 6689569.5 15.5, 355228.6 6689568.7 15.2)
TRONROUT0000000029474701;Route à 1 chaussée;R DES DEUX PONTS;R DES DEUX PONTS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355228.6 6689568.7 15.2, 355232.9 6689572.6 15.2, 355238.3 6689575.4 15.2, 355241.9 6689577 17.2)
TRONROUT0000000029474097;Escalier;R BEAUREPAIRE;R BEAUREPAIRE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;1;2B;1;44109;44109;;;;441090656;441090656;;;;;;;;;;;;;commune;commune;Rue Beaurepaire;Rue Beaurepaire;;;44109_0656;44109_0656;;;;;LINESTRING Z (355241.9 6689577 17.2, 355249.2 6689576.5 16.4, 355266.4 6689580.6 14.8)
TRONROUT0000000029475133;Escalier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355266.4 6689580.6 14.8, 355289.2 6689586.5 10, 355296.9 6689586.4 8.3)
TRONROUT0000000029474362;Route à 1 chaussée;R DU PONT SAUVETOUT;R DU PONT SAUVETOUT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;;4;;44109;44109;;;;441096784;441096784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Pont Sauvetout;Rue du Pont Sauvetout;;;44109_6784;44109_6784;;;;;LINESTRING Z (355223.5 6689597 17, 355231.9 6689587.4 15.8, 355241.9 6689577 17.2)
TRONROUT0000000200678100;Route à 1 chaussée;R DU PONT SAUVETOUT;R DU PONT SAUVETOUT;5;Non;1;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096784;441096784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Pont Sauvetout;Rue du Pont Sauvetout;;;44109_6784;44109_6784;;;;;LINESTRING Z (355223.5 6689597 17, 355221.4 6689599.5 17.2, 355218.6 6689602.7 17.3, 355215.1 6689606.7 17.6, 355212.7 6689609.5 16.8)
TRONROUT0000000200678092;Route à 1 chaussée;R DES DEUX PONTS;R DES DEUX PONTS;5;Non;0;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441092456;441092456;;;;;;;;;;;;;commune;commune;Rue des Deux Ponts;Rue des Deux Ponts;;;44109_2456;44109_2456;;;;;LINESTRING Z (355167.3 6689554 19.3, 355174.2 6689556.9 19.3, 355190.1 6689560.6 19)
TRONROUT0000000029474356;Route à 1 chaussée;R PIERRE CHEREAU;R PIERRE CHEREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;4;3;4;44109;44109;;;;441096592;441096592;;;;;;;;;;;;;commune;commune;Rue Pierre Chéreau;Rue Pierre Chéreau;;;44109_6592;44109_6592;;;;;LINESTRING Z (355167.3 6689554 19.3, 355137.8 6689583.2 19.6)
TRONROUT0000000029474353;Route à 1 chaussée;R PIERRE CHEREAU;R PIERRE CHEREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;5;;5;44109;44109;;;;441096592;441096592;;;;;;;;;;;;;commune;commune;Rue Pierre Chéreau;Rue Pierre Chéreau;;;44109_6592;44109_6592;;;;;LINESTRING Z (355125.2 6689598.7 20.1, 355137.8 6689583.2 19.6)
TRONROUT0000000029474361;Route à 1 chaussée;R PIERRE CHEREAU;R PIERRE CHEREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096592;441096592;;;;;;;;;;;;;commune;commune;Rue Pierre Chéreau;Rue Pierre Chéreau;;;44109_6592;44109_6592;;;;;LINESTRING Z (355111 6689611.6 21.1, 355116.6 6689606.8 20.7, 355125.2 6689598.7 20.1)
TRONROUT0000000029474340;Route à 1 chaussée;R PIERRE CHEREAU;R PIERRE CHEREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096592;441096592;;;;;;;;;;;;;commune;commune;Rue Pierre Chéreau;Rue Pierre Chéreau;;;44109_6592;44109_6592;;;;;LINESTRING Z (355125.2 6689598.7 20.1, 355122.2 6689610.7 20.6, 355119.7 6689619.3 20.9)
TRONROUT0000000029474401;Rond-point;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355111 6689611.6 21.1, 355116 6689613.6 21, 355118.1 6689616.2 21, 355119.7 6689619.3 20.9)
TRONROUT0000000029474406;Rond-point;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355095.7 6689625.1 20.9, 355095 6689621.1 21, 355098.3 6689615.6 21.1, 355105 6689612.3 21.1, 355111 6689611.6 21.1)
TRONROUT0000000029474373;Rond-point;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355119.7 6689619.3 20.9, 355120.4 6689623.3 20.8, 355120.3 6689627.3 20.8, 355118.4 6689630.7 20.8, 355117.1 6689631.9 20.8)
TRONROUT0000000029474428;Rond-point;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355106.1 6689635.5 21, 355100.8 6689633.8 20.9, 355098.3 6689631.1 20.8, 355096.5 6689628.1 20.8, 355095.7 6689625.1 20.9)
TRONROUT0000000029474412;Rond-point;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355117.1 6689631.9 20.8, 355116.1 6689632.7 20.8, 355112.1 6689634.8 20.9, 355106.1 6689635.5 21)
TRONROUT0000000029474497;Route à 1 chaussée;PL DU CIRQUE;PL DU CIRQUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091916;441091916;;;;;;;;;;;;;commune;commune;Place du Cirque;Place du Cirque;;;44109_1916;44109_1916;;;;;LINESTRING Z (355278.6 6689651.6 7.8, 355281.3 6689647.2 7.8, 355284.3 6689643.7 7.6)
TRONROUT0000000029474540;Route à 1 chaussée;R DE L'ABREUVOIR;R DE L'ABREUVOIR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090024;441090024;;;;;;;;;;;;;commune;commune;Rue de l'Abreuvoir;Rue de l'Abreuvoir;;;44109_0024;44109_0024;;;;;LINESTRING Z (355268.1 6689665.4 8, 355278.6 6689651.6 7.8)
TRONROUT0000000227885048;Route à 1 chaussée;R DE L'ABREUVOIR;R DE L'ABREUVOIR;5;Non;0;En service;2010-01-12 13:49:13;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441090024;441090024;;;;;;;;;;;;;commune;commune;Rue de l'Abreuvoir;Rue de l'Abreuvoir;;;44109_0024;44109_0024;;;;;LINESTRING Z (355230 6689677.9 11.7, 355263.8 6689668.1 8, 355268.1 6689665.4 8)
TRONROUT0000000029473911;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355268.1 6689665.4 8, 355278.4 6689676 7.6, 355278 6689681.9 7.6)
TRONROUT0000000029474411;Rond-point;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355196 6689715.5 20.6, 355195.2 6689711.7 20.6, 355195.2 6689708.7 20.6, 355195.7 6689706.6 20.6, 355197.7 6689703.2 20.9)
TRONROUT0000000029474168;Rond-point;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355197.7 6689703.2 20.9, 355200.8 6689701 20.9, 355204.3 6689699.4 20.9, 355208.5 6689699.3 20.8, 355211.9 6689699.9 20.8, 355215.1 6689701.5 20.8, 355217.6 6689704.2 20.8, 355219.2 6689707.9 20.8, 355219.7 6689711.3 20.8, 355219.4 6689714.8 20.8, 355217.9 6689718.3 20.8, 355215.9 6689720.7 20.8, 355212.8 6689722.4 20.8)
TRONROUT0000000317258090;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;1;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355284.3 6689746.1 6.2, 355281.1 6689727.7 6.4, 355279 6689713.1 6.8, 355278.1 6689697.3 7.3, 355278 6689681.9 7.6)
TRONROUT0000000029473516;Rond-point;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355212.8 6689722.4 20.8, 355209.2 6689723.8 20.7, 355205.2 6689724 20.6, 355202.1 6689722.9 20.6, 355199.8 6689721.4 20.6, 355197.8 6689719 20.6, 355196 6689715.5 20.6)
TRONROUT0000000029473608;Route à 1 chaussée;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355204.9 6689753.1 19.8, 355201.4 6689738.4 19.8, 355197.8 6689727.6 20.4, 355196.9 6689723.9 20.6, 355196 6689715.5 20.6)
TRONROUT0000000029474395;Route à 1 chaussée;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355212.8 6689722.4 20.8, 355209.9 6689728.1 20.4, 355207.8 6689733 20.2, 355206.7 6689737.4 20.1, 355204.9 6689753.1 19.8)
TRONROUT0000000029474398;Route à 1 chaussée;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;5;;1;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355075.4 6689642.9 21.1, 355083 6689639.7 21.3, 355090.4 6689632.9 21.5, 355095.7 6689625.1 20.9)
TRONROUT0000000029473746;Route à 1 chaussée;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (355106.1 6689635.5 21, 355099.5 6689638.5 21, 355087.2 6689641.8 21, 355075.4 6689642.9 21.1)
TRONROUT0000000200678101;Route à 1 chaussée;R DU PONT SAUVETOUT;R DU PONT SAUVETOUT;5;Non;0;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;3;2;3;44109;44109;;;;441096784;441096784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Pont Sauvetout;Rue du Pont Sauvetout;;;44109_6784;44109_6784;;;;;LINESTRING Z (355148.2 6689681.6 20.4, 355211 6689611.4 18, 355212.7 6689609.5 16.8)
TRONROUT0000000029474170;Route à 1 chaussée;PL DE BRETAGNE;PL DE BRETAGNE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441091216;441091216;;;;;;;;;;;;;commune;commune;Place de Bretagne;Place de Bretagne;;;44109_1216;44109_1216;;;;;LINESTRING Z (355139.6 6689673.7 20.5, 355134.9 6689667.8 20.4, 355130.9 6689661.4 20.3, 355127.5 6689655.3 20.2, 355124.6 6689649.2 20.1, 355121.2 6689640.7 20.1, 355119.2 6689636.1 20.2, 355117.1 6689631.9 20.8)
TRONROUT0000000029474392;Route à 1 chaussée;PL DE BRETAGNE;PL DE BRETAGNE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091216;441091216;;;;;;;;;;;;;commune;commune;Place de Bretagne;Place de Bretagne;;;44109_1216;44109_1216;;;;;LINESTRING Z (355139.6 6689673.7 20.5, 355146.2 6689679.9 20.7, 355148.2 6689681.6 20.7)
TRONROUT0000000029474352;Route à 1 chaussée;PL DE BRETAGNE;PL DE BRETAGNE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091216;441091216;;;;;;;;;;;;;commune;commune;Place de Bretagne;Place de Bretagne;;;44109_1216;44109_1216;;;;;LINESTRING Z (355148.2 6689681.6 20.7, 355153.3 6689685.8 20.9, 355154.5 6689686.5 20.9, 355156 6689687.5 20.9)
TRONROUT0000000029473607;Route à 1 chaussée;PL DE BRETAGNE;PL DE BRETAGNE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441091216;441091216;;;;;;;;;;;;;commune;commune;Place de Bretagne;Place de Bretagne;;;44109_1216;44109_1216;;;;;LINESTRING Z (355156 6689687.5 20.9, 355160 6689690 21, 355167.3 6689693.7 21, 355173.8 6689696.6 21.2, 355180.4 6689698.6 21.2, 355188.9 6689700.7 21.2, 355195 6689702.1 21, 355197.7 6689703.2 20.9)
TRONROUT0000000029474162;Route à 1 chaussée;R PRESIDENT EDOUARD HERRIOT;R PRESIDENT EDOUARD HERRIOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;9;2;1;44109;44109;;;;441096956;441096956;;;;;;;;;;;;;commune;commune;Rue Président Edouard Herriot;Rue Président Edouard Herriot;;;44109_6956;44109_6956;;;;;LINESTRING Z (355139.6 6689673.7 20.5, 355138.3 6689679.5 20.6, 355136.8 6689682.1 20.5, 355100.9 6689724.1 22.8, 355049.2 6689782.7 35.2)
TRONROUT0000000029473512;Route à 1 chaussée;R PRESIDENT EDOUARD HERRIOT;R PRESIDENT EDOUARD HERRIOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;2;2;7;44109;44109;;;;441096956;441096956;;;;;;;;;;;;;commune;commune;Rue Président Edouard Herriot;Rue Président Edouard Herriot;;;44109_6956;44109_6956;;;;;LINESTRING Z (355156 6689687.5 20.9, 355151.5 6689690.3 21.1, 355144.4 6689698.2 21.2, 355110.4 6689736.9 22.9, 355081.8 6689770.1 23.6, 355055 6689798.7 24.4, 355044.5 6689809.8 24.8, 355038.3 6689814.9 24.8)
TRONROUT0000000029475163;Route à 1 chaussée;R EDMOND PRIEUR;R EDMOND PRIEUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CW;44109#0CW;;;;;;;;;;;;;commune;commune;Rue Edmond Prieur;Rue Edmond Prieur;;;44109_2719;44109_2719;;;;;LINESTRING Z (355205.3 6689815.9 19.6, 355163.4 6689827.9 21.4)
TRONROUT0000000029474429;Route à 1 chaussée;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;20;9;8;5;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (354989.9 6689668 23.2, 355075.4 6689642.9 21.1)
TRONROUT0000000029474059;Route à 1 chaussée;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;22;;20;;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (354938.9 6689681 24, 354989.9 6689668 23.2)
TRONROUT0000000029474776;Route à 1 chaussée;R MERCOEUR;R MERCOEUR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;24;19;24;19;44109;44109;;;;441095592;441095592;;;;;;;;;;;;;commune;commune;Rue Mercoeur;Rue Mercoeur;;;44109_5592;44109_5592;;;;;LINESTRING Z (354912.7 6689703.7 24.6, 354938.9 6689681 24)
TRONROUT0000000029473831;Route à 1 chaussée;R DE L'INDUSTRIE;R DE L'INDUSTRIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;3;2;17;16;44109;44109;;;;441094280;441094280;;;;;;;;;;;;;commune;commune;Rue de l'Industrie;Rue de l'Industrie;;;44109_4280;44109_4280;;;;;LINESTRING Z (355049.2 6689782.7 35.2, 354938.9 6689681 24)
TRONROUT0000000029474546;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;30;35;18;21;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355026.8 6689805.7 25, 354912.7 6689703.7 24.6)
TRONROUT0000000029474346;Route à 1 chaussée;R D'ERLON;R D'ERLON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;11;14;44109;44109;;;;441092876;441092876;;;;;;;;;;;;;commune;commune;Rue d'Erlon;Rue d'Erlon;;;44109_2876;44109_2876;;;;;LINESTRING Z (354982.5 6689838.7 25.8, 354978.9 6689837.1 26.5, 354976.4 6689834.9 26.2, 354928.2 6689768 25.5, 354895.3 6689721.9 24.2)
TRONROUT0000000029473610;Route à 1 chaussée;R PRESIDENT EDOUARD HERRIOT;R PRESIDENT EDOUARD HERRIOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;11;19;19;19;44109;44109;;;;441096956;441096956;;;;;;;;;;;;;commune;commune;Rue Président Edouard Herriot;Rue Président Edouard Herriot;;;44109_6956;44109_6956;;;;;LINESTRING Z (355049.2 6689782.7 35.2, 355029.7 6689802.9 25, 355026.8 6689805.7 25)
TRONROUT0000000029474720;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2008-11-15 06:12:08;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355026.8 6689805.7 25, 355038.3 6689814.9 24.8)
TRONROUT0000000029474404;Route à 1 chaussée;R DU MARCHIX;R DU MARCHIX;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095340;441095340;;;;;;;;;;;;;commune;commune;Rue du Marchix;Rue du Marchix;;;44109_5340;44109_5340;;;;;LINESTRING Z (355001.5 6689830.9 25.1, 355005.8 6689825.8 24.9, 355013.6 6689817.5 25, 355025.3 6689806.8 25, 355026.8 6689805.7 25)
TRONROUT0000000029474504;Route à 1 chaussée;R CAPITAINE CORHUMEL;R CAPITAINE CORHUMEL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;8;3;18;44109;44109;;;;441091404;441091404;;;;;;;;;;;;;commune;commune;Rue Capitaine Corhumel;Rue Capitaine Corhumel;;;44109_1404;44109_1404;;;;;LINESTRING Z (354879.5 6689796.8 26.2, 354882.9 6689798.6 26.2, 354929.5 6689845.2 27, 354941.7 6689855.9 27.3, 354948.3 6689860.6 27.3, 354953 6689862.8 27.3)
TRONROUT0000000029477785;Route à 1 chaussée;R COPERNIC;R COPERNIC;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:33:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441092140;441092140;;;;;;;;;;;;;commune;commune;Rue Copernic;Rue Copernic;;;44109_2140;44109_2140;;;;;LINESTRING Z (354739.1 6689382.8 28.8, 354792.3 6689394.6 28.6)
TRONROUT0000000029477679;Route à 1 chaussée;R CASSINI;R CASSINI;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;12;7;10;1;44109;44109;;;;441091492;441091492;;;;;;;;;;;;;commune;commune;Rue Cassini;Rue Cassini;;;44109_1492;44109_1492;;;;;LINESTRING Z (354736.8 6689437.4 29.2, 354684.3 6689372.3 29.3)
TRONROUT0000000029477731;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354736.8 6689437.4 29.2, 354792.3 6689394.6 28.5)
TRONROUT0000000029477658;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2;;6;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354799.3 6689408.6 28.5, 354747.9 6689449.8 29.2)
TRONROUT0000000029477837;Route à 1 chaussée;R MARCEAU;R MARCEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095308;441095308;;;;;;;;;;;;;commune;commune;Rue Marceau;Rue Marceau;;;44109_5308;44109_5308;;;;;LINESTRING Z (354747.9 6689449.8 29.2, 354736.8 6689437.4 29.2)
TRONROUT0000000029477766;Route à 1 chaussée;R MARCEAU;R MARCEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;24;11;20;9;44109;44109;;;;441095308;441095308;;;;;;;;;;;;;commune;commune;Rue Marceau;Rue Marceau;;;44109_5308;44109_5308;;;;;LINESTRING Z (354778.7 6689487.7 28.1, 354747.9 6689449.8 29.2)
TRONROUT0000000029477760;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;13;;5;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354640.9 6689519.2 30.5, 354736.8 6689437.4 29.2)
TRONROUT0000000029477761;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;8;;16;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354747.9 6689449.8 29.2, 354651.1 6689530.9 30.5)
TRONROUT0000000029477812;Rond-point;PL NEWTON;PL NEWTON;5;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CS;44109#0CS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354779.5 6689496.1 28, 354779.2 6689496 28, 354777.4 6689494.2 28, 354776.7 6689491.6 28, 354777.4 6689489 28, 354778.7 6689487.7 28.1)
TRONROUT0000000029477703;Route à 1 chaussée;R DESHOULIERES;R DESHOULIERES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;13;2;1;44109;44109;;;;441092424;441092424;;;;;;;;;;;;;commune;commune;Rue Deshoulières;Rue Deshoulières;;;44109_2424;44109_2424;;;;;LINESTRING Z (354779.5 6689496.1 28, 354720.2 6689612.7 29.5)
TRONROUT0000000029477792;Rond-point;PL NEWTON;PL NEWTON;5;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CS;44109#0CS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354784.9 6689495.4 28.1, 354784.4 6689495.9 28.1, 354781.8 6689496.6 28.1, 354779.5 6689496.1 28)
TRONROUT0000000029477663;Route à 1 chaussée;R DUGOMMIER;R DUGOMMIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;11;2;3;44109;44109;;;;441092612;441092612;;;;;;;;;;;;;commune;commune;Rue Dugommier;Rue Dugommier;;;44109_2612;44109_2612;;;;;LINESTRING Z (354955.1 6689524.5 21.3, 354903 6689513 23.2, 354872.8 6689506.5 24.4, 354786.7 6689490.6 27.7)
TRONROUT0000000029477704;Route à 1 chaussée;R MARCEAU;R MARCEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;7;18;44109;44109;;;;441095308;441095308;;;;;;;;;;;;;commune;commune;Rue Marceau;Rue Marceau;;;44109_5308;44109_5308;;;;;LINESTRING Z (354863.2 6689590.5 23.6, 354860.7 6689588.1 23.6, 354840.4 6689563.1 24.8, 354784.9 6689495.4 28.1)
TRONROUT0000000029473852;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354881.8 6689606 23.2, 354872.5 6689599.5 23.3, 354863.2 6689590.5 23.6)
TRONROUT0000000029474853;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354881.8 6689606 23.2, 354893 6689613.1 23.2)
TRONROUT0000000029474309;Sentier;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;6;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;5;;5;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354830.7 6689640.8 22.7, 354863.2 6689590.5 23.6)
TRONROUT0000000029475223;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354902.9 6689619.7 23.1, 354893 6689613.1 23.2)
TRONROUT0000000029473959;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354852.1 6689650.5 24.5, 354881.8 6689606 23.2)
TRONROUT0000000029474061;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354902.9 6689619.7 23.1, 354872.4 6689663.9 24.4)
TRONROUT0000000029474957;Route à 1 chaussée;R DESCARTES;R DESCARTES;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092420;441092420;;;;;;;;;;;;;commune;commune;Rue Descartes;Rue Descartes;;;44109_2420;44109_2420;;;;;LINESTRING Z (354852.1 6689650.5 24.5, 354846.1 6689647.3 24.3, 354841 6689644.6 24.4, 354830.7 6689640.8 22.7)
TRONROUT0000000029477718;Route à 1 chaussée;R DESCARTES;R DESCARTES;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:31:45;;;;;Calculé;20.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092420;441092420;;;;;;;;;;;;;commune;commune;Rue Descartes;Rue Descartes;;;44109_2420;44109_2420;;;;;LINESTRING Z (354640.9 6689519.2 30.5, 354651.1 6689530.9 30.5)
TRONROUT0000000029477756;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;23;;15;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354533.9 6689609 31.5, 354640.9 6689519.2 30.5)
TRONROUT0000000029477627;Route à 2 chaussées;BD GABRIEL GUIST'HAU;BD GABRIEL GUIST'HAU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;Calculé;20.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;18;;26;44109;44109;;;;441093412;441093412;;;;;;;;;;;;;commune;commune;Boulevard Gabriel Guist'Hau;Boulevard Gabriel Guist'Hau;;;44109_3412;44109_3412;;;;;LINESTRING Z (354651.1 6689530.9 30.5, 354547.9 6689619.9 31.5)
TRONROUT0000000029478041;Route à 1 chaussée;R MARIE ANNE DU BOCCAGE;R MARIE ANNE DU BOCCAGE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:26:01;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095387;441095387;;;;;;;;;;;;;commune;commune;Rue Marie Anne du Boccage;Rue Marie Anne du Boccage;;;44109_5387;44109_5387;;;;;LINESTRING Z (354501.6 6689595.2 30.7, 354509.9 6689598.9 31, 354533.9 6689609 31.5)
TRONROUT0000000029477777;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:26:01;;;;;Calculé;20.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354533.9 6689609 31.5, 354547.9 6689619.9 31.5)
TRONROUT0000000029477770;Route à 1 chaussée;R HAROUYS;R HAROUYS;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:26:01;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;32;7;26;7;44109;44109;;;;441094036;441094036;;;;;;;;;;;;;commune;commune;Rue Harouys;Rue Harouys;;;44109_4036;44109_4036;;;;;LINESTRING Z (354547.9 6689619.9 31.5, 354560.2 6689630.6 31, 354583 6689648.5 30.5, 354603.4 6689666.6 30.3)
TRONROUT0000000029477657;Route à 1 chaussée;IMP DE LA NOBILIERE;IMP DE LA NOBILIERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CT;44109#0CT;;;;;;;;;;;;;commune;commune;Impasse de la Nobilière;Impasse de la Nobilière;;;44109_5928;44109_5928;;;;;LINESTRING Z (354603.4 6689666.6 30.3, 354588.8 6689687.5 30.3, 354580.5 6689704 30.3, 354570.1 6689712 30.3)
TRONROUT0000000029477781;Route à 1 chaussée;R HAROUYS;R HAROUYS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;22;5;16;3;44109;44109;;;;441094036;441094036;;;;;;;;;;;;;commune;commune;Rue Harouys;Rue Harouys;;;44109_4036;44109_4036;;;;;LINESTRING Z (354603.4 6689666.6 30.3, 354638.5 6689692.3 30, 354669.1 6689716.5 29.8)
TRONROUT0000000029477617;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;15;30;21;34T;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354630.2 6689795 29.9, 354600.4 6689798.5 30.3, 354568.9 6689803 30.9)
TRONROUT0000000029477640;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;21;36;23B;40;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354568.9 6689803 30.9, 354542.2 6689807.1 30.9, 354525 6689810.9 31.1)
TRONROUT0000000029474488;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;6;;6;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354872.4 6689663.9 24.4, 354852.1 6689650.5 24.5)
TRONROUT0000000029474809;Sentier;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;6;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354898.9 6689662.9 24.2, 354886.7 6689680.4 24.8)
TRONROUT0000000029473531;Route à 1 chaussée;PL ARISTIDE BRIAND;PL ARISTIDE BRIAND;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;6.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090360;441090360;;;;;;;;;;;;;commune;commune;Place Aristide Briand;Place Aristide Briand;;;44109_0360;44109_0360;;;;;LINESTRING Z (354886.7 6689680.4 24.8, 354883.7 6689676.9 24.8, 354879.9 6689671.6 24.8, 354876.7 6689668 24.5, 354872.4 6689663.9 24.4)
TRONROUT0000000029473567;Route à 1 chaussée;R ALPHONSE GAUTTE;R ALPHONSE GAUTTE;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441090192;441090192;;;;;;;;;;;;;commune;commune;Rue Alphonse Gautté;Rue Alphonse Gautté;;;44109_0192;44109_0192;;;;;LINESTRING Z (354912.7 6689703.7 24.6, 354891.6 6689685.7 24.8, 354886.7 6689680.4 24.8)
TRONROUT0000002205717094;Route à 1 chaussée;ALL YVES COSSON;ALL YVES COSSON;5;Non;0;En service;2019-11-05 10:04:25;2023-03-17 03:41:53;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;;;;;;44109;44109;;;;44109#0TK;44109#0TK;;;;;;;;;;;;;commune;commune;Allée Yves Cosson;Allée Yves Cosson;;;44109_8591;44109_8591;;;;;LINESTRING Z (354830.7 6689640.8 22.7, 354829.4 6689644.3 25, 354822.4 6689656.6 25.4, 354789.1 6689705.8 26.7, 354766.9 6689739.6 27.6, 354764.5 6689746.5 27.8)
TRONROUT0000000029474795;Route à 1 chaussée;R FAUSTIN HELIE;R FAUSTIN HELIE;4;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GI;44109#0GI;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354895.3 6689721.9 24.2, 354912.7 6689703.7 24.6)
TRONROUT0000000029474640;Route à 1 chaussée;R FAUSTIN HELIE;R FAUSTIN HELIE;4;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GI;44109#0GI;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354895.3 6689721.9 24.2, 354847.2 6689772.3 25.5)
TRONROUT0000002274983456;Route à 1 chaussée;R HAROUYS;R HAROUYS;5;Non;0;En service;2021-11-17 15:54:41;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;14;44109;44109;;;;441094036;441094036;;;;;;;;;;;;;commune;commune;Rue Harouys;Rue Harouys;;;44109_4036;44109_4036;;;;;LINESTRING Z (354764.5 6689746.5 27.8, 354847.2 6689772.3 25.7)
TRONROUT0000000029473903;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354847.2 6689772.3 25.5, 354845.6 6689786.9 25.5)
TRONROUT0000000029474493;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;1;;4;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354847.2 6689772.3 25.5, 354863.2 6689779.7 25.5, 354874 6689789.3 25.7, 354879.5 6689796.8 26.2)
TRONROUT0000000029477705;Route à 1 chaussée;R DESCARTES;R DESCARTES;4;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:31:45;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;441092420;441092420;;;;;;;;;;;;;commune;commune;Rue Descartes;Rue Descartes;;;44109_2420;44109_2420;;;;;LINESTRING Z (354651.1 6689530.9 30.5, 354681.6 6689567.1 30, 354720.2 6689612.7 29.5)
TRONROUT0000000029477729;Route à 1 chaussée;R DESCARTES;R DESCARTES;4;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;9;10;15;24;44109;44109;;;;441092420;441092420;;;;;;;;;;;;;commune;commune;Rue Descartes;Rue Descartes;;;44109_2420;44109_2420;;;;;LINESTRING Z (354720.2 6689612.7 29.5, 354743 6689618.5 28.5, 354792.1 6689630.6 26.3, 354796.4 6689631.4 26.2, 354822.4 6689638.2 25.1, 354830.7 6689640.8 22.7)
TRONROUT0000000029477742;Route à 1 chaussée;R DESHOULIERES;R DESHOULIERES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092424;441092424;;;;;;;;;;;;;commune;commune;Rue Deshoulières;Rue Deshoulières;;;44109_2424;44109_2424;;;;;LINESTRING Z (354720.2 6689612.7 29.5, 354696.5 6689661 29.6, 354689.9 6689674.4 29.7, 354669.1 6689716.5 29.8)
TRONROUT0000002205717093;Sentier;ALL MICHEL CHAILLOU;ALL MICHEL CHAILLOU;6;Non;0;En service;2019-11-05 10:04:25;2022-12-10 14:57:12;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#0TJ;44109#0TJ;;;;;;;;;;;;;commune;commune;Allée Michel Chaillou;Allée Michel Chaillou;;;44109_5635;44109_5635;;;;;LINESTRING Z (354669.1 6689716.5 -1000, 354701.4 6689700.2 -1000, 354721.9 6689683.1 -1000, 354732.6 6689678.2 -1000)
TRONROUT0000000029477660;Route à 1 chaussée;R HAROUYS;R HAROUYS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;14;44109;44109;;;;441094036;441094036;;;;;;;;;;;;;commune;commune;Rue Harouys;Rue Harouys;;;44109_4036;44109_4036;;;;;LINESTRING Z (354669.1 6689716.5 29.8, 354695.4 6689724.8 29.2, 354739.3 6689738.5 28.2, 354756 6689743.8 27.9, 354764.5 6689746.5 27.8)
TRONROUT0000000029477623;Route à 1 chaussée;R DESHOULIERES;R DESHOULIERES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;32;25;30;19;44109;44109;;;;441092424;441092424;;;;;;;;;;;;;commune;commune;Rue Deshoulières;Rue Deshoulières;;;44109_2424;44109_2424;;;;;LINESTRING Z (354669.1 6689716.5 29.8, 354630.2 6689795 29.9)
TRONROUT0000000029477769;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;9;8;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354821.8 6689796.8 26.4, 354816.3 6689795.1 26.6, 354802 6689789.9 26.7, 354781.9 6689786 27, 354765.1 6689784.3 27.1, 354748.5 6689784 26.9, 354735.7 6689785 27.2, 354693.2 6689788.4 28.5)
TRONROUT0000000029477650;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;11;20B;13;30;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354693.2 6689788.4 28.5, 354667.5 6689790.6 29.1, 354634.7 6689794.4 29.8, 354630.2 6689795 29.9)
TRONROUT0000000029477667;Route à 1 chaussée;PAS SAINT-YVES;PAS SAINT-YVES;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;7B;2;1;44109;44109;;;;441097802;441097802;;;;;;;;;;;;;commune;commune;Passage Saint Yves;Passage Saint Yves;;;44109_7802;44109_7802;;;;;LINESTRING Z (354659.2 6689863.1 29, 354686.2 6689822.6 28.7, 354689.4 6689816.7 28.7, 354691.6 6689811 28.6, 354692.7 6689805.8 28.6, 354693.2 6689799.8 29.9, 354693.2 6689788.4 28.5)
TRONROUT0000000029477620;Route à 1 chaussée;PAS LOUIS LEVESQUE;PAS LOUIS LEVESQUE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;4;9;6;44109;44109;;;;441095113;441095113;;;;;;;;;;;;;commune;commune;Passage Louis Lévesque;Passage Louis Lévesque;;;44109_5113;44109_5113;;;;;LINESTRING Z (354773.9 6689845.6 27.5, 354769 6689850.2 28.9, 354766 6689853.1 29.5, 354743.9 6689874.1 28.5, 354710.2 6689906.2 29.8, 354705.2 6689910.5 29.8)
TRONROUT0000000029473600;Rond-point;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354845.6 6689786.9 27.7, 354848.9 6689786.3 27.6, 354852.1 6689787.1 27.5, 354855.1 6689789.4 27.8, 354856.7 6689791.9 28.2, 354856.9 6689792.2 28)
TRONROUT0000000029474280;Rond-point;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354839.3 6689798.7 27.9, 354838.8 6689794.7 27.7, 354840.6 6689791.4 27.6, 354842.7 6689788.8 27.7, 354845.6 6689786.9 27.7)
TRONROUT0000000029473845;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354856.9 6689792.2 28.2, 354863.7 6689796.8 28.4, 354867.8 6689798.7 28.2, 354870.6 6689799.2 27.7, 354877.8 6689798.3 27.7)
TRONROUT0000000029474028;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354877.8 6689798.3 26, 354879.5 6689796.8 26.2)
TRONROUT0000000029477804;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354839.3 6689798.7 26.5, 354821.8 6689796.8 26.4)
TRONROUT0000000029474246;Rond-point;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354856.9 6689792.2 28, 354857.6 6689795.4 28.4, 354857.2 6689798.8 28.8, 354855.8 6689802.1 29.3, 354853.4 6689804.6 29.1, 354850.2 6689806.1 29, 354846.8 6689806.5 28.7, 354843.4 6689805.1 28.7)
TRONROUT0000000029474091;Rond-point;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354843.4 6689805.1 28.7, 354840.9 6689802.6 28.6, 354839.3 6689798.7 27.9)
TRONROUT0000000029474492;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;6;;5;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354877.8 6689798.3 26, 354874.1 6689800.1 26.4, 354869.8 6689804.4 26.4, 354862.9 6689810.7 26.6, 354852.1 6689821.3 26.7, 354845 6689830 26.9)
TRONROUT0000000029474499;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354845 6689830 26.9, 354845.8 6689819.1 26.7, 354845.1 6689813.2 26.6, 354843.4 6689805.1 26.5)
TRONROUT0000000029477624;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;21;15B;18;15B;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354821.8 6689796.8 26.4, 354773.9 6689845.6 27.5)
TRONROUT0000000029474197;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;10;;7;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354836.1 6689866.5 28.3, 354838.7 6689861.3 28.3, 354839.9 6689855.9 28.3, 354845 6689830 26.9)
TRONROUT0000000029477635;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;;13;;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354773.9 6689845.6 27.5, 354795.9 6689873.6 28.4, 354810.7 6689892.5 29)
TRONROUT0000000029477641;Route à 1 chaussée;PL EDOUARD NORMAND;PL EDOUARD NORMAND;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;11;;12;44109;44109;;;;441092732;441092732;;;;;;;;;;;;;commune;commune;Place Edouard Normand;Place Edouard Normand;;;44109_2732;44109_2732;;;;;LINESTRING Z (354810.7 6689892.5 29, 354830.9 6689873.4 28.6, 354836.1 6689866.5 28.3)
TRONROUT0000000029473495;Route à 1 chaussée;R JOSEPH CAILLE;R JOSEPH CAILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;14;15;2;1;44109;44109;;;;441094568;441094568;;;;;;;;;;;;;commune;commune;Rue Joseph Caillé;Rue Joseph Caillé;;;44109_4568;44109_4568;;;;;LINESTRING Z (354836.1 6689866.5 28.3, 354844.7 6689873.2 28.6, 354870.9 6689893.8 30.3, 354888.4 6689909.8 30.9, 354898.7 6689921.8 30.9, 354911.9 6689941.1 30.9, 354917.6 6689963.1 30.9)
TRONROUT0000002205718679;Route à 1 chaussée;R MENOU;R MENOU;4;Non;0;En service;2019-11-05 14:11:35;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;9;10;5;44109;44109;;;;441095588;441095588;;;;;;;;;;;;;commune;commune;Rue Menou;Rue Menou;;;44109_5588;44109_5588;;;;;LINESTRING Z (354848.9 6689939.5 30.5, 354844.8 6689934.6 30.3, 354810.7 6689892.5 29)
TRONROUT0000002205718678;Route à 1 chaussée;ALL DES SOEURS DE L'ESPERANCE;ALL DES SOEURS DE L'ESPERANCE;5;Non;0;En service;2019-11-05 14:11:35;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097933;441097933;;;;;;;;;;;;;commune;commune;Allée des Soeurs de l'Espérance;Allée des Soeurs de l'Espérance;;;44109_7933;44109_7933;;;;;LINESTRING Z (354792.8 6689969.7 30.5, 354814.2 6689970 30.5, 354818.9 6689966.2 30.5, 354848.9 6689939.5 30.5)
TRONROUT0000000029477707;Route à 1 chaussée;R MENOU;R MENOU;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;3;2;1;44109;44109;;;;441095588;441095588;;;;;;;;;;;;;commune;commune;Rue Menou;Rue Menou;;;44109_5588;44109_5588;;;;;LINESTRING Z (354893.3 6689994.5 31.5, 354848.9 6689939.5 30.5)
TRONROUT0000002205718680;Route à 1 chaussée;ALL DES SOEURS DE L'ESPERANCE;ALL DES SOEURS DE L'ESPERANCE;5;Non;0;En service;2019-11-05 14:11:35;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441097933;441097933;;;;;;;;;;;;;commune;commune;Allée des Soeurs de l'Espérance;Allée des Soeurs de l'Espérance;;;44109_7933;44109_7933;;;;;LINESTRING Z (354773.3 6689969.4 30.5, 354792.8 6689969.7 30.5)
TRONROUT0000000029473942;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;30;;30;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354901.3 6689971.4 31.2, 354893.3 6689994.5 31.5)
TRONROUT0000000029475158;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;28;;28;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354893.3 6689994.5 31.5, 354879.3 6690035.6 31.5)
TRONROUT0000000029477730;Route à 1 chaussée;R DOCTEUR BRINDEAU;R DOCTEUR BRINDEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;5;4;33;30;44109;44109;;;;441092496;441092496;;;;;;;;;;;;;commune;commune;Rue Docteur Brindeau;Rue Docteur Brindeau;;;44109_2496;44109_2496;;;;;LINESTRING Z (354568.9 6689803 30.9, 354565.4 6689875.5 31.1, 354564.2 6689901.8 32.3, 354563.3 6689906.3 32.3, 354534.5 6689968 32.3)
TRONROUT0000000029477615;Route à 1 chaussée;PAS SAINT-YVES;PAS SAINT-YVES;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;28;29;4B;9;44109;44109;;;;441097802;441097802;;;;;;;;;;;;;commune;commune;Passage Saint Yves;Passage Saint Yves;;;44109_7802;44109_7802;;;;;LINESTRING Z (354583.5 6690046.2 32, 354585.2 6690035.4 32.1, 354585.3 6690034.9 32.1, 354595.4 6689975 31.2, 354599.5 6689955.6 30.9, 354601.2 6689951.5 30.9, 354609.2 6689937.2 30.9, 354651.4 6689874.8 29.3, 354659.2 6689863.1 29)
TRONROUT0000000029477613;Route à 1 chaussée;R DOCTEUR BRINDEAU;R DOCTEUR BRINDEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;35;30;43;40;44109;44109;;;;441092496;441092496;;;;;;;;;;;;;commune;commune;Rue Docteur Brindeau;Rue Docteur Brindeau;;;44109_2496;44109_2496;;;;;LINESTRING Z (354534.5 6689968 32.3, 354532.1 6689974.7 31.8, 354530.6 6689984.3 32, 354523.8 6690048.1 31.7)
TRONROUT0000000029477700;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;21;26;25;36;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354681.2 6690043.1 32.6, 354602.6 6690045.6 32.1)
TRONROUT0000000029477678;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;42;;42;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354602.6 6690045.6 32.1, 354583.5 6690046.2 32)
TRONROUT0000000029477689;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;31;44;37;66;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354583.5 6690046.2 32, 354523.8 6690048.1 31.7)
TRONROUT0000000029477648;Route à 1 chaussée;AV LIEUTENANT COIFFARD;AV LIEUTENANT COIFFARD;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;13;12;44109;44109;;;;441094968;441094968;;;;;;;;;;;;;commune;commune;Avenue Lieutenant Coiffard;Avenue Lieutenant Coiffard;;;44109_4968;44109_4968;;;;;LINESTRING Z (354602.6 6690045.6 32.1, 354602.7 6690051.7 32.1, 354603.3 6690104.2 32.4)
TRONROUT0000000029478518;Route à 1 chaussée;IMP D'HAVELOOZE;IMP D'HAVELOOZE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;1;6;44109;44109;;;;441094089;441094089;;;;;;;;;;;;;commune;commune;Impasse d'Havelooze;Impasse d'Havelooze;;;44109_4089;44109_4089;;;;;LINESTRING Z (354510.3 6690145.6 31.9, 354537.1 6690133.7 31.9)
TRONROUT0000000029477639;Route à 1 chaussée;R DE MISERICORDE;R DE MISERICORDE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;33;;13;44109;44109;;;;441095680;441095680;;;;;;;;;;;;;commune;commune;Rue de Miséricorde;Rue de Miséricorde;;;44109_5680;44109_5680;;;;;LINESTRING Z (354686.3 6690113.2 33.2, 354681.6 6690115.1 33.2, 354677.4 6690116.4 33.2, 354673.6 6690118 33.2, 354521.2 6690173 31.9)
TRONROUT0000000029478173;Route à 1 chaussée;R D'HAVELOOZE;R D'HAVELOOZE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;16;21;14;15;44109;44109;;;;441094090;441094090;;;;;;;;;;;;;commune;commune;Rue d'Havelooze;Rue d'Havelooze;;;44109_4090;44109_4090;;;;;LINESTRING Z (354521.2 6690173 31.9, 354510.3 6690145.6 31.9)
TRONROUT0000000317154543;Route à 1 chaussée;PETIT PASSAGE SAINT-YVES;PETIT PASSAGE SAINT-YVES;5;Non;0;En service;2013-01-07 18:15:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;5;;44109;44109;;;;44109#0D2;44109#0D2;;;;;;;;;;;;;commune;commune;Petit Passage Saint Yves;Petit Passage Saint Yves;;;44109_6487;44109_6487;;;;;LINESTRING Z (354659.2 6689863.1 29, 354698.5 6689903.4 29.6)
TRONROUT0000000029477622;Route à 1 chaussée;PETIT PASSAGE SAINT-YVES;PETIT PASSAGE SAINT-YVES;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0D2;44109#0D2;;;;;;;;;;;;;commune;commune;Petit Passage Saint Yves;Petit Passage Saint Yves;;;44109_6487;44109_6487;;;;;LINESTRING Z (354698.5 6689903.4 29.6, 354705.2 6689910.5 29.8)
TRONROUT0000000295264851;Route à 1 chaussée;PAS LOUIS LEVESQUE;PAS LOUIS LEVESQUE;5;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;11;6B;19;12;44109;44109;;;;441095113;441095113;;;;;;;;;;;;;commune;commune;Passage Louis Lévesque;Passage Louis Lévesque;;;44109_5113;44109_5113;;;;;LINESTRING Z (354705.2 6689910.5 29.8, 354704.4 6689911.2 29.8, 354695.7 6689920.5 29.8, 354693.3 6689924.6 29.9, 354691.7 6689932.6 30.1, 354689.8 6689952.4 30.5, 354682.3 6690031.3 32.1, 354682.2 6690032.4 32.1, 354681.2 6690043.1 32.6)
TRONROUT0000000029477805;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;9;14;9;18;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354779.2 6690039 33, 354752.7 6690039.6 33.2, 354736.5 6690039.9 33.3)
TRONROUT0000000029477754;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;11;20;19;26;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354736.5 6690039.9 33.3, 354681.2 6690043.1 32.6)
TRONROUT0000000029477614;Route à 1 chaussée;R DE MISERICORDE;R DE MISERICORDE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;16B;;2;;44109;44109;;;;441095680;441095680;;;;;;;;;;;;;commune;commune;Rue de Miséricorde;Rue de Miséricorde;;;44109_5680;44109_5680;;;;;LINESTRING Z (354686.3 6690113.2 33.2, 354689.7 6690110.8 33.4, 354694.2 6690105.6 33.4, 354733.5 6690057.2 33.4, 354735.9 6690051.5 33.3, 354736.5 6690039.9 33.3)
TRONROUT0000000029477714;Route à 1 chaussée;R BERGERE;R BERGERE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;13;2;1;44109;44109;;;;441090760;441090760;;;;;;;;;;;;;commune;commune;Rue Bergère;Rue Bergère;;;44109_0760;44109_0760;;;;;LINESTRING Z (354774.1 6690162.7 34.2, 354779.2 6690039 33)
TRONROUT0000000029477848;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354641.4 6690158.2 34.9, 354667.6 6690133.3 34.4, 354682.5 6690120.6 34.2)
TRONROUT0000000029477702;Route à 1 chaussée;R DU BOURGET;R DU BOURGET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;1;10;44109;44109;;;;441091152;441091152;;;;;;;;;;;;;commune;commune;Rue du Bourget;Rue du Bourget;;;44109_1152;44109_1152;;;;;LINESTRING Z (354686.3 6690113.2 33.2, 354716.5 6690173.8 35.3, 354729 6690197.4 34.8)
TRONROUT0000000295264746;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354653.2 6690171.5 35, 354667 6690185.1 35.1)
TRONROUT0000000029474355;Rond-point;;;4;Non;0;En service;2006-10-04 09:41:10;2018-11-13 07:54:47;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354874 6690038.6 30.6, 354875.5 6690037 30.6, 354877.4 6690035.8 30.6, 354879.3 6690035.6 30.6)
TRONROUT0000000029477803;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;12;7;2;1;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354779.2 6690039 33, 354784.9 6690038.9 32.3, 354835.8 6690038.2 31.3, 354874 6690038.6 30.6)
TRONROUT0000000029474342;Rond-point;;;4;Non;0;En service;2006-10-04 09:41:10;2018-11-13 07:54:47;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354879.3 6690035.6 30.6, 354880.1 6690035.5 30.6, 354882 6690036.3 30.6, 354883.4 6690038 30.6, 354884.3 6690040.7 30.6, 354884.3 6690043 30.6, 354883.6 6690044.7 30.6, 354881.9 6690045.9 30.6, 354879.3 6690046.5 30.6, 354876.7 6690046.4 30.6, 354875 6690045.2 30.6)
TRONROUT0000000029474351;Rond-point;;;4;Non;0;En service;2006-10-04 09:41:10;2018-11-13 07:54:47;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354875 6690045.2 30.6, 354873.6 6690042.9 30.6, 354873.5 6690041.2 30.6, 354874 6690038.6 30.6)
TRONROUT0000000029474430;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;27;;24;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354859.3 6690094.4 33.3, 354858.7 6690086.6 32.2, 354859.5 6690082.4 32.2, 354861.5 6690075.2 31.6, 354867.8 6690061.9 31.1, 354872.7 6690051.5 31.1, 354875 6690045.2 30.6)
TRONROUT0000000029474400;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;23;;22;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354885.4 6690124.7 32.3, 354881 6690119.9 31.9, 354875 6690112.5 31.5, 354862.6 6690096.7 31.9, 354859.3 6690094.4 33.3)
TRONROUT0000000029474631;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354894.2 6690130.7 31.2, 354890.1 6690127.9 31.7, 354885.4 6690124.7 32.3)
TRONROUT0000000029477685;Route à 1 chaussée;R D'AUVOURS;R D'AUVOURS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;8B;11;8B;44109;44109;;;;441090480;441090480;;;;;;;;;;;;;commune;commune;Rue d'Auvours;Rue d'Auvours;;;44109_0480;44109_0480;;;;;LINESTRING Z (354774.1 6690162.7 34.2, 354859.3 6690094.4 33.3)
TRONROUT0000000029474975;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354903.2 6690135.6 31.1, 354894.2 6690130.7 31.2)
TRONROUT0000000029475001;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354894.2 6690130.7 31.2, 354890.6 6690138.5 33.8)
TRONROUT0000000220005324;Route à 1 chaussée;R DES BOIRES;R DES BOIRES;5;Non;0;En service;2009-04-02 09:42:50;2023-05-26 09:18:12;;;;;Levé GPS;2.5;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HX;44109#0HX;;;;;;;;;;;;;commune;commune;Rue des Boires;Rue des Boires;;;44109_0913;44109_0913;;;;;LINESTRING Z (356233.4044904433 6688312.003221275 7.127430686765968, 356231.2 6688339.3 8.1)
TRONROUT0000000220005325;Route à 1 chaussée;R DES STEAMERS DE LOIRE;R DES STEAMERS DE LOIRE;5;Non;0;En service;2009-04-02 09:42:50;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0I6;44109#0I6;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Rue des Steamers de Loire;Rue des Steamers de Loire;;;44109_7971;44109_7971;;;;;LINESTRING Z (356355.7 6688359.5 7.8, 356357.4 6688344.2 5.6, 356357.8 6688336.4 7.9, 356358.7 6688327.7 8, 356359.6 6688317.8 8.2, 356360.2956134469 6688312.003221275 8.362309804286784)
TRONROUT0000000224176919;Route à 1 chaussée;R DES FRERES MANO;R DES FRERES MANO;5;Non;0;En service;2009-09-09 16:27:07;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#09Q;44109#09Q;;;;;;;;;;;;;commune;commune;Rue des Frères Mano;Rue des Frères Mano;;;44109_3366;44109_3366;;;;;LINESTRING Z (356275.8027030328 6688312.003221275 6.784568327597402, 356273.1 6688349.1 7.7)
TRONROUT0000000220005333;Route à 1 chaussée;R DES BOIRES;R DES BOIRES;5;Non;0;En service;2009-04-02 09:42:50;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HX;44109#0HX;;;;;;;;;;;;;commune;commune;Rue des Boires;Rue des Boires;;;44109_0913;44109_0913;;;;;LINESTRING Z (356226.6 6688340 8.1, 356228.879487203 6688312.003221275 7.5155161017850265)
TRONROUT0000000326049878;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;4.0;14.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356226.6 6688340 8.1, 356231.2 6688339.3 8.1)
TRONROUT0000000326049877;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;4.0;14.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356222.9 6688346.9 8, 356222.7 6688346.2 8.1, 356223.5 6688342.6 8, 356226.6 6688340 8.1)
TRONROUT0000000348676008;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2015-03-10 16:43:46;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;4.0;14.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356231.2 6688339.3 8.1, 356236.6 6688339.5 8.1, 356242.3 6688339.7 7.9, 356248.4 6688340.5 8.2, 356254.4 6688341.1 8.1, 356259.9 6688341.6 8.1, 356264.8 6688342 7.8, 356268.5 6688343.2 8, 356271.4 6688345.6 7.7, 356273.1 6688349.1 7.7)
TRONROUT0000000326049870;Route à 1 chaussée;;;5;Non;0;En service;2013-09-05 19:15:48;2020-02-12 17:33:37;;;;;Levé non GPS;5.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356222.9 6688346.9 8, 356272.9 6688351.5 7.7)
TRONROUT0000000326049868;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;4.0;14.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356273.1 6688349.1 7.7, 356272.9 6688351.5 7.7)
TRONROUT0000000326049869;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2023-05-26 09:18:12;;;;;Levé GPS;2.5;Levé GPS;1.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356272.9 6688351.5 7.7, 356272.9 6688353.3 7.6, 356270.1 6688356.5 7.6, 356264.5 6688358 7.6, 356257.7 6688357.6 7.6, 356250.6 6688357.1 7.5, 356243.8 6688356.4 7.6, 356237.6 6688355.7 7.8, 356232 6688355 7.7, 356223.9 6688350 7.7, 356222.9 6688346.9 8)
TRONROUT0000000029474681;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-29 12:07:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356443.3 6688368.1 8.4, 356461.2 6688327.9 8.8, 356469.1396452598 6688312.003221275 8.83497641083615)
TRONROUT0000000329965167;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-11-29 12:07:14;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;6;5;6;5;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356355.7 6688359.5 7.8, 356380.7 6688361.9 7.9, 356407.8 6688364.2 8, 356413.6 6688364.7 8)
TRONROUT0000000029474793;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356413.6 6688364.7 8, 356426.8 6688366.1 8.1, 356443.3 6688368.1 8.4)
TRONROUT0000000029474379;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;3;2;3;4;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356506.81139568595 6688371.573847092 7.920871763599154, 356478.8 6688369.2 8, 356443.3 6688368.1 8.4)
TRONROUT0000000029474808;Route à 1 chaussée;R FRANCOIS ALBERT;R FRANCOIS ALBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093291;441093291;;;;;;;;;;;;;commune;commune;Rue François Albert;Rue François Albert;;;44109_3291;44109_3291;;;;;LINESTRING Z (356370.7 6688468.1 8.2, 356386.3 6688430 8.3, 356401.5 6688394.5 8, 356413.6 6688364.7 8)
TRONROUT0000000329622980;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356487.2 6688481.5 10, 356503.7 6688460.9 9.6, 356506.81139568595 6688455.276297239 9.56134912191345)
TRONROUT0000000295265427;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;7.5;;;;Non;1;;1;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356386.5 6688474.1 8.2, 356401 6688463.4 9, 356410.3 6688456.4 10, 356417.1 6688450.3 10.1, 356420.9 6688447 10.3, 356426.3 6688445 10.4, 356431.9 6688444.9 10.4)
TRONROUT0000000295265430;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;7.5;;;;Non;;;;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356431.9 6688444.9 10.4, 356442.9 6688448.8 10.4, 356448.1 6688450.8 10.4, 356458.2 6688455.5 10.3, 356461.4 6688457.9 10.3, 356462.7 6688460.1 10.3, 356462.6 6688463.6 10.3, 356460.7 6688470.3 10.3, 356458.2 6688475.5 10.3)
TRONROUT0000000029474446;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356370.7 6688468.1 8.2, 356386.5 6688474.1 8.2)
TRONROUT0000000295265396;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356458.2 6688475.5 10.3, 356473.9 6688478.8 10.1)
TRONROUT0000000224176922;Sentier;PL DES FONDERIES;PL DES FONDERIES;6;Non;0;En service;2009-09-09 16:27:07;2022-12-10 14:57:12;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;2;1;2;1;44109;44109;;;;44109#0HW;44109#0HW;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Place des Fonderies;Place des Fonderies;;;44109_3182;44109_3182;;;;;LINESTRING Z (356088.5 6688326.1 7.8, 356090.2 6688321.3 7.7, 356091.17860828683 6688312.003221275 7.7)
TRONROUT0000000326049875;Rond-point;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356079.9 6688331.9 8, 356080.3 6688330.5 8, 356081 6688329.2 8, 356081.9 6688328.1 8, 356083 6688327.2 8, 356084.3 6688326.5 8, 356085.7 6688326.1 8, 356087.1 6688326 8, 356088.5 6688326.1 8)
TRONROUT0000000326049872;Rond-point;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356088.5 6688326.1 8, 356089.9 6688326.5 8, 356091.2 6688327.2 8, 356092.3 6688328.1 8, 356093.2 6688329.2 8, 356093.9 6688330.5 8, 356094.3 6688331.9 8, 356094.4 6688333.3 8)
TRONROUT0000000295265414;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;24;29;24;29;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356046.5 6688329.7 7.4, 356079.9 6688331.9 8)
TRONROUT0000000326049873;Route à 1 chaussée;;;5;Non;0;En service;2013-09-05 19:15:48;2020-02-12 17:33:37;;;;;Levé non GPS;5.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356094.4 6688333.3 8, 356079.9 6688331.9 8)
TRONROUT0000000326049876;Rond-point;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356085.7 6688340.5 8, 356084.3 6688340.1 8, 356083 6688339.4 8, 356081.9 6688338.5 8, 356081 6688337.4 8, 356080.3 6688336.1 8, 356079.9 6688334.7 8, 356079.8 6688333.3 8, 356079.9 6688331.9 8)
TRONROUT0000000326049874;Rond-point;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2013-09-05 19:15:48;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356094.4 6688333.3 8, 356094.3 6688334.7 8, 356093.9 6688336.1 8, 356093.2 6688337.4 8, 356092.3 6688338.5 8, 356091.2 6688339.4 8, 356089.9 6688340.1 8, 356088.5 6688340.5 8, 356087.1 6688340.6 8, 356085.7 6688340.5 8)
TRONROUT0000000220005328;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2009-04-02 09:42:50;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;8;;10;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356222.9 6688346.9 8, 356094.4 6688333.3 8)
TRONROUT0000000029474264;Route à 1 chaussée;R DES FRANCAIS LIBRES;R DES FRANCAIS LIBRES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;20;97;20;25;44109;44109;;;;441093263;441093263;;;;;;;;;;;;;commune;commune;Rue des Français Libres;Rue des Français Libres;;;44109_3263;44109_3263;;;;;LINESTRING Z (356085.7 6688340.5 8, 356067.9 6688399.9 7.9, 356046.6 6688450.4 8, 356034.1 6688477.8 7.9, 356032.2 6688480.8 7.9)
TRONROUT0000000029473644;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356140.7 6688535.2 7.4, 356124 6688528.7 7.5, 356040.6 6688494.7 7.5, 356035.7 6688490 7.5, 356033.2 6688488 7.5)
TRONROUT0000002200208191;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2018-12-18 18:28:36;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356272.9 6688351.5 7.7, 356327.7 6688356.8 7.7)
TRONROUT0000000220005326;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2009-04-02 09:42:50;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (356327.7 6688356.8 7.7, 356355.7 6688359.5 7.8)
TRONROUT0000002004822302;Sentier;ALL PAULINE-ISABELLE UTILE;ALL PAULINE-ISABELLE UTILE;6;Non;0;En service;2017-07-28 17:55:21;2022-12-10 14:57:12;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;1;2;9;10;44109;44109;;;;44109#0QY;44109#0QY;;;;;;;;;;;;;commune;commune;Allée Pauline-Isabelle Utile;Allée Pauline-Isabelle Utile;;;44109_6259;44109_6259;;;;;LINESTRING Z (356308 6688498.1 -1000, 356358.9 6688376.3 -1000)
TRONROUT0000002200208194;Route à 1 chaussée;AV EUGENIE BRAZIER;AV EUGENIE BRAZIER;5;Non;0;En service;2018-12-18 18:28:42;2019-12-05 10:26:42;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;Plot amovible;;;;;;Non;;;;;44109;44109;;;;44109#0R1;44109#0R1;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356250.8 6688578.8 -1000, 356285 6688494.6 -1000, 356287.5 6688487.4 -1000, 356286.3 6688480.6 -1000, 356282.8 6688468.9 -1000, 356284.7 6688462.6 -1000, 356327.7 6688356.8 -1000)
TRONROUT0000000029473633;Route à 1 chaussée;R FRANCOIS ALBERT;R FRANCOIS ALBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093291;441093291;;;;;;;;;;;;;commune;commune;Rue François Albert;Rue François Albert;;;44109_3291;44109_3291;;;;;LINESTRING Z (356329 6688567.1 7.8, 356345.4 6688530.3 8.3, 356352.4 6688513.4 8.2, 356370.7 6688468.1 8.2)
TRONROUT0000002007432832;Sentier;PL CLEMENCE LEFEUVRE;PL CLEMENCE LEFEUVRE;6;Non;0;En service;2017-12-04 15:37:14;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;6;;1;;44109;44109;;;;44109#0RK;44109#0RK;;;;;;;;;;;;;commune;commune;Place Clémence Lefeuvre;Place Clémence Lefeuvre;;;44109_1957;44109_1957;;;;;LINESTRING Z (356308 6688498.1 -1000, 356288.1 6688548 -1000, 356314.1 6688562.4 -1000, 356329 6688567.1 -1000)
TRONROUT0000000295265309;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356250.8 6688578.8 7.4, 356240.9 6688574.6 7.4)
TRONROUT0000000295265318;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2017-11-28 11:01:55;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356366.2 6688583.1 10.5, 356353.2 6688587.2 9.2, 356343.1 6688586.1 8.5, 356335 6688578.9 7.9, 356329 6688567.1 7.8)
TRONROUT0000002215754256;Route à 1 chaussée;R FRANCOIS ALBERT;R FRANCOIS ALBERT;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093291;441093291;;;;;;;;;;;;;commune;commune;Rue François Albert;Rue François Albert;;;44109_3291;44109_3291;;;;;LINESTRING Z (356329 6688567.1 7.8, 356319.4 6688589 7.2)
TRONROUT0000002206012521;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2019-12-05 10:26:42;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356271.6 6688587.7 7.4, 356250.8 6688578.8 7.4)
TRONROUT0000000295265479;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356473.9 6688478.8 10.1, 356487.2 6688481.5 10)
TRONROUT0000000295265455;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356473.9 6688478.8 10, 356479.1 6688493.2 10)
TRONROUT0000000295265469;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356479.1 6688493.2 10, 356487.2 6688481.5 10)
TRONROUT0000000029473521;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;7.5;;;;Non;5;;5;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356398.8 6688539.4 10.6, 356401.9 6688532 10.6, 356402.4 6688529.7 10.6, 356401.5 6688527.1 10.6, 356397.9 6688523.4 10.6, 356393.7 6688517.7 10.1, 356391.6 6688511.6 10, 356389.4 6688503.6 9.6, 356387.9 6688494.4 9.1, 356387.2 6688484.3 9, 356387.2 6688484.1 8.9, 356387.2 6688478.9 8.7, 356386.5 6688474.1 8.2)
TRONROUT0000000029473494;Route à 2 chaussées;BD GENERAL DE GAULLE;BD GENERAL DE GAULLE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093562;441093562;;;;;;;;;;;;;commune;commune;Boulevard Général de Gaulle;Boulevard Général de Gaulle;;;44109_3562;44109_3562;;;;;LINESTRING Z (356460.4 6688592.7 11, 356468.4 6688571.9 10.4, 356480.1 6688549.3 10.1, 356483.3 6688541.9 9.7, 356486.9 6688534.5 9.9, 356490.3 6688527.5 9.8, 356493.6 6688520.6 9.9, 356496.8 6688513.6 9.8, 356500.2 6688506.2 9.8, 356503.8 6688498.6 9.8, 356506.81139568595 6688492.345562806 9.722784726004683)
TRONROUT0000000295265433;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;7.5;;;;Non;3;;3;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356458.2 6688475.5 10.3, 356449.2 6688494.4 10.3, 356435.7 6688522.4 10.3, 356422 6688549.7 10.3, 356419.1 6688555.9 10.6)
TRONROUT0000000053385267;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:26:37;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356442.7 6688646.5 8.7, 356454.7 6688619.1 11.6, 356471.9 6688581.2 10.4, 356506.81139568595 6688509.576845174 9.69550995252646)
TRONROUT0000000053385261;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:26:37;2021-08-27 18:05:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6688523.322608861 9.353200199617897, 356505.8 6688525.4 9.4, 356460 6688618 9.4, 356451.3 6688636 11, 356445.3 6688647.3 8.3)
TRONROUT0000000295265404;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356432.8 6688571.9 10, 356439.6 6688570.6 10, 356442.5 6688568.6 10, 356444.3 6688564.7 10, 356444.3 6688563.1 10, 356441.6 6688560.7 10, 356438.6 6688558.1 10, 356438 6688555.3 10, 356438.3 6688552.9 10, 356479.1 6688493.2 10)
TRONROUT0000000318045662;Route à 1 chaussée;R FRANCOISE GIROUD;R FRANCOISE GIROUD;5;Non;0;En service;2013-01-28 10:16:04;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;1;;11;44109;44109;;;;44109#0P3;44109#0P3;;;;;;;;;;;;;commune;commune;Rue Françoise Giroud;Rue Françoise Giroud;;;44109_3325;44109_3325;;;;;LINESTRING Z (356506.81139568595 6688567.794872461 7.397711597363864, 356487.4 6688607.5 6.8)
TRONROUT0000000295265434;Route à 1 chaussée;ALL DE LA CITE;ALL DE LA CITE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;7.5;;;;Non;;;;;44109;44109;;;;441091918;441091918;;;;;;;;;;;;;commune;commune;Allée de la Cité;Allée de la Cité;;;44109_1918;44109_1918;;;;;LINESTRING Z (356419.1 6688555.9 10.6, 356415.7 6688557.1 10.6, 356411.6 6688556.7 10.6, 356407.1 6688554.7 10.6, 356405.1 6688553.9 10.6, 356398.4 6688550.6 10.6, 356397.4 6688549.8 10.6, 356396.5 6688548.3 10.6, 356396.4 6688546.2 10.6, 356397.2 6688543.5 10.6, 356398.8 6688539.4 10.6)
TRONROUT0000000039537086;Route à 2 chaussées;BD GENERAL DE GAULLE;BD GENERAL DE GAULLE;3;Non;0;En service;2006-11-07 13:35:09;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093562;441093562;;;;;;;;;;;;;commune;commune;Boulevard Général de Gaulle;Boulevard Général de Gaulle;;;44109_3562;44109_3562;;;;;LINESTRING Z (356506.81139568595 6688540.5060690595 9.70962014379669, 356504.1 6688546.2 9.8, 356500.9 6688553.2 9.9, 356497.5 6688560.1 10, 356494.6 6688566.5 10.1, 356491.8 6688572.3 10.4, 356488.7 6688578.4 10.8, 356485.1 6688584.9 11, 356481.1 6688591.5 11.1, 356476.5 6688598.1 11.3, 356471.3 6688605 11.1, 356448.6 6688648.7 11.8)
TRONROUT0000000295265490;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356398.8 6688539.4 10.6, 356391.1 6688538 10.6, 356388.7 6688538.2 10.6, 356385.9 6688541 10.6, 356366.2 6688583.1 10.6)
TRONROUT0000000295265402;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-05-24 11:05:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356432.8 6688571.9 10, 356423.7 6688568 10, 356419.1 6688555.9 10.6)
TRONROUT0000000295265477;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356443.3 6688576.4 10, 356432.8 6688571.9 10)
TRONROUT0000000295265495;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356437 6688589.9 9.9, 356443.3 6688576.4 10)
TRONROUT0000000295265499;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356443.3 6688576.4 10, 356448.3 6688578.1 10, 356460.4 6688592.7 11)
TRONROUT0000000295265416;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356432.6 6688597.9 9.9, 356430.3 6688595 9.9, 356437 6688589.9 9.9)
TRONROUT0000000295265465;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356366.2 6688583.1 10.5, 356421.1 6688607.9 10.6)
TRONROUT0000000295265464;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356437 6688589.9 9.9, 356441.8 6688597.7 9.9, 356438.9 6688600.6 9.9, 356436 6688601.3 9.9)
TRONROUT0000000295265497;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356436 6688601.3 9.9, 356432.6 6688597.9 9.9)
TRONROUT0000000295265498;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356421.1 6688607.9 7, 356424.8 6688604.5 8.3, 356427.6 6688601.8 8.9, 356429.7 6688599.8 9, 356432.6 6688597.9 9.9)
TRONROUT0000002330332029;Route à 1 chaussée;R NATHALIE SARRAUTE;R NATHALIE SARRAUTE;5;Non;0;En service;2023-02-27 08:17:17;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.5;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;8;;2;;44109;44109;;;;44109#0P2;44109#0P2;;;;;;;;;;;;;commune;commune;Rue Nathalie Sarraute;Rue Nathalie Sarraute;;;44109_5891;44109_5891;;;;;LINESTRING Z (356487.4 6688607.5 -1000, 356506.81139568595 6688615.264558274 -1000)
TRONROUT0000000295265398;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356436 6688601.3 9.9, 356435.2 6688606.1 9.9, 356435.9 6688608.4 9.9, 356436 6688611 9.9, 356433.9 6688613.9 9.9, 356431.7 6688615.1 9.9, 356429.7 6688617.3 9.9, 356427.5 6688618.8 9.9, 356426.9 6688621.5 9.9, 356425.1 6688624.5 9.9, 356423.4 6688627.4 9.8, 356420.5 6688629.1 9.8, 356417.4 6688629.6 9.8)
TRONROUT0000000295265314;Route à 2 chaussées;BD GENERAL DE GAULLE;BD GENERAL DE GAULLE;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093562;441093562;;;;;;;;;;;;;commune;commune;Boulevard Général de Gaulle;Boulevard Général de Gaulle;;;44109_3562;44109_3562;;;;;LINESTRING Z (356439.3 6688645.1 12.1, 356460 6688593.7 11.1, 356460.4 6688592.7 11)
TRONROUT0000000329622982;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2013-11-15 09:08:43;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;2;;1;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356355.7 6688624.2 6.9, 356376.6 6688632.6 6.6, 356410.9 6688645.8 6.1, 356411.6 6688646 6)
TRONROUT0000000287857095;Route à 1 chaussée;R FRANCOISE GIROUD;R FRANCOISE GIROUD;5;Non;0;En service;2011-08-29 09:41:33;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0P3;44109#0P3;;;;;;;;;;;;;commune;commune;Rue Françoise Giroud;Rue Françoise Giroud;;;44109_3325;44109_3325;;;;;LINESTRING Z (356487.4 6688607.5 6.8, 356461.2 6688665.2 5.9)
TRONROUT0000000329622984;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356417.4 6688629.6 -1000, 356414.2 6688639.7 -1000, 356411.6 6688646 -1000)
TRONROUT0000000029474158;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2006-10-04 09:41:10;2023-02-27 08:17:17;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356411.6 6688646 6, 356436.4 6688655.7 5.9, 356440.1 6688656.7 5.9)
TRONROUT0000000329622981;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356411.6 6688646 -1000, 356411.3 6688654.2 -1000, 356408.2 6688661.6 -1000)
TRONROUT0000002215754258;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356271.6 6688587.7 7.4, 356295.3 6688596.5 7.2, 356308.4 6688596.7 7.1, 356311.3 6688596.1 7.1)
TRONROUT0000002215754255;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356311.3 6688596.1 7.1, 356311 6688594.6 7, 356311.5 6688592.3 7, 356312.8 6688590.3 7, 356314.8 6688589 7, 356317.1 6688588.5 7.1, 356319.4 6688589 7.2)
TRONROUT0000002215754254;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356319.4 6688589 7.2, 356321.4 6688590.3 7.1, 356322.7 6688592.3 7, 356323.2 6688594.6 7, 356322.7 6688596.9 6.9, 356321.4 6688598.9 7)
TRONROUT0000000295265475;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2017-11-28 11:13:23;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356301.1 6688618.7 4.9, 356285.6 6688612.3 4.9, 356266.2 6688604.6 4.9, 356253.3 6688599.4 5.4, 356244.2 6688596.1 6.2, 356239.1 6688592.9 6.6, 356235.8 6688588.2 7.2, 356236.6 6688583.4 7.2, 356240.9 6688574.6 7.4)
TRONROUT0000002215754259;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356315.1 6688600.3 6.8, 356312.8 6688598.9 6.9, 356311.5 6688596.9 7, 356311.3 6688596.1 7.1)
TRONROUT0000002215754260;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356321.4 6688598.9 7, 356319.4 6688600.2 6.9, 356317.1 6688600.7 6.8, 356315.1 6688600.3 6.8)
TRONROUT0000000295265403;Escalier;;;6;Non;0;En service;2012-02-08 10:00:49;2020-11-06 13:57:47;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356315.1 6688600.3 6.8, 356311.7 6688609.2 6.8, 356306.2 6688613.3 6.8, 356301.1 6688618.7 4.9)
TRONROUT0000002215754257;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:47;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356355.7 6688624.2 6.9, 356347.2 6688618.9 6.9, 356325.3 6688602.9 7, 356321.4 6688598.9 7)
TRONROUT0000000329622983;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356301.1 6688618.7 4.9, 356324.8 6688628.5 4.2, 356351.9 6688639.2 4.1, 356382.1 6688651.5 4.4, 356408.2 6688661.6 4.4)
TRONROUT0000000029474565;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2006-10-04 09:41:10;2020-10-28 11:40:19;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356226.9 6688782.6 6.9, 356234.9 6688787.3 6.9, 356236.3 6688790.2 7)
TRONROUT0000002215754252;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2020-11-06 13:57:37;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356240.9 6688574.6 7.4, 356140.7 6688535.2 7.4)
TRONROUT0000000356559121;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:50:52;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (356226.9 6688782.6 6.9, 356224.1 6688789.3 6.8, 356221.7 6688791 6.8, 356215.8 6688789.8 6.8, 356141 6688758.1 6.8, 356033 6688713 6.8, 356024.2 6688709.5 6.8, 356017.6 6688708.4 6.8, 356006 6688704.5 6.8, 355976 6688691.8 6.8, 355961.7 6688686.9 6.8, 355925.7 6688670.3 6.8, 355916.9 6688665.1 6.8)
TRONROUT0000000356559119;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2016-02-15 14:50:52;2020-10-28 11:40:17;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355978.4 6688677.5 5.8, 355999.7 6688686.2 5.9, 356126.5 6688739.1 6, 356145.1 6688747.6 5.9, 356226.9 6688782.6 6.9)
TRONROUT0000000029474313;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;50;;34;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356230.3 6688800.7 7.3, 356159.1 6688769.9 7.4, 355992.7 6688704.9 7.7)
TRONROUT0000000029474101;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;21;10;35;14;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356176.4 6688880.7 8.3, 356170.6 6688874.3 8.2, 356157.4 6688866.2 7.3, 356013.1 6688795.1 7.2)
TRONROUT0000000295265302;Rond-point;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;19;;15;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356176.4 6688880.7 8.3, 356178.4 6688879.3 8.3, 356180.8 6688879.1 8.3, 356183.4 6688879.9 8.3, 356185.2 6688881.3 8.3, 356185.6 6688882.2 8.3)
TRONROUT0000000295265423;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356185.6 6688882.2 8.3, 356191.4 6688883.6 8, 356199.2 6688885.5 8.2)
TRONROUT0000000029474584;Rond-point;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356178 6688890.7 7.7, 356176.4 6688888.9 8, 356175.3 6688887.3 8, 356174.9 6688884.6 8, 356175 6688882.8 8, 356176.4 6688880.7 8.3)
TRONROUT0000000029474242;Rond-point;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356185.6 6688882.2 8.3, 356186.8 6688884.5 8.3, 356186.6 6688886.8 8.3, 356185.6 6688889.1 8.4, 356184 6688890.2 8.4)
TRONROUT0000000295265307;Rond-point;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356184 6688890.2 8.4, 356181.4 6688891 8.3, 356178 6688890.7 7.7)
TRONROUT0000000318045660;Route à 1 chaussée;BD LOUIS BARTHOU;BD LOUIS BARTHOU;5;Non;0;En service;2013-01-28 10:15:42;2023-02-27 08:17:17;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441095062;441095062;;;;;;;;;;;;;commune;commune;Boulevard Louis Barthou;Boulevard Louis Barthou;;;44109_5062;44109_5062;;;;;LINESTRING Z (356440.1 6688656.7 5.9, 356447.5 6688659.6 5.9, 356461.2 6688665.2 5.9)
TRONROUT0000000053385263;Route à 1 chaussée;;;5;Non;1;En service;2007-01-24 11:26:37;2023-05-26 09:18:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356416 6688707.5 13, 356442.7 6688646.5 8.7)
TRONROUT0000000294302096;Route à 1 chaussée;;;5;Non;1;En service;2012-01-17 12:39:06;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356445.3 6688647.3 8.3, 356416 6688707.5 13)
TRONROUT0000000320704114;Route à 1 chaussée;BD LOUIS BARTHOU;BD LOUIS BARTHOU;5;Non;0;En service;2013-04-03 17:23:48;2023-02-27 08:17:17;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441095062;441095062;;;;;;;;;;;;;commune;commune;Boulevard Louis Barthou;Boulevard Louis Barthou;;;44109_5062;44109_5062;;;;;LINESTRING Z (356461.2 6688665.2 5.9, 356480.4 6688673 5.9, 356506.81139568595 6688683.219123127 6.331793934922227)
TRONROUT0000000294302145;Sentier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;;;;;;;;;;;;;LINESTRING Z (356408.2 6688661.6 4.4, 356409.8 6688662.3 4.4, 356430.1 6688671.2 7.9, 356432.2 6688672.1 7.9, 356447.9 6688679 4.7, 356462 6688684.7 4.4, 356487.7 6688694.7 4.2, 356506.81139568595 6688702.306046646 4.2)
TRONROUT0000000029474244;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;1;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356338.8 6688850.8 12.9, 356359 6688810.8 13.7, 356372.4 6688784.9 13.6, 356389.7 6688749.5 13.6, 356405.5 6688716.6 13.3, 356417.4 6688692 12.9, 356428.9 6688668.5 12.5, 356439.3 6688645.1 12.1)
TRONROUT0000000029474159;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;1;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356448.6 6688648.7 11.8, 356438.5 6688672.5 12.4, 356434.1 6688681.7 12.5, 356429.7 6688690.4 12.8, 356415.6 6688718.4 12.9, 356394.1 6688764.4 13, 356381.7 6688790.8 12.9, 356377.2 6688800.9 12.8, 356367.5 6688819 12.6, 356359 6688835.8 12.4, 356349.1 6688855.5 12.1)
TRONROUT0000000294302095;Route à 1 chaussée;;;5;Non;1;En service;2012-01-17 12:39:06;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356416 6688707.5 13, 356355.7 6688829 7.6, 356343 6688853 6.6)
TRONROUT0000000029473944;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;8;;12;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356387.1 6688868.4 7.4, 356381.3 6688866 7.3, 356378.5 6688866.4 7.3)
TRONROUT0000002245140105;Rond-point;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2021-09-02 17:32:49;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356378.5 6688866.4 7.3, 356378.5 6688868.9 7.3, 356377.4 6688871.9 7.3, 356376.3 6688873.7 7.3, 356373.8 6688875.1 7.3)
TRONROUT0000000029473848;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;10;;10;;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355926 6688316.3 8.3, 355927.8155403061 6688312.003221275 8.209222984694392)
TRONROUT0000002275574183;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2021-12-28 14:52:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;7B;;7;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355949.16830709757 6688312.003221275 8.20045236488482, 355949.1 6688312.2 8.2, 355946.8 6688317.2 8.2)
TRONROUT0000002003341987;Sentier;R DE RECIFE;R DE RECIFE;6;Non;0;En service;2017-05-04 18:17:29;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;1;;1;;44109;44109;;;;44109#0IN;44109#0IN;;;;;;;;;;;;;commune;commune;Rue de Recife;Rue de Recife;;;44109_7162;44109_7162;;;;;LINESTRING Z (356045.54106125137 6688312.003221275 7.487176249877163, 356046.5 6688329.7 7.4)
TRONROUT0000000029473824;Route à 1 chaussée;BD BABIN CHEVAYE;BD BABIN CHEVAYE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090496;441090496;;;;;;;;;;;;;commune;commune;Boulevard Babin Chevaye;Boulevard Babin Chevaye;;;44109_0496;44109_0496;;;;;LINESTRING Z (355876.098774352 6688312.003221275 7.811729690332405, 355926 6688316.3 8.3)
TRONROUT0000000029474726;Route à 1 chaussée;;;4;Non;0;En service;2006-10-04 09:41:10;2022-01-03 15:31:51;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355926 6688316.3 8.3, 355934.4 6688316.7 8.3, 355940.3 6688316.4 8.2)
TRONROUT0000000356559115;Route à 1 chaussée;;;4;Non;0;En service;2016-02-15 14:50:09;2022-01-03 21:16:30;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355940.3 6688316.4 8.2, 355946.8 6688317.2 8.2)
TRONROUT0000002275586578;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2022-01-03 15:31:51;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;4B;;2;;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355922.3 6688323.5 8.1, 355926 6688316.3 8.3)
TRONROUT0000000356559112;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:50:09;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355939.3 6688323.5 8.1, 355940.3 6688316.4 8.2)
TRONROUT0000002275586582;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2022-01-03 15:31:51;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355946.8 6688317.2 8.2, 355943.7 6688323.5 8.2)
TRONROUT0000002275574181;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2021-12-28 14:52:10;2022-12-10 14:57:12;;2020-06-22;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;;;;;;;;;;;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (355946.8 6688317.2 8.2, 355953.1 6688316.8 8.2, 355959.3 6688317.2 8.2, 355966.4 6688318.2 8.2, 355972.5 6688319.5 8.2, 355980 6688324.7 7.3)
TRONROUT0000002275586601;Route à 1 chaussée;BD BABIN CHEVAYE;BD BABIN CHEVAYE;4;Non;0;En service;2022-01-03 15:32:29;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;14B;;14;;44109;44109;;;;441090496;441090496;;;;;;;;;;;;;commune;commune;Boulevard Babin Chevaye;Boulevard Babin Chevaye;;;44109_0496;44109_0496;;;;;LINESTRING Z (355806.1921984496 6688312.003221275 8.216678587714522, 355817.3 6688313.1 8.1)
TRONROUT0000000295264879;Route à 1 chaussée;BD BABIN CHEVAYE;BD BABIN CHEVAYE;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090496;441090496;;;;;;;;;;;;;commune;commune;Boulevard Babin Chevaye;Boulevard Babin Chevaye;;;44109_0496;44109_0496;;;;;LINESTRING Z (355817.3 6688313.1 8.1, 355824.57337470044 6688312.003221275 8.04227480396482)
TRONROUT0000000029474608;Route à 1 chaussée;R GRANDE BIESSE;R GRANDE BIESSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;5;20;7;24;44109;44109;;;;441093796;441093796;;;;;;;;;;;;;commune;commune;Rue Grande Biesse;Rue Grande Biesse;;;44109_3796;44109_3796;;;;;LINESTRING Z (355855.6 6688318.8 7.5, 355856.51176299964 6688312.003221275 7.665775090838471)
TRONROUT0000002275586602;Route à 1 chaussée;BD BABIN CHEVAYE;BD BABIN CHEVAYE;4;Non;0;En service;2022-01-03 15:32:29;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;10;;12;44109;44109;;;;441090496;441090496;;;;;;;;;;;;;commune;commune;Boulevard Babin Chevaye;Boulevard Babin Chevaye;;;44109_0496;44109_0496;;;;;LINESTRING Z (355855.6 6688318.8 7.5, 355817.3 6688313.1 8.1)
TRONROUT0000002275586577;Route à 1 chaussée;BD BABIN CHEVAYE;BD BABIN CHEVAYE;4;Non;0;En service;2022-01-03 15:31:51;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;2;;8;44109;44109;;;;441090496;441090496;;;;;;;;;;;;;commune;commune;Boulevard Babin Chevaye;Boulevard Babin Chevaye;;;44109_0496;44109_0496;;;;;LINESTRING Z (355922.3 6688323.5 8.2, 355905.7 6688322.8 7.8, 355855.6 6688318.8 7.5)
TRONROUT0000002275586603;Route à 1 chaussée;R GRANDE BIESSE;R GRANDE BIESSE;5;Non;0;En service;2022-01-03 15:32:29;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;5;20;7;24;44109;44109;;;;441093796;441093796;;;;;;;;;;;;;commune;commune;Rue Grande Biesse;Rue Grande Biesse;;;44109_3796;44109_3796;;;;;LINESTRING Z (355850.6 6688359.9 7, 355855.6 6688318.8 7.5)
TRONROUT0000000029474536;Route à 1 chaussée;R MICHEL ROCHER;R MICHEL ROCHER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;14;17;8;7;44109;44109;;;;441095644;441095644;;;;;;;;;;;;;commune;commune;Rue Michel Rocher;Rue Michel Rocher;;;44109_5644;44109_5644;;;;;LINESTRING Z (355766.6 6688348.9 7, 355784 6688350.2 7, 355829 6688355.8 7, 355850.6 6688359.9 7)
TRONROUT0000000029473589;Route à 1 chaussée;R GRANDE BIESSE;R GRANDE BIESSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;3;6;5;14;44109;44109;;;;441093796;441093796;;;;;;;;;;;;;commune;commune;Rue Grande Biesse;Rue Grande Biesse;;;44109_3796;44109_3796;;;;;LINESTRING Z (355844.1 6688427.1 7.2, 355844.4 6688416.1 7.3, 355850.6 6688359.9 7)
TRONROUT0000000029474002;Route à 1 chaussée;QU HOCHE;QU HOCHE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;4;;2;44109;44109;;;;441094221;441094221;;;;;;;;;;;;;commune;commune;Quai Hoche;Quai Hoche;;;44109_4221;44109_4221;;;;;LINESTRING Z (355728.3 6688428.2 6.4, 355762 6688428.7 6.7, 355844.1 6688427.1 7.2)
TRONROUT0000000029475293;Route à 1 chaussée;QU HOCHE;QU HOCHE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094221;441094221;;;;;;;;;;;;;commune;commune;Quai Hoche;Quai Hoche;;;44109_4221;44109_4221;;;;;LINESTRING Z (355844.1 6688427.1 7.2, 355858 6688428.5 7.7, 355867.3 6688431.1 7.7)
TRONROUT0000002275586579;Route à 1 chaussée;;;4;Non;0;En service;2022-01-03 15:31:51;;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355939.3 6688323.5 8.1, 355922.3 6688323.5 8.2)
TRONROUT0000002275586580;Route à 1 chaussée;;;4;Non;0;En service;2022-01-03 15:31:51;;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355943.7 6688323.5 8.2, 355939.3 6688323.5 8.1)
TRONROUT0000002275574182;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2021-12-28 14:52:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (355980 6688324.7 7.3, 355963.4 6688323.1 7.6, 355943.7 6688323.5 8.2)
TRONROUT0000002003341989;Route à 1 chaussée;BD VINCENT GACHE;BD VINCENT GACHE;4;Non;0;En service;2017-05-04 18:17:29;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;4.0;14.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;30;39;26;31;44109;44109;;;;441098536;441098536;;ITI_AUT_0000002285727501;;;;;;;;Autre;La petite Amazonie;;commune;commune;Boulevard Vincent Gâche;Boulevard Vincent Gâche;;;44109_8536;44109_8536;;;;;LINESTRING Z (355980 6688324.7 7.3, 356009.2 6688327.4 6.9, 356046.5 6688329.7 7.4)
TRONROUT0000000029473918;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;4B;;2;;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355867.3 6688431.1 7.7, 355874.3 6688415.8 7.8, 355914.6 6688339.7 8, 355922.3 6688323.5 8.1)
TRONROUT0000002275586581;Route à 1 chaussée;;;6;Non;0;En service;2022-01-03 15:31:51;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355888.8 6688437.8 7.8, 355910.3 6688385 7.9, 355929.2 6688346.6 8, 355938.6 6688328.1 8.1, 355939.3 6688323.5 8.1)
TRONROUT0000000029474557;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355943.7 6688323.5 8.2, 355917.9 6688376.4 8.2, 355910.3 6688392.7 8.2, 355892 6688438.9 7.7)
TRONROUT0000000029474759;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2016-02-15 14:50:09;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355888.8 6688437.8 7.8, 355892 6688438.9 7.7)
TRONROUT0000000029473645;Route à 1 chaussée;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;21;;21;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (355892 6688438.9 7.7, 355906.5 6688443.1 7.5, 355926.7 6688451.6 7.6, 356015.1 6688484.5 7.9, 356021.1 6688484.9 7.9, 356024.2 6688484.8 7.9)
TRONROUT0000002223016864;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2021-02-16 14:42:03;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356024.2 6688484.8 7.9, 356024.9 6688482.2 7.9, 356026.7 6688480.4 7.9, 356029.3 6688479.7 7.9, 356031.9 6688480.4 7.9, 356032.2 6688480.8 7.9)
TRONROUT0000002223008769;Route à 1 chaussée;R CONAN MERIADEC;R CONAN MERIADEC;5;Non;0;En service;2021-02-16 12:55:59;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;;8;;44109;44109;;;;441092104;441092104;;;;;;;;;;;;;commune;commune;Rue Conan Mériadec;Rue Conan Mériadec;;;44109_2104;44109_2104;;;;;LINESTRING Z (355722.65344070917 6688312.003221275 7, 355723.8 6688346.4 7)
TRONROUT0000000029475119;Sentier;ALL DE LA RAFFINERIE DE SUCRE;ALL DE LA RAFFINERIE DE SUCRE;6;Non;0;En service;2006-10-04 09:41:10;2022-01-03 15:32:29;;;Nantes Métropole;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0UR;44109#0UR;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355769.42419787776 6688312.003221275 8.457650517534404, 355766.6 6688348.9 7)
TRONROUT0000000029475026;Route à 1 chaussée;R MICHEL ROCHER;R MICHEL ROCHER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095644;441095644;;;;;;;;;;;;;commune;commune;Rue Michel Rocher;Rue Michel Rocher;;;44109_5644;44109_5644;;;;;LINESTRING Z (355723.8 6688346.4 7, 355766.6 6688348.9 7)
TRONROUT0000000029473536;Route à 1 chaussée;R CONAN MERIADEC;R CONAN MERIADEC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;3;6;1;44109;44109;;;;441092104;441092104;;;;;;;;;;;;;commune;commune;Rue Conan Mériadec;Rue Conan Mériadec;;;44109_2104;44109_2104;;;;;LINESTRING Z (355723.8 6688346.4 7, 355725.1 6688370 6.9, 355726.8 6688400.8 6.6, 355728.3 6688428.2 6.4)
TRONROUT0000000029474892;Route à 1 chaussée;QU HOCHE;QU HOCHE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;;10;;44109;44109;;;;441094221;441094221;;;;;;;;;;;;;commune;commune;Quai Hoche;Quai Hoche;;;44109_4221;44109_4221;;;;;LINESTRING Z (355728.3 6688428.2 6.4, 355705 6688428.9 6.6, 355680.9 6688429.6 6.8, 355652 6688430.7 2.8, 355633.4 6688431.5 6.4, 355624.6 6688431.1 6.4)
TRONROUT0000002200207675;Sentier;;;6;Non;0;En service;2018-12-18 17:48:46;2020-11-06 13:57:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356140.7 6688535.2 7.4, 356132.9 6688544.3 -1000, 356117.1 6688538.6 -1000, 356059.5 6688517.9 -1000, 356053.2 6688519.9 -1000, 356041.6 6688523.1 -1000, 356031.9 6688520.5 -1000, 355919.3 6688476.6 -1000, 355889.5 6688469.2 -1000, 355842.1 6688454.1 -1000, 355777.5 6688449.9 -1000, 355742.4 6688446.3 -1000, 355705.3 6688446.2 -1000, 355703.8 6688439.1 -1000, 355690.9 6688439.8 -1000, 355687.7 6688451.2 -1000, 355671.9 6688455.7 -1000, 355623.5 6688460.8 -1000, 355552.9 6688476.3 -1000, 355419.4 6688516.3 -1000, 355383.4 6688519.9 -1000, 355354.8 6688521.3 -1000, 355314.5 6688523.9 -1000, 355295.3 6688523.4 -1000)
TRONROUT0000000029473752;Route à 1 chaussée;QU MONCOUSU;QU MONCOUSU;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095713;441095713;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Moncousu;Quai Moncousu;;;44109_5713;44109_5713;;;;;LINESTRING Z (355663.6 6688660.5 6.6, 355756.8 6688639.9 6.7, 355770 6688639.2 6.9, 355787.4 6688636.6 7.9)
TRONROUT0000000029474657;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-10-09 19:04:25;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355648.6 6688646.5 6.2, 355653.9 6688645.8 6.2, 355655.1 6688645.9 6.2, 355656.5 6688646.2 6.2, 355658.7 6688647.5 6.2, 355660.4 6688649.1 6.2, 355662 6688651.6 6.2, 355663.2 6688655.1 6.2, 355663.6 6688660.5 6.6)
TRONROUT0000000029475229;Route à 1 chaussée;BD JEAN MONNET;BD JEAN MONNET;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094501;441094501;;;;;;;;;;;;;commune;commune;Boulevard Jean Monnet;Boulevard Jean Monnet;;;44109_4501;44109_4501;;;;;LINESTRING Z (355742.9 6688710.3 7.1, 355781.6 6688649.3 7.1, 355787.4 6688636.6 7.9)
TRONROUT0000000331462426;Route à 1 chaussée;R DE LA FAIENCERIE;R DE LA FAIENCERIE;3;Non;0;En service;2014-01-27 18:45:29;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CD;44109#0CD;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355755.1 6688718.2 7.2, 355751.2 6688713.9 7.3, 355742.9 6688710.3 7.1)
TRONROUT0000000356559113;Route à 1 chaussée;;;5;Non;0;En service;2016-02-15 14:50:09;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355867.3 6688431.1 7.7, 355874.8 6688433.5 7.9, 355888.8 6688437.8 7.8)
TRONROUT0000000029475042;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355861.2 6688444 8.4, 355867.3 6688431.1 7.7)
TRONROUT0000000356559114;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:50:09;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355879.9 6688460.3 7.7, 355880.3 6688459.4 7.6, 355888.8 6688437.8 7.8)
TRONROUT0000000029474571;Route à 1 chaussée;BD DES MARTYRS NANTAIS DE LA RESISTANCE;BD DES MARTYRS NANTAIS DE LA RESISTANCE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095448;441095448;;;;;;;;;;;;;commune;commune;Boulevard des Martyrs Nantais de la Résistance;Boulevard des Martyrs Nantais de la Résistance;;;44109_d3tuvn;44109_d3tuvn;;;;;LINESTRING Z (355892 6688438.9 7.7, 355882.8 6688461.2 8)
TRONROUT0000000029474178;Route à 1 chaussée;PONT GENERAL AUDIBERT;PONT GENERAL AUDIBERT;3;Non;1;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#093;44109#093;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355804 6688600.1 8.8, 355810.8 6688578.8 10.2, 355816.8 6688562.3 10.6, 355824 6688543.5 10.8, 355835.6 6688511.9 10.8, 355846.4 6688482.6 9.8, 355855.2 6688459.4 8.6, 355861.2 6688444 8.4)
TRONROUT0000000356559117;Route à 1 chaussée;;;6;Non;1;En service;2016-02-15 14:50:09;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355824.9 6688606.4 7, 355826.5 6688602.6 7.1, 355837.2 6688572.3 7.2, 355851.3 6688536.5 7.4, 355862.6 6688504.4 7.5, 355879.9 6688460.3 7.7)
TRONROUT0000000029473847;Route à 1 chaussée;PONT GENERAL AUDIBERT;PONT GENERAL AUDIBERT;3;Non;1;En service;2006-10-04 09:41:10;2016-02-15 14:50:09;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#093;44109#093;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355882.8 6688461.2 8, 355882.1 6688463 8.1, 355878.5 6688472.4 7.9, 355876.2 6688478.5 7.9, 355860.2 6688520.5 9.5, 355855.7 6688532.8 9.3, 355849.7 6688549 9.1, 355834 6688591.4 7.1, 355832.1 6688596.4 6.9, 355828 6688607.2 8)
TRONROUT0000000029474890;Route à 1 chaussée;PL AIME DELRUE;PL AIME DELRUE;3;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C9;44109#0C9;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355787.4 6688636.6 7.9, 355793.1 6688625.9 0.6, 355798.9 6688613.6 8.3, 355800.7 6688608.7 8.5, 355804 6688600.1 8.8)
TRONROUT0000000356559116;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:50:09;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355817.7 6688630.4 6.9, 355815 6688629.7 7, 355824.9 6688606.4 7)
TRONROUT0000000356559111;Route à 1 chaussée;PL AIME DELRUE;PL AIME DELRUE;3;Non;0;En service;2016-02-15 14:50:09;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C9;44109#0C9;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355828 6688607.2 8, 355823.3 6688620.2 8.2, 355817.7 6688630.4 6.9)
TRONROUT0000002223016863;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2021-02-16 14:42:03;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356032.2 6688480.8 7.9, 356033.7 6688482.2 7.8, 356034.4 6688484.8 7.7, 356033.7 6688487.4 7.6, 356033.2 6688488 7.5)
TRONROUT0000002223016865;Rond-point;BD GASTON DOUMERGUE;BD GASTON DOUMERGUE;5;Non;0;En service;2021-02-16 14:42:03;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093506;441093506;;;;;;;;;;;;;commune;commune;Boulevard Gaston Doumergue;Boulevard Gaston Doumergue;;;44109_3506;44109_3506;;;;;LINESTRING Z (356033.2 6688488 7.5, 356031.9 6688489.2 7.5, 356029.3 6688489.9 7.6, 356026.7 6688489.2 7.7, 356024.9 6688487.4 7.8, 356024.2 6688484.8 7.9)
TRONROUT0000000295265489;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2016-02-15 14:50:52;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355916.9 6688665.1 6.8, 355916.2 6688665.2 6.8, 355911.4 6688666.4 6.8)
TRONROUT0000000295265285;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2012-02-08 10:00:49;2020-10-28 11:40:17;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355928 6688657 5.8, 355978.4 6688677.5 5.8)
TRONROUT0000000356559120;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;5;Non;0;En service;2016-02-15 14:50:52;2020-10-28 11:40:17;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355978.4 6688677.5 5.8, 355964.5 6688677.5 5.5, 355956.9 6688677.2 5.7, 355950.7 6688676.4 5.8, 355943.5 6688673.6 5.8, 355934.4 6688669.1 6.2, 355927.6 6688666 6.7, 355922.7 6688664.9 6.7, 355916.9 6688665.1 6.8)
TRONROUT0000000029473890;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;51;;58;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (355992.7 6688704.9 7.7, 355958.9 6688690.1 7.6, 355911.4 6688666.4 6.8)
TRONROUT0000000029473591;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;46;55;38;49;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355911.4 6688666.4 6.8, 355887.1 6688746.5 6.4)
TRONROUT0000000029473768;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;58;53;58;51;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (355992.7 6688704.9 7.7, 356011.4 6688787.9 7.3)
TRONROUT0000000029474852;Route à 1 chaussée;IMP MARMONTEL;IMP MARMONTEL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;8;;8;44109;44109;;;;441095400;441095400;;;;;;;;;;;;;commune;commune;Impasse Marmontel;Impasse Marmontel;;;44109_5400;44109_5400;;;;;LINESTRING Z (355887.1 6688746.5 6.4, 355934.5 6688753 7.7)
TRONROUT0000000029475166;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355937.6 6688782.2 6.9, 355940.2 6688757.4 7.4)
TRONROUT0000000214956356;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;-1;En service;2009-01-06 13:43:21;2009-11-20 16:53:05;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355772.7 6688625.9 3.3, 355793.1 6688625.9 0.6, 355801.5 6688626.2 0.6, 355818.5 6688628.5 0.9, 355840.3 6688633.1 2.6)
TRONROUT0000000029474692;Route à 1 chaussée;PL AIME DELRUE;PL AIME DELRUE;3;Non;0;En service;2006-10-04 09:41:10;2019-04-04 22:00:01;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;3.0;10.5;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C9;44109#0C9;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (355817.7 6688630.4 6.9, 355810.6 6688642.5 7.8)
TRONROUT0000000029474689;Route à 1 chaussée;PL AIME DELRUE;PL AIME DELRUE;5;Non;0;En service;2006-10-04 09:41:10;2019-04-04 22:00:01;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C9;44109#0C9;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (355787.4 6688636.6 7.9, 355796.5 6688640.5 7.8, 355810.6 6688642.5 7.8)
TRONROUT0000000029473657;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2006-10-04 09:41:10;2009-11-20 16:53:05;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355840.3 6688633.1 2.6, 355852.2 6688634.8 3.6, 355889 6688644 4.9, 355917.9 6688652.9 5.8, 355928 6688657 5.8)
TRONROUT0000000356559110;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:50:09;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (355916.9 6688665.1 6.8, 355905.8 6688658.3 6.8, 355899.6 6688656.1 6.8, 355887.5 6688651.9 6.8, 355841.4 6688641.4 6.8, 355834 6688639.2 6.8, 355827.3 6688633.1 6.8, 355817.7 6688630.4 6.9)
TRONROUT0000000029473585;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;66;;61;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (355810.6 6688642.5 7.8, 355817.4 6688643.6 7.8, 355852.5 6688648.7 7.6, 355893.7 6688658.9 7.3, 355911.4 6688666.4 6.8)
TRONROUT0000000029474019;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;49;;45;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355810.6 6688642.5 7.8, 355798.5 6688660.6 7.7, 355780.3 6688685.6 7.3, 355767.2 6688708 7.3, 355759.8 6688723.3 6.9)
TRONROUT0000000029473891;Route à 1 chaussée;R MARMONTEL;R MARMONTEL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;11;2;1;44109;44109;;;;441095404;441095404;;;;;;;;;;;;;commune;commune;Rue Marmontel;Rue Marmontel;;;44109_5404;44109_5404;;;;;LINESTRING Z (355759.8 6688723.3 6.9, 355887.1 6688746.5 6.4)
TRONROUT0000000029473568;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;34;47;32;45;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355887.1 6688746.5 6.4, 355879.3 6688772.1 6.7)
TRONROUT0000000029473595;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;30;43;28;41;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355879.3 6688772.1 6.7, 355871.8 6688796.1 7.1)
TRONROUT0000000029474290;Route à 1 chaussée;R DE LA FAIENCERIE;R DE LA FAIENCERIE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CD;44109#0CD;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355759.8 6688723.3 6.9, 355755.1 6688718.2 7.2)
TRONROUT0000000119652098;Route à 1 chaussée;BD JEAN MONNET;BD JEAN MONNET;5;Non;0;En service;2008-03-19 10:53:38;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094501;441094501;;;;;;;;;;;;;commune;commune;Boulevard Jean Monnet;Boulevard Jean Monnet;;;44109_4501;44109_4501;;;;;LINESTRING Z (355719.6 6688746 7.3, 355731.4 6688728.5 7.2, 355742.9 6688710.3 7.1)
TRONROUT0000000029474691;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2020-09-22 17:11:39;;2009-07-01;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355677 6688809.6 8.3, 355665.2 6688802 8.6, 355656.9 6688795.7 8.2, 355652.8 6688792.1 8.1, 355649.9 6688786.2 8.1, 355639.2 6688740.4 7.8, 355634.4 6688715.9 7.8, 355640.9 6688708.1 7.8, 355648.5 6688707.9 7.8, 355655.7 6688712.6 7.8, 355663.7 6688720 7.8, 355684.7 6688730.1 7.8, 355706.5 6688740.1 7.3, 355719.6 6688746 7.3)
TRONROUT0000000119652099;Route à 1 chaussée;BD JEAN MONNET;BD JEAN MONNET;5;Non;0;En service;2008-03-19 10:53:38;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;34;;34;;44109;44109;;;;441094501;441094501;;;;;;;;;;;;;commune;commune;Boulevard Jean Monnet;Boulevard Jean Monnet;;;44109_4501;44109_4501;;;;;LINESTRING Z (355677 6688809.6 8.3, 355719.6 6688746 7.3)
TRONROUT0000000331462425;Route à 1 chaussée;;;6;Non;0;En service;2014-01-27 18:45:29;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355658.6 6688868.5 7.3, 355674.2 6688848.4 7.2, 355678.5 6688838.9 7.2, 355689.8 6688822.8 7.2, 355700.2 6688809.4 7.2, 355724 6688773.1 7.2, 355735.2 6688755.8 7.2, 355747.7 6688733.6 7.2, 355755.1 6688718.2 7.2)
TRONROUT0000000029473582;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;43;;19;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355759.8 6688723.3 6.9, 355682.3 6688887.3 7.5)
TRONROUT0000000029474964;Sentier;PAS TONKINOIS;PAS TONKINOIS;6;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0DG;44109#0DG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355757.9 6688866.9 -1000, 355729.2 6688853.4 -1000)
TRONROUT0000000295265252;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2014-01-27 18:45:29;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355690.3 6688829.9 7.3, 355680.4 6688846.2 7.6, 355674.8 6688858.6 7.6, 355674.6 6688864.7 7.6, 355672.5 6688870.1 7.6, 355665.3 6688886.7 7.6, 355662.5 6688891.8 7.6)
TRONROUT0000000029473753;Route à 1 chaussée;R SANLECQUE;R SANLECQUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;3;2;3;44109;44109;;;;441097812;441097812;;;;;;;;;;;;;commune;commune;Rue Sanlecque;Rue Sanlecque;;;44109_7812;44109_7812;;;;;LINESTRING Z (355757.9 6688866.9 6.7, 355736 6688908.6 6.9)
TRONROUT0000000029473948;Route à 1 chaussée;R PERRAULT;R PERRAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;8;9;8;44109;44109;;;;441096352;441096352;;;;;;;;;;;;;commune;commune;Rue Perrault;Rue Perrault;;;44109_6352;44109_6352;;;;;LINESTRING Z (355736 6688908.6 6.9, 355682.3 6688887.3 7.5)
TRONROUT0000000029474012;Route à 1 chaussée;R PERELLE;R PERELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;15;18;21;22;44109;44109;;;;441096340;441096340;;;;;;;;;;;;;commune;commune;Rue Pérelle;Rue Pérelle;;;44109_6340;44109_6340;;;;;LINESTRING Z (355937.6 6688782.2 6.9, 355879.3 6688772.1 6.7)
TRONROUT0000000029473914;Route à 1 chaussée;R PERELLE;R PERELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;12;13;16;44109;44109;;;;441096340;441096340;;;;;;;;;;;;;commune;commune;Rue Pérelle;Rue Pérelle;;;44109_6340;44109_6340;;;;;LINESTRING Z (355998.2 6688792.4 7.2, 355937.6 6688782.2 6.9)
TRONROUT0000000029474792;Route à 1 chaussée;R PERELLE;R PERELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096340;441096340;;;;;;;;;;;;;commune;commune;Rue Pérelle;Rue Pérelle;;;44109_6340;44109_6340;;;;;LINESTRING Z (356011.4 6688787.9 7.3, 355998.2 6688792.4 7.2)
TRONROUT0000000029475157;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356011.4 6688787.9 7.3, 356013.1 6688795.1 7.2)
TRONROUT0000000029474498;Route à 1 chaussée;R COLUMELLE;R COLUMELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;6;9B;10;44109;44109;;;;441092040;441092040;;;;;;;;;;;;;commune;commune;Rue Columelle;Rue Columelle;;;44109_2040;44109_2040;;;;;LINESTRING Z (355976.3 6688846.3 7.3, 355988.5 6688820.6 7.1, 355998.2 6688792.4 7.2)
TRONROUT0000000029474677;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2011-08-26 22:19:23;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355930 6688838.2 7.5, 355976.3 6688846.3 7.3)
TRONROUT0000000029474903;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;33;42;37;54;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356039.7 6688918.8 7.1, 356013.1 6688795.1 7.2)
TRONROUT0000000029474017;Route à 1 chaussée;R COLUMELLE;R COLUMELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;4;5;6;44109;44109;;;;441092040;441092040;;;;;;;;;;;;;commune;commune;Rue Columelle;Rue Columelle;;;44109_2040;44109_2040;;;;;LINESTRING Z (355958.7 6688882.9 7.1, 355976.3 6688846.3 7.3)
TRONROUT0000000029474666;Route à 1 chaussée;COUR FOUCAULT;COUR FOUCAULT;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0DC;44109#0DC;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355873 6688879.2 7.2, 355875.9 6688866.1 6.2, 355880 6688864.6 6.2, 355886.1 6688864.1 6.3, 355894.2 6688864.8 6.3, 355945 6688877.1 6.2, 355958.7 6688882.9 7.1)
TRONROUT0000000029474008;Route à 1 chaussée;R BARON;R BARON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;18;13;12;9;44109;44109;;;;441090556;441090556;;;;;;;;;;;;;commune;commune;Rue Baron;Rue Baron;;;44109_0556;44109_0556;;;;;LINESTRING Z (355944.9 6688893.6 7.2, 355873 6688879.2 7.2)
TRONROUT0000000029474909;Route empierrée;COUR MASSE;COUR MASSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441095472;441095472;;;;;;;;;;;;;commune;commune;Cour Massé;Cour Massé;;;44109_wuwy3v;44109_wuwy3v;;;;;LINESTRING Z (355785.4 6688781.6 6.6, 355821.5 6688788.7 6.5, 355871.8 6688796.1 7.1)
TRONROUT0000000029474601;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;26B;41;22;29;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355871.8 6688796.1 7.1, 355847.3 6688874.1 7.1)
TRONROUT0000000029475013;Route à 1 chaussée;R SANLECQUE;R SANLECQUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;14;9;6;5;44109;44109;;;;441097812;441097812;;;;;;;;;;;;;commune;commune;Rue Sanlecque;Rue Sanlecque;;;44109_7812;44109_7812;;;;;LINESTRING Z (355781.4 6688814 6.9, 355757.9 6688866.9 6.7)
TRONROUT0000000029475227;Route à 1 chaussée;R BARON;R BARON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;22;15;20;15;44109;44109;;;;441090556;441090556;;;;;;;;;;;;;commune;commune;Rue Baron;Rue Baron;;;44109_0556;44109_0556;;;;;LINESTRING Z (355873 6688879.2 7.2, 355847.3 6688874.1 7.1)
TRONROUT0000000029474272;Route à 1 chaussée;PAS DE LA POULE NOIRE;PAS DE LA POULE NOIRE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096905;441096905;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355757.9 6688866.9 6.7, 355762.7 6688869.9 6.7, 355820.6 6688895.3 6.9)
TRONROUT0000000029474117;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;20;27;18;25;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355847.3 6688874.1 7.1, 355838.9 6688903 6.9)
TRONROUT0000000029473472;Route à 1 chaussée;PAS DE LA POULE NOIRE;PAS DE LA POULE NOIRE;5;Non;0;En service;2006-10-04 09:41:10;2015-06-29 19:34:01;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;3.0;;;;;Non;;;;;44109;44109;;;;441096905;441096905;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355838.9 6688903 6.9, 355820.6 6688895.3 6.9)
TRONROUT0000000029473594;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;23;16;23;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355838.9 6688903 6.9, 355833.5 6688919.1 19.1)
TRONROUT0000000029473827;Route à 1 chaussée;R PERRAULT;R PERRAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;5;6;44109;44109;;;;441096352;441096352;;;;;;;;;;;;;commune;commune;Rue Perrault;Rue Perrault;;;44109_6352;44109_6352;;;;;LINESTRING Z (355825 6688946.6 7.3, 355736 6688908.6 6.9)
TRONROUT0000000029474579;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;21;14;21;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355833.5 6688919.1 19.1, 355825 6688946.6 7.3)
TRONROUT0000000029475241;Route à 1 chaussée;R DE HERCE;R DE HERCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EE;44109#0EE;;;;;;;;;;;;;commune;commune;Rue de Hercé;Rue de Hercé;;;44109_4170;44109_4170;;;;;LINESTRING Z (355523.3 6688363.5 6.9, 355513.4 6688361.3 6.7, 355511.5 6688358.8 6.7, 355511.7 6688356.2 6.7, 355514.72887015034 6688312.003221275 6.947254706153284)
TRONROUT0000000029473714;Route à 1 chaussée;R SAINT-HERMELAND;R SAINT-HERMELAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;1;;5;44109;44109;;;;441097636;441097636;;;;;;;;;;;;;commune;commune;Rue Saint Hermeland;Rue Saint Hermeland;;;44109_7636;44109_7636;;;;;LINESTRING Z (355544.81176143733 6688312.003221275 6.9, 355539.9 6688364.6 6.9)
TRONROUT0000000295264884;Route à 1 chaussée;R SAINT-HERMELAND;R SAINT-HERMELAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;7;;7;44109;44109;;;;441097636;441097636;;;;;;;;;;;;;commune;commune;Rue Saint Hermeland;Rue Saint Hermeland;;;44109_7636;44109_7636;;;;;LINESTRING Z (355539.9 6688364.6 6.9, 355523.3 6688363.5 6.9)
TRONROUT0000000295265010;Route à 1 chaussée;R SAINT-HERMELAND;R SAINT-HERMELAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097636;441097636;;;;;;;;;;;;;commune;commune;Rue Saint Hermeland;Rue Saint Hermeland;;;44109_7636;44109_7636;;;;;LINESTRING Z (355539.9 6688364.6 6.9, 355545.4 6688366.5 6.9, 355566.3 6688367.3 6.9, 355596.8 6688369.8 7.6, 355614.8 6688370.9 7.6)
TRONROUT0000000029474578;Route à 1 chaussée;R MICHEL COLUMB;R MICHEL COLUMB;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;10;15;14;44109;44109;;;;441095632;441095632;;;;;;;;;;;;;commune;commune;Rue Michel Columb;Rue Michel Columb;;;44109_5632;44109_5632;;;;;LINESTRING Z (355519.4 6688420.5 6.5, 355523.3 6688363.5 6.9)
TRONROUT0000000029473675;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;7;2;1;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355519.4 6688420.5 6.5, 355617.8 6688430.9 6.4, 355624.6 6688431.1 6.4)
TRONROUT0000000029474610;Route à 1 chaussée;R MICHEL COLUMB;R MICHEL COLUMB;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2B;3;2B;44109;44109;;;;441095632;441095632;;;;;;;;;;;;;commune;commune;Rue Michel Columb;Rue Michel Columb;;;44109_5632;44109_5632;;;;;LINESTRING Z (355515.9 6688472.6 6.4, 355519.4 6688420.5 6.5)
TRONROUT0000000029474623;Route à 1 chaussée;QU ANDRE RHUYS;QU ANDRE RHUYS;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;4;;1;44109;44109;;;;441090297;441090297;;;;;;;;;;;;;commune;commune;Quai André Rhuys;Quai André Rhuys;;;44109_0297;44109_0297;;;;;LINESTRING Z (355515.9 6688472.6 6.4, 355620.5 6688446.9 6.5, 355623.7 6688441.3 6.5, 355624.4 6688435.1 6.5, 355624.6 6688431.1 6.4)
TRONROUT0000000295265165;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355547.5 6688668.6 6, 355591.5 6688658.5 6, 355617.2 6688652.7 6.2, 355648.6 6688646.5 6.2)
TRONROUT0000000029475243;Route à 1 chaussée;QU MONCOUSU;QU MONCOUSU;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;10;;3;;44109;44109;;;;441095713;441095713;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Moncousu;Quai Moncousu;;;44109_5713;44109_5713;;;;;LINESTRING Z (355551.7 6688685.3 6.8, 355663.6 6688660.5 6.6)
TRONROUT0000000029474604;Route à 1 chaussée;PL DE LA REPUBLIQUE;PL DE LA REPUBLIQUE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097276;441097276;;;;;;;;;;;;;commune;commune;Place de la République;Place de la République;;;44109_7276;44109_7276;;;;;LINESTRING Z (355399.80778204993 6688312.003221275 7.4, 355411.3 6688326.7 7.4)
TRONROUT0000000029473618;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;21;20;25B;22;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355366.3 6688407.1 6.9, 355301.7 6688401.5 6.9, 355280.2 6688400.3 6.8)
TRONROUT0000000320084037;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2013-03-12 15:44:51;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;19;16;19;18;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355404.2 6688410.4 6.9, 355366.3 6688407.1 6.9)
TRONROUT0000000320084036;Route à 1 chaussée;PAS DE L'IMPRIMERIE;PAS DE L'IMPRIMERIE;5;Non;0;En service;2013-03-12 15:44:51;2017-07-28 17:55:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QO;44109#0QO;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355351.3 6688433.6 7, 355363.3 6688434.5 6.9, 355366.3 6688407.1 6.9)
TRONROUT0000000320084038;Sentier;PAS DE L'IMPRIMERIE;PAS DE L'IMPRIMERIE;6;Non;0;En service;2013-03-12 15:44:51;2017-07-28 17:55:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0QO;44109#0QO;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355345.8 6688511.9 7.1, 355351.3 6688433.6 7)
TRONROUT0000000029473581;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;2;;1;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355345.8 6688511.9 7.1, 355395.2 6688501 7.9)
TRONROUT0000000029475231;Route à 1 chaussée;PONT HAUDAUDINE;PONT HAUDAUDINE;4;Non;0;En service;2006-10-04 09:41:10;2012-12-18 18:22:46;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#096;44109#096;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355395.2 6688501 7.9, 355394.3 6688515.8 8.7)
TRONROUT0000000320084035;Route à 1 chaussée;QU FRANCOIS MITTERRAND;QU FRANCOIS MITTERRAND;5;Non;0;En service;2013-03-12 15:44:51;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;4;;2B;44109;44109;QU FERNAND CROUAN;QU FERNAND CROUAN;;441093315;441093315;;;;;;;;;;;;;commune;commune;Quai François Mitterrand;Quai François Mitterrand;;;44109_3315;44109_3315;;;;;LINESTRING Z (355295.3 6688523.4 6.6, 355303.6 6688521.3 6.6, 355345.8 6688511.9 7.1)
TRONROUT0000000029473510;Route à 1 chaussée;PONT HAUDAUDINE;PONT HAUDAUDINE;4;Non;1;En service;2006-10-04 09:41:10;2012-12-18 18:22:46;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#096;44109#096;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355394.3 6688515.8 8.7, 355393.4 6688522.8 8, 355392.7 6688529.3 7.5, 355391.4 6688540.1 9.9, 355389.3 6688566.5 11.5, 355385.4 6688606.3 12.3, 355384 6688620.8 12.2, 355382.6 6688636.5 12.2, 355379.3 6688666.9 11.4, 355378.6 6688672.5 11.2, 355378.3 6688674.6 11, 355376.8 6688687.8 10.1, 355376.1 6688695.5 9.7, 355376.1 6688695.9 9.7, 355374.9 6688708.4 9, 355374.9 6688708.6 9, 355374.4 6688713.2 8.7)
TRONROUT0000000029474706;Route à 1 chaussée;PONT HAUDAUDINE;PONT HAUDAUDINE;4;Non;0;En service;2006-10-04 09:41:10;2012-12-18 18:22:46;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#096;44109#096;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355374.4 6688713.2 8.7, 355374.3 6688725.5 8.3)
TRONROUT0000000029473888;Route à 1 chaussée;PL DE LA REPUBLIQUE;PL DE LA REPUBLIQUE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097276;441097276;;;;;;;;;;;;;commune;commune;Place de la République;Place de la République;;;44109_7276;44109_7276;;;;;LINESTRING Z (355411.3 6688326.7 7.4, 355413.2139990897 6688312.003221275 7.4)
TRONROUT0000000029473587;Route à 1 chaussée;R LOUIS BLANC;R LOUIS BLANC;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;15;16;21;28;44109;44109;;;;441095064;441095064;;;;;;;;;;;;;commune;commune;Rue Louis Blanc;Rue Louis Blanc;;;44109_5064;44109_5064;;;;;LINESTRING Z (355404.2 6688410.4 6.9, 355407.1 6688376.6 7.2, 355411.3 6688326.7 7.7)
TRONROUT0000000029473721;Route à 1 chaussée;R LA TOUR D'AUVERGNE;R LA TOUR D'AUVERGNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7B;10;17;14T;44109;44109;;;;441094812;441094812;;;;;;;;;;;;;commune;commune;Rue La Tour d'Auvergne;Rue La Tour d'Auvergne;;;44109_4812;44109_4812;;;;;LINESTRING Z (355519.4 6688420.5 6.5, 355404.2 6688410.4 6.9)
TRONROUT0000000029475019;Route à 1 chaussée;R LOUIS BLANC;R LOUIS BLANC;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;4;7;14;44109;44109;;;;441095064;441095064;;;;;;;;;;;;;commune;commune;Rue Louis Blanc;Rue Louis Blanc;;;44109_5064;44109_5064;;;;;LINESTRING Z (355395.2 6688501 7.9, 355404.2 6688410.4 6.9)
TRONROUT0000000029474443;Route à 1 chaussée;QU ANDRE RHUYS;QU ANDRE RHUYS;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;9B;;5;44109;44109;;;;441090297;441090297;;;;;;;;;;;;;commune;commune;Quai André Rhuys;Quai André Rhuys;;;44109_0297;44109_0297;;;;;LINESTRING Z (355395.2 6688501 7.9, 355515.9 6688472.6 6.4)
TRONROUT0000000214956354;Route à 1 chaussée;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2009-01-06 13:42:58;2016-12-13 13:42:35;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355144.7 6688747.3 6.7, 355221.8 6688730.1 4, 355372.6 6688696.6 9.6, 355376.1 6688695.9 9.7, 355409.4 6688688.7 4.6, 355619.2 6688642.3 5, 355672.1 6688633.2 5, 355696.8 6688629.9 5.1, 355718.1 6688627.8 4.7, 355769.1 6688626 3.4, 355772.7 6688625.9 3.3)
TRONROUT0000000029475306;Route à 1 chaussée;QU MONCOUSU;QU MONCOUSU;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095713;441095713;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Moncousu;Quai Moncousu;;;44109_5713;44109_5713;;;;;LINESTRING Z (355374.3 6688725.5 8.3, 355413.4 6688716.4 7.5, 355464.3 6688704.6 6.5, 355535.8 6688689 6.8, 355551.7 6688685.3 6.8)
TRONROUT0000000295266733;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2013-01-10 10:48:11;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355469.6 6689001.5 9.7, 355458.5 6688996.7 9.8, 355437.3 6688908.8 14.1, 355435.7 6688897.8 14.3, 355439.5 6688888.8 14.5, 355446 6688884.6 14.6, 355457.3 6688882.5 13.8, 355460.3 6688887 14, 355463.5 6688894.6 14, 355483 6688988.1 9.4, 355479.8 6688996.9 9.4)
TRONROUT0000000029474925;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-01-10 10:48:11;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355479.8 6688996.9 9.4, 355469.6 6689001.5 9.7)
TRONROUT0000000295265259;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355404.1 6689022.1 8.7, 355409.1 6689011.9 8.7, 355413.1 6689004.4 9)
TRONROUT0000000029474535;Route à 1 chaussée;QU DE TOURVILLE;QU DE TOURVILLE;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1B;;1;;44109;44109;;;;441098161;441098161;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai de Tourville;Quai de Tourville;;;44109_8161;44109_8161;;;;;LINESTRING Z (355308.3 6688738.6 6.5, 355374.3 6688725.5 8.3)
TRONROUT0000000029473801;Route à 1 chaussée;R LUC-AUGUSTIN BACQUA;R LUC-AUGUSTIN BACQUA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;3;12;11;44109;44109;;;;441090516;441090516;;;;;;;;;;;;;commune;commune;Rue Luc-Augustin Bacqua;Rue Luc-Augustin Bacqua;;;44109_0516;44109_0516;;;;;LINESTRING Z (355314.8 6688792.5 6.5, 355308.3 6688738.6 6.5)
TRONROUT0000000029473601;Route à 1 chaussée;R GASTON VEIL;R GASTON VEIL;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;10;;14B;44109;44109;;;;441093524;441093524;;;;;;;;;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355360.2 6688860.3 7, 355361.4 6688855.1 7.2, 355363.5 6688836.5 7.4, 355374.3 6688725.5 8.3)
TRONROUT0000002002203253;Route à 1 chaussée;R LUC-AUGUSTIN BACQUA;R LUC-AUGUSTIN BACQUA;5;Non;0;En service;2017-03-08 17:36:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090516;441090516;;;;;;;;;;;;;commune;commune;Rue Luc-Augustin Bacqua;Rue Luc-Augustin Bacqua;;;44109_0516;44109_0516;;;;;LINESTRING Z (355319.3 6688848.2 6.4, 355319.5 6688831.4 6.5, 355314.8 6688792.5 6.5)
TRONROUT0000002002203255;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2017-03-08 17:36:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;3;;3;;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355319.3 6688848.2 6.4, 355290.5 6688842.2 6.4)
TRONROUT0000000029474771;Route à 1 chaussée;R BIAS;R BIAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;44109#0BX;44109#0BX;;;;;;;;;;;;;commune;commune;Rue Bias;Rue Bias;;;44109_0820;44109_0820;;;;;LINESTRING Z (355319.3 6688848.2 6.4, 355360.2 6688860.3 7)
TRONROUT0000000029474949;Route à 1 chaussée;R GASTON VEIL;R GASTON VEIL;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;6;;8;44109;44109;;;;441093524;441093524;;;;;;;;;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355344.2 6688895.3 7.2, 355353.3 6688877.6 7.1, 355356.2 6688872 7.1, 355360.2 6688860.3 7)
TRONROUT0000000029475161;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355344.2 6688895.3 7.2, 355358 6688903.6 7.5, 355360.7 6688907.8 7.5, 355369.8 6688950.6 7.5)
TRONROUT0000000029473941;Route à 1 chaussée;R GASTON VEIL;R GASTON VEIL;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;441093524;441093524;;;;;;;;;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355314.8 6688953.1 8.1, 355344.2 6688895.3 7.2)
TRONROUT0000000029475182;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2013-02-21 18:03:35;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355369.8 6688950.6 7.5, 355330.4 6688959.1 8.1, 355321.8 6688961.1 8.2, 355311.1 6688959.8 8.2)
TRONROUT0000000295264917;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355547.5 6688668.6 6, 355511.6 6688676.4 5.9, 355496.5 6688679.3 5.9)
TRONROUT0000000295265195;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355551.7 6688685.3 6.8, 355547.5 6688668.6 6)
TRONROUT0000000029474917;Route à 1 chaussée;BD JEAN MONNET;BD JEAN MONNET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441094501;441094501;;;;;;;;;;;;;commune;commune;Boulevard Jean Monnet;Boulevard Jean Monnet;;;44109_4501;44109_4501;;;;;LINESTRING Z (355483.8 6689041 10.2, 355494.9 6689038.7 10.3, 355504.9 6689035.4 10.4, 355520.8 6689030.3 9.4, 355528.2 6689024.8 9.4, 355533 6689020.7 9.5, 355536.4 6689015.1 9.5, 355589.6 6688938.2 7.7, 355628.2 6688881.1 9.2, 355662.1 6688831.7 7.8, 355673.5 6688814.8 8.5, 355677 6688809.6 8.3)
TRONROUT0000000295265007;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355642 6688923.6 7.3, 355632.1 6688928.4 7.3, 355626.7 6688931.9 7.3, 355620.8 6688938.8 7.3, 355607.4 6688957.8 7.3)
TRONROUT0000000325617290;Route à 1 chaussée;;;6;Non;0;En service;2013-09-02 15:17:00;2022-12-10 06:26:51;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355507.7 6689077.6 9.8, 355516.4 6689067.2 4, 355550.4 6689024.8 4.8, 355583 6688975 5.6, 355589.2 6688966.7 6.4, 355658.6 6688868.5 7.3)
TRONROUT0000000029474509;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;7;;1;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355645.5 6688969.3 7.7, 355608.2 6689049.6 8.1)
TRONROUT0000000029474877;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355596.9 6689057 8.9, 355596.2 6689055 8.9, 355597.5 6689051.4 8.7, 355600.4 6689049 8.5, 355604.5 6689048.3 8.3, 355608.2 6689049.6 8.1)
TRONROUT0000000029474942;Rond-point;;;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355608.2 6689049.6 8.1, 355608.7 6689049.8 8.1, 355611.5 6689052.6 8, 355612.6 6689056.6 8, 355611.8 6689060 7.9)
TRONROUT0000000295264890;Rond-point;;;3;Non;0;En service;2012-02-08 10:00:49;2017-10-19 14:26:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355611.8 6689060 7.9, 355611.6 6689060.6 8, 355608.8 6689063.4 8.2, 355604.8 6689064.5 8.4, 355604.6 6689064 8.4, 355600.4 6689062.3 8.6, 355597.5 6689059.1 8.8, 355596.9 6689057 8.9)
TRONROUT0000000227214043;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2009-12-08 10:39:02;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355566.2 6689069.9 9.2, 355573.2 6689065.6 8.7, 355584.9 6689060.2 8.3, 355593.8 6689057.5 8.3, 355596.9 6689057 8.9)
TRONROUT0000000029474133;Route à 1 chaussée;R GASTON VEIL;R GASTON VEIL;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;;;;;;;;;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355311.1 6688959.8 8.2, 355314.8 6688953.1 8.1)
TRONROUT0000000029474960;Route à 1 chaussée;R GASTON VEIL;R GASTON VEIL;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;;;;;;;;;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355306.5 6688973.6 8.2, 355311.1 6688959.8 8.2)
TRONROUT0000000295264881;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355293.8 6688979.4 8.3, 355294.1 6688976.8 8.3, 355300.3 6688972.7 8.3, 355306.5 6688973.6 8.2)
TRONROUT0000000295264887;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355306.5 6688973.6 8.2, 355308.4 6688974.6 8, 355310.2 6688975.8 8, 355311.7 6688978.4 8, 355312.1 6688980.9 8.2)
TRONROUT0000000029475196;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355369.8 6688950.6 8.8, 355378.1 6688983 8.8, 355382.8 6688988.8 8.6, 355391.2 6688994 8.9, 355413.1 6689004.4 9)
TRONROUT0000000029474887;Route à 2 chaussées;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355281.5 6688987.5 7.5, 355288.3 6688983.5 7.6, 355293.8 6688979.4 8.3)
TRONROUT0000000029474500;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355312.1 6688980.9 8.2, 355312.3 6688982.7 8.4, 355310.5 6688987.9 8.9, 355308.9 6688989.4 8.7)
TRONROUT0000000295264883;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355299 6688991.2 8.3, 355294.5 6688987.2 8.3, 355293.1 6688984.5 8.3, 355293.8 6688979.4 8.3)
TRONROUT0000000295265179;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355312.1 6688980.9 8.2, 355319.4 6688986.4 8.2, 355331 6688993.4 8.7)
TRONROUT0000000295264882;Rond-point;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355308.9 6688989.4 8.7, 355308.1 6688990.2 8.7, 355304.7 6688991.4 8.5, 355299 6688991.2 8.3)
TRONROUT0000000295265074;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2015-06-25 19:13:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355479.8 6688996.9 9.4, 355482.9 6689007.2 9.4, 355484.7 6689015.3 9.5, 355485.2 6689020.2 9.8, 355484.4 6689024 9.9, 355482.4 6689027.4 9.8, 355477.7 6689033.1 9.8)
TRONROUT0000000029475153;Route à 1 chaussée;ALL CHARLES MIRALLIE;ALL CHARLES MIRALLIE;5;Non;0;En service;2006-10-04 09:41:10;2015-06-25 19:13:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CR;44109#0CR;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355472.7 6689032.3 9.5, 355473.7 6689026 9.5, 355473.5 6689020 9.5, 355471.9 6689012.1 9.5, 355469.6 6689001.5 9.7)
TRONROUT0000000295265254;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2014-06-16 18:46:18;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355453.7 6689034.5 8.9, 355457.3 6689024.3 9, 355456.3 6689016.2 9.5, 355451.1 6689008.1 9.5, 355445.5 6689006.6 9.3, 355436.8 6689007.8 9.1, 355429.7 6689010 9, 355413.1 6689004.4 9)
TRONROUT0000000029475201;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355432.3 6689031.6 8.9, 355424 6689029 8.7, 355404.1 6689022.1 8.7)
TRONROUT0000000295266732;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355472.7 6689032.3 9.5, 355476.3 6689032.7 9.7, 355477.7 6689033.1 9.8)
TRONROUT0000000295265138;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355432.3 6689031.6 8.9, 355449.9 6689034.4 8.9, 355453.7 6689034.5 8.9)
TRONROUT0000000029474875;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355467.1 6689034.1 9.4, 355469.5 6689032.7 9.4, 355472.7 6689032.3 9.5)
TRONROUT0000000295265169;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355453.7 6689034.5 8.9, 355459.6 6689034.6 8.9, 355467.1 6689034.1 9.4)
TRONROUT0000000029474902;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355477.7 6689033.1 9.8, 355479.5 6689034.3 9.8, 355482 6689036.7 9.9, 355483.6 6689039.8 10, 355483.8 6689041 10.2)
TRONROUT0000000295265097;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355462.5 6689046.8 9.4, 355453.6 6689042.1 9.4, 355451.2 6689040.9 9.4, 355442.5 6689036.7 9.4, 355432.3 6689031.6 8.9)
TRONROUT0000000295264893;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355462.5 6689046.8 9.4, 355461.9 6689043.4 9.4, 355462.3 6689040.6 9.4, 355462.4 6689040 9.4, 355464 6689036.9 9.4, 355466.5 6689034.4 9.4, 355467.1 6689034.1 9.4)
TRONROUT0000000029474943;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355483.8 6689041 10.2, 355483.8 6689044.2 9.9, 355483.2 6689046.8 9.9, 355482.2 6689049.5 9.7, 355479.9 6689052.4 9.4)
TRONROUT0000000029474945;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355471.7 6689055.1 9.4, 355469.7 6689053.9 9.4, 355466.6 6689052.4 9.4, 355464.1 6689049.9 9.4, 355462.5 6689046.8 9.4)
TRONROUT0000000029475058;Rond-point;PL ALEXIS RICORDEAU;PL ALEXIS RICORDEAU;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090120;441090120;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place Alexis Ricordeau;Place Alexis Ricordeau;;;44109_0120;44109_0120;;;;;LINESTRING Z (355479.9 6689052.4 9.4, 355477 6689053.8 9.4, 355473.3 6689054.7 9.4, 355471.7 6689055.1 9.4)
TRONROUT0000000029474821;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355479.9 6689052.4 9.4, 355491.1 6689064.6 9.5, 355505.8 6689076.2 9.8, 355507.7 6689077.6 9.8)
TRONROUT0000000029475104;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355493.5 6689078.1 9.9, 355479.8 6689065.5 9.3, 355471.7 6689055.1 9.4)
TRONROUT0000000325617292;Route à 1 chaussée;;;6;Non;0;En service;2013-09-02 15:17:00;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355503.1 6689084.4 10.1, 355507.7 6689077.6 9.8)
TRONROUT0000000029474907;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355503.1 6689084.4 10.1, 355493.5 6689078.1 9.9)
TRONROUT0000000029475194;Route à 1 chaussée;QU TURENNE;QU TURENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;8;;10B;44109;44109;;;;441098260;441098260;;;;;;;;;;;;;commune;commune;Quai Turenne;Quai Turenne;;;44109_8260;44109_8260;;;;;LINESTRING Z (355477.6 6689107.2 6.2, 355457.6 6689096.4 6.2, 355431.5 6689082.8 6.2, 355410.9 6689071.8 6.2, 355385.8 6689059 6.8)
TRONROUT0000000029475255;Escalier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-09-28 17:33:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355477.6 6689107.2 6.2, 355480.3 6689099.1 6.5, 355485.5 6689089.6 7.9, 355488.8 6689083.3 8.8, 355493.5 6689078.1 9.9)
TRONROUT0000000322978302;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2013-06-10 16:39:37;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355560.6 6689074.3 9.2, 355564.8 6689070.8 9.2, 355566.2 6689069.9 9.2)
TRONROUT0000000029473854;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355556.5 6689077.8 9.3, 355560.6 6689074.3 9.2)
TRONROUT0000000295265244;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355538.3 6689088 9.4, 355543.7 6689086.1 9.5, 355548.8 6689083.6 9.7, 355556.5 6689077.8 9.3)
TRONROUT0000000325617295;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2013-09-02 15:17:00;2023-05-26 09:18:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355507.7 6689077.6 9.8, 355516.2 6689083.6 10.2, 355531.3 6689089 9.3)
TRONROUT0000000295265245;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355556.5 6689077.8 9.3, 355551.8 6689084 9.7, 355548.6 6689089.3 9.8, 355546.9 6689094.5 9.7)
TRONROUT0000000295265172;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2018-11-13 07:54:47;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355531.3 6689089 9.3, 355532.6 6689088.7 9.3, 355535.2 6689088 9.3, 355538.3 6689088 9.4)
TRONROUT0000000325617294;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2013-09-02 15:17:00;2017-07-28 17:55:21;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355525.6 6689097.2 10.1, 355511.4 6689089.9 10.2, 355503.1 6689084.4 10.1)
TRONROUT0000000295265203;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355538.3 6689088 9.4, 355541.3 6689089 9.5, 355544 6689090.3 9.6, 355545.8 6689092.3 9.7, 355546.9 6689094.5 9.7)
TRONROUT0000000295266790;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355525.6 6689097.2 10.1, 355526.2 6689095.4 8.7, 355527.3 6689093.1 8.7, 355529.1 6689090.9 8.9, 355531.3 6689089 9.3)
TRONROUT0000000227214040;Route à 1 chaussée;;;6;Non;0;En service;2009-12-08 10:39:02;2022-12-10 06:26:51;;;;;Levé non GPS;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355560.6 6689074.3 9.2, 355583.1 6689090.3 -1000, 355635.3 6689116.5 7.5)
TRONROUT0000000295265181;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355331 6688993.4 8.7, 355320 6688990.9 8.7, 355308.9 6688989.4 8.7)
TRONROUT0000000295265200;Route à 2 chaussées;R GASTON VEIL;R GASTON VEIL;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093524;441093524;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Gaston Veil;Rue Gaston Veil;;;44109_3524;44109_3524;;;;;LINESTRING Z (355299 6688991.2 8.3, 355294 6688992.5 8.3, 355289.6 6688994.2 7.7)
TRONROUT0000000029475154;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355404.1 6689022.1 8.7, 355378.2 6689012.2 8.7, 355339.8 6688996.8 8.7, 355331 6688993.4 8.7)
TRONROUT0000000029475090;Route à 1 chaussée;QU TURENNE;QU TURENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;11;;13;44109;44109;;;;441098260;441098260;;;;;;;;;;;;;commune;commune;Quai Turenne;Quai Turenne;;;44109_8260;44109_8260;;;;;LINESTRING Z (355385.8 6689059 6.8, 355366.8 6689048.9 6.8, 355351.2 6689040.7 6.5, 355326.4 6689027.8 6.8, 355302.1 6689015.2 7.4, 355287.9 6689008.5 7.4, 355282.2 6689006.7 7.7)
TRONROUT0000000029474718;Route à 1 chaussée;;;6;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355385.8 6689059 6.8, 355390 6689050.4 6.8, 355394.8 6689040.4 7.9, 355399.3 6689032.1 8.9, 355404.1 6689022.1 8.7)
TRONROUT0000000029473956;Route à 1 chaussée;R KERVEGAN;R KERVEGAN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;32;23;24;17;44109;44109;;;;441094708;441094708;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Kervégan;Rue Kervégan;;;44109_4708;44109_4708;;;;;LINESTRING Z (355364.2 6689100 6.8, 355259.2 6689045 6.9)
TRONROUT0000000029475237;Route à 1 chaussée;R DU GUESCLIN;R DU GUESCLIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;3;8;3;10;44109;44109;;;;441092620;441092620;;;;;;;;;;;;;commune;commune;Rue du Guesclin;Rue du Guesclin;;;44109_2620;44109_2620;;;;;LINESTRING Z (355364.2 6689100 6.8, 355385.8 6689059 6.8)
TRONROUT0000000029474566;Route à 1 chaussée;ALL DUGUAY TROUIN;ALL DUGUAY TROUIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092616;441092616;;;;;;;;;;;;;commune;commune;Allée Duguay Trouin;Allée Duguay Trouin;;;44109_2616;44109_2616;;;;;LINESTRING Z (355341.4 6689143.2 6.7, 355294.4 6689119.3 6.8, 355268.4 6689106.1 6.9, 355247.2 6689095.9 7.1, 355235.7 6689089.6 7.2)
TRONROUT0000000029474456;Route à 1 chaussée;R DU GUESCLIN;R DU GUESCLIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;6;44109;44109;;;;441092620;441092620;;;;;;;;;;;;;commune;commune;Rue du Guesclin;Rue du Guesclin;;;44109_2620;44109_2620;;;;;LINESTRING Z (355341.4 6689143.2 6.7, 355364.2 6689100 6.8)
TRONROUT0000000029474370;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 20:43:48;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355412.1 6689206.6 7.3, 355399.3 6689201.6 7.2, 355283.7 6689141.4 6.3, 355245.9 6689123.3 6.8, 355231 6689115.1 6.9)
TRONROUT0000000029474119;Route à 1 chaussée;;;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 06:26:51;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (356284.3 6688804.5 6.6, 356279.3 6688802.4 6.6, 356229.4 6688779.9 7, 356226.9 6688782.6 6.9)
TRONROUT0000000029474195;Rond-point;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2006-10-04 09:41:10;2020-10-28 11:40:19;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356230.3 6688800.7 7.3, 356229.9 6688798.7 7.8, 356230.2 6688797.1 7.8, 356231.7 6688794.2 7.6, 356234.4 6688791.5 7.2, 356236.3 6688790.2 7)
TRONROUT0000000295265305;Rond-point;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2012-02-08 10:00:49;2020-10-28 11:40:19;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356236.3 6688790.2 7, 356240.9 6688790.2 7, 356246.9 6688792.5 7.2, 356248.9 6688795 7.2, 356250.1 6688798.6 7.2, 356249.5 6688803.6 7.6)
TRONROUT0000000029474031;Rond-point;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2006-10-04 09:41:10;2020-10-28 11:40:19;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356236.2 6688809.1 7.6, 356234.3 6688807.9 7.2, 356232.4 6688806.1 7.2, 356231.1 6688804.4 7.1, 356230.3 6688800.7 7.3)
TRONROUT0000000295265428;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.6;;;;;Non;;23;;26;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356282.6 6688810.3 7.4, 356272.4 6688807 7.1, 356262.9 6688805 6.5, 356253.4 6688803.8 6.5, 356249.5 6688803.6 7.6)
TRONROUT0000000029473698;Rond-point;QU ANDRE MORICE;QU ANDRE MORICE;3;Non;0;En service;2006-10-04 09:41:10;2020-10-28 11:40:19;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;3.3;;;;;Non;;;;;44109;44109;;;;441090282;441090282;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356249.5 6688803.6 7.6, 356248.5 6688805.3 7.6, 356247.9 6688807.2 7.7, 356246.6 6688808.6 7.6, 356244.9 6688809.9 7.8, 356242.1 6688810.4 7.9, 356239.5 6688810.2 7.5, 356236.2 6688809.1 7.6)
TRONROUT0000000029474172;Route à 1 chaussée;R VASCO DE GAMA;R VASCO DE GAMA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098307;441098307;;;;;;;;;;;;;commune;commune;Rue Vasco de Gama;Rue Vasco de Gama;;;44109_8307;44109_8307;;;;;LINESTRING Z (356303.7 6688833.4 7.4, 356284.7 6688825.4 7.3, 356282.6 6688810.3 7.4)
TRONROUT0000000295265438;Route à 1 chaussée;;;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 06:26:51;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (356387.1 6688868.4 7.4, 356386.9 6688860.7 7.3, 356382.5 6688855.7 7.3, 356371.7 6688852.6 6.7, 356362.8 6688849.1 6.3, 356353.4 6688842.7 6.2, 356349.3 6688840.1 6.1, 356338.1 6688833 6, 356323.9 6688824.7 6, 356311.3 6688817.6 6.6, 356294.7 6688808.8 6.6, 356284.3 6688804.5 6.6)
TRONROUT0000000029474974;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.6;;;;;Non;;;;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356365.9 6688864.2 7.5, 356362.7 6688859.2 7.2, 356356.3 6688852.5 6.9, 356348 6688845.7 6.7, 356346.9 6688845.1 6.6, 356336.6 6688839.2 6.6, 356324.6 6688832 6.5, 356310.1 6688823.6 6.5, 356296.3 6688816.3 6.6, 356282.6 6688810.3 7.4)
TRONROUT0000000316466089;Route à 1 chaussée;R VASCO DE GAMA;R VASCO DE GAMA;5;Non;0;En service;2012-12-10 15:36:44;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098307;441098307;;;;;;;;;;;;;commune;commune;Rue Vasco de Gama;Rue Vasco de Gama;;;44109_8307;44109_8307;;;;;LINESTRING Z (356330.1 6688846.9 7.3, 356327.6 6688843.6 7.4, 356303.7 6688833.4 7.4)
TRONROUT0000000029473970;Route à 1 chaussée;R DE BELFORT;R DE BELFORT;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;5.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;1;;11;;44109;44109;;;;441090704;441090704;;;;;;;;;;;;;commune;commune;Rue de Belfort;Rue de Belfort;;;44109_0704;44109_0704;;;;;LINESTRING Z (356205.4 6688884.9 8.2, 356221.4 6688843.3 7.7, 356236.2 6688809.1 7.6)
TRONROUT0000000295265296;Rond-point;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356365.9 6688864.2 7.5, 356367.7 6688862.3 7.5, 356369.2 6688861.6 7.6, 356370.8 6688861.5 7.6, 356373.2 6688861.6 7.5, 356376 6688862.9 7.5, 356377.9 6688865.4 7.4, 356378.5 6688866.4 7.3)
TRONROUT0000000029475047;Rond-point;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356368 6688875.1 7.4, 356366.1 6688872.8 7.4, 356364.8 6688870.2 7.4, 356364.8 6688867.2 7.5, 356365.9 6688864.2 7.5)
TRONROUT0000000029474798;Rond-point;QU MAGELLAN;QU MAGELLAN;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356373.8 6688875.1 7.3, 356371.2 6688875.3 7.3, 356368 6688875.1 7.4)
TRONROUT0000000316466087;Route à 1 chaussée;R VASCO DE GAMA;R VASCO DE GAMA;5;Non;0;En service;2012-12-10 15:36:44;2023-05-26 09:18:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;10;5;2;1;44109;44109;;;;441098307;441098307;;;;;;;;;;;;;commune;commune;Rue Vasco de Gama;Rue Vasco de Gama;;;44109_8307;44109_8307;;;;;LINESTRING Z (356261.3 6688923.3 7.4, 356303.7 6688833.4 7.4)
TRONROUT0000000295265315;Rond-point;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;15;;15;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356199.2 6688885.5 8.2, 356202.3 6688884.2 8.2, 356205.4 6688884.9 8.2)
TRONROUT0000002209483779;Route à 1 chaussée;;;5;Non;0;En service;2020-09-23 10:42:32;2021-11-18 18:07:39;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356273.9 6688930.1 7.3, 356277.4 6688921.5 7.4, 356283 6688924.4 7.4, 356288.9 6688926.4 7.4, 356294.1 6688925.7 7.4, 356330.5 6688850.7 7.3, 356330.1 6688846.9 7.3)
TRONROUT0000000029474081;Rond-point;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356198 6688893.7 8.2, 356196.8 6688890.5 8.2, 356197.8 6688887.1 8.2, 356199.2 6688885.5 8.2)
TRONROUT0000000029473663;Rond-point;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;9;;9;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356205.4 6688884.9 8.2, 356207.6 6688886.4 8.1, 356209.5 6688888.6 8.1, 356209.6 6688891 8.1, 356208.3 6688894.7 8.2)
TRONROUT0000000039537304;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2006-11-08 07:40:16;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356291.1 6688937.2 8, 356297.4 6688931 8.2, 356302.1 6688925.9 8.5, 356306 6688918.7 8.9, 356328.4 6688873.4 14.6, 356338.8 6688850.8 12.9)
TRONROUT0000000029473655;Rond-point;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356208.3 6688894.7 8.2, 356205.2 6688896.3 8.2, 356200.6 6688896.2 8.2, 356198 6688893.7 8.2)
TRONROUT0000000053385301;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356343 6688853 6.6, 356300.7 6688940.6 8.2)
TRONROUT0000000029473523;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356349.1 6688855.5 12.1, 356335.8 6688880.9 11.3, 356327.8 6688897.2 10.3, 356315.4 6688923.5 8.6, 356312.2 6688930.8 8.3, 356310.2 6688938.6 8.1, 356307.9 6688945.4 8.1)
TRONROUT0000000029474858;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;1;;7;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356261.3 6688923.3 7.4, 356208.3 6688894.7 8.2)
TRONROUT0000000029474966;Route à 2 chaussées;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:10:23;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;31;;31;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356376.4 6688972.2 9.4, 356370.8 6688949.9 8, 356367.4 6688936.4 7.6, 356366.6 6688922.5 7.5, 356366.1 6688905.6 7.6, 356367.3 6688881.7 7.6, 356368 6688875.1 7.4)
TRONROUT0000000316466088;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2012-12-10 15:36:44;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356273.9 6688930.1 7.3, 356261.3 6688923.3 7.4)
TRONROUT0000000029475228;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356291.1 6688937.2 8.1, 356273.9 6688930.1 7.3)
TRONROUT0000002274997838;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;3;Non;0;En service;2021-11-18 18:07:39;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356281.3 6688944.7 8, 356273.9 6688930.1 7.3)
TRONROUT0000000294302141;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356291.1 6688937.2 8.1, 356297.1 6688938.4 8.2, 356300.7 6688940.6 8.2)
TRONROUT0000000053385289;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356281.3 6688944.7 8, 356284.9 6688940.4 8.1, 356291.1 6688937.2 8.1)
TRONROUT0000000356559129;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2016-02-15 14:51:01;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;8;;12;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356450.3 6688894.7 8.2, 356387.1 6688868.4 7.4)
TRONROUT0000000295265303;Route à 1 chaussée;QU MAGELLAN;QU MAGELLAN;5;Non;0;En service;2012-02-08 10:00:49;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;1;;7;44109;44109;;;;441095201;441095201;;;;;;;;;;;;;commune;commune;Quai Magellan;Quai Magellan;;;44109_5201;44109_5201;;;;;LINESTRING Z (356450.3 6688894.7 8.2, 356504.1 6688916.7 7.8, 356506.81139568595 6688917.9445750695 7.785183630130523)
TRONROUT0000002245140104;Route à 2 chaussées;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2021-09-02 17:32:49;2023-01-19 14:10:23;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;4.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356373.8 6688875.1 -1000, 356371.6 6688906.1 -1000, 356372.1 6688928 -1000, 356376.9 6688952.4 -1000, 356385.1 6688973.4 -1000)
TRONROUT0000000295265311;Route à 1 chaussée;R DE BITCHE;R DE BITCHE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;2;3;8;44109;44109;;;;441090844;441090844;;;;;;;;;;;;;commune;commune;Rue de Bitche;Rue de Bitche;;;44109_0844;44109_0844;;;;;LINESTRING Z (356450.3 6688894.7 8.2, 356419.6 6688956.1 7.4)
TRONROUT0000000356559127;Route à 1 chaussée;;;6;Non;0;En service;2016-02-15 14:51:01;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (356387.1 6688868.4 7.4, 356385.3 6688874.5 7.8, 356378.6 6688882.1 8.2, 356377.3 6688889 8.6, 356376.9 6688903.2 9.1, 356376.9 6688928.4 9.5, 356383.8 6688956.5 9.9, 356390.4 6688971.5 10.4, 356397.9 6688988.7 10.8, 356405.6 6689001.2 11.2, 356420.4 6689016.9 11.7, 356435.9 6689029 12.1, 356452.4 6689039.1 12.6)
TRONROUT0000002274984484;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2021-11-17 17:40:22;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356506.81139568595 6688983.700193799 6.818739761208458, 356498.7 6688994.1 7)
TRONROUT0000002245140106;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2021-09-02 17:32:49;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356376.4 6688972.2 9.4, 356381.4 6688972.5 9.2, 356385.1 6688973.4 9.2)
TRONROUT0000002274997837;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2021-11-18 18:07:39;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356385.1 6688973.4 9.2, 356387.5 6688975.6 9, 356389.1 6688979 9, 356389.4 6688984.9 9.4)
TRONROUT0000000029473979;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356389.4 6688984.9 9.4, 356386.6 6688988.4 9.6, 356382.3 6688991.1 10)
TRONROUT0000000029474521;Route à 1 chaussée;R DE BITCHE;R DE BITCHE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;9;10;9;16;44109;44109;;;;441090844;441090844;;;;;;;;;;;;;commune;commune;Rue de Bitche;Rue de Bitche;;;44109_0844;44109_0844;;;;;LINESTRING Z (356419.6 6688956.1 7.4, 356408.6 6688978.1 7.2, 356408.9 6688983.1 7.2, 356411.7 6688988.7 7.2, 356477.5 6689021.2 7.5)
TRONROUT0000000053385304;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356300.7 6688940.6 8.2, 356307.9 6688945.4 8.1)
TRONROUT0000000053385286;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356307.9 6688945.4 8.1, 356311.1 6688949.8 7.9, 356311.7 6688957.8 8)
TRONROUT0000000053385303;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356300.7 6688940.6 8.2, 356287.2 6688968.8 8.3)
TRONROUT0000002274997839;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2021-11-18 18:07:39;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356282 6688964.7 8.1, 356279 6688958.6 8.1, 356278.6 6688950.6 8, 356281.3 6688944.7 8)
TRONROUT0000000053385287;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356311.7 6688957.8 7.7, 356309.6 6688962.2 7.8, 356306.9 6688966.5 7.7)
TRONROUT0000000053385306;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356287.2 6688968.8 8.3, 356284.8 6688967.3 8.2, 356282 6688964.7 8.1)
TRONROUT0000000029474262;Route à 2 chaussées;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;31;;31;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356311.7 6688957.8 8.5, 356318.9 6688963 7.8, 356327.7 6688968.5 7.8, 356339.7 6688973.3 8, 356352.5 6688976.6 8.2, 356359.9 6688977 8.8, 356365.7 6688976.8 8.8, 356369.7 6688977 8.8)
TRONROUT0000000294302142;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356306.9 6688966.5 7.7, 356302.7 6688969.7 7.7, 356297.2 6688971.4 7.8)
TRONROUT0000000053385305;Rond-point;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356297.2 6688971.4 7.8, 356291.4 6688970.6 8, 356287.2 6688968.8 8.3)
TRONROUT0000000029474839;Route à 2 chaussées;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:10:23;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356348.1 6688981.4 7.8, 356318.4 6688969.7 8.2, 356306.9 6688966.5 0.1)
TRONROUT0000000029474750;Route à 1 chaussée;R DE RIEUX;R DE RIEUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097324;441097324;;;;;;;;;;;;;commune;commune;Rue de Rieux;Rue de Rieux;;;44109_7324;44109_7324;;;;;LINESTRING Z (356198 6688893.7 8.2, 356193.2 6688893 8, 356188.3 6688891.5 8.2, 356184 6688890.2 8.4)
TRONROUT0000000029475051;Route à 1 chaussée;R DE MAYENCE;R DE MAYENCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095556;441095556;;;;;;;;;;;;;commune;commune;Rue de Mayence;Rue de Mayence;;;44109_5556;44109_5556;;;;;LINESTRING Z (356150.1 6688945.1 7.2, 356165.2 6688914.1 7.4, 356175.4 6688893.5 7.6, 356178 6688890.7 7.7)
TRONROUT0000000029474507;Route à 1 chaussée;R DE SAVERNE;R DE SAVERNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;8;9;2;5;44109;44109;;;;441097852;441097852;;;;;;;;;;;;;commune;commune;Rue de Saverne;Rue de Saverne;;;44109_7852;44109_7852;;;;;LINESTRING Z (356039.7 6688918.8 7.1, 356117.6 6688935.7 6.9, 356150.1 6688945.1 7.2)
TRONROUT0000000029474969;Route à 1 chaussée;R DE MAYENCE;R DE MAYENCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;4;;4;44109;44109;;;;441095556;441095556;;;;;;;;;;;;;commune;commune;Rue de Mayence;Rue de Mayence;;;44109_5556;44109_5556;;;;;LINESTRING Z (356132.3 6688981.7 7.5, 356150.1 6688945.1 7.2)
TRONROUT0000000029474576;Route à 1 chaussée;R DE COLMAR;R DE COLMAR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;441092020;441092020;;;;;;;;;;;;;commune;commune;Rue de Colmar;Rue de Colmar;;;44109_2020;44109_2020;;;;;LINESTRING Z (356132.3 6688981.7 7.5, 356117.8 6688977.3 7.3, 356109.1 6688978.7 7.2, 356055.9 6688990.9 6.9)
TRONROUT0000000029474023;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;19;30;19;32;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356059.5 6689007.3 6.7, 356055.9 6688990.9 6.9)
TRONROUT0000000029475174;Route à 1 chaussée;R DE MAYENCE;R DE MAYENCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;12;44109;44109;;;;441095556;441095556;;;;;;;;;;;;;commune;commune;Rue de Mayence;Rue de Mayence;;;44109_5556;44109_5556;;;;;LINESTRING Z (356132.3 6688981.7 7.5, 356124.3 6688996.6 6.6, 356114.4 6689017 6.7, 356105.3 6689035 6.7, 356101.3 6689044.2 6.7, 356099.5 6689048.8 6.7)
TRONROUT0000000029474021;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;15;24;17;28;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356068 6689045.7 6.9, 356059.5 6689007.3 6.7)
TRONROUT0000000294302118;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356068 6689045.7 6.9, 356074.3 6689045.1 6.9, 356079.9 6689045.6 6.9, 356085.9 6689046.9 6.7, 356090.9 6689048.6 6.6, 356094.5 6689049.4 6.7)
TRONROUT0000000294302117;Rond-point;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356094.5 6689049.4 6.7, 356097.2 6689048.8 6.7, 356099.5 6689048.8 6.7)
TRONROUT0000000029473880;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356382.3 6688991.1 10, 356378.7 6688991.7 9.4, 356374.5 6688990.8 9.4, 356371.6 6688989 9.4)
TRONROUT0000000329622969;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6688998.528635575 -1000, 356498.7 6688994.1 -1000)
TRONROUT0000002274997836;Route à 1 chaussée;PONT DE TBILISSI;PONT DE TBILISSI;3;Non;0;En service;2021-11-18 18:07:39;;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08Z;44109#08Z;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356389.4 6688984.9 9.4, 356394 6688992.5 9.8, 356404.3 6689006.3 10.8, 356414.7 6689017.4 11.6, 356425.8 6689028.3 12.5)
TRONROUT0000000029473983;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;7;;7;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356498.7 6688994.1 7, 356477.5 6689021.2 7.5)
TRONROUT0000000029474314;Route à 1 chaussée;PONT DE TBILISSI;PONT DE TBILISSI;3;Non;0;En service;2006-10-04 09:41:10;2021-11-18 18:07:39;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08Z;44109#08Z;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356425.8 6689028.3 12.5, 356418.1 6689025.1 12.3, 356410.8 6689020 12.3, 356405.4 6689014.8 11.8, 356399.6 6689009.1 11.3, 356382.3 6688991.1 10)
TRONROUT0000000029474749;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2021-11-18 18:07:39;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356445.5 6689063 6.7, 356437.2 6689056.3 6.7, 356420.3 6689044.6 6.7, 356401.5 6689032.8 7.1, 356379.1 6689018 7.5, 356358.3 6689005.3 7.9, 356351.2 6689000.3 7.9, 356349.4 6688996.1 7.9, 356348.7 6688990.3 8.1, 356348.2 6688986.5 8.1, 356348.1 6688981.4 7.8)
TRONROUT0000002274997835;Route à 1 chaussée;PONT DE TBILISSI;PONT DE TBILISSI;3;Non;0;En service;2021-11-18 18:07:39;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08Z;44109#08Z;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356449.8 6689043 13.1, 356425.8 6689028.3 12.5)
TRONROUT0000000029474543;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356445.5 6689063 6.7, 356457.1 6689047.6 6.7, 356468.2 6689032.7 6.9, 356477.5 6689021.2 7.5)
TRONROUT0000000356559128;Route à 1 chaussée;;;6;Non;1;En service;2016-02-15 14:51:01;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;;;;;;;;;;;;;LINESTRING Z (356452.4 6689039.1 12.6, 356460 6689044.6 12.1, 356506.81139568595 6689073.333337505 11.800694400984236)
TRONROUT0000000029474560;Route à 1 chaussée;PONT DE TBILISSI;PONT DE TBILISSI;3;Non;1;En service;2006-10-04 09:41:10;2012-12-18 18:44:26;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08Z;44109#08Z;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6689077.82167333 13.025820410313484, 356488 6689066.5 13.2, 356475.7 6689059.1 13.3, 356469.7 6689055.3 13.2, 356461.5 6689050.3 13.4, 356455.7 6689046.7 13.2, 356449.8 6689043 13.1)
TRONROUT0000000029474876;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356369.7 6688977 8.8, 356371.6 6688974.3 8.8, 356376.4 6688972.2 9.4)
TRONROUT0000000029474832;Rond-point;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356371.6 6688989 9.4, 356370.2 6688986.9 9.4, 356369.4 6688984 9.4, 356368.8 6688981.7 9.2, 356369.7 6688977 8.8)
TRONROUT0000000029474998;Route à 1 chaussée;R DE FLEURUS;R DE FLEURUS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093160;441093160;;;;;;;;;;;;;commune;commune;Rue de Fleurus;Rue de Fleurus;;;44109_3160;44109_3160;;;;;LINESTRING Z (356371.6 6688989 9.4, 356348.1 6688981.4 7.8)
TRONROUT0000000053385300;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356211.3 6689107.2 7.3, 356212.1 6689105.7 9, 356214.7 6689100.9 9.6, 356217.3 6689095.7 9.5, 356220.2 6689090.2 9.4, 356223 6689084.6 9.6, 356226 6689078.7 9.6, 356228.6 6689072.6 9.4, 356231.6 6689066.6 9.5, 356241 6689047.6 9.6, 356244.8 6689041 9.8, 356275.3 6688984.8 10.6, 356279.7 6688975.7 9.4, 356281.2 6688970.6 9.6, 356282 6688964.7 8.2)
TRONROUT0000000294302101;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356215.1 6689112.1 7.8, 356217.8 6689106.7 7.8, 356281.7 6688975.9 7.3, 356287.2 6688968.8 8.3)
TRONROUT0000000053385294;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356287.2 6688968.8 8.3, 356285.3 6688978.1 7.3, 356218.6 6689115.3 9.1)
TRONROUT0000000039537302;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2006-11-08 07:40:16;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356297.2 6688971.4 7.8, 356292.1 6688976.1 7.7, 356286.4 6688984.5 7.6, 356281.9 6688993.8 7.5, 356273.4 6689010.9 7.5, 356264.8 6689027.3 7.5, 356255.3 6689047 7.5, 356246.1 6689066 7.5, 356237 6689084.8 7.4, 356229.2 6689101.1 7.3, 356226.9 6689107.7 7.1, 356225.4 6689112.1 7.1, 356223.6 6689117.4 7.2, 356222.8 6689119.9 7)
TRONROUT0000000053385293;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356211.3 6689107.2 7.3, 356215.1 6689112.1 7.8)
TRONROUT0000000053385290;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356204.5 6689119.3 8.4, 356211.3 6689107.2 7.3)
TRONROUT0000000053385292;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356215.1 6689112.1 9.2, 356218.6 6689115.3 9.2)
TRONROUT0000000029473950;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356069.9 6689054.1 6.9, 356068.8 6689049.3 7, 356068 6689045.7 6.9)
TRONROUT0000000294302111;Rond-point;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356099.5 6689048.8 6.7, 356101.9 6689049.6 6.7, 356103.4 6689050.9 6.7, 356104.2 6689052.4 6.7, 356104.6 6689054 6.7, 356104.5 6689056 6.7)
TRONROUT0000000294302109;Rond-point;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356091.1 6689057.1 6.7, 356090.9 6689055 6.7, 356091.4 6689052.8 6.7, 356092.8 6689050.7 6.7, 356094.5 6689049.4 6.7)
TRONROUT0000000294302112;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;14B;;14B;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356091.1 6689057.1 6.7, 356088.3 6689055.3 6.7, 356084.7 6689053.8 6.7, 356081.3 6689053.2 6.7, 356076.1 6689053.3 6.7, 356069.9 6689054.1 6.9)
TRONROUT0000000294302116;Rond-point;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356104.5 6689056 6.7, 356103.9 6689058.1 6.7, 356103.2 6689059.7 6.7, 356101.4 6689061 6.7, 356099.6 6689061.9 6.7)
TRONROUT0000000294302108;Rond-point;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356099.6 6689061.9 6.7, 356097.1 6689062 6.7, 356094.9 6689061.7 6.7, 356093.2 6689060.8 6.7, 356092 6689059.4 6.7, 356091.1 6689057.1 6.7)
TRONROUT0000000294302114;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356104.5 6689056 6.7, 356107.7 6689058 6.7, 356112.5 6689060 7, 356135.4 6689071 6.9)
TRONROUT0000000294302119;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;14;;14;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356125.8 6689076 6.8, 356110.6 6689068 6.8, 356102.6 6689064 6.7, 356099.6 6689061.9 6.7)
TRONROUT0000000294302110;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2013-11-15 09:08:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356135.4 6689071 6.9, 356152.2 6689084.6 7.1)
TRONROUT0000000294302115;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2013-11-15 09:08:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356152.2 6689084.6 7, 356125.8 6689076 6.8)
TRONROUT0000000084490765;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2007-07-17 07:55:01;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356135.4 6689071 6.9, 356154.9 6689078.2 6.9, 356177.1 6689089.7 7.1, 356195.2 6689099.3 7.3, 356211.3 6689107.2 7.3)
TRONROUT0000000294302144;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;11;16;13;24;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356086.1 6689127.2 6.7, 356069.9 6689054.1 6.9)
TRONROUT0000000294302113;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2013-11-15 09:08:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356152.2 6689084.6 7, 356161.4 6689089.4 7, 356172.7 6689095 5.3, 356183.1 6689100.4 4)
TRONROUT0000000084490764;Route à 1 chaussée;R DE JEMMAPES;R DE JEMMAPES;5;Non;0;En service;2007-07-17 07:55:01;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;2;;12;44109;44109;;;;441094524;441094524;;;;;;;;;;;;;commune;commune;Rue de Jemmapes;Rue de Jemmapes;;;44109_4524;44109_4524;;;;;LINESTRING Z (356204.5 6689119.3 8.4, 356191.8 6689112.4 7.6, 356167 6689099 7.6, 356146 6689087.8 6.9, 356131.4 6689080 6.7, 356125.8 6689076 6.8)
TRONROUT0000000084490767;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2007-07-17 07:55:01;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;12;;14;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356174.4 6689180.9 9.1, 356192.5 6689144.6 9.1, 356194.9 6689139.9 9, 356197.4 6689135.2 9, 356204.5 6689119.3 8.4)
TRONROUT0000000053385295;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356178.2 6689188.6 7.6, 356215.1 6689112.1 7.8)
TRONROUT0000000029475029;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;1;2;5;8;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (356174.4 6689180.9 10.6, 356086.1 6689127.2 6.7)
TRONROUT0000000040995053;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-11-23 11:50:58;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;14;9;8;7;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356086.1 6689127.2 6.7, 356104.9 6689207.6 6.7)
TRONROUT0000000294302103;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356172.1 6689185.6 7.3, 356174.4 6689180.9 7.6)
TRONROUT0000000029474779;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356178.2 6689188.6 7.6, 356175 6689186.9 7.3, 356172.1 6689185.6 7.3)
TRONROUT0000000029474345;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;15;;13;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355682.3 6688887.3 7.5, 355667.7 6688919 7.4)
TRONROUT0000000295264980;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355662.5 6688891.8 7.5, 355654.4 6688893 7.6, 355650.1 6688895.1 7.6, 355646.6 6688899.8 7.6, 355637 6688917.9 7.6, 355637.9 6688920.3 7.6, 355642 6688923.6 7.3)
TRONROUT0000000295265056;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355642 6688923.6 7.3, 355642.5 6688923.3 7.3, 355649.4 6688918.8 7.3, 355654.3 6688910.9 7.3, 355659.8 6688898.5 7.3, 355662.5 6688891.8 7.6)
TRONROUT0000000295265201;Route à 1 chaussée;AV DE L'HOTEL DIEU;AV DE L'HOTEL DIEU;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.3;;;;;Non;;;;;44109;44109;;;;441094240;441094240;;;;;;;;;;;;;commune;commune;Avenue de l'Hôtel Dieu;Avenue de l'Hôtel Dieu;;;44109_4240;44109_4240;;;;;LINESTRING Z (355689.5 6688925.8 6.8, 355673 6688920.2 7, 355667.7 6688919 7.4)
TRONROUT0000000255793175;Route à 1 chaussée;;;5;Non;0;En service;2011-03-18 10:05:16;2015-06-29 19:33:47;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355722.2 6688939.2 6.7, 355729.4 6688923.6 6.7, 355736 6688908.6 6.9)
TRONROUT0000000295264880;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355667.7 6688919 7.4, 355662 6688931.3 7.4)
TRONROUT0000000295265106;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355642 6688923.6 7.3, 355654 6688928.1 7.3, 355662 6688931.3 7.4)
TRONROUT0000000029473463;Route à 1 chaussée;AV DE L'HOTEL DIEU;AV DE L'HOTEL DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.3;;;;;Non;12;13;12;13;44109;44109;;;;441094240;441094240;;;;;;;;;;;;;commune;commune;Avenue de l'Hôtel Dieu;Avenue de l'Hôtel Dieu;;;44109_4240;44109_4240;;;;;LINESTRING Z (355689.5 6688925.8 6.8, 355690.4 6688926 6.8, 355722.2 6688939.2 6.7)
TRONROUT0000000029474253;Route à 1 chaussée;CHS DE LA MADELEINE;CHS DE LA MADELEINE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109A105;44109A105;;;;;;;;;;;;;commune;commune;Chaussée de la Madeleine;Chaussée de la Madeleine;;;44109_a105;44109_a105;;;;;LINESTRING Z (355662 6688931.3 7.4, 355659.8 6688935.9 7.5, 355645.5 6688969.3 7.7)
TRONROUT0000000029474184;Route à 1 chaussée;IMP DE L'AVENUE DE L'HOTEL DIEU;IMP DE L'AVENUE DE L'HOTEL DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;3;8;44109;44109;;;;44109#0CA;44109#0CA;;;;;;;;;;;;;commune;commune;Impasse de l'Avenue de l'Hôtel Dieu;Impasse de l'Avenue de l'Hôtel Dieu;;;44109_0490;44109_0490;;;;;LINESTRING Z (355722.2 6688939.2 6.7, 355709.5 6688968 6.7)
TRONROUT0000000029474066;Route à 1 chaussée;R COLUMELLE;R COLUMELLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;1;2;44109;44109;;;;441092040;441092040;;;;;;;;;;;;;commune;commune;Rue Columelle;Rue Columelle;;;44109_2040;44109_2040;;;;;LINESTRING Z (355952.8 6688895.2 7.1, 355958.7 6688882.9 7.1)
TRONROUT0000000029473926;Route à 1 chaussée;R BARON;R BARON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;9;8;9;44109;44109;;;;441090556;441090556;;;;;;;;;;;;;commune;commune;Rue Baron;Rue Baron;;;44109_0556;44109_0556;;;;;LINESTRING Z (355944.9 6688893.6 7.2, 355952.8 6688895.2 7.1)
TRONROUT0000000029473946;Route à 1 chaussée;R BARON;R BARON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;7;2;1;44109;44109;;;;441090556;441090556;;;;;;;;;;;;;commune;commune;Rue Baron;Rue Baron;;;44109_0556;44109_0556;;;;;LINESTRING Z (355952.8 6688895.2 7.1, 356018.9 6688911.9 6.9, 356034.2 6688916.9 6.7)
TRONROUT0000000029474669;Route à 1 chaussée;R BARON;R BARON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441090556;441090556;;;;;;;;;;;;;commune;commune;Rue Baron;Rue Baron;;;44109_0556;44109_0556;;;;;LINESTRING Z (356034.2 6688916.9 6.7, 356039.7 6688918.8 7.1)
TRONROUT0000000029473732;Route à 1 chaussée;PAS ANDRE CRETAUX;PAS ANDRE CRETAUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;3;2;1;44109;44109;;;;441090269;441090269;;;;;;;;;;;;;commune;commune;Passage André Crétaux;Passage André Crétaux;;;44109_0269;44109_0269;;;;;LINESTRING Z (355922.1 6688955.5 7.8, 355933.1 6688933.7 7.2, 355941.2 6688911.3 7.3, 355944.9 6688893.6 7.2)
TRONROUT0000000029474024;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;21;32;31;40;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356055.9 6688990.9 6.9, 356039.7 6688918.8 7.1)
TRONROUT0000000029474108;Route à 1 chaussée;R LAENNEC;R LAENNEC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;15;14;7B;44109;44109;;;;441094744;441094744;;;;;;;;;;;;;commune;commune;Rue Laennec;Rue Laennec;;;44109_4744;44109_4744;;;;;LINESTRING Z (356034.2 6688916.9 6.7, 356006.4 6688963.5 6.8, 355988.8 6688994.5 6.1)
TRONROUT0000000029474467;Route à 1 chaussée;PAS BERTHAULT;PAS BERTHAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090801;441090801;;;;;;;;;;;;;commune;commune;Passage Berthault;Passage Berthault;;;44109_oe4mpt;44109_oe4mpt;;;;;LINESTRING Z (355957.5 6688975.9 6.5, 355931.7 6688960.6 7, 355922.1 6688955.5 7.8)
TRONROUT0000000228004592;Route à 1 chaussée;PAS BERTHAULT;PAS BERTHAULT;5;Non;0;En service;2010-01-18 17:38:37;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;;5;;44109;44109;;;;441090801;441090801;;;;;;;;;;;;;commune;commune;Passage Berthault;Passage Berthault;;;44109_oe4mpt;44109_oe4mpt;;;;;LINESTRING Z (355988.8 6688994.5 6.1, 355957.5 6688975.9 6.5)
TRONROUT0000000228004590;Sentier;SQ DU LAIT DE MAI;SQ DU LAIT DE MAI;6;Non;0;En service;2010-01-18 17:38:37;2011-09-06 08:54:31;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H7;44109#0H7;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355957.5 6688975.9 6.5, 355924.3 6689033.6 6.2)
TRONROUT0000000029473570;Route à 1 chaussée;PAS BERTHAULT;PAS BERTHAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;10;17;12;44109;44109;;;;441090801;441090801;;;;;;;;;;;;;commune;commune;Passage Berthault;Passage Berthault;;;44109_oe4mpt;44109_oe4mpt;;;;;LINESTRING Z (355922.1 6688955.5 7.8, 355911.7 6688950.1 6.7, 355833.5 6688919.1 19.1)
TRONROUT0000000029474103;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;17;10;17;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355825 6688946.6 7.3, 355817 6688972.6 6.8)
TRONROUT0000000029474050;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;10;;10;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355817 6688972.6 6.8, 355814.7 6688980.3 6.4)
TRONROUT0000000029475162;Route à 1 chaussée;PAS DOUARD;PAS DOUARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;1;;11;44109;44109;;;;44109#0GS;44109#0GS;;;;;;;;;;;;;commune;commune;Passage Douard;Passage Douard;;;44109_2564;44109_2564;;;;;LINESTRING Z (355808.5 6688999.9 6.7, 355800.2 6688997.7 6.7, 355744.4 6688973.8 6.5, 355740.2 6688972.1 6.5, 355732.1 6688994.2 6)
TRONROUT0000000029474380;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;13;4;15;6;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355814.7 6688980.3 6.4, 355808.5 6688999.9 6.7)
TRONROUT0000000029473560;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;32;23;26;23;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (355817 6688972.6 6.8, 355870.8 6689002 6.7, 355872.9 6689003.1 6.7, 355896.1 6689016.9 6.7)
TRONROUT0000000214228470;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2008-12-16 17:02:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2B;11;2B;9;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355808.5 6688999.9 6.7, 355795.4 6689042.3 6.7)
TRONROUT0000000029473469;Route à 1 chaussée;PAS DU CARROUSEL;PAS DU CARROUSEL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;3.2;;;;;Non;1;2;3;10;44109;44109;;;;441091472;441091472;;;;;;;;;;;;;commune;commune;Passage du Carrousel;Passage du Carrousel;;;44109_1472;44109_1472;;;;;LINESTRING Z (355896.1 6689016.9 6.7, 355884.7 6689034.9 6.7, 355875 6689050.4 6.9, 355862.5 6689069.2 7.1)
TRONROUT0000000029474281;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355795.4 6689042.3 6.7, 355785.8 6689073.4 6.7)
TRONROUT0000000029474055;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355785.8 6689073.4 6.7, 355776.8 6689102.9 7)
TRONROUT0000000029473638;Route à 1 chaussée;AV DE L'HOTEL DIEU;AV DE L'HOTEL DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;2;11;10;44109;44109;;;;441094240;441094240;;;;;;;;;;;;;commune;commune;Avenue de l'Hôtel Dieu;Avenue de l'Hôtel Dieu;;;44109_4240;44109_4240;;;;;LINESTRING Z (355814.7 6688980.3 6.4, 355722.2 6688939.2 6.7)
TRONROUT0000000029474783;Route à 1 chaussée;IMP JUTON;IMP JUTON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;;7;;44109;44109;COUR DE LA BOULE D'OR;COUR DE LA BOULE D'OR;;44109#0CJ;44109#0CJ;;;;;;;;;;;;;commune;commune;Impasse Juton;Impasse Juton;;;44109_4692;44109_4692;;;;;LINESTRING Z (355673.5 6688980 6.9, 355660.8 6688975.3 6.9, 355645.5 6688969.3 7.7)
TRONROUT0000000029475122;Route à 1 chaussée;IMP JUTON;IMP JUTON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;8;21;10;44109;44109;COUR DE LA BOULE D'OR;COUR DE LA BOULE D'OR;;44109#0CJ;44109#0CJ;;;;;;;;;;;;;commune;commune;Impasse Juton;Impasse Juton;;;44109_4692;44109_4692;;;;;LINESTRING Z (355673.5 6688980 6.9, 355684.3 6688973.2 6.7, 355713.5 6688986.2 6.3, 355732.1 6688994.2 6)
TRONROUT0000000343013507;Sentier;CRS DES ARTS;CRS DES ARTS;6;Non;0;En service;2015-01-15 19:26:53;;;;;;Plan non métrique papier;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0I8;44109#0I8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355673.5 6688980 6.9, 355675 6688994.9 6.8, 355742.1 6689020.9 6.8)
TRONROUT0000000214228469;Sentier;CRS DES ARTS;CRS DES ARTS;6;Non;0;En service;2008-12-16 17:02:10;2015-01-15 19:26:23;;;;;Plan non métrique papier;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0I8;44109#0I8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355742.1 6689020.9 6.8, 355744.8 6689014.6 6.7, 355767.1 6689023.8 6.7, 355765.2 6689034.6 6.7, 355795.4 6689042.3 6.7)
TRONROUT0000000343013506;Sentier;CRS DES ARTS;CRS DES ARTS;6;Non;0;En service;2015-01-15 19:26:53;;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0I8;44109#0I8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355742.1 6689020.9 6.8, 355742.1 6689026.5 6.9, 355734.1 6689051.9 7)
TRONROUT0000000029474422;Route à 1 chaussée;R PELISSON;R PELISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;2;11;2;44109;44109;;;;441096292;441096292;;;;;;;;;;;;;commune;commune;Rue Pélisson;Rue Pélisson;;;44109_6292;44109_6292;;;;;LINESTRING Z (355709.6 6689045.2 6.8, 355693.5 6689040.7 6.8, 355677.2 6689037.2 7.1)
TRONROUT0000000029473571;Route à 1 chaussée;R PELISSON;R PELISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;2B;7;2B;44109;44109;;;;441096292;441096292;;;;;;;;;;;;;commune;commune;Rue Pélisson;Rue Pélisson;;;44109_6292;44109_6292;;;;;LINESTRING Z (355734.1 6689051.9 7, 355709.6 6689045.2 6.8)
TRONROUT0000000343013498;Route à 1 chaussée;R PELISSON;R PELISSON;5;Non;0;En service;2015-01-15 19:26:23;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2T;3;2B;44109;44109;;;;441096292;441096292;;;;;;;;;;;;;commune;commune;Rue Pélisson;Rue Pélisson;;;44109_6292;44109_6292;;;;;LINESTRING Z (355785.8 6689073.4 6.7, 355773.5 6689065.6 7.1, 355742.7 6689054.3 7, 355734.1 6689051.9 7)
TRONROUT0000000029475084;Route à 1 chaussée;R PELISSON;R PELISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096292;441096292;;;;;;;;;;;;;commune;commune;Rue Pélisson;Rue Pélisson;;;44109_6292;44109_6292;;;;;LINESTRING Z (355703.7 6689090.6 6.6, 355710.3 6689060 6.3, 355711.1 6689054.6 6.3, 355709.6 6689045.2 6.8)
TRONROUT0000000107837510;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2007-12-03 22:15:03;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (355916.2 6689029 6.3, 355908.5 6689024.2 6.4, 355896.1 6689016.9 6.7)
TRONROUT0000000029475144;Route à 1 chaussée;R LAENNEC;R LAENNEC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;7;2;1;44109;44109;;;;441094744;441094744;;;;;;;;;;;;;commune;commune;Rue Laennec;Rue Laennec;;;44109_4744;44109_4744;;;;;LINESTRING Z (355988.8 6688994.5 6.1, 355955.3 6689052.2 6.1)
TRONROUT0000000107837512;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2007-12-03 22:15:03;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (355924.3 6689033.6 6.2, 355916.2 6689029 6.3)
TRONROUT0000000228004591;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2010-01-18 17:38:37;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;17;24;21;24;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (355955.3 6689052.2 6.1, 355924.3 6689033.6 6.2)
TRONROUT0000000029474038;Route à 1 chaussée;R MONTEIL;R MONTEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;15;22;19;26;44109;44109;;;;441095760;441095760;;;;;;;;;;;;;commune;commune;Rue Monteil;Rue Monteil;;;44109_5760;44109_5760;;;;;LINESTRING Z (356011.9 6689083.7 6.5, 356052.8 6689015.6 6.7, 356059.5 6689007.3 6.7)
TRONROUT0000000029474033;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (355961.4 6689055.6 6.1, 355955.3 6689052.2 6.1)
TRONROUT0000000228004589;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2010-01-18 17:38:37;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;13;16;15;22;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (356011.9 6689083.7 6.5, 355961.4 6689055.6 6.1)
TRONROUT0000000107837513;Sentier;PAS DU CARROUSEL;PAS DU CARROUSEL;6;Non;0;En service;2007-12-03 22:15:03;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091472;441091472;;;;;;;;;;;;;commune;commune;Passage du Carrousel;Passage du Carrousel;;;44109_1472;44109_1472;;;;;LINESTRING Z (355916.2 6689029 6.3, 355909.5 6689039.1 6.3, 355906.1 6689044.7 6.3, 355905.4 6689048 6.3, 355906.1 6689052.6 6.3, 355906.1 6689056.8 6.4, 355904.5 6689061.7 6.6, 355902.2 6689064.6 6.7, 355898 6689069.4 6.8, 355896.2 6689072 6.8, 355895.7 6689075 6.8, 355895.1 6689087.6 7.2, 355896.7 6689092.4 7.2, 355905 6689103.3 7.2, 355895.2 6689119.4 7.2, 355883.3 6689123.8 7.4, 355870 6689126.4 7.8, 355861.8 6689120.6 8.2)
TRONROUT0000000228004588;Sentier;;;6;Non;0;En service;2010-01-18 17:38:37;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355978.4 6689138.9 6.8, 355965 6689131.2 6.6, 355950.8 6689123.4 6.5, 355940.2 6689116.9 6.2, 355933.4 6689112.4 6.2, 355931.5 6689110.1 6.2, 355931.7 6689108.6 6.1, 355937.8 6689098.4 6, 355946.7 6689082.6 6.2, 355952.4 6689072.2 6.1, 355957.6 6689062.5 6, 355961.4 6689055.6 6.1)
TRONROUT0000000029473548;Route à 1 chaussée;R EMILE PEHANT;R EMILE PEHANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;7;10;11;14B;44109;44109;;;;441092792;441092792;;;;;;;;;;;;;commune;commune;Rue Emile Péhant;Rue Emile Péhant;;;44109_2792;44109_2792;;;;;LINESTRING Z (356086.1 6689127.2 6.7, 356011.9 6689083.7 6.5)
TRONROUT0000000029473522;Route à 1 chaussée;ALL DE LA MAISON ROUGE;ALL DE LA MAISON ROUGE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;13;;7;44109;44109;;;;441095240;441095240;;;;;;;;;;;;;commune;commune;Allée de la Maison Rouge;Allée de la Maison Rouge;;;44109_5240;44109_5240;;;;;LINESTRING Z (355611.8 6689060 7.9, 355624.6 6689066.6 7.8, 355666.4 6689081 7.1, 355695.9 6689089.3 6.6)
TRONROUT0000000029474538;Route à 1 chaussée;ALL DE LA MAISON ROUGE;ALL DE LA MAISON ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;7;;7;44109;44109;;;;441095240;441095240;;;;;;;;;;;;;commune;commune;Allée de la Maison Rouge;Allée de la Maison Rouge;;;44109_5240;44109_5240;;;;;LINESTRING Z (355695.9 6689089.3 6.6, 355703.7 6689090.6 6.6)
TRONROUT0000000029474527;Route à 1 chaussée;ALL DE LA MAISON ROUGE;ALL DE LA MAISON ROUGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;21;6;21;1;44109;44109;;;;441095240;441095240;;;;;;;;;;;;;commune;commune;Allée de la Maison Rouge;Allée de la Maison Rouge;;;44109_5240;44109_5240;;;;;LINESTRING Z (355703.7 6689090.6 6.6, 355776.8 6689102.9 7)
TRONROUT0000000295264895;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (355695.9 6689089.3 6.6, 355723 6689112.1 6.5, 355750.9 6689131.1 6.6)
TRONROUT0000000322978301;Route à 1 chaussée;;;5;Non;0;En service;2013-06-10 16:39:37;2020-02-12 17:33:37;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355820.8 6689178.8 6.7, 355797 6689168.4 6.3, 355781 6689160.7 6.5, 355750.7 6689147.2 8.9, 355740.3 6689140.7 6.4, 355730.7 6689134.1 6.4, 355719.9 6689126.9 6.7, 355708.7 6689119.3 6.8, 355703.1 6689115.8 6.9, 355697.2 6689112.4 6.9, 355690.7 6689109.5 6.6, 355683.7 6689106.5 6.5, 355676.3 6689103.7 6.5, 355668.8 6689101 6.5, 355661.2 6689098.3 6.6, 355653.5 6689095.6 6.7, 355646.1 6689092.9 6.8, 355638.7 6689090.1 6.9, 355631.9 6689087.6 7, 355625.3 6689085.2 7.2, 355618.8 6689082.8 7.4, 355612.3 6689080.5 7.6, 355606.5 6689078.4 7.8, 355601 6689076.3 7.9, 355595.7 6689074.4 8.1, 355590.6 6689072.6 8.7, 355585.6 6689071 8.7, 355581.2 6689069.8 8.9, 355577.1 6689069.4 9.1, 355566.2 6689069.9 9.2)
TRONROUT0000000295264744;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355770.5 6689121.5 6.8, 355763 6689126.4 6.7, 355756.2 6689129.7 6.7, 355750.9 6689131.1 6.6)
TRONROUT0000000295264905;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355770.5 6689121.5 6.8, 355764.2 6689140.2 6.7)
TRONROUT0000000029474132;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (355750.9 6689131.1 6.6, 355764.2 6689140.2 6.7)
TRONROUT0000002011475940;Rond-point;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;3.0;10.5;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355643.2 6689144.7 7.5, 355648 6689150.2 7.5, 355648.2 6689155.2 7.5)
TRONROUT0000000320704092;Rond-point;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2013-04-03 17:23:34;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;3.0;10.5;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355648.2 6689155.2 7.5, 355646.8 6689157.4 7.5, 355642 6689159.3 7.5)
TRONROUT0000000029473745;Sentier;PAS DU CARROUSEL;PAS DU CARROUSEL;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;16;;12;;44109;44109;;;;441091472;441091472;;;;;;;;;;;;;commune;commune;Passage du Carrousel;Passage du Carrousel;;;44109_1472;44109_1472;;;;;LINESTRING Z (355861.8 6689120.6 8.2, 355855.7 6689116.3 7.7, 355858 6689112.3 7.7, 355858 6689108.3 7.7, 355855.7 6689103.8 7.7, 355855.3 6689099.4 7.7, 355855.2 6689094.6 7.7, 355855.6 6689089.1 7.7, 355857.6 6689083.7 7.7, 355860.2 6689079 7.7, 355862.8 6689074.8 7.6, 355863.1 6689071.3 7.6, 355862.5 6689069.2 7.1)
TRONROUT0000000029474071;Route à 1 chaussée;R DES OLIVETTES;R DES OLIVETTES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441096012;441096012;;;;;;;;;;;;;commune;commune;Rue des Olivettes;Rue des Olivettes;;;44109_6012;44109_6012;;;;;LINESTRING Z (355776.8 6689102.9 7, 355770.5 6689121.5 6.8)
TRONROUT0000000107837511;Route à 1 chaussée;R CRUCY;R CRUCY;5;Non;0;En service;2007-12-03 22:15:03;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;34;37;30;31;44109;44109;;;;441092336;441092336;;;;;;;;;;;;;commune;commune;Rue Crucy;Rue Crucy;;;44109_2336;44109_2336;;;;;LINESTRING Z (355776.8 6689102.9 7, 355807.5 6689108 6.7, 355816.6 6689112.2 6.5, 355849.2 6689135.4 6.6)
TRONROUT0000000107837499;Escalier;PAS DU CARROUSEL;PAS DU CARROUSEL;6;Non;0;En service;2007-12-03 22:15:03;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091472;441091472;;;;;;;;;;;;;commune;commune;Passage du Carrousel;Passage du Carrousel;;;44109_1472;44109_1472;;;;;LINESTRING Z (355861.8 6689120.6 8.2, 355849.2 6689135.4 6.6)
TRONROUT0000000322978303;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2013-06-10 16:39:37;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (355764.2 6689140.2 6.7, 355820.8 6689178.8 6.7)
TRONROUT0000000351473270;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2015-06-10 18:40:12;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (355820.8 6689178.8 6.7, 355826.8 6689182.8 6.7)
TRONROUT0000000351473267;Sentier;;;6;Non;-1;En service;2015-06-10 18:40:12;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355801.9 6689223 -1000, 355813 6689203.9 -1000, 355818.3 6689195.8 -1000, 355826.8 6689182.8 -1000)
TRONROUT0000000029473844;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (355826.8 6689182.8 6.7, 355875.7 6689216.3 6.7, 355913.6 6689242.3 6.7)
TRONROUT0000002011475906;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355801.9 6689223 6.9, 355822.4 6689233.8 7.4, 355825.7 6689235.7 7.4)
TRONROUT0000002011475943;Sentier;;;6;Non;-1;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355806.3 6689246.9 -1000, 355811.6 6689240 -1000, 355799.8 6689226.6 -1000, 355801.9 6689223 -1000)
TRONROUT0000000295265205;Route à 1 chaussée;;;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 06:26:51;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355817.6 6689212.6 4, 355797 6689201.4 7, 355754 6689178.3 7, 355701.6 6689151.3 7.1, 355650.6 6689125 7.2, 355635.6 6689117.2 7.5, 355635.3 6689116.5 7.5)
TRONROUT0000002011475921;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355643.2 6689144.7 7.5, 355652 6689145.7 8.6, 355658.6 6689147.6 7.8, 355667.4 6689152.4 7.8, 355737.2 6689189.1 7.6, 355801.9 6689223 6.9)
TRONROUT0000002011475957;Route à 1 chaussée;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355648.2 6689155.2 7.5, 355706.9 6689181.8 7.7, 355723.8 6689190.8 7.2, 355758 6689208.7 7.1, 355766.4 6689213.1 6.7, 355774.2 6689218.1 6.4, 355785.1 6689225.9 7)
TRONROUT0000002011475935;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355746.9 6689249.9 7.8, 355744.4 6689245.8 7.8, 355735.6 6689235.9 7.8, 355717.3 6689217.1 7.6, 355711.6 6689211.6 7.5, 355710.3 6689211.5 7.5, 355701.8 6689212.5 7.5, 355699.7 6689211.8 7.5, 355691.7 6689202.9 7.5, 355678.8 6689187.9 7.4, 355672.3 6689182.4 7.4, 355644.5 6689166 7.9, 355642 6689159.3 7.5)
TRONROUT0000002011475898;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355781.7 6689276.7 7.9, 355774.1 6689270.6 7.9, 355765.7 6689263.8 7.9, 355757.2 6689255 7.9, 355746.9 6689249.9 7.8)
TRONROUT0000002011475934;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355742.3 6689301.2 7.9, 355748.7 6689292.9 8.1, 355752.1 6689287.3 7.9, 355753.7 6689281.5 7.4, 355754.3 6689273.5 7.8, 355753.3 6689265.1 7.9, 355750.8 6689256.5 7.9, 355746.9 6689249.9 7.8)
TRONROUT0000002011475949;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2018-06-11 11:56:08;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355561.5 6689262.9 8.5, 355602.5 6689271.2 8.5, 355661.3 6689286.3 7.8, 355675 6689289.7 7.7, 355723.9 6689303.5 7.8, 355737.6 6689307.2 7.8)
TRONROUT0000002011475901;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355742.3 6689301.2 7.9, 355755.8 6689297.5 7.9, 355762.9 6689293.4 7.9, 355773.6 6689284.9 7.9, 355781.7 6689276.7 7.9)
TRONROUT0000000029474583;Route à 1 chaussée;ALL DU PORT MAILLARD;ALL DU PORT MAILLARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;12;;13;44109;44109;;;;441096868;441096868;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Allée du Port Maillard;Allée du Port Maillard;;;44109_6868;44109_6868;;;;;LINESTRING Z (355668.3 6689311.1 7.6, 355610.4 6689296.5 7.8)
TRONROUT0000002011475929;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355737.6 6689307.2 7.8, 355742.3 6689301.2 7.9)
TRONROUT0000000029474939;Route à 1 chaussée;R MONTEIL;R MONTEIL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;9;12;13B;18;44109;44109;;;;441095760;441095760;;;;;;;;;;;;;commune;commune;Rue Monteil;Rue Monteil;;;44109_5760;44109_5760;;;;;LINESTRING Z (356011.9 6689083.7 6.5, 355984.9 6689128.3 6.8, 355978.4 6689138.9 6.8)
TRONROUT0000000053382402;Route à 1 chaussée;R EMILE MASSON;R EMILE MASSON;6;Non;0;En service;2007-01-24 06:48:04;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;4;5;2;1;44109;44109;;;;441095485;441095485;;;;;;;;;;;;;commune;commune;Rue Emile Masson;Rue Emile Masson;;;44109_5485;44109_5485;;;;;LINESTRING Z (356003.8 6689153.8 9, 355988.4 6689144.8 7.5, 355978.4 6689138.9 6.8)
TRONROUT0000000029474047;Route à 1 chaussée;R MONTEIL;R MONTEIL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095760;441095760;;;;;;;;;;;;;commune;commune;Rue Monteil;Rue Monteil;;;44109_5760;44109_5760;;;;;LINESTRING Z (355978.4 6689138.9 6.8, 355956 6689175.8 7)
TRONROUT0000000053382403;Route à 1 chaussée;R EMILE MASSON;R EMILE MASSON;5;Non;0;En service;2007-01-24 06:48:04;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;5;2;1;44109;44109;;;;441095485;441095485;;;;;;;;;;;;;commune;commune;Rue Emile Masson;Rue Emile Masson;;;44109_5485;44109_5485;;;;;LINESTRING Z (356057.3 6689184.3 9, 356003.8 6689153.8 9)
TRONROUT0000000029474083;Route à 1 chaussée;R CRUCY;R CRUCY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;28;29;18;17;44109;44109;;;;441092336;441092336;;;;;;;;;;;;;commune;commune;Rue Crucy;Rue Crucy;;;44109_2336;44109_2336;;;;;LINESTRING Z (355849.2 6689135.4 6.6, 355856.6 6689140.7 6.7, 355920.7 6689190.4 6.8, 355939.6 6689203 7.3)
TRONROUT0000000321061195;Route à 1 chaussée;R MONTEIL;R MONTEIL;5;Non;0;En service;2013-04-16 17:06:12;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;3;6;7;8;44109;44109;;;;441095760;441095760;;;;;;;;;;;;;commune;commune;Rue Monteil;Rue Monteil;;;44109_5760;44109_5760;;;;;LINESTRING Z (355939.6 6689203 7.3, 355956 6689175.8 7)
TRONROUT0000000053382401;Route à 1 chaussée;PAS JOSEPH PARIS;PAS JOSEPH PARIS;5;Non;0;En service;2007-01-24 06:48:04;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;2;5;4;44109;44109;;;;441096149;441096149;;;;;;;;;;;;;commune;commune;Passage Joseph Paris;Passage Joseph Paris;;;44109_6149;44109_6149;;;;;LINESTRING Z (356057.3 6689184.3 9.2, 356046.7 6689205.6 9.2, 356023.8 6689249 9.1)
TRONROUT0000000029474802;Route à 1 chaussée;R MONTEIL;R MONTEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441095760;441095760;;;;;;;;;;;;;commune;commune;Rue Monteil;Rue Monteil;;;44109_5760;44109_5760;;;;;LINESTRING Z (355913.6 6689242.3 6.7, 355939.6 6689203 7.3)
TRONROUT0000000040995051;Route à 1 chaussée;R CRUCY;R CRUCY;5;Non;0;En service;2006-11-23 11:50:58;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;16;15;6;3;44109;44109;;;;441092336;441092336;;;;;;;;;;;;;commune;commune;Rue Crucy;Rue Crucy;;;44109_2336;44109_2336;;;;;LINESTRING Z (355939.6 6689203 7.3, 355971 6689221.3 7, 356008.7 6689241.7 7.3, 356023.8 6689249 7.3)
TRONROUT0000000351473268;Route à 1 chaussée;;;6;Non;0;En service;2015-06-10 18:40:12;2022-12-10 06:26:51;;;;;Levé non GPS;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355817.6 6689212.6 -1000, 355837.2 6689221.9 -1000, 355884.8 6689250.1 -1000, 355940.4 6689286 -1000, 355984.9 6689314.2 -1000, 356052.2 6689351.9 -1000, 356062.5 6689354.6 -1000, 356068.8 6689355.4 -1000, 356078.2 6689354.7 -1000)
TRONROUT0000000351473269;Route à 1 chaussée;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2015-06-10 18:40:12;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355785.1 6689225.9 7, 355788.5 6689228.3 7.2, 355799.2 6689238.4 7.3, 355806.3 6689246.9 6.9)
TRONROUT0000002011475955;Route à 1 chaussée;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355800.6 6689250 8.1, 355798.8 6689246.5 8.1, 355796.3 6689242.2 8.2, 355791.7 6689235.4 8.2, 355785.1 6689225.9 7)
TRONROUT0000002011475927;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355800.6 6689250 8.1, 355806.3 6689246.9 6.9)
TRONROUT0000002011475915;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355832.4 6689263.7 7.6, 355830.4 6689249.3 7.6, 355825.7 6689235.7 7.4)
TRONROUT0000002011475930;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355796.9 6689253.5 8.1, 355800.6 6689250 8.1)
TRONROUT0000000326050043;Route à 1 chaussée;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2013-09-05 19:16:26;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355806.3 6689246.9 6.9, 355811.9 6689257.9 7.9)
TRONROUT0000002011475954;Route à 1 chaussée;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355804.9 6689263 7.9, 355803.8 6689257.7 8, 355802 6689252.9 8.1, 355800.6 6689250 8.1)
TRONROUT0000000326050046;Rond-point;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2013-09-05 19:16:26;2018-06-11 11:56:08;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355804.9 6689263 7.9, 355805.2 6689262.3 7.9, 355808.6 6689259 7.9, 355811.9 6689257.9 7.9)
TRONROUT0000000326050049;Rond-point;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2013-09-05 19:16:26;2018-11-13 07:54:47;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355811.9 6689257.9 7.9, 355812.4 6689257.8 7.8, 355817.2 6689257.4 7.9, 355820.3 6689259.4 7.9, 355823.5 6689262.6 7.9, 355824.1 6689264.2 7.9)
TRONROUT0000002011475941;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355824.1 6689264.2 7.9, 355832.4 6689263.7 7.6)
TRONROUT0000000029474544;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355546.9 6689094.5 9.7, 355547.4 6689097.3 9.7, 355547.5 6689100.3 9.5)
TRONROUT0000000029475037;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355526 6689100.9 8.5, 355525.6 6689097.2 10.1)
TRONROUT0000000295265226;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355547.5 6689100.3 9.5, 355546.9 6689103.1 9.5, 355546.2 6689104 9.4, 355545.5 6689105 9.4, 355543.2 6689107 9, 355540.1 6689108.4 8.8)
TRONROUT0000000029474553;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355532.8 6689108.9 8.8, 355529.9 6689107.5 8.8, 355527.6 6689105.4 8.8, 355527.2 6689104.5 8.8, 355526.5 6689102.9 8.8, 355526 6689100.9 8.5)
TRONROUT0000000295265217;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-07-28 17:55:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355547.5 6689100.3 9.5, 355551.6 6689104.8 9.5, 355556.6 6689109.5 9.5, 355561.3 6689112.8 9.6)
TRONROUT0000000029473982;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355508.8 6689115.1 7.7, 355514.7 6689110.7 8.1, 355519.6 6689106.7 8.4, 355523.2 6689103.6 8.5, 355526 6689100.9 8.5)
TRONROUT0000000295265213;Rond-point;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-10-19 14:26:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355540.1 6689108.4 8.8, 355536.5 6689108.9 8.7, 355532.8 6689108.9 8.8)
TRONROUT0000000295265223;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2012-02-08 10:00:49;2017-07-28 17:55:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355561.3 6689112.8 9.6, 355556 6689111.5 9.6, 355547.6 6689109.7 9.6, 355540.1 6689108.4 8.8)
TRONROUT0000000295265246;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355532.8 6689108.9 8.8, 355522.9 6689110.2 8.8, 355515.4 6689112 8.3, 355508.8 6689115.1 7.7)
TRONROUT0000000029475213;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2017-07-28 17:55:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355578.8 6689121.7 8.8, 355578.4 6689121.5 8.9, 355561.3 6689112.8 9.6)
TRONROUT0000000295265100;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355502.2 6689120.8 7.5, 355504.5 6689118.5 7.6, 355508.8 6689115.1 7.7)
TRONROUT0000000325617296;Route à 1 chaussée;;;6;Non;0;En service;2013-09-02 15:17:00;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355466.2 6689152.2 7, 355503.1 6689084.4 10.1)
TRONROUT0000000029473961;Route à 1 chaussée;R KERVEGAN;R KERVEGAN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;22;15;10;9;44109;44109;;;;441094708;441094708;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Kervégan;Rue Kervégan;;;44109_4708;44109_4708;;;;;LINESTRING Z (355456.9 6689147.2 7, 355364.2 6689100 6.8)
TRONROUT0000000029474721;Sentier;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;6;;8;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355456.9 6689147.2 7, 355461.9 6689139.4 7, 355465.9 6689131.7 6.4, 355469.3 6689124.4 6.1, 355473 6689117 6.1, 355477.6 6689107.2 6.2)
TRONROUT0000000029474920;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355482.5 6689160.5 7, 355487.1 6689150.8 7.1, 355492.7 6689138.7 7.1, 355497.3 6689128.6 7.6, 355500.7 6689122.5 7.6, 355502.2 6689120.8 7.5)
TRONROUT0000000325617293;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2013-09-02 15:17:00;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355466.2 6689152.2 7, 355461.4 6689150.4 7, 355456.9 6689147.2 7)
TRONROUT0000000029474564;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355482.5 6689160.5 7, 355470.9 6689154 7.1, 355466.2 6689152.2 7)
TRONROUT0000000029473790;Sentier;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;4;;2;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355456.9 6689147.2 7, 355447.9 6689165.4 7, 355437.7 6689185 7, 355433.9 6689193.2 7.1)
TRONROUT0000000029474062;Route à 1 chaussée;R KERVEGAN;R KERVEGAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;5;6;3;44109;44109;;;;441094708;441094708;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Kervégan;Rue Kervégan;;;44109_4708;44109_4708;;;;;LINESTRING Z (355482.5 6689160.5 7, 355527.5 6689184.3 7.1)
TRONROUT0000000325617297;Route à 1 chaussée;;;6;Non;0;En service;2013-09-02 15:17:00;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355466.2 6689152.2 7, 355445.4 6689190.4 7.2, 355448.6 6689194.7 7.1, 355453.5 6689198 7, 355456.2 6689202.8 7)
TRONROUT0000000029475148;Route à 1 chaussée;QU TURENNE;QU TURENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;4;44109;44109;;;;441098260;441098260;;;;;;;;;;;;;commune;commune;Quai Turenne;Quai Turenne;;;44109_8260;44109_8260;;;;;LINESTRING Z (355542.4 6689140.5 7.5, 355526.4 6689132 7.6, 355516.3 6689126.9 7.5, 355508.9 6689123.9 7.9, 355502.2 6689120.8 7.5)
TRONROUT0000000029475149;Route à 1 chaussée;BD JEAN PHILIPPOT;BD JEAN PHILIPPOT;3;Non;0;En service;2006-10-04 09:41:10;2017-07-28 17:55:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0RG;44109#0RG;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355624 6689144.5 7.6, 355607.6 6689136.2 7.9, 355591.4 6689128.1 8.6, 355578.8 6689121.7 8.8)
TRONROUT0000000029474769;Route à 1 chaussée;;;6;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355566.7 6689152.7 7.8, 355570.4 6689143.2 8.3, 355573.1 6689136.2 8.5, 355575.9 6689129.4 8.9, 355578.8 6689121.7 8.8)
TRONROUT0000000320704091;Rond-point;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2013-04-03 17:23:34;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;3.0;10.5;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355624 6689144.5 7.6, 355626.1 6689141.3 7.5, 355633.8 6689141.1 7.5, 355643.2 6689144.7 7.5)
TRONROUT0000000029475218;Route à 1 chaussée;QU TURENNE;QU TURENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;1B;;1B;;44109;44109;;;;441098260;441098260;;;;;;;;;;;;;commune;commune;Quai Turenne;Quai Turenne;;;44109_8260;44109_8260;;;;;LINESTRING Z (355542.4 6689140.5 7.5, 355566.7 6689152.7 7.8)
TRONROUT0000000351473266;Rond-point;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2015-06-10 18:40:12;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;3.0;10.5;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355624.8 6689152.8 7.5, 355623 6689149.1 7.5, 355624 6689144.5 7.6)
TRONROUT0000000029474845;Route à 1 chaussée;R DES POISSONNIERS;R DES POISSONNIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096728;441096728;;;;;;;;;;;;;commune;commune;Rue des Poissonniers;Rue des Poissonniers;;;44109_6728;44109_6728;;;;;LINESTRING Z (355542.4 6689140.5 7.5, 355534.1 6689163.9 7.5)
TRONROUT0000002011475944;Rond-point;CRS COMMANDANT D'ESTIENNE D'ORVES;CRS COMMANDANT D'ESTIENNE D'ORVES;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Z corrigé;2.5;3.0;10.5;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092052;441092052;;;;;;;;;;;;;commune;commune;Cours Commandant d'Estienne d'Orves;Cours Commandant d'Estienne d'Orves;;;44109_2052;44109_2052;;;;;LINESTRING Z (355642 6689159.3 7.5, 355637.1 6689159.1 7.5, 355629.2 6689157.7 7.5, 355624.8 6689152.8 7.5)
TRONROUT0000000029474708;Route à 1 chaussée;R PAGAN;R PAGAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CU;44109#0CU;;;;;;;;;;;;;commune;commune;Rue Pagan;Rue Pagan;;;44109_6104;44109_6104;;;;;LINESTRING Z (355534.1 6689163.9 7.5, 355514.9 6689158.2 7.6)
TRONROUT0000000029474445;Route à 1 chaussée;R BON SECOURS;R BON SECOURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;15;12;17;12;44109;44109;;;;441091044;441091044;;;;;;;;;;;;;commune;commune;Rue Bon Secours;Rue Bon Secours;;;44109_1044;44109_1044;;;;;LINESTRING Z (355557.1 6689172.5 7.6, 355566.7 6689152.7 7.8)
TRONROUT0000000029475233;Route à 1 chaussée;QU TURENNE;QU TURENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441098260;441098260;;;;;;;;;;;;;commune;commune;Quai Turenne;Quai Turenne;;;44109_8260;44109_8260;;;;;LINESTRING Z (355566.7 6689152.7 7.8, 355580.2 6689159.8 7.8, 355589.2 6689166.2 7.5, 355599.2 6689176.2 7.6, 355603.1 6689180.2 7.7)
TRONROUT0000000295265241;Route à 1 chaussée;R LEON MAITRE;R LEON MAITRE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441094915;441094915;;;;;;;;;;;;;commune;commune;Rue Léon Maître;Rue Léon Maître;;;44109_4915;44109_4915;;;;;LINESTRING Z (355603.1 6689180.2 7.7, 355609.1 6689168.7 7.4, 355624.8 6689152.8 7.5)
TRONROUT0000000029475152;Route à 1 chaussée;R PAGAN;R PAGAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CU;44109#0CU;;;;;;;;;;;;;commune;commune;Rue Pagan;Rue Pagan;;;44109_6104;44109_6104;;;;;LINESTRING Z (355557.1 6689172.5 7.6, 355534.1 6689163.9 7.5)
TRONROUT0000000029473935;Route à 1 chaussée;R DES POISSONNIERS;R DES POISSONNIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441096728;441096728;;;;;;;;;;;;;commune;commune;Rue des Poissonniers;Rue des Poissonniers;;;44109_6728;44109_6728;;;;;LINESTRING Z (355534.1 6689163.9 7.5, 355527.5 6689184.3 7.1)
TRONROUT0000000339545468;Sentier;PRV NEPTUNE;PRV NEPTUNE;6;Non;0;En service;2014-11-27 19:15:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095908;441095908;;;;;;;;;;;;;commune;commune;Parvis Neptune;Parvis Neptune;;;44109_5914;44109_5914;;;;;LINESTRING Z (355613.6 6689187.3 -1000, 355603.1 6689180.2 -1000)
TRONROUT0000000029474439;Route à 1 chaussée;R BON SECOURS;R BON SECOURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;11;6;15;10;44109;44109;;;;441091044;441091044;;;;;;;;;;;;;commune;commune;Rue Bon Secours;Rue Bon Secours;;;44109_1044;44109_1044;;;;;LINESTRING Z (355546.6 6689195.4 6.9, 355557.1 6689172.5 7.6)
TRONROUT0000000029473963;Route à 1 chaussée;R KERVEGAN;R KERVEGAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;4;;4;;44109;44109;;;;441094708;441094708;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Kervégan;Rue Kervégan;;;44109_4708;44109_4708;;;;;LINESTRING Z (355527.5 6689184.3 7.1, 355546.6 6689195.4 6.9)
TRONROUT0000000029475070;Route à 1 chaussée;R LEON MAITRE;R LEON MAITRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;5;;5;44109;44109;;;;441094915;441094915;;;;;;;;;;;;;commune;commune;Rue Léon Maître;Rue Léon Maître;;;44109_4915;44109_4915;;;;;LINESTRING Z (355585.2 6689214.9 6.9, 355603.1 6689180.2 7.7)
TRONROUT0000000029473976;Route à 1 chaussée;R BON SECOURS;R BON SECOURS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;5;2B;9;4;44109;44109;;;;441091044;441091044;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Bon Secours;Rue Bon Secours;;;44109_1044;44109_1044;;;;;LINESTRING Z (355546.6 6689195.4 6.9, 355538.4 6689213.4 7)
TRONROUT0000000029475290;Route à 1 chaussée;R KERVEGAN;R KERVEGAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;2B;1;2B;1;44109;44109;;;;441094708;441094708;;;;;;;;;;;;;commune;commune;Rue Kervégan;Rue Kervégan;;;44109_4708;44109_4708;;;;;LINESTRING Z (355546.6 6689195.4 6.9, 355585.2 6689214.9 6.9)
TRONROUT0000000029473552;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;;5;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355456.2 6689202.8 7.7, 355482.5 6689160.5 7)
TRONROUT0000000029473477;Route à 1 chaussée;IMP DE LA BASSE SAULZAIE;IMP DE LA BASSE SAULZAIE;5;Non;0;En service;2006-10-04 09:41:10;2012-09-28 17:33:20;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0H6;44109#0H6;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355493.3 6689197.5 7.7, 355498.5 6689188 7.7, 355513.4 6689193.1 7.5)
TRONROUT0000000325617291;Route à 1 chaussée;ALL DUGUAY TROUIN;ALL DUGUAY TROUIN;5;Non;0;En service;2013-09-02 15:17:00;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092616;441092616;;;;;;;;;;;;;commune;commune;Allée Duguay Trouin;Allée Duguay Trouin;;;44109_2616;44109_2616;;;;;LINESTRING Z (355452.2 6689204.1 7.5, 355450.3 6689201.2 7.2, 355441.9 6689197 7.2, 355438.8 6689195.5 7.2, 355433.9 6689193.2 7.1)
TRONROUT0000000295264974;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355422.7 6689211.8 7.4, 355433.9 6689193.2 7.1)
TRONROUT0000000029474879;Rond-point;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355452.2 6689204.1 7.5, 355453.8 6689203.1 7.5, 355455.3 6689202.8 7.5, 355456.2 6689202.8 7.7)
TRONROUT0000000029474881;Rond-point;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355456.2 6689202.8 7.7, 355457.9 6689203.9 7.7, 355458.7 6689205.1 7.7, 355458.6 6689206.2 7.8)
TRONROUT0000000029474880;Rond-point;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355451.6 6689207 7.8, 355451.5 6689205.3 7.8, 355452.2 6689204.1 7.5)
TRONROUT0000000029474898;Rond-point;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355458.6 6689206.2 7.8, 355457.8 6689207.6 7.8, 355456.6 6689208.5 7.8, 355455 6689209 7.7, 355453.5 6689208.7 7.7)
TRONROUT0000000317411039;Rond-point;;;5;Non;0;En service;2013-01-14 14:55:44;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355453.5 6689208.7 7.7, 355452.5 6689208.2 7.8, 355451.6 6689207 7.8)
TRONROUT0000000029473479;Route à 1 chaussée;R BALEN;R BALEN;5;Non;0;En service;2006-10-04 09:41:10;2012-09-28 17:33:20;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BU;44109#0BU;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355479.8 6689218.5 8.2, 355487 6689209.8 7.9, 355493.3 6689197.5 7.7)
TRONROUT0000000295264901;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2012-02-08 10:00:49;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355422.7 6689211.8 7.4, 355418.1 6689209 7.4, 355412.1 6689206.6 7.3)
TRONROUT0000000029474080;Route à 1 chaussée;ALL DUGUAY TROUIN;ALL DUGUAY TROUIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;5;;5;44109;44109;;;;441092616;441092616;;;;;;;;;;;;;commune;commune;Allée Duguay Trouin;Allée Duguay Trouin;;;44109_2616;44109_2616;;;;;LINESTRING Z (355479.8 6689218.5 8.2, 355458.6 6689206.2 7.8)
TRONROUT0000000317411036;Route à 1 chaussée;;;6;Non;0;En service;2013-01-14 14:55:44;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355439 6689225 7.5, 355451.6 6689207 7.8)
TRONROUT0000000029474526;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355453.5 6689208.7 7.7, 355450.3 6689213.8 7.7, 355442.9 6689227.9 7.5)
TRONROUT0000000227876289;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2010-01-08 14:34:21;2013-01-24 17:08:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355439 6689225 7.5, 355438.1 6689221.1 7.5, 355431.8 6689217.3 7.4, 355428.2 6689215.2 7.4, 355422.7 6689211.8 7.4)
TRONROUT0000000029474703;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 20:43:48;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355397.1 6689235.4 7, 355408 6689223.5 7.2, 355412.1 6689206.6 7.4)
TRONROUT0000000295265267;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355407.8 6689240.1 7, 355415.9 6689225.1 7.3, 355422.7 6689211.8 7.4)
TRONROUT0000000317411038;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2013-01-14 14:55:44;2013-01-24 17:08:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355442.9 6689227.9 7.5, 355439 6689225 7.5)
TRONROUT0000000029474214;Route à 1 chaussée;ALL DUGUAY TROUIN;ALL DUGUAY TROUIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;1;44109;44109;;;;441092616;441092616;;;;;;;;;;;;;commune;commune;Allée Duguay Trouin;Allée Duguay Trouin;;;44109_2616;44109_2616;;;;;LINESTRING Z (355479.8 6689218.5 8.2, 355514 6689237 8.7, 355518.3 6689238.5 8.8, 355525.4 6689240.9 8.8)
TRONROUT0000000317411037;Route à 1 chaussée;;;6;Non;0;En service;2013-01-14 14:55:44;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355425.1 6689247.1 7.5, 355439 6689225 7.5)
TRONROUT0000000029474078;Route à 1 chaussée;R HAUTE SAULZAIE;R HAUTE SAULZAIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;5;;3;44109;44109;;;;441094064;441094064;;;;;;;;;;;;;commune;commune;Rue Haute Saulzaie;Rue Haute Saulzaie;;;44109_4064;44109_4064;;;;;LINESTRING Z (355493.3 6689197.5 7.7, 355525.8 6689209.2 7.1, 355538.4 6689213.4 7)
TRONROUT0000000339545469;Sentier;R LEON MAITRE;R LEON MAITRE;6;Non;0;En service;2014-11-27 19:15:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;16;;9;;44109;44109;;;;441094915;441094915;;;;;;;;;;;;;commune;commune;Rue Léon Maître;Rue Léon Maître;;;44109_4915;44109_4915;;;;;LINESTRING Z (355584.2 6689249.6 -1000, 355613.6 6689187.3 -1000)
TRONROUT0000000029474371;Route à 1 chaussée;R BON SECOURS;R BON SECOURS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;5;2;44109;44109;;;;441091044;441091044;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Bon Secours;Rue Bon Secours;;;44109_1044;44109_1044;;;;;LINESTRING Z (355538.4 6689213.4 7, 355525.4 6689240.9 8.8)
TRONROUT0000000029474051;Route à 1 chaussée;R LEON MAITRE;R LEON MAITRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;4;44109;44109;;;;441094915;441094915;;;;;;;;;;;;;commune;commune;Rue Léon Maître;Rue Léon Maître;;;44109_4915;44109_4915;;;;;LINESTRING Z (355569.7 6689242.1 8.1, 355585.2 6689214.9 6.9)
TRONROUT0000000339545471;Sentier;PRV NEPTUNE;PRV NEPTUNE;6;Non;0;En service;2014-11-27 19:15:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;1;29;1;3;44109;44109;;;;441095908;441095908;;;;;;;;;;;;;commune;commune;Parvis Neptune;Parvis Neptune;;;44109_5914;44109_5914;;;;;LINESTRING Z (355584.2 6689249.6 -1000, 355591.1 6689253.3 -1000, 355600.5 6689257.4 -1000, 355657.6 6689271.9 -1000, 355664.7 6689272.6 -1000, 355682.5 6689239.7 -1000, 355643.2 6689206 -1000, 355633.5 6689199.8 -1000, 355616.3 6689189.2 -1000, 355613.6 6689187.3 -1000)
TRONROUT0000000029474058;Route à 1 chaussée;R LEON MAITRE;R LEON MAITRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;3;;1;;44109;44109;;;;441094915;441094915;;;;;;;;;;;;;commune;commune;Rue Léon Maître;Rue Léon Maître;;;44109_4915;44109_4915;;;;;LINESTRING Z (355569.7 6689242.1 8.1, 355530.6 6689243 8.7, 355525.4 6689240.9 8.8)
TRONROUT0000000339545470;Sentier;PRV NEPTUNE;PRV NEPTUNE;6;Non;0;En service;2014-11-27 19:15:41;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095908;441095908;;;;;;;;;;;;;commune;commune;Parvis Neptune;Parvis Neptune;;;44109_5914;44109_5914;;;;;LINESTRING Z (355569.7 6689242.1 -1000, 355584.2 6689249.6 -1000)
TRONROUT0000000029474637;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355525.4 6689240.9 8.8, 355519.8 6689254.4 8.7)
TRONROUT0000000029474674;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-01-24 17:08:53;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355561.5 6689262.9 8, 355569.7 6689242.1 8.1)
TRONROUT0000000029474378;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2013-01-24 17:08:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355561.5 6689262.9 8.5, 355519.8 6689254.4 8.7)
TRONROUT0000000227876296;Route à 1 chaussée;ALL DUGUAY TROUIN;ALL DUGUAY TROUIN;5;Non;0;En service;2010-01-08 14:34:21;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;12;;6;44109;44109;;;;441092616;441092616;;;;;;;;;;;;;commune;commune;Allée Duguay Trouin;Allée Duguay Trouin;;;44109_2616;44109_2616;;;;;LINESTRING Z (355433.9 6689193.2 7.1, 355341.4 6689143.2 6.7)
TRONROUT0000000227876295;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2010-01-08 14:34:21;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355295 6689191.8 6.3, 355301.7 6689195.8 6.3, 355311.6 6689203.7 5.9)
TRONROUT0000000227876288;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2010-01-08 14:34:21;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;Sens inverse;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355311.6 6689203.7 5.9, 355318.6 6689204.6 6.2, 355342.4 6689211.2 6.3, 355397.1 6689235.4 7)
TRONROUT0000000029474189;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;;2;;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355311.6 6689203.7 5.9, 355327.4 6689212.3 6, 355344.8 6689221 6.4, 355363.5 6689229.9 6.6, 355379.4 6689236.4 7, 355387.8 6689239.3 7, 355394.1 6689240 7.1, 355400.9 6689240 7.1, 355407.8 6689240.1 7)
TRONROUT0000000029474899;Route à 1 chaussée;R DU COUEDIC;R DU COUEDIC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;2;44109;44109;;;;441092228;441092228;;;;;;;;;;;;;commune;commune;Rue du Couédic;Rue du Couédic;;;44109_2228;44109_2228;;;;;LINESTRING Z (355311.6 6689203.7 5.9, 355286.8 6689245.1 6.7)
TRONROUT0000000029474814;Route à 1 chaussée;ALL CASSARD;ALL CASSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441091488;441091488;;;;;;;;;;;;;commune;commune;Allée Cassard;Allée Cassard;;;44109_1488;44109_1488;;;;;LINESTRING Z (355407.8 6689240.1 7, 355402.2 6689250.5 7.6, 355385.3 6689281.5 6.5)
TRONROUT0000000029473650;Route à 1 chaussée;R SAINTE-CATHERINE;R SAINTE-CATHERINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;11;2;1;44109;44109;;;;441097576;441097576;;;;;;;;;;;;;commune;commune;Rue Sainte Catherine;Rue Sainte Catherine;;;44109_7576;44109_7576;;;;;LINESTRING Z (355286.8 6689245.1 6.7, 355385.3 6689281.5 6.5)
TRONROUT0000000317258105;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355365 6689358 7, 355367.3 6689353.1 7.1, 355371 6689343.1 7.2, 355382.1 6689322.5 7.3, 355413.2 6689263.3 7.4, 355422 6689246 7.5)
TRONROUT0000000317258132;Route à 1 chaussée;;;6;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355367.9 6689359.4 7, 355375.7 6689342.4 7.1, 355386 6689321.7 7.2, 355404.2 6689286.3 7.3, 355425.1 6689247.1 7.5)
TRONROUT0000000321100662;Route à 1 chaussée;ALL CASSARD;ALL CASSARD;5;Non;0;En service;2013-04-17 17:20:18;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;8;;44109;44109;;;;441091488;441091488;;;;;;;;;;;;;commune;commune;Allée Cassard;Allée Cassard;;;44109_1488;44109_1488;;;;;LINESTRING Z (355385.3 6689281.5 6.5, 355371.4 6689305.5 6.8, 355362 6689323.7 6.8, 355354.7 6689337 6.8)
TRONROUT0000000227876290;Route à 1 chaussée;ALL BRANCAS;ALL BRANCAS;5;Non;0;En service;2010-01-08 14:34:21;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;Sens direct;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091184;441091184;;;;;;;;;;;;;commune;commune;Allée Brancas;Allée Brancas;;;44109_1184;44109_1184;;;;;LINESTRING Z (355397.1 6689235.4 7, 355407.8 6689240.1 7)
TRONROUT0000000029473739;Route à 1 chaussée;CRS OLIVIER DE CLISSON;CRS OLIVIER DE CLISSON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096021;441096021;;;;;;;;;;;;;commune;commune;Cours Olivier De Clisson;Cours Olivier De Clisson;;;44109_6021;44109_6021;;;;;LINESTRING Z (355442.9 6689227.9 7.5, 355439.8 6689232.2 7.5, 355435.9 6689238.7 7.5, 355430.8 6689249.1 7.6)
TRONROUT0000000029473549;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2013-01-24 17:08:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355519.8 6689254.4 8.7, 355499.5 6689248.1 8.4, 355477.7 6689240.7 8.2, 355442.9 6689227.9 7.5)
TRONROUT0000000317258109;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355407.8 6689240.1 7, 355414.3 6689243 7.3, 355415.5 6689243.6 7.3, 355420.8 6689245.6 7.5, 355422 6689246 7.5)
TRONROUT0000000317258133;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355422 6689246 7.5, 355425.1 6689247.1 7.5)
TRONROUT0000000029474209;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355425.1 6689247.1 7.5, 355430.8 6689249.1 7.6)
TRONROUT0000000029474147;Route à 1 chaussée;ALL FLESSELLES;ALL FLESSELLES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093148;441093148;;;;;;;;;;;;;commune;commune;Allée Flesselles;Allée Flesselles;;;44109_3148;44109_3148;;;;;LINESTRING Z (355430.8 6689249.1 7.6, 355440.4 6689251.5 7.7)
TRONROUT0000000029475020;Route à 1 chaussée;ALL FLESSELLES;ALL FLESSELLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093148;441093148;;;;;;;;;;;;;commune;commune;Allée Flesselles;Allée Flesselles;;;44109_3148;44109_3148;;;;;LINESTRING Z (355512.6 6689271.3 7.9, 355440.4 6689251.5 7.7)
TRONROUT0000000029474988;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355430.8 6689249.1 7.6, 355426.1 6689256.1 7.5, 355408.1 6689288.6 6.5)
TRONROUT0000000029473806;Route à 1 chaussée;ALL JEAN BART;ALL JEAN BART;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;1;;44109;44109;;;;441094412;441094412;;;;;;;;;;;;;commune;commune;Allée Jean Bart;Allée Jean Bart;;;44109_4412;44109_4412;;;;;LINESTRING Z (355413.8 6689292.4 6.4, 355422.1 6689276.5 6.4, 355427 6689267.5 6.8, 355430.3 6689261.9 7.4, 355433.8 6689258.4 7.4, 355437.6 6689255.3 7.4, 355440.4 6689251.5 7.7)
TRONROUT0000000029474985;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355519.8 6689254.4 8.7, 355512.6 6689271.3 7.9)
TRONROUT0000000029474077;Route à 1 chaussée;ALL DE LA TREMPERIE;ALL DE LA TREMPERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;3;44109;44109;;;;441098196;441098196;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Allée de la Tremperie;Allée de la Tremperie;;;44109_8196;44109_8196;;;;;LINESTRING Z (355568.7 6689285.8 8.3, 355512.6 6689271.3 7.9)
TRONROUT0000000029475048;Route à 1 chaussée;ALL DE LA TREMPERIE;ALL DE LA TREMPERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098196;441098196;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Allée de la Tremperie;Allée de la Tremperie;;;44109_8196;44109_8196;;;;;LINESTRING Z (355610.4 6689296.5 7.8, 355568.7 6689285.8 8.3)
TRONROUT0000000029474929;Route à 1 chaussée;PL DU BOUFFAY;PL DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091092;441091092;;;;;;;;;;;;;commune;commune;Place du Bouffay;Place du Bouffay;;;44109_1092;44109_1092;;;;;LINESTRING Z (355610.4 6689296.5 7.8, 355604 6689319.7 7.8)
TRONROUT0000000029473974;Route à 1 chaussée;PL DU BOUFFAY;PL DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441091092;441091092;;;;;;;;;;;;;commune;commune;Place du Bouffay;Place du Bouffay;;;44109_1092;44109_1092;;;;;LINESTRING Z (355559.8 6689330.8 8.4, 355568.7 6689285.8 8.3)
TRONROUT0000000029473947;Route à 1 chaussée;PL DU BOUFFAY;PL DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;2;44109;44109;;;;441091092;441091092;;;;;;;;;;;;;commune;commune;Place du Bouffay;Place du Bouffay;;;44109_1092;44109_1092;;;;;LINESTRING Z (355604 6689319.7 7.8, 355598.1 6689341.6 7.9)
TRONROUT0000000029474193;Route à 1 chaussée;R DE L'ANCIENNE MONNAIE;R DE L'ANCIENNE MONNAIE;5;Non;0;En service;2006-10-04 09:41:10;2012-12-10 15:47:01;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#09H;44109#09H;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355604 6689319.7 7.8, 355611.9 6689319.9 7.5, 355615.7 6689318.4 7.5, 355620 6689319.1 7.5, 355624.8 6689321.1 7.3, 355660.1 6689343.3 7.5)
TRONROUT0000000029474113;Route à 1 chaussée;R DU BOUFFAY;R DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;1;2;1;44109;44109;;;;441091093;441091093;;;;;;;;;;;;;commune;commune;Rue du Bouffay;Rue du Bouffay;;;44109_1093;44109_1093;;;;;LINESTRING Z (355511.6 6689339.7 9.4, 355540.8 6689335 9.4, 355559.8 6689330.8 8.4)
TRONROUT0000000029475014;Route à 1 chaussée;PL DU BOUFFAY;PL DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;;3;;44109;44109;;;;441091092;441091092;;;;;;;;;;;;;commune;commune;Place du Bouffay;Place du Bouffay;;;44109_1092;44109_1092;;;;;LINESTRING Z (355559.8 6689330.8 8.4, 355598.1 6689341.6 7.9)
TRONROUT0000000029474054;Route à 1 chaussée;R DES ECHEVINS;R DES ECHEVINS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092676;441092676;;;;;;;;;;;;;commune;commune;Rue des Echevins;Rue des Echevins;;;44109_2676;44109_2676;;;;;LINESTRING Z (355598.1 6689341.6 7.9, 355602.5 6689344 9.7)
TRONROUT0000000029474151;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356218.6 6689115.3 9.1, 356220.5 6689117.5 9, 356222.8 6689119.9 7)
TRONROUT0000000039537305;Route à 2 chaussées;AV JEAN CLAUDE BONDUELLE;AV JEAN CLAUDE BONDUELLE;3;Non;0;En service;2006-11-08 07:40:16;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094425;441094425;;;;;;;;;;;;;commune;commune;Avenue Jean Claude Bonduelle;Avenue Jean Claude Bonduelle;;;44109_4425;44109_4425;;;;;LINESTRING Z (356222.8 6689119.9 7, 356216.8 6689131.5 7, 356212.4 6689140.5 7)
TRONROUT0000000327188494;Route à 2 chaussées;R DE VALMY;R DE VALMY;5;Non;0;En service;2013-09-11 19:15:05;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;65;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098292;441098292;;;;;;;;;;;;;commune;commune;Rue de Valmy;Rue de Valmy;;;44109_8292;44109_8292;;;;;LINESTRING Z (356254 6689156.3 7.2, 356244.7 6689151.9 7.2, 356226.9 6689142.9 7.4, 356220.6 6689140.1 7.3, 356217.1 6689139.8 7.3, 356212.4 6689140.5 7)
TRONROUT0000000029473853;Route à 2 chaussées;R DE VALMY;R DE VALMY;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;65;Libre;;;;;;;;;Non;1;;3;;44109;44109;;;;441098292;441098292;;;;;;;;;;;;;commune;commune;Rue de Valmy;Rue de Valmy;;;44109_8292;44109_8292;;;;;LINESTRING Z (356222.8 6689119.9 8, 356247.5 6689133.7 8, 356310.9 6689163.7 7.5, 356314 6689165.1 7.5, 356343.7 6689179.3 7.2, 356352 6689183.1 7.2)
TRONROUT0000000053385298;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356218.6 6689115.3 9.1, 356181.8 6689190.4 8.1)
TRONROUT0000000039537307;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2006-11-08 07:40:16;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;11;;11;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356212.4 6689140.5 7, 356204.4 6689156.8 7, 356195.3 6689175.6 7, 356189 6689188 7.1)
TRONROUT0000000029474679;Route à 2 chaussées;R DE VALMY;R DE VALMY;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;65;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098292;441098292;;;;;;;;;;;;;commune;commune;Rue de Valmy;Rue de Valmy;;;44109_8292;44109_8292;;;;;LINESTRING Z (356341.5 6689196.8 7.2, 356337 6689196.5 7.2, 356331.7 6689194.5 7, 356315.1 6689186.2 6.8, 356288 6689172.7 7.2, 356265.7 6689162 7.2, 356254 6689156.3 7.2)
TRONROUT0000000327188493;Route à 1 chaussée;CRS DU CHAMP DE MARS;CRS DU CHAMP DE MARS;6;Non;0;En service;2013-09-11 19:15:05;2022-12-10 14:57:12;;;;;Levé non GPS;5.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;2;;2;;44109;44109;;;;441091577;441091577;;;;;;;;;;;;;commune;commune;Cours du Champ de Mars;Cours du Champ de Mars;;;44109_1577;44109_1577;;;;;LINESTRING Z (356226.2 6689210.5 6.5, 356254 6689156.3 7.2)
TRONROUT0000000029474591;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356352 6689183.1 7.2, 356341.5 6689196.8 7.2)
TRONROUT0000000029473828;Route à 1 chaussée;R LEFEVRE-UTILE;R LEFEVRE-UTILE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441094866;441094866;;;;;;;;;;;;;commune;commune;Rue Lefévre-Utile;Rue Lefévre-Utile;;;44109_4866;44109_4866;;;;;LINESTRING Z (356226.2 6689210.5 6.4, 356216.3 6689204.5 7.1, 356208.1 6689199.4 7.1, 356199.2 6689193.9 7.1, 356191.6 6689189.6 7.1, 356189 6689188 7.1)
TRONROUT0000000329622964;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2023-05-30 15:54:11;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356485.1 6689152.2 -1000, 356506.81139568595 6689122.771556511 -1000)
TRONROUT0000000029473761;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356352 6689183.1 7.2, 356445.5 6689063 6.7)
TRONROUT0000000029471221;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6689169.845278522 7.207346351533221, 356506.4 6689169.5 7.2, 356485.1 6689152.2 5.8)
TRONROUT0000000029470926;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;39;;43;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356506.81139568595 6689227.803926547 7.927646180204869, 356495.2 6689240.3 7.9)
TRONROUT0000000029474872;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2008-11-15 06:12:08;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356495.2 6689240.3 7.9, 356482 6689228.2 7.2, 356478.4 6689224.8 7, 356466.2 6689213.5 6.5, 356461.7 6689209.4 6.2)
TRONROUT0000000329622966;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356347.6 6689331.2 6, 356372.6 6689297.9 5.6, 356403.7 6689257 5.4, 356439.3 6689210.8 5.2, 356485.1 6689152.2 5.8)
TRONROUT0000000029474075;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;43;;45;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356495.2 6689240.3 7.9, 356452.2 6689287 6.4)
TRONROUT0000002011475894;Rond-point;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356442.3 6689297 6.4, 356441 6689295.4 6.4, 356440.4 6689294 6.4, 356440.1 6689293.2 6.4, 356439.9 6689291 6.4, 356440.5 6689288.9 6.4, 356441.4 6689287.3 6.4, 356443.3 6689285.8 6.4, 356444.9 6689285.3 6.4, 356447.4 6689285.3 6.4, 356448.8 6689285.6 6.4, 356449.6 6689285.9 6.4, 356452.2 6689287 6.4)
TRONROUT0000002011475892;Rond-point;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356452.2 6689287 6.4, 356453.4 6689288.3 6.4, 356453.9 6689289.4 6.4, 356454.1 6689290.1 6.4, 356454.2 6689290.7 6.4, 356454.3 6689292.1 6.4, 356453.9 6689294.1 6.4, 356452.7 6689296 6.4)
TRONROUT0000002011475893;Rond-point;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356452.7 6689296 6.4, 356450.9 6689297.4 6.4, 356449 6689298.2 6.4, 356447.1 6689298.5 6.4, 356445.4 6689298.4 6.4, 356444.9 6689298.3 6.4, 356443.5 6689297.9 6.4, 356442.3 6689297 6.4)
TRONROUT0000000053385296;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356181.8 6689190.4 7, 356178.2 6689188.6 7.8)
TRONROUT0000000294302102;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356189 6689188 7, 356187.9 6689190.2 7, 356186.7 6689192.4 7.1)
TRONROUT0000000053385297;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356186.7 6689192.4 7, 356181.8 6689190.4 7)
TRONROUT0000000053382404;Route à 1 chaussée;R EMILE MASSON;R EMILE MASSON;5;Non;0;En service;2007-01-24 06:48:04;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;5;2;1;44109;44109;;;;441095485;441095485;;;;;;;;;;;;;commune;commune;Rue Emile Masson;Rue Emile Masson;;;44109_5485;44109_5485;;;;;LINESTRING Z (356104.9 6689207.6 9.4, 356099 6689204.9 9, 356087.9 6689200.7 9.1, 356078.6 6689195.7 8.9, 356072.6 6689192.2 8.9, 356057.3 6689184.3 9)
TRONROUT0000000053385291;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2007-01-24 11:27:21;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356148.2 6689239.1 7.2, 356155.5 6689223.5 7.4, 356162.2 6689210.2 7.4, 356165.8 6689202.6 7, 356167.4 6689196.7 7, 356168.7 6689192.5 7, 356172.1 6689185.6 7.3)
TRONROUT0000000029475055;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356104.9 6689207.6 7.2, 356108.4 6689221.6 7.2)
TRONROUT0000000029473487;Route à 1 chaussée;R DE THIONVILLE;R DE THIONVILLE;6;Non;0;En service;2006-10-04 09:41:10;2013-10-11 14:44:24;;2012-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#09O;44109#09O;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356108.4 6689221.6 7.2, 356148.2 6689239.1 7.2)
TRONROUT0000000053385299;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356131.7 6689285.2 7, 356178.2 6689188.6 7.6)
TRONROUT0000000053385284;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:21;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;Sens direct;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356181.8 6689190.4 8.1, 356140 6689275.8 7, 356131.7 6689285.2 7)
TRONROUT0000000029474919;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;6;5;2;1;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356108.4 6689221.6 7.2, 356112.6 6689244.7 6.9, 356115.8 6689262.8 7.2, 356116.7 6689267.7 7.6)
TRONROUT0000000039537281;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2006-11-08 07:23:27;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;7;;9;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356186.7 6689192.4 7.1, 356181 6689203.3 7.1, 356176 6689211.5 7.1, 356169.1 6689225.4 7.1, 356160.2 6689243.3 7.1, 356151.3 6689261.2 7.5, 356145.4 6689273.9 7.7, 356140.8 6689282.3 7.8, 356135.6 6689291.7 8.3, 356131.8 6689299 8.4)
TRONROUT0000000053385315;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2007-01-24 11:27:53;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356127.5 6689273.3 7.9, 356129.3 6689270.4 7.7, 356133.4 6689265.3 7.7, 356138.2 6689258.8 7.7, 356141.2 6689253.3 7.7, 356144.3 6689247.2 7.6, 356148.2 6689239.1 7.2)
TRONROUT0000000294302143;Route à 1 chaussée;R CRUCY;R CRUCY;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;4;1;2;1;44109;44109;;;;441092336;441092336;;;;;;;;;;;;;commune;commune;Rue Crucy;Rue Crucy;;;44109_2336;44109_2336;;;;;LINESTRING Z (356023.8 6689249 7.8, 356098.3 6689289.1 7.8)
TRONROUT0000000294302106;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356116.7 6689267.7 7.5, 356119 6689270.5 7.6, 356122.4 6689272.7 7.6, 356125.7 6689273.3 7.6, 356127.5 6689273.3 7.9)
TRONROUT0000000294302107;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356116.9 6689276 7.9, 356116.8 6689275.7 7.9, 356116.5 6689271.8 7.9, 356116.7 6689267.7 7.6)
TRONROUT0000000294302105;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356120.3 6689287.6 7.9, 356123.6 6689280.7 8, 356126.3 6689275.3 8, 356127.5 6689273.3 7.9)
TRONROUT0000000029475279;Route à 1 chaussée;R FOURE;R FOURE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093252;441093252;;;;;;;;;;;;;commune;commune;Rue Fouré;Rue Fouré;;;44109_3252;44109_3252;;;;;LINESTRING Z (356120.3 6689287.6 7.9, 356118 6689280.5 7.9, 356116.9 6689276 7.9)
TRONROUT0000000029474834;Route à 1 chaussée;R CRUCY;R CRUCY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092336;441092336;;;;;;;;;;;;;commune;commune;Rue Crucy;Rue Crucy;;;44109_2336;44109_2336;;;;;LINESTRING Z (356098.3 6689289.1 7.8, 356106.1 6689283.7 7.7, 356112.4 6689279 7.8, 356116.9 6689276 7.9)
TRONROUT0000000053385316;Route à 1 chaussée;;;5;Non;0;En service;2007-01-24 11:27:53;2019-05-23 15:23:50;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356126.3 6689296.1 8.5, 356126.8 6689295.1 8.5, 356131.7 6689285.2 8.3)
TRONROUT0000000301053853;Route à 1 chaussée;CRS DU CHAMP DE MARS;CRS DU CHAMP DE MARS;6;Non;0;En service;2012-05-04 16:23:14;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091577;441091577;;;;;;;;;;;;;commune;commune;Cours du Champ de Mars;Cours du Champ de Mars;;;44109_1577;44109_1577;;;;;LINESTRING Z (356173.4 6689318.2 7, 356196.6 6689270.8 6.8)
TRONROUT0000000029474970;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356341.5 6689196.8 7.2, 356298.4 6689252.3 7)
TRONROUT0000000029474394;Route à 1 chaussée;R LEFEVRE-UTILE;R LEFEVRE-UTILE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;1;4;1;4;44109;44109;;;;441094866;441094866;;;;;;;;;;;;;commune;commune;Rue Lefévre-Utile;Rue Lefévre-Utile;;;44109_4866;44109_4866;;;;;LINESTRING Z (356298.4 6689252.3 7, 356267 6689234.1 6.6, 356229.6 6689212.4 6.5, 356226.2 6689210.5 6.4)
TRONROUT0000000029474871;Route à 1 chaussée;CRS DU CHAMP DE MARS;CRS DU CHAMP DE MARS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;0;Physiquement impossible;;;;;;;;;Non;6;;6;;44109;44109;;;;441091577;441091577;;;;;;;;;;;;;commune;commune;Cours du Champ de Mars;Cours du Champ de Mars;;;44109_1577;44109_1577;;;;;LINESTRING Z (356196.6 6689270.8 6.8, 356226.2 6689210.5 6.5)
TRONROUT0000000301053852;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2012-05-04 16:23:14;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;15;;19;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356298.4 6689252.3 7, 356281.8 6689273.9 7, 356261.4 6689301.1 7)
TRONROUT0000000301053851;Sentier;SQ JEAN HEURTIN;SQ JEAN HEURTIN;6;Non;0;En service;2012-05-04 16:23:14;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441094459;441094459;;;;;;;;;;;;;commune;commune;Square Jean Heurtin;Square Jean Heurtin;;;44109_4459;44109_4459;;;;;LINESTRING Z (356261.4 6689301.1 7, 356225.5 6689285 6.9, 356196.6 6689270.8 6.8)
TRONROUT0000000214838225;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2008-12-19 16:37:00;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;21;;23;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356261.4 6689301.1 7, 356243.8 6689324.8 7, 356223.8 6689341.4 6)
TRONROUT0000000029474251;Route à 1 chaussée;R DE LA BISCUITERIE;R DE LA BISCUITERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441090838;441090838;;;;;;;;;;;;;commune;commune;Rue de la Biscuiterie;Rue de la Biscuiterie;;;44109_0838;44109_0838;;;;;LINESTRING Z (356173.4 6689318.2 7, 356177.8 6689320.2 6.9, 356223.8 6689341.4 6)
TRONROUT0000000295265462;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356347.6 6689331.2 6, 356357.2 6689337.4 6.4, 356360.3 6689339.4 6.6)
TRONROUT0000000029475046;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-09-29 19:30:36;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356384 6689359.7 7.9, 356373.8 6689350.3 7.6, 356372.7 6689349.4 7.5, 356360.3 6689339.4 6.6)
TRONROUT0000000214838221;Sentier;;;6;Non;0;En service;2008-12-19 16:37:00;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356294.9 6689397.1 5.9, 356325.3 6689359.3 5.6, 356347.6 6689331.2 6)
TRONROUT0000002202713288;Sentier;;;6;Non;0;En service;2019-05-23 15:23:50;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356126.3 6689296.1 -1000, 356124.3 6689295 -1000)
TRONROUT0000002202713289;Sentier;;;6;Non;0;En service;2019-05-23 15:23:50;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356131.8 6689299 -1000, 356126.3 6689296.1 -1000)
TRONROUT0000000039537283;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2006-11-08 07:23:27;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356109.3 6689310.4 9, 356115.5 6689298 9, 356120.3 6689287.6 7.9)
TRONROUT0000000294302104;Route à 1 chaussée;R DE LA BISCUITERIE;R DE LA BISCUITERIE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090838;441090838;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de la Biscuiterie;Rue de la Biscuiterie;;;44109_0838;44109_0838;;;;;LINESTRING Z (356131.8 6689299 8.4, 356136.4 6689300.9 7.8)
TRONROUT0000002202713290;Route à 1 chaussée;;;5;Non;0;En service;2019-05-23 15:23:50;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356117.2 6689314.5 9.2, 356126.3 6689296.1 8.5)
TRONROUT0000000039537259;Route à 2 chaussées;AV CARNOT;AV CARNOT;3;Non;0;En service;2006-11-08 07:23:27;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;70;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356131.8 6689299 8.4, 356128.3 6689304.4 8.5, 356124.2 6689310.8 8.7, 356120.9 6689316.5 8.6)
TRONROUT0000000029473792;Route à 1 chaussée;R DE LA BISCUITERIE;R DE LA BISCUITERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090838;441090838;;;;;;;;;;;;;commune;commune;Rue de la Biscuiterie;Rue de la Biscuiterie;;;44109_0838;44109_0838;;;;;LINESTRING Z (356136.4 6689300.9 7.8, 356173.4 6689318.2 7)
TRONROUT0000000029474241;Route à 1 chaussée;R COUSTARD;R COUSTARD;5;Non;0;En service;2006-10-04 09:41:10;2012-01-17 12:39:06;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;1;2;1;4;44109;44109;;;;44109#09F;44109#09F;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356078.2 6689354.7 7.8, 356081.7 6689347.5 7.8, 356102.3 6689310.6 7.8, 356103.8 6689305.1 7.8, 356104.3 6689299.4 7.8, 356103.9 6689294.2 7.8, 356101.8 6689291 7.8, 356098.3 6689289.1 7.8)
TRONROUT0000000029474807;Route à 1 chaussée;AV CARNOT;AV CARNOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (356136.4 6689300.9 7.8, 356135.9 6689302 7.8, 356103.2 6689369.7 6.9)
TRONROUT0000002011475936;Route à 1 chaussée;PONT DE LA ROTONDE;PONT DE LA ROTONDE;3;Non;1;En service;2018-06-11 11:56:08;2023-05-26 09:18:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08V;44109#08V;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356120.9 6689316.5 8.5, 356113 6689332.8 10.6, 356105.8 6689348.3 11.9, 356098.7 6689362.8 13.1, 356094.4 6689372.2 13.7, 356094.1 6689372.7 12.8)
TRONROUT0000002011475937;Route à 1 chaussée;PONT DE LA ROTONDE;PONT DE LA ROTONDE;3;Non;1;En service;2018-06-11 11:56:08;2022-01-25 18:59:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08V;44109#08V;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356054.6 6689393.3 15.3, 356063.7 6689383.8 14.8, 356065.5 6689381.9 14.8, 356075.1 6689371.3 14.8, 356082.2 6689361.8 14.2, 356087.3 6689353.7 13, 356096.3 6689337.2 12.6, 356103.3 6689322.6 11.4, 356109.3 6689310.4 9.1)
TRONROUT0000000053385319;Route à 1 chaussée;PONT DE LA ROTONDE;PONT DE LA ROTONDE;5;Non;1;En service;2007-01-24 11:27:53;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#08V;44109#08V;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356074.1 6689401 12.6, 356077.2 6689394.7 12.5, 356078.9 6689391.3 12.3, 356092.5 6689364 11.2, 356114.1 6689320.9 9.5, 356117.2 6689314.5 9.2)
TRONROUT0000000294302130;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356223.8 6689341.4 6, 356206 6689358.4 7, 356181.8 6689370.6 7, 356159.1 6689377.1 7)
TRONROUT0000000053385318;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2007-01-24 11:27:53;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;4.0;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (356078.2 6689354.7 7.8, 356087.2 6689361.2 7.8, 356092.5 6689364 11.2, 356099.7 6689367.9 7.8, 356103.2 6689369.7 6.9)
TRONROUT0000000029474654;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356103.2 6689369.7 6.9, 356125.6 6689379.2 7.8)
TRONROUT0000000294302124;Escalier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-06-14 15:27:56;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356094.1 6689372.7 12.8, 356112.3 6689381.2 8)
TRONROUT0000000029474357;Route à 1 chaussée;QU FERDINAND FAVRE;QU FERDINAND FAVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093103;441093103;;;;;;;;;;;;;commune;commune;Quai Ferdinand Favre;Quai Ferdinand Favre;;;44109_3103;44109_3103;;;;;LINESTRING Z (356159.1 6689377.1 7, 356148.3 6689380.2 7.1, 356131.9 6689381.9 8.1)
TRONROUT0000000294302120;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356125.6 6689379.2 7.8, 356131.9 6689381.9 8.1)
TRONROUT0000002287928812;Route à 1 chaussée;PONT DE LA ROTONDE;PONT DE LA ROTONDE;3;Non;1;En service;2022-06-14 15:27:56;2023-05-26 09:18:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08V;44109#08V;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356094.1 6689372.7 12.8, 356090.6 6689379.5 14.1, 356087.8 6689385.5 14.2, 356086.3 6689389 13)
TRONROUT0000000294302129;Escalier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356179.1 6689387.1 5.8, 356171.5 6689383.9 6.2, 356162.5 6689382 8.3, 356161.5 6689381.1 8.3, 356159.1 6689377.1 8.3)
TRONROUT0000000294302123;Sentier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356112.3 6689381.2 8, 356115.7 6689382 8, 356123.4 6689385 8, 356124 6689382.9 8, 356125.6 6689379.2 7.8)
TRONROUT0000000029474138;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356160.5 6689395.5 9.5, 356131.9 6689381.9 8.1)
TRONROUT0000002287928811;Escalier;;;6;Non;0;En service;2022-06-14 15:27:56;2022-06-14 20:07:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356105.5 6689399 8.4, 356086.3 6689389 13)
TRONROUT0000002287928810;Route à 1 chaussée;PONT DE LA ROTONDE;PONT DE LA ROTONDE;3;Non;1;En service;2022-06-14 15:27:56;2023-05-26 09:18:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08V;44109#08V;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356086.3 6689389 13, 356084.9 6689392.2 13.3, 356084.1 6689393.8 13.2, 356079.7 6689403 13.1)
TRONROUT0000000029473952;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;1;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356160.5 6689395.5 9.5, 356189.5 6689408.5 2.1)
TRONROUT0000000294302121;Sentier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356108.3 6689406 8.4, 356108.1 6689403.6 8.4, 356105.5 6689399 8.4)
TRONROUT0000000294302133;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-01-17 12:39:06;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356068.3 6689411.8 12.5, 356068.9 6689410.4 12.6, 356072.7 6689403.8 12.9, 356074.1 6689401 12.6)
TRONROUT0000002011476013;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356105.9 6689410.6 8.4, 356108.4 6689406.7 8.4, 356108.3 6689406 8.4)
TRONROUT0000000294302125;Sentier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356095.1 6689432.5 6, 356097.5 6689435.1 5.7, 356099.6 6689435 5.7, 356109 6689428.9 5.7, 356128.1 6689416.4 5.8, 356137.6 6689411.4 5.8, 356148.2 6689404.5 5.8, 356160.4 6689396.6 5.8, 356163.3 6689395 5.8, 356166.5 6689394.3 5.8, 356173.1 6689392.4 5.8, 356177.2 6689389.8 5.8, 356179.1 6689387.1 5.8)
TRONROUT0000002011475925;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356068.3 6689411.8 12.5, 356062.3 6689411.3 12.5)
TRONROUT0000000039537275;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2006-11-08 07:23:27;2015-03-12 20:24:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356105.9 6689410.6 8.4, 356117.7 6689418.9 9)
TRONROUT0000002202713287;Sentier;;;6;Non;0;En service;2019-05-23 15:23:50;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356105.9 6689410.6 -1000, 356102 6689418 -1000, 356103.6 6689426.5 -1000, 356095.1 6689432.5 -1000)
TRONROUT0000000214838226;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;3;Non;0;En service;2008-12-19 16:37:00;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356079.7 6689403 13, 356077.3 6689410.8 12.5, 356075.8 6689418.5 11.9, 356075.8 6689428.7 11.2, 356077.8 6689440.3 10.6, 356078.9 6689443.6 10.4)
TRONROUT0000002206013067;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;1;En service;2019-12-05 14:02:47;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356117.7 6689418.9 6, 356135.5 6689433 7.5)
TRONROUT0000000294302131;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;1;En service;2012-01-17 12:39:06;2019-12-05 14:02:47;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356117.7 6689418.9 9, 356123.1 6689423.6 9, 356128.5 6689429.1 9, 356133 6689434.6 9)
TRONROUT0000000294302126;Escalier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356078.9 6689443.6 10.4, 356084.4 6689440.8 10.3, 356095.1 6689432.5 6)
TRONROUT0000002011476014;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356071.6 6689465.9 9.8, 356071.6 6689464.2 9.9, 356070.4 6689454.8 10.5, 356068.3 6689441.2 11, 356066.9 6689431.8 11.5, 356066 6689424.6 11.8, 356066 6689420.2 12.2, 356066.7 6689415.9 12.3, 356068.3 6689411.8 12.5)
TRONROUT0000002206013064;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356135.5 6689433 7.5, 356137.6 6689434.7 6.2, 356143.2 6689440 6.4, 356148.4 6689444.5 6.4, 356153.5 6689448.4 6.3, 356159.5 6689451 6.4, 356165.8 6689453.1 6.4, 356171.1 6689456.7 6.4, 356172.5 6689459 7.8)
TRONROUT0000002206013066;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356151.1 6689459 8.4, 356148.7 6689454.1 8.4, 356145.1 6689448.9 8.4, 356140.8 6689443.8 8.4, 356135.6 6689438 8.5, 356133 6689434.6 8.6)
TRONROUT0000002206013065;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356151.1 6689459 8.6, 356152.1 6689457.7 9.1, 356157.3 6689454.9 9.2, 356163.2 6689454.3 9.2, 356169.1 6689456.1 9.2, 356172.5 6689459 7.8)
TRONROUT0000000214838224;Sentier;;;6;Non;0;En service;2008-12-19 16:37:00;2019-06-20 22:30:01;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356179.1 6689387.1 5.8, 356182.8 6689383.2 5.8, 356186.6 6689380.3 5.8, 356197.4 6689375.1 5.8, 356205.1 6689371.2 5.8, 356211.9 6689366.6 5.8, 356216.8 6689362 5.8, 356221.1 6689356.9 5.8, 356225.6 6689350.7 5.8, 356227.6 6689346.3 6.1, 356227.1 6689344.4 6.2, 356223.8 6689341.4 6)
TRONROUT0000002322750696;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2022-11-04 16:09:51;2023-03-16 14:38:43;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;48B;;48;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356384 6689359.7 7.9, 356364.6 6689381.8 8.1)
TRONROUT0000000214838223;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2008-12-19 16:37:00;2023-03-16 14:38:43;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;48B;;48;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356364.6 6689381.8 8.1, 356361.9 6689383.5 8.2, 356335 6689407.4 8.2)
TRONROUT0000000294302127;Sentier;;;6;Non;0;En service;2012-01-17 12:39:06;2022-09-29 19:30:36;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356335 6689407.4 8.2, 356294.9 6689397.1 5.9)
TRONROUT0000002275197862;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2021-11-30 14:06:58;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;48B;;48;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356335 6689407.4 8.2, 356328.4 6689412.9 8.2, 356322.3 6689417.6 8.2, 356312.9 6689422 8.2, 356299.1 6689429.1 8.2)
TRONROUT0000000029473529;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;48B;;48;44109;44109;;;;441095252;441095252;;;;;;;;;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356284.6 6689430.5 8.4, 356270.9 6689427.3 8.4, 356240.7 6689425.1 8.6, 356225.8 6689422 8.8, 356208.5 6689416.5 9.2, 356189.5 6689408.5 2.1)
TRONROUT0000002275197863;Rond-point;;;4;Non;0;En service;2021-11-30 14:06:58;2022-09-29 19:30:36;;;;;Levé non GPS;5.0;Pas de Z;9999.0;1.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356284.6 6689430.5 -1000, 356284.6 6689429.9 -1000, 356284.7 6689428.5 -1000, 356285.2 6689427.1 -1000, 356285.8 6689425.9 -1000, 356286.7 6689424.8 -1000, 356287.9 6689423.8 -1000, 356289.1 6689423.2 -1000, 356290.5 6689422.7 -1000, 356291.9 6689422.6 -1000, 356293.3 6689422.7 -1000, 356294.7 6689423.2 -1000, 356295.9 6689423.8 -1000, 356297 6689424.7 -1000, 356298 6689425.9 -1000, 356298.6 6689427.1 -1000, 356299.1 6689428.5 -1000, 356299.1 6689429.1 -1000)
TRONROUT0000002275197861;Rond-point;;;4;Non;0;En service;2021-11-30 14:06:58;2022-09-29 19:30:36;;;;;Levé non GPS;5.0;Pas de Z;9999.0;1.0;5.0;Non;Non;Sens direct;;Non;25;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356299.1 6689429.1 -1000, 356299.2 6689429.9 -1000, 356299.1 6689431.3 -1000, 356298.6 6689432.7 -1000, 356298 6689433.9 -1000, 356297.1 6689435 -1000, 356295.9 6689436 -1000, 356294.7 6689436.6 -1000, 356293.3 6689437.1 -1000, 356291.9 6689437.2 -1000, 356290.5 6689437.1 -1000, 356289.1 6689436.6 -1000, 356287.9 6689436 -1000, 356286.8 6689435.1 -1000, 356285.8 6689433.9 -1000, 356285.2 6689432.7 -1000, 356284.7 6689431.3 -1000, 356284.6 6689430.5 -1000)
TRONROUT0000000325977069;Sentier;;;6;Non;0;En service;2013-09-05 12:56:25;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356115.5 6689470 9, 356114.3 6689463.9 9, 356113.8 6689460.7 8.4, 356113.7 6689455.7 7.3, 356113.8 6689450.2 6.6, 356114.5 6689444.7 5.9, 356115.7 6689439.1 5.9, 356118.4 6689435.9 5.9, 356125.2 6689432.1 5.9, 356136.4 6689424.8 6.1, 356145.4 6689419.6 6.4, 356153.3 6689417 6.4, 356161.9 6689414.3 6.4, 356180.3 6689405.2 6.4, 356181.2 6689404.8 6.3, 356192.6 6689399.9 6, 356196.7 6689398.4 6, 356242.5 6689398 5.9, 356294.9 6689397.1 5.9)
TRONROUT0000000084983251;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;5;Non;0;En service;2007-07-18 11:02:16;2019-12-05 14:02:47;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Double sens;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356188.4 6689501.3 8.1, 356192.4 6689505.4 8.1, 356197.1 6689510.4 8.1, 356202.3 6689515.4 8.1, 356207.9 6689520.2 8, 356213.6 6689524.5 8, 356219.3 6689528.3 8.1, 356225 6689531.4 8.2, 356230.4 6689534.1 8.3, 356235.3 6689536.7 8.3, 356240.3 6689539.1 8.4, 356244.8 6689541.1 8.3, 356248.8 6689542.8 8.3, 356252.1 6689544.3 8.3, 356254.7 6689545.5 8.3, 356256.4 6689546.2 8, 356258 6689547 8.1, 356259.6 6689547.8 8.1)
TRONROUT0000002011475907;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355781.7 6689276.7 7.9, 355786.7 6689269.8 8, 355796.9 6689253.5 8.1)
TRONROUT0000002011475956;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355832.4 6689263.7 7.6, 355836.2 6689263.5 7.5, 355841.6 6689264.8 7.3, 355847.3 6689266.5 7.3, 355853.5 6689268.5 7.1, 355860.1 6689270.8 7.1, 355865 6689272.5 7)
TRONROUT0000002011475924;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355833.5 6689272.7 8, 355832.4 6689263.7 7.6)
TRONROUT0000002011475958;Rond-point;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355824.1 6689264.2 7.9, 355825.3 6689266.9 7.9, 355825.5 6689271.6 7.9, 355824.4 6689274.4 7.9)
TRONROUT0000002011475928;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355800.2 6689285.5 8.1, 355798.8 6689276.2 8.1, 355798.1 6689269 8.1, 355797.7 6689259.9 8.1, 355796.9 6689253.5 8.1)
TRONROUT0000002011475959;Rond-point;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355811.6 6689280.3 7.9, 355810.2 6689280.1 7.9, 355807 6689277.9 7.9, 355804.4 6689275.2 7.9, 355803.1 6689270.9 7.9, 355803.2 6689266.4 7.9, 355804.9 6689263 7.9)
TRONROUT0000002011475952;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355865 6689272.5 7, 355854.6 6689272.3 7, 355846 6689271.9 7.6, 355839.2 6689272 7.8, 355833.5 6689272.7 8)
TRONROUT0000002011475953;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2018-06-11 11:56:08;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355833.5 6689272.7 8, 355831.7 6689272.9 8.1, 355824.4 6689274.4 7.9)
TRONROUT0000002011475926;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355835.1 6689279.1 8.3, 355833.5 6689272.7 8)
TRONROUT0000000326050048;Rond-point;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2013-09-05 19:16:26;2018-06-11 11:56:08;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355824.4 6689274.4 7.9, 355823.9 6689275.8 7.9, 355821 6689278.8 7.9, 355817.5 6689280.4 7.9, 355813.8 6689280.7 7.9, 355811.6 6689280.3 7.9)
TRONROUT0000002011475903;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355800.2 6689285.5 8.1, 355789.9 6689281.9 8.1, 355781.7 6689276.7 7.9)
TRONROUT0000002011475942;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355811.6 6689280.3 7.9, 355810.5 6689289.6 7.9)
TRONROUT0000002011475904;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355835.1 6689279.1 8.3, 355830.7 6689280.3 8.3, 355825.6 6689282.9 8.3, 355822.8 6689285.1 8.3, 355819.9 6689289.2 8.3, 355818.7 6689291.8 8.3)
TRONROUT0000002011475913;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355810.5 6689289.6 7.9, 355800.2 6689285.5 8.1)
TRONROUT0000002011475905;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355848 6689301.7 8.3, 355835.1 6689279.1 8.3)
TRONROUT0000002011475945;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355818.7 6689291.8 8.3, 355810.5 6689289.6 7.9)
TRONROUT0000002011475920;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355848 6689301.7 8.3, 355846.5 6689301.3 8.3, 355818.7 6689291.8 8.3)
TRONROUT0000002011475932;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355790.7 6689324 7.8, 355798.5 6689310.1 8.7, 355800 6689305.2 8.1, 355801.1 6689295.4 8.1, 355800.7 6689288.6 8.1, 355800.2 6689285.5 8.1)
TRONROUT0000000324785228;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2013-08-19 15:41:49;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355810.5 6689289.6 7.9, 355809.4 6689298.3 7.9, 355799.6 6689327.1 7.8)
TRONROUT0000002202713286;Sentier;;;6;Non;0;En service;2019-05-23 15:23:50;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355818.7 6689291.8 8.3, 355807.8 6689333.9 8.6)
TRONROUT0000000029474950;Route à 1 chaussée;ALL BACO;ALL BACO;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;58;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090512;441090512;;;;;;;;;;;;;commune;commune;Allée Baco;Allée Baco;;;44109_0512;44109_0512;;;;;LINESTRING Z (356078.2 6689354.7 7.8, 355968 6689279.4 7, 355913.6 6689242.3 6.7)
TRONROUT0000000326050044;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2013-09-05 19:16:26;2018-06-11 11:56:08;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355865 6689272.5 7, 355866.9 6689273.2 7, 355874 6689276 6.8, 355881.2 6689279.3 6.6, 355888.3 6689282.7 6.3, 355895.4 6689286.4 6.1, 355902.4 6689290.6 5.8, 355909.4 6689294.8 5.1, 355916 6689299.5 6.3, 355922.9 6689303.7 6.2, 355929.8 6689308.2 6.4, 355936.9 6689312.5 6.1, 355943.9 6689317.3 6, 355950.8 6689321.9 6.8, 355964.6 6689330.6 7.7, 355971.5 6689334.6 7.5, 355982 6689340.9 7.7, 355996.7 6689359 8)
TRONROUT0000002011475946;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-01-25 18:59:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355825.7 6689235.7 7.4, 355862.4 6689256.1 7.4, 355867.2 6689260.2 7.5, 355907.1 6689284.6 7.9, 355955.3 6689315.3 7.9, 355982.8 6689333 8, 356028.6 6689360.8 8, 356036.6 6689365.1 8, 356038.3 6689366.4 8, 356039.4 6689368.4 8, 356041.2 6689373.4 8, 356057.6 6689380.8 7.5, 356098.5 6689400.8 8.8, 356108.3 6689406 8.4)
TRONROUT0000002011475908;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355943.5 6689354.4 8.1, 355924.9 6689323.2 8.2, 355848 6689301.7 8.3)
TRONROUT0000002011475910;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355870.1 6689337.6 8.1, 355888.1 6689340.5 8.1, 355943.5 6689354.4 8.1)
TRONROUT0000002011475923;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355953.1 6689371.1 8, 355944.6 6689356.4 8.1, 355943.5 6689354.4 8.1)
TRONROUT0000002011475951;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2018-06-11 11:56:08;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355996.7 6689359 8, 355998.7 6689357.5 8, 356000.5 6689356.7 8, 356003.2 6689356.3 7.9, 356005.2 6689356.8 7.9, 356007 6689357.6 7.9, 356008.1 6689358.8 7.9, 356009 6689360 7.9, 356009.6 6689361.1 7.7, 356010.2 6689362.8 7.7, 356010.8 6689365.8 8, 356010.5 6689367.6 8.1, 356009.2 6689370.4 7.5)
TRONROUT0000002011475950;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2018-06-11 11:56:08;;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355998.5 6689374.6 7.9, 355995.7 6689372.2 8.5, 355994.5 6689370.5 8.6, 355994.2 6689369.4 8.6, 355993.6 6689366.9 8.5, 355993.7 6689363.8 8.3, 355994 6689362.4 8.3, 355995.5 6689360.4 8.3, 355996.7 6689359 8)
TRONROUT0000000324785223;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2013-08-19 15:41:49;2018-06-11 11:56:08;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356009.2 6689370.4 7.5, 356008.8 6689371 7.5, 356007 6689373.3 7.8, 356004.5 6689374.5 7.8, 356002 6689375 7.9, 355998.5 6689374.6 7.9)
TRONROUT0000002011475900;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355953.1 6689371.1 8, 355960.5 6689371.1 8, 355983.8 6689377 8.6, 355987.7 6689377.1 8.6, 355994.1 6689380.3 8)
TRONROUT0000002011475919;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355870.1 6689337.6 8.1, 355848 6689301.7 8.3)
TRONROUT0000000029474278;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2006-10-04 09:41:10;2018-06-11 11:56:08;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355790.7 6689324 7.8, 355799.6 6689327.1 7.8)
TRONROUT0000000029474068;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355794.1 6689342.7 7.8, 355797.5 6689332.6 7.8, 355799.6 6689327.1 7.8)
TRONROUT0000002202713285;Sentier;;;6;Non;0;En service;2019-05-23 15:23:50;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355807.8 6689333.9 -1000, 355803.6 6689347.1 -1000)
TRONROUT0000002011475912;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355807.8 6689333.9 8.6, 355866.2 6689350.9 8)
TRONROUT0000002245095832;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2021-08-30 10:51:57;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355794.1 6689342.7 8.3, 355797.5 6689343.8 8.3)
TRONROUT0000002011475917;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355870.1 6689337.6 8.1, 355866.2 6689350.9 8)
TRONROUT0000002202713284;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2019-05-23 15:23:50;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355797.5 6689343.8 8.3, 355802.9 6689346.5 8.3, 355803.6 6689347.1 8.3)
TRONROUT0000000295264955;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355789.5 6689353.1 8.4, 355792.3 6689347.4 8.1, 355794.1 6689342.7 7.8)
TRONROUT0000002011475916;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355895.5 6689359.4 7.7, 355870.1 6689337.6 8.1)
TRONROUT0000000029474503;Route à 1 chaussée;R DES PETITES ECURIES;R DES PETITES ECURIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096492;441096492;;;;;;;;;;;;;commune;commune;Rue des Petites Ecuries;Rue des Petites Ecuries;;;44109_6492;44109_6492;;;;;LINESTRING Z (355668.3 6689311.1 7.6, 355666.9 6689316.4 7.6)
TRONROUT0000002011475939;Route à 1 chaussée;CRS FRANKLIN ROOSEVELT;CRS FRANKLIN ROOSEVELT;5;Non;0;En service;2018-06-11 11:56:08;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#022;44109#022;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355737.6 6689307.2 7.8, 355762.2 6689313.8 7.8, 355790.7 6689324 7.8)
TRONROUT0000000029474222;Route à 1 chaussée;ALL DU PORT MAILLARD;ALL DU PORT MAILLARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;7;;11;44109;44109;;;;441096868;441096868;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Allée du Port Maillard;Allée du Port Maillard;;;44109_6868;44109_6868;;;;;LINESTRING Z (355731.6 6689328.1 7.9, 355668.3 6689311.1 7.6)
TRONROUT0000000029474276;Route à 1 chaussée;R DES PETITES ECURIES;R DES PETITES ECURIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441096492;441096492;;;;;;;;;;;;;commune;commune;Rue des Petites Ecuries;Rue des Petites Ecuries;;;44109_6492;44109_6492;;;;;LINESTRING Z (355666.9 6689316.4 7.6, 355664.3 6689327.4 7.5, 355661.2 6689340.3 7.5, 355660.1 6689343.3 7.5)
TRONROUT0000000029474609;Route à 1 chaussée;ALL DU PORT MAILLARD;ALL DU PORT MAILLARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;5;44109;44109;;;;441096868;441096868;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Allée du Port Maillard;Allée du Port Maillard;;;44109_6868;44109_6868;;;;;LINESTRING Z (355794.1 6689342.7 7.8, 355774.7 6689338.3 7.8, 355731.6 6689328.1 7.9)
TRONROUT0000000029474115;Route à 1 chaussée;R PAUL DUBOIS;R PAUL DUBOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;3;2;1;44109;44109;;;;441096224;441096224;;;;;;;;;;;;;commune;commune;Rue Paul Dubois;Rue Paul Dubois;;;44109_6224;44109_6224;;;;;LINESTRING Z (355732.4 6689372.2 7.9, 355731.6 6689328.1 7.9)
TRONROUT0000000029474277;Route à 1 chaussée;R DES PETITES ECURIES;R DES PETITES ECURIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;6;3;8;44109;44109;;;;441096492;441096492;;;;;;;;;;;;;commune;commune;Rue des Petites Ecuries;Rue des Petites Ecuries;;;44109_6492;44109_6492;;;;;LINESTRING Z (355660.1 6689343.3 7.5, 355658.6 6689347 7.5, 355654.3 6689351.6 7.4, 355650.5 6689362.8 7.9)
TRONROUT0000000029473665;Route à 1 chaussée;IMP JOSEPH PEIGNON;IMP JOSEPH PEIGNON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441094587;441094587;;;;;;;;;;;;;commune;commune;Impasse Joseph Peignon;Impasse Joseph Peignon;;;44109_4587;44109_4587;;;;;LINESTRING Z (355732.4 6689372.2 7.9, 355714.4 6689365.7 7.9, 355701 6689360.3 7.3)
TRONROUT0000000029474039;Route à 1 chaussée;R LAMBERT;R LAMBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;3;4;3;44109;44109;;;;441094756;441094756;;;;;;;;;;;;;commune;commune;Rue Lambert;Rue Lambert;;;44109_4756;44109_4756;;;;;LINESTRING Z (355650.5 6689362.8 7.9, 355680.6 6689370.2 7.9, 355709.5 6689379.6 7.9)
TRONROUT0000000029474534;Route à 1 chaussée;R DES PETITES ECURIES;R DES PETITES ECURIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;15;18;17;20;44109;44109;;;;441096492;441096492;;;;;;;;;;;;;commune;commune;Rue des Petites Ecuries;Rue des Petites Ecuries;;;44109_6492;44109_6492;;;;;LINESTRING Z (355650.5 6689362.8 7.9, 355649.3 6689367 7.4, 355647.6 6689389.4 7.8)
TRONROUT0000000108282933;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2007-12-04 10:47:38;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355803.6 6689347.1 8.3, 355806.4 6689349.4 8.4, 355808.2 6689353.8 8.3)
TRONROUT0000002011475918;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355866.2 6689350.9 8, 355895.5 6689359.4 7.7)
TRONROUT0000000108282932;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2007-12-04 10:47:38;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355808.2 6689353.8 8.3, 355808 6689359.9 8.3)
TRONROUT0000000107837496;Sentier;;;6;Non;0;En service;2007-12-03 22:15:03;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355817.3 6689367.7 7.5, 355808 6689359.9 8.3)
TRONROUT0000000295265263;Escalier;;;6;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355820.2 6689381.2 5, 355817.5 6689378.8 4.9, 355822.5 6689370.1 7.6, 355820 6689369 7.6, 355817.3 6689367.7 7.5)
TRONROUT0000000107837503;Sentier;;;6;Non;0;En service;2007-12-03 22:15:03;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355820.2 6689381.2 5, 355822.8 6689376 4.7, 355824.5 6689370.8 4.8, 355826.3 6689368.4 4.8, 355827.9 6689366.4 4.8, 355830.9 6689364.6 4.8, 355836.3 6689363.8 4.8, 355841.2 6689364.7 4.8, 355852.1 6689368.2 4.8, 355867.1 6689373.9 4.8, 355890.7 6689384.3 4.8, 355891 6689386.3 4.8, 355888.6 6689390.3 4.8)
TRONROUT0000000107837498;Sentier;;;6;Non;0;En service;2007-12-03 22:15:03;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355959.8 6689417.2 7.8, 355955.6 6689413.3 7.8, 355947.7 6689407.5 7.8, 355934.6 6689399.5 7.7, 355917.8 6689390.1 7.5, 355902 6689382.3 7.4, 355882.7 6689373.4 7.2, 355862.1 6689365.1 7.2, 355843.4 6689358.9 7.6, 355832.6 6689356.3 7.7, 355822.6 6689355 7.7, 355808.2 6689353.8 8.3)
TRONROUT0000000029473811;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;10;9;6;5;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355751.2 6689429.2 9.8, 355789.5 6689353.1 8.4)
TRONROUT0000000029473912;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;;9;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355808 6689359.9 8.3, 355804.3 6689371.2 8.3, 355800.6 6689382.7 8.8, 355796.1 6689396.9 8.9, 355792.5 6689409.2 9.1, 355788.8 6689422.6 9.6, 355786.9 6689431.1 10.3)
TRONROUT0000000107837502;Sentier;;;6;Non;1;En service;2007-12-03 22:15:03;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355888.6 6689390.3 4.8, 355882.1 6689402.5 4.8)
TRONROUT0000002011476016;Route à 1 chaussée;AV CARNOT;AV CARNOT;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (355998.5 6689374.6 7.9, 355994.1 6689380.3 8)
TRONROUT0000002011475914;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355976.5 6689409.4 8.1, 355949.5 6689391.9 7.8, 355896 6689359.8 7.7, 355895.5 6689359.4 7.7)
TRONROUT0000002011475899;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355976.5 6689409.4 8.1, 355969.8 6689400 7.7, 355953.1 6689371.1 8)
TRONROUT0000000053385317;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2007-01-24 11:27:53;2017-11-03 16:26:24;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356105.9 6689410.6 8.4, 356104.1 6689409.3 8.4, 356091.5 6689402 8.1, 356079.5 6689395.8 7.9, 356077.2 6689394.7 12.5, 356066.8 6689389.8 7.9, 356056.5 6689385.8 7.7, 356045.1 6689381.9 7.7, 356009.2 6689370.4 7.5)
TRONROUT0000000326050042;Route à 1 chaussée;AV CARNOT;AV CARNOT;3;Non;0;En service;2013-09-05 19:16:26;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091448;441091448;;;;;;;;;;;;;commune;commune;Avenue Carnot;Avenue Carnot;;;44109_1448;44109_1448;;;;;LINESTRING Z (355994.1 6689380.3 8, 355991.5 6689383.8 8.1, 355990.6 6689390.4 8.3, 355991.1 6689398.8 8.7, 355994.1 6689405 8.9, 355998.7 6689410.4 9.2, 356005.3 6689414.8 9.4, 356012.1 6689416.7 9.6, 356019.9 6689416.6 10, 356027.5 6689414.9 10.6, 356035 6689411.9 10.8, 356040.5 6689408.7 11.4, 356049.6 6689399.5 13.8, 356054.6 6689393.3 15.3)
TRONROUT0000002011475931;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356006.6 6689429.1 9.1, 356002.6 6689428.7 8.9, 355997.1 6689426.3 8.7, 355986.4 6689417.8 8.4, 355976.5 6689409.4 8.1)
TRONROUT0000002011475933;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2022-05-13 20:06:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356062.3 6689411.3 12.5, 356057.6 6689410.8 12.5, 356053.7 6689411.2 11.6, 356047.8 6689413.3 11.3, 356039.8 6689417.5 11, 356032.6 6689422.2 11, 356026.9 6689425.8 10.5, 356018.6 6689428.3 9.9, 356014.2 6689429.1 9.4, 356009.3 6689429.4 9.2, 356006.6 6689429.1 9.1)
TRONROUT0000000327841961;Sentier;;;6;Non;0;En service;2013-09-27 10:55:15;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355959.8 6689417.2 7.8, 355977.6 6689429 8, 355992.9 6689438.4 8)
TRONROUT0000002011475902;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356040.4 6689449.1 9.8, 356057.7 6689418.4 12, 356062.3 6689411.3 12.5)
TRONROUT0000002011475911;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356040.4 6689449.1 9.8, 356039.7 6689448.8 9.8, 356014 6689435.4 9.7, 356006.6 6689429.1 9.1)
TRONROUT0000000029474459;Route à 1 chaussée;R PAUL DUBOIS;R PAUL DUBOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;5;8;5;44109;44109;;;;441096224;441096224;;;;;;;;;;;;;commune;commune;Rue Paul Dubois;Rue Paul Dubois;;;44109_6224;44109_6224;;;;;LINESTRING Z (355731.5 6689385.2 7.9, 355732.4 6689372.2 7.9)
TRONROUT0000000029475059;Sentier;R LAMBERT;R LAMBERT;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;;2;;44109;44109;;;;441094756;441094756;;;;;;;;;;;;;commune;commune;Rue Lambert;Rue Lambert;;;44109_4756;44109_4756;;;;;LINESTRING Z (355709.5 6689379.6 7.9, 355724.6 6689384.5 7.9, 355731.5 6689385.2 7.9)
TRONROUT0000000029473478;Sentier;IMP HAUTE MAILLARD;IMP HAUTE MAILLARD;6;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;1;;3;44109;44109;;;;441094059;441094059;;;;;;;;;;;;;commune;commune;Haute Impasse Maillard;Haute Impasse Maillard;;;44109_4055;44109_4055;;;;;LINESTRING Z (355647.6 6689389.4 7.8, 355675.4 6689387.7 7.8)
TRONROUT0000000029475011;Route à 1 chaussée;R PAUL DUBOIS;R PAUL DUBOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;7;10;7;44109;44109;;;;441096224;441096224;;;;;;;;;;;;;commune;commune;Rue Paul Dubois;Rue Paul Dubois;;;44109_6224;44109_6224;;;;;LINESTRING Z (355731.1 6689412.4 8.6, 355731.5 6689385.2 7.9)
TRONROUT0000000029473681;Route à 1 chaussée;R DES PETITES ECURIES;R DES PETITES ECURIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;17;22;21;30;44109;44109;;;;441096492;441096492;;;;;;;;;;;;;commune;commune;Rue des Petites Ecuries;Rue des Petites Ecuries;;;44109_6492;44109_6492;;;;;LINESTRING Z (355647.6 6689389.4 7.8, 355646.3 6689406.6 8, 355643.8 6689425.5 10, 355643.6 6689426.9 9.6)
TRONROUT0000000029473784;Route à 1 chaussée;PL DES JACOBINS;PL DES JACOBINS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;4;44109;44109;;;;441094288;441094288;;;;;;;;;;;;;commune;commune;Place des Jacobins;Place des Jacobins;;;44109_4288;44109_4288;;;;;LINESTRING Z (355730.8 6689428.6 9, 355731.1 6689412.4 8.6)
TRONROUT0000000029473532;Route à 1 chaussée;R DE L'EMERY;R DE L'EMERY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;11;2;3;44109;44109;;;;441092760;441092760;;;;;;;;;;;;;commune;commune;Rue de l'Emery;Rue de l'Emery;;;44109_2760;44109_2760;;;;;LINESTRING Z (355643.6 6689426.9 9.6, 355673.6 6689426.4 9.6, 355692.8 6689426.9 9.6, 355706.7 6689428.2 9.8, 355730.8 6689428.6 9)
TRONROUT0000000029474947;Route à 1 chaussée;R DE L'EMERY;R DE L'EMERY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092760;441092760;;;;;;;;;;;;;commune;commune;Rue de l'Emery;Rue de l'Emery;;;44109_2760;44109_2760;;;;;LINESTRING Z (355730.8 6689428.6 9, 355751.2 6689429.2 9.8)
TRONROUT0000000029474672;Route à 1 chaussée;R DE L'UNION;R DE L'UNION;5;Non;0;En service;2006-10-04 09:41:10;2012-02-08 10:00:49;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0D1;44109#0D1;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355786.9 6689431.1 10.3, 355770.8 6689428 10.3, 355751.2 6689429.2 9.8)
TRONROUT0000000029473975;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;16;13;12;11;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355724.5 6689482.1 10.2, 355751.2 6689429.2 9.8)
TRONROUT0000000295265271;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2013-11-15 09:02:56;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355998.9 6689469.3 7, 355995.3 6689463.3 7, 355990.6 6689458.7 7.2, 355985.6 6689454.3 7.2, 355978.4 6689449.9 7.5, 355967.7 6689444.2 7.7, 355964 6689441.4 7.8, 355962.2 6689436.8 7.8, 355960.8 6689426.8 7.8, 355959.8 6689417.2 7.8)
TRONROUT0000000329622505;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355992.9 6689438.4 8, 356000.8 6689456.2 8.3, 356004.2 6689467.6 8.2)
TRONROUT0000002011475909;Sentier;;;6;Non;0;En service;2018-06-11 11:56:08;2020-02-12 17:33:37;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356071.6 6689465.9 9.8, 356040.4 6689449.1 9.8)
TRONROUT0000000327841960;Sentier;;;6;Non;0;En service;2013-09-27 10:55:15;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355992.9 6689438.4 -1000, 356011.8 6689450.4 -1000, 356047.1 6689469.9 -1000, 356067.8 6689482.8 -1000)
TRONROUT0000000329622506;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355820.2 6689381.2 5, 355819 6689383.7 4.7, 355814.9 6689391.2 4.7, 355808 6689402.8 4.7, 355807.9 6689403.1 4.7, 355802.1 6689413.4 4.7, 355798.5 6689421.3 4.9, 355795.3 6689430.8 4.9, 355794.1 6689441.8 4.9, 355795.2 6689452.6 4.9, 355798.6 6689464 4.9, 355802.5 6689474.3 4.8, 355806.8 6689482.5 4.8, 355812.2 6689490.6 4.6, 355819 6689503.3 4.6, 355825.4 6689516.1 4.9, 355831.7 6689527.4 5.1, 355835.6 6689532.2 5.1, 355842.5 6689537.2 5, 355850.3 6689540.1 5, 355860.8 6689542.4 5.1, 355877.3 6689543.8 5.3, 355890.3 6689545 5.3, 355896.8 6689546.6 5.3, 355904.7 6689549.4 5.2, 355910.8 6689551 5.2, 355916.6 6689551.3 5.2, 355920.8 6689549.9 5.2, 355923.4 6689547 5.2, 355924.8 6689543 5.2, 355925.1 6689537.5 5.2, 355924 6689530.2 5.4, 355924 6689527.7 5.4, 355927.1 6689524.7 5.4, 355934.3 6689522.8 5.8, 355944.3 6689520.5 5.9, 355963.1 6689516.6 5.9, 355979.5 6689514.1 6.3, 355989.1 6689511.2 6.3, 355993 6689508.2 6.3, 356001.7 6689489 6.6, 356002.4 6689482.7 6.6, 356001.2 6689476.3 6.9, 355999.1 6689469.8 7.1, 355998.9 6689469.3 7)
TRONROUT0000000329622504;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355998.9 6689469.3 7, 356004.2 6689467.6 8.2)
TRONROUT0000000295265401;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-09-27 15:33:05;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355882.4 6689465.5 10.2, 355896.7 6689472.3 10.2, 355909 6689480.2 10.1, 355915.5 6689484.7 9.8, 355922.1 6689493.5 9.3, 355925.6 6689498.4 8.9, 355928.5 6689507.9 9.4)
TRONROUT0000000295265506;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356013.2 6689517.9 10, 356020.9 6689501 9.8, 356027 6689487.9 9.6, 356031.1 6689479 9.6, 356032.7 6689476.9 9.6, 356034.7 6689476.8 9.6, 356038.8 6689478.7 9.6, 356044.1 6689481.2 9.6, 356045.4 6689483 9.7, 356045.3 6689484.3 9.7, 356041.7 6689492.8 10.1, 356035.1 6689506.6 9.9, 356025.8 6689523.8 9.8)
TRONROUT0000000327842450;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2013-09-27 10:56:18;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;;;;;;;;;;;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356044.7 6689528.3 9.2, 356048.1 6689522 9.2, 356056 6689507.6 9.2, 356061.3 6689496.9 9.2, 356065 6689489 9.5, 356067.8 6689482.8 9.6)
TRONROUT0000000107837497;Sentier;;;6;Non;0;En service;2007-12-03 22:15:03;2019-10-23 21:08:52;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356004.2 6689467.6 8.2, 356008.5 6689481.9 8.1, 355983.5 6689538.8 8, 355981.2 6689546.2 8.8, 355980.2 6689549.5 10.4)
TRONROUT0000000321100659;Route à 1 chaussée;R DU CHATEAU;R DU CHATEAU;5;Non;0;En service;2013-04-17 17:20:14;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;16;23;10;11;44109;44109;;;;441091784;441091784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Château;Rue du Château;;;44109_1784;44109_1784;;;;;LINESTRING Z (355627.1 6689470.2 10.2, 355642.1 6689472.8 10.2, 355669.9 6689475.4 10.2, 355704.7 6689479.6 10.2)
TRONROUT0000000029473993;Route à 1 chaussée;R DU CHATEAU;R DU CHATEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091784;441091784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Château;Rue du Château;;;44109_1784;44109_1784;;;;;LINESTRING Z (355704.7 6689479.6 10.2, 355724.5 6689482.1 10.2)
TRONROUT0000000321100660;Route à 1 chaussée;R DU CHATEAU;R DU CHATEAU;5;Non;0;En service;2013-04-17 17:20:14;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091784;441091784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Château;Rue du Château;;;44109_1784;44109_1784;;;;;LINESTRING Z (355742.4 6689483.7 10.5, 355724.5 6689482.1 10.2)
TRONROUT0000000029473691;Route à 1 chaussée;R DU CHATEAU;R DU CHATEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;3;2B;1;44109;44109;;;;441091784;441091784;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue du Château;Rue du Château;;;44109_1784;44109_1784;;;;;LINESTRING Z (355742.4 6689483.7 10.5, 355781.2 6689488 11.3, 355791 6689487.2 11.3, 355793.7 6689486.6 11.3)
TRONROUT0000000029474016;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355720 6689491 11.7, 355724.5 6689482.1 10.2)
TRONROUT0000000029475295;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355720 6689491 11.7, 355721.4 6689511.6 11.8)
TRONROUT0000000029474041;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;15B;;15;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355700.2 6689529.7 12.3, 355720 6689491 11.7)
TRONROUT0000000029474049;Route à 1 chaussée;R DES CARMELITES;R DES CARMELITES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;2;;12;44109;44109;;;;441091436;441091436;;;;;;;;;;;;;commune;commune;Rue des Carmélites;Rue des Carmélites;;;44109_1436;44109_1436;;;;;LINESTRING Z (355721.4 6689511.6 11.8, 355724 6689532 11.8)
TRONROUT0000000029473995;Route à 1 chaussée;R DES CARMELITES;R DES CARMELITES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;15;;13;;44109;44109;;;;441091436;441091436;;;;;;;;;;;;;commune;commune;Rue des Carmélites;Rue des Carmélites;;;44109_1436;44109_1436;;;;;LINESTRING Z (355724 6689532 11.8, 355714.4 6689531.2 12.3, 355700.2 6689529.7 12.3)
TRONROUT0000000322228671;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2013-05-21 12:16:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;38;37;14;25;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355620.9 6689492.2 11.4, 355665.5 6689571.4 12.8)
TRONROUT0000000029475206;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-01-10 17:06:11;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355413.8 6689292.4 6.4, 355408.1 6689288.6 6.5)
TRONROUT0000000029473999;Route à 1 chaussée;R DE LA PAIX;R DE LA PAIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;9;6;44109;44109;;;;441096112;441096112;;;;;;;;;;;;;commune;commune;Rue de la Paix;Rue de la Paix;;;44109_6112;44109_6112;;;;;LINESTRING Z (355512.6 6689271.3 7.9, 355492 6689324.4 7.8)
TRONROUT0000000029473683;Route à 1 chaussée;R DU VIEIL HOPITAL;R DU VIEIL HOPITAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;;9;;44109;44109;;;;441098436;441098436;;;;;;;;;;;;;commune;commune;Rue du Vieil Hôpital;Rue du Vieil Hôpital;;;44109_8436;44109_8436;;;;;LINESTRING Z (355436.4 6689312 6.5, 355428.3 6689302.8 6.4, 355417.7 6689294.6 6.4, 355413.8 6689292.4 6.4)
TRONROUT0000000200678090;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2008-07-03 11:38:52;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355408.1 6689288.6 6.5, 355389.5 6689324.2 6.2)
TRONROUT0000000029475251;Route à 1 chaussée;ALL JEAN BART;ALL JEAN BART;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441094412;441094412;;;;;;;;;;;;;commune;commune;Allée Jean Bart;Allée Jean Bart;;;44109_4412;44109_4412;;;;;LINESTRING Z (355395.3 6689327.4 6, 355403.4 6689313.5 6.1, 355413.8 6689292.4 6.4)
TRONROUT0000000296813292;Route à 1 chaussée;R DU VIEIL HOPITAL;R DU VIEIL HOPITAL;5;Non;0;En service;2012-03-08 14:25:03;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;8;44109;44109;;;;441098436;441098436;;;;;;;;;;;;;commune;commune;Rue du Vieil Hôpital;Rue du Vieil Hôpital;;;44109_8436;44109_8436;;;;;LINESTRING Z (355467.1 6689317.9 7, 355436.4 6689312 6.5)
TRONROUT0000000296813291;Route à 1 chaussée;PL ALBERT ATHIMON;PL ALBERT ATHIMON;5;Non;0;En service;2012-03-08 14:25:03;2017-11-03 18:51:56;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090075;441090075;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355436.4 6689312 6.5, 355433.8 6689319 6.5)
TRONROUT0000000029474114;Route à 1 chaussée;R DU VIEIL HOPITAL;R DU VIEIL HOPITAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;5;2;5;44109;44109;;;;441098436;441098436;;;;;;;;;;;;;commune;commune;Rue du Vieil Hôpital;Rue du Vieil Hôpital;;;44109_8436;44109_8436;;;;;LINESTRING Z (355467.1 6689317.9 7, 355492 6689324.4 7.8)
TRONROUT0000000029475022;Route à 1 chaussée;R BEAUREGARD;R BEAUREGARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;17;16;17;16;44109;44109;;;;441090652;441090652;;;;;;;;;;;;;commune;commune;Rue Beauregard;Rue Beauregard;;;44109_0652;44109_0652;;;;;LINESTRING Z (355411.8 6689334.8 6.3, 355401.1 6689330.6 6.1, 355395.3 6689327.4 6)
TRONROUT0000000029474388;Route à 1 chaussée;R DU BOUFFAY;R DU BOUFFAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441091093;441091093;;;;;;;;;;;;;commune;commune;Rue du Bouffay;Rue du Bouffay;;;44109_1093;44109_1093;;;;;LINESTRING Z (355511.6 6689339.7 9.4, 355511.8 6689337.4 10.2, 355501.1 6689330.3 10.2, 355492 6689324.4 8.7)
TRONROUT0000000321100661;Sentier;COUR DE VERSAILLES;COUR DE VERSAILLES;6;Non;0;En service;2013-04-17 17:20:18;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0OL;44109#0OL;;;;;;;;;;;;;commune;commune;Cour de Versailles;Cour de Versailles;;;44109_b063;44109_b063;;;;;LINESTRING Z (355354.7 6689337 6.8, 355345 6689331.4 6.9, 355324.4 6689322.7 7, 355322.3 6689317.7 7.1, 355319.1 6689314.2 7.2, 355316.2 6689310.1 7.3, 355307.6 6689304.2 7.5)
TRONROUT0000000029475248;Route à 1 chaussée;R BEAUREGARD;R BEAUREGARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090652;441090652;;;;;;;;;;;;;commune;commune;Rue Beauregard;Rue Beauregard;;;44109_0652;44109_0652;;;;;LINESTRING Z (355395.3 6689327.4 6, 355389.5 6689324.2 6.2)
TRONROUT0000000029473945;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;4;11;16;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355335.5 6689343.5 7.3, 355324.6 6689338.7 7.3, 355279.3 6689318.9 7.6)
TRONROUT0000000029474358;Route à 1 chaussée;ALL JEAN BART;ALL JEAN BART;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;;4;;44109;44109;;;;441094412;441094412;;;;;;;;;;;;;commune;commune;Allée Jean Bart;Allée Jean Bart;;;44109_4412;44109_4412;;;;;LINESTRING Z (355380.7 6689355.9 6.6, 355390.1 6689337.4 6.6, 355395.3 6689327.4 6)
TRONROUT0000000029474922;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355389.5 6689324.2 6.2, 355378.3 6689345.2 6.7, 355371.5 6689361.3 6.8)
TRONROUT0000000029475028;Route à 1 chaussée;ALL CASSARD;ALL CASSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091488;441091488;;;;;;;;;;;;;commune;commune;Allée Cassard;Allée Cassard;;;44109_1488;44109_1488;;;;;LINESTRING Z (355354.7 6689337 6.8, 355352.3 6689341.6 6.8, 355348.2 6689349.3 7.2)
TRONROUT0000000029473766;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355335.5 6689343.5 7.3, 355348.2 6689349.3 7.2)
TRONROUT0000000317258108;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355365 6689358 7, 355355.1 6689353.1 7.1, 355348.2 6689349.3 7.2)
TRONROUT0000000029475262;Route à 1 chaussée;R DU BOIS TORTU;R DU BOIS TORTU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441090988;441090988;;;;;;;;;;;;;commune;commune;Rue du Bois Tortu;Rue du Bois Tortu;;;44109_0988;44109_0988;;;;;LINESTRING Z (355335.5 6689343.5 7.3, 355323.2 6689368.6 7.4, 355315.1 6689370 7.2, 355305.2 6689371.7 7)
TRONROUT0000000317258151;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355365 6689358 7, 355367.9 6689359.4 7)
TRONROUT0000000029474079;Route à 1 chaussée;R DE LA BLETERIE;R DE LA BLETERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;9;;11;;44109;44109;;;;441090888;441090888;;;;;;;;;;;;;commune;commune;Rue de la Bléterie;Rue de la Bléterie;;;44109_0888;44109_0888;;;;;LINESTRING Z (355467.1 6689317.9 7, 355458.9 6689352.9 7.3)
TRONROUT0000000029475209;Route à 1 chaussée;R DE LA PAIX;R DE LA PAIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;13;10;19;44109;44109;;;;441096112;441096112;;;;;;;;;;;;;commune;commune;Rue de la Paix;Rue de la Paix;;;44109_6112;44109_6112;;;;;LINESTRING Z (355478.3 6689359.6 7.8, 355492 6689324.4 7.8)
TRONROUT0000000029473980;Route à 1 chaussée;R BEAUREGARD;R BEAUREGARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;6;17;16;44109;44109;;;;441090652;441090652;;;;;;;;;;;;;commune;commune;Rue Beauregard;Rue Beauregard;;;44109_0652;44109_0652;;;;;LINESTRING Z (355458.9 6689352.9 7.3, 355411.8 6689334.8 6.3)
TRONROUT0000000029474953;Route à 1 chaussée;R BEAUREGARD;R BEAUREGARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441090652;441090652;;;;;;;;;;;;;commune;commune;Rue Beauregard;Rue Beauregard;;;44109_0652;44109_0652;;;;;LINESTRING Z (355478.3 6689359.6 7.8, 355458.9 6689352.9 7.3)
TRONROUT0000000029474819;Route à 1 chaussée;R BEAUREGARD;R BEAUREGARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441090652;441090652;;;;;;;;;;;;;commune;commune;Rue Beauregard;Rue Beauregard;;;44109_0652;44109_0652;;;;;LINESTRING Z (355496.9 6689378.4 9, 355478.3 6689359.6 7.8)
TRONROUT0000000029473513;Route à 1 chaussée;R DE LA BARILLERIE;R DE LA BARILLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090552;441090552;;;;;;;;;;;;;commune;commune;Rue de la Barillerie;Rue de la Barillerie;;;44109_0552;44109_0552;;;;;LINESTRING Z (355429.7 6689387.5 6, 355377.1 6689364 6.6)
TRONROUT0000000029474580;Route à 1 chaussée;R DE LA BLETERIE;R DE LA BLETERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;17;16;21;18;44109;44109;;;;441090888;441090888;;;;;;;;;;;;;commune;commune;Rue de la Bléterie;Rue de la Bléterie;;;44109_0888;44109_0888;;;;;LINESTRING Z (355458.9 6689352.9 7.3, 355451.3 6689398.7 7.2)
TRONROUT0000000029473907;Route à 1 chaussée;R DE LA PAIX;R DE LA PAIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;21;14;25;20;44109;44109;;;;441096112;441096112;;;;;;;;;;;;;commune;commune;Rue de la Paix;Rue de la Paix;;;44109_6112;44109_6112;;;;;LINESTRING Z (355478.3 6689359.6 7.8, 355467.3 6689387.9 7.6, 355462 6689404.2 7.6)
TRONROUT0000000332292564;Route à 1 chaussée;R BELLE IMAGE;R BELLE IMAGE;5;Non;0;En service;2014-02-27 11:47:02;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090724;441090724;;;;;;;;;;;;;commune;commune;Rue Belle Image;Rue Belle Image;;;44109_0724;44109_0724;;;;;LINESTRING Z (355502.1 6689391.7 9.7, 355509 6689374.5 9.5)
TRONROUT0000000029474070;Route à 1 chaussée;PL SAINTE-CROIX;PL SAINTE-CROIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;3;2;44109;44109;;;;441097580;441097580;;;;;;;;;;;;;commune;commune;Place Sainte Croix;Place Sainte Croix;;;44109_7580;44109_7580;;;;;LINESTRING Z (355502.1 6689391.7 9.7, 355496.9 6689378.4 9)
TRONROUT0000000029473838;Route à 1 chaussée;R DE LA BACLERIE;R DE LA BACLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441090508;441090508;;;;;;;;;;;;;commune;commune;Rue de la Baclerie;Rue de la Baclerie;;;44109_0508;44109_0508;;;;;LINESTRING Z (355595.5 6689352.7 7.8, 355602.5 6689344 9.7)
TRONROUT0000000029474510;Route à 1 chaussée;R DES ECHEVINS;R DES ECHEVINS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;2;;44109;44109;;;;441092676;441092676;;;;;;;;;;;;;commune;commune;Rue des Echevins;Rue des Echevins;;;44109_2676;44109_2676;;;;;LINESTRING Z (355602.5 6689344 9.7, 355611.4 6689349.2 7.9, 355620.6 6689352.9 7.9)
TRONROUT0000000029475273;Route à 1 chaussée;R BELLE IMAGE;R BELLE IMAGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;3;2;1;44109;44109;;;;441090724;441090724;;;;;;;;;;;;;commune;commune;Rue Belle Image;Rue Belle Image;;;44109_0724;44109_0724;;;;;LINESTRING Z (355509 6689374.5 9.5, 355511.6 6689339.7 9.4)
TRONROUT0000000029473460;Sentier;R DU PETIT BACCHUS;R DU PETIT BACCHUS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;14;;14;;44109;44109;;;;441096396;441096396;;;;;;;;;;;;;commune;commune;Rue du Petit Bacchus;Rue du Petit Bacchus;;;44109_6396;44109_6396;;;;;LINESTRING Z (355595.5 6689352.7 7.8, 355616.7 6689362.7 7.9)
TRONROUT0000000029475006;Route empierrée;R DU PETIT BACCHUS;R DU PETIT BACCHUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;12;;12;44109;44109;;;;441096396;441096396;;;;;;;;;;;;;commune;commune;Rue du Petit Bacchus;Rue du Petit Bacchus;;;44109_6396;44109_6396;;;;;LINESTRING Z (355620.6 6689352.9 7.9, 355616.7 6689362.7 7.9)
TRONROUT0000000029474120;Route à 1 chaussée;R DES ECHEVINS;R DES ECHEVINS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;3;6;1;44109;44109;;;;441092676;441092676;;;;;;;;;;;;;commune;commune;Rue des Echevins;Rue des Echevins;;;44109_2676;44109_2676;;;;;LINESTRING Z (355620.6 6689352.9 7.9, 355631 6689357.3 7.9, 355650.5 6689362.8 7.9)
TRONROUT0000000029473819;Route à 1 chaussée;R DE LA BACLERIE;R DE LA BACLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;16;5;4;3;44109;44109;;;;441090508;441090508;;;;;;;;;;;;;commune;commune;Rue de la Baclerie;Rue de la Baclerie;;;44109_0508;44109_0508;;;;;LINESTRING Z (355556.5 6689395.2 9.7, 355573.3 6689377.9 9.7, 355595.5 6689352.7 7.8)
TRONROUT0000000029474893;Route empierrée;R DU PETIT BACCHUS;R DU PETIT BACCHUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096396;441096396;;;;;;;;;;;;;commune;commune;Rue du Petit Bacchus;Rue du Petit Bacchus;;;44109_6396;44109_6396;;;;;LINESTRING Z (355616.7 6689362.7 7.9, 355615.1 6689366.9 7.9, 355608.5 6689385.4 7.9)
TRONROUT0000000332292563;Sentier;JARD SAINTE-CROIX;JARD SAINTE-CROIX;6;Non;0;En service;2014-02-27 11:47:02;2019-03-01 22:00:01;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355509 6689374.5 -1000, 355545.2 6689375.7 -1000)
TRONROUT0000000029473695;Route à 1 chaussée;R DE LA JUIVERIE;R DE LA JUIVERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;22;21;20;21;44109;44109;;;;441094604;441094604;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Juiverie;Rue de la Juiverie;;;44109_4604;44109_4604;;;;;LINESTRING Z (355556.5 6689395.2 9.7, 355568.7 6689400.9 9.7)
TRONROUT0000000317258104;Route à 1 chaussée;ALL JEAN BART;ALL JEAN BART;6;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441094412;441094412;;;;;;;;;;;;;commune;commune;Allée Jean Bart;Allée Jean Bart;;;44109_4412;44109_4412;;;;;LINESTRING Z (355377.1 6689364 6.6, 355380.7 6689355.9 6.6)
TRONROUT0000000029473933;Route à 1 chaussée;R D'ORLEANS;R D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096060;441096060;;;;;;;;;;;;;commune;commune;Rue d'Orléans;Rue d'Orléans;;;44109_6060;44109_6060;;;;;LINESTRING Z (355367.9 6689359.4 7, 355371.5 6689361.3 6.8)
TRONROUT0000000029474299;Route à 1 chaussée;R DE LA BARILLERIE;R DE LA BARILLERIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441090552;441090552;;;;;;;;;;;;;commune;commune;Rue de la Barillerie;Rue de la Barillerie;;;44109_0552;44109_0552;;;;;LINESTRING Z (355371.5 6689361.3 6.8, 355377.1 6689364 6.6)
TRONROUT0000000029473789;Route à 1 chaussée;ALL D'ORLEANS;ALL D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;2;;44109;44109;;;;441096052;441096052;;;;;;;;;;;;;commune;commune;Allée d'Orléans;Allée d'Orléans;;;44109_6052;44109_6052;;;;;LINESTRING Z (355348.2 6689349.3 7.2, 355345.1 6689356.8 7.2, 355342 6689372.4 7.2, 355339 6689389.4 6.9)
TRONROUT0000000029473740;Route à 1 chaussée;ALL PENTHIEVRE;ALL PENTHIEVRE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441096324;441096324;;;;;;;;;;;;;commune;commune;Allée Penthiévre;Allée Penthiévre;;;44109_6324;44109_6324;;;;;LINESTRING Z (355372.9 6689386.7 6.5, 355375.4 6689373.8 6.6, 355377.1 6689364 6.6)
TRONROUT0000000029473776;Route à 1 chaussée;PL FERNAND SOIL;PL FERNAND SOIL;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 20:43:48;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;4;;6;44109;44109;;;;44109#08K;44109#08K;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355310.6 6689388.1 6.7, 355308.8 6689379.1 6.7, 355305.2 6689371.7 7)
TRONROUT0000000029475267;Route à 1 chaussée;R BASSE CASSERIE;R BASSE CASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C5;44109#0C5;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355310.6 6689388.1 6.7, 355339 6689389.4 6.9)
TRONROUT0000000029474778;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355371.5 6689361.3 6.8, 355368.7 6689370.2 7.1, 355362.4 6689394.9 6.9, 355351.6 6689439.8 6.7, 355349.6 6689451.5 6.8)
TRONROUT0000000029473702;Route à 1 chaussée;R DE LA CLAVURERIE;R DE LA CLAVURERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;9;2;5;44109;44109;;;;441091954;441091954;;;;;;;;;;;;;commune;commune;Rue de la Clavurerie;Rue de la Clavurerie;;;44109_1954;44109_1954;;;;;LINESTRING Z (355306.1 6689434.6 7, 355311.2 6689395 6.7, 355310.6 6689388.1 6.7)
TRONROUT0000000029475289;Route à 1 chaussée;ALL D'ORLEANS;ALL D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;9;;44109;44109;;;;441096052;441096052;;;;;;;;;;;;;commune;commune;Allée d'Orléans;Allée d'Orléans;;;44109_6052;44109_6052;;;;;LINESTRING Z (355339 6689389.4 6.9, 355334.1 6689410.8 6.9, 355329.7 6689437.4 7)
TRONROUT0000000029474588;Route à 1 chaussée;R HAUTE CASSERIE;R HAUTE CASSERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441094052;441094052;;;;;;;;;;;;;commune;commune;Rue de la Haute Casserie;Rue de la Haute Casserie;;;44109_4052;44109_4052;;;;;LINESTRING Z (355429.7 6689387.5 6, 355393.5 6689387.9 6.6, 355378.6 6689387.8 6.9, 355372.9 6689386.7 6.5)
TRONROUT0000000029473909;Route à 1 chaussée;R DE LA BARILLERIE;R DE LA BARILLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;6;9;12;44109;44109;;;;441090552;441090552;;;;;;;;;;;;;commune;commune;Rue de la Barillerie;Rue de la Barillerie;;;44109_0552;44109_0552;;;;;LINESTRING Z (355451.3 6689398.7 7.2, 355429.7 6689387.5 6)
TRONROUT0000000029473896;Route à 1 chaussée;PL SAINTE-CROIX;PL SAINTE-CROIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;1;4;1;44109;44109;;;;441097580;441097580;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Sainte Croix;Place Sainte Croix;;;44109_7580;44109_7580;;;;;LINESTRING Z (355507.1 6689401.4 9.8, 355502.1 6689391.7 9.7)
TRONROUT0000000029475263;Route à 1 chaussée;R TRAVERS;R TRAVERS;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0A6;44109#0A6;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355502.1 6689391.7 9.7, 355483.7 6689404.7 9.3, 355480.8 6689406.3 9.2, 355473.8 6689410.1 9)
TRONROUT0000000029474109;Route à 1 chaussée;R DE LA BARILLERIE;R DE LA BARILLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;3;4;44109;44109;;;;441090552;441090552;;;;;;;;;;;;;commune;commune;Rue de la Barillerie;Rue de la Barillerie;;;44109_0552;44109_0552;;;;;LINESTRING Z (355462 6689404.2 7.6, 355451.3 6689398.7 7.2)
TRONROUT0000000029474700;Route à 1 chaussée;R DE LA MARNE;R DE LA MARNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;28;;28;44109;44109;;;;441095408;441095408;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Marne;Rue de la Marne;;;44109_5408;44109_5408;;;;;LINESTRING Z (355473.8 6689410.1 9, 355462 6689404.2 7.6)
TRONROUT0000000029475121;Route à 1 chaussée;R DE LA MARNE;R DE LA MARNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;26;25;26;25;44109;44109;;;;441095408;441095408;;;;;;;;;;;;;commune;commune;Rue de la Marne;Rue de la Marne;;;44109_5408;44109_5408;;;;;LINESTRING Z (355473.8 6689410.1 9, 355501.6 6689424.1 8.8)
TRONROUT0000000029474005;Route à 1 chaussée;PL DU CHANGE;PL DU CHANGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;5;1;6;44109;44109;;;;441091596;441091596;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place du Change;Place du Change;;;44109_1596;44109_1596;;;;;LINESTRING Z (355454.7 6689431.4 7.6, 355460.9 6689408.2 7.6, 355462 6689404.2 7.6)
TRONROUT0000000029474840;Route à 1 chaussée;R DE LA MARNE;R DE LA MARNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441095408;441095408;;;;;;;;;;;;;commune;commune;Rue de la Marne;Rue de la Marne;;;44109_5408;44109_5408;;;;;LINESTRING Z (355501.6 6689424.1 9, 355504.3 6689425.4 10.2)
TRONROUT0000000029474131;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;3;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355501.4 6689430.8 8.7, 355501.6 6689424.1 8.8)
TRONROUT0000000317258106;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355338.7 6689474.8 9.4, 355339.5 6689467.8 8.8, 355358 6689381 8.2, 355361.6 6689366 7.6, 355365 6689358 7)
TRONROUT0000000317258150;Route à 1 chaussée;;;6;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355342.3 6689474.5 8.1, 355352.1 6689425.4 7.7, 355362.1 6689377.3 7.3, 355367.9 6689359.4 7)
TRONROUT0000000029473558;Route à 1 chaussée;ALL PENTHIEVRE;ALL PENTHIEVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;2;;44109;44109;;;;441096324;441096324;;;;;;;;;;;;;commune;commune;Allée Penthiévre;Allée Penthiévre;;;44109_6324;44109_6324;;;;;LINESTRING Z (355359.3 6689448.8 6.7, 355361.5 6689435.2 6.7, 355364.5 6689420.4 6.7, 355367.8 6689406.6 6.4, 355371.2 6689394.5 6.4, 355372.9 6689386.7 6.5)
TRONROUT0000000029474790;Route à 1 chaussée;R DU PRE NIAN;R DU PRE NIAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;1;44109;44109;;;;441096948;441096948;;;;;;;;;;;;;commune;commune;Rue du Pré Nian;Rue du Pré Nian;;;44109_6948;44109_6948;;;;;LINESTRING Z (355306.1 6689434.6 7, 355329.7 6689437.4 7)
TRONROUT0000000317258092;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;Levé non GPS;5.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355359.3 6689448.8 6.7, 355349.6 6689451.5 6.8)
TRONROUT0000000029473565;Route à 1 chaussée;R DE LA CLAVURERIE;R DE LA CLAVURERIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;13;;11B;44109;44109;;;;441091954;441091954;;;;;;;;;;;;;commune;commune;Rue de la Clavurerie;Rue de la Clavurerie;;;44109_1954;44109_1954;;;;;LINESTRING Z (355306.1 6689434.6 7, 355301.8 6689478.1 8.6)
TRONROUT0000000029473960;Route à 1 chaussée;ALL D'ORLEANS;ALL D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10;;10;;44109;44109;;;;441096052;441096052;;;;;;;;;;;;;commune;commune;Allée d'Orléans;Allée d'Orléans;;;44109_6052;44109_6052;;;;;LINESTRING Z (355329.7 6689437.4 7, 355325 6689463 7.6, 355322.9 6689472.6 8.1, 355321.3 6689480.1 8.1)
TRONROUT0000000029474542;Route à 1 chaussée;ALL PENTHIEVRE;ALL PENTHIEVRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441096324;441096324;;;;;;;;;;;;;commune;commune;Allée Penthiévre;Allée Penthiévre;;;44109_6324;44109_6324;;;;;LINESTRING Z (355356.7 6689474.3 7, 355358.2 6689461 6.9, 355359.3 6689448.8 6.7)
TRONROUT0000000317258093;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355349.6 6689451.5 6.8, 355345.7 6689476 6.9)
TRONROUT0000000317258154;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355338.7 6689474.8 9.4, 355342.3 6689474.5 8.1)
TRONROUT0000000029473725;Route à 1 chaussée;R SAINTE-CROIX;R SAINTE-CROIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;1;11;1;44109;44109;;;;441097584;441097584;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Sainte Croix;Rue Sainte Croix;;;44109_7584;44109_7584;;;;;LINESTRING Z (355507.1 6689401.4 9.8, 355531.5 6689403.4 9.8, 355538.8 6689402.7 9.8, 355545.2 6689401 9.7, 355554.4 6689397.4 9.7, 355556.5 6689395.2 9.7)
TRONROUT0000000029474754;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-09-27 15:32:54;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355504.3 6689425.4 10.2, 355507.1 6689401.4 9.8)
TRONROUT0000000029473868;Route à 1 chaussée;R DE LA JUIVERIE;R DE LA JUIVERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;18;19;2;1;44109;44109;;;;441094604;441094604;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de la Juiverie;Rue de la Juiverie;;;44109_4604;44109_4604;;;;;LINESTRING Z (355568.7 6689400.9 9.7, 355643.6 6689426.9 10)
TRONROUT0000000029474425;Sentier;PAS BOUCHAUD;PAS BOUCHAUD;6;Non;0;En service;2006-10-04 09:41:10;2012-09-27 15:32:54;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C0;44109#0C0;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355549.5 6689446.9 -1000, 355555.6 6689428.5 -1000, 355560.9 6689423.2 -1000, 355565.5 6689410.6 -1000, 355568.7 6689400.9 9.7)
TRONROUT0000000029473780;Route à 1 chaussée;R DE LA MARNE;R DE LA MARNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;11;12;23;24;44109;44109;;;;441095408;441095408;;;;;;;;;;;;;commune;commune;Rue de la Marne;Rue de la Marne;;;44109_5408;44109_5408;;;;;LINESTRING Z (355549.5 6689446.9 10, 355504.3 6689425.4 10.2)
TRONROUT0000000029474243;Route à 1 chaussée;R DES CHAPELIERS;R DES CHAPELIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;5;6;44109;44109;;;;441091652;441091652;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Chapeliers;Rue des Chapeliers;;;44109_1652;44109_1652;;;;;LINESTRING Z (355643.6 6689426.9 9.6, 355633.4 6689456.6 10, 355631 6689461.7 10.1)
TRONROUT0000000029474515;Route à 1 chaussée;R DE LA MARNE;R DE LA MARNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;9;10;44109;44109;;;;441095408;441095408;;;;;;;;;;;;;commune;commune;Rue de la Marne;Rue de la Marne;;;44109_5408;44109_5408;;;;;LINESTRING Z (355580.6 6689461.7 9.9, 355549.5 6689446.9 10)
TRONROUT0000000029474006;Route à 1 chaussée;PL DU PILORI;PL DU PILORI;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;15;;9;;44109;44109;;;;441096628;441096628;;;;;;;;;;;;;commune;commune;Place du Pilori;Place du Pilori;;;44109_6628;44109_6628;;;;;LINESTRING Z (355627.1 6689470.2 10.2, 355580.6 6689461.7 9.9)
TRONROUT0000000029473747;Route à 1 chaussée;R DES CHAPELIERS;R DES CHAPELIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091652;441091652;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Chapeliers;Rue des Chapeliers;;;44109_1652;44109_1652;;;;;LINESTRING Z (355631 6689461.7 10.1, 355627.1 6689470.2 10.2)
TRONROUT0000000029474018;Route à 1 chaussée;PL DU PILORI;PL DU PILORI;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;3;;6;44109;44109;;;;441096628;441096628;;;;;;;;;;;;;commune;commune;Place du Pilori;Place du Pilori;;;44109_6628;44109_6628;;;;;LINESTRING Z (355618.3 6689489 10, 355611.6 6689481.1 10, 355600.4 6689471.4 10, 355580.6 6689461.7 9.9)
TRONROUT0000000029473923;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355342.3 6689474.5 8.1, 355345.7 6689476 6.9)
TRONROUT0000000317258107;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355334.3 6689480.2 9.5, 355335.2 6689477.3 9.4, 355338.7 6689474.8 9.4)
TRONROUT0000000029474484;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441093092;441093092;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355321.3 6689480.1 8.1, 355311.3 6689478.8 8.2, 355301.8 6689478.1 8.6)
TRONROUT0000000029475098;Route à 1 chaussée;R DE FELTRE;R DE FELTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441093092;441093092;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue de Feltre;Rue de Feltre;;;44109_3092;44109_3092;;;;;LINESTRING Z (355334.3 6689480.2 7.2, 355327.5 6689480.4 7.6, 355321.3 6689480.1 8.1)
TRONROUT0000000029475045;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;ITI_AUT_0000002285710202;;;;;;Ev1 : la Vélodyssée;;Sentier de découverte;Voyage à Nantes;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355345.7 6689476 6.9, 355348.4 6689496.2 10.1)
TRONROUT0000000029475040;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355336.1 6689494.1 10, 355334.4 6689490.5 10.3, 355333.7 6689485 9.5, 355334.3 6689480.2 9.5)
TRONROUT0000000029473771;Route à 1 chaussée;PL DE L'ECLUSE;PL DE L'ECLUSE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092680;441092680;;;;;;;;;;;;;commune;commune;Place de l'Ecluse;Place de l'Ecluse;;;44109_2680;44109_2680;;;;;LINESTRING Z (355364.8 6689503.8 7.1, 355366.6 6689492.1 7.4, 355367.6 6689484.3 7.1, 355368.4 6689479.4 7.1, 355367.9 6689477.2 7.1, 355364.4 6689475.6 7.1, 355356.7 6689474.3 7)
TRONROUT0000000029474286;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355339 6689498.3 10, 355336.1 6689494.1 10)
TRONROUT0000000317258113;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355348.4 6689496.2 10.1, 355346.3 6689498.5 10, 355343 6689499.1 10)
TRONROUT0000000317258152;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355343 6689499.1 10, 355339 6689498.3 10)
TRONROUT0000000029474616;Route à 1 chaussée;R DES HALLES;R DES HALLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;4;19;22;44109;44109;;;;441094020;441094020;;;;;;;;;;;;;commune;commune;Rue des Halles;Rue des Halles;;;44109_4020;44109_4020;;;;;LINESTRING Z (355454.7 6689431.4 7.6, 355434.8 6689432.5 6.2, 355377.7 6689444.9 6.6, 355359.3 6689448.8 6.7)
TRONROUT0000000029473904;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;9;2;1;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355499.6 6689498.4 7.4, 355501.4 6689430.8 8.7)
TRONROUT0000000029473873;Route à 1 chaussée;R DES CARMES;R DES CARMES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;18;25;2;5;44109;44109;;;;441091440;441091440;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Carmes;Rue des Carmes;;;44109_1440;44109_1440;;;;;LINESTRING Z (355432.9 6689532.4 6.3, 355436.6 6689511.3 6.7, 355444.8 6689478.9 6.9, 355454.7 6689431.4 7.6)
TRONROUT0000000029473728;Route à 1 chaussée;R DES BONS FRANCAIS;R DES BONS FRANCAIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;5;2B;1;44109;44109;;;;441091048;441091048;;;;;;;;;;;;;commune;commune;Rue des Bons Français;Rue des Bons Français;;;44109_1048;44109_1048;;;;;LINESTRING Z (355444.6 6689537.4 7.2, 355456 6689528.1 7.5, 355495 6689500.9 8, 355499.6 6689498.4 7.4)
TRONROUT0000000029474014;Route à 1 chaussée;R DES TROIS CROISSANTS;R DES TROIS CROISSANTS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;9;8;3;44109;44109;;;;441098224;441098224;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Trois Croissants;Rue des Trois Croissants;;;44109_8224;44109_8224;;;;;LINESTRING Z (355364.8 6689503.8 7.1, 355384.2 6689511.8 6.1, 355432.9 6689532.4 6.3)
TRONROUT0000000029473553;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;20;19;14;11;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355499 6689558.8 8.5, 355499.2 6689546.9 8.1, 355499.6 6689498.4 7.4)
TRONROUT0000000029474625;Route à 1 chaussée;R DES TROIS CROISSANTS;R DES TROIS CROISSANTS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;6;;6;44109;44109;;;;441098224;441098224;;;;;;;;;;;;;commune;commune;Rue des Trois Croissants;Rue des Trois Croissants;;;44109_8224;44109_8224;;;;;LINESTRING Z (355444.6 6689537.4 7.2, 355432.9 6689532.4 6.3)
TRONROUT0000000029473596;Route à 1 chaussée;R DES TROIS CROISSANTS;R DES TROIS CROISSANTS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;6;1;6;44109;44109;;;;441098224;441098224;;;;;;;;;;;;;commune;commune;Rue des Trois Croissants;Rue des Trois Croissants;;;44109_8224;44109_8224;;;;;LINESTRING Z (355463.4 6689545.3 8.6, 355444.6 6689537.4 7.2)
TRONROUT0000000029473869;Route à 1 chaussée;R DES TROIS CROISSANTS;R DES TROIS CROISSANTS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;2;;4;44109;44109;;;;441098224;441098224;;;;;;;;;;;;;commune;commune;Rue des Trois Croissants;Rue des Trois Croissants;;;44109_8224;44109_8224;;;;;LINESTRING Z (355499 6689558.8 8.5, 355491 6689556.9 8.3, 355463.4 6689545.3 8.6)
TRONROUT0000000029474298;Route à 1 chaussée;R SAINT-LEONARD;R SAINT-LEONARD;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;11;2;1;44109;44109;;;;441097672;441097672;;;;;;;;;;;;;commune;commune;Rue Saint Léonard;Rue Saint Léonard;;;44109_7672;44109_7672;;;;;LINESTRING Z (355432.9 6689532.4 6.3, 355426.2 6689586.3 6.5)
TRONROUT0000000029473829;Route à 1 chaussée;R DES REMORQUEURS;R DES REMORQUEURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;11;2;1;44109;44109;;;;441097192;441097192;;;;;;;;;;;;;commune;commune;Rue des Remorqueurs;Rue des Remorqueurs;;;44109_7192;44109_7192;;;;;LINESTRING Z (356452.7 6689296 7.3, 356506.81139568595 6689326.701501098 7.7605225164762475)
TRONROUT0000002011475891;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;48;;46;;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356403.3 6689338.8 6.7, 356442.3 6689297 6.4)
TRONROUT0000000029473954;Route à 1 chaussée;QU MALAKOFF;QU MALAKOFF;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095252;441095252;ROUTNOMM0000000325297519;;;;;;;la Loire à Vélo;;;;;commune;commune;Quai Malakoff;Quai Malakoff;;;44109_5252;44109_5252;;;;;LINESTRING Z (356403.3 6689338.8 7.8, 356384 6689359.7 7.9)
TRONROUT0000000029470741;Route à 1 chaussée;R DE CORNULIER;R DE CORNULIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;37;;43;;44109;44109;;;;441092184;441092184;;;;;;;;;;;;;commune;commune;Rue de Cornulier;Rue de Cornulier;;;44109_2184;44109_2184;;;;;LINESTRING Z (356506.81139568595 6689374.942883779 8.642745987919684, 356505.7 6689377.7 8.6, 356499.1 6689408.5 8.2)
TRONROUT0000002223016874;Route à 1 chaussée;R DE LOURMEL;R DE LOURMEL;5;Non;0;En service;2021-02-16 14:42:21;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;6.0;Non;Non;Double sens;Double sens;Non;0;Restreint aux ayants droit;Libre;;;;;;;;Non;3;;5;;44109;44109;;;;441098266;441098266;;;;;;;;;;;;;commune;commune;Rue de Lourmel;Rue de Lourmel;;;44109_8266;44109_8266;;;;;LINESTRING Z (356499.1 6689408.5 8.2, 356418.1 6689393.3 8.2, 356364.6 6689381.8 8.1)
TRONROUT0000002322750697;Route à 1 chaussée;;;5;Non;0;En service;2022-11-04 16:09:51;2023-03-16 14:38:43;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;6.0;Non;Non;Double sens;Double sens;Oui;30;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356499.1 6689408.5 8.2, 356506.81139568595 6689409.423195259 -539.3090937069528)
TRONROUT0000000029474384;Sentier;R DE LOURMEL;R DE LOURMEL;6;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;441098266;441098266;;;;;;;;;;;;;commune;commune;Rue de Lourmel;Rue de Lourmel;;;44109_8266;44109_8266;;;;;LINESTRING Z (356494.3 6689430.1 8.2, 356498.9 6689418.5 8.2, 356499.3 6689414.4 8.2, 356499.1 6689408.5 8.2)
TRONROUT0000002220840083;Escalier;;;6;Non;0;En service;2020-12-03 12:02:17;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356428.8 6689428.8 -1000, 356433.8 6689416.7 -1000)
TRONROUT0000002220840086;Sentier;;;6;Non;1;En service;2020-12-03 12:02:17;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356396.9 6689570.8 -1000, 356428.8 6689428.8 -1000)
TRONROUT0000000106929635;Sentier;;;6;Non;-1;En service;2007-11-22 11:54:43;2012-02-13 08:57:14;;;;;Levé non GPS;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356494.3 6689430.1 -1000, 356456 6689609.7 -1000)
TRONROUT0000000214838222;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;3;Non;0;En service;2008-12-19 16:37:00;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356078.9 6689443.6 10.4, 356081.4 6689450.7 9.9, 356086.3 6689458.4 9.6, 356093.2 6689464.9 9.3, 356097.7 6689468 9.3, 356102.1 6689469.6 9.2, 356107.2 6689470 9.2, 356115.5 6689470 9.1)
TRONROUT0000002206013062;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;3;Non;0;En service;2019-12-05 14:02:47;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356115.5 6689470 9.1, 356116.8 6689470.1 9.3, 356123.8 6689469.3 8.9, 356131.1 6689468.6 8.7, 356136.8 6689467.6 8, 356141.4 6689465.9 8, 356146 6689463.1 8.3, 356150.6 6689459.3 8.3, 356151.1 6689459 8.6)
TRONROUT0000002206013052;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356172.5 6689459 7.8, 356173.8 6689460.1 9.2, 356176.4 6689465.8 9.3, 356177.3 6689472 9.3, 356175.9 6689477.4 9.3)
TRONROUT0000002206013063;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356149.2 6689477.6 7.3, 356147.5 6689474.7 9.2, 356146.8 6689468.6 9.1, 356148.4 6689462.6 9.1, 356151.1 6689459 8.6)
TRONROUT0000000325977067;Sentier;;;6;Non;0;En service;2013-09-05 12:56:25;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356115.5 6689470 -1000, 356116.6 6689475.2 -1000)
TRONROUT0000002011476015;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356067.8 6689482.8 9.6, 356069.4 6689478.9 9.6, 356071.1 6689474.1 9.8, 356071.7 6689470.2 9.8, 356071.6 6689465.9 9.8)
TRONROUT0000000294302132;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2012-01-17 12:39:06;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;;;;;;;;;;;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356128 6689473.6 8.8, 356119.3 6689474.7 8.8, 356116.6 6689475.2 8.8)
TRONROUT0000002206013056;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2019-12-05 14:02:47;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;;;;;;;;;;;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356149.2 6689477.6 7.3, 356147.1 6689476.3 5.5, 356141.3 6689473.9 5.4, 356134.6 6689473.4 5.4, 356128 6689473.6 5.5)
TRONROUT0000000329622961;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356116.6 6689475.2 -1000, 356118.5 6689478.7 -1000)
TRONROUT0000000325977068;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2013-09-05 12:56:25;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356116.6 6689475.2 8.8, 356111.6 6689476.1 8.8, 356106.8 6689476.7 9, 356102 6689476.2 9.1, 356097.5 6689474.7 9.3, 356094.1 6689473.7 9.3, 356090.7 6689473.3 9.3, 356086.1 6689474 9.3, 356082.9 6689475.5 9.3, 356078.8 6689478 9.5, 356075.1 6689481.8 9.5, 356072.7 6689485.2 9.6)
TRONROUT0000002206013058;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356152.4 6689481.3 6.3, 356150.6 6689480 9.2, 356149.2 6689477.6 7.3)
TRONROUT0000002206013061;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356175.9 6689477.4 8.7, 356171.5 6689482.5 8.7, 356167.4 6689484.5 8.8)
TRONROUT0000000329622960;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356118.5 6689478.7 -1000, 356110.4 6689479.4 -1000, 356104.3 6689479.4 -1000, 356096.6 6689477.5 -1000, 356092 6689475.8 -1000, 356087.6 6689476.8 -1000, 356081.3 6689489.8 -1000)
TRONROUT0000002206013057;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356164.2 6689485 7.1, 356161 6689484.8 8.9, 356155.5 6689483.5 9, 356152.4 6689481.3 6.3)
TRONROUT0000000327842451;Sentier;;;6;Non;0;En service;2013-09-27 10:56:18;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356067.8 6689482.8 -1000, 356072.7 6689485.2 -1000)
TRONROUT0000002206013054;Rond-point;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Non;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356167.4 6689484.5 8.8, 356164.2 6689485 7.1)
TRONROUT0000000329622959;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356118.5 6689478.7 -1000, 356122.5 6689484.3 -1000, 356127.8 6689489.1 -1000, 356132.7 6689491.3 -1000, 356139.3 6689491.5 -1000)
TRONROUT0000000329622963;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2013-11-15 09:08:43;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;24;;24;;44109;44109;;;;441092048;441092048;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356072.7 6689485.2 9.6, 356081.3 6689489.8 9)
TRONROUT0000002206013059;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;5;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356175.9 6689477.4 9.3, 356177.2 6689484.7 9.3, 356180.1 6689490.5 9.1, 356184.1 6689495.9 9, 356188.4 6689501.3 8.9)
TRONROUT0000002206013060;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;5;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356188.4 6689501.3 8.3, 356175 6689489.9 8.6, 356167.4 6689484.5 8.7)
TRONROUT0000000029474991;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;23;;22;;44109;44109;;;;441092048;441092048;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356081.3 6689489.8 9, 356109 6689504.7 7.3)
TRONROUT0000002206013055;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356176.3 6689520.4 4.9, 356165 6689511.8 4.9, 356157.8 6689504.2 4.9, 356155 6689498.4 5, 356153.6 6689492.4 5.2, 356152.9 6689486.2 5.3, 356152.4 6689481.3 6.3)
TRONROUT0000000029474857;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356072.7 6689485.2 9.5, 356066.6 6689496.3 9, 356060.3 6689509 8.6, 356054.1 6689522.6 8.7, 356051.6 6689527.6 9, 356049 6689530.7 8.9)
TRONROUT0000002206013053;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2019-12-05 14:02:47;;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356164.2 6689485 7.1, 356161.9 6689488.7 7.1, 356160.7 6689494.2 7.1, 356161.5 6689500.7 6.9, 356164.7 6689506.8 6.9, 356169.8 6689512.2 6.9, 356176.2 6689517 6.9, 356184.3 6689521.1 6.8, 356193.1 6689525.6 6.8, 356205.4 6689531.3 6.8)
TRONROUT0000000329622962;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2019-12-05 14:02:47;;;;;Levé GPS;2.5;Levé GPS;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356159.5 6689531.8 8.2, 356156.3 6689528.3 8.9, 356153.6 6689525.1 9.5, 356151.2 6689519.6 9.1, 356148.7 6689514.2 9.2, 356146.5 6689508.6 9.3, 356144.2 6689502.9 9.9, 356142 6689496.5 9.9, 356139.3 6689491.5 10.1)
TRONROUT0000000029473639;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;21;;19;;44109;44109;;;;441092048;441092048;;;;;;;;;;;;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356109 6689504.7 7.3, 356147.2 6689525.5 8.2)
TRONROUT0000000029474397;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;17;;16;;44109;44109;;;;441092048;441092048;;;;;;;;;;;;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356147.2 6689525.5 8.2, 356159.5 6689531.8 8.2)
TRONROUT0000000029473626;Route à 1 chaussée;R GENERAL DE LASALLE;R GENERAL DE LASALLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;2;;2;;44109;44109;;;;44109#09S;44109#09S;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Général de Lasalle;Rue Général de Lasalle;;;44109_3574;44109_3574;;;;;LINESTRING Z (356089.9 6689554.9 7.3, 356099.4 6689527.8 7.3, 356109 6689504.7 7.3)
TRONROUT0000000039537279;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-11-08 07:23:27;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;47;;45;44109;44109;;;;441097304;441097304;;;;;;;;;;;;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356049.2 6689535 8.6, 356056.6 6689537.9 8, 356089.9 6689554.9 7.3)
TRONROUT0000000029475235;Route à 1 chaussée;R DE LOYNES;R DE LOYNES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;2;;2;44109;44109;;;;441092404;441092404;;;;;;;;;;;;;commune;commune;Rue De Loynes;Rue De Loynes;;;44109_kw40rp;44109_kw40rp;;;;;LINESTRING Z (356147.2 6689525.5 8.2, 356137.8 6689548 8.2, 356128.2 6689574.8 8.2)
TRONROUT0000000029474160;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356244.7 6689552.5 9.3, 356225.4 6689544.6 6.2, 356217 6689540.8 6.7, 356208.1 6689536.1 6.8, 356199.3 6689531.7 7.7, 356191.3 6689528.1 7.8, 356176.3 6689520.4 8.5)
TRONROUT0000000029474163;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2006-10-04 09:41:10;2019-12-05 14:02:47;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356205.4 6689531.3 9.4, 356244.7 6689552.5 9.2)
TRONROUT0000000029474167;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;441092048;441092048;;;;;;;;;;;;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356254.6 6689580.6 7.8, 356224.1 6689565.5 8.3, 356220.1 6689563.4 8.3, 356186 6689545.7 8.2, 356159.5 6689531.8 8.2)
TRONROUT0000000029474040;Route à 1 chaussée;CRS JOHN KENNEDY;CRS JOHN KENNEDY;3;Non;0;En service;2006-10-04 09:41:10;2011-09-06 08:54:31;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094541;441094541;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356244.7 6689552.5 9.4, 356266.9 6689563.9 6.2)
TRONROUT0000000295266722;Route à 1 chaussée;ALL DES GENERAUX PATTON ET WOOD;ALL DES GENERAUX PATTON ET WOOD;5;Non;0;En service;2012-02-08 10:00:49;2020-12-03 12:02:17;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Non;35;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093622;441093622;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356259.6 6689547.8 9.2, 356297 6689568 9, 356307.7 6689572 9, 356330.4 6689578.1 8.9, 356360.1 6689585.4 8.8, 356365.4 6689587.7 8.7, 356370.1 6689590.5 8.7, 356372.1 6689593.6 8.7, 356373.7 6689599 8.7)
TRONROUT0000000029474205;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356361.5 6689601.6 1.9, 356343.7 6689597.1 3.2, 356321.1 6689590.1 4.3, 356306.4 6689584.5 5.3, 356294.1 6689579.8 6.1, 356278 6689570.4 7, 356266.9 6689563.9 6.2)
TRONROUT0000000029474191;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;9;;7;;44109;44109;;;;441092048;441092048;;;;;;;;;;;;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356254.6 6689580.6 7.8, 356268.7 6689587.6 8.2, 356285.3 6689594.4 7.8)
TRONROUT0000000130607111;Sentier;IMP VAUDREUIL;IMP VAUDREUIL;6;Non;0;En service;2008-06-05 14:31:47;2008-11-15 06:12:08;;;;;BDParcellaire;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;1;;1;44109;44109;;;;441098324;441098324;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356205.9 6689609.9 7.8, 356212.3 6689584.9 7.8)
TRONROUT0000000029475275;Route à 1 chaussée;R SURCOUF;R SURCOUF;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#0A5;44109#0A5;;;;;;;;;;;;;commune;commune;Rue Surcouf;Rue Surcouf;;;44109_8004;44109_8004;;;;;LINESTRING Z (356236.2 6689622 7.8, 356254.6 6689580.6 7.8)
TRONROUT0000000029473667;Route à 1 chaussée;ALL COMMANDANT CHARCOT;ALL COMMANDANT CHARCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;;2;;44109;44109;;;;441092048;441092048;;;;;;;;;;;;;commune;commune;Allée Commandant Charcot;Allée Commandant Charcot;;;44109_2048;44109_2048;;;;;LINESTRING Z (356285.3 6689594.4 7.8, 356353.1 6689611.7 7.9, 356369.1 6689614.8 8)
TRONROUT0000000029473637;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;40;43;34;41;44109;44109;;;;441097304;441097304;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356089.9 6689554.9 7.3, 356115.1 6689568.6 7.8, 356128.2 6689574.8 8.2)
TRONROUT0000000029473564;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;32;37;28;37;44109;44109;;;;441097304;441097304;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356128.2 6689574.8 8.2, 356158 6689588.7 7.8)
TRONROUT0000000029473804;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;26;35;20;33;44109;44109;;;;441097304;441097304;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356158 6689588.7 7.8, 356183.6 6689600.3 7.2)
TRONROUT0000000029475155;Escalier;R COUSTOU;R COUSTOU;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092284;441092284;;;;;;;;;;;;;commune;commune;Rue Coustou;Rue Coustou;;;44109_2284;44109_2284;;;;;LINESTRING Z (356150 6689606.5 9.7, 356158 6689588.7 7.8)
TRONROUT0000000130607112;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2008-06-05 14:31:47;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;18;31;16;29;44109;44109;;;;441097304;441097304;;;;;;;;;;;;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356183.6 6689600.3 7.2, 356197.3 6689606.5 7.8, 356205.9 6689609.9 7.8)
TRONROUT0000000029475187;Escalier;R COUSTOU;R COUSTOU;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;1;;6;44109;44109;;;;441092284;441092284;;;;;;;;;;;;;commune;commune;Rue Coustou;Rue Coustou;;;44109_2284;44109_2284;;;;;LINESTRING Z (356141.4 6689623.9 11, 356150 6689606.5 9.7)
TRONROUT0000000029473809;Route à 1 chaussée;R RABELAIS;R RABELAIS;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;6;5;2;1;44109;44109;;;;441097088;441097088;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356156.9 6689660 10, 356183.6 6689600.3 7.2)
TRONROUT0000000029474007;Route à 1 chaussée;R COUSTOU;R COUSTOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;6;5B;2;1;44109;44109;;;;441092284;441092284;;;;;;;;;;;;;commune;commune;Rue Coustou;Rue Coustou;;;44109_2284;44109_2284;;;;;LINESTRING Z (356123.5 6689650.7 11.8, 356137.6 6689626.8 11.8, 356141.4 6689623.9 11)
TRONROUT0000000029474968;Route à 1 chaussée;R MALHERBE;R MALHERBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;16;15;8;5;44109;44109;;;;441095256;441095256;;;;;;;;;;;;;commune;commune;Rue Malherbe;Rue Malherbe;;;44109_5256;44109_5256;;;;;LINESTRING Z (356005.7 6689624.3 13.2, 356074.8 6689656.9 11.9, 356096.1 6689667.8 13.2, 356105.8 6689645.9 10, 356123.5 6689650.7 11.8)
TRONROUT0000000029474089;Route à 1 chaussée;R MALHERBE;R MALHERBE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;6;1;2;1;44109;44109;;;;441095256;441095256;;;;;;;;;;;;;commune;commune;Rue Malherbe;Rue Malherbe;;;44109_5256;44109_5256;;;;;LINESTRING Z (356123.5 6689650.7 11.8, 356156.9 6689660 10)
TRONROUT0000002220840085;Escalier;;;6;Non;0;En service;2020-12-03 12:02:17;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356394.6 6689581 -1000, 356396.9 6689570.8 -1000)
TRONROUT0000002220840084;Sentier;;;6;Non;0;En service;2020-12-03 12:02:17;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356390.8 6689599.8 -1000, 356394.6 6689581 -1000)
TRONROUT0000000029475073;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356390.8 6689599.8 8.7, 356386.2 6689601.8 8.7, 356380.9 6689601.2 8.7, 356373.7 6689599 8.7)
TRONROUT0000002220840087;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;6;Non;0;En service;2020-12-03 12:02:17;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356456 6689609.7 8.7, 356440.3 6689607.1 8.7, 356408.1 6689601.1 8.7, 356390.8 6689599.8 8.7)
TRONROUT0000000106929637;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;6;Non;0;En service;2007-11-22 11:54:43;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356468 6689613.8 8.5, 356464.2 6689611.5 8.6, 356463.2 6689611.3 8.6, 356456 6689609.7 8.7)
TRONROUT0000000106929638;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;3;Non;-1;En service;2007-11-22 11:54:43;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;4.2;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356474.4 6689627.8 2.7, 356448.4 6689621.6 2.4, 356436 6689618.6 2.3, 356418.8 6689614.6 2.2, 356400.2 6689610.1 2.1, 356380.2 6689605.8 2, 356361.5 6689601.6 1.9)
TRONROUT0000000029473759;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;Plot amovible;;;;;;Non;;24;;26;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356466 6689635 8.2, 356369.1 6689614.8 8)
TRONROUT0000000256963796;Route à 1 chaussée;R ECORCHARD;R ECORCHARD;5;Non;0;En service;2011-04-12 13:01:15;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;441092692;441092692;;;;;;;;;;;;;commune;commune;Rue Ecorchard;Rue Ecorchard;;;44109_2692;44109_2692;;;;;LINESTRING Z (356466 6689635 8.2, 356469.3 6689641.6 8.1)
TRONROUT0000000029474962;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Non;0;Restreint aux ayants droit;;;Plot amovible;;;;;;Non;;22;;23;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356506.81139568595 6689643.800930749 8.2, 356466 6689635 8.2)
TRONROUT0000000029473662;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Non;0;Restreint aux ayants droit;;;Plot amovible;;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356468 6689613.8 8.5, 356492.5 6689619.3 7.9, 356506.81139568595 6689622.361641863 7.9)
TRONROUT0000000029474648;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2020-12-03 12:02:17;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356373.7 6689599 8.7, 356373.5 6689599 8.5, 356370.9 6689605.8 8.3, 356369.4 6689609.7 8.2, 356369.1 6689614.8 8)
TRONROUT0000000029474325;Route à 1 chaussée;R MONTCALM;R MONTCALM;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;4;;4;44109;44109;;;;441095752;441095752;;;;;;;;;;;;;commune;commune;Rue Montcalm;Rue Montcalm;;;44109_5752;44109_5752;;;;;LINESTRING Z (356285.3 6689594.4 7.8, 356282.1 6689599.2 6.8, 356280.3 6689604.7 6.8, 356270.3 6689629.6 6.8, 356268.7 6689636.1 7.7)
TRONROUT0000000029473718;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;14;27;6;27;44109;44109;;;;441097304;441097304;;;;;;;;;;;;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356205.9 6689609.9 7.8, 356236.2 6689622 7.8)
TRONROUT0000000029474239;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097304;441097304;;;;;;;;;;;;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356236.2 6689622 7.8, 356240.9 6689624.1 7.5)
TRONROUT0000000029474458;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;4;25;4;23;44109;44109;;;;441097304;441097304;;;;;;;;;;;;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356240.9 6689624.1 7.5, 356258.1 6689631.5 7.2)
TRONROUT0000000029474064;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;23;;23;44109;44109;;;;441097304;441097304;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356258.1 6689631.5 7.2, 356268.7 6689636.1 7.7)
TRONROUT0000000029473457;Route à 1 chaussée;IMP SAINT-FRANCOIS;IMP SAINT-FRANCOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;2.8;;;;;Non;3;2;3;2;44109;44109;;;;441097612;441097612;;;;;;;;;;;;;commune;commune;Impasse Saint François;Impasse Saint François;;;44109_7612;44109_7612;;;;;LINESTRING Z (356240.9 6689624.1 7.5, 356234.2 6689638.7 7.6, 356227.8 6689652.5 7.6)
TRONROUT0000000029474629;Route à 1 chaussée;R STANISLAS BAUDRY;R STANISLAS BAUDRY;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;;2;;44109;44109;;;;441097968;441097968;;;;;;;;;;;;;commune;commune;Rue Stanislas Baudry;Rue Stanislas Baudry;;;44109_7968;44109_7968;;;;;LINESTRING Z (356369.1 6689614.8 8, 356340.5 6689672.6 8.7)
TRONROUT0000000029474063;Route à 1 chaussée;R DE RICHEBOURG;R DE RICHEBOURG;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;9;;21;;44109;44109;;;;441097304;441097304;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue de Richebourg;Rue de Richebourg;;;44109_7304;44109_7304;;;;;LINESTRING Z (356268.7 6689636.1 7.7, 356340.5 6689672.6 8.7)
TRONROUT0000000029474838;Route à 1 chaussée;R SAINT-FRANCOIS;R SAINT-FRANCOIS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-31 00:37:57;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;2;;4;;44109;44109;;;;441097616;441097616;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Saint François;Rue Saint François;;;44109_7616;44109_7616;;;;;LINESTRING Z (356258.1 6689631.5 7.2, 356250.5 6689647.2 7.4, 356241.1 6689667 9.1, 356235.1 6689679.9 9.7)
TRONROUT0000000256963795;Route à 1 chaussée;;;5;Non;0;En service;2011-04-12 13:01:15;2022-05-13 20:06:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356472.3 6689665.1 8.5, 356472.3 6689657.9 8.5, 356472.9 6689651.2 8.5, 356472.9 6689646.7 8.5, 356471.6 6689643.7 8.5, 356469.3 6689641.6 8.1)
TRONROUT0000000029470928;Route à 1 chaussée;BD DE STALINGRAD;BD DE STALINGRAD;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Non;63;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097964;441097964;;;;;;;;;;;;;commune;commune;Boulevard de Stalingrad;Boulevard de Stalingrad;;;44109_7964;44109_7964;;;;;LINESTRING Z (356506.81139568595 6689634.933136779 4.507937893234402, 356474.4 6689627.8 2.7)
TRONROUT0000000029473971;Route à 1 chaussée;R ECORCHARD;R ECORCHARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;Plot amovible;;;;;;Non;1;;7;;44109;44109;;;;441092692;441092692;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Ecorchard;Rue Ecorchard;;;44109_2692;44109_2692;;;;;LINESTRING Z (356469.3 6689641.6 8.1, 356361.9 6689685.1 9)
TRONROUT0000002285624383;Route à 1 chaussée;;;5;Non;0;En service;2022-05-03 09:57:22;2022-05-13 20:06:25;;;;;Levé non GPS;5.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356467.5 6689674 -1000, 356472.3 6689665.1 -1000)
TRONROUT0000000029475110;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-03 20:06:06;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356467.5 6689674 8.5, 356456.3 6689672.3 8.5, 356446.2 6689673.1 6.8)
TRONROUT0000000295265503;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2022-05-03 09:57:22;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356472.3 6689665.1 8.5, 356476.8 6689665.4 8.5, 356481.3 6689665.7 8.5, 356486.6 6689665.6 8.5, 356491.1 6689666.6 8.5, 356494.4 6689668.7 8.5, 356496.5 6689672 8.5, 356497.9 6689676.3 8.5, 356498.2 6689681.9 8.5, 356497 6689686.2 8.5, 356494.6 6689688.3 8.5, 356492.2 6689689.9 8.5)
TRONROUT0000000256963797;Route à 1 chaussée;;;5;Non;0;En service;2011-04-12 13:01:15;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356492.2 6689689.9 8.5, 356484.8 6689684.4 8.6, 356477.8 6689679.6 8.7, 356471.7 6689675.9 8.6, 356467.5 6689674 8.5)
TRONROUT0000000029475123;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-03 20:06:06;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356446.2 6689673.1 6.8, 356433.6 6689676.6 7.2, 356398.8 6689688.5 8.5, 356372 6689701.9 8.9, 356363.3 6689707.3 8.8, 356355.1 6689714.3 8)
TRONROUT0000000029474702;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356446.2 6689673.1 6.8, 356435.4 6689679.5 8.3, 356424.2 6689688.9 8.2, 356413.7 6689702.5 8.2, 356409.6 6689709.8 8.2, 356408 6689715.4 8.3)
TRONROUT0000000029475087;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356387.8 6689711 7.5, 356397.5 6689712.1 7.6, 356408 6689715.4 8.3)
TRONROUT0000000029471275;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356488 6689743.7 7.5, 356494.2 6689732.7 7.7, 356496.1 6689725.6 7.8, 356497.1 6689711.2 7.8, 356496.3 6689703.6 7.8, 356494.5 6689695.9 7.8, 356492.2 6689689.9 8.5)
TRONROUT0000000029474856;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2017-10-30 19:25:34;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356488 6689743.7 7.5, 356486.7 6689737.5 7.5, 356483.7 6689730.8 7.5, 356472.9 6689713.3 7.5, 356468.4 6689708.7 7.4, 356462.9 6689705.3 7.4, 356451.8 6689700.9 7.4, 356445.2 6689700 7.3, 356439.7 6689700 7.3, 356434.2 6689700.8 7.3, 356427.2 6689702.9 7.3, 356420.8 6689705.5 7.3, 356414.5 6689709 7.3, 356408 6689715.4 8.3)
TRONROUT0000000029471328;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6689710.347799971 8.706823653721143, 356505.6 6689707.6 8.5, 356492.2 6689689.9 8.5)
TRONROUT0000000029475176;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2017-10-30 19:25:34;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356408 6689715.4 8.3, 356407.1 6689721.6 8.2, 356407.2 6689728.1 8.1, 356408.1 6689736.6 7.3, 356410.8 6689748.6 7.8, 356413 6689753.7 7.8, 356416.4 6689759.6 7.9, 356424 6689767 8)
TRONROUT0000000029471306;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2017-10-30 19:25:34;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356484.2 6689751.1 7.8, 356488 6689743.7 7.5)
TRONROUT0000000029475139;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2017-10-30 19:25:34;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356424 6689767 8, 356435.8 6689770.1 8, 356441.5 6689770.8 7.9, 356451.4 6689770.1 7.7, 356460.5 6689768.2 7.8, 356466.9 6689766 7.8, 356472.6 6689762.6 7.8, 356477.6 6689758.6 7.8, 356484.2 6689751.1 7.8)
TRONROUT0000000029475171;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356352.2 6689761.2 8.3, 356361.1 6689760.2 8.3, 356371.1 6689759.5 8.1, 356383.5 6689759.7 7.9, 356410.1 6689763.2 8)
TRONROUT0000000029475109;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356424 6689767 8, 356414 6689763.3 8, 356410.1 6689763.2 8)
TRONROUT0000000029475124;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356436.4 6689796.8 9.9, 356434 6689789.5 9.5, 356424 6689767 8)
TRONROUT0000000295265507;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2013-11-15 09:08:43;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356424 6689767 8, 356439.5 6689775 8.4, 356454.2 6689783.8 9.8, 356465.5 6689793.4 10.5, 356473.4 6689801.5 12.4)
TRONROUT0000000295265407;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-09-27 15:33:05;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355882.1 6689402.5 4.8, 355879.7 6689407.1 4.9, 355878 6689412.7 6.6, 355876.6 6689419.2 8.3, 355876.2 6689421.8 9, 355875.8 6689428.3 9.7, 355878.3 6689440.8 9.9, 355882.4 6689465.5 10.2)
TRONROUT0000000029473588;Route à 1 chaussée;R DES ETATS;R DES ETATS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;13;;15;;44109;44109;;;;441092916;441092916;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue des Etats;Rue des Etats;;;44109_2916;44109_2916;;;;;LINESTRING Z (355786.9 6689431.1 10.3, 355786.3 6689439.3 10.1, 355786.6 6689446.9 9.9, 355787.2 6689456 9.9, 355789.3 6689463.3 10.2, 355793.4 6689472.6 10.4, 355793.7 6689486.6 11.3)
TRONROUT0000000295264739;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-09-27 15:33:05;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355882.4 6689465.5 10.2, 355866.5 6689466.4 10.2, 355851.7 6689469.3 10.2, 355836.5 6689476 10.1)
TRONROUT0000000029475274;Route à 1 chaussée;;;5;Non;1;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355793.7 6689486.6 11.3, 355817.6 6689480.6 10.4, 355836.5 6689476 10.1)
TRONROUT0000000029475210;Route à 1 chaussée;PL MARC ELDER;PL MARC ELDER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441095316;441095316;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Place Marc Elder;Place Marc Elder;;;44109_5316;44109_5316;;;;;LINESTRING Z (355793.7 6689486.6 11.3, 355809.8 6689501.6 11.3, 355813 6689507.3 11.3, 355813.3 6689508.1 11.3)
TRONROUT0000000029473894;Sentier;PL MARC ELDER;PL MARC ELDER;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;1;;1;;44109;44109;;;;441095316;441095316;;;;;;;;;;;;;commune;commune;Place Marc Elder;Place Marc Elder;;;44109_5316;44109_5316;;;;;LINESTRING Z (355793.7 6689486.6 11.3, 355794.7 6689496.1 11.3, 355795.5 6689505.6 11.3, 355796 6689506.9 11.3, 355797 6689507.8 11.3, 355801.9 6689508 11.3, 355813.3 6689508.1 11.3)
TRONROUT0000000295266724;Route à 1 chaussée;R MATHELIN RODIER;R MATHELIN RODIER;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;1;44109;44109;;;;441095488;441095488;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Mathelin Rodier;Rue Mathelin Rodier;;;44109_5488;44109_5488;;;;;LINESTRING Z (355817.7 6689522 11.6, 355813.3 6689508.1 11.3)
TRONROUT0000000029474474;Route à 1 chaussée;R PREMION;R PREMION;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;3;;44109;44109;;;;441096940;441096940;;;;;;;;;;;;;commune;commune;Rue Prémion;Rue Prémion;;;44109_6940;44109_6940;;;;;LINESTRING Z (355817.7 6689522 11.6, 355823 6689535.9 11.9, 355828.6 6689541.5 12, 355836.8 6689545.1 12.3, 355857 6689550.3 12.7, 355904.3 6689558.6 12.8, 355930.1 6689563.1 13.2)
TRONROUT0000000029474301;Route à 1 chaussée;R MATHELIN RODIER;R MATHELIN RODIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;19;12;44109;44109;;;;441095488;441095488;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Mathelin Rodier;Rue Mathelin Rodier;;;44109_5488;44109_5488;;;;;LINESTRING Z (355792.5 6689640 16.7, 355799.9 6689596.3 17.3, 355807.4 6689572.5 17.3, 355814.4 6689552.2 17.3, 355817.7 6689531.3 11.8, 355817.7 6689522 11.6)
TRONROUT0000000314528471;Route à 1 chaussée;IMP SAINT-LAURENT;IMP SAINT-LAURENT;5;Non;0;En service;2012-10-23 09:46:29;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;7;6;7;44109;44109;;;;441097668;441097668;;;;;;;;;;;;;commune;commune;Impasse Saint Laurent;Impasse Saint Laurent;;;44109_7668;44109_7668;;;;;LINESTRING Z (355851.2 6689612.4 16.9, 355850.2 6689620.4 16.4, 355841.2 6689624.6 16.5)
TRONROUT0000000295265393;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356025.8 6689523.8 9.8, 356013.2 6689517.9 10)
TRONROUT0000000295265399;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356040.4 6689530.8 9.2, 356030.8 6689526.2 9.8, 356025.8 6689523.8 9.8)
TRONROUT0000000107837504;Sentier;;;6;Non;1;En service;2007-12-03 22:15:03;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355937 6689548.8 9, 355928.5 6689507.9 9.4)
TRONROUT0000000294302138;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356044.7 6689528.3 9.2, 356046.8 6689528.9 9.1, 356047.2 6689529 9, 356049 6689530.7 8.9)
TRONROUT0000000295265331;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356040.4 6689530.8 9.2, 356042.2 6689529 9.2, 356044.7 6689528.3 9.2)
TRONROUT0000000039537278;Route à 1 chaussée;;;5;Non;0;En service;2006-11-08 07:23:27;2021-08-06 16:51:06;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356049 6689530.7 8.9, 356049.7 6689533.2 8.8, 356049.2 6689535 8.6)
TRONROUT0000000294302139;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356041.9 6689537.2 9.2, 356040.5 6689535.8 9.2, 356039.7 6689533.3 9.2, 356040.4 6689530.8 9.2)
TRONROUT0000000295265406;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356001 6689552.5 10.2, 355999.3 6689551.8 10.2, 355997.3 6689550.3 10.2, 355997.1 6689548.7 10.2, 355997.9 6689546.6 10.1, 356004.8 6689532.7 9.9, 356013.2 6689517.9 10)
TRONROUT0000000294302137;Route à 1 chaussée;;;5;Non;0;En service;2012-01-17 12:39:06;2021-08-06 16:51:06;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356049.2 6689535 8.6, 356049 6689535.7 8.7, 356047.3 6689537.5 8.9, 356044.8 6689538.3 9, 356042.7 6689537.7 9.2, 356042.3 6689537.6 9.2, 356041.9 6689537.2 9.2)
TRONROUT0000000295265504;Route à 1 chaussée;PL DE LA DUCHESSE ANNE;PL DE LA DUCHESSE ANNE;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092596;441092596;;;;;;;;;;;;;commune;commune;Place de la Duchesse Anne;Place de la Duchesse Anne;;;44109_2596;44109_2596;;;;;LINESTRING Z (356025.8 6689523.8 9.8, 356017.6 6689538.8 9.8, 356010 6689552.7 10.2, 356007.9 6689554.4 10.2, 356005.6 6689554.4 10.2, 356001 6689552.5 10.2)
TRONROUT0000000107837505;Sentier;;;6;Non;0;En service;2007-12-03 22:15:03;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355980.2 6689549.5 10.4, 355975.1 6689550.9 10.1, 355971.4 6689551.5 9.9, 355961 6689550.9 9.7, 355942.9 6689549.4 9.7, 355937 6689548.8 9)
TRONROUT0000000107837506;Escalier;;;6;Non;0;En service;2007-12-03 22:15:03;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355985.3 6689555.1 10.9, 355980.2 6689549.5 10.4)
TRONROUT0000000295265447;Escalier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355937 6689548.8 9, 355933.5 6689557.1 12.9, 355930.1 6689563.1 13.2)
TRONROUT0000000295265471;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355993.4 6689566.6 12, 355993.8 6689566 12, 355997.7 6689558.6 11.5, 355999.5 6689555.3 10.8, 356001 6689552.5 10.2)
TRONROUT0000000329622503;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355993.4 6689566.6 12, 355993.4 6689566.3 12.1, 355988.1 6689558.1 11.1, 355985.3 6689555.1 10.9)
TRONROUT0000000029474918;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356041.9 6689537.2 9.2, 356037.7 6689544.4 9.4, 356031.3 6689556.5 9.9, 356025.2 6689569.1 10.6, 356023.9 6689572.1 10.7, 356021.3 6689578 10.9, 356019.3 6689584 11.5, 356018.5 6689588.4 11.7, 356018 6689593.1 12.3)
TRONROUT0000000295265282;Route à 1 chaussée;R PREMION;R PREMION;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;2;;2;;44109;44109;;;;441096940;441096940;;;;;;;;;;;;;commune;commune;Rue Prémion;Rue Prémion;;;44109_6940;44109_6940;;;;;LINESTRING Z (355930.1 6689563.1 13.2, 355938.4 6689565 11.7, 355958.4 6689569.6 12.8, 355973.3 6689571.9 12.9, 355989.3 6689579.5 12.2, 355991.6 6689580.6 12.1)
TRONROUT0000000295265287;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355991.6 6689580.6 12.1, 355994 6689571.1 12, 355993.4 6689566.6 12)
TRONROUT0000000029475049;Route à 1 chaussée;R PREMION;R PREMION;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;;1;;44109;44109;;;;441096940;441096940;;;;;;;;;;;;;commune;commune;Rue Prémion;Rue Prémion;;;44109_6940;44109_6940;;;;;LINESTRING Z (355991.6 6689580.6 12.1, 355996.9 6689583.1 12.1, 356018 6689593.1 12.3)
TRONROUT0000000317157118;Escalier;;;6;Non;0;En service;2013-01-08 09:43:37;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355984.3 6689598 15.8, 355991.6 6689580.6 12.1)
TRONROUT0000000029474249;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;26;19;22;15T;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355672 6689583.7 13.1, 355700.2 6689529.7 12.3)
TRONROUT0000000029473690;Route à 1 chaussée;R DES CARMELITES;R DES CARMELITES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;13;12B;25;18;44109;44109;;;;441091436;441091436;;;;;;;;;;;;;commune;commune;Rue des Carmélites;Rue des Carmélites;;;44109_1436;44109_1436;;;;;LINESTRING Z (355720.2 6689597 12, 355725.3 6689568.3 12, 355724 6689532 11.8)
TRONROUT0000000029474285;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355665.5 6689571.4 12.8, 355672 6689583.7 13.1)
TRONROUT0000000029473881;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;21;;21;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355662.1 6689603.4 13.4, 355672 6689583.7 13.1)
TRONROUT0000000029474512;Route à 1 chaussée;IMP MAILLARD;IMP MAILLARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;20;;20;;44109;44109;;;;44109#0D4;44109#0D4;;;;;;;;;;;;;commune;commune;Impasse Maillard;Impasse Maillard;;;44109_6869;44109_6869;;;;;LINESTRING Z (355720.2 6689597 12, 355744.1 6689603 11.9, 355749.2 6689602.5 11.9, 355758.6 6689598.2 11.9, 355765.2 6689594.3 11.9, 355779.6 6689599.3 11.9)
TRONROUT0000000029473989;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;23;10;15;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355672 6689583.7 13.1, 355695.6 6689616.7 14.4, 355705.5 6689630.5 14.9)
TRONROUT0000000029473534;Route à 1 chaussée;R DES CARMELITES;R DES CARMELITES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;25;22;27;24;44109;44109;;;;441091436;441091436;;;;;;;;;;;;;commune;commune;Rue des Carmélites;Rue des Carmélites;;;44109_1436;44109_1436;;;;;LINESTRING Z (355714.1 6689622.7 14, 355717.9 6689610.2 12, 355720.2 6689597 12)
TRONROUT0000000029473901;Route à 1 chaussée;R SAINT-PIERRE;R SAINT-PIERRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097728;441097728;;;;;;;;;;;;;commune;commune;Rue Saint Pierre;Rue Saint Pierre;;;44109_7728;44109_7728;;;;;LINESTRING Z (355707.7 6689633.7 15, 355712.3 6689628.7 15, 355714.1 6689622.7 14)
TRONROUT0000000029475224;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;19;;19;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355705.5 6689630.5 14.9, 355707.7 6689633.7 15)
TRONROUT0000000029473730;Route à 1 chaussée;R SAINT-PIERRE;R SAINT-PIERRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;17;2;1;44109;44109;;;;441097728;441097728;;;;;;;;;;;;;commune;commune;Rue Saint Pierre;Rue Saint Pierre;;;44109_7728;44109_7728;;;;;LINESTRING Z (355790.6 6689647.2 17.2, 355770.1 6689644.3 15.5, 355756.3 6689639.9 15.4, 355727.3 6689626.6 15.2, 355714.1 6689622.7 14)
TRONROUT0000000029473986;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;32;25;28;23;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355627.1 6689673.3 14.6, 355662.1 6689603.4 13.4)
TRONROUT0000000029475038;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;2;1;2;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355707.7 6689633.7 15, 355728.3 6689661.6 16.7, 355740.2 6689672.7 16.8)
TRONROUT0000000029474594;Route à 1 chaussée;R SAINT-DENIS;R SAINT-DENIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;;9;;44109;44109;;;;441097560;441097560;;;;;;;;;;;;;commune;commune;Rue Saint Denis;Rue Saint Denis;;;44109_7560;44109_7560;;;;;LINESTRING Z (355705.5 6689630.5 14.9, 355698.5 6689637.7 14.9, 355697.7 6689640.9 14.9, 355693.2 6689679.1 14.9)
TRONROUT0000000039538613;Route à 1 chaussée;PL SAINT-PIERRE;PL SAINT-PIERRE;5;Non;0;En service;2006-11-08 11:47:45;2023-05-27 02:00:25;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;1;5;1;44109;44109;;;;441097724;441097724;;;;;;;;;;;;;commune;commune;Place Saint Pierre;Place Saint Pierre;;;44109_7724;44109_7724;;;;;LINESTRING Z (355740.2 6689672.7 15.3, 355742.7 6689670.4 15.8, 355745.8 6689669.2 15.7, 355748.9 6689668.2 15.9, 355753.3 6689668.6 15.9, 355759.7 6689669.6 15.9, 355779.8 6689669.8 17.5)
TRONROUT0000000029474367;Route à 1 chaussée;R GENERAL LECLERC DE HAUTECLOCQUE;R GENERAL LECLERC DE HAUTECLOCQUE;3;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;3.0;9.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;3B;;5;;44109;44109;;;;441093596;441093596;;;;;;;;;;;;;commune;commune;Rue Général Leclerc de Hautecloque;Rue Général Leclerc de Hautecloque;;;44109_3596;44109_3596;;;;;LINESTRING Z (355693.2 6689679.1 15.2, 355627.1 6689673.3 14.6)
TRONROUT0000000039538612;Route à 1 chaussée;PL SAINT-PIERRE;PL SAINT-PIERRE;5;Non;0;En service;2006-11-08 11:47:45;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441097724;441097724;;;;;;;;;;;;;commune;commune;Place Saint Pierre;Place Saint Pierre;;;44109_7724;44109_7724;;;;;LINESTRING Z (355740.2 6689672.7 15.3, 355736.1 6689677.1 16, 355734.9 6689683.1 16.6)
TRONROUT0000000029474053;Route à 1 chaussée;R GENERAL LECLERC DE HAUTECLOCQUE;R GENERAL LECLERC DE HAUTECLOCQUE;3;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;3.0;9.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441093596;441093596;;;;;;;;;;;;;commune;commune;Rue Général Leclerc de Hautecloque;Rue Général Leclerc de Hautecloque;;;44109_3596;44109_3596;;;;;LINESTRING Z (355734.9 6689683.1 16.6, 355693.2 6689679.1 14.9)
TRONROUT0000000039538611;Route à 1 chaussée;PL SAINT-PIERRE;PL SAINT-PIERRE;3;Non;0;En service;2006-11-08 11:47:45;2023-05-27 02:00:25;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;3;;3A;;44109;44109;;;;441097724;441097724;;;;;;;;;;;;;commune;commune;Place Saint Pierre;Place Saint Pierre;;;44109_7724;44109_7724;;;;;LINESTRING Z (355734.9 6689683.1 16.6, 355734.3 6689690.6 16.3, 355734.9 6689698.9 16.1)
TRONROUT0000000029474128;Route à 1 chaussée;R SAINT-DENIS;R SAINT-DENIS;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;11;;11;;44109;44109;;;;441097560;441097560;;;;;;;;;;;;;commune;commune;Rue Saint Denis;Rue Saint Denis;;;44109_7560;44109_7560;;;;;LINESTRING Z (355693.2 6689679.1 15.2, 355686.5 6689706.7 15.5)
TRONROUT0000002200319314;Route à 1 chaussée;PL SAINT-PIERRE;PL SAINT-PIERRE;3;Non;0;En service;2019-01-10 17:53:40;2023-05-27 02:00:25;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441097724;441097724;;;;;;;;;;;;;commune;commune;Place Saint Pierre;Place Saint Pierre;;;44109_7724;44109_7724;;;;;LINESTRING Z (355734.9 6689698.9 16.1, 355739.9 6689703.9 16.3, 355747.6 6689707.7 16.6, 355752.7 6689709.1 16.7, 355757.8 6689709.9 17.4, 355762.6 6689710.6 17.4)
TRONROUT0000000357667945;Sentier;SQ DE LA PSALETTE;SQ DE LA PSALETTE;6;Non;0;En service;2016-06-10 09:50:26;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GR;44109#0GR;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355841.2 6689624.6 16.5, 355842.8 6689627.1 16.6, 355845.8 6689628.9 16.7)
TRONROUT0000000029474173;Route à 1 chaussée;IMP SAINT-LAURENT;IMP SAINT-LAURENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;5;2;1;44109;44109;;;;441097668;441097668;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Impasse Saint Laurent;Impasse Saint Laurent;;;44109_7668;44109_7668;;;;;LINESTRING Z (355841.2 6689624.6 16.5, 355818.8 6689635.2 16.8, 355792.5 6689640 16.7)
TRONROUT0000000029473822;Route à 1 chaussée;R MATHELIN RODIER;R MATHELIN RODIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095488;441095488;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Mathelin Rodier;Rue Mathelin Rodier;;;44109_5488;44109_5488;;;;;LINESTRING Z (355790.6 6689647.2 17.2, 355792.5 6689640 16.7)
TRONROUT0000000357667944;Sentier;;;6;Non;0;En service;2016-06-10 09:50:26;2020-02-12 17:33:37;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355838.4 6689679.7 18, 355840.9 6689660.4 17.7, 355843.7 6689647.5 17.4, 355843 6689639.2 17.2, 355843.8 6689631.6 16.9, 355845.8 6689628.9 16.7)
TRONROUT0000000321100658;Route à 1 chaussée;R MATHELIN RODIER;R MATHELIN RODIER;5;Non;0;En service;2013-04-17 17:19:58;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095488;441095488;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Mathelin Rodier;Rue Mathelin Rodier;;;44109_5488;44109_5488;;;;;LINESTRING Z (355779.8 6689669.8 17.5, 355784.4 6689665.7 17.5, 355788.5 6689656.1 17.5, 355790.6 6689647.2 17.2)
TRONROUT0000000314528469;Sentier;SQ DE LA PSALETTE;SQ DE LA PSALETTE;6;Non;0;En service;2012-10-23 09:46:29;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GR;44109#0GR;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355845.8 6689628.9 16.7, 355852.9 6689629.5 16.8, 355856.2 6689631.1 16.9, 355859.7 6689635.2 17.1, 355862.1 6689641.8 17.2, 355863.2 6689648.7 17.3, 355863.4 6689653.5 17.4, 355864.3 6689655.9 17.5, 355867.1 6689657.4 17.7, 355876.3 6689659.4 17.8, 355883.3 6689662.3 17.9, 355891.2 6689667.6 18, 355896.9 6689671.9 18.1, 355931.6 6689699.6 18.3)
TRONROUT0000000321100657;Route à 1 chaussée;IMP DE LA PSALETTE;IMP DE LA PSALETTE;5;Non;0;En service;2013-04-17 17:19:58;2021-11-17 13:01:43;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0OS;44109#0OS;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355779.8 6689669.8 17.5, 355796.4 6689675.5 17.6, 355818.6 6689676.8 17.8, 355838.4 6689679.7 18)
TRONROUT0000002200319313;Sentier;;;6;Non;0;En service;2019-01-10 17:53:40;2023-02-01 08:20:10;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355779.8 6689669.8 17.5, 355770.9 6689684.5 17.4, 355764.5 6689702.8 17.4, 355762.6 6689710.6 17.4)
TRONROUT0000000039538610;Route à 1 chaussée;PL SAINT-PIERRE;PL SAINT-PIERRE;3;Non;0;En service;2006-11-08 11:47:45;2023-05-27 02:00:25;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097724;441097724;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place Saint Pierre;Place Saint Pierre;;;44109_7724;44109_7724;;;;;LINESTRING Z (355762.6 6689710.6 17.4, 355767.2 6689712.2 17.5, 355771 6689713.6 17.5, 355776.7 6689718.9 17.5)
TRONROUT0000000029474626;Route à 1 chaussée;R DU ROI ALBERT;R DU ROI ALBERT;5;Non;0;En service;2006-10-04 09:41:10;2023-02-01 08:20:10;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;1;2;1;44109;44109;;;;441097428;441097428;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue du Roi Albert;Rue du Roi Albert;;;44109_7428;44109_7428;;;;;LINESTRING Z (355762 6689755.8 17, 355776.7 6689718.9 17.9)
TRONROUT0000000029475193;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;Sens inverse;Oui;30;Libre;;;;;;;;;Non;7;;7;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356018 6689593.1 12.3, 356015 6689603.2 12.3, 356005.7 6689624.3 13.2)
TRONROUT0000000314528470;Route empierrée;CRS SAINT-PIERRE;CRS SAINT-PIERRE;5;Non;0;En service;2012-10-23 09:46:29;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097720;441097720;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355984.3 6689598 15.8, 355931.6 6689699.6 18.3)
TRONROUT0000000029475064;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Sens direct;Sens inverse;Oui;30;Libre;;;;;;;;;Non;12;;8;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (356005.7 6689624.3 13.2, 355954.4 6689730.3 17)
TRONROUT0000000324171816;Sentier;;;6;Non;0;En service;2013-07-25 18:52:41;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355954.4 6689730.3 -1000, 355931.6 6689699.6 -1000)
TRONROUT0000000029473850;Route à 1 chaussée;R GEORGES CLEMENCEAU;R GEORGES CLEMENCEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093664;441093664;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Georges Clemenceau;Rue Georges Clemenceau;;;44109_3664;44109_3664;;;;;LINESTRING Z (355954.4 6689730.3 17, 355965.3 6689732 16.8, 355970.8 6689733.7 16.9)
TRONROUT0000000029473504;Route à 1 chaussée;R GEORGES CLEMENCEAU;R GEORGES CLEMENCEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;13;12;17;16;44109;44109;;;;441093664;441093664;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Georges Clemenceau;Rue Georges Clemenceau;;;44109_3664;44109_3664;;;;;LINESTRING Z (356047.8 6689768.9 17.4, 355989.6 6689740.6 17, 355970.8 6689733.7 16.9)
TRONROUT0000000129688883;Route empierrée;CRS SAINT-PIERRE;CRS SAINT-PIERRE;5;Non;0;En service;2008-05-20 07:32:13;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Double sens;;Oui;10;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097720;441097720;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (355931.6 6689699.6 18.3, 355877.2 6689805.6 20.9)
TRONROUT0000000029474971;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (355924.8 6689789.6 18.1, 355941.7 6689754.8 17.6, 355943.5 6689751.3 17.5, 355954.4 6689730.3 17)
TRONROUT0000000029473893;Route à 1 chaussée;PL DE L'ORATOIRE;PL DE L'ORATOIRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;13;;14;44109;44109;;;;441096048;441096048;;;;;;;;;;;;;commune;commune;Place de l'Oratoire;Place de l'Oratoire;;;44109_6048;44109_6048;;;;;LINESTRING Z (355970.8 6689733.7 16.9, 355961.5 6689749.5 16.9, 355949.5 6689770.8 17.9, 355940.1 6689788.9 17.7, 355938 6689793.3 17.7)
TRONROUT0000000029475067;Route à 1 chaussée;R HENRI IV;R HENRI IV;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Double sens;Double sens;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;15;;15;;44109;44109;;;;441094156;441094156;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Henri IV;Rue Henri IV;;;44109_4156;44109_4156;;;;;LINESTRING Z (355901.8 6689818.7 18.6, 355911.4 6689811 18.4, 355924.8 6689789.6 18.1)
TRONROUT0000000029474095;Route à 1 chaussée;R NOTRE DAME;R NOTRE DAME;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441095972;441095972;;;;;;;;;;;;;commune;commune;Rue Notre Dame;Rue Notre Dame;;;44109_5972;44109_5972;;;;;LINESTRING Z (355686.5 6689706.7 15.5, 355667 6689707.5 14.7)
TRONROUT0000000029475060;Route à 1 chaussée;R NOTRE DAME;R NOTRE DAME;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441095972;441095972;;;;;;;;;;;;;commune;commune;Rue Notre Dame;Rue Notre Dame;;;44109_5972;44109_5972;;;;;LINESTRING Z (355667 6689707.5 14.7, 355651.6 6689707.4 14.1)
TRONROUT0000000029474155;Route à 1 chaussée;R PORTAIL;R PORTAIL;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441096800;441096800;;;;;;;;;;;;;commune;commune;Rue Portail;Rue Portail;;;44109_6800;44109_6800;;;;;LINESTRING Z (355684.1 6689725.1 16.2, 355691.2 6689723.9 16.2, 355714.9 6689712.4 16.5, 355734.9 6689698.9 16.1)
TRONROUT0000000029474965;Route à 1 chaussée;PL DUMOUSTIER;PL DUMOUSTIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:00;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092632;441092632;;;;;;;;;;;;;commune;commune;Place Dumoustier;Place Dumoustier;;;44109_2632;44109_2632;;;;;LINESTRING Z (355686.5 6689706.7 15.5, 355684.1 6689725.1 16.2)
TRONROUT0000000029474885;Route à 1 chaussée;PL DUMOUSTIER;PL DUMOUSTIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441092632;441092632;;;;;;;;;;;;;commune;commune;Place Dumoustier;Place Dumoustier;;;44109_2632;44109_2632;;;;;LINESTRING Z (355667 6689707.5 14.7, 355667.3 6689723.9 15.4, 355667.4 6689742.8 16)
TRONROUT0000000029474318;Route à 1 chaussée;PL DUMOUSTIER;PL DUMOUSTIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;4T;;5;44109;44109;;;;441092632;441092632;;;;;;;;;;;;;commune;commune;Place Dumoustier;Place Dumoustier;;;44109_2632;44109_2632;;;;;LINESTRING Z (355651.6 6689707.4 14.1, 355651.5 6689714.4 15.3, 355652 6689726.7 15.4, 355652.1 6689739.8 16, 355652.9 6689742.1 16, 355656.7 6689743.1 16, 355667.4 6689742.8 16)
TRONROUT0000000029475000;Route à 1 chaussée;PL DUMOUSTIER;PL DUMOUSTIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:00;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441092632;441092632;;;;;;;;;;;;;commune;commune;Place Dumoustier;Place Dumoustier;;;44109_2632;44109_2632;;;;;LINESTRING Z (355684.1 6689725.1 16.2, 355683.8 6689737.2 16.3)
TRONROUT0000000295264898;Route à 1 chaussée;R DU REFUGE;R DU REFUGE;5;Non;0;En service;2012-02-08 10:00:49;2023-06-01 18:29:00;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097172;441097172;;;;;;;;;;;;;commune;commune;Rue du Refuge;Rue du Refuge;;;44109_7172;44109_7172;;;;;LINESTRING Z (355683.8 6689737.2 16.3, 355683.4 6689742.5 16.2)
TRONROUT0000000029474011;Route à 1 chaussée;PL DUMOUSTIER;PL DUMOUSTIER;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;4;;4;44109;44109;;;;441092632;441092632;;;;;;;;;;;;;commune;commune;Place Dumoustier;Place Dumoustier;;;44109_2632;44109_2632;;;;;LINESTRING Z (355667.4 6689742.8 16, 355683.4 6689742.5 16.2)
TRONROUT0000000029474044;Route à 1 chaussée;R OGEE;R OGEE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;5;10;44109;44109;;;;441096008;441096008;;;;;;;;;;;;;commune;commune;Rue Ogée;Rue Ogée;;;44109_6008;44109_6008;;;;;LINESTRING Z (355762 6689755.8 17, 355716.2 6689745.3 17, 355683.8 6689737.2 16.3)
TRONROUT0000000029475141;Route à 1 chaussée;R DE L'EVECHE;R DE L'EVECHE;3;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;6;1;2;1;44109;44109;;;;441092992;441092992;;;;;;;;;;;;;commune;commune;Rue de l'Evêché;Rue de l'Evêché;;;44109_2992;44109_2992;;;;;LINESTRING Z (355776.7 6689718.9 18.9, 355790.1 6689731.4 18.9, 355826.4 6689776.6 18.9)
TRONROUT0000000129688886;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2008-05-20 07:32:13;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355826.4 6689776.6 18.9, 355829.2 6689779.5 21.9, 355837.8 6689786.3 23.1)
TRONROUT0000000295265222;Route à 1 chaussée;R CHAUVIN;R CHAUVIN;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;3;4;3;44109;44109;;;;441091816;441091816;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Chauvin;Rue Chauvin;;;44109_1816;44109_1816;;;;;LINESTRING Z (355751.3 6689773.7 16.3, 355771.1 6689782.3 16.3, 355798.7 6689795.2 17.3)
TRONROUT0000000029474316;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355812.9 6689802.8 18.8, 355826.4 6689776.6 18.9)
TRONROUT0000000029474447;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355837.8 6689786.3 23.1, 355858.2 6689797.5 22.5)
TRONROUT0000000029474320;Route à 1 chaussée;R CHAUVIN;R CHAUVIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441091816;441091816;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Chauvin;Rue Chauvin;;;44109_1816;44109_1816;;;;;LINESTRING Z (355798.7 6689795.2 17.3, 355798.7 6689795.4 37.1, 355799.7 6689796.2 36.8, 355809.6 6689801.3 34.9, 355812.9 6689802.8 18.8)
TRONROUT0000000129688887;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2008-05-20 07:32:13;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355858.2 6689797.5 22.5, 355877.2 6689805.6 20.9)
TRONROUT0000000129688884;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;5;Non;0;En service;2008-05-20 07:32:13;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;Double sens;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355815.7 6689832 21.6, 355837.8 6689786.3 23.1)
TRONROUT0000000129688885;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;5;Non;0;En service;2008-05-20 07:32:13;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;5;;2;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355815.7 6689832 21.6, 355800.3 6689829.5 24.3, 355812.9 6689802.8 18.8)
TRONROUT0000000029474684;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;;;;;;;;;;;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355836.8 6689838.4 18, 355858.2 6689797.5 22.5)
TRONROUT0000000029474952;Route à 1 chaussée;COUR JULES DUPRE;COUR JULES DUPRE;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GV;44109#0GV;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356005.2 6689855.3 18.9, 356008.3 6689849 18.9, 356045.9 6689772.7 17.4, 356047.8 6689768.9 17.4)
TRONROUT0000000029473813;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355877.2 6689805.6 20.9, 355901.8 6689818.7 18.6)
TRONROUT0000000029474003;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355901.8 6689818.7 18.6, 355901.3 6689827.3 18.7)
TRONROUT0000000029473967;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;45;112;45;112;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (355901.3 6689827.3 18.7, 355951.1 6689831.5 18.7)
TRONROUT0000000029474789;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355901.3 6689827.3 18.7, 355888.8 6689852.5 19)
TRONROUT0000000029474457;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;110;43;110;39;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (355951.1 6689831.5 18.7, 356005.2 6689855.3 18.9)
TRONROUT0000000029474994;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356005.2 6689855.3 18.9, 356012.3 6689858.5 19.4)
TRONROUT0000000029473783;Route à 1 chaussée;R LABOUCHERE;R LABOUCHERE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;5;6;5;6;44109;44109;;;;441094732;441094732;;;;;;;;;;;;;commune;commune;Rue Labouchère;Rue Labouchère;;;44109_4732;44109_4732;;;;;LINESTRING Z (355920.5 6689891.4 18.7, 355939.8 6689854.8 19.5, 355951.1 6689831.5 18.7)
TRONROUT0000000029473574;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;94;85;94;93;44109;44109;;;;441095368;441095368;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (355917.3 6689887.6 19.5, 355898.1 6689864.6 19.1, 355888.8 6689852.5 19)
TRONROUT0000000029474791;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;108;;108;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356012.3 6689858.5 19.4, 356023.8 6689863.6 14, 356071.3 6689884.9 18.9)
TRONROUT0000000029474067;Route à 1 chaussée;PL DU PILORI;PL DU PILORI;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;1;;2;44109;44109;;;;441096628;441096628;;;;;;;;;;;;;commune;commune;Place du Pilori;Place du Pilori;;;44109_6628;44109_6628;;;;;LINESTRING Z (355627.1 6689470.2 10.2, 355618.3 6689489 10)
TRONROUT0000000029474831;Route à 1 chaussée;R DE VERDUN;R DE VERDUN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;39;;39;;44109;44109;;;;441098344;441098344;;;;;;;;;;;;;commune;commune;Rue de Verdun;Rue de Verdun;;;44109_8344;44109_8344;;;;;LINESTRING Z (355620.9 6689492.2 11.4, 355618.3 6689489 10)
TRONROUT0000000029473661;Route à 1 chaussée;R DE BRIORD;R DE BRIORD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;18;15;4;3;44109;44109;;;;441091256;441091256;;;;;;;;;;;;;commune;commune;Rue de Briord;Rue de Briord;;;44109_1256;44109_1256;;;;;LINESTRING Z (355596.8 6689582.3 12.4, 355599.6 6689550.9 12.3, 355600.6 6689533.1 12.3, 355602.2 6689524.3 12.3, 355607.9 6689512.4 12.3, 355620.9 6689492.2 11.4)
TRONROUT0000000029473870;Route à 1 chaussée;R FENELON;R FENELON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;7;2B;5;44109;44109;;;;441093096;441093096;;;;;;;;;;;;;commune;commune;Rue Fénelon;Rue Fénelon;;;44109_3096;44109_3096;;;;;LINESTRING Z (355498.8 6689579.1 8.6, 355514.9 6689580.6 8.4, 355527.1 6689581.1 8.4, 355535.2 6689582.4 8.4, 355554.8 6689590.2 10.5)
TRONROUT0000000322228670;Route à 1 chaussée;R DE BRIORD;R DE BRIORD;5;Non;0;En service;2013-05-21 12:16:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441091256;441091256;;;;;;;;;;;;;commune;commune;Rue de Briord;Rue de Briord;;;44109_1256;44109_1256;;;;;LINESTRING Z (355588.5 6689604.6 12.3, 355593.1 6689593.5 12.4, 355596.8 6689582.3 12.4)
TRONROUT0000000029473936;Route à 1 chaussée;R FENELON;R FENELON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;3;2;3;44109;44109;;;;441093096;441093096;;;;;;;;;;;;;commune;commune;Rue Fénelon;Rue Fénelon;;;44109_3096;44109_3096;;;;;LINESTRING Z (355554.8 6689590.2 10.5, 355566.8 6689596.3 8.4, 355588.5 6689604.6 12.3)
TRONROUT0000000029473684;Route à 1 chaussée;R BEAUSOLEIL;R BEAUSOLEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;9;12;1;44109;44109;;;;441090660;441090660;;;;;;;;;;;;;commune;commune;Rue Beau-Soleil;Rue Beau-Soleil;;;44109_hxw9r1;44109_hxw9r1;;;;;LINESTRING Z (355588.5 6689604.6 12.3, 355597.7 6689600.7 12.8, 355619.2 6689599.6 12.8, 355641.1 6689600.7 12.9, 355662.1 6689603.4 13.4)
TRONROUT0000000029475016;Route à 1 chaussée;R FLECHIER;R FLECHIER;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;3;2;3;44109;44109;;;;441093144;441093144;;;;;;;;;;;;;commune;commune;Rue Fléchier;Rue Fléchier;;;44109_3144;44109_3144;;;;;LINESTRING Z (355543.3 6689626 10.5, 355546 6689617.2 10.5, 355549.9 6689604.5 10.5, 355554.8 6689590.2 10.5)
TRONROUT0000000029474462;Route à 1 chaussée;R FANNY PECCOT;R FANNY PECCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;3;;3;;44109;44109;;;;441093020;441093020;;;;;;;;;;;;;commune;commune;Rue Fanny Peccot;Rue Fanny Peccot;;;44109_3020;44109_3020;;;;;LINESTRING Z (355543.3 6689626 10.5, 355552.4 6689621.3 10.7, 355588.5 6689604.6 12.3)
TRONROUT0000000029475191;Route à 1 chaussée;R FANNY PECCOT;R FANNY PECCOT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441093020;441093020;;;;;;;;;;;;;commune;commune;Rue Fanny Peccot;Rue Fanny Peccot;;;44109_3020;44109_3020;;;;;LINESTRING Z (355524.6 6689639.6 10.3, 355543.3 6689626 10.5)
TRONROUT0000000029475234;Route à 1 chaussée;R DES TROIS CROISSANTS;R DES TROIS CROISSANTS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;7.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098224;441098224;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue des Trois Croissants;Rue des Trois Croissants;;;44109_8224;44109_8224;;;;;LINESTRING Z (355364.8 6689503.8 7.1, 355348.4 6689496.2 10.1)
TRONROUT0000000029473915;Route à 1 chaussée;PL DE L'ECLUSE;PL DE L'ECLUSE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;4;;4;;44109;44109;;;;441092680;441092680;;;;;;;;;;;;;commune;commune;Place de l'Ecluse;Place de l'Ecluse;;;44109_2680;44109_2680;;;;;LINESTRING Z (355359.5 6689532.1 6.4, 355363.6 6689511.1 7.2, 355364.8 6689503.8 7.1)
TRONROUT0000000029475035;Route à 1 chaussée;PL DE L'ECLUSE;PL DE L'ECLUSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092680;441092680;;;;;;;;;;;;;commune;commune;Place de l'Ecluse;Place de l'Ecluse;;;44109_2680;44109_2680;;;;;LINESTRING Z (355345.7 6689530.7 6.4, 355359.5 6689532.1 6.4)
TRONROUT0000000029474518;Route à 1 chaussée;ALL D'ORLEANS;ALL D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;21;;17;44109;44109;;;;441096052;441096052;;;;;;;;;;;;;commune;commune;Allée d'Orléans;Allée d'Orléans;;;44109_6052;44109_6052;;;;;LINESTRING Z (355296.9 6689586.4 8.3, 355302.5 6689560.7 7.5, 355307.4 6689539.5 7.5, 355312.1 6689519.8 8, 355316.7 6689500.4 8.1, 355321.3 6689480.1 8.1)
TRONROUT0000000029473476;Sentier;PAS CELINE SIMON;PAS CELINE SIMON;6;Non;0;En service;2006-10-04 09:41:10;2012-09-28 17:45:51;;;;;BDParcellaire;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#076;44109#076;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355402.6 6689536 -1000, 355363.7 6689531.9 -1000, 355359.5 6689532.1 6.4)
TRONROUT0000000029474786;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355343 6689499.1 10, 355339 6689513.3 9, 355331.2 6689544.2 6.9, 355323.5 6689585.6 6.7)
TRONROUT0000000029473837;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;;2;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355335 6689587.4 7.3, 355339.2 6689563.9 7.1, 355342.7 6689546.2 6.7, 355345.7 6689530.7 6.5)
TRONROUT0000000029473602;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;3;10;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355359.5 6689532.1 6.4, 355365 6689592 7)
TRONROUT0000000317258110;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355306.3 6689635.9 8.8, 355309 6689629.8 8.9, 355311.7 6689622.4 9.1, 355314.3 6689602.7 9.2, 355317.6 6689585.1 9.4, 355324.6 6689544.3 9.5, 355328.3 6689519.6 9.7, 355333.8 6689498.2 9.8, 355336.1 6689494.1 10)
TRONROUT0000000317258130;Route à 1 chaussée;;;6;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355309.2 6689636.3 8.8, 355314.6 6689623.8 9, 355320.8 6689585.1 9.2, 355328.1 6689545.9 9.4, 355329.8 6689534.3 9.4, 355333.5 6689515.9 9.6, 355336.3 6689505.6 9.8, 355339 6689498.3 10)
TRONROUT0000000029474906;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;21;20;23;22;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355499 6689558.8 8.5, 355499.6 6689570.9 8.5, 355498.8 6689579.1 8.6)
TRONROUT0000000029473862;Route à 1 chaussée;R BOSSUET;R BOSSUET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;13;2;1;44109;44109;;;;441091056;441091056;;;;;;;;;;;;;commune;commune;Rue Bossuet;Rue Bossuet;;;44109_1056;44109_1056;;;;;LINESTRING Z (355463.4 6689545.3 8.6, 355459.7 6689561.1 8.6, 355458.6 6689572.6 8.7, 355458.7 6689586.6 8.6, 355459.8 6689591.7 8.6, 355461.4 6689596.2 8.7, 355466.5 6689603.5 8.7, 355483.5 6689615.2 8.9)
TRONROUT0000000029475247;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;23;;27;;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355498.8 6689579.1 8.6, 355486.3 6689610.5 9, 355483.5 6689615.2 8.9)
TRONROUT0000000029473652;Route à 1 chaussée;R SAINT-LEONARD;R SAINT-LEONARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;21;14;23;18;44109;44109;;;;441097672;441097672;;;;;;;;;;;;;commune;commune;Rue Saint Léonard;Rue Saint Léonard;;;44109_7672;44109_7672;;;;;LINESTRING Z (355426.2 6689586.3 6.5, 355423.5 6689610.4 7, 355427 6689633.3 7.1, 355431 6689659.2 7.1)
TRONROUT0000000029473839;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;29;;29;;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355483.5 6689615.2 8.9, 355480.5 6689620.8 9, 355479.1 6689624.8 9, 355475.2 6689645.9 9.2)
TRONROUT0000000029474192;Route à 1 chaussée;PL DE L'HOTEL DE VILLE;PL DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GH;44109#0GH;;;;;;;;;;;;;commune;commune;Place de l'Hôtel de Ville;Place de l'Hôtel de Ville;;;44109_4236;44109_4236;;;;;LINESTRING Z (355475.2 6689645.9 9.2, 355495.5 6689646.3 9.7, 355505.9 6689645.3 9.9, 355516 6689643.3 10.3, 355524.6 6689639.6 10.3)
TRONROUT0000000029474712;Route à 1 chaussée;R DU MOULIN;R DU MOULIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095820;441095820;;;;;;;;;;;;;commune;commune;Rue du Moulin;Rue du Moulin;;;44109_5820;44109_5820;;;;;LINESTRING Z (355473.7 6689656.3 8.6, 355474.3 6689651.7 8.8, 355475.2 6689645.9 9.2)
TRONROUT0000000029474294;Route à 1 chaussée;PL DE L'HOTEL DE VILLE;PL DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GH;44109#0GH;;;;;;;;;;;;;commune;commune;Place de l'Hôtel de Ville;Place de l'Hôtel de Ville;;;44109_4236;44109_4236;;;;;LINESTRING Z (355496.7 6689656.9 9.5, 355488.8 6689656.1 9.3, 355473.7 6689656.3 8.6)
TRONROUT0000000029473648;Route à 1 chaussée;R DE L'HOTEL DE VILLE;R DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;;5;;44109;44109;;;;441094237;441094237;;;;;;;;;;;;;commune;commune;Rue de l'Hôtel de Ville;Rue de l'Hôtel de Ville;;;44109_4237;44109_4237;;;;;LINESTRING Z (355473.7 6689656.3 8.6, 355431 6689659.2 7.1)
TRONROUT0000000029473673;Route à 1 chaussée;R DE L'HOTEL DE VILLE;R DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;6;13;4;7;44109;44109;;;;441094237;441094237;;;;;;;;;;;;;commune;commune;Rue de l'Hôtel de Ville;Rue de l'Hôtel de Ville;;;44109_4237;44109_4237;;;;;LINESTRING Z (355369.3 6689665.8 6.3, 355431 6689659.2 7.1)
TRONROUT0000000317258094;Route à 1 chaussée;;;5;Non;0;En service;2013-01-10 17:06:11;2020-02-12 17:33:37;;;;;Levé non GPS;5.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355335 6689587.4 7.3, 355323.5 6689585.6 6.7)
TRONROUT0000000029474211;Route à 1 chaussée;R DU CHEVAL BLANC;R DU CHEVAL BLANC;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441091852;441091852;;;;;;;;;;;;;commune;commune;Rue du Cheval Blanc;Rue du Cheval Blanc;;;44109_1852;44109_1852;;;;;LINESTRING Z (355365 6689592 7, 355365.8 6689587.8 7, 355367.9 6689584.9 6.5, 355370.7 6689582.8 6.6, 355374.2 6689582.4 6.7, 355426.2 6689586.3 6.5)
TRONROUT0000000029474308;Route à 1 chaussée;PL DES PETITS MURS;PL DES PETITS MURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;;4;;44109;44109;;;;441096544;441096544;;;;;;;;;;;;;commune;commune;Place des Petits Murs;Place des Petits Murs;;;44109_6544;44109_6544;;;;;LINESTRING Z (355335 6689587.4 7.3, 355365 6689592 7)
TRONROUT0000000317258095;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355323.5 6689585.6 6.7, 355317.5 6689624.8 6.9, 355311.8 6689638.2 7)
TRONROUT0000000029475239;Route à 1 chaussée;ALL D'ORLEANS;ALL D'ORLEANS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;22;;24;;44109;44109;;;;441096052;441096052;;;;;;;;;;;;;commune;commune;Allée d'Orléans;Allée d'Orléans;;;44109_6052;44109_6052;;;;;LINESTRING Z (355296.9 6689586.4 8.3, 355291.8 6689611.2 7.6, 355285.5 6689639.8 7.7, 355284.3 6689643.7 7.6)
TRONROUT0000000029473816;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;;4;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355325.8 6689657.7 7.1, 355326.9 6689642.5 7.3, 355328.4 6689629.4 7.3, 355330.2 6689615.5 7.3, 355332.5 6689600.4 7.4, 355335 6689587.4 7.3)
TRONROUT0000000029473679;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;12;9;18;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355369.3 6689665.8 6.3, 355366.1 6689610.4 6.2, 355365 6689592 7)
TRONROUT0000000317258142;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355306.3 6689635.9 8.8, 355309.2 6689636.3 8.8)
TRONROUT0000000317258112;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355309.2 6689636.3 8.8, 355311.8 6689638.2 8.7)
TRONROUT0000000029474329;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355299.9 6689644 8.9, 355300.3 6689641.1 8.9, 355301.5 6689639.2 8.8, 355303 6689637.5 8.8, 355306.3 6689635.9 8.8)
TRONROUT0000000029473940;Route à 1 chaussée;R SAINT-VINCENT;R SAINT-VINCENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;3;2;3;44109;44109;;;;441097768;441097768;;;;;;;;;;;;;commune;commune;Rue Saint Vincent;Rue Saint Vincent;;;44109_7768;44109_7768;;;;;LINESTRING Z (355588.4 6689668.3 12.3, 355586.9 6689625.7 12.5, 355588.5 6689604.6 12.3)
TRONROUT0000000029474465;Route à 1 chaussée;PL DE L'HOTEL DE VILLE;PL DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GH;44109#0GH;;;;;;;;;;;;;commune;commune;Place de l'Hôtel de Ville;Place de l'Hôtel de Ville;;;44109_4236;44109_4236;;;;;LINESTRING Z (355524.6 6689639.6 10.3, 355527.2 6689643.2 10.3, 355528.3 6689649.2 10.3, 355528.7 6689655.8 10.3, 355527.6 6689660.4 10.4)
TRONROUT0000000295264907;Route à 1 chaussée;PL DE L'HOTEL DE VILLE;PL DE L'HOTEL DE VILLE;5;Non;0;En service;2012-02-08 10:00:49;2023-02-01 08:20:10;;;;;BDTopo;2.5;BDTopo;1.5;3.0;9.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GH;44109#0GH;;;;;;;;;;;;;commune;commune;Place de l'Hôtel de Ville;Place de l'Hôtel de Ville;;;44109_4236;44109_4236;;;;;LINESTRING Z (355527.6 6689660.4 10.4, 355496.7 6689656.9 9.5)
TRONROUT0000000029474382;Route à 1 chaussée;R GENERAL LECLERC DE HAUTECLOCQUE;R GENERAL LECLERC DE HAUTECLOCQUE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;3.0;9.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;9;;11;;44109;44109;;;;441093596;441093596;;;;;;;;;;;;;commune;commune;Rue Général Leclerc de Hautecloque;Rue Général Leclerc de Hautecloque;;;44109_3596;44109_3596;;;;;LINESTRING Z (355588.4 6689668.3 12.3, 355527.6 6689660.4 10.4)
TRONROUT0000000295265082;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2023-02-01 08:20:10;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355524.6 6689676.1 10.4, 355513 6689668.8 10.4, 355505 6689662.3 9.8, 355496.7 6689656.9 9.5)
TRONROUT0000000029474375;Route à 1 chaussée;R DE LA COMMUNE;R DE LA COMMUNE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;5;4;5;44109;44109;;;;441092100;441092100;;;;;;;;;;;;;commune;commune;Rue de la Commune;Rue de la Commune;;;44109_2100;44109_2100;;;;;LINESTRING Z (355527.6 6689660.4 10.4, 355527.3 6689666.7 10.4, 355526.7 6689671.7 10.4, 355526.9 6689674.4 10.4)
TRONROUT0000000029474785;Route à 1 chaussée;R GENERAL LECLERC DE HAUTECLOCQUE;R GENERAL LECLERC DE HAUTECLOCQUE;5;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;BDTopo;2.5;BDTopo;1.5;3.0;9.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;;7;;44109;44109;;;;441093596;441093596;;;;;;;;;;;;;commune;commune;Rue Général Leclerc de Hautecloque;Rue Général Leclerc de Hautecloque;;;44109_3596;44109_3596;;;;;LINESTRING Z (355627.1 6689673.3 12.9, 355588.4 6689668.3 12.3)
TRONROUT0000000295264899;Route à 1 chaussée;R SAINT-VINCENT;R SAINT-VINCENT;5;Non;0;En service;2012-02-08 10:00:49;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;9;;9;;44109;44109;;;;441097768;441097768;;;;;;;;;;;;;commune;commune;Rue Saint Vincent;Rue Saint Vincent;;;44109_7768;44109_7768;;;;;LINESTRING Z (355589.4 6689681.6 12.4, 355588.4 6689668.3 12.3)
TRONROUT0000000295265231;Route à 1 chaussée;R DE LA COMMUNE;R DE LA COMMUNE;5;Non;0;En service;2012-02-08 10:00:49;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092100;441092100;;;;;;;;;;;;;commune;commune;Rue de la Commune;Rue de la Commune;;;44109_2100;44109_2100;;;;;LINESTRING Z (355526.9 6689674.4 10.4, 355524.6 6689676.1 10.4)
TRONROUT0000000295265256;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2023-02-01 08:20:10;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355589.4 6689681.6 12.4, 355564.4 6689678.7 11.9, 355538.2 6689675.7 10.8, 355526.9 6689674.4 10.4)
TRONROUT0000000317258111;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355311.8 6689638.2 8.7, 355312.9 6689642.4 8.7, 355312.5 6689645.9 8.7, 355311 6689647.8 8.7)
TRONROUT0000000029475034;Route à 1 chaussée;PL DU CIRQUE;PL DU CIRQUE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091916;441091916;;;;;;;;;;;;;commune;commune;Place du Cirque;Place du Cirque;;;44109_1916;44109_1916;;;;;LINESTRING Z (355284.3 6689643.7 7.6, 355299.9 6689644 7.1)
TRONROUT0000000029474330;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355302.7 6689648.9 8.9, 355301 6689647.9 8.9, 355300.3 6689646.4 8.9, 355299.9 6689644 8.9)
TRONROUT0000000317258141;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355311 6689647.8 8.7, 355309.3 6689649.1 8.7, 355307.2 6689649.6 8.7, 355306.7 6689649.7 8.8, 355302.7 6689648.9 8.9)
TRONROUT0000000029473812;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355311 6689647.8 8.7, 355312.5 6689656.5 8.5, 355312.6 6689661.5 8.4)
TRONROUT0000000029474287;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355305.2 6689662.1 8.6, 355304.1 6689655.1 8.9, 355302.7 6689648.9 8.9)
TRONROUT0000000029474575;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355305.2 6689662.1 8.6, 355308.5 6689661.1 8.7, 355312.6 6689661.5 8.7)
TRONROUT0000000317258089;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;6;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355325.3 6689669.5 6.3, 355325.8 6689657.7 7.1)
TRONROUT0000000029474331;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355312.6 6689661.5 8.4, 355315.8 6689663.5 8.4, 355316.9 6689666.3 8.4, 355317.1 6689669.1 8.4)
TRONROUT0000000317258155;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355305.2 6689672.5 8.6, 355303.8 6689669.1 8.6, 355303.6 6689665.6 8.6, 355305.2 6689662.1 8.6)
TRONROUT0000000029473670;Route à 1 chaussée;R DE L'HOTEL DE VILLE;R DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;10B;;8;;44109;44109;;;;441094237;441094237;;;;;;;;;;;;;commune;commune;Rue de l'Hôtel de Ville;Rue de l'Hôtel de Ville;;;44109_4237;44109_4237;;;;;LINESTRING Z (355325.3 6689669.5 6.3, 355369.3 6689665.8 6.3)
TRONROUT0000000029473643;Route à 1 chaussée;R DE L'HOTEL DE VILLE;R DE L'HOTEL DE VILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441094237;441094237;;;;;;;;;;;;;commune;commune;Rue de l'Hôtel de Ville;Rue de l'Hôtel de Ville;;;44109_4237;44109_4237;;;;;LINESTRING Z (355317.1 6689669.1 6.7, 355323.4 6689669.7 6.3, 355325.3 6689669.5 6.3)
TRONROUT0000000029474522;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355317.1 6689669.1 8.4, 355316.1 6689671 8.4, 355315.2 6689672.4 8.4, 355312.7 6689674.6 8.4, 355310 6689675.2 8.4)
TRONROUT0000000317258138;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355307.7 6689675 8.5, 355305.2 6689672.5 8.6)
TRONROUT0000000029474438;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355324.5 6689679 6.4, 355325.3 6689673.4 6.8, 355325.3 6689669.5 6.3)
TRONROUT0000000029474921;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355310 6689675.2 8.4, 355307.7 6689675 8.5)
TRONROUT0000000029474537;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;24;13;22;13;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355371.9 6689701.5 6.1, 355369.3 6689665.8 6.3)
TRONROUT0000000317258097;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355310 6689675.2 6.8, 355308.3 6689686.1 6.6, 355309.8 6689713.6 5.8)
TRONROUT0000000317258103;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;8;;8;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355324.6 6689710.5 5.9, 355324.2 6689698 5.9, 355324.3 6689686.9 6, 355324.5 6689679 6.4)
TRONROUT0000000029474029;Route à 1 chaussée;R DU MARAIS;R DU MARAIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;7;8;7;44109;44109;;;;441095296;441095296;;;;;;;;;;;;;commune;commune;Rue du Marais;Rue du Marais;;;44109_5296;44109_5296;;;;;LINESTRING Z (355337.8 6689708 5.9, 355371.9 6689701.5 6.1)
TRONROUT0000000295265239;Route à 1 chaussée;R DE LA COMMUNE;R DE LA COMMUNE;5;Non;0;En service;2012-02-08 10:00:49;2023-03-17 03:41:53;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;3;2;44109;44109;;;;441092100;441092100;;;;;;;;;;;;;commune;commune;Rue de la Commune;Rue de la Commune;;;44109_2100;44109_2100;;;;;LINESTRING Z (355558 6689702.3 11.5, 355549.3 6689695.7 11, 355536.6 6689686 10.7, 355524.6 6689676.1 10.4)
TRONROUT0000000029473763;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;34;27;34;27;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355608.9 6689709.2 13, 355627.1 6689673.3 12.9)
TRONROUT0000000029473592;Route à 1 chaussée;R SAINT-VINCENT;R SAINT-VINCENT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;11;10;11;10;44109;44109;;;;441097768;441097768;;;;;;;;;;;;;commune;commune;Rue Saint Vincent;Rue Saint Vincent;;;44109_7768;44109_7768;;;;;LINESTRING Z (355587.4 6689714.1 12.7, 355588.4 6689709.5 12.6, 355589.3 6689703.7 12.5, 355589.4 6689681.6 12.4)
TRONROUT0000002329005887;Route à 1 chaussée;R DE LA COMMUNE;R DE LA COMMUNE;5;Non;0;En service;2023-02-01 08:20:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;3;2;44109;44109;;;;441092100;441092100;;;;;;;;;;;;;commune;commune;Rue de la Commune;Rue de la Commune;;;44109_2100;44109_2100;;;;;LINESTRING Z (355558 6689702.3 11.5, 355565.2 6689705.5 12.2, 355576.8 6689709.6 12.5, 355587.4 6689714.1 12.7)
TRONROUT0000000029474153;Route à 1 chaussée;R NOTRE DAME;R NOTRE DAME;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;6;;6;44109;44109;;;;441095972;441095972;;;;;;;;;;;;;commune;commune;Rue Notre Dame;Rue Notre Dame;;;44109_5972;44109_5972;;;;;LINESTRING Z (355651.6 6689707.4 14.1, 355608.9 6689709.2 13)
TRONROUT0000000029475103;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2023-02-01 08:20:10;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;36;;36;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355599.9 6689727.2 12.7, 355608.9 6689709.2 13)
TRONROUT0000000029473835;Route à 1 chaussée;R DE LA COMMUNE;R DE LA COMMUNE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441092100;441092100;;;;;;;;;;;;;commune;commune;Rue de la Commune;Rue de la Commune;;;44109_2100;44109_2100;;;;;LINESTRING Z (355599.9 6689727.2 12.7, 355589.7 6689718.9 12.7, 355587.4 6689714.1 12.7)
TRONROUT0000000029475039;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2023-02-01 08:20:10;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;38;;38;;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355596.6 6689733.6 12.6, 355599.9 6689727.2 12.7)
TRONROUT0000000029473769;Route à 1 chaussée;R SAINT-JEAN;R SAINT-JEAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;8;;8;44109;44109;;;;441097648;441097648;;;;;;;;;;;;;commune;commune;Rue Saint Jean;Rue Saint Jean;;;44109_7648;44109_7648;;;;;LINESTRING Z (355596.6 6689733.6 12.6, 355607.9 6689775 12.5)
TRONROUT0000000029475009;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;42;29;40;29;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355566.7 6689792.7 11.2, 355582.9 6689760.6 11.9, 355596.6 6689733.6 12.6)
TRONROUT0000000029474129;Route à 1 chaussée;R DU MARAIS;R DU MARAIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;14;;14;;44109;44109;;;;441095296;441095296;;;;;;;;;;;;;commune;commune;Rue du Marais;Rue du Marais;;;44109_5296;44109_5296;;;;;LINESTRING Z (355324.6 6689710.5 5.9, 355337.8 6689708 5.9)
TRONROUT0000000317258096;Route à 1 chaussée;R DU MARAIS;R DU MARAIS;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;Levé non GPS;5.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441095296;441095296;;;;;;;;;;;;;commune;commune;Rue du Marais;Rue du Marais;;;44109_5296;44109_5296;;;;;LINESTRING Z (355324.6 6689710.5 5.9, 355309.8 6689713.6 5.8)
TRONROUT0000000317258117;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355344.9 6689808.8 5.7, 355340 6689804.5 5.9, 355330.8 6689792.2 6.2, 355319.2 6689774.1 6.4, 355312.7 6689759.4 6.7, 355308.3 6689747.6 7, 355305.2 6689734.1 7.2, 355304 6689726.2 7.5, 355302.5 6689713.4 7.8, 355302.5 6689690.7 8, 355303.5 6689677.7 8.3, 355305.2 6689672.5 8.6)
TRONROUT0000000317258145;Route à 1 chaussée;;;6;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355346.9 6689806.8 5.7, 355338.9 6689797.9 6, 355324 6689775.6 6.4, 355316.6 6689760.6 6.7, 355310.1 6689744.1 7.1, 355307.6 6689728.8 7.4, 355305.7 6689713.3 7.8, 355306.4 6689681.4 8.1, 355307.7 6689675 8.5)
TRONROUT0000000029473692;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;28;25;26;15;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355379.9 6689784.5 5.7, 355371.9 6689701.5 6.1)
TRONROUT0000000029473498;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;13;;9;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355372.5 6689802.1 5.9, 355359.7 6689791.6 5.9, 355348.3 6689781.1 5.9, 355341.4 6689772.9 5.8, 355335.5 6689764.3 5.5, 355329.8 6689752.5 5.5, 355327.6 6689743.9 5.5, 355325.5 6689730.3 5.5, 355324.3 6689716.5 5.5, 355324.6 6689710.5 5.9)
TRONROUT0000000029474381;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355309.8 6689713.6 5.8, 355311 6689731.7 5.6, 355315.8 6689751 5.6, 355323.3 6689767.4 5.6, 355335.1 6689786.9 5.5, 355349.8 6689806 5.7)
TRONROUT0000000029473556;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;;6;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355284.3 6689746.1 6.2, 355288.1 6689760.3 6.2, 355291.9 6689772.7 6.2, 355296.3 6689783.7 6.3)
TRONROUT0000000029474046;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355380.8 6689809.9 5.9, 355379.9 6689784.5 5.7)
TRONROUT0000000317258091;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;7;;10;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355296.3 6689783.7 6.3, 355301.1 6689793.6 6.3, 355309.6 6689805.8 6, 355318.6 6689817.9 6)
TRONROUT0000000029474085;Route à 1 chaussée;R SAINT-LEONARD;R SAINT-LEONARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;29;;29;;44109;44109;;;;441097672;441097672;;;;;;;;;;;;;commune;commune;Rue Saint Léonard;Rue Saint Léonard;;;44109_7672;44109_7672;;;;;LINESTRING Z (355431 6689659.2 7.1, 355435.9 6689690.2 6.9)
TRONROUT0000000029473832;Route à 1 chaussée;R DU MARAIS;R DU MARAIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;3;2;1;44109;44109;;;;441095296;441095296;;;;;;;;;;;;;commune;commune;Rue du Marais;Rue du Marais;;;44109_5296;44109_5296;;;;;LINESTRING Z (355371.9 6689701.5 6.1, 355435.9 6689690.2 6.9)
TRONROUT0000000029474416;Route à 1 chaussée;R SAINT-LEONARD;R SAINT-LEONARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;31;;35;;44109;44109;;;;441097672;441097672;;;;;;;;;;;;;commune;commune;Rue Saint Léonard;Rue Saint Léonard;;;44109_7672;44109_7672;;;;;LINESTRING Z (355435.9 6689690.2 6.9, 355438.1 6689701.9 6.9, 355460 6689762.1 7.3)
TRONROUT0000000029473871;Route à 1 chaussée;R SAINT-LEONARD;R SAINT-LEONARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;37;;37;;44109;44109;;;;441097672;441097672;;;;;;;;;;;;;commune;commune;Rue Saint Léonard;Rue Saint Léonard;;;44109_7672;44109_7672;;;;;LINESTRING Z (355460 6689762.1 7.3, 355449.8 6689764.5 7.4)
TRONROUT0000000029474787;Route à 1 chaussée;R LEON BLUM;R LEON BLUM;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;7;;44109;44109;;;;441094900;441094900;;;;;;;;;;;;;commune;commune;Rue Léon Blum;Rue Léon Blum;;;44109_4900;44109_4900;;;;;LINESTRING Z (355449.8 6689764.5 7.4, 355453.7 6689777.6 7.2)
TRONROUT0000000029473685;Route à 1 chaussée;R SIMEON FOUCAULT;R SIMEON FOUCAULT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;5;2;44109;44109;;;;441097908;441097908;;;;;;;;;;;;;commune;commune;Rue Siméon Foucault;Rue Siméon Foucault;;;44109_7908;44109_7908;;;;;LINESTRING Z (355449.8 6689764.5 7.4, 355441.7 6689766.3 7.2, 355379.9 6689784.5 5.7)
TRONROUT0000000029474323;Route à 1 chaussée;R GARDE DIEU;R GARDE DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;14;17;6;5;44109;44109;;;;441093460;441093460;;;;;;;;;;;;;commune;commune;Rue Garde Dieu;Rue Garde Dieu;;;44109_3460;44109_3460;;;;;LINESTRING Z (355453.7 6689777.6 7.2, 355466.1 6689778.9 7.7, 355542.5 6689786.7 10.7)
TRONROUT0000000029473583;Route à 1 chaussée;R LEON BLUM;R LEON BLUM;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;9;2;21;16;44109;44109;;;;441094900;441094900;;;;;;;;;;;;;commune;commune;Rue Léon Blum;Rue Léon Blum;;;44109_4900;44109_4900;;;;;LINESTRING Z (355453.7 6689777.6 7.2, 355456.3 6689786.6 7.2, 355459.4 6689792.2 7.2, 355479.2 6689828 7.2, 355484.6 6689836.3 7.2, 355490.9 6689843.1 7.2, 355499 6689849.2 7.2, 355506 6689852.7 7.4)
TRONROUT0000000317258101;Route à 1 chaussée;ALL D'ERDRE;ALL D'ERDRE;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092868;441092868;;;;;;;;;;;;;commune;commune;Allée d'Erdre;Allée d'Erdre;;;44109_2868;44109_2868;;;;;LINESTRING Z (355484.6 6689893.2 7.3, 355471.8 6689887.6 7.3, 355461.1 6689882.6 7, 355454.2 6689877.5 6.8, 355436.1 6689862.9 6.6, 355417.9 6689845.9 6.5, 355404.4 6689833.2 6.5, 355395.3 6689824.6 6.5, 355389.5 6689819 6.4, 355385.7 6689813.4 6.3, 355380.8 6689809.9 5.9)
TRONROUT0000000029473519;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355381.3 6689825.1 7.6, 355399.9 6689838.3 7.7, 355414 6689852.5 8.2, 355427.1 6689864.4 6.8, 355437.2 6689873.7 8.2, 355451.4 6689884.8 8.2, 355468 6689893.8 7.8, 355490.3 6689904.6 7.7, 355497.3 6689911.2 8.1)
TRONROUT0000000029475310;Route à 1 chaussée;R DU REFUGE;R DU REFUGE;5;Non;0;En service;2006-10-04 09:41:10;2023-06-01 18:29:00;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;2;2;4;44109;44109;;;;441097172;441097172;;;;;;;;;;;;;commune;commune;Rue du Refuge;Rue du Refuge;;;44109_7172;44109_7172;;;;;LINESTRING Z (355683.4 6689742.5 16.2, 355682.2 6689769.5 15.9)
TRONROUT0000000029474627;Route à 1 chaussée;R DU ROI ALBERT;R DU ROI ALBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;3;4;3;44109;44109;;;;441097428;441097428;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue du Roi Albert;Rue du Roi Albert;;;44109_7428;44109_7428;;;;;LINESTRING Z (355751.3 6689773.7 16.3, 355762 6689755.8 17)
TRONROUT0000000029473821;Route à 1 chaussée;R DES CORDELIERS;R DES CORDELIERS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;;7;;44109;44109;;;;441092160;441092160;;;;;;;;;;;;;commune;commune;Rue des Cordeliers;Rue des Cordeliers;;;44109_2160;44109_2160;;;;;LINESTRING Z (355682.2 6689769.5 15.9, 355607.9 6689775 12.5)
TRONROUT0000000029473624;Route à 1 chaussée;R DU REFUGE;R DU REFUGE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;6;7;12;44109;44109;;;;441097172;441097172;;;;;;;;;;;;;commune;commune;Rue du Refuge;Rue du Refuge;;;44109_7172;44109_7172;;;;;LINESTRING Z (355648.5 6689879.5 11.2, 355656 6689866.6 10.2, 355681.2 6689824.1 13.7, 355679.3 6689798.9 15.4, 355682.2 6689769.5 15.9)
TRONROUT0000000029473501;Route à 1 chaussée;R DU ROI ALBERT;R DU ROI ALBERT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;16;19;6;5;44109;44109;;;;441097428;441097428;;;;;;;;;;;;;commune;commune;Rue du Roi Albert;Rue du Roi Albert;;;44109_7428;44109_7428;;;;;LINESTRING Z (355678 6689897.1 11.6, 355696.3 6689866.3 12.7, 355714.9 6689834.9 13.9, 355734.7 6689801.6 15.2, 355751.3 6689773.7 16.3)
TRONROUT0000000029474230;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355648.5 6689879.5 11.2, 355663.6 6689888.5 11.4, 355668 6689891.1 11.4)
TRONROUT0000000295264906;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355668 6689891.1 11.4, 355678 6689897.1 11.6)
TRONROUT0000000029473777;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355678 6689897.1 11.6, 355687.5 6689903.1 11.7)
TRONROUT0000000295264904;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;4;;4;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355687.5 6689903.1 11.7, 355705 6689914.1 12.1)
TRONROUT0000000295265092;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355668 6689891.1 11.4, 355657.3 6689910.3 11.4, 355647.2 6689926.2 10.5)
TRONROUT0000000029474327;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355836.8 6689838.4 18, 355815.7 6689832 21.6)
TRONROUT0000000029474932;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355885.1 6689861.4 18.9, 355836.8 6689838.4 18)
TRONROUT0000000029475178;Route à 1 chaussée;PL MARECHAL FOCH;PL MARECHAL FOCH;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;4.0;14.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095364;441095364;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Place Maréchal Foch;Place Maréchal Foch;;;44109_5364;44109_5364;;;;;LINESTRING Z (355888.8 6689852.5 19, 355885.1 6689861.4 18.9)
TRONROUT0000000029475173;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355885.1 6689861.4 18.9, 355876.8 6689888.2 19.5)
TRONROUT0000000029474941;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;2;;3;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355876.8 6689888.2 19.5, 355854.4 6689933.9 19.4)
TRONROUT0000000029474072;Route à 1 chaussée;R TOURNEFORT;R TOURNEFORT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;5;;3;44109;44109;;;;441098152;441098152;;;;;;;;;;;;;commune;commune;Rue Tournefort;Rue Tournefort;;;44109_8152;44109_8152;;;;;LINESTRING Z (355754.1 6689991.6 15.4, 355822.6 6689850.7 17.8, 355836.8 6689838.4 18)
TRONROUT0000000329622493;Sentier;COURS SAINT-ANDRE;COURS SAINT-ANDRE;6;Non;0;En service;2013-11-15 09:02:56;2023-06-01 17:51:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BS;44109#0BS;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355750.5 6690028.7 -1000, 355776.8 6689971.1 -1000, 355805.4 6689910.9 -1000, 355830.7 6689855.4 -1000, 355836.8 6689838.4 -1000)
TRONROUT0000000029475214;Route à 1 chaussée;IMP AUDRAN;IMP AUDRAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441090436;441090436;;;;;;;;;;;;;commune;commune;Impasse Audran;Impasse Audran;;;44109_0436;44109_0436;;;;;LINESTRING Z (355854.4 6689933.9 19.4, 355888.7 6689970.2 19.2)
TRONROUT0000000029474137;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.5;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;4;;5;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355854.4 6689933.9 19.4, 355827.5 6689989.2 16.3)
TRONROUT0000000029474127;Route à 1 chaussée;IMP VIGNOLLE;IMP VIGNOLLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;4;1;7;44109;44109;;;;441098496;441098496;;;;;;;;;;;;;commune;commune;Impasse Vignole;Impasse Vignole;;;44109_8496;44109_8496;;;;;LINESTRING Z (355827.5 6689989.2 16.3, 355849.9 6690009.6 16.3)
TRONROUT0000000029473981;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095368;441095368;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (355920.5 6689891.4 18.7, 355917.3 6689887.6 19.5)
TRONROUT0000000029475010;Route à 1 chaussée;R LEBRUN;R LEBRUN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;1;2;1;44109;44109;;;;441094852;441094852;;;;;;;;;;;;;commune;commune;Rue Lebrun;Rue Lebrun;;;44109_4852;44109_4852;;;;;LINESTRING Z (355876.8 6689888.2 19.5, 355898.6 6689899 19.5, 355917.3 6689887.6 19.5)
TRONROUT0000000029474619;Route à 1 chaussée;R DUGAST MATIFEUX;R DUGAST MATIFEUX;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;6;5;2;5;44109;44109;;;;441092608;441092608;;;;;;;;;;;;;commune;commune;Rue Dugast Matifeux;Rue Dugast Matifeux;;;44109_2608;44109_2608;;;;;LINESTRING Z (355969.1 6689931.9 20.9, 355985.9 6689909.2 20.5, 355989.7 6689902 20.4, 356009.7 6689863.7 19.5, 356012.3 6689858.5 19.4)
TRONROUT0000000029475113;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;90;91;72;77;44109;44109;;;;441095368;441095368;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (355962.1 6689941.4 21.3, 355920.5 6689891.4 18.7)
TRONROUT0000000029474060;Route à 1 chaussée;R DUGAST MATIFEUX;R DUGAST MATIFEUX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441092608;441092608;;;;;;;;;;;;;commune;commune;Rue Dugast Matifeux;Rue Dugast Matifeux;;;44109_2608;44109_2608;;;;;LINESTRING Z (355969.1 6689931.9 20.9, 355962.1 6689941.4 21.3)
TRONROUT0000000029473818;Route à 1 chaussée;IMP SAINT-CLEMENT;IMP SAINT-CLEMENT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;3;;1B;44109;44109;;;;441097556;441097556;;;;;;;;;;;;;commune;commune;Impasse Saint Clément;Impasse Saint Clément;;;44109_7556;44109_7556;;;;;LINESTRING Z (355969.1 6689931.9 20.9, 355995 6689947.3 20.3, 356003.3 6689954.6 20.1, 356012.5 6689963.3 20.1)
TRONROUT0000000029474311;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;72;75;44;47;44109;44109;;;;441095368;441095368;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (356023.8 6690015.3 20.3, 355962.1 6689941.4 21.3)
TRONROUT0000000029475116;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;42;47;38;41;44109;44109;;;;441095368;441095368;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (356046.7 6690042.9 20.7, 356023.8 6690015.3 20.3)
TRONROUT0000000029473897;Route à 1 chaussée;R GEOFFROY DROUET;R GEOFFROY DROUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;11;2;1;44109;44109;;;;441093648;441093648;;;;;;;;;;;;;commune;commune;Rue Geoffroy Drouet;Rue Geoffroy Drouet;;;44109_3648;44109_3648;;;;;LINESTRING Z (355991.7 6690062 16.7, 356023.8 6690015.3 20.3)
TRONROUT0000000029475083;Route à 1 chaussée;IMP FURET;IMP FURET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CF;44109#0CF;;;;;;;;;;;;;commune;commune;Impasse Furet;Impasse Furet;;;44109_3401;44109_3401;;;;;LINESTRING Z (355947.2 6690016.5 17.7, 355965 6690037.4 17.5, 355979.5 6690051.5 16.5, 355991.7 6690062 16.7)
TRONROUT0000000029475288;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355705 6689914.1 12.1, 355722.6 6689914.3 12)
TRONROUT0000000295265109;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355666.8 6689938.4 11, 355674.8 6689924.4 11.1, 355682.4 6689911.5 11.1, 355687.5 6689903.1 11.7)
TRONROUT0000000029474229;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355705 6689914.1 12.1, 355692.9 6689932.3 11.9, 355682.5 6689948.1 11.7)
TRONROUT0000000295264903;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355647.2 6689926.2 10.5, 355656.7 6689932.1 10.9, 355666.8 6689938.4 11)
TRONROUT0000000029473774;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355666.8 6689938.4 11, 355671.3 6689941.2 11.3, 355682.5 6689948.1 11.7)
TRONROUT0000000029473887;Route à 1 chaussée;R D'ARGENTRE;R D'ARGENTRE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;7;6;44109;44109;;;;441090356;441090356;;;;;;;;;;;;;commune;commune;Rue d'Argentré;Rue d'Argentré;;;44109_0356;44109_0356;;;;;LINESTRING Z (355754.1 6689991.6 15.4, 355682.5 6689948.1 11.7)
TRONROUT0000000029475232;Route à 1 chaussée;R TOURNEFORT;R TOURNEFORT;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;7;;7;44109;44109;;;;441098152;441098152;;;;;;;;;;;;;commune;commune;Rue Tournefort;Rue Tournefort;;;44109_8152;44109_8152;;;;;LINESTRING Z (355729.4 6690040.4 12.6, 355742.9 6690015.5 16.3, 355754.1 6689991.6 15.4)
TRONROUT0000002333155122;Route à 2 chaussées;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2023-06-01 17:51:00;2023-06-14 08:02:51;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens inverse;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355729.4 6690040.4 12.6, 355724.1 6690036.6 12.5, 355703.4 6690025.1 11.4, 355695.9 6690023.6 11.1)
TRONROUT0000002333155125;Escalier;;;6;Non;0;En service;2023-06-01 17:51:00;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355750.5 6690028.7 -1000, 355746.8 6690036.2 -1000, 355751.7 6690039.2 -1000)
TRONROUT0000002333155123;Route à 2 chaussées;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2023-06-01 17:51:00;2023-06-02 00:42:28;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355726.5 6690046.9 12.6, 355713.4 6690040.7 12.8, 355700.5 6690029.2 13.1, 355695.9 6690023.6 13.3)
TRONROUT0000000029475076;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;6;;7;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355827.5 6689989.2 16.3, 355797.5 6690050.6 14)
TRONROUT0000000329622494;Escalier;;;6;Non;0;En service;2013-11-15 09:02:56;2023-06-01 17:51:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355774.9 6690051.3 -1000, 355781.3 6690054.3 -1000, 355785.4 6690046.8 -1000)
TRONROUT0000000329622486;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2023-06-01 17:51:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355773.3 6690060.9 -1000, 355774.9 6690051.3 -1000)
TRONROUT0000000029474801;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355797.5 6690050.6 14, 355785.1 6690073.3 12.6)
TRONROUT0000002245069173;Sentier;;;6;Non;0;En service;2021-08-25 15:00:52;2023-06-01 17:51:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355771.6 6690067.4 -1000, 355773.3 6690060.9 -1000)
TRONROUT0000002245069171;Route à 1 chaussée;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2021-08-25 15:00:52;2023-06-02 00:42:28;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355773.3 6690060.9 -1000, 355776.8 6690062.9 -1000, 355785.1 6690073.3 -1000)
TRONROUT0000000029474432;Route à 1 chaussée;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355785.1 6690073.3 12.6, 355771.6 6690067.4 12.6)
TRONROUT0000000329622487;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2023-06-01 17:51:00;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355767.5 6690075.5 -1000, 355771.6 6690067.4 -1000)
TRONROUT0000000029474613;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;53;60;81;88;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (355797.5 6690050.6 14, 355846.4 6690078.2 14, 355869.8 6690089.6 13.3, 355943.9 6690115.8 12.4, 355952.6 6690118.9 12.3)
TRONROUT0000000029474825;Route à 1 chaussée;ALL DE VILLEBON;ALL DE VILLEBON;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;441098517;441098517;;;;;;;;;;;;;commune;commune;Allée de Villebon;Allée de Villebon;;;44109_8517;44109_8517;;;;;LINESTRING Z (355891.4 6690178.3 12.3, 355858.6 6690163.2 9.1, 355837.6 6690152.9 8.1)
TRONROUT0000002333155126;Sentier;COURS SAINT-ANDRE;COURS SAINT-ANDRE;6;Non;0;En service;2023-06-01 17:51:00;2023-06-03 01:10:35;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BS;44109#0BS;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355785.4 6690046.8 -1000, 355750.5 6690028.7 -1000)
TRONROUT0000002333155124;Route à 1 chaussée;R TOURNEFORT;R TOURNEFORT;3;Non;0;En service;2023-06-01 17:51:00;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;7;;7;44109;44109;;;;441098152;441098152;;;;;;;;;;;;;commune;commune;Rue Tournefort;Rue Tournefort;;;44109_8152;44109_8152;;;;;LINESTRING Z (355726.5 6690046.9 12.6, 355729.4 6690040.4 12.6)
TRONROUT0000002245069172;Route à 2 chaussées;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2021-08-25 15:00:52;2023-06-02 00:42:28;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355729.4 6690040.4 -1000, 355739 6690045.2 -1000, 355742.1 6690046.3 -1000, 355770.4 6690059.3 -1000, 355773.3 6690060.9 -1000)
TRONROUT0000000329622488;Route à 2 chaussées;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2013-11-15 09:02:56;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.5;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355771.6 6690067.4 12.6, 355767 6690065.6 12.7, 355737.1 6690051.9 12.7, 355729.3 6690048.2 12.6, 355726.5 6690046.9 12.6)
TRONROUT0000000029475002;Route à 2 chaussées;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;9;;8;;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355785.1 6690073.3 12.6, 355743.7 6690148.2 9)
TRONROUT0000002245069170;Route à 2 chaussées;R SULLY;R SULLY;3;Non;0;En service;2021-08-25 15:00:52;2023-06-02 00:42:28;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;5.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355726.7 6690170.2 -1000, 355733.4 6690158.3 -1000, 355769.1 6690086.5 -1000, 355773.8 6690076.5 -1000, 355773.6 6690073.7 -1000, 355771.6 6690067.4 -1000)
TRONROUT0000002245069174;Sentier;;;6;Non;0;En service;2021-08-25 15:00:52;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355767.5 6690075.5 -1000, 355761.1 6690095.3 -1000, 355747.8 6690090.5 -1000, 355717.3 6690154.8 -1000, 355721.1 6690160.6 -1000, 355720.8 6690166.9 -1000, 355726.7 6690170.2 -1000)
TRONROUT0000000130607091;Sentier;IMP SULLY;IMP SULLY;6;Non;0;En service;2008-06-05 14:30:16;2012-09-27 15:32:59;;;;;BDParcellaire;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441097996;441097996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355743.7 6690148.2 9, 355789.9 6690172.1 9)
TRONROUT0000000130607092;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2008-06-05 14:30:16;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;11;;11;;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355743.7 6690148.2 9, 355730.5 6690172.3 8)
TRONROUT0000000329622490;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355726.7 6690170.2 -1000, 355730.5 6690172.3 -1000)
TRONROUT0000000029473625;Route à 1 chaussée;R GEOFFROY DROUET;R GEOFFROY DROUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12;19;10;11;44109;44109;;;;441093648;441093648;;;;;;;;;;;;;commune;commune;Rue Geoffroy Drouet;Rue Geoffroy Drouet;;;44109_3648;44109_3648;;;;;LINESTRING Z (355983 6690074.8 15.7, 355991.7 6690062 16.7)
TRONROUT0000000029473825;Route à 1 chaussée;R GEOFFROY DROUET;R GEOFFROY DROUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;23;;21;44109;44109;;;;441093648;441093648;;;;;;;;;;;;;commune;commune;Rue Geoffroy Drouet;Rue Geoffroy Drouet;;;44109_3648;44109_3648;;;;;LINESTRING Z (355952.6 6690118.9 12.3, 355983 6690074.8 15.7)
TRONROUT0000000029474036;Route à 1 chaussée;R GEOFFROY DROUET;R GEOFFROY DROUET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;18;;14;;44109;44109;;;;441093648;441093648;;;;;;;;;;;;;commune;commune;Rue Geoffroy Drouet;Rue Geoffroy Drouet;;;44109_3648;44109_3648;;;;;LINESTRING Z (355983 6690074.8 15.7, 355971 6690130.3 12.9)
TRONROUT0000000029474466;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;56;;58;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (355971 6690130.3 12.9, 355952.6 6690118.9 12.3)
TRONROUT0000000029474182;Route à 1 chaussée;ALL DE LA REINE MARGOT;ALL DE LA REINE MARGOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;5;6;44109;44109;;;;441097186;441097186;;;;;;;;;;;;;commune;commune;Allée de la Reine Margot;Allée de la Reine Margot;;;44109_7186;44109_7186;;;;;LINESTRING Z (355891.4 6690178.3 12.3, 355952.6 6690118.9 12.3)
TRONROUT0000000029473726;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;41;42;47;54;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (356007.6 6690170.9 15.4, 355984.5 6690144.5 14.1, 355974.5 6690134.4 13.3, 355971 6690130.3 12.9)
TRONROUT0000000029473932;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;35;36;41;40;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (356036.2 6690208.2 17.5, 356020.7 6690185.8 16.7, 356007.6 6690170.9 15.4)
TRONROUT0000000029473744;Route à 1 chaussée;R COLONEL BOUTIN;R COLONEL BOUTIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;7;4;1;44109;44109;;;;441092028;441092028;;;;;;;;;;;;;commune;commune;Rue Colonel Boutin;Rue Colonel Boutin;;;44109_2028;44109_2028;;;;;LINESTRING Z (356036.2 6690208.2 17.5, 355980.5 6690249.6 13, 355973.3 6690254.7 12.4)
TRONROUT0000000029473715;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;27;22;33;30;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (356071.3 6690267.9 18.1, 356059.9 6690245.7 18, 356049.1 6690227 18, 356041.4 6690214.8 17.9, 356036.2 6690208.2 17.5)
TRONROUT0000000029474226;Route à 1 chaussée;R HENRI COCHARD;R HENRI COCHARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;2;13;36;44109;44109;;;;441094124;441094124;;;;;;;;;;;;;commune;commune;Rue Henri Cochard;Rue Henri Cochard;;;44109_4124;44109_4124;;;;;LINESTRING Z (356007.6 6690170.9 15.4, 355905.9 6690254.5 10.2, 355884.9 6690272.3 9.7, 355844.4 6690305.7 8.9)
TRONROUT0000000329622491;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2013-11-15 09:02:56;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098000;441098000;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355726 6690180.7 7.7, 355730.5 6690172.3 8)
TRONROUT0000000029473462;Route à 1 chaussée;CRS SULLY;CRS SULLY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;14;;2;;44109;44109;IMP SULLY;IMP SULLY;;441097997;441097997;;;;;;;;;;;;;commune;commune;Cours Sully;Cours Sully;;;44109_7997;44109_7997;;;;;LINESTRING Z (355726 6690180.7 7.7, 355765.1 6690198.5 7.7)
TRONROUT0000002245069179;Route à 2 chaussées;R SULLY;R SULLY;3;Non;0;En service;2021-08-25 15:02:00;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098000;441098000;;;;;;;;;;;;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355701.1 6690210.6 -1000, 355711.4 6690197 -1000, 355726.7 6690170.2 -1000)
TRONROUT0000000029473796;Route à 1 chaussée;R SULLY;R SULLY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;13;;10;;44109;44109;;;;441098000;441098000;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Sully;Rue Sully;;;44109_8000;44109_8000;;;;;LINESTRING Z (355706.2 6690212.1 7.7, 355713.4 6690201.8 7.3, 355724.3 6690183.3 7.4, 355726 6690180.7 7.7)
TRONROUT0000000029473666;Rond-point;PL DE LA BONDE;PL DE LA BONDE;3;Non;0;En service;2006-10-04 09:41:10;2021-08-25 15:02:00;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BZ;44109#0BZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355701.1 6690210.6 8.3, 355702.7 6690210.6 8.3, 355706.2 6690212.1 7.7)
TRONROUT0000002245069178;Rond-point;PL DE LA BONDE;PL DE LA BONDE;3;Non;0;En service;2021-08-25 15:02:00;;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BZ;44109#0BZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355691.1 6690219.3 7.8, 355691.3 6690216.4 8.3, 355692.2 6690214 8.3, 355695.1 6690211.4 8.3, 355698.8 6690210.6 8.3, 355701.1 6690210.6 8.3)
TRONROUT0000000029474312;Rond-point;PL DE LA BONDE;PL DE LA BONDE;3;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BZ;44109#0BZ;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355706.2 6690212.1 7.7, 355708.9 6690215.4 8.1, 355709.2 6690218.1 8.1, 355709.3 6690221 8.1)
TRONROUT0000000029474190;Route à 1 chaussée;PONT SAINT-MIHIEL;PONT SAINT-MIHIEL;5;Non;1;En service;2006-10-04 09:41:10;2021-06-17 19:11:23;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#098;44109#098;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355636.8 6690216.1 8.3, 355643.8 6690216.7 8.5, 355665.3 6690218.9 9.2, 355674.2 6690219.2 6.8, 355678 6690219.4 7.2, 355685.2 6690219.7 8.2)
TRONROUT0000000029475253;Route à 1 chaussée;PONT SAINT-MIHIEL;PONT SAINT-MIHIEL;5;Non;0;En service;2006-10-04 09:41:10;2012-12-18 18:27:54;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#098;44109#098;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355685.2 6690219.7 8.2, 355691.1 6690219.3 7.8)
TRONROUT0000000029473898;Rond-point;PL DE LA BONDE;PL DE LA BONDE;3;Non;0;En service;2006-10-04 09:41:10;2018-11-13 07:54:47;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BZ;44109#0BZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355699.4 6690227.8 7.1, 355696.1 6690226.5 8.7, 355693.3 6690224.6 8.8, 355691.7 6690222 8.3, 355691.1 6690219.3 7.8)
TRONROUT0000000228331538;Escalier;CRS SULLY;CRS SULLY;6;Non;0;En service;2010-02-01 16:20:54;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;IMP SULLY;IMP SULLY;;441097997;441097997;;;;;;;;;;;;;commune;commune;Cours Sully;Cours Sully;;;44109_7997;44109_7997;;;;;LINESTRING Z (355765.1 6690198.5 7.7, 355765.3 6690202.7 7.7, 355766.2 6690203.3 7.7, 355767.3 6690203.5 7.7, 355768.3 6690203.6 8.7, 355769.6 6690203.3 9.5, 355770.3 6690202.7 10, 355771.2 6690201.6 10, 355772.2 6690201.4 10, 355772.9 6690201.4 10, 355774.9 6690201.7 10, 355778 6690202.7 10.8, 355779.8 6690203.8 11)
TRONROUT0000000029474201;Route à 1 chaussée;ALL DE LA REINE MARGOT;ALL DE LA REINE MARGOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;7;8;11;12;44109;44109;;;;441097186;441097186;;;;;;;;;;;;;commune;commune;Allée de la Reine Margot;Allée de la Reine Margot;;;44109_7186;44109_7186;;;;;LINESTRING Z (355859.3 6690245 10.5, 355861.9 6690240 11.2, 355883.1 6690195.6 12.3, 355891.4 6690178.3 12.3)
TRONROUT0000000228331540;Sentier;CRS SULLY;CRS SULLY;6;Non;0;En service;2010-02-01 16:20:54;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;IMP SULLY;IMP SULLY;;441097997;441097997;;;;;;;;;;;;;commune;commune;Cours Sully;Cours Sully;;;44109_7997;44109_7997;;;;;LINESTRING Z (355779.8 6690203.8 11, 355826.5 6690228.4 10.6)
TRONROUT0000000228331539;Route à 1 chaussée;CRS SULLY;CRS SULLY;5;Non;0;En service;2010-02-01 16:20:54;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;IMP SULLY;IMP SULLY;;441097997;441097997;;;;;;;;;;;;;commune;commune;Cours Sully;Cours Sully;;;44109_7997;44109_7997;;;;;LINESTRING Z (355859.3 6690245 10.5, 355826.5 6690228.4 10.6)
TRONROUT0000000029473664;Route à 1 chaussée;ALL DE LA REINE MARGOT;ALL DE LA REINE MARGOT;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;13;;15;;44109;44109;;;;441097186;441097186;;;;;;;;;;;;;commune;commune;Allée de la Reine Margot;Allée de la Reine Margot;;;44109_7186;44109_7186;;;;;LINESTRING Z (355844.4 6690305.7 8.9, 355842.7 6690299.2 9.9, 355841.9 6690291.3 9.9, 355859.3 6690245 10.5)
TRONROUT0000000295264909;Route à 1 chaussée;R PITRE CHEVALIER;R PITRE CHEVALIER;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;22;;22;;44109;44109;;;;441096668;441096668;;;;;;;;;;;;;commune;commune;Rue Pitre Chevalier;Rue Pitre Chevalier;;;44109_6668;44109_6668;;;;;LINESTRING Z (355813.1 6690299.8 8.4, 355832.8 6690316.7 8.7)
TRONROUT0000000029473640;Route à 1 chaussée;R HENRI COCHARD;R HENRI COCHARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094124;441094124;;;;;;;;;;;;;commune;commune;Rue Henri Cochard;Rue Henri Cochard;;;44109_4124;44109_4124;;;;;LINESTRING Z (355844.4 6690305.7 8.9, 355832.8 6690316.7 8.7)
TRONROUT0000000029474475;Route à 1 chaussée;R PITRE CHEVALIER;R PITRE CHEVALIER;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;20;15;16;13;44109;44109;;;;441096668;441096668;;;;;;;;;;;;;commune;commune;Rue Pitre Chevalier;Rue Pitre Chevalier;;;44109_6668;44109_6668;;;;;LINESTRING Z (355832.8 6690316.7 8.7, 355876.3 6690354.6 10.9)
TRONROUT0000000029414975;Route à 1 chaussée;R JEAN EMILE LABOUREUR;R JEAN EMILE LABOUREUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;22;17;2;1;44109;44109;;;;441094452;441094452;;;;;;;;;;;;;commune;commune;Rue Jean Emile Laboureur;Rue Jean Emile Laboureur;;;44109_4452;44109_4452;;;;;LINESTRING Z (355806.5 6690453 12.1, 355828 6690425 12, 355876.3 6690354.6 10.9)
TRONROUT0000000029415133;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2018-06-04 12:14:25;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355806.5 6690453 12.1, 355795.8 6690448.5 11.5, 355786.5 6690443.6 11.3, 355777.7 6690435.7 10.9, 355753.4 6690411 8.9)
TRONROUT0000002000156712;Route à 1 chaussée;R COLONEL BOUTIN;R COLONEL BOUTIN;5;Non;0;En service;2016-10-06 16:56:01;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;13;6;11;44109;44109;;;;441092028;441092028;;;;;;;;;;;;;commune;commune;Rue Colonel Boutin;Rue Colonel Boutin;;;44109_2028;44109_2028;;;;;LINESTRING Z (355973.3 6690254.7 12.4, 355923 6690290.6 8.5, 355918.3 6690295.1 8.2)
TRONROUT0000002000156710;Sentier;PAS SAINT-CHRISTOPHE;PAS SAINT-CHRISTOPHE;6;Non;0;En service;2016-10-06 16:56:01;;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355973.3 6690254.7 12.4, 356013.3 6690308.7 13.4)
TRONROUT0000002000156711;Route à 1 chaussée;R MONFOULON;R MONFOULON;5;Non;0;En service;2016-10-06 16:56:01;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;4;1;8;44109;44109;;;;441095720;441095720;;;;;;;;;;;;;commune;commune;Rue Monfoulon;Rue Monfoulon;;;44109_5720;44109_5720;;;;;LINESTRING Z (356013.3 6690308.7 13.4, 356036.1 6690292.7 15.1, 356058.3 6690276.1 16.9, 356071.3 6690267.9 18.1)
TRONROUT0000000029474263;Route à 1 chaussée;R COLONEL BOUTIN;R COLONEL BOUTIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;21;;15;44109;44109;;;;441092028;441092028;;;;;;;;;;;;;commune;commune;Rue Colonel Boutin;Rue Colonel Boutin;;;44109_2028;44109_2028;;;;;LINESTRING Z (355918.3 6690295.1 8.2, 355915.2 6690298.1 8.3, 355876.3 6690354.6 10.9)
TRONROUT0000000029473629;Route à 1 chaussée;AV HENRI OLLIVIER;AV HENRI OLLIVIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;5;5;1;44109;44109;;;;441094149;441094149;;;;;;;;;;;;;commune;commune;Avenue Henri Ollivier;Avenue Henri Ollivier;;;44109_4149;44109_4149;;;;;LINESTRING Z (355973.2 6690374.9 11.1, 355966.8 6690367 10.8, 355957.9 6690352 9.4, 355949.8 6690339.9 8.2, 355931.8 6690315.7 8.5, 355918.3 6690295.1 8.2)
TRONROUT0000000029473503;Route à 1 chaussée;R MONFOULON;R MONFOULON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;5;10;5;16;44109;44109;;;;441095720;441095720;;;;;;;;;;;;;commune;commune;Rue Monfoulon;Rue Monfoulon;;;44109_5720;44109_5720;;;;;LINESTRING Z (355973.2 6690374.9 11.1, 355980.5 6690357 10.7, 355984.6 6690332.4 11.5, 355986.2 6690330 11.8, 356006.8 6690313.3 12.9, 356013.3 6690308.7 13.4)
TRONROUT0000000029415061;Route à 1 chaussée;R PITRE CHEVALIER;R PITRE CHEVALIER;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;14;9;2;3;44109;44109;;;;441096668;441096668;;;;;;;;;;;;;commune;commune;Rue Pitre Chevalier;Rue Pitre Chevalier;;;44109_6668;44109_6668;;;;;LINESTRING Z (355876.3 6690354.6 10.9, 355945.1 6690414.1 12.8)
TRONROUT0000000029415071;Route à 1 chaussée;R MONFOULON;R MONFOULON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;16;;22;44109;44109;;;;441095720;441095720;;;;;;;;;;;;;commune;commune;Rue Monfoulon;Rue Monfoulon;;;44109_5720;44109_5720;;;;;LINESTRING Z (355945.1 6690414.1 12.8, 355969.8 6690381.8 11.1, 355973.2 6690374.9 11.1)
TRONROUT0000000029414956;Route à 1 chaussée;R FRANCOIS JOSEPH TALMA;R FRANCOIS JOSEPH TALMA;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;2;5;2;1;44109;44109;;;;441093310;441093310;;;;;;;;;;;;;commune;commune;Rue François Joseph Talma;Rue François Joseph Talma;;;44109_3310;44109_3310;;;;;LINESTRING Z (355945.1 6690414.1 12.8, 356010.75084163935 6690471.022695063 14.925113949020474)
TRONROUT0000000029415097;Route à 1 chaussée;R DU 65EME REGIMENT D'INFANTERIE;R DU 65EME REGIMENT D'INFANTERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;27;22;44109;44109;;;;441097932;441097932;;;;;;;;;;;;;commune;commune;Rue du 65 ème Régiment d'Infanterie;Rue du 65 ème Régiment d'Infanterie;;;44109_7932;44109_7932;;;;;LINESTRING Z (355945.1 6690414.1 12.8, 355915.1 6690455.1 15.6, 355898.1235971755 6690471.022695063 15.307303399578302)
TRONROUT0000002333126217;Route à 1 chaussée;;;5;Non;0;En service;2023-05-30 15:53:32;2023-05-31 05:43:35;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356209.7 6689673.5 -1000, 356227 6689680.7 -1000)
TRONROUT0000000029474123;Route à 1 chaussée;R ECORCHARD;R ECORCHARD;5;Non;0;En service;2006-10-04 09:41:10;2023-06-14 12:35:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;Plot amovible;;;;;;Non;9;;9;;44109;44109;;;;441092692;441092692;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Rue Ecorchard;Rue Ecorchard;;;44109_2692;44109_2692;;;;;LINESTRING Z (356361.9 6689685.1 9, 356352.1 6689680.7 9.1, 356344.3 6689675.2 9.1, 356340.5 6689672.6 8.7)
TRONROUT0000000329622958;Route à 1 chaussée;;;5;Non;0;En service;2013-11-15 09:08:43;2023-05-30 15:53:32;;;;;Orthophotographie;3.0;Pas de Z;9999.0;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356227 6689680.7 -1000, 356233.7 6689682.9 -1000, 356235.1 6689679.9 -1000)
TRONROUT0000002220840082;Route empierrée;;;6;Non;0;En service;2020-12-03 12:02:17;2023-06-14 12:35:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Double sens;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356340.5 6689672.6 8.7, 356344.8 6689688.5 8.4, 356352.3 6689706.3 8.2, 356355.1 6689714.3 8)
TRONROUT0000000029474816;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356355.1 6689714.3 8, 356372.7 6689712 8, 356387.8 6689711 7.5)
TRONROUT0000000029475127;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356387.8 6689711 7.5, 356377.6 6689715 7.6, 356370.5 6689717.6 7.5, 356359.5 6689723.6 7.6, 356349.8 6689731.5 7.9, 356343.8 6689739.2 8, 356339.7 6689746.2 8.2, 356338.9 6689751.1 8.2, 356340.4 6689754.7 8.2, 356342.7 6689756.4 8.2, 356352.2 6689761.2 8.3)
TRONROUT0000000029475167;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356312.9 6689765.8 10.8, 356326.7 6689742 9.6, 356335.5 6689728.8 9, 356342.2 6689721.6 8.2, 356348.8 6689716.7 8, 356355.1 6689714.3 8)
TRONROUT0000000029475130;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356312.9 6689765.8 10.8, 356338.2 6689762.9 9, 356352.2 6689761.2 8.3)
TRONROUT0000000029473627;Route à 1 chaussée;R STANISLAS BAUDRY;R STANISLAS BAUDRY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097968;441097968;;;;;;;;;;;;;commune;commune;Rue Stanislas Baudry;Rue Stanislas Baudry;;;44109_7968;44109_7968;;;;;LINESTRING Z (356244.3 6689865.2 17, 356246 6689861.8 16.9, 356252.9 6689847.5 16.5, 356306.7 6689737.9 11.2, 356326 6689701.1 9.6, 356340.5 6689672.6 8.7)
TRONROUT0000000029475106;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356410.1 6689763.2 8, 356379.8 6689775.3 7.9, 356370 6689781.5 8.3, 356354.4 6689794.5 9.4, 356342.7 6689805.7 10.4, 356337.5 6689809.8 10.3)
TRONROUT0000000329622956;Route à 1 chaussée;;;5;Non;0;En service;2013-11-15 09:08:43;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356156.9 6689660 -1000, 356180.8 6689665.9 -1000)
TRONROUT0000000329622957;Sentier;;;6;Non;0;En service;2013-11-15 09:08:43;2023-05-30 15:53:32;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356180.8 6689665.9 -1000, 356184.8 6689666.5 -1000, 356189.6 6689667.1 -1000, 356197.2 6689668.3 -1000, 356202.3 6689670.1 -1000, 356209.7 6689673.5 -1000)
TRONROUT0000000029473689;Route à 1 chaussée;R GEORGES CLEMENCEAU;R GEORGES CLEMENCEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;10;11;10;44109;44109;;;;441093664;441093664;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Georges Clemenceau;Rue Georges Clemenceau;;;44109_3664;44109_3664;;;;;LINESTRING Z (356112.7 6689800.6 16.9, 356047.8 6689768.9 17.4)
TRONROUT0000000029473497;Route à 1 chaussée;R GEORGES CLEMENCEAU;R GEORGES CLEMENCEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;1;8;44109;44109;;;;441093664;441093664;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;commune;commune;Rue Georges Clemenceau;Rue Georges Clemenceau;;;44109_3664;44109_3664;;;;;LINESTRING Z (356244.3 6689865.2 17, 356237.6 6689861.9 17, 356115.1 6689801.8 17.2, 356112.7 6689800.6 16.9)
TRONROUT0000000029474025;Route à 1 chaussée;R ELIE DELAUNAY;R ELIE DELAUNAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;;2;;44109;44109;;;;441092756;441092756;;;;;;;;;;;;;commune;commune;Rue Elie Delaunay;Rue Elie Delaunay;;;44109_2756;44109_2756;;;;;LINESTRING Z (356071.3 6689884.9 18.9, 356082 6689863.1 18.3, 356112.7 6689800.6 16.9)
TRONROUT0000000295265329;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356071.3 6689884.9 18.9, 356078 6689887.9 18.8)
TRONROUT0000002011475984;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;106;35;98;21;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356078 6689887.9 18.8, 356159.9 6689924.7 18.4, 356162.7 6689926 18.4)
TRONROUT0000000333150199;Route à 1 chaussée;;;5;Non;0;En service;2014-03-17 15:58:17;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356078 6689887.9 18.8, 356050.6 6689938.3 19.3, 356049.9 6689940.6 19.9, 356049.9 6689942.6 20.4, 356051.1 6689945.4 21)
TRONROUT0000000029474300;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356162.7 6689926 18.4, 356182.1 6689934.8 18.4)
TRONROUT0000002011475982;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;3;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;2017-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356162.7 6689926 18.4, 356167.4 6689930 19.4, 356170 6689932.7 19.5, 356170.9 6689934.6 19.5, 356171.4 6689937.1 19.4, 356171.5 6689939 19.2, 356171.9 6689943 18.5)
TRONROUT0000000029471329;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356500.3 6689837.5 10.9, 356499.7 6689828.6 10.9, 356495.4 6689800.5 10.3, 356490.7 6689769.2 8.8, 356488.7 6689760.6 8.4, 356484.2 6689751.1 7.8)
TRONROUT0000000295265327;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356436.4 6689796.8 9.9, 356445.7 6689795.1 10.5, 356453.7 6689794.5 10.8, 356462.4 6689795.5 11.2, 356472 6689800.3 12.2, 356473.4 6689801.5 12.4)
TRONROUT0000000029475097;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356437.7 6689810.9 10.3, 356437.6 6689804.2 10.3, 356436.4 6689796.8 9.9)
TRONROUT0000000256963812;Route à 1 chaussée;;;5;Non;0;En service;2011-04-12 13:03:31;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356500.3 6689837.5 10.9, 356506.81139568595 6689823.185692129 10.630934062565965)
TRONROUT0000000029475095;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356337.5 6689809.8 10.3, 356356.4 6689804 9.4, 356371.5 6689799.5 9.1, 356388.5 6689796.3 9.1, 356396 6689796.7 9.1, 356399.4 6689798 9.2, 356403.2 6689800.6 9.4, 356406.9 6689804.5 9.7, 356410.3 6689810.9 10, 356412.7 6689817.6 10.3, 356414.4 6689827.1 11, 356415.1 6689847.3 11.6, 356416 6689855.2 11.9, 356417.2 6689859.8 11.6)
TRONROUT0000000029474646;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356417.2 6689859.8 11.6, 356430.7 6689830 10.6, 356436.4 6689816.7 10.7, 356437.7 6689810.9 10.3)
TRONROUT0000000029475299;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356473.4 6689801.5 12.4, 356476.3 6689803.8 13, 356479.9 6689808.1 13.2, 356483.2 6689814.3 13.7, 356485.5 6689820.2 13.7, 356486.9 6689825.8 13.6, 356486.5 6689834.4 12.8, 356485.6 6689838.9 13.3, 356483 6689845.3 13.2, 356479.3 6689851.5 12.9, 356473.1 6689859.9 12.5, 356467.9 6689866.9 12.9, 356453.6 6689890.8 13.5)
TRONROUT0000000029475220;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356437.7 6689810.9 10.3, 356441.2 6689825.6 11.1, 356447.4 6689860.1 12.6, 356453.6 6689890.8 13.5)
TRONROUT0000000029474707;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356396.6 6689898.4 13.3, 356402.5 6689889.6 13.2, 356412.9 6689869.9 12.2, 356417 6689860.4 11.6, 356417.2 6689859.8 11.6)
TRONROUT0000000029475147;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356421.1 6689931.4 14.5, 356433.1 6689926.7 14.7, 356440.1 6689922.1 14.1, 356456.9 6689909.6 14, 356465 6689902.2 13.8, 356471.5 6689894.3 13.4, 356482.2 6689876.3 12.6, 356489.9 6689859.8 11.9, 356500.3 6689837.5 10.9)
TRONROUT0000000029475140;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356277.1 6689833.5 14, 356296.9 6689794.5 12.6, 356312.9 6689765.8 10.8)
TRONROUT0000000029475246;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356337.5 6689809.8 10.3, 356312.5 6689821.2 12.1, 356300.1 6689825.5 13.4, 356277.1 6689833.5 14)
TRONROUT0000000029474851;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2019-10-23 21:08:52;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356277.1 6689833.5 14, 356270.2 6689844.6 15.2, 356266.2 6689853.7 15.8, 356264.6 6689857.3 16.4, 356263.7 6689861.6 16.5, 356261.6 6689875.3 16.6)
TRONROUT0000000029475271;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356244.3 6689865.2 17, 356251.7 6689869.5 16.9, 356261.6 6689875.3 16.6)
TRONROUT0000000084490763;Route à 1 chaussée;PL SOPHIE TREBUCHET;PL SOPHIE TREBUCHET;5;Non;0;En service;2007-07-17 07:48:02;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;11;;13;;44109;44109;;;;441097939;441097939;;;;;;;;;;;;;commune;commune;Place Sophie Trébuchet;Place Sophie Trébuchet;;;44109_7939;44109_7939;;;;;LINESTRING Z (356244.3 6689865.2 17, 356234.5 6689882.8 17.6, 356230.4 6689890.3 17.6)
TRONROUT0000000029475203;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356261.6 6689875.3 16.6, 356262.5 6689879.8 16.6, 356265 6689885.3 16.6, 356268.6 6689889.2 16.6, 356272.7 6689892 16.6, 356303.6 6689910.5 15.2, 356306.9 6689911.9 15.2, 356327.8 6689920.7 15.4, 356342.3 6689926.1 15.6, 356354.6 6689929.8 15.4)
TRONROUT0000000029474589;Route à 1 chaussée;PL SOPHIE TREBUCHET;PL SOPHIE TREBUCHET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;17;;11;44109;44109;;;;441097939;441097939;;;;;;;;;;;;;commune;commune;Place Sophie Trébuchet;Place Sophie Trébuchet;;;44109_7939;44109_7939;;;;;LINESTRING Z (356182.1 6689934.8 18.4, 356190.6 6689926.4 18.4, 356206.4 6689912.4 18.4, 356218.1 6689902.4 18.2, 356230.4 6689890.3 17.6)
TRONROUT0000000029474827;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356354.6 6689929.8 15.4, 356370.1 6689922.2 14.8, 356384.4 6689911.4 14.1, 356396.6 6689898.4 13.3)
TRONROUT0000000029475215;Route à 1 chaussée;PL SOPHIE TREBUCHET;PL SOPHIE TREBUCHET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097939;441097939;;;;;;;;;;;;;commune;commune;Place Sophie Trébuchet;Place Sophie Trébuchet;;;44109_7939;44109_7939;;;;;LINESTRING Z (356230.4 6689890.3 17.6, 356222 6689905.9 17.7, 356214.9 6689916.8 17.7, 356209.3 6689927.1 17.9, 356206.4 6689937.5 17.9, 356207.3 6689945.4 18)
TRONROUT0000000029475120;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202/ITI_AUT_0000002285710179;;;;;;;;Autre/Sentier de découverte;Balade au Cœur de Nantes/Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356354.6 6689929.8 15.4, 356363.3 6689932.2 15.5)
TRONROUT0000000029473734;Route à 1 chaussée;R FREDERIC CAILLIAUD;R FREDERIC CAILLIAUD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;14A;;30;;44109;44109;;;;441093344;441093344;;;;;;;;;;;;;commune;commune;Rue Frédéric Cailliaud;Rue Frédéric Cailliaud;;;44109_3344;44109_3344;;;;;LINESTRING Z (356373 6690020.4 17.3, 356384.3 6690014 17.2, 356392.1 6690008.7 17.2, 356402 6689998.3 16.6, 356423.5 6689973.9 15.8, 356431.4 6689965.4 15.3, 356458.1 6689936.2 14.2, 356471 6689922.2 13.8, 356474.9 6689917.9 13.9, 356484.5 6689907.1 13.4, 356487.9 6689900 12.8, 356503.2 6689863.5 11.3, 356504.8 6689859.7 11.2, 356506.81139568595 6689854.917049055 11.038550179064412)
TRONROUT0000000029475314;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356453.6 6689890.8 13.5, 356428.8 6689921 13.9)
TRONROUT0000000029474855;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356396.6 6689898.4 13.3, 356428.8 6689921 13.9)
TRONROUT0000000029475185;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2013-11-15 09:08:43;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356428.8 6689921 13.9, 356421.1 6689931.4 14.5)
TRONROUT0000000029475170;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (356363.3 6689932.2 15.5, 356376.2 6689935.5 15.4, 356391 6689937.5 15.2, 356407.3 6689935.1 15.1, 356421.1 6689931.4 14.5)
TRONROUT0000000029471314;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356506.81139568595 6689953.572481493 14.146359495808836, 356500 6689947.7 14.3, 356464.8 6689993.5 16.1)
TRONROUT0000000029471274;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356503.3 6690025.9 15, 356506.81139568595 6690021.69783795 14.846496363451989)
TRONROUT0000000029475129;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356503.3 6690025.9 15, 356464.8 6689993.5 16.1)
TRONROUT0000000029475198;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:46:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356464.8 6689993.5 16.1, 356437.3 6690029.4 17.1)
TRONROUT0000000029475134;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:48:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356373 6690020.4 17.3, 356396.4 6690021.1 18.1, 356413.4 6690021.8 17.6, 356424.1 6690020 17.5, 356437.3 6690029.4 17.1)
TRONROUT0000000029474250;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;94;;94;;44109;44109;;;;441093448;441093448;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356207.3 6689945.4 18, 356223.8 6689953.5 18.6)
TRONROUT0000000029474958;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356223.8 6689953.5 18.6, 356227.2 6689955 18.5)
TRONROUT0000000029475208;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;;;;;;;;;;;;;LINESTRING Z (356363.3 6689932.2 15.5, 356327.1 6689985.9 17.3, 356320.3 6689996 17.4)
TRONROUT0000000029474032;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;92;17;88;17;44109;44109;;;;441093448;441093448;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356227.2 6689955 18.5, 356320.3 6689996 17.4)
TRONROUT0000000029473937;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;86;15;86;15;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356320.3 6689996 17.4, 356345.6 6690007.1 17.8)
TRONROUT0000000029474387;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;106;113;98;101;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356227.2 6689955 18.5, 356232.4 6689966.3 18.6, 356237.4 6689975.3 18.6, 356244.7 6689987.2 18.7, 356263.7 6690018.5 19.2, 356282 6690048 19.7, 356289.4 6690062.4 19.5)
TRONROUT0000000029474676;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356345.6 6690007.1 17.8, 356360.6 6690013.7 17.6, 356373 6690020.4 17.3)
TRONROUT0000000029474104;Route à 1 chaussée;R GUILLAUME GROU;R GUILLAUME GROU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;;2;;44109;44109;;;;441093960;441093960;;;;;;;;;;;;;commune;commune;Rue Guillaume Grou;Rue Guillaume Grou;;;44109_3960;44109_3960;;;;;LINESTRING Z (356289.4 6690062.4 19.5, 356345.6 6690007.1 17.8)
TRONROUT0000000029474461;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;92;;96;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356289.4 6690062.4 19.5, 356297.8 6690082.8 19.9, 356301.4 6690093.9 19.7)
TRONROUT0000000029474926;Escalier;AV BASCHER;AV BASCHER;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441090568;441090568;;;;;;;;;;;;;commune;commune;Avenue Bascher;Avenue Bascher;;;44109_0568;44109_0568;;;;;LINESTRING Z (356267.9 6690115.2 21.3, 356279.2 6690108.5 20.7, 356301.4 6690093.9 19.7)
TRONROUT0000002011475983;Route à 1 chaussée;R LORETTE DE LA REFOULAIS;R LORETTE DE LA REFOULAIS;5;Non;0;En service;2018-06-11 11:56:08;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095035;441095035;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Lorette de la Refoulais;Rue Lorette de la Refoulais;;;44109_5035;44109_5035;;;;;LINESTRING Z (356182.1 6689934.8 18.4, 356171.9 6689943 18.5)
TRONROUT0000000029475065;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;94;;94;;44109;44109;;;;441093448;441093448;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356182.1 6689934.8 18.4, 356207.3 6689945.4 18)
TRONROUT0000000029474618;Route à 1 chaussée;R LORETTE DE LA REFOULAIS;R LORETTE DE LA REFOULAIS;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;2;11;4;44109;44109;;;;441095035;441095035;;ITI_AUT_0000002285710202;;;;;;;;Sentier de découverte;Voyage à Nantes;;commune;commune;Rue Lorette de la Refoulais;Rue Lorette de la Refoulais;;;44109_5035;44109_5035;;;;;LINESTRING Z (356171.9 6689943 18.5, 356046.7 6690042.9 20.7)
TRONROUT0000000029473928;Route à 1 chaussée;R GUIBOURD DE LUZINAIS;R GUIBOURD DE LUZINAIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;9;2;7;44109;44109;;;;441093932;441093932;;;;;;;;;;;;;commune;commune;Rue Guibourd de Luzinais;Rue Guibourd de Luzinais;;;44109_3932;44109_3932;;;;;LINESTRING Z (356075.4 6690072.7 21.3, 356223.8 6689953.5 18.6)
TRONROUT0000000029474042;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;32;;36;44109;44109;;;;441095368;441095368;;;;;;;;;;;;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (356075.4 6690072.7 21.3, 356046.7 6690042.9 20.7)
TRONROUT0000000029474559;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;9B;8;39;28;44109;44109;;;;441095368;441095368;;;;;;;;;;;;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (356176.1 6690174.7 22.4, 356169.4 6690164.3 22.7, 356162.9 6690156.9 22.7, 356135.9 6690132.6 22.2, 356114.8 6690113.2 22.1, 356075.4 6690072.7 21.3)
TRONROUT0000000029474174;Route à 1 chaussée;R PREFET BONNEFOY;R PREFET BONNEFOY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;2;21;20;44109;44109;;;;441096928;441096928;;;;;;;;;;;;;commune;commune;Rue Préfet Bonnefoy;Rue Préfet Bonnefoy;;;44109_6928;44109_6928;;;;;LINESTRING Z (356135.8 6690388.4 17.3, 356121.3 6690363.9 17.1, 356071.3 6690267.9 18.1)
TRONROUT0000000029474614;Route à 1 chaussée;AV CHANZY;AV CHANZY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441091640;441091640;;;;;;;;;;;;;commune;commune;Avenue Chanzy;Avenue Chanzy;;;44109_1640;44109_1640;;;;;LINESTRING Z (356135.8 6690388.4 17.3, 356180.7 6690345.6 20, 356227.8 6690300.7 22.8, 356236.7 6690294.4 23.4, 356244.9 6690287 23.3)
TRONROUT0000000029414958;Route à 1 chaussée;R AMIRAL RONARC'H;R AMIRAL RONARC'H;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;52;;38;;44109;44109;;;;441090240;441090240;;;;;;;;;;;;;commune;commune;Rue Amiral Ronarc'h;Rue Amiral Ronarc'h;;;44109_0240;44109_0240;;;;;LINESTRING Z (356135.8 6690388.4 17.3, 356164.6 6690436.3 17.5, 356168.3 6690443.4 17.5, 356182.3508506677 6690471.022695063 17.899171893968234)
TRONROUT0000000029415032;Route à 1 chaussée;AV CHANZY;AV CHANZY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;7;6;21;16;44109;44109;;;;441091640;441091640;;;;;;;;;;;;;commune;commune;Avenue Chanzy;Avenue Chanzy;;;44109_1640;44109_1640;;;;;LINESTRING Z (356135.8 6690388.4 17.3, 356050.3056124572 6690471.022695063 15.905177938361838)
TRONROUT0000000029471296;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:48:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356476.8 6690057.5 16.5, 356503.3 6690025.9 15)
TRONROUT0000000029475126;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:48:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356437.3 6690029.4 17.1, 356476.8 6690057.5 16.5)
TRONROUT0000000029471284;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2014-06-16 18:48:56;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356476.8 6690057.5 16.5, 356502.7 6690076 16.1, 356506.81139568595 6690078.203493113 15.938768796631178)
TRONROUT0000000029473563;Route à 1 chaussée;R GAMBETTA;R GAMBETTA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;34;;74;44109;44109;;;;441093448;441093448;;;;;;;;;;;;;commune;commune;Rue Gambetta;Rue Gambetta;;;44109_3448;44109_3448;;;;;LINESTRING Z (356506.81139568595 6690093.947729114 15.633006156488056, 356469.4 6690073.4 16.1, 356393.6 6690031.8 17.1, 356373 6690020.4 17.3)
TRONROUT0000000029473530;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;39;38;45;56;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356377.5 6690266.4 22, 356421.1 6690302.9 21.7, 356470.1 6690344.2 21.5)
TRONROUT0000000029471303;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (356492.3 6690358.6 21.5, 356506.81139568595 6690337.58623029 20.75989238759364)
TRONROUT0000000029474511;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;31;32;33;34;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356492.3 6690358.6 21.5, 356470.1 6690344.2 21.5)
TRONROUT0000000029473802;Route à 1 chaussée;R SAINT-CHARLES;R SAINT-CHARLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;1;4;44109;44109;;;;441097548;441097548;;;;;;;;;;;;;commune;commune;Rue Saint Charles;Rue Saint Charles;;;44109_7548;44109_7548;;;;;LINESTRING Z (356470.1 6690344.2 21.5, 356454.3 6690356.3 21.6, 356430.3 6690373.3 21.9, 356427.6 6690375 21.9)
TRONROUT0000000029411965;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;19;20;29;30;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356506.81139568595 6690368.075240474 21.370202185278373, 356492.3 6690358.6 21.5)
TRONROUT0000000029414949;Route à 1 chaussée;IMP SAINT-CHARLES;IMP SAINT-CHARLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;1;12;9;44109;44109;;;;441097544;441097544;;;;;;;;;;;;;commune;commune;Impasse Saint Charles;Impasse Saint Charles;;;44109_7544;44109_7544;;;;;LINESTRING Z (356427.6 6690375 21.9, 356428.7 6690378.5 21.9, 356452.4 6690422.8 21.9)
TRONROUT0000000029474225;Route à 1 chaussée;AV BASCHER;AV BASCHER;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;9;18;44109;44109;;;;441090568;441090568;;;;;;;;;;;;;commune;commune;Avenue Bascher;Avenue Bascher;;;44109_0568;44109_0568;;;;;LINESTRING Z (356267.9 6690115.2 21.3, 356266.7 6690116 21.4, 356264.9 6690112.8 21.4, 356227.9 6690138.7 21.8, 356191.7 6690163.8 22.3, 356181.9 6690170.6 22.4, 356176.1 6690174.7 22.4)
TRONROUT0000000029473542;Route à 1 chaussée;R GASTON TURPIN;R GASTON TURPIN;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;63;72;87;90;44109;44109;;;;441093520;441093520;;;;;;;;;;;;;commune;commune;Rue Gaston Turpin;Rue Gaston Turpin;;;44109_3520;44109_3520;;;;;LINESTRING Z (356301.4 6690093.9 19.7, 356313.7 6690128.2 20.4, 356349.2 6690222.7 21.1, 356366.8 6690243.2 21.6, 356377.5 6690266.4 22)
TRONROUT0000000029473882;Route à 1 chaussée;R MARECHAL JOFFRE;R MARECHAL JOFFRE;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;1;2;9;6;44109;44109;;;;441095368;441095368;;;;;;;;;;;;;commune;commune;Rue Maréchal Joffre;Rue Maréchal Joffre;;;44109_5368;44109_5368;;;;;LINESTRING Z (356244.9 6690287 23.3, 356232.3 6690266.4 23.2, 356220.8 6690247.6 23.1, 356191.3 6690198.9 22.8, 356176.1 6690174.7 22.4)
TRONROUT0000000029474479;Route à 1 chaussée;R DE COURSON;R DE COURSON;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;9;8;44109;44109;;;;441092256;441092256;;;;;;;;;;;;;commune;commune;Rue de Courson;Rue de Courson;;;44109_2256;44109_2256;;;;;LINESTRING Z (356279.2 6690339.9 23.4, 356369.9 6690272.1 22, 356377.5 6690266.4 22)
TRONROUT0000000029475117;Route à 1 chaussée;R GENERAL BUAT;R GENERAL BUAT;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;139;202;145;204;44109;44109;;;;441093556;441093556;;;;;;;;;;;;;commune;commune;Rue Général Buat;Rue Général Buat;;;44109_3556;44109_3556;;;;;LINESTRING Z (356279.2 6690339.9 23.4, 356244.9 6690287 23.3)
TRONROUT0000000029473733;Route à 1 chaussée;R DUFOUR;R DUFOUR;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;47;;65;;44109;44109;;;;441092604;441092604;;;;;;;;;;;;;commune;commune;Rue Dufour;Rue Dufour;;;44109_2604;44109_2604;;;;;LINESTRING Z (356244.9 6690287 23.3, 356245.9 6690324.7 23.3, 356251.8 6690343.5 23.4, 356260.1 6690363.5 23.6, 356270.5 6690384 23.7, 356282.7 6690405.6 23.6, 356296 6690435.1 23)
TRONROUT0000000029474303;Route à 1 chaussée;R GENERAL BUAT;R GENERAL BUAT;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;125;190;137;200;44109;44109;;;;441093556;441093556;;;;;;;;;;;;;commune;commune;Rue Général Buat;Rue Général Buat;;;44109_3556;44109_3556;;;;;LINESTRING Z (356330.8 6690425.3 22.8, 356279.2 6690339.9 23.4)
TRONROUT0000000029415126;Route à 1 chaussée;R SAINT-CHARLES;R SAINT-CHARLES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;17;;19;;44109;44109;;;;441097548;441097548;;;;;;;;;;;;;commune;commune;Rue Saint Charles;Rue Saint Charles;;;44109_7548;44109_7548;;;;;LINESTRING Z (356296 6690435.1 23, 356330.8 6690425.3 22.8)
TRONROUT0000000029415140;Route à 1 chaussée;R GENERAL BUAT;R GENERAL BUAT;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;186;123;176;119;44109;44109;;;;441093556;441093556;;;;;;;;;;;;;commune;commune;Rue Général Buat;Rue Général Buat;;;44109_3556;44109_3556;;;;;LINESTRING Z (356330.8 6690425.3 22.8, 356358.9941162255 6690471.022695063 22.429024786506705)
TRONROUT0000000029414948;Route à 1 chaussée;R DUFOUR;R DUFOUR;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;41;8;44109;44109;;;;441092604;441092604;;;;;;;;;;;;;commune;commune;Rue Dufour;Rue Dufour;;;44109_2604;44109_2604;;;;;LINESTRING Z (356296 6690435.1 23, 356311.17231841164 6690471.022695063 23.44624465916579)
TRONROUT0000000029415100;Route à 1 chaussée;R SAINT-CHARLES;R SAINT-CHARLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;8;15;16;44109;44109;;;;441097548;441097548;;;;;;;;;;;;;commune;commune;Rue Saint Charles;Rue Saint Charles;;;44109_7548;44109_7548;;;;;LINESTRING Z (356427.6 6690375 21.9, 356391.1 6690398.4 22.1, 356368.8 6690412.1 22.2, 356330.8 6690425.3 22.8)
TRONROUT0000000029411946;Route à 1 chaussée;AV THEODORE BOTREL;AV THEODORE BOTREL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;11;2;1;44109;44109;;;;441091068;441091068;;;;;;;;;;;;;commune;commune;Avenue Théodore Botrel;Avenue Théodore Botrel;;;44109_1068;44109_1068;;;;;LINESTRING Z (356480.7 6690441.1 23, 356506.81139568595 6690423.789111748 22.129620143797073)
TRONROUT0000000029415045;Route à 1 chaussée;AV CHANTEPIE;AV CHANTEPIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;9;2;1B;44109;44109;;;;441091628;441091628;;;;;;;;;;;;;commune;commune;Avenue Chantepie;Avenue Chantepie;;;44109_1628;44109_1628;;;;;LINESTRING Z (356420.1 6690447.1 23.3, 356368.8619367559 6690471.022695063 22.517075434300295)
TRONROUT0000000317258100;Route à 1 chaussée;ALL DUQUESNE;ALL DUQUESNE;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441092644;441092644;;;;;;;;;;;;;commune;commune;Allée Duquesne;Allée Duquesne;;;44109_2644;44109_2644;;;;;LINESTRING Z (355372.5 6689802.1 5.9, 355380.8 6689809.9 5.9)
TRONROUT0000000317258136;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355346.9 6689806.8 5.7, 355349.8 6689806 5.7)
TRONROUT0000000317258135;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355344.9 6689808.8 5.7, 355345.4 6689808.4 5.7, 355346.9 6689806.8 5.7)
TRONROUT0000000317258121;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355349.8 6689806 5.7, 355352.7 6689806.7 5.8, 355354.7 6689808.7 5.8, 355355.5 6689811.6 5.8)
TRONROUT0000000317258137;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355345.6 6689815.4 5.8, 355344.9 6689814.6 5.8, 355344.1 6689811.7 5.7, 355344.9 6689808.8 5.7)
TRONROUT0000000029474567;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355355.5 6689811.6 5.8, 355354.7 6689814.5 5.8, 355352.7 6689816.5 5.8)
TRONROUT0000000029474705;Route à 1 chaussée;R ARMAND BROSSARD;R ARMAND BROSSARD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090372;441090372;;;;;;;;;;;;;commune;commune;Rue Armand Brossard;Rue Armand Brossard;;;44109_0372;44109_0372;;;;;LINESTRING Z (355377.9 6689819.5 6.4, 355380.9 6689812.6 6, 355380.8 6689809.9 5.9)
TRONROUT0000000317258119;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355355.5 6689811.6 5.8, 355371.5 6689819.6 6.2)
TRONROUT0000000029473924;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355352.7 6689816.5 5.8, 355349.9 6689817.3 5.8, 355347 6689816.6 5.8, 355345.6 6689815.4 5.8)
TRONROUT0000000029474914;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355371.5 6689819.6 6.2, 355374.7 6689818.6 6.3, 355377.9 6689819.5 6.4)
TRONROUT0000000029474143;Route à 1 chaussée;R SAINT-JEAN;R SAINT-JEAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;10;;10;44109;44109;;;;441097648;441097648;;;;;;;;;;;;;commune;commune;Rue Saint Jean;Rue Saint Jean;;;44109_7648;44109_7648;;;;;LINESTRING Z (355607.9 6689775 12.5, 355606.4 6689801 11.1)
TRONROUT0000000029474136;Route à 1 chaussée;R GARDE DIEU;R GARDE DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093460;441093460;;;;;;;;;;;;;commune;commune;Rue Garde Dieu;Rue Garde Dieu;;;44109_3460;44109_3460;;;;;LINESTRING Z (355542.5 6689786.7 10.7, 355566.7 6689792.7 11.2)
TRONROUT0000000029473996;Route à 1 chaussée;R GARDE DIEU;R GARDE DIEU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441093460;441093460;;;;;;;;;;;;;commune;commune;Rue Garde Dieu;Rue Garde Dieu;;;44109_3460;44109_3460;;;;;LINESTRING Z (355606.4 6689801 11.1, 355566.7 6689792.7 11.2)
TRONROUT0000000029474372;Route à 1 chaussée;R D'AGUESSEAU;R D'AGUESSEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090056;441090056;;;;;;;;;;;;;commune;commune;Rue d'Aguesseau;Rue d'Aguesseau;;;44109_0056;44109_0056;;;;;LINESTRING Z (355606.4 6689801 11.1, 355606.1 6689806.8 11.3)
TRONROUT0000000029473805;Route à 1 chaussée;R D'ENFER;R D'ENFER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;3;;1;44109;44109;;;;441092832;441092832;;;;;;;;;;;;;commune;commune;Rue d'Enfer;Rue d'Enfer;;;44109_2832;44109_2832;;;;;LINESTRING Z (355542.5 6689786.7 10.7, 355529.2 6689817.9 9.2, 355522.1 6689829.3 8.3, 355506 6689852.7 7.4)
TRONROUT0000000029473985;Route à 1 chaussée;R DE STRASBOURG;R DE STRASBOURG;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;48;33;42;31;44109;44109;;;;441097984;441097984;;;;;;;;;;;;;commune;commune;Rue de Strasbourg;Rue de Strasbourg;;;44109_7984;44109_7984;;;;;LINESTRING Z (355529.6 6689864.6 7.8, 355566.7 6689792.7 11.2)
TRONROUT0000000029473817;Route à 1 chaussée;R DES PENITENTES;R DES PENITENTES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;1;4;1;44109;44109;;;;441096320;441096320;;;;;;;;;;;;;commune;commune;Rue des Pénitentes;Rue des Pénitentes;;;44109_6320;44109_6320;;;;;LINESTRING Z (355606.1 6689806.8 11.3, 355563.2 6689867.4 8.7, 355555.9 6689877.8 8.3)
TRONROUT0000000029474581;Route à 1 chaussée;R D'AGUESSEAU;R D'AGUESSEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;12;1;8;1;44109;44109;;;;441090056;441090056;;;;;;;;;;;;;commune;commune;Rue d'Aguesseau;Rue d'Aguesseau;;;44109_0056;44109_0056;;;;;LINESTRING Z (355648.5 6689879.5 11.2, 355641.2 6689866.7 9.9, 355606.1 6689806.8 11.3)
TRONROUT0000000029473541;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355506 6689852.7 7.4, 355529.6 6689864.6 7.8)
TRONROUT0000000029473590;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355529.6 6689864.6 7.8, 355535.5 6689867.6 7.9, 355555.9 6689877.8 8.3)
TRONROUT0000000317258118;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355368.3 6689825.2 6.3, 355352.7 6689816.5 5.8)
TRONROUT0000000029474930;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355377.9 6689819.5 6.4, 355378.1 6689819.5 6.4, 355380.4 6689821.8 6.5, 355381.3 6689825.1 6.6)
TRONROUT0000000317258122;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355368.3 6689825.2 6.3, 355369.2 6689822 5.9, 355371.5 6689819.6 6.2)
TRONROUT0000000029474847;Route à 1 chaussée;R LE NOTRE;R LE NOTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094896;441094896;;;;;;;;;;;;;commune;commune;Rue Le Nôtre;Rue Le Nôtre;;;44109_4896;44109_4896;;;;;LINESTRING Z (355345.6 6689815.4 5.8, 355330.6 6689830.6 6)
TRONROUT0000000029475024;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355318.6 6689817.9 6, 355326.6 6689827.2 6, 355330.6 6689830.6 6)
TRONROUT0000000317258127;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355381.3 6689825.1 6.6, 355380.4 6689828.3 6.7)
TRONROUT0000000317258115;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355378.1 6689830.7 6.7, 355374.9 6689831.6 6.6, 355371.6 6689830.8 6.5, 355369.2 6689828.5 6.4, 355368.3 6689825.2 6.3)
TRONROUT0000000317258126;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355380.4 6689828.3 6.7, 355378.1 6689830.7 6.7)
TRONROUT0000000317258099;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355342.5 6689842.5 6.2, 355330.6 6689830.6 6)
TRONROUT0000000029473998;Route à 1 chaussée;R LE NOTRE;R LE NOTRE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;5;;44109;44109;;;;441094896;441094896;;;;;;;;;;;;;commune;commune;Rue Le Nôtre;Rue Le Nôtre;;;44109_4896;44109_4896;;;;;LINESTRING Z (355330.6 6689830.6 6, 355320.6 6689841.7 6.2, 355301.1 6689870.3 4.5, 355290.4 6689886.2 7.6)
TRONROUT0000000317258102;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;5;;4;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355506 6689852.7 7.4, 355498.6 6689866.7 7.3, 355488 6689886.9 7.2)
TRONROUT0000000317258125;Route à 1 chaussée;;;6;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé non GPS;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355495.1 6689912.9 9.2, 355484 6689905.3 8.7, 355460.8 6689894.7 8.3, 355450.2 6689889.4 7.9, 355435 6689876.5 7.5, 355395.4 6689839.9 7.1, 355380.4 6689828.3 6.7)
TRONROUT0000000317258114;Route à 1 chaussée;CRS DES 50 OTAGES;CRS DES 50 OTAGES;5;Non;0;En service;2013-01-10 17:06:11;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;;;;;;;;;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355494.2 6689915.7 9.2, 355488.4 6689911.7 8.9, 355478 6689906 8.6, 355463.3 6689900.3 8.3, 355452.2 6689894.9 8, 355442.9 6689889.2 7.8, 355429.8 6689877.2 7.5, 355406.4 6689854.9 7.2, 355386.9 6689837.8 6.9, 355378.1 6689830.7 6.7)
TRONROUT0000000029473496;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;5;;4;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355488 6689886.9 7.2, 355484.6 6689893.2 7.3)
TRONROUT0000000039538617;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2006-11-08 11:53:07;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355497.3 6689911.2 9.3, 355499.1 6689910.2 9.4, 355499.3 6689910.1 9.4, 355502.1 6689909.7 9.5, 355505.3 6689910.1 9.7)
TRONROUT0000000039538616;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2006-11-08 11:53:07;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355495.1 6689912.9 9.2, 355497.3 6689911.2 9.3)
TRONROUT0000000317258129;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355494.2 6689915.7 9.2, 355495.1 6689912.9 9.2)
TRONROUT0000000317258116;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2013-01-10 17:06:11;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355499.3 6689923.9 9.3, 355496.5 6689922.4 9.3, 355494.5 6689919.4 9.2, 355494.2 6689915.7 9.2)
TRONROUT0000000039538619;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2006-11-08 11:53:07;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355509.2 6689917 9.4, 355507.7 6689921 9.3, 355504.2 6689923.7 9.3, 355499.3 6689923.9 9.3)
TRONROUT0000000029473680;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355453.9 6689950.3 7.1, 355434.4 6689931.5 7.6)
TRONROUT0000000029475062;Route à 1 chaussée;PL DU PONT MORAND;PL DU PONT MORAND;3;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#08H;44109#08H;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Place du Pont Morand;Place du Pont Morand;;;44109_6781;44109_6781;;;;;LINESTRING Z (355499.3 6689923.9 8, 355475.1 6689969.6 8)
TRONROUT0000000029474319;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;;20;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355453.9 6689950.3 7.1, 355475.1 6689969.6 8)
TRONROUT0000000316373863;Route à 1 chaussée;R MOQUECHIEN;R MOQUECHIEN;5;Non;0;En service;2012-12-06 10:18:12;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;7;1;1;44109;44109;;;;441095796;441095796;;;;;;;;;;;;;commune;commune;Rue Moquechien;Rue Moquechien;;;44109_5796;44109_5796;;;;;LINESTRING Z (355453.9 6689950.3 7.1, 355448.5 6689955.5 7, 355405.5 6689988.9 6.8, 355403.8 6689991.7 6.8, 355404.7 6689992.6 6.8)
TRONROUT0000000295266755;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096200;441096200;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355475.1 6689969.6 8, 355469.8 6689980.8 8.1)
TRONROUT0000000029475008;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;4.0;14.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;1;2;7;10;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355469.8 6689980.8 8.1, 355445.4 6690031.9 9)
TRONROUT0000000029473840;Route à 1 chaussée;R MOQUECHIEN;R MOQUECHIEN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;7;1;1;44109;44109;;;;441095796;441095796;;;;;;;;;;;;;commune;commune;Rue Moquechien;Rue Moquechien;;;44109_5796;44109_5796;;;;;LINESTRING Z (355404.7 6689992.6 6.8, 355428.1 6690026.4 10.8)
TRONROUT0000000029474651;Route à 1 chaussée;R JEANNE D'ARC;R JEANNE D'ARC;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094500;441094500;;;;;;;;;;;;;commune;commune;Rue Jeanne d'Arc;Rue Jeanne d'Arc;;;44109_4500;44109_4500;;;;;LINESTRING Z (355399.3 6690019.4 11.4, 355422 6690025 10.8)
TRONROUT0000000054044875;Rond-point;;;4;Non;0;En service;2007-01-26 07:35:00;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355399.3 6690019.4 13.1, 355401 6690021.8 14.6, 355402.5 6690024.3 13.9, 355402.9 6690027.3 13.4, 355402.2 6690029.8 13.4, 355401.4 6690031.6 13.4)
TRONROUT0000000039538440;Route à 1 chaussée;R JEANNE D'ARC;R JEANNE D'ARC;4;Non;0;En service;2006-11-08 09:32:17;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094500;441094500;;;;;;;;;;;;;commune;commune;Rue Jeanne d'Arc;Rue Jeanne d'Arc;;;44109_4500;44109_4500;;;;;LINESTRING Z (355428.1 6690026.4 10.8, 355422 6690025 10.8)
TRONROUT0000000039538439;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355433.1 6690027.3 10.7, 355433.5 6690025.9 10.7, 355435.3 6690024.1 10.7, 355437.8 6690023.4 10.7, 355440.3 6690024.1 10.7, 355442.1 6690025.8 10.7, 355442.8 6690028.3 10.7)
TRONROUT0000000039538447;Route à 1 chaussée;R JEANNE D'ARC;R JEANNE D'ARC;4;Non;0;En service;2006-11-08 09:32:17;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094500;441094500;;;;;;;;;;;;;commune;commune;Rue Jeanne d'Arc;Rue Jeanne d'Arc;;;44109_4500;44109_4500;;;;;LINESTRING Z (355433.1 6690027.3 10.7, 355428.1 6690026.4 10.8)
TRONROUT0000000054044876;Route à 1 chaussée;R DE TALENSAC;R DE TALENSAC;4;Non;0;En service;2007-01-26 07:35:00;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2;;4;44109;44109;;;;441098032;441098032;;;;;;;;;;;;;commune;commune;Rue de Talensac;Rue de Talensac;;;44109_8032;44109_8032;;;;;LINESTRING Z (355422 6690025 10.8, 355401.4 6690031.6 11.7)
TRONROUT0000000039538438;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355435.4 6690032.7 10.7, 355433.5 6690030.9 10.7, 355432.8 6690028.4 10.7, 355433.1 6690027.3 10.7)
TRONROUT0000000039538436;Route à 1 chaussée;;;3;Non;0;En service;2006-11-08 09:32:17;2023-05-26 09:18:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355442.8 6690028.3 9.8, 355445.4 6690031.9 9)
TRONROUT0000000039538442;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355442.8 6690028.3 10.7, 355442.1 6690030.8 10.7, 355440.4 6690032.6 10.7, 355437.9 6690033.4 10.7, 355435.4 6690032.7 10.7)
TRONROUT0000000054044874;Rond-point;;;4;Non;0;En service;2007-01-26 07:35:00;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355401.4 6690031.6 13.4, 355399.5 6690033.2 13.4, 355397.2 6690033.6 11.7)
TRONROUT0000000039538445;Route à 1 chaussée;;;3;Non;0;En service;2006-11-08 09:32:17;2023-05-26 09:18:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355445.4 6690031.9 9, 355448.9 6690036.3 8.1)
TRONROUT0000000039538444;Route à 1 chaussée;;;3;Non;0;En service;2006-11-08 09:32:17;2010-05-04 22:20:04;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355438.6 6690037.4 9.2, 355435.4 6690032.7 10.7)
TRONROUT0000000039538443;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355441.1 6690040.8 8.2, 355441.8 6690038.2 8.2, 355443.7 6690036.3 8.2, 355446.3 6690035.6 8.1, 355448.9 6690036.3 8.1)
TRONROUT0000000039538446;Route à 1 chaussée;;;3;Non;0;En service;2006-11-08 09:32:17;2010-05-04 22:20:04;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355441.1 6690040.8 8.2, 355438.6 6690037.4 9.2)
TRONROUT0000000029475114;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355505.3 6689910.1 8.1, 355510.6 6689901.6 7.9, 355528.1 6689867.7 7.8, 355529.6 6689864.6 7.8)
TRONROUT0000000029473762;Route à 1 chaussée;R MAURICE DUVAL;R MAURICE DUVAL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;2;5;2;1B;44109;44109;;;;441095508;441095508;;;;;;;;;;;;;commune;commune;Rue Maurice Duval;Rue Maurice Duval;;;44109_5508;44109_5508;;;;;LINESTRING Z (355555.9 6689877.8 8.3, 355627.9 6689914.2 10)
TRONROUT0000000029474385;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355627.9 6689914.2 10, 355638.8 6689895.8 10.6, 355648.5 6689879.5 11.2)
TRONROUT0000000029474525;Route à 1 chaussée;PL DU PORT COMMUNEAU;PL DU PORT COMMUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096824;441096824;;;;;;;;;;;;;commune;commune;Place du Port Communeau;Place du Port Communeau;;;44109_6824;44109_6824;;;;;LINESTRING Z (355555.9 6689877.8 8.3, 355535.6 6689914.1 7.5, 355529.6 6689924.8 7.4)
TRONROUT0000000039538618;Rond-point;CRS DES 50 OTAGES;CRS DES 50 OTAGES;3;Non;0;En service;2006-11-08 11:53:07;2023-06-16 20:05:03;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0HG;44109#0HG;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Cours des 50 Otages;Cours des 50 Otages;;;44109_1912;44109_1912;;;;;LINESTRING Z (355505.3 6689910.1 9.7, 355508.2 6689912.9 9.6, 355509.2 6689917 9.4)
TRONROUT0000000029474937;Route à 1 chaussée;PL ROGER SALENGRO;PL ROGER SALENGRO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;;4;;44109;44109;;;;441097424;441097424;;;;;;;;;;;;;commune;commune;Place Roger Salengro;Place Roger Salengro;;;44109_7424;44109_7424;;;;;LINESTRING Z (355627.9 6689914.2 10, 355642.6 6689923.4 10.4, 355647.2 6689926.2 10.5)
TRONROUT0000000029474139;Route à 1 chaussée;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355509.2 6689917 9.4, 355529.6 6689924.8 7.4)
TRONROUT0000000029474426;Route à 1 chaussée;QU CEINERAY;QU CEINERAY;3;Non;0;En service;2006-10-04 09:41:10;2023-06-02 00:42:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;50;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091521;441091521;;;;;;;;;;;;;commune;commune;Quai Ceineray;Quai Ceineray;;;44109_1521;44109_1521;;;;;LINESTRING Z (355695.9 6690023.6 11.1, 355685.5 6690017.8 10.7, 355655.5 6690000.6 10.8, 355549.3 6689935.8 7.9, 355540.9 6689931.1 7.7, 355529.6 6689924.8 7.4)
TRONROUT0000000329622492;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355636.8 6690216.1 -1000, 355638.2 6690194.5 -1000, 355637 6690163.4 -1000, 355632.8 6690134.9 -1000, 355627.4 6690118.4 -1000, 355623.6 6690104.4 -1000, 355614.1 6690085.7 -1000, 355604.6 6690068.3 -1000, 355591.5 6690051.8 -1000, 355575.4 6690034.7 -1000, 355563 6690021.1 -1000, 355549 6690011 -1000, 355499.4 6689970.4 -1000, 355522.6 6689934.3 -1000, 355537.5 6689941.2 -1000, 355567.7 6689959 -1000, 355605.1 6689980.5 -1000, 355642.2 6690001.4 -1000, 355678.4 6690027.4 -1000, 355701.9 6690041.7 -1000, 355727.3 6690056.9 -1000, 355754.5 6690068.8 -1000, 355767.5 6690075.5 -1000)
TRONROUT0000000029474188;Route à 1 chaussée;QU DE VERSAILLES;QU DE VERSAILLES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;15;;1;44109;44109;;;;441098359;441098359;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Quai de Versailles;Quai de Versailles;;;44109_8359;44109_8359;;;;;LINESTRING Z (355623.7 6690213.6 7.7, 355625.6 6690201.3 7.7, 355625.9 6690185.4 7.5, 355625.7 6690169.9 7.5, 355624.2 6690156.9 7.5, 355622.7 6690145 7.5, 355619.5 6690132.6 7.3, 355615.1 6690119.5 7.3, 355611.5 6690110.3 7.1, 355606.7 6690098.4 6.9, 355600.9 6690086.9 6.9, 355593.4 6690074.1 6.7, 355582.9 6690061.2 6.7, 355572.6 6690049.5 6.7, 355558.7 6690036.9 6.7, 355544.3 6690024.3 6.7, 355529.7 6690012.2 6.7, 355513.3 6689998.9 7.1, 355498.5 6689987 7.9, 355487.7 6689978.8 7.9, 355482.6 6689977.4 7.9, 355477.8 6689977.5 7.9, 355473.6 6689978.7 7.9, 355469.8 6689980.8 8.1)
TRONROUT0000000317258098;Route à 1 chaussée;ALL DES TANNEURS;ALL DES TANNEURS;5;Non;0;En service;2013-01-10 17:06:11;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;12;;18;;44109;44109;;;;441098044;441098044;;;;;;;;;;;;;commune;commune;Allée des Tanneurs;Allée des Tanneurs;;;44109_8044;44109_8044;;;;;LINESTRING Z (355434.4 6689931.5 7.6, 355412.4 6689910.1 7.6, 355395.1 6689893.2 6.9, 355376 6689875.2 6.6, 355357.4 6689857.3 6.3, 355342.5 6689842.5 6.2)
TRONROUT0000000029473830;Route à 1 chaussée;R JEANNE D'ARC;R JEANNE D'ARC;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;5;;19;;44109;44109;;;;441094500;441094500;;;;;;;;;;;;;commune;commune;Rue Jeanne d'Arc;Rue Jeanne d'Arc;;;44109_4500;44109_4500;;;;;LINESTRING Z (355334.8 6689998.8 14.4, 355381.2 6690014.4 12.1, 355394.9 6690018 11.4)
TRONROUT0000000054044878;Rond-point;;;4;Non;0;En service;2007-01-26 07:35:00;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355394.9 6690018 12, 355399.3 6690019.4 13.1)
TRONROUT0000000054044877;Rond-point;;;4;Non;0;En service;2007-01-26 07:35:00;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355397.2 6690033.6 11.7, 355394.9 6690033.2 11.8, 355392.1 6690031.8 12, 355390 6690030 12, 355388.4 6690026.9 12.1, 355388.3 6690023.2 12.1, 355389.5 6690020.9 12.1, 355391.9 6690019 12, 355394.9 6690018 12)
TRONROUT0000000029473674;Route à 1 chaussée;R DE TALENSAC;R DE TALENSAC;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;18;;6;;44109;44109;;;;441098032;441098032;;;;;;;;;;;;;commune;commune;Rue de Talensac;Rue de Talensac;;;44109_8032;44109_8032;;;;;LINESTRING Z (355397.2 6690033.6 11.7, 355379.6 6690042.1 12.5, 355262.7 6690092.5 18.1, 355233.1 6690105.2 19.7, 355198.2 6690120.2 21.8, 355190.3 6690121.3 21.8, 355178.9 6690119.8 21.8)
TRONROUT0000000029474171;Route à 1 chaussée;IMP DE LA COURTINE;IMP DE LA COURTINE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GZ;44109#0GZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355301.8 6690195.3 16.1, 355320.8 6690162.3 15.9, 355320.6 6690160.5 15.9, 355319.3 6690158.6 15.9, 355307.5 6690152.4 16.3, 355306 6690152.6 16.3, 355304.9 6690153.6 16.3, 355265.7 6690212 17.1)
TRONROUT0000000029473724;Route à 1 chaussée;R SAINT-STANISLAS;R SAINT-STANISLAS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;11;6;11;44109;44109;;;;441097756;441097756;;;;;;;;;;;;;commune;commune;Rue Saint Stanislas;Rue Saint Stanislas;;;44109_7756;44109_7756;;;;;LINESTRING Z (355424.7 6690217.5 13.5, 355418.3 6690217.4 13.6, 355408.6 6690213.9 14.2, 355362.2 6690193.3 14.7)
TRONROUT0000000029473773;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;36;;36;;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355348.7 6690219.4 15.1, 355362.2 6690193.3 14.7)
TRONROUT0000000029473485;Route à 1 chaussée;IMP DE LA COURTINE;IMP DE LA COURTINE;5;Non;0;En service;2006-10-04 09:41:10;2012-09-28 17:38:38;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GZ;44109#0GZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355348.7 6690219.4 15.4, 355329.8 6690209.9 14.7, 355301.8 6690195.3 16.1)
TRONROUT0000000029474989;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;54;51;38;25;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355299 6690318.3 17.6, 355348.7 6690219.4 15.1)
TRONROUT0000000029473682;Route à 1 chaussée;R CHATEAUBRIAND;R CHATEAUBRIAND;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;22;31;2B;5;44109;44109;;;;441091792;441091792;;;;;;;;;;;;;commune;commune;Rue Chateaubriand;Rue Chateaubriand;;;44109_1792;44109_1792;;;;;LINESTRING Z (355478.4 6690054.6 8, 355491.8 6690067.1 7.4, 355557.4 6690144.7 7.7, 355617.7 6690217.4 7.7)
TRONROUT0000000029473535;Route à 1 chaussée;R ADOLPHE MOITIE;R ADOLPHE MOITIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;30;19;12;9;44109;44109;;;;441090032;441090032;;;;;;;;;;;;;commune;commune;Rue Adolphe Moitié;Rue Adolphe Moitié;;;44109_0032;44109_0032;;;;;LINESTRING Z (355569.7 6690254.6 7.7, 355529.1 6690211.5 7.8, 355482.7 6690162.3 7.9, 355475.8 6690158.2 7.9)
TRONROUT0000000029475044;Route à 1 chaussée;PONT SAINT-MIHIEL;PONT SAINT-MIHIEL;5;Non;0;En service;2006-10-04 09:41:10;2012-12-18 18:27:54;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#098;44109#098;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355623.7 6690213.6 7.7, 355629.8 6690213.9 7.3, 355636.8 6690216.1 8.3)
TRONROUT0000000029474624;Route à 1 chaussée;PL CHATEAUBRIAND;PL CHATEAUBRIAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C6;44109#0C6;;;;;;;;;;;;;commune;commune;Place Chateaubriand;Place Chateaubriand;;;44109_1788;44109_1788;;;;;LINESTRING Z (355617.7 6690217.4 7.7, 355620.8 6690215.5 7.8, 355623.7 6690213.6 7.7)
TRONROUT0000000029475050;Route à 1 chaussée;R SAGET;R SAGET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;6;3;2;1;44109;44109;;;;441097524;441097524;;;;;;;;;;;;;commune;commune;Rue Saget;Rue Saget;;;44109_7524;44109_7524;;;;;LINESTRING Z (355617.7 6690217.4 7.7, 355569.7 6690254.6 7.7)
TRONROUT0000000295265230;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;;;;;;;;;;;;;LINESTRING Z (355623.7 6690213.6 7.7, 355618.6 6690302.3 7.1)
TRONROUT0000000029474481;Route à 1 chaussée;R ADOLPHE MOITIE;R ADOLPHE MOITIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;32;27;32;23;44109;44109;;;;441090032;441090032;;;;;;;;;;;;;commune;commune;Rue Adolphe Moitié;Rue Adolphe Moitié;;;44109_0032;44109_0032;;;;;LINESTRING Z (355598.4 6690285.7 7.9, 355569.7 6690254.6 7.7)
TRONROUT0000000295265214;Route à 1 chaussée;QU DE VERSAILLES;QU DE VERSAILLES;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;19;30;19;30;44109;44109;;;;441098359;441098359;;;;;;;;;;;;;commune;commune;Quai de Versailles;Quai de Versailles;;;44109_8359;44109_8359;;;;;LINESTRING Z (355618.6 6690302.3 7.1, 355615.5 6690302.2 7.1, 355613.4 6690301.3 7.1, 355610.6 6690298.6 7.1, 355598.4 6690285.7 7.9)
TRONROUT0000000329622489;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355613.5 6690391.9 -1000, 355615.2 6690376.6 -1000, 355619.9 6690368.4 -1000, 355624.7 6690357.9 -1000, 355627.5 6690339.8 -1000, 355630.4 6690312 -1000, 355635.1 6690262.5 -1000, 355636.1 6690235.9 -1000, 355636.8 6690216.1 -1000)
TRONROUT0000000029474596;Route à 1 chaussée;IMP DE VERSAILLES;IMP DE VERSAILLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098364;441098364;;;;;;;;;;;;;commune;commune;Impasse de Versailles;Impasse de Versailles;;;44109_8358;44109_8358;;;;;LINESTRING Z (355598.4 6690285.7 7.9, 355563.7 6690313.2 10.6, 355536.3 6690334.9 10)
TRONROUT0000000039538437;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355448.9 6690036.3 8.1, 355450.8 6690038.2 8.1, 355451.5 6690040.8 8, 355451 6690042.8 8.4)
TRONROUT0000000039538441;Rond-point;;;3;Non;0;En service;2006-11-08 09:32:17;2017-10-19 14:26:21;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355451 6690042.8 8.4, 355450.8 6690043.4 8.4, 355449 6690045.3 8.4, 355446.4 6690046 8.3, 355443.8 6690045.3 8.3, 355441.8 6690043.4 8.3, 355441.1 6690040.8 8.2)
TRONROUT0000000029474035;Route à 1 chaussée;R CHATEAUBRIAND;R CHATEAUBRIAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2B;3;2;1;44109;44109;;;;441091792;441091792;;;;;;;;;;;;;commune;commune;Rue Chateaubriand;Rue Chateaubriand;;;44109_1792;44109_1792;;;;;LINESTRING Z (355478.4 6690054.6 8, 355451 6690042.8 8.4)
TRONROUT0000000029474486;Route à 1 chaussée;R ADOLPHE MOITIE;R ADOLPHE MOITIE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;7;10;44109;44109;;;;441090032;441090032;;;;;;;;;;;;;commune;commune;Rue Adolphe Moitié;Rue Adolphe Moitié;;;44109_0032;44109_0032;;;;;LINESTRING Z (355475.8 6690158.2 7.9, 355476.5 6690098.9 7.2, 355478.4 6690054.6 8)
TRONROUT0000000029473978;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;34;23;14;11;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355362.2 6690193.3 14.7, 355438.6 6690037.4 9.8)
TRONROUT0000000029474212;Route à 1 chaussée;R SAINT-STANISLAS;R SAINT-STANISLAS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;2;9;2;1;44109;44109;;;;441097756;441097756;;;;;;;;;;;;;commune;commune;Rue Saint Stanislas;Rue Saint Stanislas;;;44109_7756;44109_7756;;;;;LINESTRING Z (355475.8 6690158.2 7.9, 355463.2 6690173 9.8, 355435 6690205.7 12.2, 355424.7 6690217.5 13.5)
TRONROUT0000000029474592;Route à 1 chaussée;IMP SAINT-STANISLAS;IMP SAINT-STANISLAS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;;4;;44109;44109;;;;44109#0D9;44109#0D9;;;;;;;;;;;;;commune;commune;Impasse Saint Stanislas;Impasse Saint Stanislas;;;44109_7757;44109_7757;;;;;LINESTRING Z (355424.7 6690217.5 13.5, 355418.6 6690230.5 14.2, 355398.8 6690270.9 18.7)
TRONROUT0000000029473538;Route à 1 chaussée;R DE LA DISTILLERIE;R DE LA DISTILLERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;45;62;44109;44109;;;;441092484;441092484;;;;;;;;;;;;;commune;commune;Rue de la Distillerie;Rue de la Distillerie;;;44109_2484;44109_2484;;;;;LINESTRING Z (355569.7 6690254.6 7.7, 355537.7 6690281.5 10, 355435.9 6690362.3 19.2, 355405.9 6690386.5 18.7, 355405.6 6690386.9 18.7, 355404 6690388.8 18.7, 355399.2 6690398.4 20.5, 355387.7 6690420.9 19.6, 355382.9 6690429.9 19.6, 355379.8 6690435.9 19.2, 355361.8714410198 6690471.022695063 17.385543428511507)
TRONROUT0000000029414933;Route à 1 chaussée;AV DU COCHE D'EAU;AV DU COCHE D'EAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;9;2;1;44109;44109;;;;441092001;441092001;;;;;;;;;;;;;commune;commune;Avenue du Coche d'Eau;Avenue du Coche d'Eau;;;44109_2001;44109_2001;;;;;LINESTRING Z (355454.1 6690369.4 11.9, 355491.8 6690419.5 8.5, 355518.4 6690453.9 7.1)
TRONROUT0000000084491404;Route à 1 chaussée;QU DE VERSAILLES;QU DE VERSAILLES;5;Non;0;En service;2007-07-17 10:35:19;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;36;;30B;44109;44109;;;;441098359;441098359;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Quai de Versailles;Quai de Versailles;;;44109_8359;44109_8359;;;;;LINESTRING Z (355500.7492132608 6690471.022695063 6.9684232769044385, 355506.1 6690464.4 7.1, 355518.4 6690453.9 7.1)
TRONROUT0000000029475052;Route à 1 chaussée;IMP DE VERSAILLES;IMP DE VERSAILLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;441098364;441098364;;;;;;;;;;;;;commune;commune;Impasse de Versailles;Impasse de Versailles;;;44109_8358;44109_8358;;;;;LINESTRING Z (355536.3 6690334.9 10, 355521 6690315.3 10)
TRONROUT0000000029474452;Route à 1 chaussée;IMP DE VERSAILLES;IMP DE VERSAILLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;15;;15;;44109;44109;;;;441098364;441098364;;;;;;;;;;;;;commune;commune;Impasse de Versailles;Impasse de Versailles;;;44109_8358;44109_8358;;;;;LINESTRING Z (355536.3 6690334.9 10, 355524.5 6690345.2 10)
TRONROUT0000000295265242;Route à 1 chaussée;QU DE VERSAILLES;QU DE VERSAILLES;5;Non;0;En service;2012-02-08 10:00:49;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;29;;28;;44109;44109;;;;441098359;441098359;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Quai de Versailles;Quai de Versailles;;;44109_8359;44109_8359;;;;;LINESTRING Z (355576.4 6690408.3 7.3, 355583.7 6690400.6 7.3, 355599.3 6690379.7 7.3, 355609.7 6690357.6 7.9, 355616.2 6690330.2 7.1, 355618.6 6690302.3 7.1)
TRONROUT0000000029415161;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355613.5 6690391.9 6.8, 355613.3 6690393.8 6.8, 355612.1 6690404.8 7.4, 355610.1 6690423.7 7.7)
TRONROUT0000000295265272;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355576.4 6690408.3 7.3, 355577.6 6690412.2 6.9, 355579.5 6690416.4 6.9, 355610.1 6690423.7 7.7)
TRONROUT0000000029415117;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355610.1 6690423.7 7.7, 355609.3 6690429.2 7.4)
TRONROUT0000000084491405;Route à 1 chaussée;QU DE VERSAILLES;QU DE VERSAILLES;5;Non;0;En service;2007-07-17 10:35:19;2023-06-16 20:05:03;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;27;18;26;18;44109;44109;;;;441098359;441098359;ROUTNOMM0000002333266497;;;;;;;Ev1 : la Vélodyssée;;;;;commune;commune;Quai de Versailles;Quai de Versailles;;;44109_8359;44109_8359;;;;;LINESTRING Z (355518.4 6690453.9 7.1, 355535.7 6690440.3 6.9, 355561.2 6690420.7 6.9, 355576.4 6690408.3 7.3)
TRONROUT0000000029415155;Sentier;;;6;Non;1;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355609.3 6690429.2 7.4, 355608.4 6690443.7 7.7, 355607.9 6690453.3 7.9)
TRONROUT0000000029415171;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355607.9 6690453.3 7.9, 355605.952451092 6690471.022695063 7.218357882204269)
TRONROUT0000000029415129;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355603.90777069627 6690471.022695063 5.376395302936307, 355586.7 6690466.9 6.9, 355582.1 6690468.2 6.9, 355577.52265665564 6690471.022695063 6.442265665565584)
TRONROUT0000000029474477;Rond-point;PL DE LA BONDE;PL DE LA BONDE;3;Non;0;En service;2006-10-04 09:41:10;2022-05-13 20:06:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0BZ;44109#0BZ;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355709.3 6690221 8.1, 355708.4 6690223.3 8.1, 355706.6 6690225.4 8.1, 355703.6 6690226.6 8.1, 355699.4 6690227.8 7.1)
TRONROUT0000000295264910;Route à 1 chaussée;QU HENRI BARBUSSE;QU HENRI BARBUSSE;3;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094106;441094106;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;commune;commune;Quai Henri Barbusse;Quai Henri Barbusse;;;44109_4106;44109_4106;;;;;LINESTRING Z (355692.5 6690255.5 6.8, 355695.5 6690242.7 6.9, 355696 6690240.4 7, 355699.4 6690227.8 7.1)
TRONROUT0000002244452977;Route à 1 chaussée;;;6;Non;0;En service;2021-06-17 19:11:23;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;Piste cyclable;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355699.4 6690227.8 -1000, 355692 6690231.3 -1000, 355687 6690255.9 -1000)
TRONROUT0000000329622497;Sentier;;;6;Non;0;En service;2013-11-15 09:02:56;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355687 6690255.9 -1000, 355692.5 6690255.5 -1000)
TRONROUT0000000029474218;Route à 1 chaussée;R PITRE CHEVALIER;R PITRE CHEVALIER;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;34;19;24;19;44109;44109;;;;441096668;441096668;;;;;;;;;;;;;commune;commune;Rue Pitre Chevalier;Rue Pitre Chevalier;;;44109_6668;44109_6668;;;;;LINESTRING Z (355709.3 6690221 8.1, 355731.9 6690229.9 7.6, 355813.1 6690299.8 8.4)
TRONROUT0000000295265274;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355813.1 6690299.8 8.4, 355789.4 6690327.8 6.8, 355788.8 6690328.1 6.8, 355787.8 6690328.6 6.8, 355786.2 6690328.6 6.8, 355784.7 6690327.9 6.8, 355773.6 6690317.8 6.6, 355760.2 6690304.4 7, 355752.9 6690301.4 7, 355736.6 6690297.3 7, 355734.8 6690297.2 7, 355733.2 6690297.8 7, 355732 6690298.4 7, 355730.2 6690299.1 7, 355727.6 6690298.8 7, 355712.2 6690296.4 6.6)
TRONROUT0000000329622498;Route à 1 chaussée;QU HENRI BARBUSSE;QU HENRI BARBUSSE;3;Non;0;En service;2013-11-15 09:02:56;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094106;441094106;;;;;;;;;;;;;commune;commune;Quai Henri Barbusse;Quai Henri Barbusse;;;44109_4106;44109_4106;;;;;LINESTRING Z (355671.3707587069 6690471.022695063 7.801384265693141, 355683.9 6690319.5 6.9, 355686.6 6690288.1 6.7, 355687.6 6690279.2 6.7, 355690.7 6690263.7 6.8, 355692.5 6690255.5 6.8)
TRONROUT0000002244451862;Route à 1 chaussée;;;6;Non;0;En service;2021-06-17 16:48:53;2022-12-10 06:26:51;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;Piste cyclable;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355687 6690255.9 -1000, 355685.9 6690261.1 -1000, 355682.3 6690278.6 -1000, 355679 6690319.4 -1000, 355673.5 6690382.4 -1000, 355666.3 6690469.7 -1000, 355666.19712371734 6690471.022695063 -1000)
TRONROUT0000002244451863;Sentier;;;6;Non;0;En service;2021-06-17 16:48:53;2022-05-13 20:06:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285710179;;;;;;;;Autre;Balade au Cœur de Nantes;;;;;;;;;;;;;;LINESTRING Z (355655.98460928345 6690471.022695063 -1000, 355657.7 6690454.8 -1000, 355663.8 6690402.1 -1000, 355667.3 6690343.6 -1000, 355674 6690266.5 -1000, 355675.1 6690257.8 -1000, 355676.5 6690256 -1000, 355682.3 6690256.2 -1000, 355687 6690255.9 -1000)
TRONROUT0000000029414954;Route à 1 chaussée;R JEAN EMILE LABOUREUR;R JEAN EMILE LABOUREUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;66;55;24;19;44109;44109;;;;441094452;441094452;;;;;;;;;;;;;commune;commune;Rue Jean Emile Laboureur;Rue Jean Emile Laboureur;;;44109_4452;44109_4452;;;;;LINESTRING Z (355793.27654951485 6690471.022695063 11.997888413242094, 355806.5 6690453 12.1)
TRONROUT0000000029478590;Route à 1 chaussée;IMP LIMONIER;IMP LIMONIER;5;Non;0;En service;2006-10-04 09:41:10;2012-02-08 10:00:49;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#02T;44109#02T;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (353941 6689770.4 11, 353945.2 6689775.4 11.3, 353955.2 6689786.2 11.2, 353962.2 6689794.5 10.6, 353970.1 6689805 9.8, 353978.3 6689814.2 9.1)
TRONROUT0000000312797820;Sentier;;;6;Non;0;En service;2012-09-10 12:40:43;2022-05-17 20:06:43;;;;;Fichier numérique non métrique;5.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Non;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (354027.1 6689808.9 6.3, 354043.3 6689790.5 8.2)
TRONROUT0000000029478392;Route à 1 chaussée;AV DES ROSES;AV DES ROSES;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 19:59:35;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#00N;44109#00N;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (353974.5 6689843.3 8.3, 353956.1 6689823.8 8.9, 353940.6 6689807.5 10.1, 353921.9 6689789 12.4)
TRONROUT0000000029478478;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354182.8 6689874.8 23.7, 354180.5 6689871 21.9, 354179.7 6689870.4 21.9, 354176.3 6689867.5 21.7, 354171.8 6689867.1 20, 354143.9 6689879 19, 354127.4 6689885.7 18.1, 354122.3 6689886.5 17.3, 354115.5 6689885.2 16.4, 354113.7 6689884.4 16.2, 354111.7 6689882.3 15.5, 354107.8 6689876 15, 354098.4 6689857.4 10.4, 354092.6 6689842.9 10.3, 354088.8 6689839.4 9.5, 354076.8 6689830.7 8.9, 354066.4 6689820.7 7.2, 354049.1 6689799.2 8.3, 354047.7 6689797.4 8.3, 354043.3 6689790.5 8.2)
TRONROUT0000000029478523;Route à 1 chaussée;R DE LA CHEZINE;R DE LA CHEZINE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;20;25;38;43;44109;44109;;;;441091892;441091892;;;;;;;;;;;;;commune;commune;Rue de la Chézine;Rue de la Chézine;;;44109_1892;44109_1892;;;;;LINESTRING Z (353921.9 6689789 12.4, 353892.0022898072 6689817.1936956225 13.871648947313679)
TRONROUT0000000029478678;Route empierrée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-05-30 15:56:19;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;;;;ITI_AUT_0000002285776843;;;;;;;;Autre;Vallée de la Chézine-Chantenay;;;;;;;;;;;;;;LINESTRING Z (353892.0022898072 6689919.253262256 4.119918448363164, 353899.2 6689913.6 3.1, 353920.5 6689909.5 3.7, 353933.8 6689903.5 4.6, 353949.8 6689890.2 4.6, 353957.1 6689883.8 4.5, 353965.5 6689880.4 4.5, 353977.3 6689874.1 4.5, 353983 6689865 4.2, 353992.7 6689855.9 3.6, 353999.4 6689847.4 4, 354011.7 6689826 4.9, 354021.6 6689812.8 5.6, 354027.1 6689808.9 6.3)
TRONROUT0000000029477873;Route à 1 chaussée;AV CAMUS;AV CAMUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;29;30;71;76;44109;44109;;;;441091388;441091388;;;;;;;;;;;;;commune;commune;Avenue Camus;Avenue Camus;;;44109_1388;44109_1388;;;;;LINESTRING Z (354182.8 6689874.8 23.7, 354174.5 6689878.7 23.4, 354133.2 6689898.5 22.2, 353965.5 6689979.1 17.1, 353960.9 6689982.7 17.1, 353957.2 6689991.7 17.5, 353944.8 6690061.9 20.2)
TRONROUT0000000029478440;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;77;80;93;84;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354084.1 6690020.5 24.8, 354091.2 6690014.5 25, 354112.2 6689999.9 25.1, 354127.2 6689990.9 25.6, 354161.6 6689975.2 25)
TRONROUT0000000029478307;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354077.7 6690024.3 28.4, 354078.3 6690021 28.8, 354082.3 6690019.4 27.9, 354084.1 6690020.5 28)
TRONROUT0000000029478313;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354084.1 6690020.5 28, 354085.6 6690021.3 28.1, 354086.9 6690024.9 28.3, 354085.8 6690028.9 29.7)
TRONROUT0000000029478356;Route à 1 chaussée;R MONDESIR;R MONDESIR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;16;21;10;19;44109;44109;;;;441095716;441095716;;;;;;;;;;;;;commune;commune;Rue Mondésir;Rue Mondésir;;;44109_5716;44109_5716;;;;;LINESTRING Z (354357.5 6689878.8 28.7, 354357.8 6689877.2 28.7, 354372.4 6689784.8 29.5)
TRONROUT0000000029478187;Route à 1 chaussée;AV CAMUS;AV CAMUS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;13;12;27;28;44109;44109;;;;441091388;441091388;;;;;;;;;;;;;commune;commune;Avenue Camus;Avenue Camus;;;44109_1388;44109_1388;;;;;LINESTRING Z (354282 6689827.1 26.8, 354189.1 6689871.7 23.8, 354182.8 6689874.8 23.7)
TRONROUT0000000029478499;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;45;62;55;66;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354274.5 6689920.3 26.9, 354357.5 6689878.8 28.7)
TRONROUT0000000029478475;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;59;68;65;70;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354232.3 6689941.3 25.9, 354274.5 6689920.3 26.9)
TRONROUT0000000029478013;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;18;15;2;1;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354357.5 6689878.8 28.7, 354341.2 6689987.4 29.4)
TRONROUT0000000029477972;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;65;72;71;74;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354187.8 6689962.5 25.4, 354232.3 6689941.3 25.9)
TRONROUT0000000029477971;Route à 1 chaussée;R DE LA BASTILLE;R DE LA BASTILLE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;71;76;75;78;44109;44109;;;;441090616;441090616;;;;;;;;;;;;;commune;commune;Rue de la Bastille;Rue de la Bastille;;;44109_0616;44109_0616;;;;;LINESTRING Z (354161.6 6689975.2 25, 354187.8 6689962.5 25.4)
TRONROUT0000000029478695;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354161.6 6689975.2 25, 354161.6 6689986.6 25.1)
TRONROUT0000000029478005;Route à 1 chaussée;R LIEUTENANT SAGERAN;R LIEUTENANT SAGERAN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;10;13;4;3;44109;44109;;;;441094984;441094984;;;;;;;;;;;;;commune;commune;Rue Lieutenant Sageran;Rue Lieutenant Sageran;;;44109_4984;44109_4984;;;;;LINESTRING Z (354317.2 6690053.9 30.4, 354313.3 6690050.3 30.7, 354309.2 6690039.1 30.5, 354290.8 6689975.6 28.2, 354274.5 6689920.3 26.9)
TRONROUT0000000029478647;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354380.9 6689992.7 30.2, 354341.2 6689987.4 29.4)
TRONROUT0000000029478579;Route à 1 chaussée;R GUIBAL;R GUIBAL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;4;15;18;44109;44109;;;;441093924;441093924;;;;;;;;;;;;;commune;commune;Rue Guibal;Rue Guibal;;;44109_3924;44109_3924;;;;;LINESTRING Z (354262.8 6690066.4 28.6, 354232.3 6689941.3 25.9)
TRONROUT0000000029478347;Route empierrée;R DE TOUTES JOIES;R DE TOUTES JOIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;;;;44109;44109;;;;44109#09P;44109#09P;;;;;;;;;;;;;commune;commune;Rue de Toutes Joies;Rue de Toutes Joies;;;44109_8171;44109_8171;;;;;LINESTRING Z (354187.8 6689962.5 25.4, 354195.3 6689976.1 25.4, 354199.1 6690019.6 25.4, 354201.2 6690071.6 28)
TRONROUT0000000029477954;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;28;23;20;17;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354341.2 6689987.4 29.4, 354332.1 6690048.3 29.7)
TRONROUT0000000029478358;Route à 1 chaussée;AV DE TOUTES JOIES;AV DE TOUTES JOIES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;3;2;5;6;44109;44109;;;;441098170;441098170;;;;;;;;;;;;;commune;commune;Avenue de Toutes Joies;Avenue de Toutes Joies;;;44109_8170;44109_8170;;;;;LINESTRING Z (354161.6 6689986.6 25.1, 354161.3 6690072.6 26.4)
TRONROUT0000000029478024;Rond-point;PL EMILE SARRADIN;PL EMILE SARRADIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;6;;6;44109;44109;;;;441092796;441092796;;;;;;;;;;;;;commune;commune;Place Emile Sarradin;Place Emile Sarradin;;;44109_2796;44109_2796;;;;;LINESTRING Z (354317.2 6690053.9 30.4, 354318.8 6690051.4 30.5, 354321.9 6690049.5 30.4, 354325.5 6690048.1 30.6, 354329.4 6690047.4 30.8, 354332.1 6690048.3 29.7)
TRONROUT0000000029478294;Rond-point;PL EMILE SARRADIN;PL EMILE SARRADIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;1;;1;44109;44109;;;;441092796;441092796;;;;;;;;;;;;;commune;commune;Place Emile Sarradin;Place Emile Sarradin;;;44109_2796;44109_2796;;;;;LINESTRING Z (354332.1 6690048.3 29.7, 354335.8 6690049.9 31.3, 354336.8 6690050.9 31.3, 354337.7 6690052.3 31.3, 354338.3 6690056.5 30)
TRONROUT0000000029478495;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;57;80;67;88;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354412.3 6690052.1 31.2, 354389.4 6690052.9 31.5, 354345.6 6690055.9 30.4, 354338.3 6690056.5 30)
TRONROUT0000000029478269;Rond-point;PL EMILE SARRADIN;PL EMILE SARRADIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;5;;5;44109;44109;;;;441092796;441092796;;;;;;;;;;;;;commune;commune;Place Emile Sarradin;Place Emile Sarradin;;;44109_2796;44109_2796;;;;;LINESTRING Z (354317.1 6690063.6 30.1, 354316.1 6690060.3 30.2, 354316 6690057.1 30.3, 354316.9 6690054.4 30.4, 354317.2 6690053.9 30.4)
TRONROUT0000000029478519;Rond-point;PL EMILE SARRADIN;PL EMILE SARRADIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;2;;3;44109;44109;;;;441092796;441092796;;;;;;;;;;;;;commune;commune;Place Emile Sarradin;Place Emile Sarradin;;;44109_2796;44109_2796;;;;;LINESTRING Z (354338.3 6690056.5 30, 354337.7 6690061.1 30.9, 354336.8 6690064.5 30.5, 354334.6 6690067.7 30.6, 354332.5 6690069.1 30.2, 354328.7 6690070.7 29.7)
TRONROUT0000000029478058;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;2;1;6;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354262.8 6690066.4 28.6, 354307.2 6690063 29.3, 354317.1 6690063.6 30)
TRONROUT0000000029478423;Route à 1 chaussée;PAS LEROY;PAS LEROY;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;22B;17;2;1;44109;44109;;;;441094933;441094933;;;;;;;;;;;;;commune;commune;Passage Leroy;Passage Leroy;;;44109_4933;44109_4933;;;;;LINESTRING Z (354483.9 6689976.3 32, 354486.6 6689965.8 31.3, 354486.8 6689965 31.3, 354509.7 6689876 23.2, 354523.2 6689823.6 31.1, 354523.6 6689822 31.1, 354525 6689810.9 31.1)
TRONROUT0000000029477597;Route à 1 chaussée;IMP PENEAU;IMP PENEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;2.3;;;;;Non;E;A;V;V;44109;44109;;;;441096308;441096308;;;;;;;;;;;;;commune;commune;Impasse Péneau;Impasse Péneau;;;44109_6308;44109_6308;;;;;LINESTRING Z (354413.9 6689853.6 29.9, 354424.5 6689965.7 31.1)
TRONROUT0000000029478242;Route à 1 chaussée;R EMILE COSSE;R EMILE COSSE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;1;6;1;44109;44109;;;;441092776;441092776;;;;;;;;;;;;;commune;commune;Rue Emile Cossé;Rue Emile Cossé;;;44109_2776;44109_2776;;;;;LINESTRING Z (354483.9 6689976.3 32, 354534.5 6689968 32.3)
TRONROUT0000000029477867;Route à 1 chaussée;IMP EMILE COSSE;IMP EMILE COSSE;5;Non;0;En service;2006-10-04 09:41:10;2023-02-19 11:52:55;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;24;13;8;5;44109;44109;;;;441092775;441092775;;;;;;;;;;;;;commune;commune;Impasse Emile Cossé;Impasse Emile Cossé;;;44109_2775;44109_2775;;;;;LINESTRING Z (354394.5 6689985.9 30.2, 354427 6689985.7 30.2, 354460.6 6689979.8 30.2, 354474.8 6689978.3 32, 354475.3 6689978.2 32, 354483.9 6689976.3 32)
TRONROUT0000000029478348;Route à 1 chaussée;R LEROY;R LEROY;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;19;24;27;32;44109;44109;;;;441094936;441094936;;;;;;;;;;;;;commune;commune;Rue Leroy;Rue Leroy;;;44109_4936;44109_4936;;;;;LINESTRING Z (354465.3 6690049.5 31.8, 354470.6 6690032.3 31.4, 354483.9 6689976.3 32)
TRONROUT0000000029478191;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;39;66;45;70;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354523.8 6690048.1 31.7, 354483.9 6690048.8 31.5)
TRONROUT0000000029478119;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;47;72;47;72;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354483.9 6690048.8 31.5, 354465.3 6690049.5 31.8)
TRONROUT0000000029478165;Route à 1 chaussée;R FELIBIEN;R FELIBIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;49;72;55;78;44109;44109;;;;441093056;441093056;;;;;;;;;;;;;commune;commune;Rue Félibien;Rue Félibien;;;44109_3056;44109_3056;;;;;LINESTRING Z (354465.3 6690049.5 31.8, 354412.3 6690052.1 31.2)
TRONROUT0000000029478073;Route à 1 chaussée;R D'HAVELOOZE;R D'HAVELOOZE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12B;15;2;1;44109;44109;;;;441094090;441094090;;;;;;;;;;;;;commune;commune;Rue d'Havelooze;Rue d'Havelooze;;;44109_4090;44109_4090;;;;;LINESTRING Z (354510.3 6690145.6 31.9, 354489.5 6690098.5 32, 354483.9 6690048.8 31.5)
TRONROUT0000000029478476;Route à 1 chaussée;PAS FELIBIEN;PAS FELIBIEN;5;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;1;2;13;22;44109;44109;;;;441093055;441093055;;;;;;;;;;;;;commune;commune;Passage Félibien;Passage Félibien;;;44109_3055;44109_3055;;;;;LINESTRING Z (354454.5 6690206.7 30.9, 354452.8 6690202.5 30.8, 354414 6690103.3 32.2, 354412.5 6690057.9 31.2, 354412.3 6690052.1 31.2)
TRONROUT0000000029478322;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354085.8 6690028.9 28.2, 354082 6690028.7 28, 354079.5 6690026.7 28, 354077.7 6690024.3 28.4)
TRONROUT0000000029478068;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354085.8 6690028.9 29.7, 354089.7 6690034.5 32.6, 354091.7 6690035.9 32.9)
TRONROUT0000000029478306;Route à 1 chaussée;R BOUCHAUD;R BOUCHAUD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;91;78;109;94;44109;44109;;;;441091080;441091080;;;;;;;;;;;;;commune;commune;Rue Bouchaud;Rue Bouchaud;;;44109_1080;44109_1080;;;;;LINESTRING Z (353892.0022898072 6690073.612518788 17.96534347110355, 353896.9 6690079 18.7)
TRONROUT0000000029478331;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354091.7 6690035.9 30.2, 354095.9 6690035.8 30.2, 354098.8 6690040 30.4)
TRONROUT0000000029477990;Route à 1 chaussée;R DES DERVALLIERES;R DES DERVALLIERES;4;Non;0;En service;2006-10-04 09:41:10;2023-05-31 00:37:57;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;2;7T;6;44109;44109;;;;441092412;441092412;;;;;;;;;;;;;commune;commune;Rue des Dervallières;Rue des Dervallières;;;44109_2412;44109_2412;;;;;LINESTRING Z (353990.6 6690053.3 22.3, 354028.1 6690044.2 24.8, 354077.7 6690024.3 24.7)
TRONROUT0000000029478066;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354090.1 6690044 30.9, 354089 6690039.3 30.8, 354091.7 6690035.9 30.2)
TRONROUT0000000029478061;Rond-point;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354098.8 6690040 27.9, 354098.7 6690043.3 29.4, 354094.6 6690045.9 30.1, 354090.1 6690044 30.9)
TRONROUT0000000029478336;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;19;19;19;13;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354116.8 6690055.8 25.9, 354098.8 6690040 25.3)
TRONROUT0000000029477988;Route à 1 chaussée;R DES DERVALLIERES;R DES DERVALLIERES;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;12;7T;10;7T;44109;44109;;;;441092412;441092412;;;;;;;;;;;;;commune;commune;Rue des Dervallières;Rue des Dervallières;;;44109_2412;44109_2412;;;;;LINESTRING Z (353944.8 6690061.9 20.2, 353960.1 6690059.6 21.6, 353990.6 6690053.3 22.3)
TRONROUT0000000029478325;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;19;;13;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354116.8 6690055.8 27.6, 354128.1 6690062.1 27.9, 354142.6 6690074.1 28.5)
TRONROUT0000000029478096;Rond-point;PL EMILE SARRADIN;PL EMILE SARRADIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;4;;4;44109;44109;;;;441092796;441092796;;;;;;;;;;;;;commune;commune;Place Emile Sarradin;Place Emile Sarradin;;;44109_2796;44109_2796;;;;;LINESTRING Z (354328.7 6690070.7 29.7, 354325.3 6690070 30.1, 354322 6690069.1 30, 354319.3 6690066.6 30, 354317.1 6690063.9 30.1, 354317.1 6690063.6 30.1)
TRONROUT0000000029478520;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;16;5B;8;3;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354201.2 6690071.6 28, 354242.4 6690069 28.6, 354262.8 6690066.4 28.6)
TRONROUT0000000029477953;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;16;5T;16;5T;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354190.5 6690072.2 27.3, 354201.2 6690071.6 28)
TRONROUT0000000029478128;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;22;7;18;5T;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354161.3 6690072.6 26.4, 354190.5 6690072.2 27.3)
TRONROUT0000000029478305;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;24;11;22;9;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354142.6 6690074.1 26.4, 354149.9 6690073 26.4, 354161.3 6690072.6 26.4)
TRONROUT0000000029477970;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;27;30;35;36B;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354328.7 6690070.7 29.7, 354317.7 6690144.1 29.6)
TRONROUT0000000029478186;Route à 1 chaussée;R GUIBAL;R GUIBAL;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;19;20;35;36;44109;44109;;;;441093924;441093924;;;;;;;;;;;;;commune;commune;Rue Guibal;Rue Guibal;;;44109_3924;44109_3924;;;;;LINESTRING Z (354296.6 6690196.2 28.6, 354262.8 6690066.4 28.6)
TRONROUT0000000029477910;Route à 1 chaussée;AV LOUIS VASSEUR;AV LOUIS VASSEUR;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;1;2;5;4;44109;44109;;;;441095142;441095142;;;;;;;;;;;;;commune;commune;Avenue Louis Vasseur;Avenue Louis Vasseur;;;44109_5142;44109_5142;;;;;LINESTRING Z (354351.9 6690158.7 29.5, 354382.5 6690142.7 29.6)
TRONROUT0000000029478290;Route à 1 chaussée;R GABRIEL LUNEAU;R GABRIEL LUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;3;6;44109;44109;;;;441093420;441093420;;;;;;;;;;;;;commune;commune;Rue Gabriel Luneau;Rue Gabriel Luneau;;;44109_3420;44109_3420;;;;;LINESTRING Z (354351.9 6690158.7 29.5, 354344.9 6690150.2 29.6, 354337.2 6690147.2 29.6, 354317.7 6690144.1 29.6)
TRONROUT0000000029478500;Route à 1 chaussée;R ALFRED DE MUSSET;R ALFRED DE MUSSET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;3;4;27;20;44109;44109;;;;441090128;441090128;;;;;;;;;;;;;commune;commune;Rue Alfred de Musset;Rue Alfred de Musset;;;44109_0128;44109_0128;;;;;LINESTRING Z (354190.5 6690072.2 27.3, 354237.5 6690247.4 27.1)
TRONROUT0000000029478502;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Levé GPS;2.5;Levé GPS;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;19;;13;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354128 6690079.8 26.1, 354124.5 6690068.4 25.9, 354116.8 6690055.8 25.9)
TRONROUT0000000029477900;Route à 1 chaussée;R DES DERVALLIERES;R DES DERVALLIERES;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;16B;15;12;11B;44109;44109;;;;441092412;441092412;;;;;;;;;;;;;commune;commune;Rue des Dervallières;Rue des Dervallières;;;44109_2412;44109_2412;;;;;LINESTRING Z (353896.9 6690079 18.7, 353908 6690074.4 19.5, 353939.7 6690064.5 20.5, 353944.8 6690061.9 20.2)
TRONROUT0000000029478489;Route à 1 chaussée;R GERMAIN BOFFRAND;R GERMAIN BOFFRAND;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;24;11;22;9;44109;44109;;;;441093712;441093712;;;;;;;;;;;;;commune;commune;Rue Germain Boffrand;Rue Germain Boffrand;;;44109_3712;44109_3712;;;;;LINESTRING Z (354128 6690079.8 26.1, 354142.6 6690074.1 26.4)
TRONROUT0000000029477864;Route à 1 chaussée;R DES DERVALLIERES;R DES DERVALLIERES;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;16T;17;16B;17;44109;44109;;;;441092412;441092412;;;;;;;;;;;;;commune;commune;Rue des Dervallières;Rue des Dervallières;;;44109_2412;44109_2412;;;;;LINESTRING Z (353892.0022898072 6690081.311278967 18.534908645189944, 353896.9 6690079 18.7)
TRONROUT0000000029478298;Route à 1 chaussée;R OCTAVE FEUILLET;R OCTAVE FEUILLET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;3;;15;;44109;44109;;;;441095996;441095996;;;;;;;;;;;;;commune;commune;Rue Octave Feuillet;Rue Octave Feuillet;;;44109_5996;44109_5996;;;;;LINESTRING Z (354090.1 6690044 25.3, 354089.1 6690091.9 24.3, 354092 6690124.5 23.6, 354095 6690140.5 23.3)
TRONROUT0000000029478425;Route à 1 chaussée;R ALEXANDRE DUMAS;R ALEXANDRE DUMAS;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;8;;4;;44109;44109;;;;441090088;441090088;;;;;;;;;;;;;commune;commune;Rue Alexandre Dumas;Rue Alexandre Dumas;;;44109_0088;44109_0088;;;;;LINESTRING Z (354148.9 6690136.6 26.1, 354131.6 6690100.3 25.6, 354129.4 6690091 25.6, 354128 6690079.8 26.1)
TRONROUT0000000029478455;Route à 1 chaussée;R CHANOINE COURTONNE;R CHANOINE COURTONNE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0C8;44109#0C8;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354095 6690140.5 23.3, 354129.1 6690138 25.1, 354148.9 6690136.6 26.1)
TRONROUT0000000029478384;Route à 1 chaussée;R FRANCIS MERLANT;R FRANCIS MERLANT;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;16;33;2;1;44109;44109;;;;441093288;441093288;;;;;;;;;;;;;commune;commune;Rue Francis Merlant;Rue Francis Merlant;;;44109_3288;44109_3288;;;;;LINESTRING Z (354051.6 6690318.5 18.8, 354044.9 6690307.4 18.8, 354019.7 6690188.8 20.4, 354016 6690172 20.6, 354009.3 6690140.3 21.1, 353990.6 6690053.3 22.3)
TRONROUT0000002204086591;Route à 1 chaussée;R DES FOLIES CHAILLOU;R DES FOLIES CHAILLOU;5;Non;0;En service;2019-09-11 09:41:06;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1B;2;41;42;44109;44109;;;;441093176;441093176;;;;;;;;;;;;;commune;commune;Rue des Folies Chaillou;Rue des Folies Chaillou;;;44109_3176;44109_3176;;;;;LINESTRING Z (353892.0022898072 6690162.074057897 20.804707127151485, 353931.1 6690272.7 18.5, 353933.2 6690278.5 18.2)
TRONROUT0000000029477912;Route à 1 chaussée;R OCTAVE FEUILLET;R OCTAVE FEUILLET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;15;20;43;38;44109;44109;;;;441095996;441095996;;;;;;;;;;;;;commune;commune;Rue Octave Feuillet;Rue Octave Feuillet;;;44109_5996;44109_5996;;;;;LINESTRING Z (354095 6690140.5 23.3, 354098 6690152.6 23, 354102.9 6690178.3 22, 354103.8 6690185.6 22, 354103.6 6690198 22, 354103.4 6690226.2 21.6, 354103.2 6690290.5 20.7)
TRONROUT0000000029478344;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;37;38;39;44;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354317.7 6690144.1 29.6, 354309.5 6690199.1 28.8)
TRONROUT0000000295265180;Route à 1 chaussée;R GUIBAL;R GUIBAL;5;Non;0;En service;2012-02-08 10:00:49;2023-05-27 02:00:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;38;;40;44109;44109;;;;441093924;441093924;;;;;;;;;;;;;commune;commune;Rue Guibal;Rue Guibal;;;44109_3924;44109_3924;;;;;LINESTRING Z (354309.5 6690199.1 28.8, 354302.8 6690198.7 28.7, 354300.2 6690198.5 28.7, 354297.7 6690197.4 28.7, 354296.6 6690196.2 28.6)
TRONROUT0000000029477877;Route à 1 chaussée;R ALEXANDRE DUMAS;R ALEXANDRE DUMAS;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;10;25;20;44109;44109;;;;441090088;441090088;;;;;;;;;;;;;commune;commune;Rue Alexandre Dumas;Rue Alexandre Dumas;;;44109_0088;44109_0088;;;;;LINESTRING Z (354201.5 6690259.8 26.7, 354179.2 6690207.5 25.8, 354167 6690178.9 25.9, 354148.9 6690136.6 26.1)
TRONROUT0000000029478424;Route à 1 chaussée;R GABRIEL LUNEAU;R GABRIEL LUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;8;13;22;44109;44109;;;;441093420;441093420;;;;;;;;;;;;;commune;commune;Rue Gabriel Luneau;Rue Gabriel Luneau;;;44109_3420;44109_3420;;;;;LINESTRING Z (354381.7 6690257.8 29.4, 354354.1 6690164.1 29.7, 354351.9 6690158.7 29.5)
TRONROUT0000000295264862;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;41;46;43;48;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354309.5 6690199.1 28.8, 354306.6 6690218.4 28.6, 354305.4 6690226.6 28.5)
TRONROUT0000000295265184;Route à 1 chaussée;R GUIBAL;R GUIBAL;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;41;;37;44109;44109;;;;441093924;441093924;;;;;;;;;;;;;commune;commune;Rue Guibal;Rue Guibal;;;44109_3924;44109_3924;;;;;LINESTRING Z (354285.3 6690232.8 28, 354296.8 6690226.7 28, 354298.4 6690224.1 28, 354299.6 6690219.2 28, 354299.5 6690213.9 28, 354295.7 6690201.4 28, 354296.6 6690196.2 28.6)
TRONROUT0000000295264863;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;3;2;1;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354285.3 6690232.8 28, 354305.4 6690226.6 28.5)
TRONROUT0000000029478696;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;8;9;4;5;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354237.5 6690247.4 27.1, 354285.3 6690232.8 28)
TRONROUT0000000029478428;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;15B;8;13;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354201.5 6690259.8 26.7, 354237.5 6690247.4 27.1)
TRONROUT0000000029477986;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;49;50;53;52;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354305.4 6690226.6 28.5, 354297.3 6690280.8 28)
TRONROUT0000000029478474;Route à 1 chaussée;R DE MISERICORDE;R DE MISERICORDE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;41;;37;44109;44109;;;;441095680;441095680;;;;;;;;;;;;;commune;commune;Rue de Miséricorde;Rue de Miséricorde;;;44109_5680;44109_5680;;;;;LINESTRING Z (354521.2 6690173 31.9, 354454.5 6690206.7 30.9)
TRONROUT0000000029478713;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354497.1 6690210.8 32.8, 354523.3 6690191.9 33.4)
TRONROUT0000000029478694;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354461.6 6690236.4 31.9, 354497.1 6690210.8 32.8)
TRONROUT0000000295264858;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354497.1 6690210.8 32.8, 354515.8 6690236.5 32.9)
TRONROUT0000000029478715;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354445.8 6690215.6 31.5, 354461.6 6690236.4 31.9)
TRONROUT0000000029478015;Route à 1 chaussée;R DE MISERICORDE;R DE MISERICORDE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;55;;43;44109;44109;;;;441095680;441095680;;;;;;;;;;;;;commune;commune;Rue de Miséricorde;Rue de Miséricorde;;;44109_5680;44109_5680;;;;;LINESTRING Z (354454.5 6690206.7 30.9, 354439.1 6690214.2 30.2, 354435.3 6690215.8 30.2, 354432.1 6690217.7 30.2, 354429.4 6690219.9 30.2, 354425.9 6690223.3 30.2, 354422 6690227 30, 354405.4 6690240.7 29.5, 354398 6690247.8 29.4, 354395.1 6690250.2 30.2, 354387.8 6690255.8 29.4, 354384.2 6690257.5 29.4, 354381.7 6690257.8 29.4)
TRONROUT0000000029478690;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354428.7 6690260.2 31.2, 354461.6 6690236.4 31.9)
TRONROUT0000000029478650;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354461.6 6690236.4 31.9, 354480 6690260.5 32.4)
TRONROUT0000000295265022;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354480 6690260.5 32.4, 354515.8 6690236.5 32.9)
TRONROUT0000000029478691;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354414.6 6690241.8 31.4, 354428.7 6690260.2 31.2)
TRONROUT0000000295265052;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354411.1 6690273.1 31.1, 354400.8 6690256.5 31.2)
TRONROUT0000000029478716;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354411.1 6690273.1 31.2, 354428.7 6690260.2 31.2)
TRONROUT0000000295264820;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354428.7 6690260.2 31.2, 354446.9 6690284.2 31.9)
TRONROUT0000000295265070;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354446.9 6690284.2 31.9, 354480 6690260.5 32.4)
TRONROUT0000000295264854;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354480 6690260.5 32.4, 354502.2 6690289.8 33)
TRONROUT0000000029478108;Route à 1 chaussée;R GABRIEL LUNEAU;R GABRIEL LUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;15;24;23;30;44109;44109;;;;441093420;441093420;;;;;;;;;;;;;commune;commune;Rue Gabriel Luneau;Rue Gabriel Luneau;;;44109_3420;44109_3420;;;;;LINESTRING Z (354398.3 6690313.3 30.8, 354381.7 6690257.8 29.4)
TRONROUT0000000295264741;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354424.2 6690299.7 31.9, 354411.1 6690273.1 31.2)
TRONROUT0000000295264954;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354424.2 6690299.7 31.9, 354446.9 6690284.2 31.9)
TRONROUT0000000029478663;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354446.9 6690284.2 31.9, 354469.5 6690313.8 32.9)
TRONROUT0000000295264843;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354502.2 6690289.8 33, 354518.4 6690311 33.6)
TRONROUT0000000029474656;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355219 6689730.3 19.9, 355218.6 6689731.3 20.1, 355216.1 6689738.9 20.4, 355215.6 6689745.2 20.3, 355216.5 6689751.5 20.1, 355217.9 6689754.3 19.8)
TRONROUT0000000029473991;Route à 1 chaussée;R DIDIENNE;R DIDIENNE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;4;;2;;44109;44109;;;;441092476;441092476;;;;;;;;;;;;;commune;commune;Rue Didienne;Rue Didienne;;;44109_2476;44109_2476;;;;;LINESTRING Z (355232.7 6689744.5 14.2, 355243 6689745.7 10.2, 355261.5 6689747.7 6.5, 355265.6 6689747.4 6.4, 355272.7 6689747.6 6.2, 355284.3 6689746.1 6.2)
TRONROUT0000000029473994;Escalier;R DIDIENNE;R DIDIENNE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441092476;441092476;;;;;;;;;;;;;commune;commune;Rue Didienne;Rue Didienne;;;44109_2476;44109_2476;;;;;LINESTRING Z (355217.9 6689754.3 19.8, 355220.2 6689752.1 19.8, 355219.7 6689743.3 18.1, 355230.1 6689744.2 15, 355232.7 6689744.5 14.2)
TRONROUT0000000029474529;Sentier;RLE DU PETIT BOURGNEUF;RLE DU PETIT BOURGNEUF;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;;2;;44109;44109;;;;441096420;441096420;;;;;;;;;;;;;commune;commune;Ruelle du Petit Bourgneuf;Ruelle du Petit Bourgneuf;;;44109_6420;44109_6420;;;;;LINESTRING Z (355238.3 6689815.2 11.4, 355237.6 6689801.5 13, 355231.9 6689776.6 14.3, 355232.7 6689744.5 14.2)
TRONROUT0000000029474768;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355217.9 6689754.3 19.8, 355220.6 6689760.8 19.7, 355221.3 6689766.7 19.6, 355220.9 6689810.8 19.1, 355218.2 6689811.7 19.1, 355214 6689813.1 19.2)
TRONROUT0000000029474369;Route à 1 chaussée;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;5;;5;;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355204.9 6689753.1 19.8, 355204.5 6689804.1 19.3, 355205.3 6689815.9 19.6)
TRONROUT0000000029473623;Sentier;RLE DES TANNEURS;RLE DES TANNEURS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;8;;8;;44109;44109;RLE DU QUAI DES TANNEURS;RLE DU QUAI DES TANNEURS;;441098040;441098040;;;;;;;;;;;;;commune;commune;Ruelle des Tanneurs;Ruelle des Tanneurs;;;44109_8040;44109_8040;;;;;LINESTRING Z (355296.3 6689783.7 6.3, 355282.1 6689789.3 6.3, 355266.7 6689796.1 6.7, 355260 6689798.1 7.6, 355249.3 6689799.1 8.2)
TRONROUT0000000295264935;Escalier;RLE DES TANNEURS;RLE DES TANNEURS;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;8;;8;;44109;44109;;;;441098040;441098040;;;;;;;;;;;;;commune;commune;Ruelle des Tanneurs;Ruelle des Tanneurs;;;44109_8040;44109_8040;;;;;LINESTRING Z (355249.3 6689799.1 8.2, 355242.9 6689800.3 10.3, 355241.6 6689801.4 10.8, 355241.5 6689803.1 11.4)
TRONROUT0000000295265215;Escalier;RLE DES TANNEURS;RLE DES TANNEURS;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;31;;31;44109;44109;;;;441098040;441098040;;;;;;;;;;;;;commune;commune;Ruelle des Tanneurs;Ruelle des Tanneurs;;;44109_8040;44109_8040;;;;;LINESTRING Z (355241.5 6689803.1 11.4, 355240.8 6689808.5 12.6, 355239.2 6689812.4 13, 355238.3 6689815.2 12.5)
TRONROUT0000000295266735;Route à 1 chaussée;;;5;Non;0;En service;2012-02-08 10:00:49;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355214 6689813.1 19.2, 355205.3 6689815.9 19.6)
TRONROUT0000000029474410;Route à 1 chaussée;R DU MARCHIX;R DU MARCHIX;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095340;441095340;;;;;;;;;;;;;commune;commune;Rue du Marchix;Rue du Marchix;;;44109_5340;44109_5340;;;;;LINESTRING Z (355038.3 6689814.9 24.8, 355030.3 6689821.4 24.8, 355022.2 6689828.2 25.6, 355012.6 6689837.7 25.8, 355005.7 6689845.6 26.1, 355003.5 6689848.9 26.2)
TRONROUT0000000029474420;Route à 1 chaussée;PL SAINTE-ELISABETH;PL SAINTE-ELISABETH;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097588;441097588;;;;;;;;;;;;;commune;commune;Place Sainte Elisabeth;Place Sainte Elisabeth;;;44109_7588;44109_7588;;;;;LINESTRING Z (354982.5 6689838.7 25.8, 354993 6689833.4 25.3, 354996.1 6689831.9 25.2, 355001.5 6689830.9 25.1)
TRONROUT0000000029473815;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;13;12;13;16;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355080.1 6689857.6 25.7, 355038.3 6689814.9 24.8)
TRONROUT0000000029473613;Route à 1 chaussée;PL SAINTE-ELISABETH;PL SAINTE-ELISABETH;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;4;;4;44109;44109;;;;441097588;441097588;;;;;;;;;;;;;commune;commune;Place Sainte Elisabeth;Place Sainte Elisabeth;;;44109_7588;44109_7588;;;;;LINESTRING Z (354953 6689862.8 27.3, 354954.6 6689859.3 27.2, 354958.2 6689854.3 26.9, 354963.5 6689849.7 26.7, 354972.9 6689843.7 26.3, 354982.5 6689838.7 25.8)
TRONROUT0000000029474391;Route à 1 chaussée;R PORTE NEUVE;R PORTE NEUVE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441096844;441096844;;;;;;;;;;;;;commune;commune;Rue Porte Neuve;Rue Porte Neuve;;;44109_6844;44109_6844;;;;;LINESTRING Z (354975.2 6689883.2 26.5, 354979 6689870.5 26, 354983.4 6689859.4 25.6, 354990.1 6689847.1 25.5, 354997.8 6689835.3 25.3, 355001.5 6689830.9 25.1)
TRONROUT0000000029474348;Route à 1 chaussée;R DU TREPIED;R DU TREPIED;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;11;;11;;44109;44109;;;;441098198;441098198;;;;;;;;;;;;;commune;commune;Rue du Trépied;Rue du Trépied;;;44109_8198;44109_8198;;;;;LINESTRING Z (355003.5 6689848.9 26.2, 355009.7 6689847.9 25.9, 355012.1 6689848.9 25.9, 355014.4 6689850.8 25.9, 355029.1 6689872 26.6)
TRONROUT0000000029473606;Route à 1 chaussée;PL SAINTE-ELISABETH;PL SAINTE-ELISABETH;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097588;441097588;;;;;;;;;;;;;commune;commune;Place Sainte Elisabeth;Place Sainte Elisabeth;;;44109_7588;44109_7588;;;;;LINESTRING Z (354953 6689862.8 27.3, 354975.2 6689883.2 26.5)
TRONROUT0000000029474972;Route à 1 chaussée;R DU TREPIED;R DU TREPIED;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;4;9;6;44109;44109;;;;441098198;441098198;;;;;;;;;;;;;commune;commune;Rue du Trépied;Rue du Trépied;;;44109_8198;44109_8198;;;;;LINESTRING Z (355038.3 6689887.1 27.2, 355052 6689879.6 26.7, 355065.7 6689871.4 25.8, 355083.4 6689860.8 25.1)
TRONROUT0000000029475021;Route à 1 chaussée;R DU TREPIED;R DU TREPIED;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098198;441098198;;;;;;;;;;;;;commune;commune;Rue du Trépied;Rue du Trépied;;;44109_8198;44109_8198;;;;;LINESTRING Z (355029.1 6689872 26.6, 355038.3 6689887.1 27.2)
TRONROUT0000000316373864;Route à 1 chaussée;ALL DOCTEUR EMILE MEEUS;ALL DOCTEUR EMILE MEEUS;6;Non;0;En service;2012-12-06 10:18:17;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EQ;44109#0EQ;;;;;;;;;;;;;commune;commune;Allée Docteur Emile Meeus;Allée Docteur Emile Meeus;;;44109_2505;44109_2505;;;;;LINESTRING Z (355029.1 6689872 26.6, 355009.3 6689929.4 27.4)
TRONROUT0000000029475240;Route à 1 chaussée;R EDMOND PRIEUR;R EDMOND PRIEUR;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CW;44109#0CW;;;;;;;;;;;;;commune;commune;Rue Edmond Prieur;Rue Edmond Prieur;;;44109_2719;44109_2719;;;;;LINESTRING Z (355163.4 6689827.9 21.4, 355080.1 6689857.6 25.7)
TRONROUT0000000029473872;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;11;12;11;12;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355083.4 6689860.8 25.1, 355080.1 6689857.6 25.7)
TRONROUT0000000029473551;Route à 1 chaussée;R LEON JAMIN;R LEON JAMIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;34;41;26;33;44109;44109;;;;441094908;441094908;;;;;;;;;;;;;commune;commune;Rue Léon Jamin;Rue Léon Jamin;;;44109_4908;44109_4908;;;;;LINESTRING Z (355172.4 6689909.1 21.5, 355168.1 6689870.6 21.4, 355166.9 6689860 21.4, 355163.4 6689827.9 21.4)
TRONROUT0000000295264896;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;11;10B;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355160.6 6689927.8 21.9, 355151.3 6689921.8 21.9, 355106.3 6689881.4 24, 355095 6689871.2 23.7, 355083.4 6689860.8 25.1)
TRONROUT0000000295265234;Route à 1 chaussée;R LEON JAMIN;R LEON JAMIN;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;36;;38;44109;44109;;;;441094908;441094908;;;;;;;;;;;;;commune;commune;Rue Léon Jamin;Rue Léon Jamin;;;44109_4908;44109_4908;;;;;LINESTRING Z (355172.4 6689909.1 21.5, 355177.1 6689914.1 21.5, 355182.3 6689918.5 21.5, 355185.7 6689921.5 21.1)
TRONROUT0000000295265236;Route à 1 chaussée;R LEON JAMIN;R LEON JAMIN;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;;;;;;;;;Non;;45;;43;44109;44109;;;;441094908;441094908;;;;;;;;;;;;;commune;commune;Rue Léon Jamin;Rue Léon Jamin;;;44109_4908;44109_4908;;;;;LINESTRING Z (355176.4 6689930.4 21.4, 355174.2 6689922.8 21.5, 355173 6689915.7 21.5, 355172.4 6689909.1 21.5)
TRONROUT0000000295264902;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355176.4 6689930.4 21.4, 355179.9 6689926.3 21.4, 355185.7 6689921.5 21.1)
TRONROUT0000000295264897;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355172.5 6689932.8 21.7, 355164.9 6689930.6 22, 355160.6 6689927.8 21.9)
TRONROUT0000000029474405;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355174.9 6689933.5 21.6, 355176.4 6689930.4 21.4)
TRONROUT0000000029474849;Route à 1 chaussée;R JEAN JAURES;R JEAN JAURES;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094476;441094476;;;;;;;;;;;;;commune;commune;Rue Jean Jaurès;Rue Jean Jaurès;;;44109_4476;44109_4476;;;;;LINESTRING Z (355174.9 6689933.5 21.6, 355172.5 6689932.8 21.7)
TRONROUT0000000295265020;Escalier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355238.3 6689815.2 12.5, 355221.9 6689819.1 19.1, 355216.4 6689818 19.3, 355214 6689813.1 19.2)
TRONROUT0000000029473727;Route à 1 chaussée;R LEOPOLD CASSEGRAIN;R LEOPOLD CASSEGRAIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;5;12;5;18;44109;44109;;;;44109#0C4;44109#0C4;;;;;;;;;;;;;commune;commune;Rue Léopold Cassegrain;Rue Léopold Cassegrain;;;44109_4924;44109_4924;;;;;LINESTRING Z (355205.3 6689815.9 19.6, 355205.9 6689870.3 20.2, 355205.8 6689875.2 20.5)
TRONROUT0000000029474436;Route à 1 chaussée;R DU BOURGNEUF;R DU BOURGNEUF;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;2;29;2;25;44109;44109;;;;441091156;441091156;;;;;;;;;;;;;commune;commune;Rue du Bourgneuf;Rue du Bourgneuf;;;44109_1156;44109_1156;;;;;LINESTRING Z (355238.3 6689815.2 12.5, 355238.4 6689816.5 12.5, 355242.5 6689824 12.5, 355244.7 6689826.9 12, 355277.7 6689869.7 4.7, 355285.6 6689879.9 8.2, 355290.4 6689886.2 7.6)
TRONROUT0000000029473988;Escalier;R LE NOTRE;R LE NOTRE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441094896;441094896;;;;;;;;;;;;;commune;commune;Rue Le Nôtre;Rue Le Nôtre;;;44109_4896;44109_4896;;;;;LINESTRING Z (355260.1 6689897.3 13.4, 355270.1 6689893.5 9, 355273.5 6689890.8 9, 355279 6689889 9, 355290.4 6689886.2 7.6)
TRONROUT0000000029473696;Route à 1 chaussée;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;18B;;18B;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355205.8 6689875.2 20.5, 355208 6689900.6 20.6, 355209.4 6689912.6 20.3)
TRONROUT0000000029474176;Route à 1 chaussée;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;1;;1;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355185.7 6689921.5 21.1, 355195.6 6689905 20.6, 355199 6689897.8 20.5, 355203.4 6689885.9 20.4, 355205.8 6689875.2 20.5)
TRONROUT0000000029475313;Escalier;R LE NOTRE;R LE NOTRE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441094896;441094896;;;;;;;;;;;;;commune;commune;Rue Le Nôtre;Rue Le Nôtre;;;44109_4896;44109_4896;;;;;LINESTRING Z (355209.4 6689912.6 20.3, 355215.2 6689912.2 19.3, 355224.5 6689908.7 17.6, 355237 6689904.7 16.1, 355260.1 6689897.3 13.4)
TRONROUT0000000029474045;Route à 1 chaussée;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355209.4 6689912.6 20.3, 355211.7 6689927.3 20.2)
TRONROUT0000000029473621;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355185.7 6689921.5 21.1, 355193.4 6689921.4 21.1, 355200.4 6689922.5 20.9, 355206.4 6689924.5 20.8, 355211.7 6689927.3 20.2)
TRONROUT0000000029474600;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;2;;2;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355211.7 6689927.3 20.2, 355212.4 6689941.1 20.2, 355210.7 6689947.2 20.2, 355208.7 6689949.5 20.2)
TRONROUT0000000029474164;Route à 1 chaussée;R PORTE NEUVE;R PORTE NEUVE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;4;;20;44109;44109;;;;441096844;441096844;;;;;;;;;;;;;commune;commune;Rue Porte Neuve;Rue Porte Neuve;;;44109_6844;44109_6844;;;;;LINESTRING Z (355003.5 6689848.9 26.2, 354999.4 6689854.4 26.4, 354994.5 6689863.8 26.6, 354990.5 6689873 26.8, 354987.1 6689882.9 26.9, 354983.3 6689896.1 27.3, 354978 6689917.8 27.8, 354971.3 6689946.7 28.1, 354968.7 6689961 28.4)
TRONROUT0000000029474946;Route à 1 chaussée;ALL MAUD MANNONI;ALL MAUD MANNONI;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;;6;;44109;44109;;;;441095275;441095275;;;;;;;;;;;;;commune;commune;Allée Maud Mannoni;Allée Maud Mannoni;;;44109_5275;44109_5275;;;;;LINESTRING Z (355076.1 6689941.7 26.9, 355069.1 6689923.9 26.9, 355063 6689907.2 26.6, 355060.5 6689900.6 26.8, 355057.9 6689897 26.8, 355053.4 6689893.6 26.8, 355038.3 6689887.1 27.2)
TRONROUT0000000029474414;Route à 1 chaussée;R PORTE NEUVE;R PORTE NEUVE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;3;;3;;44109;44109;;;;441096844;441096844;;;;;;;;;;;;;commune;commune;Rue Porte Neuve;Rue Porte Neuve;;;44109_6844;44109_6844;;;;;LINESTRING Z (354954.1 6689957 28.4, 354958.5 6689948.2 27.9, 354963.6 6689932.5 27.6, 354968.6 6689912.8 27.4, 354972.1 6689896.3 27.1, 354975.2 6689883.2 26.5)
TRONROUT0000000029474364;Route à 1 chaussée;ALL DOCTEUR EMILE MEEUS;ALL DOCTEUR EMILE MEEUS;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0EQ;44109#0EQ;;;;;;;;;;;;;commune;commune;Allée Docteur Emile Meeus;Allée Docteur Emile Meeus;;;44109_2505;44109_2505;;;;;LINESTRING Z (355009.3 6689929.4 27.4, 355004 6689945.1 27.7)
TRONROUT0000000029473480;Route à 1 chaussée;RLE DU MARTRAY;RLE DU MARTRAY;6;Non;0;En service;2006-10-04 09:41:10;2012-12-06 10:18:31;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#0CO;44109#0CO;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355009.3 6689929.4 27.4, 355018.5 6689932.4 27.2, 355030.3 6689952.7 26.6, 355041.8 6689959.1 26.4)
TRONROUT0000000029474977;Route à 1 chaussée;PL MONTAIGNE;PL MONTAIGNE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;6;2;4;7;44109;44109;;;;441095741;441095741;;;;;;;;;;;;;commune;commune;Place Montaigne;Place Montaigne;;;44109_5741;44109_5741;;;;;LINESTRING Z (355004 6689945.1 27.7, 354994.6 6689942.1 28, 354987.8 6689962.5 28.6)
TRONROUT0000000029473775;Route à 1 chaussée;PL MONTAIGNE;PL MONTAIGNE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;6;;4;;44109;44109;;;;441095741;441095741;;;;;;;;;;;;;commune;commune;Place Montaigne;Place Montaigne;;;44109_5741;44109_5741;;;;;LINESTRING Z (354987.8 6689962.5 28.6, 355004.9 6689968.1 28.6, 355012.9 6689947.8 27.9, 355004 6689945.1 27.7)
TRONROUT0000000029474956;Rond-point;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354954.1 6689957 28.4, 354957.2 6689955.9 28.4, 354960.5 6689955.9 28.4, 354962.4 6689956.3 28.4, 354963.9 6689956.9 28.4, 354966.3 6689958.2 28.4, 354968.7 6689961 28.4)
TRONROUT0000000029475093;Rond-point;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354948.5 6689964.8 28.4, 354949.4 6689961.9 28.4, 354951.1 6689959.4 28.4, 354954.1 6689957 28.4)
TRONROUT0000000029475081;Rond-point;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354968.7 6689961 28.4, 354969.7 6689964.6 28.4)
TRONROUT0000000029474981;Route à 1 chaussée;PL MONTAIGNE;PL MONTAIGNE;6;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;5.0;Non;Non;Double sens;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441095741;441095741;;;;;;;;;;;;;commune;commune;Place Montaigne;Place Montaigne;;;44109_5741;44109_5741;;;;;LINESTRING Z (354969.7 6689964.6 28.4, 354987.8 6689962.5 28.6)
TRONROUT0000000029473751;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;36;;32;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354917.6 6689963.1 30.9, 354933 6689963.1 29.9, 354948.5 6689964.8 28.4)
TRONROUT0000000029474360;Route à 1 chaussée;PL DU MARTRAY;PL DU MARTRAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;2;;1;44109;44109;;;;441095436;441095436;;;;;;;;;;;;;commune;commune;Place du Martray;Place du Martray;;;44109_5436;44109_5436;;;;;LINESTRING Z (355041.8 6689959.1 26.4, 355054.7 6689952 26.4, 355070.9 6689979.7 25.2)
TRONROUT0000000029473550;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;31;;31;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354917.6 6689963.1 30.9, 354911.6 6689963.9 31, 354907.6 6689965.9 31.2, 354904.4 6689968.5 31.5, 354901.3 6689971.4 31.2)
TRONROUT0000000029475088;Rond-point;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354969.7 6689964.6 28.4, 354970 6689968.9 28.4, 354969.5 6689970 28.4)
TRONROUT0000000029474861;Rond-point;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354969.5 6689970 28.4, 354968.7 6689972.1 28.4, 354965.5 6689975.1 28.4, 354961.7 6689976.4 28.4, 354958 6689976.5 28.4, 354955.2 6689976.1 28.4, 354953.2 6689975 28.4, 354949.8 6689971.3 28.4, 354948.6 6689968.1 28.4, 354948.5 6689964.8 28.4)
TRONROUT0000000029474863;Route à 1 chaussée;PL DU MARTRAY;PL DU MARTRAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;5;;5;44109;44109;;;;441095436;441095436;;;;;;;;;;;;;commune;commune;Place du Martray;Place du Martray;;;44109_5436;44109_5436;;;;;LINESTRING Z (355059.2 6689986.6 25.4, 355041.8 6689959.1 26.4)
TRONROUT0000000029474365;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;12;10;18;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355059.2 6689986.6 25.4, 355065.6 6689982.7 25.4, 355070.9 6689979.7 25.2)
TRONROUT0000000029474665;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355054.2 6689989.6 25.5, 355059.2 6689986.6 25.4)
TRONROUT0000000029473612;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354969.5 6689970 28.4, 354975.4 6689985.3 29, 354975.8 6689988.9 29.1, 354975 6689993.5 29.2, 354961.3 6690031.7 28.8)
TRONROUT0000000295265232;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355147.6 6689943.4 22, 355152.8 6689938.7 22.1, 355157.4 6689933.1 22.4, 355159.5 6689930 22.4, 355160.6 6689927.8 21.9)
TRONROUT0000000295265233;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355147.6 6689943.4 22, 355160.8 6689937.5 22.1, 355167.6 6689934.9 22.1, 355172.5 6689932.8 21.7)
TRONROUT0000000029474324;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355187.9 6689946.4 21.1, 355182.7 6689942.5 21.5, 355177 6689936.6 21.9, 355174.9 6689933.5 21.6)
TRONROUT0000000029473543;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;5;4;11;8;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355070.9 6689979.7 25.2, 355077.4 6689978.1 24.9, 355093.9 6689968.7 24.3, 355109.9 6689960.4 23.1, 355147.5 6689943.5 22.1, 355147.6 6689943.4 22)
TRONROUT0000000029474156;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355183.3 6690063.6 21.9, 355183.9 6690055.8 20.6)
TRONROUT0000000029474437;Route à 1 chaussée;R AUGUSTE BRIZEUX;R AUGUSTE BRIZEUX;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;1;2;23;18;44109;44109;;;;441090444;441090444;;;;;;;;;;;;;commune;commune;Rue Auguste Brizeux;Rue Auguste Brizeux;;;44109_0444;44109_0444;;;;;LINESTRING Z (354994.1 6690079.9 29.3, 355020.7 6690076.8 28.6, 355056.2 6690071.8 25.7, 355113 6690065.2 22.3, 355176.8 6690058.7 21.2, 355182.1 6690056.9 21, 355183.9 6690055.8 20.6)
TRONROUT0000000029473760;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;15;18;21;18;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355178.9 6690119.8 21.8, 355183.3 6690063.6 21.9)
TRONROUT0000000029473987;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;21;;21;;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355178.9 6690119.8 21.8, 355177.5 6690137.2 22.5)
TRONROUT0000000029474110;Route à 1 chaussée;R YVES BODIGUEL;R YVES BODIGUEL;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;22;21;2;1;44109;44109;;;;441098588;441098588;;;;;;;;;;;;;commune;commune;Rue Yves Bodiguel;Rue Yves Bodiguel;;;44109_8588;44109_8588;;;;;LINESTRING Z (355177.5 6690137.2 22.5, 355002.8 6690141.8 28.1)
TRONROUT0000000029473720;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;23;26;27;32;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355177.7 6690195.6 24.3, 355174.6 6690157 23.7, 355175.1 6690146.4 22.9, 355176.2 6690139.9 22.9, 355177.5 6690137.2 22.5)
TRONROUT0000000029473470;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;12B;2;12B;10B;44109;44109;IMP SARRAZIN;IMP SARRAZIN;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (355054.2 6689989.6 25.5, 355058 6689996.3 26, 355068.4 6690023.4 25.3)
TRONROUT0000000029474423;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;12;;18;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (354977.9 6690038.2 28.7, 354982.9 6690038.1 28.5, 354987.6 6690036.5 28.4, 354992.6 6690033.1 28.4, 355020.7 6690012.3 26.1, 355041.3 6689998 25.5, 355052.1 6689990.9 25.5, 355054.2 6689989.6 25.5)
TRONROUT0000000029474983;Route à 1 chaussée;R SARRAZIN;R SARRAZIN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097828;441097828;;;;;;;;;;;;;commune;commune;Rue Sarrazin;Rue Sarrazin;;;44109_7828;44109_7828;;;;;LINESTRING Z (354961.3 6690031.7 28.8, 354977.9 6690038.2 28.7)
TRONROUT0000000029474417;Route à 1 chaussée;R FREDUREAU;R FREDUREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;4;3;2;1;44109;44109;;;;441093352;441093352;;;;;;;;;;;;;commune;commune;Rue Frédureau;Rue Frédureau;;;44109_3352;44109_3352;;;;;LINESTRING Z (354994.1 6690079.9 29.3, 354988.5 6690047.1 29.5, 354985.1 6690042.4 29.1, 354977.9 6690038.2 28.7)
TRONROUT0000000029474408;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;23;;22;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354961.3 6690031.7 28.8, 354957.4 6690042.6 28.8, 354937.5 6690097 30.2, 354924.7 6690132 30.8, 354920.4 6690144 32.5)
TRONROUT0000000029474126;Route à 1 chaussée;R FREDUREAU;R FREDUREAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;7;6;3;44109;44109;;;;441093352;441093352;;;;;;;;;;;;;commune;commune;Rue Frédureau;Rue Frédureau;;;44109_3352;44109_3352;;;;;LINESTRING Z (355002.8 6690141.8 28.1, 354994.1 6690079.9 29.3)
TRONROUT0000000029474973;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354920.4 6690144 32.5, 354909.2 6690138.2 31.1, 354905.3 6690136.1 31.5)
TRONROUT0000000029474261;Route à 1 chaussée;R YVES BODIGUEL;R YVES BODIGUEL;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;28;23;22;21B;44109;44109;;;;441098588;441098588;;;;;;;;;;;;;commune;commune;Rue Yves Bodiguel;Rue Yves Bodiguel;;;44109_8588;44109_8588;;;;;LINESTRING Z (355002.8 6690141.8 28.1, 354932.7 6690146.3 31.8, 354925 6690146.1 32, 354920.4 6690144 32.5)
TRONROUT0000000029473617;Route à 1 chaussée;R DE SAVENAY;R DE SAVENAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;46;45;14;19;44109;44109;;;;441097848;441097848;;;;;;;;;;;;;commune;commune;Rue de Savenay;Rue de Savenay;;;44109_7848;44109_7848;;;;;LINESTRING Z (354888.6 6690222.7 34, 354898.7 6690227.5 34, 354907.2 6690229.9 34, 354913.4 6690230.3 34, 354917.3 6690230.1 34, 354925.7 6690228.4 33.7, 355047.8 6690187.3 29.4, 355057.8 6690186 28.5)
TRONROUT0000000029473997;Route à 1 chaussée;R RUSSEIL;R RUSSEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;51;42;59;42;44109;44109;;;;441097516;441097516;;;;;;;;;;;;;commune;commune;Rue Russeil;Rue Russeil;;;44109_7516;44109_7516;;;;;LINESTRING Z (354947.8 6690282.4 31.9, 354880.4 6690241.7 33.9)
TRONROUT0000000029473622;Rond-point;PL SAINT-SIMILIEN;PL SAINT-SIMILIEN;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;25;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441097748;441097748;;;;;;;;;;;;;commune;commune;Place Saint Similien;Place Saint Similien;;;44109_7748;44109_7748;;;;;LINESTRING Z (355208.7 6689949.5 20.2, 355206.4 6689950.8 20.2, 355198.9 6689950.6 20.5, 355193.5 6689949.5 20.7, 355187.9 6689946.4 21.1)
TRONROUT0000000029473859;Route à 1 chaussée;R JEANNE D'ARC;R JEANNE D'ARC;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10B;41;4;19;44109;44109;;;;441094500;441094500;;;;;;;;;;;;;commune;commune;Rue Jeanne d'Arc;Rue Jeanne d'Arc;;;44109_4500;44109_4500;;;;;LINESTRING Z (355208.7 6689949.5 20.2, 355215.5 6689956.2 20, 355225.3 6689961.7 19.7, 355231.9 6689963.9 19.4, 355264.9 6689975 17.8, 355334.8 6689998.8 14.4)
TRONROUT0000000029473500;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;10;13;2;3;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355183.9 6690055.8 20.6, 355187 6690034.6 20.6, 355189.4 6690009.9 20.4, 355191.9 6689974.5 20.7, 355190.7 6689954.1 20.7, 355187.9 6689946.4 21.1)
TRONROUT0000000029474732;Route à 1 chaussée;R BASSE PORTE;R BASSE PORTE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;7;;3;;44109;44109;;;;441090608;441090608;;;;;;;;;;;;;commune;commune;Rue Basse Porte;Rue Basse Porte;;;44109_0608;44109_0608;;;;;LINESTRING Z (355334.8 6689998.8 14.4, 355232.6 6690042.5 11.8, 355183.3 6690063.6 21.9)
TRONROUT0000000029474363;Route à 1 chaussée;IMP DE LA COURTINE;IMP DE LA COURTINE;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0GZ;44109#0GZ;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355301.8 6690195.3 16.1, 355293.7 6690199.4 15.8, 355292 6690201.7 15.9, 355273.2 6690243.4 16.6)
TRONROUT0000000029473628;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;47;40;67;54;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355199.4 6690441.4 22.8, 355193.1 6690374.1 24.2, 355186.3 6690300.9 25.8, 355183.9 6690274.4 26.4)
TRONROUT0000000029473876;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;68;63;56;53;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355227.2 6690460.1 21, 355231.6 6690451.4 20.7, 355235.9 6690443 20.5, 355299 6690318.3 17.6)
TRONROUT0000000029415062;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;69;54;71;54;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355199.4 6690441.4 22.8, 355202.1161210373 6690471.022695063 22.205848523095987)
TRONROUT0000000029414996;Route à 1 chaussée;R PAUL BELLAMY;R PAUL BELLAMY;3;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Double sens;;Oui;45;Libre;;;;;;;;;Non;72;63;70;63;44109;44109;;;;441096200;441096200;;;;;;;;;;;;;commune;commune;Rue Paul Bellamy;Rue Paul Bellamy;;;44109_6200;44109_6200;;;;;LINESTRING Z (355221.64007218817 6690471.022695063 21.433753233547826, 355227.2 6690460.1 21)
TRONROUT0000000029414997;Route à 1 chaussée;R DE BOUILLE;R DE BOUILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;7;2;1;44109;44109;;;;441091109;441091109;;;;;;;;;;;;;commune;commune;Rue de Bouillé;Rue de Bouillé;;;44109_1109;44109_1109;;;;;LINESTRING Z (355248.85164670815 6690471.022695063 20.083350886105134, 355236 6690464.5 20.6, 355227.2 6690460.1 21)
TRONROUT0000000029474908;Route à 1 chaussée;R DE SAVENAY;R DE SAVENAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;19;12;5;44109;44109;;;;441097848;441097848;;;;;;;;;;;;;commune;commune;Rue de Savenay;Rue de Savenay;;;44109_7848;44109_7848;;;;;LINESTRING Z (355057.8 6690186 28.5, 355109.1 6690182.4 27.5)
TRONROUT0000000029474470;Route à 1 chaussée;R DE SAVENAY;R DE SAVENAY;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;5;4;1;44109;44109;;;;441097848;441097848;;;;;;;;;;;;;commune;commune;Rue de Savenay;Rue de Savenay;;;44109_7848;44109_7848;;;;;LINESTRING Z (355109.1 6690182.4 27.5, 355121.3 6690182.1 27.5, 355177.7 6690195.6 24.3)
TRONROUT0000000029473741;Route à 1 chaussée;R DE BEL AIR;R DE BEL AIR;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;29;32;45;40;44109;44109;;;;441090684;441090684;;;;;;;;;;;;;commune;commune;Rue de Bel Air;Rue de Bel Air;;;44109_0684;44109_0684;;;;;LINESTRING Z (355183.9 6690274.4 26.4, 355181.1 6690239.9 25.5, 355180 6690225.6 25.1, 355177.7 6690195.6 24.3)
TRONROUT0000000029473668;Route à 1 chaussée;AV DOCTEUR HEURTEAUX;AV DOCTEUR HEURTEAUX;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14;13;2;1;44109;44109;;;;441092516;441092516;;;;;;;;;;;;;commune;commune;Avenue Docteur Heurteaux;Avenue Docteur Heurteaux;;;44109_2516;44109_2516;;;;;LINESTRING Z (355109.1 6690182.4 27.5, 355147.5 6690288.9 28.3)
TRONROUT0000000029473505;Route à 1 chaussée;R DES CAPITAINES DE CLERVILLE;R DES CAPITAINES DE CLERVILLE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;12;21;2;3;44109;44109;;;;441091416;441091416;;;;;;;;;;;;;commune;commune;Rue des Capitaines de Clerville;Rue des Capitaines de Clerville;;;44109_1416;44109_1416;;;;;LINESTRING Z (355101.8 6690307.1 28.9, 355057.8 6690186 28.5)
TRONROUT0000000029473925;Route à 1 chaussée;R JULES POLO;R JULES POLO;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;5;;1;44109;44109;;;;441094640;441094640;;;;;;;;;;;;;commune;commune;Rue Jules Polo;Rue Jules Polo;;;44109_4640;44109_4640;;;;;LINESTRING Z (355183.9 6690274.4 26.4, 355147.5 6690288.9 28.3)
TRONROUT0000000029474022;Route à 1 chaussée;R JULES POLO;R JULES POLO;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;4;11;2;7;44109;44109;;;;441094640;441094640;;;;;;;;;;;;;commune;commune;Rue Jules Polo;Rue Jules Polo;;;44109_4640;44109_4640;;;;;LINESTRING Z (355147.5 6690288.9 28.3, 355124.6 6690298 28.6, 355101.8 6690307.1 28.9)
TRONROUT0000000029474307;Route à 1 chaussée;R JULES POLO;R JULES POLO;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;15;4;13;44109;44109;;;;441094640;441094640;;;;;;;;;;;;;commune;commune;Rue Jules Polo;Rue Jules Polo;;;44109_4640;44109_4640;;;;;LINESTRING Z (355069.3 6690320.1 30, 355101.8 6690307.1 28.9)
TRONROUT0000000029414946;Route à 1 chaussée;R RUSSEIL;R RUSSEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;20;25;4;1;44109;44109;;;;441097516;441097516;;;;;;;;;;;;;commune;commune;Rue Russeil;Rue Russeil;;;44109_7516;44109_7516;;;;;LINESTRING Z (355065.2 6690357.7 27.8, 355158.3 6690415.8 24.1, 355188.2 6690436 22.8, 355199.4 6690441.4 22.8)
TRONROUT0000000029414973;Route à 1 chaussée;R HAUTE ROCHE;R HAUTE ROCHE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;14B;3B;2;1;44109;44109;;;;441094060;441094060;;;;;;;;;;;;;commune;commune;Rue Haute Roche;Rue Haute Roche;;;44109_4060;44109_4060;;;;;LINESTRING Z (355199.4 6690441.4 22.8, 355153 6690457.2 23.3, 355114.7752287366 6690471.022695063 24.689991682306335)
TRONROUT0000000295264936;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354641.4 6690158.2 34.9, 354653.2 6690171.5 35.1)
TRONROUT0000000029477825;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354614.5 6690181.7 34.9, 354591.7 6690154.8 34.4)
TRONROUT0000000295264769;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354614.5 6690181.7 34.9, 354641.4 6690158.2 34.9)
TRONROUT0000000295264806;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354523.3 6690191.9 33.4, 354551.2 6690171.7 34.1, 354569.7 6690199.4 33.6)
TRONROUT0000000295264888;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354632.9 6690203.4 35, 354642.4 6690187.4 35.1, 354653.2 6690171.5 35.1)
TRONROUT0000000295264965;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354518.5 6690185.1 33.5, 354523.3 6690191.9 33.4)
TRONROUT0000000029477842;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354632.9 6690203.4 35, 354614.5 6690181.7 34.9)
TRONROUT0000000029477851;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354588.2 6690227.2 33.2, 354586.8 6690219.9 33.5, 354588.5 6690211.6 34, 354591.1 6690207 34.1, 354587.5 6690199.5 34.1, 354597.9 6690190.7 34.9, 354614.5 6690181.7 34.9)
TRONROUT0000000295264912;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354523.3 6690191.9 33.4, 354542.1 6690218.3 33.2)
TRONROUT0000000295265017;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354542.1 6690218.3 33.2, 354569.7 6690199.4 33.6)
TRONROUT0000000029477677;Route à 1 chaussée;R D'AUVOURS;R D'AUVOURS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;19;8;13;44109;44109;;;;441090480;441090480;;;;;;;;;;;;;commune;commune;Rue d'Auvours;Rue d'Auvours;;;44109_0480;44109_0480;;;;;LINESTRING Z (354729 6690197.4 34.8, 354774.1 6690162.7 34.2)
TRONROUT0000002003976258;Route à 1 chaussée;AV CHARLES JEGOU;AV CHARLES JEGOU;5;Non;0;En service;2017-06-01 17:22:40;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Sens direct;;Oui;0;Restreint aux ayants droit;Libre;;;;;;;;Non;1;;7;;44109;44109;;;;44109#0QC;44109#0QC;;;;;;;;;;;;;commune;commune;Avenue Charles Jegou;Avenue Charles Jegou;;;44109_1714;44109_1714;;;;;LINESTRING Z (354755.1 6690225.1 35.4, 354792.7 6690194.3 35, 354794.6 6690189.6 35, 354776.4 6690166.6 34.6, 354774.1 6690162.7 34.2)
TRONROUT0000000324171798;Sentier;;;6;Non;0;En service;2013-07-25 18:52:41;2020-02-12 17:33:37;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354667 6690185.1 -1000, 354677.3 6690195 -1000, 354679.4 6690202.1 -1000, 354679.9 6690210.5 -1000)
TRONROUT0000000029477691;Route à 1 chaussée;R DU BOURGET;R DU BOURGET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091152;441091152;;;;;;;;;;;;;commune;commune;Rue du Bourget;Rue du Bourget;;;44109_1152;44109_1152;;;;;LINESTRING Z (354755.1 6690225.1 35.4, 354740.6 6690209.6 35.8, 354729 6690197.4 34.8)
TRONROUT0000000029477827;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354717.2 6690204 34.4, 354696.8 6690220 34.9)
TRONROUT0000000295264985;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2013-07-25 18:52:41;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354679.9 6690210.5 35.3, 354683.8 6690216.1 35.2)
TRONROUT0000000324171817;Sentier;;;6;Non;0;En service;2013-07-25 18:52:41;;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354651.8 6690225.8 35.3, 354679.9 6690210.5 35.3)
TRONROUT0000000295265036;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354683.8 6690216.1 35.2, 354690.1 6690225.3 35)
TRONROUT0000000295265081;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-09-28 17:32:01;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354745.3 6690230 33.9, 354731.3 6690213.5 33.9, 354728.6 6690213.3 33.9, 354710.5 6690227.3 33.9, 354696.8 6690220 34.9)
TRONROUT0000000295264762;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354696.8 6690220 34.9, 354690.1 6690225.3 35)
TRONROUT0000000029474145;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354905.3 6690136.1 31.5, 354903.2 6690135.6 31.1)
TRONROUT0000000029473767;Route à 1 chaussée;PL VIARME;PL VIARME;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441098404;441098404;;;;;;;;;;;;;commune;commune;Place Viarme;Place Viarme;;;44109_8404;44109_8404;;;;;LINESTRING Z (354903.2 6690135.6 31.1, 354896.3 6690135.7 31.9, 354893.1 6690136.5 31.9, 354890.6 6690138.5 31.9)
TRONROUT0000000029473842;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354890.6 6690138.5 31.9, 354888.1 6690142.3 31.9, 354875.2 6690170.4 32.1)
TRONROUT0000000029473483;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;4;3;2;1;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354890.8 6690175.2 31.8, 354905.3 6690136.1 31.5)
TRONROUT0000000029473482;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354890.8 6690175.2 31.8, 354875.2 6690170.4 32.1)
TRONROUT0000000295265193;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;5;4;5;4;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354890.8 6690175.2 31.8, 354884.8 6690187.9 32.2)
TRONROUT0000000029474260;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;1;2;13;10;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354920.4 6690144 32.5, 354888.6 6690222.7 34)
TRONROUT0000000029473781;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354875.2 6690170.4 32.1, 354871 6690180.3 32.4, 354857.7 6690210.1 32.9)
TRONROUT0000000029473459;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;6;;6;;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354878.4 6690200 32.9, 354884.8 6690187.9 32.2)
TRONROUT0000000029477797;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;15;;1;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354814 6690284.2 33.4, 354818.4 6690274.8 33.5, 354839.1 6690227.8 33.4, 354868.1 6690162.2 32.6, 354883.2 6690128.8 32.4, 354885.4 6690124.7 32.3)
TRONROUT0000000029477847;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354787 6690258.9 34.7, 354804.6 6690247.5 34.8, 354811.4 6690241.2 34.8, 354813.8 6690237.9 34.8, 354852.7 6690153.2 34.1)
TRONROUT0000000295265191;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;8;7;8;7;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354870.7 6690215 32.9, 354878.4 6690200 32.9)
TRONROUT0000000029473468;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354857.7 6690210.1 32.9, 354870.7 6690215 32.9)
TRONROUT0000000029473461;Sentier;COUR DE LA BROCANTE;COUR DE LA BROCANTE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109A053;44109A053;;;;;;;;;;;;;commune;commune;Cour de la Brocante;Cour de la Brocante;;;44109_a053;44109_a053;;;;;LINESTRING Z (354870.7 6690215 32.9, 354858.8 6690238.4 32.9)
TRONROUT0000000295264861;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2012-02-08 10:00:49;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354857.7 6690210.1 32.9, 354842.6 6690243.9 33.2)
TRONROUT0000000029475036;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;15;;13;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354888.6 6690222.7 34, 354880.4 6690241.7 33.9)
TRONROUT0000000295265196;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;1;;1;;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354858.8 6690238.4 32.9, 354854.1 6690247.7 32.9)
TRONROUT0000000295265044;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 17:30:28;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354854.1 6690247.7 32.9, 354842.6 6690243.9 33.2)
TRONROUT0000000029474413;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354842.6 6690243.9 33.2, 354841.9 6690245.3 33.3, 354834.5 6690263.3 33)
TRONROUT0000000029473455;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;10;2;10;2;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354850.6 6690262.1 33.1, 354854.1 6690247.7 32.9)
TRONROUT0000000295264767;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354569.7 6690199.4 33.6, 354588.2 6690227.2 33.2)
TRONROUT0000000295264799;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354651.8 6690225.8 35.3, 354632.9 6690203.4 35)
TRONROUT0000000295265008;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354627.9 6690239.2 34.6, 354623.1 6690230.6 34.7, 354624.8 6690222.1 34.7, 354629.3 6690210.5 34.7, 354632.9 6690203.4 35)
TRONROUT0000000295265061;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354515.8 6690236.5 32.9, 354542.1 6690218.3 33.2)
TRONROUT0000000295264971;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354542.1 6690218.3 33.1, 354562.2 6690246.1 33.1)
TRONROUT0000000295265087;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354627.9 6690239.2 34.7, 354651.8 6690225.8 35.3)
TRONROUT0000000029477794;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354562.2 6690246.1 33.1, 354588.2 6690227.2 33.2)
TRONROUT0000000029477832;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354588.2 6690227.2 33.2, 354606.4 6690251.2 34)
TRONROUT0000000295264941;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354606.4 6690251.2 34, 354627.9 6690239.2 34.7)
TRONROUT0000000295264926;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354627.9 6690239.2 34.6, 354638 6690251.4 34.7)
TRONROUT0000000295264734;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354683.8 6690216.1 35.1, 354658.9 6690234.7 35.5)
TRONROUT0000000295264914;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354690.1 6690225.3 35, 354696.8 6690234 34.7)
TRONROUT0000000295264809;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354658.9 6690234.7 35.5, 354652.5 6690226.6 35.4, 354651.8 6690225.8 35.3)
TRONROUT0000000295264738;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354733.4 6690239.1 33.2, 354745.3 6690230 33.9)
TRONROUT0000000295264894;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354696.8 6690220 34.9, 354719.9 6690249.2 32.5)
TRONROUT0000000295264786;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354690.1 6690225.3 35, 354666.3 6690244 35.7)
TRONROUT0000000295265006;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354757 6690243.9 33.9, 354745.3 6690230 33.9)
TRONROUT0000000295264816;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354666.3 6690244 35.7, 354658.9 6690234.7 35.5)
TRONROUT0000002003976259;Route à 1 chaussée;R DU BOURGET;R DU BOURGET;5;Non;0;En service;2017-06-01 17:22:40;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;20;;20;;44109;44109;;;;441091152;441091152;;;;;;;;;;;;;commune;commune;Rue du Bourget;Rue du Bourget;;;44109_1152;44109_1152;;;;;LINESTRING Z (354787 6690258.9 34.7, 354755.1 6690225.1 35.4)
TRONROUT0000000295264957;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354658.9 6690234.7 35.5, 354638 6690251.4 34.7)
TRONROUT0000000295265053;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354696.8 6690234 34.6, 354672.8 6690252.3 35.2)
TRONROUT0000000295265102;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354719.9 6690249.2 32.5, 354733.4 6690239.1 33.2)
TRONROUT0000000295265068;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354733.4 6690239.1 33.1, 354744.8 6690252.5 34)
TRONROUT0000000295265029;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354696.8 6690234 34.7, 354716.2 6690259.5 33.9)
TRONROUT0000000295264783;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354672.8 6690252.3 35.2, 354666.3 6690244 35.7)
TRONROUT0000000295264998;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354744.8 6690252.5 34, 354757 6690243.9 33.9)
TRONROUT0000000295264921;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354719.9 6690249.2 32.5, 354730.6 6690262.6 34.1)
TRONROUT0000000295264736;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354730.6 6690262.6 34, 354744.8 6690252.5 34)
TRONROUT0000000295265033;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354672.8 6690252.3 35.2, 354652.1 6690268.6 35.1)
TRONROUT0000000295264916;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-05-24 11:34:27;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354742.3 6690277.4 33.9, 354768.4 6690257.4 33.9, 354757 6690243.9 33.9)
TRONROUT0000000029478674;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354515.8 6690236.5 32.9, 354536.4 6690264.9 33.1)
TRONROUT0000000295264857;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354536.4 6690264.9 33.1, 354562.2 6690246.1 33.1)
TRONROUT0000000295264850;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354606.4 6690251.2 34, 354618.6 6690267.2 34.8)
TRONROUT0000000295265028;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354638 6690251.4 34.6, 354618.6 6690267.2 34.8)
TRONROUT0000000029477846;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354666.3 6690244 35.7, 354625.4 6690276.2 35.2)
TRONROUT0000000295265073;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354562.2 6690246.1 33.1, 354583.9 6690277.9 33.1)
TRONROUT0000000295264948;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354583.9 6690277.9 33, 354606.4 6690251.2 34)
TRONROUT0000000295264836;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354618.6 6690267.2 34.8, 354625.4 6690276.2 35.2)
TRONROUT0000000295264828;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354536.4 6690264.9 33.1, 354552.8 6690287.4 33.8)
TRONROUT0000000295264934;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354652.1 6690268.6 35.1, 354631.6 6690284.6 34.9)
TRONROUT0000000295265192;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354847.9 6690268.7 33, 354850.6 6690262.1 33.1)
TRONROUT0000000029473475;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354834.5 6690263.3 33, 354847.9 6690268.7 33)
TRONROUT0000002333233103;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2023-06-06 17:30:28;;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;17;20;31B;24;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354880.4 6690241.7 33.9, 354867.3 6690272.5 35.5, 354858.3 6690291.7 34.8, 354858 6690292.3 34.7)
TRONROUT0000002333233102;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2023-06-06 17:30:28;;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354834.5 6690263.3 33, 354827.8 6690277.7 33, 354827 6690279.5 33)
TRONROUT0000000029477808;Route à 1 chaussée;R DU BOURGET;R DU BOURGET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091152;441091152;;;;;;;;;;;;;commune;commune;Rue du Bourget;Rue du Bourget;;;44109_1152;44109_1152;;;;;LINESTRING Z (354787 6690258.9 34.7, 354804.8 6690279.1 34.7, 354808.6 6690282.3 34.7, 354814 6690284.2 33.4)
TRONROUT0000000295265194;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354847.9 6690268.7 33, 354844 6690276.1 33.1)
TRONROUT0000000029477586;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;9;8;9;3;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354840.2 6690284.9 33.1, 354844 6690276.1 33.1)
TRONROUT0000002333233100;Sentier;;;6;Non;0;En service;2023-06-06 17:30:28;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354827 6690279.5 -1000, 354840.2 6690284.9 -1000)
TRONROUT0000000029477665;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354827 6690279.5 33, 354824.5 6690285 33, 354818.9 6690297.1 32.6)
TRONROUT0000002333233101;Sentier;;;6;Non;0;En service;2023-06-06 17:30:28;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354840.2 6690284.9 -1000, 354858 6690292.3 -1000)
TRONROUT0000000029477852;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354692.7 6690277.7 34, 354672.8 6690252.3 35.2)
TRONROUT0000000029477824;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354716.2 6690259.5 33.9, 354692.7 6690277.7 34)
TRONROUT0000000295265086;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354730.6 6690262.6 34.1, 354742.3 6690277.4 33.9)
TRONROUT0000000295265012;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354716.2 6690259.5 33.9, 354734 6690283.7 33.9)
TRONROUT0000000029477782;Route à 1 chaussée;R DU LIMOUSIN;R DU LIMOUSIN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094996;441094996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354747.4 6690286.9 34.7, 354787 6690258.9 34.7)
TRONROUT0000000295264931;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354734 6690283.7 33.9, 354742.3 6690277.4 33.9)
TRONROUT0000000295265021;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354652.1 6690268.6 35, 354671.7 6690294 34.1)
TRONROUT0000000029477845;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354692.7 6690277.7 34, 354671.7 6690294 34.1)
TRONROUT0000000029477830;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354712 6690302.2 35.6, 354692.7 6690277.7 34)
TRONROUT0000000295264942;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354734 6690283.7 33.9, 354712 6690302.2 35.6)
TRONROUT0000000029478097;Route à 1 chaussée;R DE MISERICORDE;R DE MISERICORDE;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;32;73;20;57;44109;44109;;;;441095680;441095680;;;;;;;;;;;;;commune;commune;Rue de Miséricorde;Rue de Miséricorde;;;44109_5680;44109_5680;;;;;LINESTRING Z (354381.7 6690257.8 29.4, 354362.9 6690262.2 29.1, 354325.9 6690272.6 28.5, 354304.5 6690278 27.9, 354297.3 6690280.8 28)
TRONROUT0000000029478334;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;32;31;14;17;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354103.2 6690290.5 20.7, 354201.5 6690259.8 26.7)
TRONROUT0000000029478462;Route à 1 chaussée;R ALEXANDRE DUMAS;R ALEXANDRE DUMAS;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;26;29;26;29;44109;44109;;;;441090088;441090088;;;;;;;;;;;;;commune;commune;Rue Alexandre Dumas;Rue Alexandre Dumas;;;44109_0088;44109_0088;;;;;LINESTRING Z (354226.4 6690316.9 26.9, 354201.5 6690259.8 26.7)
TRONROUT0000000029478506;Route à 1 chaussée;R DE CARCOUET;R DE CARCOUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1;6;11;12;44109;44109;;;;441091424;441091424;;;;;;;;;;;;;commune;commune;Rue de Carcouet;Rue de Carcouet;;;44109_1424;44109_1424;;;;;LINESTRING Z (354297.3 6690280.8 28, 354226.4 6690316.9 26.9)
TRONROUT0000000029478316;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;57;56;63B;68;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354297.3 6690280.8 28, 354284.9 6690360.8 29.6)
TRONROUT0000000029478197;Route à 1 chaussée;R DE CARCOUET;R DE CARCOUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;17;20;35;34;44109;44109;;;;441091424;441091424;;;;;;;;;;;;;commune;commune;Rue de Carcouet;Rue de Carcouet;;;44109_1424;44109_1424;;;;;LINESTRING Z (354226.4 6690316.9 26.9, 354102.3 6690346.6 21.5)
TRONROUT0000000029478192;Route à 1 chaussée;R GABRIEL LUNEAU;R GABRIEL LUNEAU;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;25;32;41;46;44109;44109;;;;441093420;441093420;;;;;;;;;;;;;commune;commune;Rue Gabriel Luneau;Rue Gabriel Luneau;;;44109_3420;44109_3420;;;;;LINESTRING Z (354284.9 6690360.8 29.6, 354398.3 6690313.3 30.8)
TRONROUT0000000029478124;Route à 1 chaussée;R ALEXANDRE DUMAS;R ALEXANDRE DUMAS;4;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;33;26;41;30;44109;44109;;;;441090088;441090088;;;;;;;;;;;;;commune;commune;Rue Alexandre Dumas;Rue Alexandre Dumas;;;44109_0088;44109_0088;;;;;LINESTRING Z (354253.8 6690384.2 29.3, 354226.4 6690316.9 26.9)
TRONROUT0000000029478507;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;3.0;10.5;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;65;;65;;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354284.9 6690360.8 29.6, 354282.8 6690374.6 30.2)
TRONROUT0000000029478668;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354360.4 6690359.9 31.7, 354379.7 6690383.7 32)
TRONROUT0000000029478570;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354469.5 6690313.8 32.9, 354502.2 6690289.8 33)
TRONROUT0000000295264958;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354441.6 6690334.9 32.9, 354424.2 6690299.7 31.9)
TRONROUT0000000295264918;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354485.2 6690334.4 33.1, 354518.4 6690311 33.6)
TRONROUT0000000029478687;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354469.5 6690313.8 32.9, 354485.2 6690334.4 33.1)
TRONROUT0000000295264846;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354469.5 6690313.8 32.9, 354441.6 6690334.9 32.9)
TRONROUT0000000029478664;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354398.3 6690313.3 30.8, 354404.6 6690335.5 30.9)
TRONROUT0000000029478553;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354441.6 6690334.9 32.9, 354438.6 6690337.2 32.9)
TRONROUT0000000295264730;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354485.2 6690334.4 33.1, 354502.8 6690357.5 33.5)
TRONROUT0000000295265063;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354455.6 6690357.8 33.5, 354485.2 6690334.4 33.1)
TRONROUT0000000029478562;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354455.6 6690357.8 33.5, 354438.6 6690337.2 32.9)
TRONROUT0000002204773374;Sentier;;;6;Non;0;En service;2019-10-01 15:05:30;2020-02-12 17:33:37;;;;;Fichier numérique non métrique;5.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (353933.2 6690278.5 -1000, 353892.0022898072 6690292.526629381 -1000)
TRONROUT0000000295264865;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;31B;36;31;36;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354103.2 6690290.5 20.7, 354087.6 6690296.3 20.1)
TRONROUT0000000295264860;Route à 1 chaussée;R OCTAVE FEUILLET;R OCTAVE FEUILLET;5;Non;0;En service;2012-02-08 10:00:49;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;47;;47;44109;44109;;;;441095996;441095996;;;;;;;;;;;;;commune;commune;Rue Octave Feuillet;Rue Octave Feuillet;;;44109_5996;44109_5996;;;;;LINESTRING Z (354103.2 6690290.5 20.7, 354102.9 6690308.2 17.9)
TRONROUT0000000295265105;Route à 1 chaussée;;;6;Non;0;En service;2012-02-08 10:00:49;2022-12-10 06:26:51;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;Piste cyclable;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354102.9 6690308.2 17.9, 354087.6 6690296.3 20.1)
TRONROUT0000000029478026;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;33;38;35B;40;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354087.6 6690296.3 20.1, 354063.2 6690305.3 19.2, 354059.9 6690307.4 19.2, 354055.2 6690312.2 18.9, 354051.6 6690318.5 18.8)
TRONROUT0000000029478441;Route à 1 chaussée;R OCTAVE FEUILLET;R OCTAVE FEUILLET;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;49;;49;44109;44109;;;;441095996;441095996;;;;;;;;;;;;;commune;commune;Rue Octave Feuillet;Rue Octave Feuillet;;;44109_5996;44109_5996;;;;;LINESTRING Z (354102.9 6690308.2 17.9, 354102.3 6690346.6 21.5)
TRONROUT0000000029478335;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;37;40;39;40;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354051.6 6690318.5 18.8, 354046.7 6690325.4 18.6, 354034.8 6690347.3 18.4, 354034.5 6690348 18.3)
TRONROUT0000000029477926;Route à 1 chaussée;R DES FOLIES CHAILLOU;R DES FOLIES CHAILLOU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1B;2;41;42;44109;44109;;;;441093176;441093176;;;;;;;;;;;;;commune;commune;Rue des Folies Chaillou;Rue des Folies Chaillou;;;44109_3176;44109_3176;;;;;LINESTRING Z (353933.2 6690278.5 18.2, 353935.4 6690284.8 17.9, 353959.7 6690352.7 15, 353970.5 6690385.3 16, 353976.2 6690405.3 16.6)
TRONROUT0000002274922994;Route à 1 chaussée;R DE CARCOUET;R DE CARCOUET;5;Non;0;En service;2021-11-10 11:34:43;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;37;36;41;46;44109;44109;;;;441091424;441091424;;;;;;;;;;;;;commune;commune;Rue de Carcouet;Rue de Carcouet;;;44109_1424;44109_1424;;;;;LINESTRING Z (354102.3 6690346.6 21.5, 354085.8 6690350.3 20.8, 354069.7 6690354.8 20.2)
TRONROUT0000000295265185;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;42;;42;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354034.5 6690348 18.3, 354035.4 6690352.8 18.3, 354036.5 6690358.6 18.4, 354038.1 6690361.8 18.4, 354041 6690364.3 19.1)
TRONROUT0000000029478673;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354438.6 6690337.2 32.9, 354409.7 6690360 32.4)
TRONROUT0000000295264940;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354519.7 6690344.3 34, 354502.8 6690357.5 33.5)
TRONROUT0000000029478581;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354409.7 6690360 32.4, 354397.8 6690344.6 31.9)
TRONROUT0000000295264852;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354502.8 6690357.5 33.5, 354510 6690366.9 33.7)
TRONROUT0000000295265024;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354502.8 6690357.5 33.5, 354474.1 6690380.1 34.1)
TRONROUT0000000295264790;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354474.1 6690380.1 34.1, 354455.6 6690357.8 33.5)
TRONROUT0000000295265085;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354425.9 6690381 33, 354455.6 6690357.8 33.5)
TRONROUT0000000029478671;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354425.9 6690381 33, 354409.7 6690360 32.4)
TRONROUT0000000029478698;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354409.7 6690360 32.4, 354379.7 6690383.7 32)
TRONROUT0000000029417632;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354510 6690366.9 33.7, 354481.4 6690388.9 34.5)
TRONROUT0000000295264792;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354481.4 6690388.9 34.5, 354474.1 6690380.1 34.1)
TRONROUT0000000295264932;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354487.2 6690396.6 34.6, 354515.7 6690374.3 33.8)
TRONROUT0000000295264951;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354474.1 6690380.1 34.1, 354443.8 6690404.3 33.5)
TRONROUT0000000295264856;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354443.8 6690404.3 33.5, 354425.9 6690381 33)
TRONROUT0000000295265045;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354396.5 6690404.3 32.1, 354425.9 6690381 33)
TRONROUT0000000029417651;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354487.2 6690396.6 34.6, 354481.4 6690388.9 34.5)
TRONROUT0000000295264774;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354379.7 6690383.7 32, 354396.5 6690404.3 32.1)
TRONROUT0000000029417623;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354481.4 6690388.9 34.5, 354450.4 6690412.8 33.9)
TRONROUT0000000295265089;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354456.4 6690420.5 33.9, 354487.2 6690396.6 34.6)
TRONROUT0000000295264859;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354450.4 6690412.8 33.9, 354443.8 6690404.3 33.5)
TRONROUT0000000029417488;Route à 1 chaussée;R CHARLES MONSELET;R CHARLES MONSELET;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;5.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441091736;441091736;;;;;;;;;;;;;commune;commune;Rue Charles Monselet;Rue Charles Monselet;;;44109_1736;44109_1736;;;;;LINESTRING Z (354282.8 6690374.6 30.2, 354282.1 6690379 30)
TRONROUT0000000029417414;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354253.8 6690384.2 29.3, 354255.3 6690384.7 29.3, 354261.2 6690384.3 29.8, 354282.1 6690379 30)
TRONROUT0000000029417614;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354350.2 6690406.9 31.5, 354327.5 6690376 31.1)
TRONROUT0000000029417613;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354379.7 6690383.7 32, 354350.2 6690406.9 31.5)
TRONROUT0000000029417425;Route à 1 chaussée;BD LUC OLIVIER MERSON;BD LUC OLIVIER MERSON;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;12;23;8;9;44109;44109;;;;441095160;441095160;;;;;;;;;;;;;commune;commune;Boulevard Luc Olivier Merson;Boulevard Luc Olivier Merson;;;44109_5160;44109_5160;;;;;LINESTRING Z (354110.2 6690385.2 22.7, 354189.8 6690407.5 27.3)
TRONROUT0000000029417469;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;4;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354282.1 6690379 30, 354277.9 6690400.7 29.8, 354270.9 6690436.9 29.6)
TRONROUT0000000029417482;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;2;;6;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354270.9 6690436.9 29.6, 354263.1 6690414.1 30.3, 354260.6 6690406.5 30.5, 354253.8 6690384.2 29.3)
TRONROUT0000000029417636;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354350.2 6690406.9 31.5, 354333.9 6690419.7 32)
TRONROUT0000000029417459;Route à 1 chaussée;BD LUC OLIVIER MERSON;BD LUC OLIVIER MERSON;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;6;7;6;1;44109;44109;;;;441095160;441095160;;;;;;;;;;;;;commune;commune;Boulevard Luc Olivier Merson;Boulevard Luc Olivier Merson;;;44109_5160;44109_5160;;;;;LINESTRING Z (354189.8 6690407.5 27.3, 354244.2 6690423.1 30.4)
TRONROUT0000000029417616;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354366.4 6690427.6 32, 354350.2 6690406.9 31.5)
TRONROUT0000000029477899;Route à 1 chaussée;R DE CARCOUET;R DE CARCOUET;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;49;;43;44109;44109;;;;441091424;441091424;;;;;;;;;;;;;commune;commune;Rue de Carcouet;Rue de Carcouet;;;44109_1424;44109_1424;;;;;LINESTRING Z (354041 6690364.3 19.1, 354047.3 6690361.6 19.1, 354063.6 6690356.6 20, 354069.7 6690354.8 20.2)
TRONROUT0000000295265188;Route à 1 chaussée;R GEORGE SAND;R GEORGE SAND;5;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;43;;41;44109;44109;;;;441093652;441093652;;;;;;;;;;;;;commune;commune;Rue George Sand;Rue George Sand;;;44109_3652;44109_3652;;;;;LINESTRING Z (354022.3 6690376.4 18, 354022.1 6690372.4 18, 354022.6 6690366.8 18, 354023.7 6690361.9 18, 354028 6690354.4 18, 354034.5 6690348 18.3)
TRONROUT0000002274922993;Route à 1 chaussée;;;5;Non;0;En service;2021-11-10 11:34:43;;;;;;Orthophotographie;3.0;Z corrigé;2.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354069.7 6690354.8 20.3, 354064.5 6690371.3 20.3)
TRONROUT0000002274922995;Route à 1 chaussée;BD LUC OLIVIER MERSON;BD LUC OLIVIER MERSON;4;Non;0;En service;2021-11-10 11:34:43;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;28;;26;;44109;44109;;;;441095160;441095160;;;;;;;;;;;;;commune;commune;Boulevard Luc Olivier Merson;Boulevard Luc Olivier Merson;;;44109_5160;44109_5160;;;;;LINESTRING Z (354041 6690364.3 19.1, 354064.5 6690371.3 20.3)
TRONROUT0000000029417453;Route à 1 chaussée;BD AUGUSTE PAGEOT;BD AUGUSTE PAGEOT;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090446;441090446;;;;;;;;;;;;;commune;commune;Boulevard Auguste Pageot;Boulevard Auguste Pageot;;;44109_0446;44109_0446;;;;;LINESTRING Z (354041 6690364.3 19.1, 354022.3 6690376.4 18)
TRONROUT0000000029478048;Route à 1 chaussée;BD LUC OLIVIER MERSON;BD LUC OLIVIER MERSON;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;24;35;18;33;44109;44109;;;;441095160;441095160;;;;;;;;;;;;;commune;commune;Boulevard Luc Olivier Merson;Boulevard Luc Olivier Merson;;;44109_5160;44109_5160;;;;;LINESTRING Z (354064.5 6690371.3 20.3, 354110.2 6690385.2 22.7)
TRONROUT0000000295265154;Route à 1 chaussée;BD AUGUSTE PAGEOT;BD AUGUSTE PAGEOT;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;1;6;3;6;44109;44109;;;;441090446;441090446;;;;;;;;;;;;;commune;commune;Boulevard Auguste Pageot;Boulevard Auguste Pageot;;;44109_0446;44109_0446;;;;;LINESTRING Z (354022.3 6690376.4 18, 353993.9 6690395.2 17.3, 353976.2 6690405.3 16.6)
TRONROUT0000000295265155;Route à 1 chaussée;BD AUGUSTE PAGEOT;BD AUGUSTE PAGEOT;4;Non;0;En service;2012-02-08 10:00:49;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;13;;5;44109;44109;;;;441090446;441090446;;;;;;;;;;;;;commune;commune;Boulevard Auguste Pageot;Boulevard Auguste Pageot;;;44109_0446;44109_0446;;;;;LINESTRING Z (353892.0022898072 6690451.039935068 16.3, 353892.4 6690450.9 16.3, 353903.5 6690445.2 16.1, 353931.4 6690431.1 15.9, 353951.2 6690418.6 16.5, 353967 6690409.3 16.7, 353976.2 6690405.3 16.6)
TRONROUT0000000029417471;Route à 1 chaussée;AV LOUIS VUILLEMIN;AV LOUIS VUILLEMIN;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;11B;2;5;44109;44109;;;;441095144;441095144;;;;;;;;;;;;;commune;commune;Avenue Louis Vuillemin;Avenue Louis Vuillemin;;;44109_5144;44109_5144;;;;;LINESTRING Z (354071.68659956806 6690471.022695063 27.00141057178319, 354104 6690402.9 23.6, 354110.2 6690385.2 22.7)
TRONROUT0000000039658041;Route à 1 chaussée;BD AUGUSTE PAGEOT;BD AUGUSTE PAGEOT;4;Non;0;En service;2006-11-08 14:30:04;2022-12-10 14:57:12;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090446;441090446;;;;;;;;;;;;;commune;commune;Boulevard Auguste Pageot;Boulevard Auguste Pageot;;;44109_0446;44109_0446;;;;;LINESTRING Z (353976.2 6690405.3 16.6, 353953.3 6690422 16.3, 353918.6 6690441.4 16.3, 353892.0022898072 6690454.455583357 16.381090579856508)
TRONROUT0000000295264855;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354506.4 6690422.2 35.1, 354487.2 6690396.6 34.6)
TRONROUT0000000295264760;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354396.5 6690404.3 32.1, 354410.5 6690421.5 32.4)
TRONROUT0000000295265083;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354443.8 6690404.3 33.5, 354414.9 6690427 32.5)
TRONROUT0000000295264923;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354366.4 6690427.6 32, 354396.5 6690404.3 32.1)
TRONROUT0000000295264776;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354456.4 6690420.5 33.9, 354450.4 6690412.8 33.9)
TRONROUT0000000029417631;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354450.4 6690412.8 33.9, 354421.5 6690435.1 32.6)
TRONROUT0000000295264754;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354410.5 6690421.5 32.4, 354414.9 6690427 32.5)
TRONROUT0000000029417608;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354414.9 6690427 32.5, 354421.5 6690435.1 32.6)
TRONROUT0000000295264962;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354427.9 6690443.3 32.6, 354456.4 6690420.5 33.9)
TRONROUT0000000029417572;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354476.2 6690445.8 34, 354456.4 6690420.5 33.9)
TRONROUT0000000295264911;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354380.4 6690445.5 32.5, 354410.5 6690421.5 32.4)
TRONROUT0000000029417612;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354506.4 6690422.2 35.1, 354476.2 6690445.8 34)
TRONROUT0000000295265248;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354414.9 6690427 32.5, 354384.7 6690450.9 32.8)
TRONROUT0000000295264750;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354421.5 6690435.1 32.6, 354427.9 6690443.3 32.6)
TRONROUT0000000295264789;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354380.4 6690445.5 32.5, 354373.5 6690436.6 32.3)
TRONROUT0000000029417624;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354421.5 6690435.1 32.6, 354391.8 6690457.9 33.6)
TRONROUT0000000295264794;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354384.7 6690450.9 32.8, 354380.4 6690445.5 32.5)
TRONROUT0000000295264900;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354398.5 6690465.1 33.5, 354427.9 6690443.3 32.6)
TRONROUT0000000295264797;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354391.8 6690457.9 33.6, 354384.7 6690450.9 32.8)
TRONROUT0000000029417652;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354427.9 6690443.3 32.6, 354447.4 6690468.3 32.9)
TRONROUT0000000029417640;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354476.2 6690445.8 34, 354447.4 6690468.3 32.9)
TRONROUT0000000029417638;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354494.7 6690469.4 34.1, 354476.2 6690445.8 34)
TRONROUT0000000295265058;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354524.6 6690446.2 35, 354494.7 6690469.4 34.1)
TRONROUT0000000029417617;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354391.8 6690457.9 33.6, 354387.9 6690461.4 33.6)
TRONROUT0000000029417619;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354398.5 6690465.1 33.5, 354391.8 6690457.9 33.6)
TRONROUT0000000295264825;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354403.9784929333 6690471.022695063 33.5, 354398.5 6690465.1 33.5)
TRONROUT0000000029417630;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354447.4 6690468.3 32.9, 354443.90500201064 6690471.022695063 32.97853928066034)
TRONROUT0000000029417552;Route à 1 chaussée;R DU MOULIN DES GROLLES;R DU MOULIN DES GROLLES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441095822;441095822;;;;;;;;;;;;;commune;commune;Rue du Moulin des Grolles;Rue du Moulin des Grolles;;;44109_5822;44109_5822;;;;;LINESTRING Z (354511.2586839736 6690471.022695063 34.33308116597017, 354517.8 6690465 34.4, 354524.9 6690458.4 34.4)
TRONROUT0000000029417620;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354447.4 6690468.3 32.9, 354449.53172249114 6690471.022695063 32.93165924491744)
TRONROUT0000000295265108;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354494.7 6690469.4 34, 354492.91963416233 6690471.022695063 33.9474430749029)
TRONROUT0000000029478675;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354502.2 6690289.8 33, 354536.4 6690264.9 33.1)
TRONROUT0000000295265055;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354618.6 6690267.2 34.8, 354591.5 6690288.4 34.6)
TRONROUT0000000029477833;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354625.4 6690276.2 35.2, 354631.6 6690284.6 34.9)
TRONROUT0000000295265077;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354583.9 6690277.9 33, 354591.5 6690288.4 34.6)
TRONROUT0000000295265071;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354583.9 6690277.9 33, 354562.9 6690301.3 34.3)
TRONROUT0000000295264829;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354552.8 6690287.4 33.8, 354562.9 6690301.3 34.3)
TRONROUT0000000029477850;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354625.4 6690276.2 35.2, 354574 6690316.5 34.8)
TRONROUT0000000295264840;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354631.6 6690284.6 34.9, 354650.7 6690310.3 34.2)
TRONROUT0000000295264938;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354591.5 6690288.4 34.6, 354567.3 6690307.3 34.5)
TRONROUT0000000295265040;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354518.4 6690311 33.6, 354552.8 6690287.4 33.8)
TRONROUT0000002333233104;Sentier;COUR CATHUIS;COUR CATHUIS;6;Non;0;En service;2023-06-06 17:30:28;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;9;8;9;3;44109;44109;;;;441091506;441091506;;;;;;;;;;;;;commune;commune;Cour Cathuis;Cour Cathuis;;;44109_1506;44109_1506;;;;;LINESTRING Z (354832.4 6690302.8 33.2, 354840.2 6690284.9 33.1)
TRONROUT0000000029477734;Sentier;PL DE LA FONTAINE MORGANE;PL DE LA FONTAINE MORGANE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#089;44109#089;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354818.9 6690297.1 32.6, 354832.4 6690302.8 33.2)
TRONROUT0000000029473735;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;17;20;31B;24;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354858 6690292.3 34.7, 354849.6 6690310.1 34)
TRONROUT0000000029477750;Sentier;PL DE LA FONTAINE MORGANE;PL DE LA FONTAINE MORGANE;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;44109#089;44109#089;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354832.4 6690302.8 33.2, 354849.6 6690310.1 34)
TRONROUT0000000029477741;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354818.9 6690297.1 32.6, 354812.6 6690310.3 32.6, 354807.5 6690315.8 32.3)
TRONROUT0000000029477588;Sentier;COUR DES SONGES;COUR DES SONGES;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;8;4;9;1;44109;44109;;;;441097937;441097937;;;;;;;;;;;;;commune;commune;Cour des Songes;Cour des Songes;;;44109_7937;44109_7937;;;;;LINESTRING Z (354828.1 6690315.5 32.3, 354832.4 6690302.8 33.2)
TRONROUT0000000029477656;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354784.2 6690338.1 32.4, 354792.6 6690325.3 32.6, 354801.5 6690309.9 32.8, 354809.5 6690293.8 33.2, 354814 6690284.2 33.4)
TRONROUT0000000295265190;Sentier;COUR DES SONGES;COUR DES SONGES;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441097937;441097937;;;;;;;;;;;;;commune;commune;Cour des Songes;Cour des Songes;;;44109_7937;44109_7937;;;;;LINESTRING Z (354823.2 6690323.1 32.3, 354828.1 6690315.5 32.3)
TRONROUT0000000029477715;Sentier;COUR DES SONGES;COUR DES SONGES;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;5;;5;;44109;44109;;;;441097937;441097937;;;;;;;;;;;;;commune;commune;Cour des Songes;Cour des Songes;;;44109_7937;44109_7937;;;;;LINESTRING Z (354807.5 6690315.8 32.3, 354823.2 6690323.1 32.3)
TRONROUT0000000029477653;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354807.5 6690315.8 32.3, 354804 6690320.8 32.3, 354799.2 6690328.9 32)
TRONROUT0000000029477826;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354562.9 6690301.3 34.3, 354567.3 6690307.3 34.5)
TRONROUT0000000295265062;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354562.9 6690301.3 34.3, 354536.4 6690321.6 34)
TRONROUT0000000295264807;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354567.3 6690307.3 34.5, 354574 6690316.5 34.8)
TRONROUT0000000295265031;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354567.3 6690307.3 34.5, 354548.2 6690322.5 34)
TRONROUT0000000295264979;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-05-24 11:33:38;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354580.4 6690324.9 34.6, 354605.2 6690305.4 34.7, 354619.2 6690322.5 34.7, 354625 6690330.3 34.3)
TRONROUT0000000029478665;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354518.4 6690311 33.6, 354529.3 6690325.3 34)
TRONROUT0000000295264815;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354650.7 6690310.3 34.2, 354625 6690330.3 34.3)
TRONROUT0000000295264780;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354574 6690316.5 34.8, 354580.4 6690324.9 34.6)
TRONROUT0000000295264986;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354536.4 6690321.6 34, 354542 6690321 34, 354546.9 6690322 34, 354548.2 6690322.5 34)
TRONROUT0000000295264841;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354574 6690316.5 34.8, 354557.8 6690329.3 34.6)
TRONROUT0000000295264943;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354529.3 6690325.3 34, 354536.4 6690321.6 34)
TRONROUT0000000295264745;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354548.2 6690322.5 34, 354551.8 6690324.1 34, 354554.1 6690325.5 34, 354557.8 6690329.3 34.6)
TRONROUT0000000295264728;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354529.3 6690325.3 34, 354534.7 6690332.4 34.3)
TRONROUT0000000295265047;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354562.4 6690338.6 34.6, 354580.4 6690324.9 34.6)
TRONROUT0000000029477835;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354557.8 6690329.3 34.6, 354550.7 6690334.9 34.6)
TRONROUT0000000029477831;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354534.7 6690332.4 34.3, 354541.1 6690330.5 34.3, 354548.3 6690332.6 34.3, 354550.7 6690334.9 34.6)
TRONROUT0000000295264830;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354557.8 6690329.3 34.6, 354560.2 6690333.3 34.6, 354562.4 6690338.6 34.6)
TRONROUT0000000295265026;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354519.7 6690344.3 34, 354519.5 6690343.2 34, 354520 6690338.8 34, 354521.7 6690334.4 34, 354523.9 6690329.8 34, 354527.5 6690326.8 34, 354529.3 6690325.3 34)
TRONROUT0000000029477854;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354580.4 6690324.9 34.6, 354599.4 6690350.1 34.5)
TRONROUT0000000029477834;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354625 6690330.3 34.3, 354599.4 6690350.1 34.5)
TRONROUT0000000295264764;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354671.7 6690294 34.1, 354650.7 6690310.3 34.2)
TRONROUT0000000295265103;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354671.7 6690294 34.1, 354690 6690318.5 35.8)
TRONROUT0000000029477684;Route à 1 chaussée;R DU LIMOUSIN;R DU LIMOUSIN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094996;441094996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354691.3 6690329.8 34.5, 354747.4 6690286.9 34.7)
TRONROUT0000000295264961;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354712 6690302.2 35.5, 354690 6690318.5 35.8)
TRONROUT0000000029477745;Route à 1 chaussée;R DU PERIGORD;R DU PERIGORD;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;4;5;2;1;44109;44109;;;;441096348;441096348;;;;;;;;;;;;;commune;commune;Rue du Périgord;Rue du Périgord;;;44109_6348;44109_6348;;;;;LINESTRING Z (354784.2 6690338.1 32.4, 354776 6690327.3 32.6, 354747.4 6690286.9 34.7)
TRONROUT0000000029477784;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354650.7 6690310.3 34.2, 354668.5 6690334.4 36)
TRONROUT0000000295265088;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354690 6690318.5 35.8, 354668.5 6690334.4 36)
TRONROUT0000000295265046;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354668.5 6690334.4 36, 354642.5 6690353.5 34.3)
TRONROUT0000000029477849;Route à 1 chaussée;R DU LIMOUSIN;R DU LIMOUSIN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094996;441094996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354637.1 6690371.3 34.5, 354674.5 6690343 34.8, 354691.3 6690329.8 34.5)
TRONROUT0000000029477748;Route à 1 chaussée;R DE SAINTONGE;R DE SAINTONGE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;6;5;2;1;44109;44109;;;;441097708;441097708;;;;;;;;;;;;;commune;commune;Rue de Saintonge;Rue de Saintonge;;;44109_7708;44109_7708;;;;;LINESTRING Z (354691.3 6690329.8 34.5, 354732.6 6690384.7 31.6, 354735.5 6690387 31.4, 354738.5 6690387.9 31.3, 354742.4 6690387.3 31.2, 354753.3 6690384.4 31.1)
TRONROUT0000000029477841;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354533.3 6690348.8 34.3, 354531.1 6690344.1 34.3, 354530.7 6690341.4 34.3, 354532.2 6690336 34.3, 354534.7 6690332.4 34.3)
TRONROUT0000000295265090;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354625 6690330.3 34.3, 354642.5 6690353.5 34.3)
TRONROUT0000000029477840;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354550.7 6690334.9 34.6, 354552.5 6690337.3 34.6, 354553 6690343.4 34.6, 354551.3 6690348.5 34.6, 354549.7 6690350.4 34.6)
TRONROUT0000000295264969;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354554.9 6690357.4 34.6, 354559.8 6690351.8 34.6, 354561.5 6690348.2 34.6, 354562.2 6690344.3 34.6, 354562.4 6690338.6 34.6)
TRONROUT0000000295264758;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354525 6690355.2 34, 354521.8 6690350.8 34, 354520.1 6690346.7 34, 354519.7 6690344.3 34)
TRONROUT0000000029477823;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354549.7 6690350.4 34.6, 354545.8 6690352.1 34.6, 354541.6 6690352.4 34.6, 354536.5 6690351.2 34.5, 354533.3 6690348.8 34.3)
TRONROUT0000000295264849;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354533.3 6690348.8 34.3, 354525 6690355.2 34)
TRONROUT0000000029477795;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354554.9 6690357.4 34.6, 354549.7 6690350.4 34.6)
TRONROUT0000000295265034;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354532.9 6690361.2 33.8, 354530.9 6690360.2 33.8, 354528.5 6690359 33.8, 354525 6690355.2 34)
TRONROUT0000000295264966;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354532.9 6690361.2 33.8, 354537.7 6690362 33.8, 354544.2 6690362 33.8, 354551.3 6690359.8 33.8, 354554.9 6690357.4 34.6)
TRONROUT0000000029478651;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354525 6690355.2 34, 354510 6690366.9 33.7)
TRONROUT0000000029477790;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354599.4 6690350.1 34.5, 354617.4 6690374 34.8)
TRONROUT0000000029477838;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354599.4 6690350.1 34.5, 354567.6 6690374.7 34.6)
TRONROUT0000000295265078;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354642.5 6690353.5 34.3, 354617.4 6690374 34.8)
TRONROUT0000000295264853;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354567.6 6690374.7 34.6, 354554.9 6690357.4 34.6)
TRONROUT0000000295265003;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354515.7 6690374.3 33.8, 354532.9 6690361.2 33.8)
TRONROUT0000000295264793;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354510 6690366.9 33.7, 354515.7 6690374.3 33.8)
TRONROUT0000000295264937;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354617.4 6690374 34.8, 354585.4 6690398.8 34.6)
TRONROUT0000000029417401;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354585.4 6690398.8 34.6, 354567.6 6690374.7 34.6)
TRONROUT0000000029417627;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354515.7 6690374.3 33.8, 354535.2 6690399.9 34.5)
TRONROUT0000000029477744;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354753.3 6690384.4 31.1, 354766.7 6690368.5 31.3, 354768.5 6690364.3 31.4, 354771.9 6690356.7 31.4, 354773.9 6690353.2 31.4, 354784.2 6690338.1 32.4)
TRONROUT0000000029477655;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354788.8 6690344.9 31.7, 354780 6690359 31.2, 354765.7 6690377.9 31.1, 354749.1 6690397.1 30.7)
TRONROUT0000000029417346;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354749.1 6690397.1 30.7, 354741 6690406.7 30.3)
TRONROUT0000000029417395;Sentier;SQ DES LAVANDIERES;SQ DES LAVANDIERES;6;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;2;;2;44109;44109;;;;44109#0DF;44109#0DF;;;;;;;;;;;;;commune;commune;Square des Lavandières;Square des Lavandières;;;44109_4831;44109_4831;;;;;LINESTRING Z (354749.1 6690397.1 30.7, 354761.7 6690408.4 31)
TRONROUT0000000029417372;Route à 1 chaussée;R D'AUNIS;R D'AUNIS;5;Non;0;En service;2006-10-04 09:41:10;2023-05-27 02:00:25;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;6;5;2;1;44109;44109;;;;441090472;441090472;;;;;;;;;;;;;commune;commune;Rue d'Aunis;Rue d'Aunis;;;44109_0472;44109_0472;;;;;LINESTRING Z (354694.1 6690447.9 30.2, 354687.8 6690439.3 30.9, 354641.4 6690379.6 34.1, 354637.1 6690371.3 34.5)
TRONROUT0000000029417345;Sentier;SQ DES LAVANDIERES;SQ DES LAVANDIERES;6;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;1;;1;44109;44109;;;;44109#0DF;44109#0DF;;;;;;;;;;;;;commune;commune;Square des Lavandières;Square des Lavandières;;;44109_4831;44109_4831;;;;;LINESTRING Z (354761.7 6690408.4 31, 354777.2 6690420 31.5)
TRONROUT0000000029417375;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354694.1 6690447.9 30.2, 354697.5 6690444.7 30.2, 354716.2 6690425.5 30.7, 354734.1 6690406.2 31, 354750.6 6690387.7 31.1, 354753.3 6690384.4 31.1)
TRONROUT0000000029417352;Sentier;SQ DES LAVANDIERES;SQ DES LAVANDIERES;6;Non;0;En service;2006-10-04 09:41:10;2023-03-17 03:41:53;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;;;;;44109;44109;;;;44109#0DF;44109#0DF;;;;;;;;;;;;;commune;commune;Square des Lavandières;Square des Lavandières;;;44109_4831;44109_4831;;;;;LINESTRING Z (354767.1 6690432.7 -1000, 354741 6690406.7 -1000)
TRONROUT0000000029417337;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;42;;42;;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354777.2 6690420 31.5, 354771 6690428.5 31.3, 354767.1 6690432.7 31.3)
TRONROUT0000000029417376;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-02-01 08:19:52;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354741 6690406.7 30.3, 354733 6690415.4 30.1, 354723.7 6690425.3 29.9, 354715.3 6690433.9 29.9, 354697.2 6690452 29.8)
TRONROUT0000000029417392;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354567.6 6690374.7 34.6, 354535.2 6690399.9 34.5)
TRONROUT0000000029417391;Route à 1 chaussée;R DU LIMOUSIN;R DU LIMOUSIN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094996;441094996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354580.6 6690415.5 33.8, 354637.1 6690371.3 34.5)
TRONROUT0000000029417621;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354535.2 6690399.9 34.5, 354506.4 6690422.2 35.1)
TRONROUT0000000295264989;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354585.4 6690398.8 34.5, 354553.4 6690423.7 35.1)
TRONROUT0000000029417400;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354535.2 6690399.9 34.5, 354553.4 6690423.7 35.1)
TRONROUT0000000029417629;Sentier;;;6;Non;0;En service;2006-10-04 09:41:10;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354524.6 6690446.2 35.1, 354506.4 6690422.2 35.1)
TRONROUT0000000295265002;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354553.4 6690423.7 35, 354524.6 6690446.2 35.1)
TRONROUT0000000029417344;Route à 1 chaussée;R DU LIMOUSIN;R DU LIMOUSIN;5;Non;0;En service;2006-10-04 09:41:10;2011-09-06 09:02:18;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094996;441094996;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354524.9 6690458.4 34.4, 354574.7 6690419.9 33.8, 354580.6 6690415.5 33.8)
TRONROUT0000000029417380;Route à 1 chaussée;R D'ANGOUMOIS;R D'ANGOUMOIS;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;8;7;2;1;44109;44109;;;;441090296;441090296;;;;;;;;;;;;;commune;commune;Rue d'Angoumois;Rue d'Angoumois;;;44109_0296;44109_0296;;;;;LINESTRING Z (354621.10712344194 6690471.022695063 31.704803959898744, 354580.6 6690415.5 33.8)
TRONROUT0000002202651408;Route à 1 chaussée;R DU BERRY;R DU BERRY;5;Non;0;En service;2019-05-20 14:56:03;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;7;2;1;44109;44109;;;;441090796;441090796;;;;;;;;;;;;;commune;commune;Rue du Berry;Rue du Berry;;;44109_0796;44109_0796;;;;;LINESTRING Z (354524.9 6690458.4 34.4, 354532.1878201681 6690471.022695063 33.78077344977291)
TRONROUT0000000295265187;Sentier;COUR DES FRANCS TIREURS;COUR DES FRANCS TIREURS;6;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;1;12;1;2;44109;44109;;;;44109A074;44109A074;;;;;;;;;;;;;commune;commune;Cour des Francs Tireurs;Cour des Francs Tireurs;;;44109_a074;44109_a074;;;;;LINESTRING Z (354718.8 6690453.3 29.9, 354729.4 6690442.9 29.9, 354735 6690435.7 29.9, 354742.6 6690429.2 29.9)
TRONROUT0000000029417394;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2010-05-04 21:42:19;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354694.1 6690447.9 30.2, 354695.8 6690449.9 29.9, 354697.2 6690452 29.8)
TRONROUT0000000029417326;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;42T;59;42B;53;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354730.9 6690468.5 30.6, 354737 6690463.4 31.2, 354767.1 6690432.7 31.3)
TRONROUT0000000029417393;Route à 1 chaussée;R MICHEL MONNIER;R MICHEL MONNIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0DH;44109#0DH;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354707.3 6690464.1 29.7, 354697.2 6690452 29.8)
TRONROUT0000000029415179;Sentier;COUR DES FRANCS TIREURS;COUR DES FRANCS TIREURS;6;Non;0;En service;2006-10-04 09:41:10;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;5;14;3;14;44109;44109;;;;44109A074;44109A074;;;;;;;;;;;;;commune;commune;Cour des Francs Tireurs;Cour des Francs Tireurs;;;44109_a074;44109_a074;;;;;LINESTRING Z (354707.3 6690464.1 -1000, 354714.9 6690457.7 -1000, 354718.8 6690453.3 29.9)
TRONROUT0000000029417366;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-01-19 14:06:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354697.2 6690452 29.8, 354680.1 6690468 29.6, 354676.7086835879 6690471.022695063 29.526275730171857)
TRONROUT0000000029417396;Route à 1 chaussée;R MICHEL MONNIER;R MICHEL MONNIER;5;Non;0;En service;2006-10-04 09:41:10;2023-05-26 09:18:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;44109#0DH;44109#0DH;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354712.75827879953 6690471.022695063 29.7, 354707.3 6690464.1 29.7)
TRONROUT0000000029417341;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354669.55598838395 6690471.022695063 29.937868344631198, 354679 6690462.2 30, 354694.1 6690447.9 30.2)
TRONROUT0000000029417350;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;46;59;44;59;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354727.7906316668 6690471.022695063 30.746668317604875, 354730.9 6690468.5 30.6)
TRONROUT0000000295266738;Sentier;COUR SANS NOM;COUR SANS NOM;6;Non;0;En service;2012-02-08 10:00:49;2023-04-07 14:37:21;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;Non;7;4;3;4;44109;44109;;;;441097815;441097815;;;;;;;;;;;;;commune;commune;Cour Sans Nom;Cour Sans Nom;;;44109_7815;44109_7815;;;;;LINESTRING Z (354707.3 6690464.1 -1000, 354701.8607395933 6690471.022695063 -1000)
TRONROUT0000002324048375;Route à 1 chaussée;R RUSSEIL;R RUSSEIL;5;Non;0;En service;2022-12-06 14:47:28;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;38;51;22;27;44109;44109;;;;441097516;441097516;;;;;;;;;;;;;commune;commune;Rue Russeil;Rue Russeil;;;44109_7516;44109_7516;;;;;LINESTRING Z (354947.8 6690282.4 31.9, 355036.1 6690338.8 28.7, 355044.8 6690344.4 28.4)
TRONROUT0000000029473597;Route à 1 chaussée;R DE FRIEDLAND;R DE FRIEDLAND;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;1B;2B;19B;14;44109;44109;;;;441093384;441093384;;;;;;;;;;;;;commune;commune;Rue de Friedland;Rue de Friedland;;;44109_3384;44109_3384;;;;;LINESTRING Z (354947.8 6690282.4 31.9, 354934.1 6690296.1 32.3, 354918.3 6690318.7 32.8, 354912.9 6690328.2 32.7, 354912.9 6690331.4 32.7, 354913.7 6690332.9 32.7, 354916 6690335.7 32.7, 354971.5 6690387 33)
TRONROUT0000000029474076;Route à 1 chaussée;R RUSSEIL;R RUSSEIL;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;38;51;22;27;44109;44109;;;;441097516;441097516;;;;;;;;;;;;;commune;commune;Rue Russeil;Rue Russeil;;;44109_7516;44109_7516;;;;;LINESTRING Z (355044.8 6690344.4 28.4, 355065.2 6690357.7 27.8)
TRONROUT0000000029415024;Route à 1 chaussée;R D'IENA;R D'IENA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;55;;49;44109;44109;;;;441094264;441094264;;;;;;;;;;;;;commune;commune;Rue d'Iéna;Rue d'Iéna;;;44109_4264;44109_4264;;;;;LINESTRING Z (354981.9 6690372.6 31.5, 354971.5 6690387 33)
TRONROUT0000002000619009;Route à 1 chaussée;PAS DES PETITES SOEURS DES PAUVRES;PAS DES PETITES SOEURS DES PAUVRES;5;Non;0;En service;2016-12-19 16:48:01;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;1;10;21;44109;44109;;;;44109#0Q9;44109#0Q9;;;;;;;;;;;;;commune;commune;Passage des Petites Soeurs des Pauvres;Passage des Petites Soeurs des Pauvres;;;44109_6505;44109_6505;;;;;LINESTRING Z (354995.6 6690470.5 27.4, 355065.2 6690357.7 27.8)
TRONROUT0000000029415156;Route à 1 chaussée;R D'IENA;R D'IENA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441094264;441094264;;;;;;;;;;;;;commune;commune;Rue d'Iéna;Rue d'Iéna;;;44109_4264;44109_4264;;;;;LINESTRING Z (354971.5 6690387 33, 354925.7 6690450.2 32.7)
TRONROUT0000002324048371;Sentier;;;6;Non;0;En service;2022-12-06 14:47:28;;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (355044.8 6690344.4 28.5, 355020.8 6690369.1 -1000, 355012.4 6690380.5 -1000, 354999 6690400.9 -1000, 354976.6 6690432.5 -1000, 354963.4 6690453.2 -1000, 354957.9 6690465.7 -1000, 354954.14681758406 6690471.022695063 -1000)
TRONROUT0000000029415150;Route à 1 chaussée;R D'IENA;R D'IENA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;11;33;27;29;44109;44109;;;;441094264;441094264;;;;;;;;;;;;;commune;commune;Rue d'Iéna;Rue d'Iéna;;;44109_4264;44109_4264;;;;;LINESTRING Z (354925.7 6690450.2 32.7, 354913.7 6690466.8 32.7)
TRONROUT0000002324048373;Route à 1 chaussée;PAS DES PETITES SOEURS DES PAUVRES;PAS DES PETITES SOEURS DES PAUVRES;5;Non;0;En service;2022-12-06 14:47:28;2022-12-10 14:57:12;;;;;Orthophotographie;3.0;Z corrigé;2.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;10;1;10;21;44109;44109;;;;44109#0Q9;44109#0Q9;;;;;;;;;;;;;commune;commune;Passage des Petites Soeurs des Pauvres;Passage des Petites Soeurs des Pauvres;;;44109_6505;44109_6505;;;;;LINESTRING Z (354995.8737926519 6690471.022695063 27.300439035661224, 354995.6 6690470.5 27.4)
TRONROUT0000002324048370;Sentier;;;6;Non;0;En service;2022-12-06 14:47:28;;;;;;Orthophotographie;3.0;Z corrigé;2.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;Libre;;;;;;;;;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354994.3937806244 6690471.022695063 27.4, 354995.6 6690470.5 27.4)
TRONROUT0000000295265186;Sentier;COUR DES SONGES;COUR DES SONGES;6;Non;0;En service;2012-02-08 10:00:49;2023-06-06 23:55:25;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;441097937;441097937;;;;;;;;;;;;;commune;commune;Cour des Songes;Cour des Songes;;;44109_7937;44109_7937;;;;;LINESTRING Z (354823.2 6690323.1 32.3, 354818 6690332.3 32.3)
TRONROUT0000000029477774;Route à 2 chaussées;R DU POITOU;R DU POITOU;4;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;;;;Photogrammétrie;2.5;Photogrammétrie;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;45;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441096732;441096732;;;;;;;;;;;;;commune;commune;Rue du Poitou;Rue du Poitou;;;44109_6732;44109_6732;;;;;LINESTRING Z (354799.2 6690328.9 32, 354788.8 6690344.9 31.7)
TRONROUT0000000029477764;Route à 1 chaussée;;;5;Non;0;En service;2006-10-04 09:41:10;2023-06-06 17:30:28;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Sens direct;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354788.8 6690344.9 33.8, 354787.6 6690342.5 33.8, 354784.2 6690338.1 33.8)
TRONROUT0000000029477626;Sentier;COUR DES SONGES;COUR DES SONGES;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;7;6;7;6;44109;44109;;;;441097937;441097937;;;;;;;;;;;;;commune;commune;Cour des Songes;Cour des Songes;;;44109_7937;44109_7937;;;;;LINESTRING Z (354795.7 6690350.7 32, 354798.8 6690343.1 -1000, 354801.9 6690338.7 -1000, 354809.8 6690342.1 -1000, 354813.2 6690338.3 -1000, 354818 6690332.3 32.3)
TRONROUT0000002333233105;Sentier;COUR DES VOLTIGEURS;COUR DES VOLTIGEURS;6;Non;0;En service;2023-06-06 17:30:28;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;1;10;5;44109;44109;;;;44109A132;44109A132;;;;;;;;;;;;;commune;commune;Cour des Voltigeurs;Cour des Voltigeurs;;;44109_a132;44109_a132;;;;;LINESTRING Z (354788.8 6690344.9 31.7, 354795.7 6690350.7 31.6)
TRONROUT0000000029477751;Route à 1 chaussée;R DES HAUTS PAVES;R DES HAUTS PAVES;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;33;26;51;40;44109;44109;;;;441094080;441094080;;;;;;;;;;;;;commune;commune;Rue des Hauts Pavés;Rue des Hauts Pavés;;;44109_4080;44109_4080;;;;;LINESTRING Z (354849.6 6690310.1 34, 354846.2 6690319.3 33.8, 354842.6 6690325.1 33.8, 354836.9 6690334.9 33.8, 354819.2 6690360.4 32.7, 354808.2 6690377.4 32.7, 354777.2 6690420 31.5)
TRONROUT0000000029477591;Sentier;COUR DES VOLTIGEURS;COUR DES VOLTIGEURS;6;Non;0;En service;2006-10-04 09:41:10;2023-06-06 23:55:25;;;;;Orthophotographie;3.0;Pas de Z;9999.0;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;2;1;10;5;44109;44109;;;;44109A132;44109A132;;;;;;;;;;;;;commune;commune;Cour des Voltigeurs;Cour des Voltigeurs;;;44109_a132;44109_a132;;;;;LINESTRING Z (354795.7 6690350.7 31.6, 354791.1 6690367.1 31.6, 354788.1 6690372.3 31.5, 354773 6690394.1 31.1, 354761.7 6690408.4 31)
TRONROUT0000000029415181;Route à 1 chaussée;R D'IENA;R D'IENA;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;1.0;3.0;Non;Non;Double sens;;Oui;30;Libre;;;;3.0;;;;;Non;1;2;27;8;44109;44109;;;;441094264;441094264;;;;;;;;;;;;;commune;commune;Rue d'Iéna;Rue d'Iéna;;;44109_4264;44109_4264;;;;;LINESTRING Z (354837.5 6690373.7 36.9, 354843.8 6690379.8 35.7, 354925.7 6690450.2 32.7)
TRONROUT0000002324048374;Route à 1 chaussée;R NOIRE;R NOIRE;5;Non;0;En service;2022-12-06 14:47:28;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;66;61;32;31;44109;44109;;;;441095952;441095952;;;;;;;;;;;;;commune;commune;Rue Noire;Rue Noire;;;44109_5952;44109_5952;;;;;LINESTRING Z (354767.1 6690432.7 31.3, 354795.5 6690462.5 29.5, 354804.2163926776 6690471.022695063 29.241736513255606)
TRONROUT0000000029417329;Route à 1 chaussée;R GENERAL BEDEAU;R GENERAL BEDEAU;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Sens direct;;Oui;30;Libre;;;;;;;;;Non;34;39;2;1;44109;44109;;;;441093552;441093552;;;;;;;;;;;;;commune;commune;Rue Général Bedeau;Rue Général Bedeau;;;44109_3552;44109_3552;;;;;LINESTRING Z (354730.9 6690468.5 30.6, 354732.95888117224 6690471.022695063 30.512731881239937)
TRONROUT0000000029417434;Route à 1 chaussée;R DE LA PELLETERIE;R DE LA PELLETERIE;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;6;13;2;1;44109;44109;;;;441096300;441096300;;;;;;;;;;;;;commune;commune;Rue de la Pelleterie;Rue de la Pelleterie;;;44109_6300;44109_6300;;;;;LINESTRING Z (354354.1856937318 6690471.022695063 33.1, 354351.4 6690468.1 33.1, 354341.4 6690457.7 32.5, 354323.8 6690426.1 31.5, 354303.3 6690387.7 30.3, 354301.3 6690384.4 30.3, 354299.5 6690382.2 30.2, 354295.8 6690378.9 30.2, 354282.8 6690374.6 30.2)
TRONROUT0000000029417555;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;;;;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354244.2 6690423.1 30.4, 354250.9 6690425.1 30.8, 354263.6 6690431.7 31.3, 354266.9 6690433.4 31.4, 354270.9 6690436.9 29.6)
TRONROUT0000000295264777;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;;;;BDTopo;2.5;BDTopo;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354373.5 6690436.6 32.3, 354366.4 6690427.6 32)
TRONROUT0000000295265080;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-05-24 11:11:00;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354333.9 6690419.7 32, 354357 6690450 32, 354373.5 6690436.6 32.3)
TRONROUT0000000029417578;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;;3;;3;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354263 6690458.1 31.2, 354267.5 6690444.1 31.3, 354270.9 6690436.9 29.6)
TRONROUT0000000029417602;Route à 1 chaussée;PL ANATOLE FRANCE;PL ANATOLE FRANCE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;4;5;4;5;44109;44109;;;;441090248;441090248;;;;;;;;;;;;;commune;commune;Place Anatole France;Place Anatole France;;;44109_0248;44109_0248;;;;;LINESTRING Z (354270.9 6690436.9 29.6, 354281.2 6690458.5 31.2)
TRONROUT0000000295264827;Sentier;;;6;Non;0;En service;2012-02-08 10:00:49;2012-02-13 08:57:14;;2009-07-01;;;Photogrammétrie;2.5;Photogrammétrie;1.5;;;Non;Non;Sans objet;;Oui;0;Physiquement impossible;;;;;;;;;Non;;;;;44109;44109;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;LINESTRING Z (354387.9 6690461.4 33.5, 354375.9086415377 6690471.022695063 33.30261138333696)
TRONROUT0000000029417479;Route à 1 chaussée;R PAUL PAINLEVE;R PAUL PAINLEVE;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;7.0;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;3;2;3;2B;44109;44109;;;;441096250;441096250;;;;;;;;;;;;;commune;commune;Rue Paul Painlevé;Rue Paul Painlevé;;;44109_6250;44109_6250;;;;;LINESTRING Z (354281.2 6690458.5 31.2, 354281.8 6690459.7 31.3, 354285.70437760773 6690471.022695063 31.64450390656786)
TRONROUT0000000029417516;Route à 1 chaussée;R CAMILLE FLAMMARION;R CAMILLE FLAMMARION;5;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;4.0;Non;Non;Double sens;;Oui;30;Libre;;;;;;;;;Non;34B;31;2;3;44109;44109;;;;441091386;441091386;;;;;;;;;;;;;commune;commune;Rue Camille Flammarion;Rue Camille Flammarion;;;44109_1386;44109_1386;;;;;LINESTRING Z (354160.6037874484 6690471.022695063 28.734053922166353, 354181 6690428.5 28, 354185.8 6690418.4 27.8, 354189.8 6690407.5 27.3)
TRONROUT0000000029417506;Route à 1 chaussée;BD MEUSNIER DE QUERLON;BD MEUSNIER DE QUERLON;4;Non;0;En service;2006-10-04 09:41:10;2022-12-10 14:57:12;;;;;BDTopo;2.5;BDTopo;1.5;2.0;10.5;Non;Non;Double sens;;Oui;40;Libre;;;;;;;;;Non;28;17;2;11;44109;44109;;;;441095620;441095620;;;;;;;;;;;;;commune;commune;Boulevard Meusnier de Querlon;Boulevard Meusnier de Querlon;;;44109_5620;44109_5620;;;;;LINESTRING Z (354256.9630162704 6690471.022695063 31.363449568282313, 354262.3 6690460.1 31.2, 354263 6690458.1 31.2)
""")
        return GeoDataFrameLib.read_csv(_sio)

    @staticmethod
    def plot(oFile=None):
        import matplotlib.pyplot as plt

        buildings = NantesBDT.buildings()
        roads = NantesBDT.roads()

        # MAPPING
        fig, ax = plt.subplots(figsize=(0.7 * 8.26, 1 * 8.26))
        ax.set_title(NantesBDT.version(), size=24)
        buildings.plot(ax=ax, color="grey")
        roads.plot(ax=ax, color="black")
        ax.axis("off")
        if oFile is None:
            fig.tight_layout()
            plt.show()
        else:
            plt.savefig(oFile, bbox_inches="tight")
        plt.close(fig)


# NantesBDT.plot()
